(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  17958046,     411804]*)
(*NotebookOutlinePosition[  18054279,     414938]*)
(*  CellTagsIndexPosition[  18054126,     414930]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Exploring \nMathematics and Science \nwith ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " "
}], "Title",
  TextAlignment->Center],

Cell["Dr. Rob Knapp", "Author",
  TextAlignment->Center],

Cell["Wolfram Research, Inc.", "Affiliation",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Initialization", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(Off[General::spell];\), "\[IndentingNewLine]", 
    RowBox[{\(Off[General::spell1]\), ";", 
      RowBox[{"Symbolize", "[", 
        TagBox["\[Placeholder]",
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], "]"}]}]}], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Symbolize::"bsymbexs" \(\(:\)\(\ \)\) 
      "Warning: The box structure attempting to be symbolized has a similar \
or identical symbol already defined, possibly overriding previously \
symbolized box structure."\)], "Message",
  CellLabel->"From In[2]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TalkDirectory\  = \ "\<C:\\Web\\RD_HTML\\RKnapp\\Talks\\India\>"\)], \
"Input",
  CellLabel->"In[4]:=",
  InitializationCell->True],

Cell[BoxData[
    \("C:\\Web\\RD_HTML\\RKnapp\\Talks\\India"\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[BoxData[
    \(\($Path\  = \ 
        Join[$Path, \ 
          Map[ToFileName[
                TalkDirectory, \ #] &, \ {"\<Data\>", \ \
"\<Packages\>"}]];\)\)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Needs["\<GUIKit`\>"]\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Needs["\<NumericalMath`EquationTrekker`\>"]\)], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Needs["\<Utilities`Notation`\>"]\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"Symbolize", "[", 
      TagBox[\(\[Lambda]\__\),
        NotationBoxTag,
        TagStyle->"NotationTemplateStyle"], "]"}]], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"Symbolize", "[", 
      TagBox[\(\[Phi]\__\),
        NotationBoxTag,
        TagStyle->"NotationTemplateStyle"], "]"}]], "Input",
  CellLabel->"In[10]:=",
  InitializationCell->True],

Cell["\<\
Define a function to simulate an initial displacement along a \
possible fault line.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(ldist[p1_, \ p2_]\)[
        p_?\((VectorQ[#, \ NumberQ] &)\)]\  := \[IndentingNewLine]If[
        p1\  \[Equal] \ p2, \[IndentingNewLine]Norm[
          p\  - \ p1], \[IndentingNewLine]\ 
        Module[{pp1, pp2, \ p12}, \[IndentingNewLine]pp1\  = \ 
            p\  - \ p1; \[IndentingNewLine]pp2\  = \ 
            p\  - \ p2; \[IndentingNewLine]p12\  = \ \((p1\  - \ p2)\)/
              Norm[p1\  - \ p2]; \[IndentingNewLine]If[
            Sign[p12 . pp1]\  != \ Sign[p12 . pp2], \[IndentingNewLine]Norm[
              pp1\  - \ pp1 . p12\ p12], \[IndentingNewLine]Min[Norm[pp1], \ 
              Norm[pp2]]]]]\)], "Input",
  CellLabel->"In[11]:=",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Exploration",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:X0000K2000`400?l0
0000o`00003oo`3ooooo0?ooojX0oooo003o0?ooool0ooooZP3oool00?l0
ooooo`3ooonZ0?ooo`00o`3ooooo0?ooojX0oooo003o0?ooool0ooooZP3o
ool000/0oooo1@3no_ko0?ooool0ooooJP3oool50?knoR/0oooo000:0?oo
o`D0o_kn00<0oOgm0?ooo`3oool0o`3ooooo0?ooofP0oooo00<0oOgm0?kn
oP3no_h00`3no_hZ0?ooo`00203ooooo0?kno_l0o_knNP3no_hX0?ooo`00
203oool40?knoP@0ooooo`3no_ko0?knoVX0o_kn103oool40?knoRP0oooo
00080?ooo`H0o_kn0P3moOgo0?kno_l0o_knJP3no_h20?gmo@H0o_kn:03o
ool000T0oooo00@0o_kn0?gmo@3lo?`0no_k0P3jn_X00`3inOT0no_k0?_k
n`3o0?_knol0no_kJ03kno/01`3inOT0n_[j0?[jnP3kno/0o?cl0?gmo@3n
o_h0:@3oool000T0oooo00D0o_kn0?gmo@3kno/0nOWi0?Shn03o0?Kfm_l0
m_KfKP3fm_H01@3hn?P0nOWi0?_kn`3moOd0o_kn02T0oooo00080?ooo`05
0?_lm`3jn_P0oOgm0?Sgo03fmOX00P3alO<00`3alO40k^k^0>o_k`050>o_
k`030?3`l03_knd0kno]07H0kno]103`l>h40>o_k@030>g]j`3`l>h0lO7_
0080l?3^00<0l_;`0?7ak`3_knd0203`l>h70?3`l0090>o_k`3^l_<0kNk`
0??dmP3Xj>P0m?Cd0>o]kP3dlo40kn_Z0600k_3]103_lNh40>k`k@<0ko7^
1@3^l>d<0>oakPL0k_3]0P3_lNh02`3^l>d0kNo/0>k`k@3]kNd0lO7a0?3`
l03/k>`0l?3`0>[ZjP3dm?@0kNg]06P0ko3b203^ko480>o`lP/0l?3b1@3_
ko430>o`lPD0k^oa0P3_lNh0203]kn`0k_3]0?3bk`3]kn`0k>k[0?3bk`3d
l>l0lno^0P3cko000`3bk^l0lNc`0?;]l@1Y0??^lPP0ko3b203bkO440>oa
l0@0k_3_0P3`l?060>o_k`80lNo`1P3`k^l02@3^k^h0lo?c0?7clP3_lo80
m_Sg0?[jnP3ln_/0oogn0?clo0020?ooo`040?gmo@3oool0oooo0?gmoB40
oooo00080?ooo`080?konP3knoT0nOWi0?Gem`3cl_L0knoa0>c/k03Vi^H4
0>WYj`@0j>SZN03WinL60>SXj080inOW00P0jNWY0>[ZjP3YjNT0inOW0>KV
iP3WinL0j>SX0>WYj@P0j>SX203Vi^H0203Yj^`0h>7S0>g^l03Xj>X0i>CT
0>cZj`3Th^<0k>[[H@3WjNH50>KXi@80iNOT203WinD80>OWi`T0j>SX0P3Y
jNT03@3WinL0iNGU0>GUi@3Vi^H0inOW0>OUiP3[jNX0i^CU0>WYj@3Xj>P0
k^k^0>7Qh@3WinL0J03Xj>P80>OWi`P0j>SX203YinP80>[Xj@T0inOW00l0
jNWY0>SXj03Xj>P0jn_[0>SXj03UiND0inOW0>;Wh`3VjnL0hnST0>GYj03P
i><0j^k]0>3Ti@3UjNX0J03UjNP80>SXj0P0iNWX203WinL@0>SVi`060>[X
j@3[jn/0k_3_0?;dl`3emoH0nOWi0P3mnOX01@3no_h0oooo0?gmo@3jn_X0
oOgm0080oooo00<0o_kn0?ooo`3oool07P3oool000P0oooo00P0oOgk0?kn
o03jn_X0lo?e0>[Zk03YjN/0i^KV0>GUh`80h^;T103QhN<20>3PhW00hn?U
203Rh^@70>7Qh`070>3PhP3ShnD0h>3R0=kNh03Ph>80hn?U0>GUi`020>CT
iPl0h^;T00T0hn?U0=oOh@3YjN/0gmoQ0>7Qh`3WinL0g=cL0>GUi@3Ogml0
H03Rh^850>?Sh`<0h^;R1@3ShN830>CRh`030>?Qi03Th^D0i>;U00D0i>;U
203Rh><40>7OhP0<0>GSiP3Xi^T0i^CW0>7OhP3Sh^00hN3N0>KTi@3ShN80
gmoO0>CTi03Vi^P0hn?UJ03Sh^0H0>;Qg`d0hn;P0`3Thn40403Qgn00hn7R
0>3Ng`3OgMh0hn7R0>CRh`3Rh>40hn7R0=kPg@3WjNH0fn3L0>?Xi03Pi><0
g>3O0=oUh`3Ni>9X0>3Rh@P0h^3Q203Qhn880>CRh`030>?QhP3Th^<0i>;S
00D0i>;S203ShN80203Rh>40iNGU0>SZj@3Xj^T0j^c[0?Cdm03mnOX0o_Sj
0P3oool30?knoP80oooo00<0oOgm0?ooo`3oool07P3oool000P0oooo00X0
no_i0?clo03cloD0knoa0>SXjP3/k>`0gmoM0=oPf`3Ng]h0gMgM0`3Lg=`3
0=gMgGP0g=cL00<0g]kN0=gMg@3MgMd01@3MgMd20=[JfP050=gMg@3Ph>00
g]kN0=[JfP3IfMT01P3Kfm/30=cLg0030=gMg`3Lg=h0g=cN0080g=cN0`3M
gMl0203Og]`0g=[K0=[Hf@3Ogml0gMgM0=gOgP3KgM`0h>7SJ03Lg=`40=cJ
f`@0gM_L00<0g=[M0=gKgP3Mfmh01@3Mfmh50=kLg`<0gmgP00d0gM_N0>7O
hP3Pg^40g=[M0=_Ig03OgN00h=kQ0=kLg`3Mg=X0h=oM0=KEd`3Ng]h0g=cL
0080fmcN00<0fM[L0=gMf`3MgM/0KP3MgM/30=cLfPD0gMgK00<0g=cJ0=gM
f`3MgM/01@3MgM/50=cLfP<0gMgK103KfmT40=cLfP0@0=gMg`3Ogn40gMgO
0=_Kg@3Ng^00gmoQ0=gMg`3Kfmd0h]cL0>3JfP3Qfm/0g=SI0>7MgP3Lf]/0
hMoP0=SFfFP0hM_M203MgMd40>3Jg0@0hM_M0P3Kfm/60=cLg0P0fmgL0P3K
fm/60=cLg0090=kNgP3Mgmh0fmoN0>;Vi@3Zk^d0k>k]0?;`l@3oo?d0no_k
0080oOgm0P3oool00`3moOd0oooo0?knoP0P0?ooo`00203oool0203oood0
oOgm0?Gem`3emOL0kNg]0=gMf`2IVYD0PH9l0`1hMg<507MfLWP0NWUd2@1h
Mg<207akM`05071_J`1IF5@0ATE1040o>`14@cl01013@Sh404A3?`<0@d90
00<0@T4o04=2@013@T000P14@d402014@C`0BTI305ACC`1fMg80MWId07j0
O@1_Lg80M7QgJ01gNGH207MgM@@0N7Qf0P1iNGL307QhN0D0NGUi1@1gMgL3
07QhN00@07IfMP1iNGT0LW9b05aLG016ATH0?Shn03lo?`12@T80?Sdi04I7
@P1>CT`0Ce5@07AhM`1aMgL0MGYm07IkOVP0M7Yh301cNGL407AjN0D0MGUh
0`1fNWT507EiN0<0MWYi0P1dN7L407EiN080MWYi0100MGUj06eaLP1IGEh0
ADU:03e1@P0k?d00?41103i2@`16A4D0DU1A07UiN@1lO7h0L75c07MkO01^
M7@0O864J01gN7X807EkN`0307IgN@1gN7X0MgQj00<0MgQj0P1hNG/307=i
N@D0M7Yj101bNgX407=lN`<0M7Yj1@1eNg/03`1cNGT0N7in07IoOP1fP7l0
Mh1o07b2PP2]/K80mOKh0?[jnP3moOd0nOWi0?gmo@3oool0o?cl0?knoP0Q
0?ooo`00203oool02P3moOd0nOWi0?7al`3^k_00jn_[0=kNg027R880NW]c
08>1M@25PgL308N5N@<0QH=gL024PWH808F3M`D0QhAk0`28QG`02026PgX0
RXMn08f:P@2=RX40RHIm08N4N`29QWd0SHZ10`2:Qgh308^8O`<0S8V0102;
R7l02`2<RH00SHZ108j;PP2OV900Y:2G07mlM@1KFe<0NWef07QmM`1nQGh0
NH=k05P0NWmi201kP7X307b1N`D0OH9l101oPG`30822O@040863OP20PWl0
P89o0822O`80PH>01022Q84308>5PP@0Q8J30100PhF208N9QP27RHH0PXB1
0822O`24QX<0QhV608V;R02?TX/0Si6<09:GT@1ZL6`0Ef1O06UcM01dP800
LWeoJ01aOG/8079nO003075mN`1bOW`0LWil0080LWil1P1cOgd307B0OP@0
MH5o0`1fPX0307N3P@@0NH>20`1jQ8<04@1kQH@0NXB507^5QP1hPX<0MX21
07Z4Q@1oRHX0Phf>08NATP26U9@0KGel04iNG@1]P7h0KX:107B:R01TOGX0
JH>006P0K8:0201_PH4406j4PP@0KhF30`1dQ8<407F5Q00307J6Q@1eQH@0
MXJ50080MXJ5101gQhH00`1fQXD0MhN607N7QP0207N7QP<0N8R700X0MhF5
07^;RP1hR8L0NXf;08VIV02;VIT0TIfM0:J`/@3bl_80oooo0P3kno/00`3o
ool0o_kn0?ooo`0Q0?ooo`00203oool02`3lo?`0no_k0?Ogn@3]kNl0inOW
0=cMf01jNg<0PH=h08N2K`2<Qg@0Thik0080Ui9o0`2FTGi`09NBO`P0VIB1
0P2HTX8509VCP`0309ZDQ02MUhL0ViF50080VI>300@0W9J609nIR@2NV8P0
ViF50`2MUhL209jHR0<0WiV90100XI^=0:2JS02PVX`0WiV;0:2JS02QVhd0
XYb>0:>MS`2/Y9L0/J^O0:fYW@1SHeL0MGQ]08^CR024SX<0PXj4F029T8P;
08ZAR@L0Ri::0`2<Th/508fDS080SYF=102?UXh308jES@80SiJ>0`2@Uhl0
402CVY80TIR@08nFSP2BVI40UijF09VPV02EW9@0SiJ>096FS`2QZ:00XJ^S
0:F`ZP1GHf40K7Yj07J6QP1kSHeX07Z>S@/0Nhn>0P1lT8l307fAT0@0OY:A
0P1oTi83082DT`<0PIFD0`22UYD00`23UiH0PYBD08:DU00308>EU@<0Q9JF
00@0QYVG08NJV026VIL0QIRF0P27VYP02P29W9X0Sj:P09jd/P2?Y:D0Df][
05YdL`1dTY00Li>B07JHU`1dUYEX07>EU0P0N9BE0P1eUiH207JHU`@0MiVH
00@0NiFD07bFU@1lUYD0O9JE0P1mUiH407jHU`<0OiVH0`20VYT3086IV@<0
PYZJ0P23Vi/04025VY/0R:2P08FOWP24WYd0SjVX09Va/@2BYZL0PiFG0<?3
``3bl_80o_kn0?_kn`3oool0o_kn0?ooo`3no_hP0?ooo`00203oool03@3n
o_h0n_[j0?Ogn@3/k>`0jn_Y0>;SgP1eMVh0PhEj08n9L`2GTG/0XYb60:ZT
SP2/YY000P2[YHl00`2/YY00ZjF=0:^US@1^0:^US@P0[JN?0P2^Yi@40:nX
U@80/:VF00P0[JJC0;:[V02c[9T0/:VF0:jWU02`ZIH0/Z^H0;>/V@80/Z^H
0P2c[9T20;B]VP80]JjK0P2d[IX30;>/V@0;0;F^V`2f[i`0]k2M0;beY@2o
^JT0a/>d0;6bY01IGDl0R92309ZUU`2GXiL0F02FXY@809NSU@80VJFG102J
YYP209^WV@<0W:NI0P2MZ9X309jYV`0409jXW@2OZIh0WjVN09nYWP80X:ZO
1@2QZj020::/X@<0XjfR0100Y:jS0:>]XP2R[:40XZbQ0:6[X02R[:40Y:jS
0:NaYP2Y/:P0Z;:Y0:^f[P2d`KX0WJbY04mRH01hS8/0S:2OJ026X9l;08RR
X@80RJ>R0`2:Y:<308bTY080SJFU1P2>YZH208nWY`<0T:RX0`2CZ:T209BY
ZP<0UJZ[0100U:ZX09J/ZP2EZjT0UZbZ09N]Z`2EZjT0Ujf[09jd/P2Q/;D0
Zkg109b_/`1;H6<0NI6E08JRY@28Y:L0QJ>UJ026YJL808BXZ080QjJX0P28
YjT208VXZP80RZV[0`28ZZT208V[ZP<0RZb[0`2>[:`208n][@H0T:j^0P2A
[jl309:`/00:09>_/02?Zj`0T[2`09Jf]@2G]KD0X;bm0:Fo`02N][P0QXJ6
0=KFeP80n_[j00<0oOgm0?clo03oool08@3oool000P0oooo0100oogo0?[j
nP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2GSWd0YYj;0;N_V02o^9h0`;VO
0;nhWP2o]j00_[JQK02n]Yl40;ngX0040;ngXP30^:<0`;RS0<2hX`@0`KVT
0`32^ZD20<>kYP<0a;bW00@0`kbY0<BmZP34_JX0a;fZ1035_Z/40<Jo[0@0
al2]1038`Jl40<W2/00?0<G2[`3Cc;X0b;n^0=C;^P2VX980OGmb0:ZdZ@2V
]Z/0Z[R[0:FaY@2]]j`0Z[BY0:^cZ02[]JX0Z;:W04l0Z[BY0P2[]JX20:Zd
Z@<0ZkFZ0`2/]Z/40:fg[080[[R]102_^Jh30;2j[`H0/K^`0P2b_;430;>m
/P80][jc0`2g_k@30;S0]@@0^;ng102i`;P0402m`kL0_<Bi0;o7_02f`;L0
_LS009NTW@1ZNG@0XK2[09Vc/02J];<0U[:c09>a/`2G/kH0V;:c09N_[`2I
[je@09Jc/@P0UK:`0`2G/K0709Rb/@<0VK>b1@2J];<309^e]0<0W;Je0P2N
][H309ng]`<0X;Rh0P2Q^KT30::j^P<0Xk^k0P2V^k`30:Nl_@<0Z;fn0`2Y
_[l50:Zo`00@0:_4`02^a<40[/3008jPXP1]PXD0UkFg092h^02A_K`0SkNg
09>k^`2A]kP0UkZl09>e]`2F^K/0TkJh09:h^Eh0TkVj0P2D^[/409Jj^P80
Uk^k1P2H_;`209Vm_@80V[jn102L_[l209fo`080W/310`2O_/030:2o`@80
XL320`2S`L<20:C2a0<0YL?50`2WaLD20:S6aP<0ZLO700P0VZb`09fXZP3d
mOL0nOGd0?kimP3onoP0nogj0?_oo`80oOgm0P3no_h0103oool0o_kn0?kn
oP3no_hH0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[0>;Ri01l
NG80S8Uj09nFQ@2^YY<0_kNP0<O0YP38`JL0al2V0<NoZ037_jYX0<NoZ003
0<S0Z@39`JX0bL6Z00D0bL6Z0`3:`Zd20<_3[P@0c<B_0`3=aK030<k6/@04
0<o7/P3>ak@0c/Nd0<k7]080clRe103@bKH70=7:]`030=;;^@3Cc;X0dlbj
00D0dlbj0100d<fj0=?<^P3=a;<0e<^j0<[4]02BThD0PHUl0;;0/`2^^Zh0
]/:f0;2j[`2b_;40/kfb0;2j[`2g`KH0/;Z_CP2c_K820;Bn/`80/kfb0`2d
_[<30;Fo]0<0]/2e0`2g`KH40;S2]`<0^L>h0`2ja;T0102kaKX0_<Jk0;c6
^`2la[/30;g7_0030;k8_@2oak`0_lNl00<0`<Rm0`31bKh00`32bL40`l[2
0<?:`P050<?:`P0;0<G;_`33bl00alo40<3:`@32cLD0]/>l08^JU@1dPgh0
X[bi09fg]P2I]KH00P2N_;h00`2I]KH0Y;jm0:>l^@1H09jk^@<0X;Zi1`2Q
^kX30::l^`D0Xkfl0`2T_[d30:Fo_P80Ykno0`2X`<030:W1`@80Z/;20`2[
`l<30:c4a080[lC50`2`aLH30;76a`<0//O81@2cb<T0402_b<@0[lG20;O;
bP2_`L<0OI:E06n=S`2Ma<<0UKnn09_3``2I`L40VKo009c2``2M`<80WlG6
09Nm_P2L`/=J09_1`PH0W<;300@0W/;209o3``2O`l<0Wl?3102Pa<@30:75
a@<0X/K60P2SalL30:G7b0<0Y/S90P2WbLX0102Yb<X0Z/W;0:[9b`2ZbL/3
0:_:c0030:c;c@2]bld0[/c>0080[/c>0`2_cLl00`2`c]00[L_;0:g;b`03
0:k<c0<0[lg=00P0/LK909:QY02[/K40n_Wg0?gimP3oo?T0ooom0?Sln`P0
o_kn603oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub
08b9NP2NUH@0[JFB0;jfW`36_jD0al2V0<JoY@36_ZL0a[jYJ037_jP60<W1
ZP80b/:[0`3:`Zd20<_3[P<0c<B_103=aK030<k6/@040<o7/P3>ak@0c/Nd
0<k7]080clRe0`3@bKH60=7:]`80d/^h1P3Cc;X20=C=^`0@0=KA_P3Ab[P0
f=2m0=78]`3Fd<00_[b]08B:O027TX@0^<:g0;6k/02^^:d0]Knd0;Bn/`2`
^Zl0/kfb0;Fo]4h0/kfb0P2d_[<20;>m/P80];jc102e_k@30;K0]@<0]l6f
102h`[L20;W3^0@0^/Bi102la[/30;g7_0030;k8_@2oak`0_lNl0080`<Rm
1031bKh60<?:`P80a<_30100`/Zo0<C<`@37cl@0`/c30;_6_P31c/L0[kbe
07N4O@1gT8`0ZL?009^h]P2L^[X0XKno09nm_@2I][@0XK^hD02M^[P809jk
^@<0X;Zi1`2Q^kX20::l^`D0Xkfl0`2T_[d30:Fo_P030:K0_`2W_kl0Z<30
0080Z<300`2Y`L430:[2`P80Zl?3102/a<@20:o4a@80/<G6102aa/L30;;7
b0D0/lS90100//_70;C:a`2gblX0]LW:0:6f]`1`S8d0MYRI09o6a@2J`/80
V<3009g5a@2Na/H0V<3009k6aP2J`/80Vl?3D02J`<4<09_1`P@0W<;30P2N
`/8309o3``<0X<C40`2QaLD30:;6aP80XlO70`2UalP30:K8b@80YlW:0`2Z
bL/30:_:c080[<_=102^c<h30:o=c`030;3>d02_cLd0[lg=00<0/<k>0`2a
cll0202ecm00YKVj08bHV02j_[d0moOe0?ckn@3hmoD0ooko0`3oool50?kn
oQP0oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<
RGX0WiJ50:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<NoZV00b<2Y00<0aknX
0<S0Z@38`:T02@38`:T40<W1ZP040<W1[03:`Zd0b/:]0<[2[@<0bl>^103<
a:l20<g5/0<0c/Ja00@0cLJc0<k7]03>ak@0c/Nd0`3?b;D50=39]P@0dLZg
103BbkT40=?<^P0@0=?>^`3BcKX0f=6n0=39]P3>bKH0emC30;6cY@1aMFL0
W::F0;Jn/@2g`[@0];na0;>o/@2c_[00[[V[0;W1]4P0];jc0P2c_K880;Bn
/`<0]Knd0`2f`;D30;O1]P<0^<:g102i`kP30;[4^@H0^lFj0P2la[/30;g7
_080`<Rm0`31bKh30<;:_`@0`/W11033b/804034c<40aLg20<?;`034c/D0
_lW00;k9`@30bl<0[;N_05edKP21VYH0YKnl09Ne/`2J^[T0Xl7109Jd/P2N
^kM@09jk^@P0Wkbj1@2Q^kX50::l^`<0Xkfl0`2T_[d40:Fo_P80Y/2o0P2W
`L040:W1`@80Z/;2102[`l<30:c4a0<0[LG50P2`aLH30;76a`<0//O81@2c
b<T30;C9bP0<0;7:aP2gcL/0/LG40;34``2gc<d0V[Bc05ilO022XZ40WL?4
09No_`2G`L00V/C30P2E_kh00`2H`/40V/;209_1`P1I09_1`PH0W<;30`2O
`l<30:34a080XLG50`2Ra/H30:?7a`80Y<S80`2Vb<T30:O9bP80Z<[;00@0
ZLS:0:[9b`2ZbL/0Z/W;102[b/`30:g;c@80[/c>0`2_cLl40:o=c@@0/<k>
00P0[L_;0;;<b`2/`;l0N8B40=;Fe`3dm?@0oo_l0?oloP<0oooo103no_hI
0?ooo`00203oool02`3ooOl0n_[j0?Ggm03_l?80iNK[0>;Ri01lNG80S8Uj
0:6HQ`2`Z9D0`;RQ0080bL:X00<0b<6W0<S0Z@38`:/0I038`:T80<W1ZP@0
b/:[00@0b/:]0<_3[P3;`jh0bl>^0`3<a:l40<g5/080c/Ja0`3?ak80103>
ak@0clRe0<o8]@3?b;D30=39]PD0dLZg103BbkP40=?<^P@0e<fk00/0d/fj
0=OB_`3Ab[L0eLjk0=?>^P3Ac;T0blRi0:RVV@1VJ5d0ZJnS0;S0/`020:jj
[0030;C0/P2b_Jl0]Kf`04/0];jc1`2e_k@30;K0]@<0]l6f0`2h`[L30;W3
^0@0^/Bi0`2kaKX60;c6^`80_LNl0`2nb;d20<79_P<0`/Zo0`33bl040<?:
`P@0a<_300`0alo40<C<`@2nb;l0`/c30<SBb@32c<<0_/Ro0<C>a@2IZZ80
EVUS0:6g]02R_;/209bj^0030:;0_P2M_;L0Wkbj05L0Wkbj1P2R_;/40:>m
_0<0Y;jm0`2U_kh30:K0_`<0Yl700P2X`/430:[2`P<0Zl?3102/a<@30:g5
a@<0[/K60P2aa/L30;;7b0<0/lS91P2dbLX20;G:b`0@0;?9a`2db/P0/LO5
0;W?c@2`a/@0/<S808fWYP1GM780V;Zl0:74aP2H`<00U/;109_7aP2C_kh0
VL7109g5aE/0W<;31@2M`l@30:34a0<0XLG50P2Ra/H30:?7a`<0Y<S80P2U
bLT30:O9bP<0Z<[;0P2Ybl`40:_:c0<0[<_=00@0[Lc>0:k<cP2^c<h0[/c>
0P2_cLl30;3>d0P0/Lo?00P0[Lg:0;CBd02[aL@0W[:a08:>SP3[ko00ooko
0?kemPP0o_kn603oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3R
h^@0O7Ub08b9NP2OUXD0[ZJC0;jfW`36_jD0al2V0<JoY@36_ZL0a[jYH036
_ZL01035_JH0a[jW0<JnY`36_ZL40<NoZ080b<2Y1P39`JX30<[2[@80bl>^
103<a:l30<g5/0@0c/Ja0`3>ak@20<o8]@D0d<Vf1P3Ab[L20=;;^@H0dlbj
0100dLbi0=OB_P3BcKT0e<ni0=OA^`3Ab[L0d/^k0=;:_@2EUH/0Si660:jf
Z@2mbK/0[;Z[0;O3]@2_]jX0][b`C@2b_;450;>m/P<0];jc0`2e_k@40;K0
]@80]l6f102h`[L30;W3^0<0^/Bi00@0^lFj0;c6^`2la[/0_<Jk102mak`2
0;o7_0<0`<Rm0`31bKh20<;9`@H0`l[20100`/c30<7;`P32c<<0_lW00<G=
`P37cl@0_lNl0<;:_`34clL0PI2907B7P`2N];80Z<;109Zg]@2O_;X0W;Ve
F02M^[P209ni^0H0X;Zi0P2Q^kX30::l^`<0Xkfl0`2T_[d20:Fo_P<0Y/2o
0`2X`<020:W1`@D0Z/;20`2[`l<30:c4a080[lC50`2`aLH50;76a`H0//O8
0100]<[80;;8aP2gcL/0//S60;?9a`2^a<80/lW707^AS`1_S900W;^n0:?9
bP2F`;l0VlO609[4``2J`/80W/73D02J`<4809Vo`0<0V/311@2K`L8309k2
`P80Wl?30`2Pa<@40:75a@80X/K60P2SalL40:G7b080Y/S90P2WbLX20:[9
b`<0Zl[<0`2/bld0102]bld0[/c>0:k<cP2^c<h40:o=c`P0/Lo?00P0]M?A
0:_9b@2`c/h0[<K708jPXP2T[Zl0lO7a0?olo080oOgm0P3no_h20?ooo`80
o_kn603oool000P0oooo00/0oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub
08b9NP2PUhH0[jND0<2hX@030<S1Y`030<NoZ037_jX0aknX0640aknX0P38
`:T40<W1ZP030<[2Z`3;`j`0bl>/00@0bl>/00@0c<B]0<c4[`3<a:l0c<B_
0P3=aK040<k6/@<0clNb0`3@b;<0103AbK@0d<Vf0=39]P3@bKH20=7:]`@0
d/^h1P3Cc;T00`3DcKX0e<fk0=G>_0050=G>_00A0=K?_@3Ac;T0d/fi0=KA
^`3BcKL0d/bf0=SA_P3Gc[d0dLFg0<W5^P24Q7P0Q8am0:nm[02]^jX0]L:a
0;:jZ`2l`[@0B02c_K850;Bn/`D0]Knd0`2f`;D30;O1]P<0^<:g0`2i`kP4
0;[4^@<0^lFj0`2la[/0102mak`0_/Rm0;k8_@2nb;d30;o9_P030<3:_`31
bKh0`LVn00<0`/Zo0`33bl000`34bl<0aLc40<G<a0040<G<a00A0<K=a@32
c<<0`lg40<OAb034c<40`/Zo0<O?a036c/<0a<c10;c1^P2makl0Lh9m07f@
SP2N]k@0Xkfl09bf]@2Q^kP0D02O_;X809jk^@80XK^j1P2R_;/20:>m_0<0
Y;jm0`2U_kh20:K0_`<0Yl700`2X`/420:[2`P<0Zl?31@2/a<@30:g5a@<0
[/K60P2aa/L30;;7b0D0/lS91P2dbLX20;C:b00>0;O=b`2Y_kd0^]3>0;34
`P2baL<0/<?106j5R`1lV9`0Vkk009S0`02G`L00Vl?309g0`P2L_/1H09c2
``L0WL?400<0W/C50:34a02QaLD00P2QaLD30:;6aP@0XlO70`2Tb<P20:G9
b@<0YlW:0`2Xb//20:W;c0040:c;c@2]c<h0[Lc>0:g<cP<0[/g?00<0[lk@
0:o=c`2`c]000P2`c]030;7?d@030;;@dP2`c/h0/<k>00H0/<k>00`0]Lo>
0;;>c`2`c]00ZlW;0:g5a`2<VY/0];Rg0?Sdl`3kno/0o?cl0?gmo@3no_h2
0?ooo`030?knoP3moOd0oooo01L0oooo00080?ooo`0@0?omo`3jn_X0mOOd
0>o`lP3Ui^/0h^;T07aiLP2<RGX0WiJ50:jVT`2o]j00al2V0<S1Y`37`:H0
a[jW0<JnZF80aknX0P38`:T30<W1ZP030<[2Z`39`JX0bL6Z0080bL6Z103:
`Z/40<_3[P<0c<B_103=aK020<k6/@<0clNb103?b;D30=39]PD0dLZg103B
bkP40=?<^P@0e<fk0100em2n0=7<^03Ac;H0eM6h0=G?]`3EcKP0elbj0=G8
^03<b;d0_[jb06mgJ02EXi80//>a0:ZhY`2maKH0/[RZB02c_K850;Bn/`D0
]Knd0P2f`;D40;O1]P<0^<:g0`2i`kP40;[4^@80^lFj1`2la[/20;g7_0<0
_/Rm0P31bKh20<;:_`@0`l_01033b/840<C;``030<;<``2obL00_lW00080
aLg200/0`l_00<?9_@34b[h0aLS10<76`02e`;`0HG5`08FKV@2P^;P0XK^j
0:6k^01H09jk^@80XK^j1P2R_;/20:>m_080Y;jm102U_kh20:K0_`80Yl70
102X`/420:[2`P80Zl?31P2/a<@20:g5a@@0[/K60P2aa/L20;;7b0H0/lS9
1P2dbLX0402bb<H0]L_90;7:a`2fcl`0]<[70;G9a`2hb<L0/L700:Fi`01M
MW/0OZ2R09k6aP2Ja<<0VL7109g0`P2S`/E@09_1`PP0W<;31@2M`l@309k4
a@<0XLG50`2Ra/H50:?7a`<0Y<S80P2UbLT30:O9bP<0Z<[;0P2Ybl`20:_:
c0<0[<_=0`2]c<h30:k<cP80[lg?0`2`c]080;7?c`0<0;O?c`2_bl`0/<oA
0;CCe@2^b//0Z[bl08N=S@3>cL/0nOWi0?_kn`3moOd0o_kn0P3oool00`3n
o_h0oOgm0?ooo`0G0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[
0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:]H
0<S0Z@@0aknX2038`:T40<W1ZP040<W1[03:`Zd0b/:]0<[2[@<0bl>^103<
a:l20<g5/0<0c/Ja00@0cLJc0<k7]03>ak@0c/Nd0`3?b;D00`3@bKH0clRe
0=39]P020=39]P<0dLZg00<0d/^h0=;;^@3Cc;X01P3Cc;X80=C=^`P0eLjl
00/0blV`0=GC_P2`[Ih0J6EL0:n`Z02f_KD0[kf`0;72/P2`^Zl0/[ba0;>m
/P020;:l/@030;>m/P2d_[<0/[ba03P0/kfb00<0/[ba0;>m/P2c_K801P2c
_K830;Bn/`<0]Knd102f`;D20;O1]P@0^<:g0`2i`kP30;[4^@@0^lFj0P2l
a[/30;g7_0040;o7_030b;d0`<Rm0<38_@<0`LVn00<0`/Zo0<;9`@33b/80
1P33b/8@0<C;``0@0<K>`@31bK`0_<Jk0:JbZ01JJF@0VZj]0:Fo`02J]k/0
WKVl09jl_P2M^k/0WKfl09jn_@2L^KL0W[Rg0:Fm_D00W[^i202O_;X00`2P
^[T0XK^j0:6k^P060:6k^P<0X[bk0`2S_K`00`2T_[d0Xkfl0:Bn_@020:Bn
_@@0YKnn00@0Ykno0:S0`02X`<00Z<30102Y`L430:_3``80[<C40`2]aLD0
102_a<D0/<G60;35aP2`aLH30;76a`80//O81`2cb<T@0;C:b00;0;G8aP2@
YZ<0D6eY09:d/`2L`l80V<3009[2a02L`lP0Vl7209c2``2K`L800P2J`<42
09Vo`00309c2``2K`L80Vl7200h0Vl7200@0U/2o09g5a@2I_l00WL320P2M
_l40B`2N`L<0WL3209O4`@2I`l40Vl?209Ro_P2Ma<<0W<?209S0_`2La<<0
Uknn09C5`@2Fa<40W<300:34a02E`l00T/>o09[2`@2K`l80VL7009O1_`2G
a<40UL:o09O4`@2HaL80V/C209g1`@2L`l80V<2o09Fo_@2Ja<80UKnm09g5
a02I`L00VK^l0:O6b02L`<00W<C309[2`@2N`<40Wl7209[2`@2I`l40WLC3
09Jm_02I`l40VLK309S0_`2La<<0U<6n09Vo`02M`l@0VL2o09c3`P2La<<0
VlC009k7``2H`Kd0X;k009W0_`2Mb/L0VlG30:32``2Q`<80X<O609W7a02M
`l@0X/c;09g7aP2Rb<T0Y/C60:S4a`2Vb<T0X<S70:C6a`030:G7b0@0Y/S9
00@0ZLS:0:[9b`2ZbL/0Z/W;0`2[b/`40:c;c@80[Lc>0`2^cLl30:o=c@80
/<k>2`2acll02`2`c<d0/<k>0;3@c`2adM00[/c<0;3:b`2P]KP0MXR<0>gW
j@3hm?D0no_k00<0o_oo00<0ooko0?cjn`3oool05`3oool000P0oooo0100
oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037
`:H0b<6W0<O0YP37_jP0b<2[F038`:T40<NoZ0L0b<2Y1@39`JX40<[2[@80
bl>^103<a:l30<g5/0<0c/Ja103>ak@20<o8]@H0d<Vf0P3Ab[L20=;;^0H0
dlbj2P3DcK/80=G>_0090=CB^@36a:l0dLjm09jLT027R800][bb0;>o/`2/
^Z/0/kfb0080];jc00D0/kfb0;:l/@2b_;40/kfb0;:l/@0n0;>m/PH0];jc
0P2e_k@40;K0]@<0]l6f0`2h`[L40;W3^080^/Bi102kaKX30;c6^`<0_LNl
1030b;d20<79_P80`/Zo1P33b/8B0<C;``0@0<;:_@33bkh0a<k30;S4^P2;
VY<0Kh>10:2h^P2N^[d0WKVj0:2l_@2N_;`0U[Je09fk^`2S`;h0W[Rg09ng
]d00W[^i202O_;X60:6k^PH0X[bk0P2S_K`60:Bn_@80YKnn0P2V`;l40:S0
`080ZL710P2Z`/820:_3``<0[<C40`2]aLD40;35aP80/LK70P2balP60;?8
b@80]<W:402db/P0202`a/<0[LK308JPW@1cTI40Wl720:74aP2I`L<0U[o1
0P2J`<401P2K`L80W<;309g3a02OaLH0WL?409Vo`100Vl7201`0V/;209S0
`02J`<40W/C509k1``2J`<40Vl7209[0`@2MaL@0Uknn09_2`@2O`l<0VKfm
09k2`P2NaL@0V;nn09_1`P2OalL0V<3009bo`@2M`<80V<3009o7a`2M`l@0
VKfm09[1`02Ma<<0W<C30P2J`/404`2G_kh0VL2o09Zn_P2I_Kd0X<O609_2
`@2La<<0W/G409Nn_@2Ma<<0YLW909Nk^`2J`L00Vl?209W1`02J`L00V;nn
09[2`@2H_kh00P2O`l<07@2J`L00V;nn09W0_`2L`l80V/;109k1``2P`lD0
WL320:33a@2O`l<0W/;20:34a02Ra/H0XL?40:C;bP2Ja<80Vl?209c3`P2S
alL0WlO609k8aP2M`<80WLG509g7aP2Oa/D0YLC60:c8b`2P`/<0W/K500@0
YLO80P2Vb<T20:O9bP@0Z/W;0P2[b/`40:c;c@<0[Lc>0`2^cLl30:o=c@80
/<k>2`2acll03P2ccm00/Lo?0:o?cP2`d<l0[lg=0;;<c@2/`L@0TZFY0;2`
/P3knod0nOWi0?[jnP3oool0n_[j6P3oool000P0oooo0100oogo0?[jnP3e
mo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0
YP37_jP0b<2[F038`:T30<NoZ0L0b<2Y1P39`JX30<[2[@<0bl>^0`3<a:l3
0<g5/0@0c/Ja0`3>ak@30<o8]@D0d<Vf0`3Ab[L20=;;^0D0dlbj2`3DcK/8
0=G>_0090=C?^@3@bkL0c/Rh0<W5^@25QGT0Rhj30;G0/P2f`[@0/kfb0080
];jc0P2c_K820;:l/Ch0/kfb1P2d_[<30;Fo]0<0]/2e0`2g`KH40;S2]`<0
^L>h0`2ja;T30;_5^P<0_<Jk102mak`30<38_@<0`LVn0P32b[l50<?:`Q<0
a<_30100`/Zo0<G=`P30b;d0aLo60;C1^P1jRXL0MH^90:>k_@2P^[/0VkNh
09nm_@2M^k/0WK^i0::o_@2P^[T0WkVh@02N^kT809nl^PD0XK^j1P2R_;/3
0:>m_0@0Y;jm0`2U_kh30:K0_`80Z<300`2Y`L430:[2`P040:_3``2/a<@0
[<C40:c4a0@0[LG50`2`aLH30;76a`80//O81@2cb<T30;C9bQ00]<[800T0
[/W40:g6``2/`/00LHV907:;S`2K^[d0W<C409S4a@2M`l@00P2L`/<01@2J
`<40VKo009g3a02OaLH0VKo00100Vl7200<0W/C509Rn_`2K`L800P2K`l<0
B`2Ja<<0VlG409S2`@2G_Kh0W/C509_1`P2J`<40WL320:G8bP2I_;h0WL32
09k4a`2N_l@0Wl3509_1a02J`<<0Wl3509Zk`02K`L@0Wl;409k1``2L_l40
X<?509Zm_`2P`lD0VKbn0:;5a`2N`L<0X<?509Nj_02M`<80W;o109Nm_P2W
cLh0T[Ri09K0_`2La/D0WLG509W1`@2Na/H0U/;109S2`@2La<@0Wl7309g0
`P2O`/@0W/3209o1``2OaLH0W<;309o1``2J`<40W<;309[0`@2Qa<H0Vkk0
0:73a@2K_Kl0XL?509o7aP2E_;/0Wl?309g4``2Vc/d0VlG309[2`@2PalH0
YlG70:?7a`2Na/D0WlK50:?2a02/b/`0X<;30:?:b@020:G7b0<0Y/S90`2W
bLX30:[9b`<0Zl[<0`2/bld30:g<cP@0[/g?0P2_cLd30;3>cP/0/Lo?0100
/m7A0;;@d02_clh0/=3?0;3>cP2ccLh0/l_=0:k3aP2;UI@0/;Jf0?Wjo03l
n_d0oo_l0?klo@3jo?/0nOgl603oool000P0oooo0100oogo0?[jnP3emo@0
ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37
_jP0b<2[F038`:T20<NoZ0H0b<2Y1@39`JX30<[2Z`80b/:]0`3;`jh30<c4
[`<0cLF`0`3>a[420<o7/P80c/Nd0`3?b;D50=39]P<0dLZg0`3BbkP40=?<
^P`0e<fk203Ec[`02P3Ac;H0eM2l0=C?_03<a[P0aL>f06i`H`2CVH/0/[f]
0;:l/@2c_K820;:l/@80];jc?P2c_K860;Bn/`<0]Knd0`2f`;D30;O1]P<0
^<:g102i`kP30;[4^@<0^lFj0`2la[/30;g7_080_/Rm0P30b;d30<79_P<0
`/Zo1033b/8D0<C;``0@0<7;`036c/<0_LFj0<;<`@2ob/80[;^f06UlNP20
U9<0YKfm09fg]P2M^[P0XKnm09jl^P2L^[P0Wk^l0::l_D00W[^i202O_;X4
0:6k^PH0X[bk0`2S_K`30:Bn_@@0YKnn0P2V`;l20:O1`0@0ZL710P2Z`/82
0:_3``<0[<C40`2]aLD20:k6aP80/<G60`2aa/L30;;7b0@0/lS9102dbLX@
0;C:b00:0:k=b02_bLH0//K70:fo`@1RMgX0PinR09Ro_P2G`l80W<;309[0
`@80W<;300@0U[bm09Vo`02M`l@0V/31402K`L80102N`L<0V/3109_3``2F
`;l209O3`P0_09S4``2G`L00WL?409[0`@2MaLD0W<K509>m_02Ja<<0U[jn
09o7a`2F_/00X/?809Rk_`2LaLL0WLK809bo``2O`<D0Vl?509[2`P2D^[/0
X/S909Bg^@2O`/@0W;o10:36a`2D^[/0W<K509W3`P2K`l<0VKo00:G;c02F
_;d0Tk^k09o7a`2MbLP0Skfk09[4``2O`L<0V;jo09[;b02E`l40W/7309g0
`P2F`/40V/C309g0`P2M_l400P2G`L006@2N`<80V<;109Fm_@2Sbl/0TKVi
0:77b02J`<40X/G909Vl`02Jal@0WLC30:[<c@2K_kl0Vl?209[4`P2Ma<<0
Y<?508fWZ02Xb<L0W/G20:?:b@2Ua<H0Z<K80:K8b@2TblX0102Vb<T20:O9
bP80Z<[;0P2ZbL/30:_:c0<0[<_=0`2]c<h30:k=c`80[lk@102`c/h=0;7?
c`050;;@d02acll0/Lo?0;7?c`2acLh00P2ccLh0202]`Kl0OXb<0<;6b@3i
moX0noGi0?ono`3lo_d0noom603oool000P0oooo0100oogo0?[jnP3emo@0
ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37
_jP0b<2[GP38`:T50<W1ZPD0b/:[0`3;`jh30<c4[`@0cLF`0`3>a[430<o7
/P<0clRe0`3@bKH50=7:]`<0d/^h0P3Cc;T40=?<^P`0e<fk203Ec[`0403E
d;`0e<fj0=K?_@3Ed;d0blRg0;2aX@1/L640Y:ZL0;Bn/`2g`KH0];jc0;6k
/02d_[<0]Knd0;>m/P2b_;4l0;>m/P@0];jc0`2e_k@30;K0]@@0]l6f0`2h
`[L30;W3^0<0^/Bi0`2kaKX40;c6^`<0_LNl0`2nb;d30<79_P<0`/Zo0P33
bl040<?:`Q@0a<_30100`<[10<G<a038d<D0_lNl0<;<``30bl<0WjjY05m_
K02F[:X0YKjk0:2j]`2L^KL0W[bj09bj^P2O^k`0WkVj@02N^kT809nl^P@0
XK^j102R_;/30:>m_0<0Y;jm102U_kh20:K0_`@0Yl700P2Y`L420:[2`P@0
Zl?30P2/a<@30:g5a@<0[/K60`2aa/L30;;7b0H0/lS9102dbLX@0;C:b00@
0:k;a`2[a<40^lg?0:Zi_02S]KT0EW1a08na/02I`L00Vl7209Nm_P2J`<40
W/C509c2``2J`<40W<;309[0`A00Vl720100Vkfo09bo`@2K`l<0U<2o09S4
``2E_kh0W<C409k4a@2N`/80W<?2096k^@2Ga<40W/c909?0_@2MalD0Uknn
0P2L`/<0?P2Ja<<0U/;1096m_02La/D0U[bm09g3a02Fa<40VlG309S0_`2S
alL0V[jn09k2`P2F_K`0W<C309G6`P2?_KX0X<[809Ro_P2J`L00WLC309c6
a02G`Kl0T/2n09g>b`2G_kl0Y/;609k0`P2A`l00T/?00:6n`P2M`l@0TL?0
08o1_P2N`L<0XL?509G3`@2D`/00WKo10:7:aP2G`;`0Vl?20:38a`2J`/80
VL7109c4a02Pb<X0WlS40:?7a@2H^[T0Z/c;09^o_@2Ra/@0Z<[904i/K00o
De@0Z<G30:;6a02Sb/L0ZL_<0:C3a@2Xb//0XLO80P2Vb<T20:O9bP@0Z<[;
0`2[b/`30:c;c@@0[Lc>0`2^cLl30:o>d0<0/<k>3@2acll0402]cL`0/]3@
0;;@d02`c<d0//k?0;??d02_bl`0[L_;0;7;b02O/k80P8Z;0>3Oi03lmo/0
noWj0?[ln@3joo`H0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[
0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:]M
0<S0Z@<0bL6Z1P3:`Z/20<_3[080bl>^0`3<a:l30<g5/0@0c/Ja0`3?ak80
0`3@b;<0clRe0<o8]@030=39]PD0dLZg0`3BbkP30=?<^@<0dlbj3@3DcK/8
0=G>_00?0=SA_`3>akD0fM:o0<g6/`3<ak@0d<fl09jOS`25QgT0ZkFZ0;K0
]@2g`KH0/K^`0;:l/@2c_K80/[ba03`0/kfb1@2d_[<20;Fo]0<0]/2e0`2g
`KH40;S2]`<0^L>h0`2ja;T30;_5^P<0_<Jk102mak`30;k8_@030;o9_P31
bKh0`LVn00<0`/Zo0`33bl030<?:`QD0a<_300h0`lg50<?:`P39dLH0`/Rn
0<G;`@31b<00`Lc408VFS`1`Q880W[Ba0:O2_@2L^KD0WK^i09jl_080WKVj
@02N^kT809nl^P<0XK^j1@2R_;/20:>m_0<0Y;jm0`2U_kh30:K0_`<0Yl70
0P2X`/430:[2`P<0Zl?30P2/a<@40:g5a@<0[/K600<0[lO70;76a`2aa/L0
0`2balP60;?8b@D0]<W:402db/P0302ec//0]lg;0;?7b02ba<H0/LG608JN
WP1`SXh0X<;10:77b02L`/<0VKo009[0`@80W<;34P2K`L80D02O`L<0Vl72
09O1`02E`L00VlG409Jn_P2WbL/0V[Vl08ZTY@1oWId0YLW709Jo^`2Mal<0
T[^g09g1_`2O`L00XKZn09c4``2Kb<D0TkNg08:VYP2Jal@0X/[909nh_02E
`[d0X<W509bn_@2T`/80K8R908f[Z`2P`/40V[jl09[7`P2Ka<00V;bj0:O7
aP2M^k/0Xl?209^m_02Ma<40V/C20972_P2L`<00Z[W00:Jo``2Ea/80VLK3
0:Bg_@2N`<40U<O209O:a@2L^[`0WKVl09[8a@2Ia/<0Y[o309Vh/`1jV9H0
N9RE09fo_P2Ra/@0XLS709k6aP2G_kl0Y<;209g1_`2VcLX0X<;10:S4a@24
W9h0S:JW06V9R0003Pl0Yl2m0:S;a`2NaL80ZL_:0:G4aP2WbL/0X/S90`2W
bLX30:S:b`80ZL_<0P2[b/`30:c;c@<0[Lc>102^cLl30:o>d0030;3?d@2a
cll0/Lo?00h0/Lo?0100[/k=0;7?c`2ccm00[l_<0;7=cP2dd]80[lo>0:g=
c02Zb<H0]/k>09>SX`2_]kT0l_?e0?knoP3lo?X0ooom603oool000P0oooo
0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ng
X037`:H0b<6W0<O0YP37_jP0b<2[G038`:T40<W1ZPD0b/:[0`3;`j`20<_3
[P80c<B_103=aK030<k6/@<0clNb0P3@b;<20<o8]@80d<Vf1P3Ab[L20=;;
^0@0dlbi0P3Cc;X>0=C=^`P0eLjl00`0clRh0=WB`03Bb[L0fm>n0=3:]03?
b[L0blVj08R9N`2=Uh`0Yk6V0;Fo]02c_K830;:l/C/0/kfb1P2d_[<20;Fo
]080]/2e102g`KH30;S2]`<0^L>h102ja;T20;_5^P@0_<Jk0`2mak`30;k8
_@80_lVn0P31bKh20<;:_`@0`l_00P33b/8F0<C;``0@0<G?a`30b/40`lVo
0<K<`034ak`0a/c20;g4_02obL40NXf907nDS`2K];00X[nk09bj^02N_;`0
WKVj0:2l_d00W[^i202O_;X20:6k^PH0X[bk0P2S_K`20:Bn_@@0YKnn0P2V
`;l20:O1`0@0Z<;10P2Z`/820:_3``@0[<C40`2]aLD30:k6aP80[lO70P2a
a/L20;;7b0H0/lS91P2dbLX@0;C:b00@0;O9b@2`a<<0]l_<0;K;c02Z`/80
[LG507B>S@1hTY40UK^l09g3a02L`/<0Ukfn09[0`@2L`/<0V/3109c2`a00
Vl720340X<?509c2``2G`L00U<2o09_3``2N`<80W[Zn05AXK`001@X000@7
01<X:@2E/[00W;Zh000?3@1;Hf<0Ef]/00011`1aUI40UL2i05maL`0mCe40
VLBm09Zn^P021`d08dI20:?1_`1dRHX011HH00041`001@L0;T=40:W1`@2M
_KX0D6e[00061`0010L000D801<R9@025QL0Xk^k09_2_`2Kb<<0X/3000T=
5P0A8bL0V<O109:l^0002@l0DFIY0080V<:n01d09SPl02He>P2K_kd0X/C3
06A_M@0=5aH000@4000:2P0B92@0Ni>C0:K2``2M^k/07ci002Lj?P2Ra<<0
V/O20:34`P2CYJT03QLN05EXK02D][D000<409R/Z`2Zb/D0WlK10:;6a02Z
bL/0YLO90:G;c0020:O9bP80Z<[;102Ybl`20:_:c080[<_=102]c<h30:k=
c`<0[lk@0P2`cm4@0;7?c`030:k@c`2^c/d0/lo@0080//c=00/0]=;B0:k@
c`2/d<h0]mGE0:O1`02^`l@0S9bK0;Bm_03`l_40no[h0?ojnP0H0?ooo`00
203oool0403ooOl0n_[j0?Ggm03_l?80iNK[0>;Ri01lNG80S8Uj09jEQ02^
YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:]L0<S0Z@@0bL6Z103:`Z/40<_3
[0040<_3[P3<a:l0c<B_0<c4[`<0cLF`103>a[420<o7/P<0d<Rc00@0clRe
0=39]P3@bKH0d<Vf0`3Ab[L00`3BbkP0dLZg0=;;^0020=;;^0<0dlbi00<0
e<fj0=C=^`3DcK/01@3DcK/00`3Ec[`0e<fk0=C=^`060=C=^`P0eLjl00`0
eLjn0=C;^P3IdK`0dLVb0=WA_03?b[H0clbk0<K4]`1]Mf`0UInD0;6k/02d
_[<20;>m/P030;:l/@2d_[<0/kfb03L0/kfb1`2d_[<20;Fo]0<0]/2e0`2g
`KH40;S2]`80^L>h102ja;T30;_5^P<0_<Jk102mak`20;k8_@<0_lVn00@0
`LVn0<;:_`32b[l0`/Zo0`33bl000`34c<40a<_30<C;``050<C;``030<G<
a034bl<0a<_300h0a<_30100`L_30<?=a034b/00blk30<C7_038bl00`<Jl
0;o6_P2aa<00HWMb07fFTP2S_KX0V[Ne09nm_@2N^[/0X;bo@02N^kT809nl
^PL0X[bk0P2S_K`30:Bn_@<0YKnn00<0Y/2o0:O1`02W`L000P2W`L030:S2
`@030:W3`P2[`l<0Zl?30080Zl?30`2/a<@40:g5a@80[/K60`2_alL0102a
a/L0//O80;;7b02balP30;?8b@P0]<W:00<0]L[;0;C:b02db/P03P2db/P0
3`2ha/T0^<[<0;;7b02`b<P0/L_:0:[4``2[`l<0HGIg07ZPX@2E^k`0XLO8
09_1`P2L`/<0WL?409[0`@0A09_1`P1@09Zm_`2L`/<0V/C309O1`02K`L80
XL3308BHW`000``0@3i3051DE`001@H0F6QW0:Zm^`001@@0GFUY07b4QP09
00L0DG5/09k6_P0i?4401`X?09c4_027Yj801`05055/I`2S]kD0520P01/P
8`1iOH00FV9T00071`1PKVh0Z/2m05EXIP001PL0H6AW065RIP1LH6<00084
06McL`2O`kl0UL2i06J0O`0100P0G6M[09[7`02J`K`0008805aWJ`2K_[X0
XLC002L^=00`=C/0X;fk06Z4P`0000L04@/=05UEEP15ATP0004400TD5P2A
XjD0[/?601lg>@0Y=3X0YLG409W:a02Ma<40;CPn00002@1KJVl0X<O400P@
4P1lShd0X/:m0:K=b02Pa<80[<k?0:C6b02Rb<T40:S:b`<0ZL_<00<0Z/c=
0:_:c02/bld00P2/bld30:g<cP@0[/g?0P2_c]030;3?dA00/Lo?00P0[m7@
0:_;bP2ccm00]Lo@0;;<c@2bd=00[Lo>0:c@cP80/Lg>00H0]<c<0;34``1l
R8H0aLW80?Wem03on?LH0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80
iNK[0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038
`:]@0<S0Z@@0aknX2038`:T40<W1ZP<0b/:]0P3;`jh40<c4[`<0cLF`0`3>
a[400`3?ak80cLJc0<k7]0020<k7]0<0clRe103@bKH20=7:]`<0d/^h00<0
d/^i0=?<^P3Cc;X01@3Cc;XL0=G>_00<0=C=^`3Cc;X0d/^i0=7:^02o_Jh0
IVQJ0:N]X@2d_[D0]<2f0;:n/P2d_:l0]kj^=02c_K870;Bn/`80]Knd102f
`;D30;O1]P<0^<:g102i`kP20;[4^@<0^lFj00@0_LFj0;k6^`2na[/0_/Jk
0`2oak`01030b;d0`<No0<37_`30akl20<78`0@0`/W11`33b/8P0<C;``0@
0;_9^P2W]j`0GW5[08jTXP2S^kd0WKJj0:Fn`P2Q^k`0W[^i0:2m^`2N^kT0
WKZh09nl^P2M^[P0VkRf0:2m^c00W[^i202O_;X40:2j^@@0XK^j0`2R_;/2
0:>m_0@0Y;jm0`2U_kh30:K0_`040:O1`02X`<00Z<300:S0`080ZL710`2Z
`/830:g2``80[/?4102_a<D30;35aP<0/LK70P2balP70;?8bAP0]<[80`2e
blT20;C:b00;0;?9a`2/`/00Y;Zh05=`KP2B/:h0WL6o09_3`P2Ja<80Vl?3
09_1`P2M`<@0402K`L80D02KaL@0VKo009k0`@2K`/40VL?10:3:b02G^KP0
DVa]09G9_@2M_KP0;B<^02Pc=`2L_k/0008705]VK027Xj@0000404iYI02R
^kP01@D=00011`1RQGl0Li2;00@01018J6L0TJ^X0040101ON7D0W<?209S0
_`0:3Q40@di809^o_`1FJV/0000509c0_02K`/40P:RW000210041@0000@8
00H0100=0080000508BVY`2GaL<0Y;jm00410`1BJVh0X[Zn0:32`@0U<cH0
:S@f0:6l]`0D81h01Q0?07ZJV@2Rc<P0X<;105ihN@0000T0Ad]D0:C6a@0V
<cT0;34e09g8`@2Ra/80EFQV00<000070`80CFaW0:K5b00]=CL0EVYY0:O7
aP2Sb/T0ZLc>0:K5b02]c<h0XlG40`2ZbL/20:_:c0<0[<_=00<0[L_=0:k<
cP2^c<h01@2^c<hP0;7?c`0@0;7@dP2]cm00[]3?0:c:b02V^[T0OXJ80=[E
f@3om_`0o?cj0?cnn`3koOX0o?om0?gooP3inoX0oooo0?kloA00oooo0008
0?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jV
T`2o]j00al2V0<S1Y`37`:H0aknX0<S0Ze00b<2Y1037_jP70<S0Z@D0bL6Z
0P3:`Zd30<_3[P<0c<B_103=aK020<k6/@80clNb103>ak@20<o8]@@0d<Vf
0`3Ab[L30=;;^0H0dlbj0P3DcK/H0=G>_0030=C=^`3Ec[`0eLjl0080e<fk
00/0dlbj0=;;^@3BbkT0alBc0:Z[W@1jOG80]knd0;:n]02^^Zh0]L2b0;>n
[P0d0;>m/PH0];jc0`2e_k@30;K0]@@0]l6f0P2h`[L40;W3^0<0^/Bi0`2k
aKX40;k6^`80_lNl0P30b;d20<37_`<0`LS00`32bL460<?:`R80a<_300T0
`Lfo0;_8_P2FYJ00Kh>209ng^@2Y`l@0VKFf09jj^`2K^;H00P2M^[P01@2L
^KL0X;fk0:6n_02N^kT0VkRf0300W[^i202O_;X30:2j^@D0XK^j0P2R_;/3
0:>m_0<0Y;jm102U_kh20:K0_`80Yl700P2X`<030:W1`@<0Z/;20P2]`/<3
0:k3a0<0[lC5102`aLH20;76a`80//O81P2cb<T20;C9bQ/0]<[800d0/lW7
0;G;b@2eblT0/LO50:c2`02BZZX0IhB20:73`P2F_KX0VL7009W1`@2G_kl0
WlG60100Vl7200@0U/2o09k4a@2O`L80WLC30P2G`Kl0BP2Q`l80Y;jo0:?3
_P2L][<05Q0J028f=`2WblL0008705MVJ`2K`[l0004202e0?P1dQXH00007
00hG700cD4`0J7aj00@00`1ZS8/0Mi6>0040101^R8D0VL700:38a`0Z;S40
:C@^09g4``1AIFH0008709k2_P2I`;l0Vl?2020Z;0000@00CVIV069WJP03
00807BPZ09_3`P2Fal@0WkVh00000P1<IFT0Z<;309c0_P0T<SD0<C/m08nZ
Y@000`@0C5ED0:C6a`2F`l00X<;30:C0`@0R9B`04AHL0:G8a00Z=CL09C<c
0:;2_`2<Wj<000D403a2?P000@00C6UU0:o;c`0[<cD0FFe/0:_;bP2Qb<L0
YLS:0:W8b`2Yb<X0Zlg<0P2ZbL/30:_:c0<0[<_=1P2^c<h20:o=cb00/Lo?
00/0Zl[<0;CCe@2^c/d0Z<K40;O@c@2EXj<0[[:e0?Wdn03in?H0o_kl0?gm
n`020?koo`030?ooo`3moOd0oooo0100oooo00080?ooo`0@0?omo`3jn_X0
mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37
`:H0aknX0<S0Ze00b<2Y0`37_jP70<S0Z@H0bL6Z00@0b/:]0<_3[P3;`jh0
bl>^103<a:l30<g5/0<0c/Ja0P3?ak830<k7]0<0clRe0`3@bKH30=7:]`@0
d/^h1@3Cc;X30=C=^aP0eLjl1P3DcK/20=?<^P080=;;^`3>b;X0TY:608B:
OP2c_K80[[Z/0;G1/`2b_jhc0;>m/PH0];jc0`2e_k@40;K0]@<0]l6f0`2h
`[L30;W3^0<0^/Bi102kaKX30;k6^`<0_lNl0P30b;d01030akl0`LS00<78
`031b<040<;9`@D0`l[28`34bl<02`32b[d0_lW00;W4_P22TXl0NXj=09ng
]`2P_K/0W;Zh09nl^P2P_K/0Wkbj0080WKZh0P2Q_[`00`2M^[P0W[^i09jk
^@0^09jk^@P0Wkbj0P2P^[T60:6k^P040::l^`2S_K`0Xkfl0:>m_0@0Y;jm
0`2U_kh30:K0_`80Yl70102Y`L420:[2`P80Zl?300@0[L;30:k3a02^`l@0
[/?4102_a<D30;35aP<0/LK70P2balP50;?8b@<0]<W:602db/P0402cbLL0
]<[80;C:b02cbLL0]<[80;G;b@2db/P0//S60:c0`@1iTI40N9BE09^m_02Q
b<L0V<2o09_5a02G`L0@09_1`P1A09S2`@2OaLH0W;jo09k5a02I`l40U/2n
0:32`@2U_l00EF1R000=30041`h0EWAb09>l]P000PP0F6Y^09C3_@0L9B80
;CHe03i6B00D7b40Df=S000@3P1LIVD00@0007nQX01ZQ84010<807RBT@2I
`L00Tkfk038g>`0[>340W<?205AXJ@000@@0XLG109c2``2Ja<<0J7=e0002
001UR8@0IGUg00040P1CK6T0T[nl09O8a@2X`/4000<404m[K02N^[/0W/G2
02Tg>P0X<S@0M8n:00072027S8l0V/310:7=c02P`/<0Y/C405iUJ`000`D0
X/No02`f=`0U>3H0XkNh02@W<0024Q80X;>]00030@1MMg@0YKk202/c=@1F
JVT0ZLW80:?:b@2TalT0[Lc?0:K5a`2Zc</0Z/W;00<0Zl[<102/bld40:k<
cP@0[lg?802acll0402_cLl0/m;D0:k>c@2Zb/L0/<g;0:^o_P2DX:00[;Bf
0?WemP3no?d0n?Kg0?_inP3oool0oOgm0?ooo`3nool@0?ooo`00203oool0
403ooOl0n_[j0?Ggm03_l?80iNK[0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP
0<O0YP38`JL0al2V0<NoZ038`:]@0<S0Z@80aknX1P38`:T50<W1ZP<0b/:[
0`3;`jh30<c4[`@0cLF`0`3>a[430<o7/P80c/Nd0`3?b;D30=39]P<0dLZg
0`3BbkP20=?<^@@0dlbj103DcK/H0=G>_0P0e<fk00P0fLfo0<W2/P3=b[/0
MgU[09:HRP2a_:h0]L>d0:bm[C80/kfb1P2d_[<30;Fo]0<0]/2e102g`KH3
0;S2]`<0^L>h0`2ja;T30;_5^P80_<Jk0P2na[/30;o7_0<0`<Rm0`31b<03
0<;9`@H0`l[29034bl<04034b/00alc50;_2^`2nbLD0IGEb07jDT@2I][80
WKbg0:2m^`2O_;X0X;fk09nl^P2K^;H0WKZh0:2m^`2O_;X`09jk^@P0Wkbj
1@2Q^kX30::l^`<0Xkfl0`2T_[d40:Fo_P<0Y/2o0`2W`L020:W1`@<0Z/;2
0`2[`l<30:k3a0<0[lC5102`aLH30;76a`<0//O8102cb<T40;C9bQT0]<[8
0P2eblT40;C:b0090;?9a`2_`L40/<C506=kN`1iUiL0VKfm09_3`P2La/D0
V<C30100Vl720500V/C309c2``2L_[l0W/G409[4`P2KaL<0WKnn041JF`00
0@H011PG051OHP2E_[P0X<W30040201EHVP0V/W303A0?00>3Ph05AHJ04YM
F`2:Xil000H602HX9`000@00V[jn076>RP0000@0KX^909g7a@2F`;h0;34e
02Pe;P2Ma<<0Efa]0001102H_;P0WLG509;0_P2IZjd000X6045KFP0jCD/0
00X708>PW02E`[l0U/;10:6k^P001PD0C6YZ0:G1`P2K`[d0:STl02D_<@1h
TXl000<407InP02RaLT0V<;10:;1``2Va<@0DEaN0004102Qak`0;CHe02Xf
=P1=Feh010HB06N1P02bbL<0000205=YI`2ZbL/0:S8d05ibL@2Ta<<0Z<o>
0:G8bP2^cM00ZLS:0:K8a`<0Zl[<0`2/bld20:g<cP<0[/c>1@2_cLlP0;7?
c`0@0;;>d@2_cLd0/=3?0;GEe02YalD0]]3?0:Nm^`22UYD0`/330??am03o
nol0oocm0?ono`3moOd0o_oo0?Khma00oooo00080?ooo`0@0?omo`3jn_X0
mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37
`:H0aknX0<S0ZeH0b<2Y1@39`JX50<[2Z`80bl>^0`3<a:l30<g5/0<0c/Ja
0`3?ak820=38/`<0clRe0`3@bKH40=7:]`<0d/^h0`3Cc;T40=?<^P@0e<fk
603Ec[`70=C=^`090=G>_03EbKT0e/fl0<c6]P2n_:d0JfeO0:>[W02_^jd0
[knb0300/kfb1P2d_[<40;Fo]0<0]/2e0`2g`KH30;S2]`<0^L>h102ja;T3
0;_5^P<0_<Jk0`2oak`30<38_@80`LVn0P31b<030<;9`@L0`l[29034bl<0
2`36c<80`LJo0<oDc@2i`;T0ZkRa069eL@2:Xil0Wkbh09fj^02K^;H0W;Vg
0080Wkbj00<0WKZh09bi]`2M^[P0<02N^kT809nl^P<0XK^j1@2R_;/20:>m
_0<0Y;jm0`2U_kh30:K0_`<0Yl700P2X`/430:[2`P<0Zl?30P2/a<@20:k3
a0<0[lC50`2`aLH30;76a`<0//O81P2cb<T40;C9bQX0]<[80P2eblT0302d
b/P0/lW70;?9a`2cbLL0^<[:0:o3`P2P]KH0F79a08b/Z`2H_kh0V/C209S4
`a00Vl720500Ul7009c2``2P`/<0Vl;109W3`@2Ja<80XlG4000:2`0P9BT0
Uk6^0:>k^`2Lbl<0VL:l00<01`1KHVX0Ul6m05EVH00000800P<7082JU`2O
_kX06RPX00000P0@5Q@0W/;207:@SP000@H0Khb:09G1`02IaL@0;CDh02Dd
;`2G`;`0DVQV00<72P2J_[X0V/;409W9b@2X_L00:Shl01dT:P0E7Al06BPU
0:Bn^`2PalH0V/310:_3``001080CfaZ0:Bn_@2NaL009SDh02Ha<`2U`[h0
00<503M1@`2O_/40X/K60:_7b02J]kD03A/L02Pk>@2Pb;d0;S@d00d=3`00
10L0AEIM0:K:bP2_aL<0100205Q/J`2RblL05AdO07R<R`2Xb<L0Y/g<0:C7
b@2[b/d0[<_=0:W;bP80Zl[<0`2/bld30:g<cPD0[lg?0`2`c]0P0;7?c`0@
0;7=cP2_cLd0/<k>0;CDd`2`d<l0[L_90;;?c@2N^kT0Qh^>0<g>dP3ooOl0
oo[n0?ginP3oo_l0oOon0?cooA00oooo00080?ooo`0@0?omo`3jn_X0mOOd
0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37`:H0
aknX0<S0ZeD0b<2Y0`39`JX60<[2Z`80bl>/103<a:l30<g5/0<0c/Ja0`3?
ak830=38/`80clRe0`3@bKH30=7:]`@0d/^h0`3Cc;T0103DcKX0dlbj0=?<
^P3Cc;X50=C=^aP0eLjl1P3DcK/20=G>_0080=C=^`3BbkT0d/^h0<o:]`2Z
ZIL0N7a^0:RbY`2g`kT`0;>m/PD0];jc0`2e_k@40;K0]@<0]l6f0`2h`[L3
0;W3^0<0^/Bi102kaKX30;c6^`030;g7_02oak`0_lNl00<0`<Rm0`31bKh4
0<;9`@<0`l[200@0a<_30<?:`P33b/80`l[29@34bl<02P31b<00b<k40<;8
_P32b;h0alk609VVW`1^Pgh0VK:^0:?0_P2P_K/209bi]`030:2m^`2O_;X0
WKZh0340W[^i202O_;X60::l^`80Xkfl102T_[d30:Fo_P<0Y/2o0`2W`L03
0:S2`@80Z/;20P2[`l<40:c4a0@0[lC50`2`aLH30;76a`<0//O81P2cb<T5
0;C9bQP0]<[80P2bb<H03P2cbLL0]L_90;G;b@2db/P0/lW70;C:b02db<L0
/<C30;35aP2AZJT0JHF609Jh]`2K`/40V<;0402K`L80D02G`L00X<K709o1
`P2H_kh0VlG309O1_`2P`/4000`=04mJG02T`kh0OiBE09C1^P2LaKl00@07
069YL@2H`Kd0HWEa0001100=5aT0X<2m0:78``1AIF@000@602hh=`2I`;l0
K8Z80003201bT900V/K509K4`P0X<CH0:CXd09c6`P1BJ6H000440:75``2G
`<80TL?409fi_01TOgX00P080001101HIf@0W[^g09o1`P2S`/D0X;Ff0007
1@1GL6d0XKZg0:;7`00T<S<0<Cm209no_00nD58000@705M_K`2G];80SInQ
039:BP001@D0IG]i09W2^P0_=3P00`02010X:02N_L00WLO60;C8b@0400D0
EVaZ0:K:b0000P@0T:BS0:g=c02Sb/T0YLS:0:W8b`2ZbL/0Zlg<102/bld3
0:g<cP030:k=c`2_cLl0[lg?0080[lg?102`c]0P0;7?c`0@0;?Ad@2^c<`0
/]3@0:c:bP2dd]80ZlW90:c:bP2^c<`0XJn`09nYZ`3UjN`0ooko0?Scm`3n
o?d0n_[h0?kooA00oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0
h^;T07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Ze@0
b<2Y1039`JX50<[2Z`<0bl>/0`3<a:l30<g5/0@0c/Ja0P3?ak840=38/`80
clRe0P3@bKH40=7:]`<0d/^h0`3Cc;T20=C=^P80dlbj1P3DcK/J0=G>_0@0
e<fk0P3Ec[`0203BcKT0eM2l0<g7/@3Ec[/0cLZg09VJS02:SH@0[kJ^<02c
_K840;Bn/`@0]Knd0`2f`;D30;O1]P@0^<:g0P2i`kP40;[4^@<0^lFj0`2l
a[/20;g7_080_lNl0P30b;d40<79_P<0`/W10`33b/820<C;``80`l[29P34
bl<04033clD0a<k30<?9_@3:c<40a<Nn0;_5_@27UY40O8n;09Vf]02S`;h0
X;fk09^h]P2O_;X0X;fk09fj^02P_K/`09jk^@P0Wkbj1@2R_;/30:>m_0<0
Y;jm0`2U_kh40:K0_`80Yl70102X`/430:_3``<0[<C40P2]aLD30:o4a@<0
/<G6102aa/L20;;7b0H0/lS91P2dbLXI0;C:b0040;;8aP2cbLL0]L_90;G;
b@80]<[800T0]L_90;C=bP2aalD0/LO50:Vn_`26WZ00KXZ;09o1`P2K`/40
402K`L80D02Ja<<0W/C509bn_`2I`;l0W<K409O1_`2K_K`0?UQI00051@0M
=S<01A0D06:6PP2D_kP0008804mNH`2JbL<0LhN500071`1;Gf00X<C209Fo
^`23XIl000h>03U5A@2La<@0K8b900T<4@1XR8L0V<K409;0_P0/=CX09SLa
09K0_01DJVP00@D809Rl^P2LaLL0T<?40:K4aP2?[ZT0000800041029Y9d0
ZLc609Ni^P0O>cl000/=00030P001`L000D507BDS`0Z>3T093<f0:;6`P2L
/K806Rl`000410002`T000P900061@14DeH0Z<;10:G?b`0[;cP00`<307VI
UP2ZcM40X/S;0:[2a0001@H0DFiZ07:7RP094A<0YKVh0:_;bP2TblX0ZLc>
0:[9c02XalT0Z/c;0`2/bld30:g<cP80[/g?0P2_cLl60;3>d200/Lo?00`0
/]3@0:k<c02dd=40[l_<0;C@d@2edM@0/LoA0:_9b`2bb/X0RifM0:fg^@3_
l?@20?ono`030?ooo@3koOX0oooo00l0oooo00080?ooo`0@0?omo`3jn_X0
mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37
`:H0aknX0<S0Ze@0b<2Y1039`JX40<[2Z`@0bl>/0`3<a:l20<g5/0@0c/Ja
0`3?ak830=38/`030=79]03?b;D0d<Vf0080d<Vf0`3Ab[L40=;;^080dlbi
0`3DcKX70=C=^aT0eLjl00<0e/nm0=G>_03Ec[`0103DcK/02@3Ec[`0dm:m
0<k<]`3Fd;X0e<jh0=3;^034`[D0PH9j08bAR`0`0;>m/P@0];jc102e_k@3
0;K0]@80]l6f102h`[L30;W3^0<0^/Bi102kaKX20;c6^`<0_LNl00@0_lNl
0<38_@30b;d0`<Rm0`31bKh01032b[l0`/W10<;9`@32bL420<?:`PX0a<_3
00<0aLc40<C;``34bl<07P34bl<03`2nc/<0_LVm0<cBaP35akX0a/Rm0;k3
_02mb<80KGai07^HUP2I][@0Xl2n09fj^02P_K/0Wkbj09^h]P0a09jk^@P0
Wkbj102R_;/40:>m_0<0Y;jm0P2U_kh40:K0_`<0Yl700`2X`/40102Y`l80
Zl?30:_3``2[`l<20:c4a0<0[LG50`2_a<D20;35aP@0/LK70`2balP30;?8
b@P0]<W:00<0]L[;0;C:b02db/P05P2db/P00`2gcL/0]<[80;?9a`020;G;
b@80]<[800T0]L_90:o:a@2bblP0/LO50;C8b@2V^k`0LH^<07>BU02P`/<0
402K`L80D02H`/40V/3109k0`@2Ma<<0U/2n09[4`P2Q`l80Tjf^05YXJ@0R
=3@0HV9Z09^i]`2Ob/<0EfEX07>=SP2Aa[h0W[:a024f=`1kUiP0Vl;109C1
_P2Oa/<0=4a<06IaL`2I`L40SJf/05MJG`2<[:/0U<;009S6aP1UKW<0H75[
09S2_P1hSX`0GV9U09k2`02I`/@0S/C40:C3aP2O_k`0CEIK03Q>B`2Qak`0
TKbc0:G9b@1EKW<0FFMZ05aUI01FI6D0GVi^08ZYY01SLG80IgIi09g4_`2Y
`l80VK>b061YIP0Y=C<0=S`l06YjNP2__/40ZlG609g:a`1BFF<0GFIS0:K=
b02R`lP0Z<W>0:S6aP1EKf`0MiNB059GG@15CDl0^Lg<0:S8a`2Wc/d0ZLc>
0:_:c@2/bld0Zlg<0`2/bld20:g<cP<0[/g?1`2`c]000`2acm40/Lo?0;7?
c`0N0;7?c`040:_;bP2dd]80[/[;0;C>c`80/L[>00X0//kA0:o=c`2]blT0
[/K608JDU@2j_/40o?[m0?Ocm03noO/0o?cj403oool000P0oooo0100oogo
0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0
b<6W0<O0YP37_jP0b<2[B038`:T00`37_jP0b<2Y0<S0Z@080<S0Z@80bL6Z
0`3:`Z/0103:`Zd0bl>^0<_3[P3;`jh30<c4[`030<g5/03<a;40cLFb0080
cLFb0`3>a[<0103?ak@0c/Nd0<k7]03>ak@20<o8]@@0d<Vf1`3Ab[L00`3B
bkT0dlbj0=?<^P050=?<^RP0eLjl0100d/^i0=O@_P3BbkT0e/nm0=7:^03C
c;X0`KZX07I_G@2MYIP0[;J[0;G1]`2`_K@0ZkR_0;S4^P2a^k00]knb902c
_K850;Bn/`<0]Knd0`2f`;D40;O1]P80^<:g102i`kP30;[4^@<0^lFj00@0
_<Jk0;k6^`2na[/0_/Jk0P2oak`30<38_@<0`<No0P31b<030<;9`@@0`l[2
;034bl<04035c<@0`l[20<;9`@33b/80aLc40<?:`P2ma;`0^L2h069eK`21
Ui@0X[bk09bj_02Q_/80WK^m09fg^02R^[X@09jk^@0D09W0^`2I]kD0XkRi
0:Jj^`2P^[T0V[Zg09^k^02O_;X0Y[Zk09Vm^@2L^KL0Ykbm09Nn^@2L_;T0
XkFg09fk^@2P_K/0W[^i0:6n_02K^;H20:6o_@0R09Rf]02P_[`0W[^i0:2m
^`2N^kT0X[bk09fe]@2P^[T0W[^i09bj^02K^kP0WKfj0:30_@2F][<0X/:o
09fm^P2P`;d0W;bi0::l^`2T_;`0Xkfl09nl^P2Q_kd0X;jl0:2m^`2T_[d0
WkVh0:W3`P2T_[d0W[Rg0:_5a02Q^kX0Z<;10:K0_`80Ykno00H0[<C40:S0
`02/`L80[/?40:Rm_P2`aLH20:_3``0I0:S0`02`b<P0[lC50:c1`P2dbLX0
[L;30:g7a02[aL80/<[70:[4`@2ablP0//c90:[4`@2^b<D0]l_:0:c2`02b
c<T0[L[60;?=bP2^al@0^<[:0;K6aP2db/P0//_80;?<b@020;;<b@030;77
a@2icL`0]LO70200]<[80100]L[;0;;7b02gc<d0[/?40;C9bP2P]KH0I7Uj
08RMWP2L`/D0Ukg009c6a@2I`l80V/C309S2`02J`/40WLC3202K`L80602L
`/D0W;o109[1`02D_[X0Ul6m09k2`P2L`/<0UL7209K0_02K`[l0W<G109O1
_@2K_kd0XlO509W2_P2M`Kl0WKo009k2`P2G_[d0W<?209c4``2I`;l0WlK5
09Zn_P80W/;202T0V[fo09k4a@2F`;l0UL7209_7b02H`L<0V<K309fo`02Q
`<80VLG409K4`P2O`/@0WKk309O3a02S`L<0W<?209;0_@2PcLX0V[bm0:C0
``2P_l40W/K50::n`@2UalP0WLC30:C<c02G_kl0XLW909_5a02Lb<T0W<?2
0:g<cP2O_/00Z<[;0:W;c02O_/00YlK80:?:b@2Tb<P0Yl_;0:G<b`020:;9
b00a0:O>c@2Vc/d0U[jm08ZRY02[alX0YLO90:S>c`2Vc<d0Z/c=0;??d02a
bLT0/M3B0:G9b@2`d]<0ZlW;0;3>d02/c/l0/M3B0;3<c`2`c]00/<oA0:c>
c`2^d]80[]3A0:o>d02`c]00/lc@0;CBe02/b/`0[/g?0;3?d@2]c<h0/m7C
0;;>d@2cc=00/M3B0:k=c`2acm40]=3C0;3<c`2`c]00[/g?0;3?d@2/bld0
/m;D0:o>d02/bld0/mGF0:g?d0020:k@d@080:c@c02^d/h0Zlk:0:oBcP2a
dM00[lg=0;;>c`2acLh80;7?c`0:0:[AcP2_cLd0Yk^l0828RP3AdM<0lo?c
0?kno03jo?L0oooo0?clo080oooo00@0oOgm0?knoP3oool0o?cl203oool0
00P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0
[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[CP38`:T20<W1ZP80b<2Y0`39
`JX30<[2Z`@0bl>^0P3<a:l20<g5/0@0cLFb0P3>a[<20<o7]080c/Nd0`3?
b;D30=39]PH0dLZg0P3BbkP60=?<^P80e<fk:03Ec[`0403Gd;h0f=6o0=7:
^03Ec[`0dlbj0=;;^@3@bKL0/:VG06AZG02/]:L0];jc0:nk/@2lbKl0[KV_
0;:l/@2d_k4S0;>m/PD0];jc102e_k@20;K0]@@0]l6f0`2h`[L30;W3^0@0
^/Bi0P2kaKX20;c6^`80_/Jk0`2oak`30<38_@80`<No0`31b<030<;9`@@0
`l[2;034bl<04035c<@0`l[20<?:`P34bl<0aLc40<C;``30akl0_LBl09JW
X@1NLFd0Uk2]0:6m_P2I]kT0X;k009bh^@2R_;/@09jk^@0G09Zn^P2P_K/0
X[Jg0:6e]P2N^;L0X<2m09bj^02Q^kX0YKZk09Fi]@2R_kd0Vk>c09_2_@2H
][@0Y[Zk09nm^`2K^;H0WKZh09nl^P2K^KL0W;Zh09fk^@2Q_kd00P2M^kT0
302R_kd0V[Ne09jk^@2S_K`0X[nm09bi]`2P_[`0WkVh0::l^`2Q^kX0Y;jm
09^e]0<0XK^j00/0Xkfl0:K0_`2K]K@0Y<6o0:K3`@2K^;H0YL;00::l^`2Z
a<<0WKNf0:_5a0030:S2`@030:O1`02V`;l0Zl?30080Z<3001d0/<S80:W1
`@2W_kl0//O80:Rm_P2Y`L40[<C40;?;b`2W_kl0[/K60:[2`P2`aLH0/LK7
0;;6a@2aaL@0[l?20;75a02calH0[l?20;;6a@2ebLP0[/;10;S>c02ab/L0
/lg:0;7:a`2db/P0/L?30;k>cP020;;8aP060;7:a`2ccLX0]<g:0;77a@2g
blX0^<[:802db/P0402cb<T0//O80;K;c02gc<d0[/?40;?8b@2?Y:D0Fg1a
09Bg^@2L`/<0Vl?309Fo_P2KaL@0VL?109[2`@2I`;l809_1`P1/09_3a@2G
_Kh0X/K60:75``2O`l40Vkno09Bl_02KalP0Vl;109k2`P2K_kl0WL7109o1
`P2K_Kh0X<;309^j_02N`<40X/C509g1`@2I`L00W<C309O1_`2H`/00VL?1
0:;1``2J^K/0ZLS:09bn`02M`<80Wl;409Nj_P2O`/H0UL:o0:32``2L_[l0
UL7009C2`02M`<80V[fo09G3`@2S`/@0Uknn09[8a@2?_;T0Yl_;09fl_P2R
a/H0V<;00:S:b`2K_Kh0Xl;40:;4a@2Sa/P0X/G70:32a02U`/H0Xl[90:32
``2WbLX0Wl720:?5aP2Vb<T0YLO80:78a`2T`/@0[<[<0:;1``2`cm40Y/G7
0:c;c@2Yb<X0YlW:0:g;b`2ZbL/0/=;D0:_>d02Wb/`0[<k?0:S6a02ac/`0
YlW:0:c>c`2Ta/L0]MCF0;7@dP2_c]00ZLS:0;?Ad`2_dM00[<c;0;3@c`2b
d]40[Lg<0:k>c@2_cLd0/]3@0:o=c@2bd=00/];A0:o?cP2bd]40[L_;0;C@
d@2bc/l0/<c=0;WCe02ecm00/L_<0P2fd=401`2abl`0]M7B0;[De@2dc/l0
[LO80;GAdP2^b//00P2acLh02@2bc/l0[lo<0;CDd@2adLh0[/c:0;7?c`2^
c<`0[lg=0;CBdP080;7?c`0?0:c@cP2bd]40[L;30:Jd]@1mPh<0k>k]0?Og
m@3noO/0o?cl0?ooo`3moOd0o?cl0?ooo`3no_h0o?cl00T0oooo00080?oo
o`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jVT`2o
]j00al2V0<S1Y`37`:H0aknX0<S0Zdd0b<2Y0`39`JX01038`:T0bL6Z0<W1
ZP39`JX40<[2Z`<0bl>^0`3<a:l20<g5/0<0cLFb0`3>a[<20<o7]0040<k7
]03?b;D0clRe0<o8]@@0d<Vf103Ab[L40=;;^0D0dlbj0`3DcK/X0=G>_005
0=C=^`3Fckd0d/^i0=G>_03Fckd00`3BbkT0202BUXL0Ri630;>k/02d_[D0
/Kfc0;6m/@2g`KH0];na8P2c_K860;Bn/`<0]Knd0`2f`;D30;O1]P<0^<:g
102i`kP30;[4^@<0^lFj0P2la[/0102na[/0_lNl0;o7_02oak`40<38_@04
0<37_`31b<00`LS00<78`0@0`/W10`33b/8a0<C;``80aLc400X0`l[20<78
`030blD0QIB?07B7Q@2T_;`0VkNh09nm_@2N_;`0VKNe402N^kT05`2M_KX0
Xkfl08RLW@2ba/L0XK^j09Ne/`2O_;X0XKVi0:2e]P2N_[/0ZLK409Na/02K
_k/0W;Zh0:Bi^P2J]kD0VkRf0:?0_P2L^KL0X[nm09fk^@2L^[P0W[bj0080
V[Rf0P2O_;X01P2Q_[`0WK^i0:2n_02M^kT0Wkbj0:?0_P80VkRf0140YlC2
0::o_@2O_;X0Wkbj0:C1_`2T_;`0W[Rg0:G2`02T_[d0Y/2o0:_3``2Q^kX0
YL;00::l^`2V`;l0Yl700:>m_0020:O1`0050:W3`P2X`/40Y[jn0:W1`@2[
`l<00P2W_kl0302]aLD0[/K60:_3``2_alL0Zl?30:g5a@2/a<@0//[:0;38
b02abLT0[LG50;G;b@80[lG301D0]<[80;K<bP2fc<X0/lW70;;8aP2hc</0
//K50:o5``2bb<H0[/C20;[>c@2ealL0WZj^0;O;bP2hc/`0[/O40;7:a`2d
cLX0]L_90;C8a`2ebLP0802db/P0402dbLX0]/_<0:o4a@2dbLX0[L;30;S=
cP2balP0OY>D06V8R`2UalT0U[bm0:79b@2C_K/0W<C309[2`@2J`L0809_1
`P1609K2`@2OalL0TkFd09Rd]@2A[jl0X/K409c6a@2E_kh0U/2o09_7aP2O
alL0U;bl09c6a@2G_kl0VKo009o7a`2IaL@0T[bk09[4``2J`/80WLG509c2
``2E^k`0W/C509Jm_02Qb<L0Uknn09W1`02Na<D0W;o10:77b02J`/80V<;0
09o1`P2M`L40VLO409:n_@2O`L<0Wl;409G6``2M`l@0W<C409o9b02Ja<<0
VKo00:36a`2MaLD0V/C308jo^@2PbLD0Y/K509o1`P2I`L00WLO50:73a@2^
al`0Y<K809o5aP2Tb//0XlK80:K9b`2L`/<0YL_<0:O9b`2Zb/T0Y/K50:_=
c02O`L00[Lo>0:C6a@80ZL_:00d0Zlg<0:K8b@2Ybld0YlW;0:g<c`2]c<h0
ZLW60:o?bP2Xb/T0]MGD0;3@c`2^d<l0Zl_:0080/]3@0100[/k=0:kBd02]
clh0/m7A0;3:b`2dc/l0//k?0:_;bP2`e=80[/c<0;?Ad@2dd]80YlG50;;@
d02_cLd0/<k>0P2acll05`2/b/X0]=;B0;OEe@2Zb<P0[L_;0;KDe02^c<`0
//k?0:o;c02edm<0/m7A0;3>cP2acll0]]CD0;3>cP2cbl/0]Lg=0:k8a`2`
cL/0/Lg>0;GCd`2bd=00[/k=00P0/Lo?00`0[]3?0:g=c02`cL/0/<K409NU
Y@2V[:`0nOOh0?Wcm@3kno/0oooo0?knoP3moOd20?ooo`030?clo03oool0
oooo00L0oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07ai
LP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Zd`0b<2Y1`39
`JX30<[2Z`80bl>/0P3;`jh30<c4[`<0cLF`0P3=aK830<k6/`<0clNd0`3?
b;D30=39]PD0dLZg1@3BbkP40=?<^P@0e<fk:03Ec[`0103@bKL0e<fk0=G>
_03BbkT20=K?_@80clRf00P0cL^l07n1L`2=T8D0/k^`0:ni[P2c_k<0];na
0:nj[200/kfb1@2d_[<50;Fo]0<0]/2e0`2g`KH30;S2]`<0^L>h102ja;T3
0;_5^P<0_<Jk0`2oak`30<38_@80`LVn0`31b<030<;9`@@0`l[2=P34bl<0
2030al00_LK107J2OP21U980W[Nd0:K3`@2I^KH0W;jm402N^kT02@2M^kT0
XKVi00dO8@1/P840Xkfl0:6n_02N^;L0Y;Ri0:Jk_00209Nd/P030:?0_P2M
^kT0Wkbj0080X[Zj0P2N^kT0902L^KL0UkBb09fj^02R_;/0Y;jm09jh]`2L
^[P0W[^i0::l^`2J]kD0VKVf09bo^`2O_;X0WkNg09Vi]P2P`;d0X/:o09>c
/02M_KX0Wknl0:?3`02J^[L0XKVi0:S5``2S`;h0WkVh0:Fi^P2T^;T0Z/;2
0::o_@2X`Kh0YKjk0:Bm^P2/aL80Y;fj0::k^080Z/?002<0Z/2n0:_1_`2_
aL<0/<K40:c5`P2Z`l00ZL:o0:k7a02_aL<0//S60:c2`02eblT0YKjk0:W2
_`2dcLX0[LK30:[7``2XaL40]=7=0:g:aP2XaL40[/_70:_8a02`cLT0/L?3
0;C8a`2icL`0]<S70;_=c@2caLD0Z[Zj00LG5`2K[Jd0]l_:0;;8aP020;;;
b0030;?<b@2aalD0]<S70200]<[80100]/_<0;G:b`2eb//0^<g>0;O<c@2c
b<T0[L;30:k3a01^RXd0LY2B0:K8b@2G_[d0VL7009_3`P2F_[h0W/K6202K
`L80AP2E`l40U/?00:W7a`1LKW00:Cho09>j]`2NblP0Vl7209[8aP26_KP0
WL_909O1`02A`l00V/S609[2`P2Ca<40T/C109C5`P2Ha<<0VL7109Vl_P2J
_;h0X/740:2o`P2KaL40V<O10931^`2Ha/<0UKnm09k5a02F`;l0UlG309c4
a02M_l40W<?209O5`P2D_[`0Y/C609fo`02Ca<00V/C309W1`@2O`/@0X/G7
09[2`P2H`/40WlW809c4a02Dc<40XL_70:?3`P2Ra/@0X]3=09C9``2PcLX0
Wl720:O5a`2Qb<L0X<O60:K5a`2ZbL/0Y/g<09o6a@2WaLL0XLS50:O>b`2U
c<T0X/W60:S<bP2Vb/P20:S<bP0K0:S?c02]dLl0Y<K70;;Ae02_cLl0ZLO7
0;GCd@2[blH0/MGC0:_7b02Za/L0Zlg<0:g?cP2bc<d0]Lo@0:_;bP2/d<`0
[Lg:0;O?c`2icLh0^/k?0;7;bP2/cl/0[MC?0;GBd02Ya/@0^=GC0080]]3?
00L0]M;@0:o=b`2^c//0[m;>0;7Ed@2VcLP0Z]7<0080[]G@0180[M7=0:kA
c@2^dLd0[]7=0:c?b`2^dLd0/]GA0:W<b02/c<T0/m?@055SI@1:GUl0]lc=
0;S@d02acLh0/]3@0;7Ad02`d]480;7?c`080;CBdP2[blX0]mOD0:S6a02c
c<T0RiNG0;Ng^@3on?d20?_kn`80oooo00@0oOgm0?ooo`3oool0oOgm203o
ool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2N
UH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[C038`:T60<W1ZP<0b/:[
0`3;`j`30<c4[`<0cLF`0P3>a[430<k6/`<0clNd0P3@b;D20<o8]@<0d<Vf
0`3Ab[L50=;;^0<0dlbi103Cc;X40=C=^bP0eLjl0100e/nm0=C=^`3Ec[`0
d/^i0=C=^`3Id/00e<fk0=7:^03@b[X0a<6b075cIP2KXID0];jc0;W3^02^
^J/0]l:d802c_K830;Bn/`D0]Knd0`2f`;D30;O1]P@0^<:g0`2i`kP30;[4
^@<0^lFj0`2la[/20;g7_080_lNl0`30b;d30<79_P80`LS00`32bL430<?:
`PH0a<_30P35c<@Y0<C;``030<G<a034bl<0a<_300<0`l[200T0a<_30<K8
``2l`K/0]Kji069aK029WYT0W[Re09Zj]`2M_kh0402N^kT0D02O^KH0PiNF
000?3`2I[J`0WkVf09jk]`2T^[P0T:2P086GU@2Y_K`0XKZg09bi]@2L]K80
W[Nd0:O0_@2T^;L0WkVf0:6k^02Za<40N96>0:W2_`2R^;H0X;Jd0:Jl^P2U
`[h0Uk2]0:Vo_@2S_KX0W/6k09Nj]02V`;d0Z;Zj0:Fk^@2X_[`0X;Jd0:Jl
^P2U^kT0Y[bj0:2f]02Y_kd0Yl2m09nl^02O_[T0Xkbi0;;2`P2Z^;T0[lG3
09nn^@2BYZD0W[:a0:Vm_02^`/40Zknn0;C8a`2Y_K`0[<2o0;32`P29Vi/0
OY2@0:Rl^`2fb/T0Z/2n0;77a@2/`/00/lG50:fo_`2``/80/LG40;O;bP2`
a/@0[L?10;K<bP2ca/@0]<O50:o2`02dalD0^Lc:0;74`P2jcL/0//G30P2h
blT03P2fa/D0QYJE0:fk^`2gaLD0/l7102<c<P1RLW80/<;20;O;bP2gcL/0
/L[70;;;b02aalD0]l_:802db/P0402fbl`0[lC50;O<c@2fbl`0]L[;0;C9
bP2^`l@0/lS90::j_01QNg`0OYbL09Vk_02PalH0U[jn09[2`P2K`l<809_1
`P1`09C2`02E`[l0XKno038m@@1<GV00VlC009?0_@2S`<@0X/7309O5`P2H
_;`0YL7409[7a02M`L40X[^o09g5a02P_l40Y<;409jl_P2K^K/0XlG609k5
a02F`;h0UL?00:O4`P2E^KD0WlS409c3`02U`l<0X[^o09jm_`2L`l80VKo0
09k0`P2H`<00Tl6n0:;9b02>YZP0LHf>0:3=b02Jal@0Y<K706Z3Q`2G/kH0
Zm;A09O4`@2KaL<0Wl?309o2_P2M]kH0MhV;09:ZZP2QaL<0X<g809g7``2S
b/T0[/750:_=c02Oa/<0/<[;0:Bn_`2Sb/L0Y<K50;C7b`2^c<X0Xl6o0:o<
bP2ZalD0//c;0;3:b@2^a/H0[lO70:S;a`2^d<l0YlK80:g<cP2[bL/0]m?D
0:S2`@2ecl`0Y/W50;[?d02>Xj@0/mKB0:c<b@2jc/l0^<c=0;;Bc`2cdLl0
]]3?09V][P25U9L0ZKRk0;_@d@2edm40Z<c80;G?cP2dc<`0//O80;O;c02i
c/l0[lO70;?@cP2cdLl0/<S80;OAd02bcld0/m7?0:W7a@2ed]00//c;0;G=
c@80/lg<00h0_=KE0;C<c02:XZ80VJj_0;kCe02aa/L0NXV<000A4`2_`l@0
/<S80;C>c`2_cLd0[<c;0:c>c@P0/Lo?00d0/<c=0;7Ad02^d<l0ZLg90:[8
aP2[_Kd0Q8V=0<S6b`3dm?@0n_[j0?ooo`3moOd0no_k0080oooo00<0oOgm
0?ooo`3oool01P3oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3R
h^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[B`38
`:T50<W1ZP@0b/:[0`3;`j`00`3<a:d0c<B_0<c4[`030<g5/0<0c/Ja0P3>
a[<30<o7]0<0d<Re103@bKH30=7:]`D0d/^h103Cc;T30=?<^PD0e<fk:03E
c[`0103Id/00d/^i0=G>_03Gd;h20=C=^`80eLjl00P0d<Nf0=G>_P2]Zih0
If]M0:VaY02a^k00/kna0:nk[B00/kfb1P2e_k@40;K0]@<0]l6f0`2h`[L4
0;W3^0<0^/Bi0`2kaKX30;c6^`<0_LNl1030b;d30<79_P030<;:_`32bL40
`/W10080`/W10`33b/860<C;``<0aLc4:034bl<20<G<a0030<C;``33b/80
`l[200<0`l[200P0alc50<G:``2ma;`0Y[6Y05]/IP2CZJH0XKjl09Zi^a00
W[^i05<0XkVg05a^KP0F9RH0[<2o09Rb[`2R_;T0DFET00082@001@D08bh`
09BXY`2Q^kP0;3`l02Dg=`1gSH/000P:05I/JP2P][@0QifK01<W9P2Q/k<0
XkFe0351@@003`l0V[Ba000B4@1?Gel0Y[nl09Rk]@2N`K/0W[Bb00062000
10P0008603Pm@@20QHT000D900021P0320`00@H:0:Bm^P2N_KP0YLG00:[0
_P0e@48000<60:Jj^@2Ta;l0?dm?06MgM`2``<00NXZ:000:2P1BHV80]lO7
08bLW00C7R0000`=00051P0>7Qh0Gfm_0;G7a`2X_;/0GG5`00031@0030d0
2ALH059RHP2P/;00^L_;0;G9b0002PT00PH900021@0<41<0PhN:08nCUP04
20/000@700031P1OLW00[Kfl01@R8P02000:2P0906ahN02nc<`0DEmO04=A
DP2hb<P0]/[90;C:b02bblP0]Lk;0280]<[800@0//O80;C9bP2balP0[/?4
0P2dbLX02P2gc<d0]<W:0;K8bP2G[:d0E75_09Bd/`2SalL0V<3009c4a02I
`L4809_1`P2009[4`P2Jal@0XKnm010I7P1^P880U/>l09W3`@0S=3/09c0g
0:S6aP1jQhd0004:02Y4A@1hRXh01@D?00062@0010/0008904eHGP002`l0
NiNH09[3_`2Gb/<0S<Rn03XmA0001PT0VK6a024e=P000`T000L?00052@2T
`<40Vl720:33a@2F`;l0UlC10:;0`00a?d8031hP09Nk]`2I`kl0SZRY000<
4P17FEd0W;jm09S5`02Sb/L0Xko0059JG@000@D000@:00011`0[=SX0XkJj
0:[6a`2Ta<<0004704YXIP2Ub<@0EfU[00072@1?LVh0DFm]0002200010L0
00hA07n:SP0Z=CT0008700042P0B6Al0HFQ^0:_8aP2acll0Z/W;0:oAdP2`
cm40Q9jO000=301HJ6L0]=CA0:2^/@0?7B00Zl_80;?Ac`0Y=3P021<G0;7?
c@2X_;/08S@d000=3@001PL000@504eQH02jdm00/Lk:082FU0001`H000D5
00041@0eADD0Wk>b0;cFd`2/bLD0=STn00021@0010H000D506AdM02h`lD0
00<600001@001@L0;3Li0;Fo`@0mAdT0008500H;3`11ATX0aL[>0;c>d000
3a00HWMh0;_Cd`2edM80[L_;0:o?cP2ceM@80;7?c`0<0;;<c@2acll0YlW8
0:gAc`2adLh0//[:0:>b]@1oR8d0hn?S0?clo03oool0no_k0P3oool00`3m
oOd0oooo0?ooo`070?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[
0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:]:
0<S0Z@H0bL6Z0`3:`Z/30<_3[080c<B]0P3<a:l20<g5/0@0c/Ja0P3>a[<2
0<o7]0@0d<Re0`3@bKH30=7:]`@0d/^h1P3Cc;T20=?<^PH0e<fk:@3Ec[`2
0=?<^P0=0=SA_`3Fckd0d<Vg0=;;^@3DcK/0f<^j0<k5]03Ac[l0W9jA08:8
O02ia;H0/Kf_0;:n/00P0;>m/PD0]Knd1@2f`;D20;O1]P@0^<:g0`2i`kP3
0;[4^@@0^lFj0P2la[/40;g7_0<0`<Rm0`31bKh20<;:_`<0`/W10`33b/86
0<C;``@0aLc4:034bl<00`35c<@0a<_30<C;``050<C;``080<G=`P33bl00
_lNl0<;<`@2;V8l0LhJ20:No_`2J][T@09jk^@1P0:Fi^01GIfL0=49309fa
/02X`[l0NiFB000:2P0g@D<0BUYJ00852P1HJ6P0Y[nl02La<`0X=SL0ZKfl
00052@0lD4l0ZK^k051RHP001@D0RINH0:^f^00@6Q`0<C/m0:Fk^@0020T0
Ef9T0:Vm_02K^kH0UkZd0:Vk^`062@h0;SHi05mWJP1XL7<0O8B700072P19
DE@0FV9U05mWJP2T^[P0Y<>n0:71_02U^kT0FV9U00852P2CYJD0Y<Bo00dI
6@0d@400[[Zj06mkN`002PX0QI6A09BPX00:5QH000H804UAD`1BG5d01Q8B
00061P1hQXH0]lO605UYJ0012@/0Ff=U03i8B@001PH09c<c0:nm_@2jb/T0
00D403Dj?@1UJVd0H6EX0:N/[`2>TiH0004404]@D`1WK6l0PiJD03A4@`09
5AD0HF]/02D];`0;5AH0^lO705i/K00^>C/0_lg>0;?5a@2aalD0/lc90;G>
b`2db/P0//S6802db/P0402`aLH0]lc=0;K;c02dbLX0^m3A0;76a`2balP0
/lS90;?3``2caLD0QIfM076?S`2E^KT0W/C509No_`2La<H809_1`P2009k2
`P2Ga;l0Wkfk00031@25ViT0U<Jm09c5`@0Y<3X0:c0d0:?2_@0K9BL040lE
08BMVP1oSHh00`0503mCDP1BI6H0F6MZ08bGV`000`L0@4mB0:W1`@2G]k@0
U;Rd00401@0`>S`0ZKjo02Di>P0F7b@0EEaT05U/L02K^kX0V/;409_1`P2J
a<<0XL_909Va/`000`X0008508NQWP2Ob<80H79d00001`0C61h0Z<G309[3
_@2O`[h0C61Q00021`0A71h0E6AT034l?P000`X06AhT0;C9bP2QaL400@04
05idL@2<ZJ@010h?024[;02V`kh0EVaY00D3201SLg<0DF5Q09f[[00/>S/0
4A`N06=]K`0N9RT000<604]MG`2bb/X0/];A09o3``2_dM00[/K600041@1=
DUD0[Lc7065YK0000PD0T:fY0;3=b@0C61`0<cPl0;7;b00X<S@000<503I1
@`1HIVL06BLX00051@1;GEd0_Lo?08BFUP001@H0AU1B04eEF006418000h>
09BZZ02fd<d0<cHk01/P901JIFL0GFe]08NGU`2h`lD00`P<03@g?01PL700
J7Ig06MeMP001@L0Ef5S03Dm@0073100V9fQ0;K>cP0gCdl0<Ta;0:[4``2`
c<d0/m7A0;;Bd@2]cL`80;7?c`0<0;OAdP2^b//0/=3?0;7Ad02YbLP0[<[:
0;C>c`2@YJP0^KVi0>KViP3oool0oOgm0P3oool00`3lo?`0oooo0?ooo`07
0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[0>;Ri01lNG80S8Uj
09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:]80<S0Z@L0bL6Z103:
`Z/20<_3[0<0c<B]00@0c<B_0<g5/03=aK00cLF`0`3>a[400`3?ak80c/Jc
0<o7]0020<o7]0<0d<Re00@0dLVf0=39]P3@bKH0d<Vf0P3Ab[L30=;;^0L0
dlbi00<0e<fj0=C=^`3DcK/01@3DcK/Y0=G>_0060=;;^@3HdKl0dLZh0=;;
^@3Fckd0d/^i0P3Ec[`0203Mc[/0e/^i0=3:^P37b;X0R8j207b7N@2f`[@0
/kna802c_K840;Fo]0D0]/2e0`2g`KH30;S2]`@0^L>h0P2ja;T40;_5^P<0
_<Jk0`2mak`0102nb;d0`<Rm0<38_@30b;d20<79_P<0`/Zo0`32bL420<?:
`PL0a<_31035c<@X0<C;``040<G<a034bl<0a<_30<C;``@0aLc400P0`lg2
0<;:_@36c<00_LFj0;g8`01kRhP0M8V:0::k_a00W[^i0240Y;Jf03E3A01F
I6D0Y;Rg0:6k^02Q^[L0EFEU0:bd]`2Y]kP092<Y02`j>`2O]K<0<CHj02/e
=`2T^;L06AXO02Lg=`2V][H0;C/l00072@1?FE/0[KFh00072P0h?D40XkNf
000;3@1NIVT0XkFe0:;2_@2M_KP0Zk^k00<2201DJVP00P2R^;H0?@1jT8h0
00X807B:R02/`/00X[Rf0:Nm^`2Q`;/0Wknj0:Nm^`1_M7P01@H;07b<S01b
TXd000D70006202^][P0FF5S00031@2?UiT0AdmA00072@1aMGP0][^n0<35
b02EWIl01Q0A01TU9@2c`L40GVa/00021@31a/T0_<7406adMP001`P0Kg]k
0;O5a@002PX0FFe[0;O;b@2aaL<0^/k<07fAS`003@/0Oi>A0;C8aP2ca/@0
UZJU08VCU02k`lD0P8F800062025TI40R9JF00TD5P2gaLH0]<K60;K:b@2e
blT0[/O40;;8aP2hc/`0802db/P0402hcLh0Zl310;W>c`2dbLX0//O80;C9
bP2hcLh0/lS90;S6a`2gbLT0ZL7106n=S@1bUYH0VKo009c4a02I`L<809_1
`P1`09jm_`2G`Kd0PZ:O00041P2P^KH0U/W009[1_P0c<Ch09CDd04A_I@00
20H0EEmP0:K;``1aS8L0004407>BS02Ha[/0V<2g0:K1_00;6AT000<60000
10061`/0000400021P1SMgH0XL6l01Ti=P0R=cP0Z;fn09o1`02Fal40Vl?5
09No_`2Ja/D0UKnm07jAU@0100L00`@9059VI@2M`[X0<d5100T22@0100D0
T:VU0:79`02>[JL000D401HY9`2J^[D0WlNo0:G2_P15Ce4000@:05QeL`2O
dLP01`0205MZIP0^Ad4000@508J:R`2ab/@0FfiZ00L00P2YbL@0[/g80;3=
b@0H=C40:44n0:g6``2eblT0?U9A0004202L/;40Zl_:0;7He`2WblT0]lo?
01<K7P0e<cP0//o;03@g?00000D0C6IS0;C>b`041@X0?d1506N0O@0000@0
DUMJ0;K0`@32d=00Z;Rg01d];00010@0XJf]08NEU@0010@0SiBG0<34a`2I
WZ402ADE041DDP2gd<`0:CTh02Di=`2gd/d0]mK@0:[9``2lem8000H405m_
KP80/<o900h0Y/>n05mjM@2ec/X0ZKnl0006101IKF/0//c;0;WCdP2/bLL0
]=7?0;;@d02_cLd0/<k>0;7Ad0P0/Lo?0100/lg>0;;>c`2bc/l0/<k>0;;B
d@2]cL`0YlO60:c<b`2;Rh/0`/;20?;blP3moOd0n_[j0?knoP3oool0no_k
203oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9
NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[@038`:T40<NoZ0@0
b<2Y00@0b<2[0<W1[039`J`0bL6/0`3:`Zd00`3;`jh0b/:]0<_3[P020<_3
[P<0c<B_00@0cLF`0<c5/P3<aK80c<Fb0P3=a[<40<k7]0<0clRe0`3@bKH5
0=7:]`@0d/^h103Cc;X40=C=^cP0eLjl0100e<bi0=S@_@3>ak@0e<nl0<72
/P1dMf`0SiV@0;:o]P2d_[<0[k^_0:nm/02e`kH0ZkV/0;G1]@2g`KH0/KV^
202c_K840;:l/@P0/kfb1@2d_[<30;Fo]0<0]/2e102g`KH20;S2]`<0^L>h
0`2ja;T20;_5^P<0_<Jk00@0_/Jk0;o7_02oak`0_lNl0`30b;d00`31bKh0
`<No0<78`0020<78`0<0`/W11@33b/8l0<C;``0@0<G=`P2oak`0bM380;_5
_031cL<0[KV_07>0M`23T8L0WKbg09jm^02M^[P0Xko009Nc]02Q_[`0XL2k
09bl]`P0W[^i0600VKbf02/k>`1IHfD0Y;Zh09nl^02N]k@0Y;fj09^j]@2Q
[Jd05Q/N02m3@@2K/Jh0<3Dh02`d=P2S^KH09cLf00@>3@2Q[J/01P0400TE
4`0L6Qd0V:fX00030`1JIV@0YkZh00<4200a=CP0GfMY07AeN@2^^;T0Zkjl
00011@1JJVX0Wkji09jn^@1jS8`000@407^DT02O_[P0Xl2k0:>k^`2V_[h0
Z<6n0:Nm^P1kShd000T605mYJ01BFeP021LD00030P1dMGL0EUYK0005102^
_[/05bHS024[:P2e`<@0//C60:c2`02_`L40Ef5R0001102QZjX0GG1/00L6
2`2^`Kl0]<g90;S4a00K7200BTmB0;_5aP0010L0GF][0;W=b`2ZaL00/lc8
08:ET`002PT0P9JC0:k;aP2ZcLH0]Lk:0;S4a031bL/0GfUZ00092@25Ti<0
RIFE00@3202nb<T0]<[80;7;b02bblP0]/[90;C8b@2cb<TX0;C:b0280;;<
b@2aalD0/lO60:^m_`1WO7l0NiVI09k5a02Ja<80VLG409Bn_@2MaLD0W<;3
09_1`P2Na<D0V<3009c4a02EaLD0Y<K507:<R@000`T0V/;109G3`@2E_k/0
;SPi01lT:00=41D010lC09J`/@2Zb/T0JHb800081@1oSHh0UlS209K3_P2G
a<40AEQL00L02010BT/0CFeR014L500010d0T[Bc09o2_P0Z=3H09cDf09O0
^P2Ja<00Q9NM02/b>00/;cH0FgAa0:K6`@1>F5X0000402@/;P0l?D40W<Fm
00l>500c>ch01@8905EPHP2Ne<L0Eg5^00<01`1aQ8/0Y<?60:?=b`2PalH0
X[Nj00041`12EUL0Z<S500000P0g=CX000<802@c=P2]alH0]<W:05iYJ`00
0PD0Y/G70:_?c@2^b<L0;CLi02Ta=02cc<T0/]3>09B^[@030000K7ak0:c<
b`2]c<l0[<_>0;7?c`0Z>3P050/>0:Ro^@000`803@d?01@E5`2b`Kh000L2
05]ZI`1?De@000850:o3a02]c<h0[m;D0;7=d@1jRi8000<7075kO@21VYL0
008708VAU02`dll0Z/g904eDFP0G6R<0]Lg?02/g<`0_>CP0/<o90;3=b@2a
c/`0/m?>0004101NKVd0ZLg=0:c>c@2fdm40/L_80;S>c02BY:@000L;061W
KA00/Lo?0100/]3@0;7?c`2`c/h0/<k>0;7?c`2`c/h0[lg=0:g;b`2`aLH0
O8b<0<79c03in?d0oo[n0?olo@3oood0n_ci203oool000P0oooo0100oogo
0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0
b<6W0<O0YP37_jP0b<2[@038`:T30<NoZ0D0b<2Y1039`J`20<[2[@H0bl>^
0P3<a:l20<g5/080c<Fb0`3=a[<30<k7]0@0clRe0P3@bKH50=7:]`D0d/^h
103Cc;X40=C=^cP0eLjl0100em2m0=C=^P3DcKX0dljk0<K3/P2c]JL0KG=W
0:6YWP2c_K80/[jb0:fk[P2`_[40]L>f0;:n/P2^^:d0^<2e202c_K840;:l
/@L0/kfb1@2d_[<40;Fo]080]/2e102g`KH30;S2]`<0^L>h0P2ja;T30;_5
^P<0_<Jk102oak`20<38_@80`LVn1031b<020<;9`@H0`l[2?034bl<04035
cL80`/Zo0<K=a@36d<L0`<c20;k:`02OZZ80IG9Y09>`Z`2M^[H0YL;009Vc
]02W`l@0Wkbj09Vh/`2M_;L809jk^@1P09jn^@0S<c<0GfY/09ff/`2N_KP0
Y[bj0:>e]@1EJfT01A4A00072@1FJVP0YKjj030e>00Y<C<0Y;Zg04UIF006
1`T0Hfm]00L82P1WMg@01`L905MVH`0010D0FVIT0:>l^00010L000H80004
10001`T0EVIU0::h]@001@P0E6IV09jm^02P_KT0QHnA00L62`0S9bX0:C4c
03Hg>`2X`<00Y[jn0:Jo_02[`Kl0WK2^00050`1LIF@07B4R049BC`0kAD@0
@dA602da<P0<5QD0^<O400040P1TKF`0Zl310:W3`P2/bLD0[lS5086?S`00
1@L0RiFD05YYIP000PD0/<K30:_8``2a`L00<CTk02di>@2e`l<000L901`P
8`0b?3d0;cdm09JRXP2=UIL0004408VCU02jb/T0[lk80;K:b02BVY`0<CHi
00<=3P0B8R40^<S708BBTP010PH0^lO70;G;b@2bc<T0/L[70;C8a`2db<T0
/lS9:02db/P02`2bc<T0]L_90;;6a@2_`L<0VZnb05UeMP29[J/0Uknn09_5
a02Na/H0U;bl0080W<;307/0U[bm09o7a`2I`L40T/300:30_`1bS8T00047
0:;9b02I`l80VL:n02Xd=@0000@0008600011`1[N7h0UK6b07RBT@002@/0
620R02P_=`0X=c`0W;^m09B/[P0000L0DUiN09N/Y@061@<0;Se409o3`@2R
`[l0:38d02Td=P2L`kh0V<G0086JWP0R=3H09CLi05MgM02L^kH072HX010K
7@1SMgD02@hA08FRWP0000D0J7=e02HY;P0[=CL0VLBk05QaKP0100D0YlG7
09W1`02LblD0X<W50;;7b00X=ST09SPh0:[7``030`<00082000310075aL0
R:2P0:_8a01HJVX000440:g;c@2[cld0ZLK402lm?P0a?d00YlK10:C;aP2c
dm001@<405=VI02adM00]=?E0;3?d@2cdM40D5iN00@0001/O7/000L807n4
Q`000PD0Hfe^00061P1VLW80:S@e02/g=`2eblT0Z/c;0:c@d02cdM<0[l;6
00051@1MJf/0P9^F00021@27TI<0/]G?0:[?b01MJ6`000<90;7>c00c=C@0
3`d@02Lk>@0]?Cd0K7]n0;C:b00000@0J6e`0;WAe@2_dM00XLS30:G2_P1=
EeT0000500031`2K/k<04@2acll30;3>cP80/Lo?00X0/<k>0:k<c02]alH0
ZKfl07f8RP3Si>P0noWl0?Wgn03oood0nogj203oool000P0oooo0100oogo
0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0
b<6W0<O0YP37_jP0b<2[@038`:T20<NoZ0H0b<2Y0`39`J`30<[2[@D0bl>^
0`3<a:l20<g5/0040<c5/P3=a[<0cLJc0<g6/`@0c/Nd0`3?b;D30=39]P@0
dLZg1P3BbkP30=?<^PD0e<fk>03Ec[`0403>bKH0em:o0=7:]`3BbkP0eLjk
0<c9^02RX940QXMi0;No]02^^:d0_LVm0:fk[P2a_k80/[jb0;Fo]02d_;48
0;>m/P<0/[ba1`2c_K860;Bn/`<0]Knd0`2f`;D30;O1]P<0^<:g102i`kP0
102ja;T0^lFj0;_5^P2kaKX40;c6^`<0_lNl0`30b;d20<79_P<0`LS00`32
bL450<?:`Sd0a<_30100`/Zo0<O?a02naKd0`<[10;k8_`31cL<0`<_309:M
U@1XPG/0Y;fi09ni^02P^[/0W;Ri09jk^@2J^;H0X;nj202N^kT0H02L^KD0
:cTj05QVI`2O_;P0Vk^f09fa/01HHV@000<500HD5@1JHVD0XKNe0:2i]P0V
;S40<C/m0:>l^@1EIfL01P04020Z:`0I9bL0Y;fi01TJ7P0Q9RT01PL;07N5
Q@2L^K@000H705m[J`2N[Zd0;CLh00XM6`2P^kH000L805MWI`2R_k/0X[bi
07j6R@0610T09bP/034f>@0h=c`0Yl700:K0_`2U_[/0[/C20:fm_00=5aP0
9RX[00000P1_Ph40KWYj00041`0U:B`0;cLi0;C0`0012@/0EUYM0:o>b@2V
a/40Y/G00:c5`P1jRXT000D608J>T01TL70000P:0;C:a`2_c<L0/<2o02`h
>00/?cd0^<_90007200L7B40;SHh02lk>`2@VY/0SY>F00041`2=UIL0^<K6
0;C:a`2MZj/05Q/N00031P0/=SL0UZJU0;S8a`28UYH01@T<0;G3``2ab/L0
/L_80;G;b@2ealL0]/[;0:k6aRP0]<[808P0/lc90;36a02jc/d0/<;40;K:
b`29Xj@0IhN609k2`02A^KT0X<S809k6aP2D_;`0V/;209o5aP2H_[l0V/31
09_7b02O_kh0MY2=00042P2D^;P0Vl?309[1_P0W<C808RHW07:6Q00]=cT0
008709>f/P1eSh`00004028/:`0/;cP09S<i0:32``2N_;`07bX^01/V:01Z
MW@01P0005efNP2J`L00X;jl02/b>00X<CH0W/6m09k;b02L_[l0Xl6o0:34
`02Ia;d0TZZZ00011@0^A480UkNb00051`0Y<c@00@8609BZY`18EUH00084
09bi]01KKfd0000409Ji]@2Xdl`0V/W10:O;a`2_aL<07RT[02Ph>02]a/<0
0@0004EDC`1aQ8804ahP01DY:02Wb/@0EG1[0082102^c<h0Z/k<0:_9a`0V
=SH0:CTi0:g=b02ZdL`0Yl[600000P1SMgD0Zl_:0:C3a@2_cLl0[<[:05mb
L001008082X[01`Z:P2mcL`041`L028W:P000@@0RYJF02Tl>P0L:2P0_=;?
0;7Ac02Yc<P0]M;@0:^o_P003P`0EVUW07RCSP001@H0Si^K0:W:``2fe]40
Hg5b00031@2ee<l0=CLf00d;3P0Q<c<0;C/n06ajO@2fb//0000506=XJ`2f
bm00[<[:0;KFd`0J;Rd0000501/L8@1iR8/0/=3=402acll0102`c/h0[lg=
0:o=c@2`c/h30;7?c`090;3>cP2[blP0[/S709NWY`2Z/[@0oOko0?ooo`3k
n_P0ooom00P0oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T
07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0ZdD0b<2Y
0`39`JX20<W1[0<0b/:]1@3;`jh30<c4[`<0cLF`0`3=a[<30<k7]0@0clRe
0`3@bKH30=7:]`D0d/^h0`3Cc;T20=?<^PH0e<fk>03Ec[`0403DdL00d/fj
0=kGa03@b;<0elnj0<o8]@3Abk/0UHmo08F;P@2h`;D0/[ba0;:n/P2`_[40
]<2d0;:l/@2e_K880;>m/P80/[ba1P2c_K850;Bn/`D0]Knd0`2f`;D30;O1
]P<0^<:g0`2i`kP20;[4^@<0^lFj0`2la[/20;g7_080_lNl0`30b;d30<79
_P80`LS00`32bL450<?:`Sh0a<_30100`/Zo0<WAaP35c<@0`L_20<;<``2o
bL00_/S00<3:`P1oTX`0NXn:0:Bj^02S_K`0W;Ri0:6m_P2K^KL0XKjj202N
^kT0H02S_KX0DV1Q04=CD`2L^kH0WL2j0::d]0011PX09RT^09n_[`2W/K<0
ZL:o09^e/P0`>S`0<C`n09fg]01aQH@03`090006201>If<0X;fh04iFF004
1@T00@D8096QX02S_[T00PX<05=MGP2b`<00De]M008E4`2R^kL000P:05eX
JP2U_k`0X[nk07V9R@001PL0O92>0:G0^`2R^kL0Y/310:Fo_P2Y`L40Ykfk
0:fm_00a>C/00@8401<C5@2/aL40WJf/00082P042@`0AU1A0;Bn_`0]<SD0
824U09Z`[P2db/P0[lG30;G7a`0e@d<00@d=0;Bn_`1QJf`00@D80;?6a02d
b<H0/Kfm00061`1JKF/0]lO600031P1TKVl0]lO60;?9aP2icL/0QI>C0004
101nTHl0]Lk:0;O:b01WLG80004406icMP2kalL0/lK40;K6a@1]Ng/0:S8d
0;g=c02cc<T0[/S50;?9a`2ealL0^/k?0;;:bRP0]<[808P0/<W60;S>c02`
a<<0]lW;0;34a@2abLT0MiBB07>AS`2Ub<X0V;^m09k4a@2MaLD0V<3009g5
a@2L`/<0Vl7209Jn`02Zb<P0VkRd00893`24YZL0W/7309o6``0/=SL0:3@b
09g3^022TY8000<506BBR01aTH`0000207N:QP2J`Kh0W<K209G3`02J_[h0
EfU]00031@0f?T00004009>e]`2J`/40Wkfm02df>`0[=3T0XL7009C1_P2L
a<@0Wl?109S5`02Ga;l0JGQk00@12P1HLW40WLJn02Tc=@0300@04QLJ0:W8
`P1[QX40004406QhM`1fRXP0008505E_K02Ua;l0YLG00:o9aP29VIT000D5
05e`KP2[a<001P0005Y[I@2hblL0GV9U00082P2[c/L0DfiW00@00P2[b/`0
X/K40;;@cP0_?Ch0:C@f0;O@c@2[b<H0NHf>0001101oV9D0/=3?0;KDeP2`
c<l0/=3?08BHU`020`L0000505e]K@2cc<T0D69R00D62`0100D0ZKBf05A^
J`0010D0RIbJ0;[Ed02ccLX0/lO606AbLP0010@0Sj:P08JKUP001`H0OXR9
0;WBcP2`bLD08bh`02/f>02`b/L0:CPe02lg>@2ccLX0^m3A0;?8b@2bcld0
00<5065dLP2^d=40]<c>08RFV@0010L0BE5D0;c<c02fbl`0//o=402acll4
0;3>cP@0/Lo?00P0]MSD0:O5``2eblT0SI^K0;Jl_03nool0n_Si0?ooo@P0
oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0
WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Zd<0b<2Y1@39`JX30<[2
[@<0bl>^1@3<a:l30<g5/080c/Ja0P3=a[<30<k7]0<0clRe0`3@bKH30=7:
]`D0d/^h1@3Cc;T60=C=^cX0eLjl0100dLjm0<k9]P3Cc;T0e/ji0=?;]P3J
d[l0eLjn0<o8^01lOgH0RHn50;O1]P2[]j/0]l>g0;6m/@2_^Jh0];jc3P2c
_K850;Bn/`D0]Knd0`2f`;D30;O1]P@0^<:g0`2i`kP30;[4^@80^lFj0`2l
a[/30;g7_0<0`<Rm0`31bKh20<;:_`<0`/W10`33b/880<C;``80aLc4>034
bl<01P34c/<0`L_00<K@a`37c/H0`/W10<G<a080aLc500P0^lS106mnN`1j
SX`0Y;bl0::n_`2O_Kd0Wkbj09^h]PP0W[^i0600WkVf05]YJP0N;Rh0W[fh
09Vl]P2/_[h01P/?055DF@2U]kL0Qi:D09ni]P2T`Kd09c8d02<a<P2P_KT0
T:JT00T01`001@H0QZNP09fj]@27UiH00004004;302R]K<0WkFc00D83@1O
I6P0WjV[03@g?00:61T0Y[Zi00021`1II6H0XK^h0::o^`22TY8000T:07V=
R`2S`;/0ZL:n0:G1`P2T_[l0[<K50:>h^@2a`l<0AU9B00462@16AdT0/<_6
0:k1_`0mAdP0008406=_K`2d`/80LWam00011011BD/0Xj^]0:Va/`1NJ6T0
00X<04QFE`2e`l@0Hfi`00P7302f`<40S9RH02L[;P093Q40VZZY0;k:bP02
0@H0HFe]0;K9a`2]`l00^Lg;08>CTP002PX0PYFC0;7:aP2galH0Hfe^0002
1@2e_Kl0_/c<08bOW@2kblX0H6a/045=C@2dalD0//_80;7:a`2ebLP0]LO7
0;S<c@2_bLPX0;C:b0280;C9bP2balP0/lO80;[>c@2aaL@0]<S70:o5``1W
P7d0NIRK09k0`P2K`L80Vl?309c6a@2E_Kd0W/C509bo`@2L`/D0W;bk0:;2
_@043A80LI2B09Vk_@2I`;d0:CLg02Pd<P2M`;T0?4Y;00011`27[ZT0LXb9
0040101lS8T0XLG1096k]`2Ia/<0VL7008j/[00010L0008503Y4@`2KaL@0
Uknn0:6o_`0V=3L08c4d0:K4a02I`l40V/K509o6a@2E_kd0XLS502`g?@0:
1a80RZNU0:?<aP1MI6X01005045?D02L`KX0UkNb00021@13CU00Yl6n01HP
8P033@h0JWQh0:jn_@25Ti@07BPZ00051P2=Xj40/<o:00@0001QLV`0X;2]
02TV;@0B5a/0[<_505idL@060080[Lc>0:[>c02/b/P0:cHh03@i?@2c`L80
O8N;00H9400K9RP0Z<;10:g?cP2acLh0]M7B0:o?cP2F[Zh000@700031`2L
/:l0/<o:096WY@0000D01@@:0;S6a`2B/Zd000@8020/;023Ti80_Lg<06ih
N@094A<05b<S0;O7a`2;UiL00044096FV@2Q[jl0AeMG00031@1`Ngd0^]3>
02dm>P0`>S/0/<g90;?8b@2jcm80]mGC00041@1LL6l0Zl[<0;WAd`2@WZ40
00D807N1P`2lc<`0Rj>S0;?Aca@0/Lo?102`c/h0202[cL`0/]3>0;O?c`2d
a<@0TIVK0<75aP3oool0oO_l203oool000P0oooo0100oogo0?[jnP3emo@0
ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37
_jP0b<2[@038`:T60<W1ZP80b/:[0P3:`Zd30<_3[PD0c<B_0`3=aK030<k6
/@@0c/Nd0`3?b;D30=39]P<0dLZg0`3BbkP60=?<^@80e<fj1@3DcK/k0=G>
_00@0=;?_03Ie<40c<Fb0=gE`P3Dc;T0e/no0=[DaP3Ofll0b/_307=fK@2_
]j`0[[R]0;>o/`2^^Zh0]/:f0;6k/0d0/kfb0`2d_[<60;Fo]0@0]/2e0`2g
`KH30;S2]`@0^L>h0`2ja;T00`2kaKX0_<Jk0;c6^`020;c6^`<0_LNl00<0
_/Rm0<38_@30b;d00`31bKh30<;:_`80`/W10`33b/880<C;``<0aLc4>034
bl<04034c/<0`L_00;c6_@33b/80a<_30<G:``3>dld0cM;<0=;He02jaL40
IgYh09J_[02N^kT0VkVi09nl^P2O^KP809jk^@1P0:2m^@1oSHh00a4B096^
ZP2L_;L0XkNf041:C0002@/08CDf00dK7P1SP7h0V;Jd02`j?@0X=cX0W;Zh
09ng]`0110T07RT[09Vi]02V_;X0Xkbi01DM800@8R80ZKfl0:Fk^@041``0
0PL;00031@011PX0FVQY0:c0_`011PX0EVQX0:2o^P2P_KT0OXR:00811P02
1PT00@T;00011@2W`L80Y/310:[4``2X`<00[L7005MWI`0010@0PHV;09nl
^02]`L00KgYl00041P1ZNWX0Zkfm0;G5a@17DU@00@D80000100;2Pl00044
028`<@2S]KD0^L_;05][J`0000@010h?00082P010PH0Jg=e0;;5``2lb/X0
1@<800041`001`P000d=08:>SP25SHl01``?08B>S`2nc/d0]/[80::`/000
20T05b<S01X]:`0N<S00]<C302D_<01PKVh0Zknm0;;<b@2dcLX0]lW90;G5
a@2cb<T0/<[9:02db/P0R02fbl`0[L720;_?d02fb/T0_]3@0<;Ed`39g=X0
//G305YfNP2G][T0W/C509Bn_@2KaL@0V<;109Vo`02N`L<0X<K909Ni^02P
aKh0<T1303aNG`2Q`lD0U[nk02<f=0000`@000/900011`0f=T00V[Be07^=
S`0000D0008400412@0020`0Xko009S0_`2C`;d07C0d00001@1RLW40Tknn
09g5a@2S`L40:3e0028g>P2N_;`0WLG509[4``2Na/D0W/3109fl_P065A`0
720Y0:?1`@2J`kl0O8V?00001`1QNGT0XlO30:75`@0V<CD010lC0:;6`P2;
WIl02A4D00021@001@P000<500082`1VNW/0[L_90:K:aP0220H000D2000:
2@000`X0HFY_0:[7``1HKV`00`870:_9b`2^d]00YlG302lj?0000@D00@`>
00021`0@3AH0S9jP0:o=b`2_dM00]]3A0:k8b@2]cL`0]]?A00041`0K9RX0
]/k>0;CDd@2_bLP04Q/P01DJ802jc/l0/mKB06ieN`0010D000D400041002
2P`01@d?09NUYP2balP0RiJH00031@002P`000<500093011D5<0]l_<0;?;
b`0]>CL000440007200010X0GV]a0;76b@093Q@0G6Y[0;oBf02_bl`0/];?
00PN700>5QT0<3Di00061`2H_kXA0;7?c`80/]3@00d0/Lo?0;3>cP2`c/h0
/<k>0;7?c`2bd=00^mOH0<;Gf037fMT0_LO8092FUP3_knl0ooko00P0oooo
00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF4
0:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Zd00b<2Y1@39`JX30<[2Z`80
b/:]0P3;`jh60<c4[`80cLF`103>a[430<k7]0<0clRe103@bKH20=7:]`@0
d/^h1@3Cc;T30=C=^P@0e<fk?03Ec[`03`3Cc[X0cLRd0=SA_P3Ec[`0f=71
0>;Ld03Wi=/0i^KN0>OXh02BUH`0TIN=0;W3^02`_;00/Kfa0;:n/P0=0;>m
/P@0];jc1@2e_k@50;K0]@80]l6f102h`[L30;W3^0<0^/Bi0P2kaKX30;c6
^`<0_LNl0P2nb;d20<38_@80`LVn1032b[l20<;9`@80`l[22034bl<40<G<
a3P0a<_30100_lVn0<G?a02nb;l0alk60<gBb`36bl@0cM;<0=_Mf03Si=l0
gnGQ08FETP25WY/0X[nm09^i^@2K^;H0Xkfl202N^kT0H02K^kH0Z;Rh018M
7`1YPWl0VkZe0:Rn_02K[Jd0CVAR02]0@@1@Gf80V[Rf0:;2_`1LJVd0Gg5c
09fk^@2R_;/0?51?06EeM@2H]k80Z;Jg09jm^01GIfL0A65M0:2i]P2P_kX0
EF1R05MUIP1HK6/0NHN80:Bj^02R_k/0FFMX07R<R`2R`[d0XL6l09FSY01X
JFd0EEeO05aVI`1SJ6/0Yko10:W3a02V`<40[LO60:Bm^P1nU980;T4o0:Vi
^02Ya/80/lO60:2^[`0b@T80Q9ZH0:o9aP2^al@0[L7006]kN00oBDP0:C4c
06IbLP2T^;L0[<G20:c1`P27UYT0Hf]]05QVIP1TLW80XJV[0;S8a`2cd</0
[L?006Y^L@1VJfh0H6a/05m_KP2S/k80Yk6b06I^L02W/k<0[l;00;;;a`2`
a<80QI>C03I6A@15FeP0SZBQ0:Ng]P012@/0W[6_0;S>b`2ecl`0/L[70;?5
a@2fa/H0]<W:0;CAcbP0]<[808P0/lO80;_?d02aaLH0^/k=0<KIe`3=gM`0
dn7Q0=SThP1nUi`0Q:6U09^n`02Nb<L0U<2o09W3`P2Na<D0X<;409No`@2P
al@0W<Fm05U[K@0G>CX0VK^m09_5`@1KLFh0DVQV059WJ01TLgP0Y;Fl0:;0
`P2=ZJX0DfMX055SH`1HFf80EFMY0:2j^`2QbLP0U/W405YdM@0`>Ch0T;>]
09S1``2M`l@0VkZl05AdL`1IMgL0XL320:;5a`2J`/@0VlO609nl`02D/[@0
BfU[0728S02Wc//0UlK00:W3a00Z>D00RJf]0:73a02RbLP0MhR?05IWKP24
]K40Z<7508nUX`1>H600:CPk04QGFP1fRHd0ZlO80:C8b02Vc/d0DFYV05Yc
L01LL740MXV=0:o9bP2adM00NYBC069bLP2`bLd0[]3?0:_;b01aPh<0GVa]
05M]J`1/PH80[;Nk0;O<c`2]cL`0ZLc80:o9b02gcll0/M7>0:o=c@10DUH0
IGYk0;;?c@2^c//0/lg<05i`LP1@HV@0/<[90:g@c02mc]D0OiBG045GE@0V
>CL0DEmO0:2`/02ecLl0[]3A09V][P1LLG80Ffm`05]]L@2:WJ40^M?D0:o>
d02]cm00J7Qg06M_L@1KL740GV]a08fLX@2ecLl0FV=X08FIV02gc=40ZLW8
0:oFd@2G][40@U1A03i6B@1iSHh0[]7=402acll0102`c/h0/Lo?0;7?c`2a
cll20;3>cP0:0;7?c`2cdM40^];D0<3Ef03:g]l0enOW0=gYj@2LXZ80e]OI
0?[jnPP0oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07ai
LP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Zd00b<2Y1039
`JX40<[2Z`040<[2[@3;`jh0bl>^0<_3[P<0c<B_00<0cLF`0<c4[`3=aK00
0P3=aK030<k6/@040<o7/P3>ak@0c/Nd0<k7]080clRe103@bKH30=7:]`<0
d/^h1@3Cc;T40=C=^P@0e<fk?03Ec[`0403Dck/0d/fi0=C=^P3Fckd0h=[<
0>CQf03Yj><0kNoZ0<[:`P1XJF40]K^a0:jh[@2d`;@0/[jb0:jj[P2b_;4<
0;>m/P@0];jc102e_k@50;K0]@<0]l6f0`2h`[L40;W3^080^/Bi0`2kaKX3
0;c6^`80_LNl0`2nb;d01030b;d0`LVn0<79_P31bKh30<;:_`030<?;`032
bL40`l[20080`l[20`34bl<00`35c<@0a<_30<C;``020<C;``@0aLc4>034
bl<04033cL80`/c10<G?aP34bl<0a/_40=7Fc`3Nh=/0j>[U0>c[iP32al<0
Gfi[09ff/`2N^kT0WK^k0::o_@2N^;L809jk^@1P09Zm]`2V][H0NhF70:>i
]`2M^[H0WKJc0::k^02N_KP0X;Ff0:^j_@2Q_kd0V;Re0:Rg^P2X^[`0UkNd
0:6k^P2K^kH0Y;Rg0:?0_02]]kT0UkZd0:^o_P2G^[@0X[bi09_3^`2V^[T0
Ykfk0:2m^@2Y_kd0XL2k09c1^P2W_K/0Zkfm0:33_@2PaKh0Zl6o0:Ji]`2Y
a/40X/Fn0:;3_02X`<@0Zl?50:Fo`02Ya/@0YlC20:W3`02Y`[h0/LO40:W6
`P2[`Kl0^/[:0:^m_@2ab/L0ZLS30:G2_P2bblP0Z<No0;;9``2fa/D0/lO5
0:k8a@2_c/T0//[:0;G4a`2hb<L0^Lo<0;;6a02jb<P0/<W50:W>aP2cd/`0
]l?30;G8aP2dcLT0/<g80:c7`P2hc//0[/;00;39a@2bdL/0//o:0;K<b@2f
bLL0^<c:0;77a02icl`0]/C408bAU02ebLL0/<W50:o9aP2cbLL0^/[:0;g=
c@2balP0[/_9:02db/P0R02db<T0]LW:0;W=cP34f=L0bMcJ0=cZjP3QkN/0
`L_:05U`MP2L^;`0X<?509O1`02KalH0U/2o09c2``2M_l40W<C609O0_02F
a;X0UZZ[07jRXP2RaLL0UL:m0:S3_P2HaKh0V[jl0:75a@2I`L40U/;108o0
_02Ib<80Vl:m09c7`02?`KP0WL6o09Ro_P2Ea/80Xk^m0:Ni^`2Bb[l0V<73
09o2a02UalP0W/;00:34`P2S`/@0W/320:36b@2CaL80Y/?70:2o`P2La/@0
X<S709S6``2Gb/<0Y<S60:O0a@2KaL@0YlW;0:36a`2]`LP0[lK<09?<aP2[
b<`0Yl_70:W9aP2Za<<0[LG70:g9c02WbLX0Ylo?0:;>c@2UcLD0[Lc70:g7
b02^cLl0ZM3?0:G9b@2^c/d0[<[80;;:cP2WbLP0/MC@0:[3`02ec//0[<o9
0:c@c02eclh0]<c@0:c>c@2`dll0^=3@0;38b02`d<d0[lo>0;S;d@2gdm@0
[L_;0;;@d02`c<d0//[<0;C<cP2bc/l0[Lo>0;7=d@2_cLl0/]3>0;7;b02j
c/d0]<c<0:c>c`2Xe=<0//k?0;3@c`2]bl/0]m3D0;C@d`2Wc/d0Z=;@0:WC
dP2fdlh0]<S70;3Cc`2dc/l0[LO80;3DdP2hcLh0/=3;0:k@d@2cdm80[<W7
0;GBcP2ccLX0/lc90;O<c@2ibld@0;7?c`0?0:o=c@2`c/h0/Lo?0;7?c`2`
c/h0/Lo?0;;@d02dd]80aMSL0<kQi@3KkNl0g^k^0<C@d02:Ti80mOWj00T0
oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0
WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0ZaP0b<2Y00H0`k^T0<No
Z039`JX0aknX0<JnY`38`:T20<W1ZP050<>kY037_jP0bL6Z0<NoZ036_ZL0
0P38`:T00`36_ZL0b<2Y0<S0Z@060<S0Z@T0aknX1`38`:T30<W1[080b/:]
1P3;`jh20<c4[`<0cLF`00L0cLJc0=39]P3<aK80blBa0<k7]03=a[<0c<Fb
00@0clRe0P3@bKH40=7:]`L0d/^h103Cc;X40=C=^cP0eLjl00<0e<fk0=K?
_@3Ec[`00P3Cc;T06@3Ec[/0eLni0=?=]`3Dc;D0g=Bo0=39^@3Nf/l0hn3I
0>c[iP3^knT0gn;K06UcJ02KYIX0]Knd0;2j[`2c_K80]l6f0;>m/P2a^k00
]Knd0;2j[`2f`;D0];jc0;2j[`2d_[<00P2c_K801P2d_[<0/[ba0;Fo]02f
`;D0/kfb0;:l/@@0]/2e0P2d_[<30;O1]P050;S2]`2c_K80^L>h0;W3^02g
`KH00P2i`kP01P2h`[L0^L>h0;_5^P2ja;T0_<Jk0;[4^@80_<Jk00<0^<:g
0<?=`P2na[/00`2oak`30<38_@090<79_P30akl0_/Fm0<C;``32bL40aLc4
0<37_`34bl<0`l[201X0a<_30P32bL430<C;``0;0<G<a036cLD0aLc40<O>
aP32bL40`l[20<K=a@32bL40a/g50<C;``33b/800P34bl<01033b/80a/g5
0<K=a@31b<0@0<C;``040<?:`P34bl<0aLc40<G<a0@0a<_30100alk60<?:
`P36d<L0aLo70<cCc03MgmX0i^GS0?3/j`3?gN00IgUk07nIV02O_k`0VKbh
09no_02R_;/0X;Rh202N^kT0202M^[P0W[^i0:2m^`2K^;H0W[^i09nl^P2I
][@0X;fk102N^kT409nl^P040:2j^@2Q^kX0XK^j0:6k^P<0X[bk00D0Xkfl
0::l^`2T_[d0X[bk0:6k^P020:Fo_P070::l^`2S_K`0Ykno0:S0`02W_kl0
YKfm0:No_`020:[2`P030:Jn_P2Y`L40Z/;20080Z/;2102[`l<0102^`l@0
[lC50:o4a@2_a<D30;35aPD0/LK7102balP01`2db/P0]L_90;;8aP2bb<H0
]L_90;?9a`2aalD00P2db/P0202fc<X0]<[80;?9a`2eblT0/lW70;77a@2f
c<X0]L_90P2bb<H01@2eblT0]<[80;;8aP2bb<H0/lW702P0]<[801<0]/[9
0;G9b02ebLP0]/c:0;G;b@2cbLL0/L[70;;;b02_bLP0^<k<0<;Bc`3Cg]X0
h>WV0>G_kP3Dh^<0HW5d08J/[@2E^k`0W<;30080V/3100<0W<;309_1`P2K
`L80202K`L80102J`<40W<;309Vo`02H_[l209[0`@H0Vl72102L`/<0102J
_Kl0X<?509o2a02M`<8209o2a00<09k1``2O`/@0V/700:37aP2NaL@0X<O6
0:78a`2PalH0Xl[909g4``2UbLT0X<C40P2UbLT0102Tb<P0YLW90:C8b02Y
cLd30:W8bP80Z/W;1P2[b/`20:c;c@<0[Lc>102_cLd40;3>cP050:o=c@2`
c/h0[lg=0;3>cP2acll00P2_cLd00`2edm<0/<k>0;3>cP030;3>cP<0/Lo?
00H0/<k>0:k<c02`c/h0/]3@0:o=c@2`c/h20;;@d2P0/Lo?0100]=3A0:k<
c02adM00[lo>0;3@c`2/b<T0^M?D0<;Jg03Dhn00f^CS0>W_k`3Oh>80T92@
0=OEeP3oool0o?cl203oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GV
j`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[
6@38`:T00`3;`j`0aknX0<BlY@020<S0Z@0:0<FmYP36_ZL0cLF^0<W1ZP36
_ZL0aKfV0<S0Z@39`JX0b<2Y0<JnY`P0b<2Y2037_jP60<S0Z@80bL6Z0P39
`J`30<[2[@D0bl>^0`3<a:l30<g5/0050<[3/03=a[<0c/Nd0<o8]@3Ab[L0
0P3?b;D00`3@bKH0clRe0<o8]@030=39]P<0dLZg1P3BbkP20=?<^@@0dlbj
103DcK/h0=G>_0030=C=^`3Ec[`0eLjl0080e<fj01/0e/nl0=G>^`3Cc;T0
dl^f0=?<^@3Rg<`0gm_@0>WVg`3al^`0jNcU07]nM`2?VHh0ZkFZ0;O1]P2b
_;40/K^`0;:l/@2`^Zl0/K^`0;>m/P2/]Z/0/;Z_0;Bn/`2e_k@0]/2e0;6k
/02b_;400P2e_k@20;K0]@090;Bn/`2f`;D0]/2e0;6k/02e_k@0]/2e0;W3
^02h`[L0]/2e0080^/Bi00D0];jc0;S2]`2ja;T0^<:g0;O1]P020;[4^@0:
0;W3^02ja;T0^/Bi0;W3^02la[/0^/Bi0;g7_02nb;d0]l6f0;W3^0@0_lNl
0P30b;d20<79_P040<78`032bL40`LS00;g4_080`/W100<0`l[20<C;``34
bl<05`34bl<01@33b/80aLc40<O>aP36cLD0a<_30080alk600@0`LS00<G<
a02ma;`0`/W10`36cLD01032bL40`l[20<C;``34bl<20<G<a0040<;9`@35
c<@0b<o70<K=aA80a<_300<0aLc40<C;``34bl<00P35c<@04@36cLD0_/Ro
0<C>a@36cLD0c]G>0=?HdP3WjNH0l?;_0>SZi`1bP8<0NXb>0:Bn_@2S`l00
V;Re09Zh]P2N^;L0X;Rh00X0W[^i0P2O_;X0102Q_[`0X[nm09jk^@2O_;X4
09jk^@@0Wkbj102Q^kX20::l^`80Xkfl00X0XK^j0:>m_02U_kh0Yl700:K0
_`2S_K`0YKnn0:c6a@2T_;`0Ykno0P2Z`/80102Y`L40Z<300:[2`P2]aLD4
0:[2`P80Zl?30P2/a<@40:o4a@80/<G61@2aa/L50;;7b0040:o5``2eblT0
]/c:0;C:b080]L_900<0]<[80;K<bP2aalD00P2cbLL01P2bb<H0]/c:0;O=
b`2db/P0/LO50;36a080]/c:00D0/lW70;C:b02eblT0]L_90;O=b`0X0;C:
b00H0;G9b02db<L0]LW80;K<bP2eblT0/lW70;C:b02fc<X0^m?C0;[>c@3A
gM/0h>WV0>K_k03Pk>X0KX:1082HV02E^k`0WL?409k4a@2I_l00V/3109c2
``2K`L80V/31202K`L80202L`/<0V/3109c2``2OaLH0WL?409_1`P2L`/<0
V/31102K`L8409c2``0;0:33a@2Qa<H0Wl;409g0`P2O`/@0X<?509o2a02P
`lD0XLS709k5a02K`/400P2NaL@00`2Ma<<0XLS70:?:b@020:?7a`060:C8
b02SalL0Yl_;0:O;b`2Pa<@0X/K60P2Yb<X30:[9b`D0Zl[<0`2/bld30:g<
cP@0[lg=102`c/h02`2bd=00]=;B0;7?c`2_cLd0/m7A0;GCd`2acll0[L_;
0;3>cP2acll0/]3@0080/Lo?0`2`c/h0202cdM40/Lo?0;7?c`2bd=00/Lo?
0;?Ad@2bd=00[<[::02acll03`2bc/l0/<k>0;KDe02Xb<L0/]3@0;[Fe`2l
e=@0`]OH0=SThP3]moH0g>;R09fNX03=cLd0ooko0?gmo@090?ooo`00203o
ool0403ooOl0n_[j0?Ggm03_l?80iNK[0>;Ri01lNG80S8Uj09jEQ02^YY<0
_kNP0<O0YP38`JL0al2V0<NoZ038`:/H0<S0Z@0;0<JnY`38`:T0bL6Z0<No
Z036_ZL0aKfV0<NoZ03;`j`0aKfV0<BlY@35_JH00P38`:T20<JnY`T0b<2Y
2037_jP40<S0Z@@0bL6Z00@0bL6/0<[2[@3:`Zd0b/:]1@3;`jh30<c4[`@0
cLF`00@0c/Nd0<g6/`3>ak@0cLJc0P3<aK800`3=a[<0c/Nd0<o8]@030=39
]P@0dLZg103BbkP40=?<^@<0dlbj1@3DcK/h0=G>_0040=?<^P3Ec[`0eLjl
0=G>_0<0eLjk00`0e<fj0=G>^`3NfLH0g][>0>OTf`3fm^h0k>gW09JITP25
Rh40[[R]0;Bn/`2e_k@20;:l/@070;6k/02b_;40];jc0;Fo]02c_K80]Knd
0;>m/P020;:l/@030;6k/02e_k@0/[ba0080/kfb0P2a^k001@2f`;D0^<:g
0;Bn/`2e_k@0/[ba0080]/2e00@0/[ba0;K0]@2ja;T0]/2e0P2h`[L03P2f
`;D0]l6f0;_5^P2kaKX0^/Bi0;_5^P2ja;T0^L>h0;_5^P2ja;T0_<Jk0<7;
`02obKh0_<Jk0`2oak`30<38_@80`LVn00H0`<No0<K=a@32bL40`<No0<C;
``38clL20<;9`AT0a<_300T0`LS00<C;``34bl<0`<No0<?:`P37c/H0`/W1
0<O>aP32bL400P38clL20<;9`@80a<_300@0aLc40<C;``36cLD0aLc40P32
bL400`35c<@0a/g50<C;``0?0<C;``030<G<a034bl<0a<_30080a<_301<0
aLc40<K=a@36cLD0_/_10<C>a@39c/P0f]cG0>SXiP3XkNT0i>gZ08VDT01m
Si40Wk>d0:O1`02G]K<0WKfj09jl^P2O^KP0XKVi00P0W[^i00@0X;fk09nl
^P2L^KL0WKZh0P2N^kT00`2O_;X0W;Vg09jk^@0209jk^@D0Wkbj0`2Q^kX3
0::l^`80Xkfl00T0X[bk0:Bn_@2U_kh0Xkfl0::l^`2T_[d0YKnn0:>m_02Y
`L400P2V_[h20:S0`080Y[jn00<0Ykno0:[2`P2Z`/800`2[`l<30:c4a0<0
[lC50`2`aLH40;76a`H0//O800<0//S60;K<bP2eblT00P2aalD30;?9a`03
0;G;b@2fc<X0]L_90080/lW70P2gcL/01@2cbLL0]<[80;O=b`2bb<H0[lG3
0080]L_90P2`a/@X0;C:b00G0;G9b02db<L0]LW80;K:b@2eblT0/lW70;G;
b@2gcL/0^<k<0<cLf`3KiNH0j>k^0>Sbl@1oTY00NYNE09bn_@2L`/<0W/C5
09_1`P2H_[l0Vl7209g3a02L`/<02@2K`L80102M`l@0U[bm09Vo`02M`l@2
09Vo`00309c2``2K`L80Vl720080Vl721@2L`/<0102P`lD0Wl;409bo`@2M
`<820:74aP050:33a@2Qa<H0X<C409k2`P2QaLD00P2SalL0302Ra/H0Wl?3
0:75a@2SaLH0Y/S90:G7b02Q`l@0YlW:0:[<c@2Vb<T0ZL_<0:W8bP<0Z/W;
1@2[b/`30:c;c@@0[Lc>0`2_cLd50;3>cP0=0:g;b`2`c/h0/<k>0:k<c02`
c/h0/Lo?0;3>cP2acll0/<k>0;;@d02cdM40/]3@0;7?c`030;3>cP<0[lg=
0P2^c<`00`2bd=00]=;B0:o=c@0X0;7?c`0>0;C@d@2acLh0[lg=0;;@d02f
dm40]lo?0<gQhP3Hj^`0h^c[0>Wbl@2RYZL0aLK80?Shn03oo_l20?_kn`P0
oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0
WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0ZaP0b<2Y00d0bl>/0<Fm
YP37_jP0bL6Z0<JnY`37_jP0bL6Z0<FmYP36_ZL0aknX0<W1ZP3:`Z/0b<2Y
0080a[jW2@38`:T80<NoZ0<0b<2Y1@39`JX30<[2[@<0bl>^1@3<a:l30<g5
/080c/Ja00P0clRe0<g6/`3Ab[L0clRe0<g6/`3@bKH0d/^h0=?<^@<0d<Vf
0`3Ab[L50=;;^0D0dlbi0P3Cc;X60=C=^cP0eLjl00@0dlbi0=C=^P3Ec[`0
eLjl0P3DcK/20=G>_0090=[Da03Mf//0inGI0?CdjP3[k>@0[k:[08N=P`2g
_k@0]Knd0080/K^`0`2c_K801`2d_[<0]Knd0;6k/02f`;D0]Knd0;2j[`2a
^k000`2e_k@01P2c_K80]/2e0;S2]`2f`;D0];jc0;Fo]080]l6f00P0^/Bi
0;Fo]02e_k@0^<:g0;O1]P2d_[<0]/2e0;[4^@<0]/2e00<0^L>h0;_5^P2j
a;T00P2i`kP01P2mak`0^lFj0;g7_02la[/0^/Bi0;c6^`80_/Rm0P2oak`3
0<38_@<0`LVn00H0`LS00<C;``32bL40a<_30<?:`P36cLD20<;9`AP0a<_3
0100bM380<C;``34bl<0a/g50<C;``31b<00`/W10<K=a@32bL40a/g50<S?
a`33b/80`LS00<G<a037c/H0a/g50P33b/800`34bl<0aLc40<?:`P020<;9
`@030<?:`P34bl<0a<_300h0a<_300D0aLc40<C;``33b/80`l[20<C;``03
0<G<a00@0<;Ba`38d/T0fM_F0>7PgP3[jn/0k?;`0::a[P1bQh80X[Jg0:Jn
_P2K]K@0VKNe0:;0_P2L^[P0W;Vg0:6k^PX0W[^i00D0W;Vg0:2m^`2O_;X0
W[^i0:?0_P0309jk^@H0Wkbj0P2Q^kX30::l^`D0Xkfl00/0Y;jm0:Fo_P2T
_[d0Yl700:W3`P2V`;l0ZL710:No_`2V_[h0Ykno0:W1`@030:[2`P@0Zl?3
0P2/a<@20:g5a@80[lC50`2`aLH30;76a`D0//O80`2cb<T20;G;b@80]<[8
01<0]/c:0;S>c02gcL/0]L_90;K<bP2eblT0]/c:0;G;b@2aalD0/lW70;K<
bP2eblT0]/c:0;;8aP2`a/@0]<[80;O=b`2db/P0//S602X0]<[800<0/lW7
0;C8a`2ebLP00P2ebLP03P2gblX0^lo>0<SKf@3Dh^80h^c]0>cdmP2MZ:X0
N92@09Vm^`2LbL@0V/3109Vo`02H_[l0VKo00`2L`/<909_1`P0809o5aP2K
`L80W<;309_1`P2J`<40Vl7209[0`@2L`/<209_1`PH0W<;300@0W/7309g0
`P2M`<80Wl;40P2P`lD01@2O`/@0X<?50:;6aP2SalL0Y/[:0080XLG500/0
Yl_;0:C8b02Tb<P0YLO80:O9bP2Xb//0YLO80:C6a`2Vb<T0YlW:0:[<c@03
0:[9b`<0Zl[<1@2/bld30:g<cP80[/g?0P2_cLd60;3>cP0:0;?Ad@2acll0
/Lo?0;;@d02acll0[/c<0:o=c@2dd]80/<k>0;7?c`80/]3@00P0/Lo?0;3>
cP2acll0/]3@0;7?c`2cdM40]=;B0;?Ad@80/<k>0P2bd=0X0;7?c`0>0:o;
cP2dd=40/Lg>0;;?c@2meMD0a=SG0=?Sh`3Nk>d0koWh0;>i^@2i_Kh0no_m
0?ono`3mno`:0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[0>;R
i01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:/H0<S0
Z@060<JnY`37_jP0b<2Y0<W1ZP38`:T0aknX0P38`:T01@39`JX0b<2Y0<Jn
Y`35_JH0a[jW0080bL6Z00<0aknX0<S0Z@38`:T03P38`:T50<W1ZP<0b/:[
0P3:`Zd30<_3[PD0c<B_0`3=aK030<k6/@070<g6/`3;a;40dLZg0=39]P3?
b;D0dLZg0<k7]0030=39]P<0dLZg0`3BbkP50=?<^@<0e<fj1P3DcK/j0=G>
_080e<fj0180eLjk0=C=^`3DcK/0e<fm0=G>_P3Gd<00f=C80>OUf@3`l>H0
kNkV0<K9`P1hOW@0[KFZ0;O2]02c_K80/K^`0;:l/@2d_[<30;>m/P0R0;2j
[`2b_;40/kfb0;2j[`2a^k00]/2e0;O1]P2d_[<0[kV^0;:l/@2c_K80];jc
0;O1]P2h`[L0]Knd0;Bn/`2f`;D0/kfb0;K0]@2e_k@0]l6f0;_5^P2i`kP0
]/2e0;_5^P2h`[L0^L>h0;[4^@2kaKX0^L>h0;S2]`2i`kP0^/Bi0;_5^P80
^/Bi00<0_/Rm0;g7_02la[/00P2mak`30<38_@<0`LVn0P32b[l01`34bl<0
_lJn0<78`034bl<0_/Fm0;o6_P33b/806@34bl<03032bL40aLc40<?:`P34
bl<0b<o70<G<a032bL40a/g50<?:`P36cLD0`/W10<78`080alk600H0`l[2
0<78`033b/80`/W10<78`032bL430<G<a1T0a<_30100`Lk40=KPe`3Hf]D0
jn_Y0>oal02f`<40LHF309^e/P2P^;P0WkVh09jk^@2R_kd0WK^i09bi]`2N
^kT0XK^j202N^kT0202M^[P0Wkbj0:2m^`2Q_[`0Wkbj09bi]`2N^kT0W;Vg
1P2O_;X20:2m^`<0X[bk0`2S_K`30:Bn_@0<0:6k^P2S_K`0ZL?20:K0_`2Q
^kX0Y;jm0:[4``2V_[h0ZL710:_3``2Z`/80Z<300`2Z`/820:_3``80[<C4
102]aLD30;35aP<0/LK71@2balP50;?8b@070;C:b02bb<H0/lW70;K<bP2g
cL/0]L_90;C:b0020;?9a`060;77a@2bb<H0]L_90;G;b@2cbLL0//S60P2c
bLL01`2aalD0]L_90;O=b`2aalD0/<K40;C:b02eblT0:@2db/P20;?9a`80
]LW800/0]lW90;c>cP32e=@0eNCQ0=o[j`3Zm?H0//3307N:SP2J^;P0W/O3
0931^`0209[0`@0309_1`P2L`/<0V/310080VKo000<0V/3109_1`P2K`L80
1P2K`L80202G_Kh0Vl7209g3a02H_[l0W<;309o5aP2H_[l0Vl721P2L`/<2
09g3a080X<?50P2Qa<H02P2O`/@0W/7309o2a02P`lD0X<C40:75a@2SalL0
X<C40:75a@2Tb<P20:;6aP080:G7b02Ra<D0Y/S90:[<c@2Vb<T0YLO80:S:
b`2Vb<T20:[9b`<0Zl[<1@2/bld30:g<cP<0[/g?1P2`c/h20;7?c`050;?A
d@2`c/h0[lg=0;7?c`2bd=000`2acll0102`c/h0/Lo?0;7?c`2acll20;3>
cP050;7?c`2cdM40[lg=0:o=c@2acll00P2cdM400`2`c/h0[lg=0;7?c`0X
0;7?c`80/Lg@00h0^=CE0;K@c`33fML0enOW0=_Wi`3`n?X0`<W80;2f]P3j
nod0o_ko0?omoP3mno`0oooo0?cno@P0oooo00080?ooo`0@0?omo`3jn_X0
mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37
`:H0aknX0<S0ZaP0b<2Y00@0`k^T0<W1ZP35_JH0`[ZS0P38`:T01034_:D0
aknX0<FmYP38`:T20<[2Z`040<S0Z@36_ZL0aknX0<NoZ100b<2Y1039`JX4
0<[2Z`@0bl>^0`3<a:l50<g5/0<0c/Ja00T0clNb0<o8]@3=a[<0clRe0<_4
/@3>ak@0dLZg0<c5/P3BbkP0103Ab[L30=;;^0D0dlbi103DcKX50=C=^c/0
eLjl01D0eLjk0=C=^P3DcKX0e<fk0=C=_@3EcL00fM740=gEb03ThMP0k>cT
0?7bk03Ef=40KG9[0:2XW@2f`K<0[[^Z0;:l/@2c_K80];jc0;>m/P2b_;40
0P2c_K80202a^k00]Knd0;:l/@2b_;40]l6f0;Fo]02a^k00]/2e0P2g`KH0
0`2e_k@0/K^`0;6k/0030;Fo]00A0;S2]`2f`;D0^lFj0;S2]`2c_K80]l6f
0;_5^P2i`kP0^<:g0;W3^02ja;T0^lFj0;[4^@2i`kP0_<Jk0;k8_@2mak`0
0P2obKh0102ja;T0^lFj0;o9_P2nb;d20;o9_P80`<Rm0`31bKh30<;:_`03
0<?:`P2oa[h0aLc40080aLc400<0`LS00<G<a033b/806@34bl<01`39d<P0
aLc40<37_`34bl<0alk60<G<a034bl<00P36cLD03@32bL40aLc40<O>aP32
bL40a<_30<[Ab@35c<@0alk60<C;``31b<00a<_30<K=a@35c<@04@34bl<0
0`33b/80a<_30<C;``030<C;``0B0<K=a@37c/H0c]G=0=KKe03ZknT0jno^
0<kHe`1PL6l0SJJS09^h]P2R_kd0Wkbj09jk^@2O_;X0W;Vg0::o_@2N^kT0
WKZh202N^kT309nl^P0509^h]P2L^KL0Wkbj09jk^@2T`Kl01@2O_;X30:2m
^`80X[bk0`2S_K`30:Bn_@060:Fo_P2V`;l0Xkfl0:>m_02W`L00ZL?20P2V
`;l0202Y`L40Z<300:W1`@2Z`/80[LG50:k6aP2/a<@0ZL710`2/a<@30:g5
a@80[/K60P2`aLH30;76a`<0//O81P2cb<T20;C9bP040;K<bP2cbLL0/lW7
0;?9a`80/LO500@0]L_90;O=b`2icld0]/c:0P2bb<H00`2fc<X0]L_90;?9
a`020;C:b0070;?9a`2db/P0]<[80;;8aP2fc<X0]lg;0;;8aP0X0;C:b00D
0;G;b@2db/P0]<[80;K:b@2hb/X0_/k>0<KFeP3>g]h0gnSW0>Wcm033dm<0
I7Ul08f[[@2RaLL0U/2n09[7a02L`/<0Vl7209g3a02L`/<209Vo`00309c2
``2M`l@0Vl7200L0Vl720P2M`l@01@2Na<D0Ukfn09[0`@2M`l@0Ukfn00H0
W<;30`2M`l@0202P`lD0XLC60:;5a`2P`lD0Wl;40:;5a`2Ub<X0XlK80P2S
aLH02P2Q`l@0YLO80:G7b02SaLH0Y/S90:O9bP2[b/`0Z<O90:O6b02[b/`2
0:W8bP030:g<cP2Yb<X0Zl[<00<0Zl[<0`2/bld50:g<cP<0[/g?00<0[lk@
0;3>cP2`c/h00`2`c/h30;7?c`090:k<c02acll0]=;B0;?Ad@2`c/h0/Lo?
0;;@d02`c/h0/Lo?00@0/<k>0`2acll0102cdM40/<k>0:g;b`2]bl/20:o=
c@030;3>cP2cdM40/Lo?02L0/Lo?00d0]M7D0;7=d02gdM80amoO0<KHf03R
k^h0m?[j0=?DeP2=Ti<0h>CU0?[jo03oo_l0oogn0080oooo00<0o_oo0?oo
o`3oool01P3oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0
O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[6038`:T0
4037_jP0bL6Z0<[2Z`37_jP0`k^T0<S0Z@3;`j`0a[jW0<_3[034_:D0`[ZS
0<S0Z@39`JX0aKfV0<BlY@37_jP@0<S0Z@80bL6Z1P3:`Z/30<_3[P<0c<B_
1@3=aK030<k6/@80clNb0P3?b;D01@3@bKH0blBa0=;;^03DcKX0bL:_00@0
dLZg0`3BbkP40=?<^@H0e<fj103DcK/l0=G>_00S0=K@^P3DcKX0e<fj0=G>
_03Fckl0fM740=oGc03Vg]<0jNWQ0>o^j@3Yj^D0LgQb08nFS`2d_[<0]<2b
0;;0[`2a^k00];jc0;>m/P2b_;40/kfb0;Bn/`2c_K80]Knd0;2j[`2a^k00
];jc0;S2]`2a^k00/[ba0;W3^02`^Zl0/K^`0;S2]`2i`kP00P2e_k@20;O1
]P0<0;S2]`2ja;T0/[ba0;Bn/`2i`kP0]l6f0;W3^02kaKX0]/2e0;S2]`2i
`kP0^lFj0P2ja;T02`2obKh0_/Rm0;K0]@2c_K80`lg20<3:_`2kaKX0_LNl
0;c6^`2mak`0_/Rm0080`<Rm0P31bKh40<;:_`080<78`033b/80a/g50;W0
^03:dLT0`l[20<K=a@32bL4H0<C;``070<K=a@2oa[h0`LS00<G<a033b/80
a<_30<K=a@020<;9`@030<?:`P34bl<0alk60080`l[200X0bM380<37_`2n
aKd0a/g50<O>aP32bL40`l[20<G<a034bl<0`l[24034bl<00`33b/80a<_3
0<G<a0020<C;``0;0<K=a@3:dLT0c]G=0=gNf03Xj^D0i^cX0=oZiP1XN7L0
Q9ZH09Rb/@2U`L800P2K^KL01@2I][@0XKjl09fj^02N^kT0VkRf00X0W[^i
00L0WKZh0:2m^`2I][@0XKjl0:G2`02H]K<0XKjl00@0Wkbj102P_K/20::l
^`80Xkfl102T_[d02@2S_K`0Z<;10:Fo_P2S_K`0ZL?20:K0_`2R_;/0ZL?2
0:_3``020:No_`050:_3``2Y`L40Y[jn0:W1`@2abLT00P2/a<@20:g5a@@0
[/K60P2`aLH20;76a`@0//O81@2cb<T30;C9bP030;K<bP2eblT0]<[80080
/lW701<0^<k<0;O=b`2_aL<0[lG30;W?c@2fc<X0/LO50;G;b@2fc<X0/lW7
0;K<bP2eblT0]<[80;77a@2eblT0^Lo=0;;8aP2_aL<0^Lo=02P0]<[80100
/lc90;C:b02db/P0]l_:0;_=c@34e=@0dMoP0=_YjP3WjnX0h>[Y06QmOP1k
VY`0U[bo09[2a02La<@0VL2o0P2K`L8209c2``0409Vo`02L`/<0WlG609g3
a0P0Vl7200P0X<K709Bj^`2M`l@0W/C509Vo`02K`L80V;jo09_1`P@0W<;3
102M`l@00`2O`/@0X<?50:74aP020:33a@070:G8bP2TalT0W;o109bn_`2X
b//0X/C50:C6a`020:G7b0080:g?d02Q`l@0X;o10:o>d02/bld0Z<O90:W8
bP2XalT20:W8bP<0Zl[<0`2/bld50:g<cP<0[/g?0P2_c]040;3>cP@0/Lo?
00<0]=;B0:_9b@2[bLT00P2bd=020:o=c@80/Lo?0P2`c/h30;7?c`050:o=
c@2/b/X0ZlW90;?Ad@2dd]800P2_cLd00`2`c/h0/Lo?0;?Ad@0X0;7?c`0@
0;7=d02gdmH0_=KG0<kSi03Di>@0k?Ke0>3Qh`2HV9P0c=3A0?koo`3oool0
oO_n0?ono`3kno/0n_ck0?koo`P0oooo00080?ooo`0@0?omo`3jn_X0mOOd
0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37`:H0
aknX0<S0ZaP0b<2Y00h0Th]d0:6IPP33^j@0_KFN09B<M@2KTg`0`[ZS0<W1
ZP38`:T0Zj><09^CO02[Xh`0`[ZS0<W1ZP80aknX4038`:T70<[2Z`040<_3
[03;`jh0bl>^0<_3[P80c<B_1P3=aK020<k6/@<0clNb00P0cLJc0=7:]`3C
c;T0c<Fb0=7:]`39`Zl0/JZG0;>/V@<0dLZg0P3BbkP30=?<^@L0e<fj00<0
eLjk0=C=^`3DcK/00P3DcK/l0=G>_00R0=K@^P3DcKX0e<fj0=G>_03Gd<00
fm?60>CLd@3/i=T0m??^0>o`j`23QH00SI:<0;Nn]`2`_;00/Kn`0;;0[`2b
_;40];jc0;:l/@2a^k00];jc0;:l/@2a^k00]Knd0;>m/P2e_k@0];jc0;>m
/P2a^k00^<:g0:fg[025Sh@0R9:70:B^X`80]l6f01d0]/2e0;S2]`2g`KH0
]Knd09^UVP29ThP0W:JK0;_5^P2ja;T0]/2e0;c6^`2h`[L0^L>h0;[4^@2k
aKX0^/Bi0;_5^P2mak`0]/2e0:NaYP2=Uh`0];jc0<3:_`2mak`0_lVn0;g7
_02nb;d0_lVn0<38_@030<79_P<0`/Zo00P0`l_00<;9`@37c/H0_/Fm0::Y
X@31b<00_lJn0<G<a1T0a<_301<0YjjV09BKT`2X[jL0alk60<K=a@31b<00
alk60<?:`P36cLD0`l[20<C;``36cLD0`LS00<[Ab@30akl0TIR@0:nf[P2n
aKd0aLc40080`l[200<0aLc40<C;``34bl<04034bl<00`33b/80aLc40<G<
a0020<C;``0C0<O>aP3>eLd0dm[B0>SUh03^knX0j>kZ07^:Q@1jSX`0X[Zj
0:Fo`02K];P0WKfj09nm^`2J]kD0Xl2n09fg]P2M^[P0XKjl0:2m^`0809jk
^@80WKZh00H0Y<6o09^h]P2P_K/0V;Fc07FBT01fTi4409nl^P@0X;fk00@0
X[bk0:>m_02S_K`0Xkfl0`2T_[d04@2U_kh0Y;jm0:Bn_@2U_kh0[<K509ni
^01mUiH0OYRG0:K0_`2Y`L40Z/;20:g5a@2W_kl0TJVY082HV02@Z:P0[<C4
00@0[LG50`2^a/H00`2_alL0/<G60;76a`020;76a`<0//O81@2cb<T40;C9
bP040;?9a`2db/P0]L_90;?9a`80]/c:0140X[Rf08FKV@2AYjD0[lG30;W?
c@2cbLL0]/c:0;G;b@2aalD0]<[80;;8aP2fc<X0/lW70;K<bP2`a/@0T:JT
08fSX@0Y0;C:b00B0;?<b@2db/P0]L_90;S<b`2nd=00bMWI0=OUiP3SlO80
l_;b07R2P@1nV9L0Vl7209_7b02E`L80VKo00:;1``2K`L80V/310P2K`L80
102J`<40WL?409g3a02H_[l809_1`P0507jTY@1^U9D0R[2a09k4a@2I_l00
0P2L`/<00`2K`L80W<;309c2``0209c2``@0WL?400<0X<?50:74aP2RaLL0
0P2P`lD04`2TalT0WL3208f`/P1bU9D0VK^l0:;4a@2Vb<T0YlW:0:G7b02N
`<40N9ZK07VHVP2R`L<0Z/W;0:K5a`2]c<h0Z/W;0:S7b@2]c<h00`2[b/`2
0:c;c@H0[Lc>0P2^cLl30:o>d0@0/<k>102acll01`2_cLd0RjVY08:PX02O
_Kd0]=;B0;7?c`2^c<`00P2acll20;3>cP070;;@d02cdM40/Lo?0:c:bP2Y
alL0PInO09jl_0020;;@d0040;3>cP2acll0/Lo?0;3>cRP0/Lo?00P0]m?G
0;GAe03:h^@0d>CU0>_in@3Sk>/0XJ6Q0<C2``80o_oo00H0oOgo0?ono`3o
oOh0oooo0?koo`3koO`80?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80
iNK[0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038
`:/@0<S0Z@1G0<?2YP3:`jT0bknU0<RnX`3;ajh0/;6Q055=BP0600@01P00
00<0100L6aT092<Q00D40P1dM5`0_knM0;ZcZ@0c=3P0100100H000080000
<c8]0;FeZ@33_Z/0HUPo00@0001ZIUX0b<:/0<BmX@38`JD0a/2Z02hZ7P03
0000R89b02h[9P0510T00P0100H000070000UY:90000000g<Rh0b<:/0<W2
YP1^Ied00P4006QZG`34_jT0aK^R0084000A3PL0^;FV0<g8ZP3:aJL0cLZi
089oMP021@00;bXG0=34[P3?b;P000400002003<aKD0cl>]0=3;^00010X0
1@420<k1^03Cak40e<jd0<O9]00L6aH0;2T`0=7:`03AbKH0elfb0=7;]@0h
>300000200H41@0400001`<006aXG03Dc[h0dljk0=?>^P3Hdkl0c/Ne03l0
eLjl01<0e<fk0=?<^P3AbK`0eLjn0=39]`3FdKh0fMC10>GOd`3Xi=/0l>_W
0?SklP2AU8/0Qhf30;Fm/P2d_[<0[k^_0;G1]@2`_[40/[ba00L0/kfb00`0
/L:`0;;0/@2a^k80_L:l0;Rj]@1TIV4020/4000300021040004005IKE@2m
`[`20;Vn^00H0:nf[P0[<RX0004000@60`000P00=CXd0:^`ZP2m`[`0QHb4
0048000000800040000200001P00_<>l0:jd/00i>cX000020001000=3``0
LgYb0;g4_035c<@0_lJn0P000@00>@2nb;d0`<No0<?8`P000P0000400<K8
a@083@L000800;Nl]P37c<H0Y:VS00870@2X[JL0bLk80;k3_@001@002`d:
069TH@000@00JF]V0<_@bP35b/@0a<W20<K;a00Y:B/000<008FAQ@31b<00
IFMV00<1101ZK6T0`lg20<K8``1/KVT0004006MYI039blH0cLo:09VKUP0e
=c8010@2000100041PD0<3@c09^PW03;d//0`l_008fHRP000000=3Hc0<G:
a035c<@0a<_30<35_`1/KV/00@4106M^IP020<C;``050<G<a033b/80a/g5
0<C;``33b/802034bl<00`33b/80a<_30<C;``020<G<a080a<_30140`l[2
0<O:``35b/<0`LS00<;<``35clH0am780=GLe03Oi]h0k^k^0>[`kP2>WY/0
LHZ60:6n^P2M^[P0X;Zk0:Bl_P0@09jk^@1H09Rj^`2K^KT0YKjk0:Jf]@1K
I6<01PL;000010000@H04QLJ09VNX@0M9BL000/;07J4Q@2V^[T0Ykfk0:>l
^@2P[JH0004400041`2P/;00000000D710001080000502<c<`2c`l<0[KRj
05aTIP0=3Q00000200020@0G6aX0TJj/0:Jm]`2X]Jh0<CXi00011@000P/0
000503Pd=@2V][H0/LO5082@S`0000@00`0400041P000`80HV=U0005000^
=cH0_<c;0:G5`P2_cl`0^LW804mHE`002040CV=T0;36a02:UYH00002030f
=P2fc<T0/lc908BBU@0600@0:CTf0;3;a02gb/H0/kfn04I>D00000@02P08
0040100F5a/0Ph^=0;34`P2cc/L0[/Fo000920030080//_70;S;b@2ba/@0
]<g908:BT@010PH0;C8e0;G9ab00]<[800L0/L[70;?<b@2cc<T0//_80;C:
b02fc<X0]L_90080/lW700l0^Lo=0;G;b@2icl`0bmkL0=GSh`3Uk^d0ko?d
07nNX@1jVI`0UKNi0:G8bP2J`<40VL7109_3``2G`L00202K`L80H02GalL0
W;^n0:6m`02Ia/<0T<>j0:O7a025T980;Rlc000600000@000`8705QVJ@1[
NWl000D=028a=02Ra/80Ul?608o8_`2KakP0DEYG00031P13Fe/0DVIU00L1
1@030P00000200012@1lSi<0Yl:m08BKT`0^>CD00P0300020@0000D0FfUb
0:?5a`2^c<X0I71^00T?3`0010@00082010?501]K7@0]]3A09c9a00/>S/0
2@030002000300000@0002<W:0002@X0Oi>D0;7=cP2[cLh0Ylk=0:;0^000
00@000050:K3_`2`cLT0<S<h00401024VI@0[m7C0;3?bP0`>CH000<207ZE
T02`cL/0_<[;07B7P`0J7a/00`0000@410000P@0BE=E0;Fj`02dbL`0Z=G@
05a_J@0310P0HVec0:o>d@2]dm@0Ym3<0;G@b`0h;c80000208>GU@2^dLd0
/<k>0;G>dP2_c]00[]3?0;?=cR00/Lo?0100]];C0:o;c02`d<l0[Lo>0:g?
d02^d=40[Lc>0;7?d@2kdm<0bMgN0=OUiP3Sjnd0l?Ce0:V[ZP2j^[P0ooom
403oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9
NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[4038`:T0EP35a:P0
bL:X0<VmY@3;`:X0[jfH02h_7`030000610>03Lb;00O6a`00@0000<2000a
<2h0a<>^0<S7Z01>Ad40004002dZ9@1_IUl0;BHN00<0001?CdD0alBa0:6I
PP01000071PE0<Bn/P39`jd0`kfW0:bVVP0300003`h<0<Bo[00m>S<00002
02@S8@0j=2P0?SLW08b8O@041080>3<_0<W3[@39`ZH0KVMM0040001YJf00
al:/0<[0Y`0o?cL00`0007MbK03:aJl0d<^e0<:n]@1EDDh00@4006iYEP3B
a[00cLJf000100010`00dLZj0=75[`3?b[L0004500<0003KdLD0dlRb0<g9
/02DUH<00`8000401@2WXiX0c/Jc0=K</@3@bKH0=SH^00010`0X9bD0=C4X
03Pd:@22OW80dlfm0=?>^`3>bKD0eM2l0P3Fckdh0=G>_0<0e<fk0`3Ec[`2
0=C=^`0@0=WB`P3Ab[X0f]G20=7<^@3Uh]40f]K:0?C_j@3km_<0[:nV09BG
SP2`]Z`0^l>h0;>m/P2e`KD0ZkN[0:nm/0H0/kfb0P2d_[<0F`2]_Z`0]L6c
0;Bn]@2e^[@0E5IA0001000>4``0DUQ>05iPG@0>4`d000@00415?`2k`;X0
]kbf04Y?B@000`0092HS05eRG00]<R`0008004Y?B@2oa;h0S96;00030007
2@P0=SPe02lf;`0_=Rh0^L2h04iECP000@00@49105]MFP000P0000@00:B[
X`2h_kL0a/g500@60`000@00`/c10<C;``2oa;h00@<000010039blP0=S/e
0005002BUi40`/O106ebK0000P00J6eW0<;7`@2EVY@0008003Hh=@2IViH0
1`T401/M602oa;h0`<Fo0<kCc@2Y[ZL0000000hE3P2lb;`0bM3806a^K@01
0080JfeZ0;k8_@37bL@0JF]V00@60@1YJfH0b<[509FGTP0H6QD0004000X<
1`0f>3D03@l>0045100@5A40SiJ?0<?;`02?Uh`0000003Pj=`35b/@00P33
b/80102MXY`000400000001WKVH20<C;``050<G<a033b/80a/g50<C;``33
b/802`34bl<20<G<a00C0<C;``33b/80`l[20<S=aP2m`[/0c]G=0<C;``33
b/80fN3H0=SMeP3Sj>40l_Ke0:^e]01eR8@0WKRc09nn^@2K^KL0XKfn09jh
^@0@09jk^@1H0:2o`@2T`<40XKNe03];BP000`800PX<02P`<P0K8bH000D5
07^7Q`1KIFH000<404UDEP2W]kL0Z;bk0:Bm^P1YLVd0004503A2A@2V^;P0
10@40001000Z>CH0:S8e04iNGP2T/[<0AU5C000210001@D0;S@d020Y:000
0`00M96?0;C9a016DD/000<201lY:`1OJ6l08RL[00000013DE80[<:o082@
S`020`L03`hC02`f=`0W=CD0LGMg00`E4P000080Vj>U0;C:b02aalD0^L73
020Q8`000`00R9fN0;O=b`25TI400@43030f=P2aal@0/<W608FCUP030080
:STf0;G<aP2[^[L08bP[000310022P`0;B`a01DJ7@000`H0008406UiN02h
clT0^lk:00020P0400<0//g80:k1_`2mcL`0YKVg01DQ8@0000@0=SXm0;G;
b200]<[800D0//_80;?<b@2bblP0/lW70;C:b0020;K<bP0A0;G9b02cbLL0
/lW70;_?cP34e=<0f>KV0>Ocl`3Uko00ZK>d07RGVP2H]kX0Y<K809bo`@2F
_;d0VL7109c4a02I`l80202K`L80H02IalL0Vkfo0:?2a02H`/00V/Fn07VA
T@0<5aT000@400`Q700_=cT01@d@02<g>02X_Kh00``A00051`2<Yj80Yko9
0:?:a@2O_K<06a/K00001028X:00E6YX00@00`0A5Q00;cln01hg>`21VYh0
RYbL00XE4@000`803aTK02`g<`063a@08SDl0:W8b`2>Z:L000H500030P1>
H600CEaI000110071Ph0SjNY0:C?b00/=cT01P02020/:00[>SL0:SHf05mY
JP000`D0BUQI0:k0`P2gcll0[l_<06YoNP0310P0>3e10:_9a`2fe=80<CHj
00<21`23UY80[lkA0;KEd00Y;bd0008108BMV@2dc/d0IG1b008A3P001080
7R8S02hd=0001@D000<502P]<@2[_Kl0Ylk905m`JP000@@0GFaa0:o>d02a
cm40/M7@05abK`060080000208>GU@2^dLd0/<k>0;G>dP2_c]00[]3?0;?=
cR00/Lo?0P2_bl`03P2bd]40/M7@0:k@c`2bdM<0/]3B0;WEf032emP0eNOW
0=SVi`3^m_P0_l?40;Rj^@3oood0o_kl403oool000P0oooo0100oogo0?[j
nP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W
0<O0YP37_jP0b<2[4038`:T0E033_j@0b;jU0<g0[@36_J`0De110042001=
BCd0]:bO0<K0]01@BdD01P<0004000071@H0ZJRD0;nmY00:0@800P<00;6]
X@36_jl0]k6U00T600010@00_kb]0<c4[@0Z:BD00@0503Lc=00h=B80?3TV
02PT9@040@P0BdY60<Fn[00d<BP01@D308n>R@39`k<0a;fZ09VER@000@00
>3<_0<W3[@3:`jL0KVMM0040001YJf00b/F_0<o5[026QH400`0202@N7P0m
=b/0=c4U03/e=@0A31000`800;:]VP3AaJl0c<Fe000100010`00d/^k0=;6
/03?b[L0008300@1003@akP0dLJb0=;=^@1>CT800`8000<0101PFeD0e/nm
0=W?]P3Cc;T0<C4Y00@51`2AT8h0eM780=7=`P3<b;`0e]300=?>^`80dLbh
00<0eLjl0=?<^P3Ec[`0=`3Ec[`0103BbkT0dlbj0=C=^`3DcK/30=G>_00A
0=C=^`3Ab[P0f=?00=KA_P3Kf<L0iN7E0?;_iP3el^d0alK406ecJ@2SZIl0
]K^a0;Jn/`2d_[<0[[Z^0;O3]`2e`KD01@2c_K830;Bn/`0>0;O5]02`_:h0
^;ng09^PVP0210003@l:08Z?R030a[`0^[ni0:baZ`0730H00@H008Z?R@2l
`K/20002000F0;2e[`2oa;h0[;6[000500000P00`<Fo08J;Q@021`40=CLd
0;bn^@2naKd0`<Rm0<C<`@2EW9@0BTa70<G7a036b<D0EEMD0003001VKFD0
bM380;g4_080004003T0`/c10<?:`P31a/000`D200010037bLH0EeaF0002
001cN780_lBn02T^:0000P00:2dW0<C9``1mPW`000@004i@B`39blH09RPS
0001000i?SP0<cPb02db;00R9b40000004aCB`36d/@0_LBl06a^J`010080
K6i[0<7;`035al80KW1[0001001XJVD0alW401lQ70000@00DE=>0;Zl]`35
al80^K^h04]@C0000P0072<L0<K=a@2=UHX0000003@f<`35b/@0a/g50;Ro
]`0F6aD000400000001WKVH00P34bl<01@35c<@0`l[20<K=a@34bl<0`l[2
00X0a<_30P35c<@20<C;``80`l[20100`<No0<_BbP30akl0bLk70=KKe@3J
g=L0jngX0?Oim02h`/40HW5^09N]ZP2Q_[X0Vk^f0:C4`@2H][H0Wk^l402N
^kT0F02G]kH0XK^j05i`L0002@T00a4A086AT02U]KD0[Kno076:QP23UiD0
VjNW00082P001PT0;3Li024c<`0S>CL06AhJ0000101WMWT0XkFe00@61@00
0P00Z[fi0:nn`@2[^k/0L7]m00041P043Pl0S9RH0;?2_`2b`[l0NHV608FO
WP2/_;T000<000081`2W]KH0[Ko30:Vg^0001P<000@40:k1_`26UYD00004
02hb=@2da<<0/LO40;O5a@1BEUD0100302HU:P0Z>3T09S@e03Dd>@030080
720O0;G:b`2gcL/0PXj>00@41P0_=CD0//S50;;;b028UYT01@0402/g=@2e
b<@0CeEE0000100T;Rl0WZj]0;g9b@2da<<0HVi^000210001@H0WZfZ0;G4
`@000P800@020;G@b`2jb/T0]<3003]9B@000@@00`04038f>@2`bLDP0;C:
b080//_801<0]<[80;?9a`2db/P0]/c:0;O;bP2ebLP0]/c:0;S<b`36e=D0
e^3R0=kXj@3Pk>`0`=3?05mbL02:[:h0YLO909o1``2H^kd0W/C500<0V/;2
202K`L80H02D`<40WlG609Nn_@2I`L00Xl6o014L80000`D0>5=>09fj^02X
_;d0W;6d05IdM02Va<80BUYJ0003100M:BD0;C<o01X/;P0]>CD00`0001PK
802N^;T0G79`00000P1JJF@0Wkfk09o9b02S`/@05AlQ00000P14CU00ZL?4
0:k7`@2L/;40Igj40:W7b@1GJfX0008205EOH02[aL@0[lS405=NH00000L0
GG5b0:O;a`0[=SP02PD907^@R@2Yc<P0[/_90:Zn_@001`T000P;02lg>P0]
>CT09cDe01<M700000@0O8J80:[=b@2/cl/0:C<e00011024U940/]7D0:g:
aP0e>CP0000007nETP2M/[<01@d@00040P1GL6d0_<c<0;_;b`2O/k807bd]
00011017De<0]MC>065]J@000@@0GW9c0:o=c`2hbm40TjFW000510020040
000208>GU@2^dLd0/<k>0;G>dP2_c]00[]3?0;?=cR00/Lo?00h0/Lg>0;;@
d02cdM40[/k=0:o?cP2bd=00]m7B0<;Jg03EinL0g>c/0>cfm`3<d]80QXN9
0??cl`80ooom403oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3R
h^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[4038
`:T0>`37`JL0b[nY0=33/P34_:l01P<00082002f/j00blBZ06MPC@0:1000
9b<G05AABP050`@0GEa:09FCOP060080>3T[0<BoZ`3:`Z/0al2^034^9`06
1@00Thn30<BlY@1/KEl00@05014?500e=200<S4M00<11P0200H0VIZ<0<W2
[`0e<bL00040092@QP37`Zh0c/R`08^8N@020@00>3<_0<[4[P3;a:P0KfQN
0040001YJf00b/F_0=77[P3;b;l04`l@00@0000Y9AX0@Cdb01/E5`0400<0
@3df0<o:]`3?`jd0c/Ng0080008001/0c/Ng0=?7/@3?b[L0004000X7003B
bKP0e/jk0;jk[00?3`L01@@2020J700H5140a/2b0=;:/`3Hdl00>3P`0001
002GUY80eLk40=C@a@3EdLD0d<Zj0=C?_03JeL40d/fi0=?<^P3Fckd0>03E
c[`00`3BbkT0dlbj0=C=^`040=C=^`0A0=G>_03FdKd0f=>o0=OD``3Th]<0
k^cP0?7aj@3If]D0MGEc09FMTP2i`KH0_<Bi0:fg[02c_K80/knc0:jj[P2c
_k<0102c_K840;Bn/`1Q0:fkZP2e`K<0]kjf069WH@000P00GF9L0;Ro]`2h
`;D0U9^C08N<QP1:CdT0008005=HDP28SHL0008003<e<P2h_kL0`<Fo0;_0
^P0^<bd0008008bAR`2AUY000040030b;@34al00_/Jk0;c4]`2k`kH0a<c1
0<74_@32a;l0_;jk04a>B`000`00IFaT0;[1^@33b/800P@100010030b[l0
_lJn0<O<aP000P0000400<G7a01YKVP0008006Q]I`2^/jd0008000dB3000
0P00W:6K06aaJ`000P00JFiW0<C9``1YKVP0008000L9100i>cH0<cD`0043
000410@0V9nG0;o;_@34c<40JfeZ0040001WJF@0a<o10<c>b@1TIV4020X5
06e_JP2AThh0004000X<1`2j_;L0a<W20<[?b033b<80]kbh00`A3@000P00
U9VB09NMT`0:2PX0<38_0<?8`P38clL0?TDm0002000/;R/0000006M^IP02
0<C;``050<G<a033b/80a/g50<C;``33b/802034bl<30<G<a0<0a<_30P33
b/804030b/40bM380<C9`P3Adlh0fmgH0>W[j03cmO80dmGD06UiN027ViT0
V;6^0:C3_P2H^;D0VKVf0:?1_`2K^KT@09jk^@1H09nm_@2Q][L0:CLh0004
101]OG`0Ykfj0:6k^02P^[T0Y<Bo09fg]02^_[h0<3Pk0045200C6ad09C<c
01HY9`000@001`P<0:Zl_P2^a<8000400002002Y`;X0[L;30;30`00Y=3H0
008507V3Q02_`/00Y;fi0:W2_P2`a/<0Yl7008>BS`0220@0:c@c0:k2`@2/
a/L0/LG402Xf<P000`80RIVH07^9R@000PD0;c@g0;K<b@2Wa;l0/lW709NP
W`0100800P4602Te=@0_>c/03@`A00T72P1MIVD0^<g>0;?9a`27Ti<00`<5
02dc<`2gcLX0]<g:08NEV0060@D0<C/j0;>o_@010@<00P0508>?S`2db/L0
/lW60;SCcP2baL<0;SHh0001101RJfX0_lW8000310010080[lS40<3>cP1K
HfD000L802LX;00:0`X0<3@g0;;;ab00]<[800D0//_80;C:b02cbLL0/lW7
0;C:b0020;K:b@0?0;G9b02icl`0a=CC0=7Kg@3Vjnl0iNg`0=GSi01QMgD0
QZ2M0:33a@2N`L<0UkZl09_1`P2QalP0Vl?30080VL71202K`L80H02Ka<H0
T[Zj09g:a`2MaL@0LXJ700<32`0K9RP0XLJn0:;5a`2P_l80XL?509Nn_@2Q
b<D0OYRE00060P030`40:C0j02Xe=`083P`0000205aWJ`2]bl/0BfAQ0001
0`1@JfH0YLW70:K>cP1`S90000@901lS9P2`a<D0Y<_:0:76_P2cdM40W[^o
0:S4a`0[>CX00@84082<S02Xb/T0Y/W307nAT@040`T0:cTj0:c<a`0V<340
000407fKT`2PcLX0ZLg;0;O?d@0a?4000@D8024U9P0/<S808RdY00011@0A
4QH0/<;20:kEd02[c/X0;S`m00011029VIP0[lc@0;G?c00`=3<00@00082D
TP1JKVl0004503Q1@02]dM40]m7B0;C>c@2_c<P0R9^I00000P0330T0]/g5
05mYJ0011PT0FFm]0;GBd02`^Kh04ATL00hJ6P0J6Q`0000208>GU@2^dLd0
/<k>0;G>dP2_c]00[]3?0;?=cR00/Lo?0100/<c=0;3>cP2^c<`0[/c<0;C@
d@2hd]40_mCE0<gQhP3Hi^H0j_Kf0=WRh@2=TI80f]cK0?clo03inOT0o?kk
403oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9
NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[4038`:T0E03:`Z/0
aKZT0<RmZ@2@R7d02@P302l`:038a[40a[fN0<g6[031^ZX0`l2_08j;PP03
0000?C//092=NP0700P0=38S0<W5[038`J@0`;ZT044n=`010000TXj20<W1
ZP2_[iD02@P600/92P2o`J/0VI^50040000J6AL0a/J/0<Jo[00i=BX010@0
09BBQ@35_jL0c<F[09:<OP040`00=c8^0<[4[P3<aJT0L6UO0040001XJUl0
bLB^0<o5[036`k00G5Q?00P5001eLfH0`l6d04I2?`080`00NWMX0<k9]P3@
a:h0clRh000100000P00c<Fe0=G9/`3>bKH0004000@0003Ab[P0clRf085o
L`000@00@Shk06URG0010000TXj20=?=]`3@bkP0>cXe00430P1FEE00LfeQ
06eYGP2k]j/0eLno0=3;^080e<nk0P3DcK/h0=G>_0030=?<^P3DcK/0eLjl
0080e<fk01<0dlbj0=C=^`3Ec[`0g=O30=;?_03Sh=40jNOK0>g^iP3Yk>D0
N7eg08jCS@2c_K80]l6f0;2j[`2a^k00^<:g0;K0]@2c_k<0/[jb00@0/kfb
102d_[<0:`2f`k80]L2b0;Bk/`0^<bd000D008N<QP2j`KT0]l6f02dd;000
0`0000@00002000g?3H0QXR50002000d=S<0_<>k0;Nn]P31b<00<cPb0002
002;SHX0RH^800H81@0H6QD0HVEN06I^H`1^MVT0`l^n0;g5^P34al00S8j9
03Hh=@000@0000<00:F/Y03;d/X0_lJn000100000P00`L_00<;9`@37c<H0
0P000@00=037bLH0SiB>00030014AT<0KFm/0001001[KFX010H3061RG`1J
G5T000400868P037c/H0/kRa0002000?4@`0aLO40:2PWP00000071`L0<G<
a031cKl0c=C906U[J0050`@0JF]V0<7<_P35al80L79]0001001SIF00JVaW
0001001IFeH0b<[50<O=``36c<80`lS20<W>bP1KH5`0008006mdK@2=ThT0
000003<e<P3<dL/0IfiV0003001=DT`0J6YW00<30`1WKVH20<C;``050<G<
a033b/80a/g50<C;``33b/802034bl<00`35c<@0a<_30<C;``050<C;``0@
0<;<``39d<P0bLk80=kPf`3Ph]l0kO7`0>7Wi`1hPH00NY2>0::k^02U_k`0
UkFc09Zh]P2P`;d0V;Jd09jl^Q00W[^i05P0W;bi0::f]@001PL000840:Nj
^02O_;P0Wkfk09nm_@2D^;@0XKnm0:Jj^@1[MWP00@H9034f>@2a^kX0G6QV
00010018Be00Y[k00:S2`@00008000400:g6`P2P^[T0Z[fk000310000@@0
]/320:Vo_@2Wa/40Z<G10:W3`02/a/D0QI6?0001000e>c/0Z;jl0:_9b@2_
b<D0:STd00020P1mSHX0QYFB0001100Y<C<0/lc90:[:a@2/a/<0]LS602@Y
;0000@80SYfJ0;[9aP052@X0008509ja[`2balP0//S608^GU`000080;C<c
0;S>b`2ab/L0Pi6D00<00P0[=C@0RiNE00<31@0U8bP0^<K60:k9a02fdlh0
[Lc60:o3`@25SHl000440416AP2laL@000420082102fb/P0U9jO00492`0J
92D0P86500@0100^<SD0]Lk:8@2db/P00`2cbLL0]<[80;G9b0020;G9b00@
0;K:b@2gbLT0_m;@0=CRhP3Afm`0k?Cg0>C^l01bQ8H0NIJD0:?6`P2Na<D0
VKo009k4a@2L`/<0V;jo09_1`P80V/;2202K`L80H02G`<80X<[909?0_@2N
aL@0EFAW00@12P1JIFL0U/2f09No`@2K`lD0Uko10:G?cP2F`;`0Vkjh01XY
9P040000QINI0:no_P074Ph000L708bTYP2N`/80EV]/00410`1=K6L0YLC6
0:2l`01ML7H000L805Y]J`2Ta<<0Wlg=0:;=a02N`/80Zlg?0;;>c`0Z=SH0
0@02086?T02Wclh0Ym3:082DT`0000D09c<c0;?@b`0/=3H00@8607ZKU02[
dm80Y/S90;?;c@1hQXT0008403Dk>`2ma/<0I71/00401@17Ce80]Lo>0:S?
bP2[blP0;ce000021@26UYD0/<gA0;K@c@0^<S400@0008RKV@0/?T000005
07^1P@2Zd]80Zl[<0;7?c`2cdm00/lO502<W:0072`X0SjBM06QbL@000@@0
Gg5a0;S>c010ADT0004506ekN`0b=SL0000208>GU@2^dLd0/<k>0;G>dP2_
c]00[]3?0;?=cR00/Lo?00`0//kA0;3>cP2_cLd0]=3A0;_Ee02ndm@0b=[J
0=WYj@3[mO@0g>GT09fQXP37bLP30?ooo`030?gooP3oool0oooo00h0oooo
00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF4
0:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Za00b<2Y05P0bKjZ0<VmY@3=
`jX0S8If0001000h>C<0_KNW0<_0Y037_J80b/6`0<O2[`2@S8400`0003Th
9P2>SGP0100503Hb9`39`j/0c<>T0<W1[00c<2/02PP908N3N035_jD0aLBU
044o<`010000Wj2>05aMB`010000JVQL0<C3Y039`:l0=C4V0041002@SWl0
bL>Y0<[3Z@2FT8800@0003Lb;P3:a:h0c<FY071YG`010000J6YO0<S3[@3>
a:/0c<R]0::OT0030000?d0`0;RiZ`091P402`L00<2kY`3<ak@0eLVc0<o8
^0000@0000800<o8^03GbkD0c/Vf008210040000dlbj0=G?_`11@CT00040
09BARP2UWI0010@604I3>P3Cc;T0blRg03Dd;`000@00104000H000081000
Sh]o0=OA`@3Ie<40dljj0=7<^03BbkT0f=6o>03Ec[`0103DcK/0eLjl0=G>
_03DcK/20=?<^P0B0=G>_03Gd;h0eLno0>OTe@3Vi=P0l?3X0?3ck02?U8d0
RI280;>m/P2b_[80]<2d0:VeZ@2f`[H0];jc0:ZdZ@2i`kP0[[R]0`2c_K85
0;Bn/`0S0;O2/P2e_K00^l2i02ld;P000`00QHb50;_5_02d_[<0S9J;08B>
P`29T8P0QHZ409:GT@2;SHX01@D502`/;02h`[L0_<Jk0;[1^@0b=c400080
09>ETP28R8P00000000100031@0000H002lg;02maKX0_LBl04e?BP021040
0@<000P:1`1gOWH00P2oa[h01P33b/8000400043002obKh0a/g50<?8`P80
004003@0b<[70;Nl]P000P00<38_02PZ9`0D5Q<0^K^h02h`;@0M7a`0<C<`
0043002AVHh0_lNl0<O>aP12Ad4000400:>SX@1LG5`0000006a/JP38d<D0
`<fl0<?;`01VJ6<00`4206e_JP32cKl0aLO206]]J00620<0IfUT06i`J`00
0@00JfeX0<S:a@36c/40a<c10<G<a035b/@0K75[0001001YK6D0TYF>0000
000i>cP0UIZD0003000Y<2P0][^e06=UHP051@D0IfiV0P34bl<01@35c<@0
`l[20<K=a@34bl<0`l[20100a<_30100bM?:0<C;``3OhM`0gMoL0?7em03Q
j^T0R9JF07V<RP2R_;/0X;Zi0:?0_P2H]K<0X[nm09fj^02Q_kd0V[Rf402N
^kT0F02F^K<0[;jn0001100010L0ZKVh0:70^`2I^KH0X;jn0:;2_`2N^kT0
Z<300:Rj^P0441002Q<B0;6j^@0N92@000<207f5R02U`l<0WK^i00000P07
2@P0Xkbh0:G1`P2^`/0000<400041`2_^K/0ZL:o0:K6``2/b/P0Z/;20:[4
``21RhX02@P602da<P2eblT0Z<S70:k7a00[=S800PP608BCSP24T8h00044
038g>P2/aL80[lg;0;38b02ab/L0GFUY0004101NKFP0O8^60004100Z=SH0
/L[70;C9bP2bb<H0R9BD00000P0a=cL0]/c90:o8a@26U9L0100302hh=`25
THl0004303<b=`2nc<`0[LS30;7<a`2]b<<0_M3>08R@TP000@@0<CXi0;O1
`0031`P000020:Bb/P0J8R@00P`=096QX029Ti@0108703Di?02`a<8P0;C:
b080/lW700h0]LW80;K:b@2ebLP0]LW80;[<c02mcll0cM_K0=KRhP3YmOD0
g^c]082BU01fT940W/2o09[1_P80V<3000H0WlO709W1`@2H_[l0W<;309Rn
_`2M`l@809_1`P1P09[3a@2K`l<0V/C209Ro_P1HJV`0000705eWJ@2O`[/0
Vl?509_7b02La<H0T[Ri0:7;b@2Pbl@0CfER00D0101?JFH0LH5n0004000U
>CP0X<C40:?;b`1BIfP00P82059_K@2[alX0YKc205QZKP0010@0EV]V0:O9
b02Jb<P0YLc70:K:bP2Wb/`0YlG502Xd=@0200<0QI>F09g9b02Sc<P0P9BE
0000100a?C/0ZlW102df=@0000@0N9FA0:S:b`2cdM40/LW;0;S:c0085QH0
1a<A0<?=c00J9B40004408BDU02bd/l0[];@0;S@dP0/=c/000H808VIV02b
dM@0[/_703@h=`010000QYVG02@f>00000D0TING0:O;b`2jf=X0Z<K60;KI
e@2eblT0>Sm200020P21UY40H6i^00011@1SKFh0EfMV00011018E5@0]l_9
034i>`000080PiNE0:kAc@2`c/h0]LkB0:o>d02^d<l0/lg>802acll0402d
d]@0/m7C0;7?c`2fdm40_=CD0<GIf03Jj>P0jOGe0>[`kP2RYZD0aLG50?on
o`3knOX0o_kn0?ooo`3nool@0?ooo`00203oool0403ooOl0n_[j0?Ggm03_
l?80iNK[0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<No
Z038`:/@0<S0Z@0k0<Vm[@3;_jL0b;nR0;fkY0000P003a0;0;NaY@3>`ZX0
bKnT0<FmZP33_:X0KFUN00D1001UI580UIAo00@0100i=2h0`;RU0<_0XP32
^ZD0<Rh[00D31P2=RGh0b/FW0<BoXP29Pg<00`0005MFD@0I61<01P<00:^U
U@39a:L0akj_03Lc:P030`00TY210<W3Z@34_J<0UHn300<0000h<bl0b/B^
0<_4Z01`JEl00@0006U[H039a:h0c/B[0<O3YP3;b;T0;R/T0041001XJ5h0
1@4005UDCP3;a[80c/Vf0=C8/P3>akL00P000@006`3Cc;`0eLVc0=3;^002
00H01`800=7:^P2^Zi`01`P200l?3@38a[T0eLng01DF6P081@00]:nL0=CA
`00b<bd020X706QUGP2RVh/0VYJ;0<S4^03CcKd0dLbi0=7<^03Hdkl0e/nm
0=C=^`0h0=G>_00H0=?<^P3DcK/0eLjl0=C=^`3Cc;X0e<fk0=SA_`3Ke<80
h]kB0>_Wg03ak^L0mOK`0:FZX`22RWl0];na0;2m[02c_k<0[KV]0;S4^02b
_[80[k^_0;K0]@2b_;40^<:g0P2c_K860;Bn/`080:njZP31bK`0^[nh05QM
E`052P@0G6=L0;Bn]@2e`KD20;_5^P060;Bk/`2m`[`0_<6k08Z<R@000000
=SHf0P2i`kP04P2i`;P0=3Tc0002002CUI80TY:B0000000[;B`0RH^808fD
S@2GWYH0a/g507^2N`031@80004006AVH`2f^;D0aLc40;c3^`80`<No03/0
1@L40001002nb;d0a/g50<;7`@010`0000400<K8a@36blD03A8<00L91P00
0@00BD]80<c>b`1gNGH0004000T;20000@00`/c10<WAaP33b/80P8Eo00@6
0@1IFEL07QhN0040002_[jd0`<Rm0<CA`036c/40JF]V0040001YK6D0a<o1
0<S:a@1YJfH0004006i`J`25Qh80004003Li=034a/40`LVj0<K>`@36c/<0
_lBn034f<0041P40QHR1096DS@0000009BLT01/P6P0<4`/0UIbD0<_@bP1_
LFh0000006M^IP020<C;``050<G<a033b/80a/g50<C;``33b/802@34bl<3
0<?:`P80a<_30P35c<@04039d<P0fn3I0=cNf@3Xj^L0j_3`0:6_[`1`RHH0
XKjj0:6m_P2M^KX0W;Jg0:K0_`2I/k80YKnn0:6k^P2M^[P@09jk^@1H09c1
^P2Y_;X0<S4f00000P1kRHT0XKjj0:6o_`2U_/80WkVj09ni^02T_[d0Y[nl
04=FE0001080Ff5Q0001000F7ah0ZKNh09o3`@2YbLH00P<50000002]`l00
Y<310:Nm^P0/>3P0000408F=T02[`l<0Z/[70:6n_02a`lL0Z<G3086;RP05
0@00<S<e0:k4`P2YalL0[l?203<i=`000P00QYF@08JBT00000@0=CTl0:k2
`@2bc</0/lO80;7:a`2/][L00`L801hY9@12CDT0004207=mOP2ab/L0]L[;
0;;8aP26TY80000203<i>@2db/L0/L[708RFV@040080;cTh0:Jf/`001@D0
1PX=0:^k^P2cc<P0/lW60;O;b@2ha/H0HFU[00041@1?FeT0_LW700020P01
0080?dU:0001101[NGT0/<W508RKV@0000@0<3@g0;g=c240]<[80P2ebLP0
3P2fb/T0]LW80;S:bP30d]80amWI0=SQh03Qjn`0j?Sg09N]Z`1_S8X0X/C3
0:37aP2I`l40Vl?30P2H`<001@2J`/80W<C409c2``2I_l00W<;300P0Vl72
0600V/?509bo`@2J_[h0X/W807::RP0010X0:C<e0:K1_02MaLD0V<;10:S;
c`2O_<80W<;309C5_`2M_KX0004401P/:P15CT/0004006QlN`2Pb<P0VL71
059VI`000000E6QW0:O5a@2Xb/T0NiBA0003000d>SP0ZL710:?<cP2U`l<0
/m;E0:33a@2/c<T0;CTg00800`24TiH0XLo?0:?:a`26V9X0000402Xf=02Z
b;h0=C/k00<01@1nUYH0[/c:0:g;b@2ac/`0]m7>04EIF0001@D0GfAW0042
1P0J92D0ZL?00;3GdP2cdm80_/gB02P_=@000`D0QIFD0:c?d@2ee<l0:C8_
00D51@24V9H0Ae]L00@7301OIFD0/]3@0;?;c@2fd]<0Yl[60:Bm^P032`h0
00H90:Vo_01FJVP00`4603dm?`033@`07RPW0:g4_P2Wa;l0<S`m00000P23
UiD0[]7=0;3>cP2ec]80[lk@0:k@c`2ccLhP0;7?c`0;0:o=c`2`c]00/Lg>
0;WCdP34f]P0enOV0>Sdm03Uk^d0][Re0;^k^@3jnOL00P3oo_l00`3ooOh0
n?[i0?koo`0@0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[0>;R
i01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:/@0<S0
Z@1H0<bo[`38_:80c<>R0<2oX`0n@CH0008005I?A@3:^jP0c<2V0<Vm[@2P
VHL04`l300<0002OWXX0RXYb00P21P0i<Bl0bL2_0<_0Y039`J`0?3Ld0040
0P2BT8<0aL2R0<W1[036_jd04@`601@?5@0300@0:RDO0<_4/P36_ZT0b/2d
03Xe;`010000Shen0<_5[@3<aJ/0UY2400<00P0i=300b/B^0<_4Z01_J5h0
0@0006Y/H@3:aJl0d<J]0<c6[03:a[/0If=P00D6000?40/00`0208N2O`3A
b[X0clZg0=75[`3?b;P000800001003DcKd0dLF_0=;=^P0300T010000=;:
_@1gLfL0004005=CD@3@c[l0e<fa065RI`010@00MFmO0=3=_00g>3800040
09jKU03Ab[X0d<c10=;>`P3Abk/0f=?00<o:]P3Cc[X0e/nm0=C=^cP0eLjl
0P3Cc;X0403DcK/0dlbj0=?<^P3Ec[`0f]?10=gFa03Vh]T0k>OQ0?SglP2j
^kH0P8Eo0;6k/02`_J`0]L:^0;2n/@2e`kH20;2l/0040;C0]02d_[<0/[ba
0;6k/0L0];jc02L0]Knd0;_3]02d_:l0]KZc09ZOV@000P005QdF0:bf[@2f
`[H0^<Bf0;Fo]00nACd0LgYb0;^m^P2<SX/0000003Hd=`2kakT0^lFj0<78
`00Y<2P01`T608B6P`2>SXh00P03038c=@30`/40`<K20;o6_`2naKh0JW1/
0001001ZJfd0alW60<;4`@34bl<0`l[20<C;``32bL400P000@000`34c/<0
a<_30<?8`P020001000d0<G7a037c<H0<3D_000100021040TiFB0<K8a@2j
_;T00@<00001000=3``0`lk00;o9_P33b/80bLk700/=2P0<30X00P0102TW
:P3;blT0`l_00<3=_035cL00JVaW00D40P1]L6T0`/fm0<S:a@1ZK6L00`D0
06MYI036b<<03@l:0001001hNWD0`ljn0<G=`032b[l0Nh1j0002000=3`X0
a/S309FFT00410@000400002001fOGD0`l[20<K;a@1XJVL010@406M^IP80
a<_300D0aLc40<?:`P36cLD0a<_30<?:`P080<C;``@0`l[20P34bl<04P35
c<@0a/g50=3Gc`3Oi=d0i^SS0?Kjn@2c_;/0MHR609^h]02J_KT0VkVi09nk
_02T_[l0W;Bf0:Bl_02P^;P0VkFd0:>m_100W[^i05P0Vl2i0:Fh]P1ZJ6d0
1`D801DS8`2D/Jd0X;bm0:>k_`2L[k<0SjNY0::o_@2P_KT0QIjJ00050P0;
4@l0000004aFE@2^`<00W<?009k1_@0000800@000:c0_P2X`/<0Z<6m06Ue
M@0000@07bLZ0:6f]`2UaL80[/S90:Nf^`2@[Z`0Q8j=00@0000c<cD0/<C3
0:g;b`2ba<@0<S@c00020023TXd0QI6?00000P0_<SL0]LO70;79b@2eal/0
]L[;0;o4a`0m?Cl0008000T>2P0820X0[kBg0;G:b`2cb<T0/lW708ZFUP01
0@<0<SPh0;77a02bblP0QI>F00H0100Z=3<0^Lc803]5A0000PD0@51?0;O=
bP2gb/P0]lG509NQXP08418000@4096QWP2mc<T0008200@21@000@@0BDiA
0;W9b02_c<L0NY2=00041`0_<cH0^LO7802db/P0602fb/T0]LW80;K:b@2e
bLP0]/S80;[<c034e]H0cn7Q0>KZj`3[mOH0Z[fk07>=RP2K_[X0Vl:o09:l
^P2Ja<80Ul7009_5a02K`l<0WLG509W1`@2I_l00X<K709Rn_`P0Vl720600
V/?509fo`@2SaLH0UKbk0:G3`@0=61`000@605mcL@2Ma<<0Vl?309jm`025
W:@0Vkk009S=a`2I`;d0>d9800030P0B3Pl00`000:6c/`2MaLD0XLW905M[
K0000000GVU[0:G7aP2JblD0YLJo01/K6@070000JGAf0:?;c@2]aLT0Z<C8
086TYP2Wb/H0;3/h00<1101nSI80Xm7A0:g?d01jS8h010<802Pg<P2bd<H0
;C<c00P12@1oTi@0/<g90;;Ac02[blH0[lo:08jWY0001PL0414F00@01@1?
Gel0/m?>0:_DcP2/b/X0_LS>03<h?P0010H0Q9JF0:cBd`2`d</0;3Db0001
0023VIH0U:RY00011@0=4a<0SZJV0;W=cP2hd]40[/k;04EMG@000PL0>D97
0;O?c`1MMW<00`0400P21P0630`0UJBQ0:k=a@2fem00;3Hh00000P23UiD0
[]7=0;3>cP2ec]80[lk@0:k@c`2ccLhP0;7?c`0@0:k<cP2cdM<0^=CE0<?M
g03@i^@0hO7`0>7[jP35bl/0/k>a0?kmn`3oo_d0oogl0?kjn`3oo_l0oOon
0?kooa00oooo00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07ai
LP2<RGX0WYF40:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Za00b<2Y01/0
a[^U0<g3ZP34_J40c<J/09JAN`0J5PX00`0003Lb=P1ZIf00F5AA01<?3P03
0000EEA20;ZiY@2EThH0104003T`:`3:`k40`kjQ0<[4[P0i<2L01`0009N?
PP34_Z@0bKfS0<W1[P1MFDh00P0100007P1kMf`0a[j[0<k2Z03<ak40<R/Q
00P0002ITX`0b<>`0<O3ZP2IThD01P0003Df:02FUX`0J6MS03Pf=`010000
=3<_06][H@2DUHL0c/>_0<k7]@2n_;000@800001000T8QH0bl>f0=C8^03;
c;`0Jf]O06e/I`800@0001P0KVeX06a/H03<cKd00@<20000003@dL`06a/C
00<1002MVX/0e<jn0<o:]`2VZ9/0008001TK403Ad/X0<34[00@5001BDdh0
L71^075YGP2SVi00f];50=;;^`3Fckd20=;;^0030=G?^@3Ec[`0eLjl03H0
eLjl00<0dLZj0=K?_@3HdKh00P3BcKL02@3FdKh0fmS90>?Oe03ZjnH0k^oZ
0=OJd`1TJF80WZFM0;K0]@020;2l/0030;:l/@2c_K80/kfb00H0/kfb0`2d
_[<30;Fo]00/0;K0]@2haK@0[KV[0;_6^02^]Z/0AT]40001000Z:RP0Ogmm
08f?S00a<c00004001dO702_/Jh0SY2=0001000c=C80_/Fm0;_2^P2naKd0
<STa0002002<TH/0TIJ@0002000F6aD0IV]U06AYH`1VJfD0`lS208nDSP00
0P009R/U08B6P@1cMG00FUaG0<K8``1VJ6<0J6YU000200000@00J6eW06EZ
I03=d/`200020080alc601l0EU]E0004000E6Q@0b<g70<G:a033b<80@TM1
0002000`=Bl0aL[30<_@b@31a[l0aL[305YOF@000P0000<007IkM@36bl@0
`/O0096FS`1UJV@0=3Tc0004000_=300J6eY08jCS@1ZKfT0008006M/IP35
b/@0NGih0080008000P0@DI206I[I`13B48000800046001jOgP0`LJo09:G
T080008000L0@DI00<S=a`2oa;h0alc606U^J0000P00I6]S0080alk60P35
c<@00`34bl<0aLc40<G<a0080<C;``0@0<K;a032c<<0`<c20;c9_`33clD0
`<No0=;EcP3Ad</0g=kI0>W^j03/lNd0cMKE05i/K02?YJ<0Xl6o09Fg]PP0
W[^i202O_;X00`2P^[T0XK^j0:6k^P050:6k^P1H09fk^`2Q_Kh0Xk^k01HX
:00010@03Q@D06EWIP1BDU804AHJ07f;S02Y_kd0X[nk0::l^@0J:RX00005
00<01@2BYZL0Y/2o0::o_@2]_l400`<;00001`2b`<<0Y/C20:S1_P2^`/40
8B`^0001100D5AT0H6AW05QQH00>61L0Lhb808RDU00000@0;SHh0;;6a02`
blH0//;1030d=`000P@0SYJH08NATP0010@0;3Xj0;S8a`2dalD0]l[80;C:
a`2c`l80OXR9000110000`H0AU1A0;[:b@2db/L0Wjn^061/K019CU400004
01TJ7P1SJ6/0KGUi086AT00000@0=3Tl0;K2`P2BXZ402ATH0004100V:bh0
IfQ/051AE@062`h000D504ADD`2jb/T0^lO70001100000@04R0P0:Jj^02e
c/X0]<O508VCU0000@@0<3Pj0;S6aQP0]<[800<0]/c:0;G;b@2db/P00P2d
b/P20;G;b@0>0;C:b02db<H0]LW80;G:b`2balX0^<c=0<KFe@3Dh=`0i>gX
0>_^l`3BgMl0E6UZ09Bd/`2I`;l209W1`@0309c2a@2K`L80Vl7200h0Vl72
0600WL?609W1`@2F`;l0VL7009o1`01TO7`000L800031P1=CDl0GV9S03I0
@@0X>3P0ZL710:30_`2L`l00HHV800D000000P00?5EB09o6a@2K`l80[<_6
05]ZI@000P00DVi_0:C2`P2]cLX0Y/G006b5P@0020D0008204m=CP1ZJ6/0
>4A2028k=@2gc<L0:C8a00061P25UI80[<_30;G9a`21UI<000H402Ph=`2j
b<P0;3Ph0003102:U9D0/<oA0;7@dP2Zc</0[Lg:0;7;b00Q<C00008200D3
1P2C/K40/<g;0;_Cd`1TMWH0HF]/01TM7P000000CTa=065]K@2T/;00:cLg
0004102BX:00]<;204EEE0001`H03A8<04a>B`1[Jf/09bTX00020P0861L0
RjFR0;3@c@1TKg<000@900031`1KKg00]=;@0;3>c02hc<d0;3Dj00012@28
UI/0^<g@0:k<c02`d]40Zlg<0;CBdP2acLhH0;7?c`0B0;??dP2`c]00[lk@
0:oAdP2_dM00[lo>0:o=c@2acLh0/=3?0;SDe@35f]/0dMoP0>O`k`3Zk^d0
f=[G08R:Q@3/k>`0n_[j5P3oool000P0oooo0100oogo0?[jnP3emo@0ko3b
0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0
b<2[4038`:T0>`3<`J/0akfT0<[3Y`33_Z40c<R_09JCPP0R7AL00`0000@0
00070P00100006APE@2n^jP0a/B]092=O0040000?SD^0<2iYP3=b:/0a;jV
03de:P0>1@00ShQh0<[5Z039_JD0c<Ba09^HR@040@001@800;6^W`39`Jh0
cL6Y0<G1Z00l=RX02`<008b5O@3;a[80blN/08n9N@0:0`00=C@R06=QE00;
20400`0000H2000300001`D006IUD`3Cb;80b/>`0<S6]`12@SP01@D005aJ
C@3@bKT0eLZh0<[9]`0610000`0000801@4001000`0000L5003;b[P00040
00<2002LW9@01`D001hJ3P3;aKL0eLjn0=?<^P3>c;l08AlB00L5002OW9<0
@d0g0`030000200=1@00KfML0=;:_@3Fckl0e<fk0=;;^03Fck`0f=:l>03E
c[`0403Cc;X0em2m0<g6/`3Ke/00d/fi0=gJb@3UhMH0k^[Q0?;ckP3Qi=d0
M7M`09BITP2f_KD0/[ba0;C0]02b_[860;>m/PH0];jc0P2e_k@20;K0]@08
0;G2/@2ha;H0/kj`0<38_@2W[:D0@dE00001000000020002000>02X_:@2B
Ui40_/>m08jCS@001@00<CH`0;O1]P34bl<0^;ng030g;`042`<0QX^508>8
PP0010030002000400870@2k`;X0_/>m05=HDP<0008001L0:BhX0;>h/P00
1@000PL100020000100000D00004002k`;X01P/500870@30aKl0b<g706I[
I@000P00JFiX0<35_`38cLL0alc607j3O@000`00FEiH0<S>a0020<;7`009
0<gBb`2JWiP000800046002a][00a<W20<K;a01RIf000PL1008000800280
0@H000460P1YKVP0J6eW00<80P1UJV@0b/o90<76`01cN7803Q<=00020002
1`40008001DJ501]LV`0_/>l0<G:``2BUi00008001dR702`]Jl0`lS20<O<
aP35b/@0HfQR00870@1^MFd0_<>k0<;9`@36cLD0a<_30<37_`31b<00aLc4
2034bl<04034c<40`l_00<OCb@30c<80`lo50<cCb`3<clP0f]_E0>CVh@3]
l^h0f^?P06QgM023UiD0X[^h09Fb/02U`l<809jk^@P0Wkbj1P2Q^kX20::l
^`170:>o`02I/k@0YKfm09fa/00U=C@000T700030P00108000X<07F5Q@2Q
]kD0Y/2m0:_4`@1@HV80008502@W;02_`l@0X[nm0:c:b02U^KX000470082
2P2]_;l0YlG30:O1_P2bb<H0XJn`02de=`021`X00`P;0003100020D0PIbG
07^9R@000@@0<cdn0:_1_P2^bL@0[/6o03<h>`001`P0P8b<086=S@0030`0
:CTh0:o2`02kc/`0[l?10;O=bP2hblT0/;jn00PB4`000`@0NXR80:o2`02g
cLX0PIBB000:2P000P@00@D80001100010H0:SPh08FHUP011@P0:c<e0;S6
aP2gb/P0QIRF01XX:0000P@00P000@@03`001`T0CeeM0;?6a02dalD0]lG5
00072@000@@0Ri^J0;S>b`2_b<@0]/[808NCT`001`T0;cTj0;?3`P0H0;C:
b0040;G;b@2db/P0/lW70;C:b0<0]L_90140]<[80;O;b@2bb<H0^/o@0;W<
d036f=X0a]CD0>;]j@3TkNP0fnKX069dM025Wih0Wl7009Jn_@2I`L40VKo0
09g0a00@09_1`P0o09bo``2K`L80V/;209No_P2SalD0Z/O505Q/J`024140
00<4000820001@D08cPi0:G1`P2Ta/L0WlK509g5a@0?4A0000D506V3PP2Q
b<L0YLg<09jn^`1BIV@000L3051/K`2Wa/P0YLO60:G8a02_c<P0GG5_00/G
5`000P80000500061P0V@3d0ZlC102lm?P000`D0NXj=0:g=b02ab/L0OiFC
000<2P0W>cX0/L?30310@0001@D0QYBE0:[8bP2ad=80[]3?0;?Cd02_c<P0
Ffm]00092P0O8b@0/]3B0;OCe02Y`l@0:Cdn000=3@000`@000<2008000H6
01l0R9RH02Ph>0002PX0NH^;0<7Cd`2gblX0CV9Q0004000020D000820005
200H92@0RinN0;?@cP2_cl`0H6ia00031`13DE@0/<G60;7AcP2Zb/L0^m3A
02dk?P002@l0OY2D0;C>c`2_clh0[]3?0:g=c02dd]80]Lo@01P0/Lo?00<0
//kA0;3>d02_c]000P2_dM00302_clh0/<k>0;?@cP2acll0`M_J0<KJf`3K
jNT0io3_0=_OgP2EUi@0e=KC0?Win@80oooo0P3moOd00`3no_h0oOgm0?gm
o@0@0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80iNK[0>;Ri01lNG80
S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:/@0<S0Z@0k0<Rm
Z@3<`J/0`;VM0<G0X`38`ZP0b/F_0<6n[@2ASH40KFIF07ifJ@2]YIP0al2^
0<K0Z038`ZP0]k6K09J?O`2OUhX0b/B^0<>nX038`ZP0WIJ60969OP2n]j@0
a;nR0<^nZ`38`:/0a;n[06m^FP1bLEd0clZf0<FmZ03>`Jh0blF[0::KR`2A
R7l0`k^^0<_5[@39a:L0`;VV09B;PP2VXHd0^KBQ092:O02DSH<0V96709VC
Q@2ET7d0]K2L0=77[P3<a[00clbk0:BUU@1/KEl0/k2O0<g6]03DbKD0d/fj
09J@P02JThT00P2ITXX0402KU8X0Ui610=?>^`2CTH@0VYJ:0;ZgZ02FT880
ZJ>E0=G>_P3FcKh0eLbm0=?@_`2SX8l0T8en0<>o/`2SWi<209ZFR`0909ZF
S@2JTXD0^K6T0=WAa03>akL0e<fk0=K?_03DcKX0dLZg03P0eLjl0100dlfg
0=C>^03Dck/0e]6m0=?@_`3QgM80k>WR0?;_jP3Xjn@0RHb508^@R@2a^;00
^l>h0:ni[P2d`;@0[KV]1@2c_K860;Bn/`<0]Knd0P2f`;D0602d`;80]/:d
0;O2]02j`[L0_LBl0;_0^P2KWIP0I6IQ069ZG`1lQ7T0^/:g0;S0]@2na[/0
[KFZ08jFR`2@V8d0_<Jk0;_5^P32bL40UIbD08N>QP2g_[H0];Vc08Z?R@80
S96;01<0UY^E08B9P`37c<H0b<g70;c1^`24RH<0J6mX0868P@2ma;d0a<_4
08R?R02>UHh0TYVB08fDS@2<TH/0SY>=0<gBc02=TX`0S96;0080a/_503P0
Z:fW06M/IP2_]:h0`<Fo0<G:a039c/P0`/O106EZI02DVI<0`lVo0<C:`038
cLH0`<Fn0<G:``1]LV/0LgQb0<O<aP33b<40b<g60:R]YP2=TX/0UIZD096F
T02?U8h0Ri2:0:V^Z02^/jd0RXn90;:g/@30aKl0`lS20<[?b@2e^[@0MGYd
06M/IP1lPG/0[[>]0<G:``3:clP0a/_40:R]YP1^Lfd0TYNA0<cAb`34bL<0
b<g70<?8`P2f^kD0Ri2:0:F/Y037c/H0`/W10<S?a`36cLD0a<_30<;9`@T0
a<_30100aLg20<79_P2obL00`lg40<7;`P3;d/X0eM[D0>OYi03_knd0j>k/
07N6P`21UY40W[Re0:?0_P2M]kH0WkVj202N^kT809nl^PD0XK^j0`2R_;/0
F02U_l00XK^l0:2h^02X_[`0YKVh07nBT01GIf@0EFER08NMV`2Z`;h0Z/?0
0:Fn^`2X_[`0W;2_05YZJP20SXl0Y;bl0:6o_@2Ta<40[lC5082;S`22RHl0
/<C50:G5`P2/bLD0ZlC10:Ni^@2ha/L0QY2A05eYJ@1JJ6P0WJf/0:c6``2Y
^k/0Q8j@08jLW@2ab/L0[<W50;K:b@2>VI/0Q9:C0:fm_@2a`L40OY2@08bN
WP2hc</0/LO50;;8aP2^al@0//S60<?Cd`1/NW/0Gfe^0;K6aP2cbLL0/lc9
0:Fi]`1lShd0RiNG08RBT`25Si00QY:B08nRX02V^[P0PXb=09^WY`2ca/@0
]/[80;[>c02eb<H0NhN7065[K01RK6d0W:RX0;W<bP2calD0]<S60;c?c@1J
IVH0NhF60;G9b02gcL/0//c90;G;b@2^_[h0PHn@096QX@2ibl/I0;C:b080
/lW701D0]<[80;G;b@2eblT0]L_90;C:b02`a/<0]L_90;K:b`2jbL`0cM_N
0=gWj03XlO00iNk[07F:R`1gTI00Xl?009_2_`2MaL@0W<C409_1`P2N`L<0
402K`L80H02J_Kl0W/C509c4a02KaL<0UKjj0:;5`@2Wa<80VK6a06UnO`1@
J6P0K8J70:2n_P2WbLX0X<?50:;8b@2H`<00K7mm059XIP2T`/@0Y<O90:C:
b`2Ta/L0Tk:]07RAS@2@[K40Y/G80:C8b02UbLL0Zlg<0:c:b02M]KD0M8R7
05i/K`1_QhL0Y<C10;?Ac`25VIX0QINI0:K0_`2Zc/X0/<c=0:C0`@1hU9D0
RjFV0;O?d@2;XjD0OiBG0:Rm`02acm40/]7C0:g?cP2/cl/0/<k<0:Bn^`1K
KV`0QiFE0;3?d@2/b/`0]m?F08^UYP20UIH0PYJG08RJVP20TY80PYNJ0:Zo
`P2=YJL0P9RJ0:k6b02gdM80//c=0;7;c02Q]k@0E6QV06AfMP1eQHD0^L_=
0;;:c02ccm00/M7@08:DUP1MKg40W[:c0;cFe@2adLh0[lo<0;C>c@2>XZ<0
OY>F0:_5aP2edm<0[]3?0;;Dd`2adM00/Lg>0;?=cQP0/Lo?0100/Lg@0;3>
d02`d<l0/M7@0;3@c`2_cLd0//o=0;OAd02ofMP0b]oP0=c/k03Vl?40j>k^
0:2RX@34a/<0o_om0P3oool01@3no_h0o?cl0?knoP3oool0o_kn0140oooo
00080?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF4
0:jVT`2o]j00al2V0<S1Y`37`:H0aknX0<S0Za00b<2Y04<0b;fY0<c4[@39
`ZP0b/>W0<K1Y035_jD0b/J]0<G0ZP38`:d0`[ZW0<c4[`3<aJ/0a;fQ0<[3
Y`3;a:X0`KVT0<BmZ`39`jT0a/6S0<W4Y`38`Jh0al2^0<k8/P36`J<0b;f[
0<g5/038`ZX0a<2U0<S4Z@39`j/0bl>^0<Zo[@38`jH0c<Fb0<Fn[P3=a[@0
b<:X0<c7ZP3?bK<0b<6a0<FoY`3=ak40cLJc0=39]`3:`k40c/Nd0<k8/P3=
ajl0d<V_0=3:/P38`jl0clbi0<S5/P3Dck`0c/Nd0=;:]@3>ak@0e<fk0=7:
^P3AbK`0d/Zm0=7:^P3Ec[`0clRe0=G@_03Ac;P0clZg0080em2n00P0dLRi
0<o6]`3Hcl00cLRe0=kIaP3Hdl00dL^k0<k8^080e<k000T0f=;40=SA`@3B
bk/0eLjn0=7:^03Id/00e<fj0=;;^03Gd;d0>03Ec[`0303GdKT0dL^e0=OB
_P3Ge<<0g]c?0?CajP3Ui>00n_Wg09VNU`23R840]kjf0;S0]@80/kfb00<0
/[f_0;C0/P2c_K800`2c_K860;Bn/`<0]Knd0`2f`;D01P2lb;X0/[f_0;G0
/P2nb;d0^/:g0;Nn]P80_/>l05@0^/Fg0;K1/`31c;h0_LRj0;[5]`2g`[@0
^lJh0<7<_P2mak`0^<:g0;o9_P30akl0_/Fm0;o6_P2k`[X0`lS20<;9`@30
akl0^l:j0<;9`@2oa[h0`<No0<K=a@31b<00`<[10<;<``31bl80_/Ro0<[D
b`2makh0`L_20<;<``37c/H0a<_30<37_`34bl<0`/W10<G<a031b<00alk6
0<K;a032al00b<g60<G:``2oa;d0cM;;0<?8`@31a[l0`LVn0<?;`038d<D0
`/W10<?:`P32bL40aLc40<;9`P38c/@0`<Jl0<O<a@3:clP0`lS10<35_`36
blD0b<g70<W>a`31a[l0a<W20<W>a`34bL80alc50<76_`38cLH0a/_50<;7
`@31a/00b/o80<S=aP2n`k`0a<[00<cBb034bL80alc50;k3_037c<D20<?8
`@0:0<76_`36bl@0alk60<S?a`30akl0a<_30<;9`@37c/H0aLc40<K=a@P0
a<_30100a<c10<O?a035c<@0_lW00<gDc@3Gg]L0gNCM0>GZiP3^ko40T9VH
07>6PP2O_;L0V[Ze0:6o_@2M]kH0Ykbo202N^kT809nl^P@0XK^j102R_;/0
F02O]kT0Ykno0:W1`@2P^;P0[<G20:Fn^`2U_[X0Z<6m0:[7``2Q^kP0Y[nl
0:Vo_@2W^kX0[lG30:[0_P2V_k`0ZlG40:C2`02Ta<40ZL?20;32a02`_l80
ZL710:G5`P2T`Kl0/<[90;36a02ealL0//;20;74`P2`a<80/LG30:S5`@2Z
_[d0^l_;0;32`P2[aL80Z/O30:k7a02ibLT0]lW90;32`P2calH0]<S70;G;
b@2gcL/0/LO50;C=bP2bc<T0/L[70:k2`@2jc<`0]/S80;W=c02ec//0[/S5
0;W?c02gblT0]LS60;?3`P2mcL`0]<O50;;6a02fc<T0_/k=0;C7a@2ebLL0
]<[70;K<b@2db<H0[l;00;g=c02galH0]/W70;oCd@2^a<40/lW60;?7a@2f
bLL0^/[90;7:a`2^al@0]Lk;0:k7a02db<L0]/[90;O;bP2`a<<P0;C:b00@
0;G>bP2hc</0`];B0<kIf`3Fh>80iNg_0>G_l02EWj00LY:A0:73`P2K`[l0
VL7009K0_P2OalL0U[bm09k1`a00Vl7202T0WKo109k1``2C^k/0V/C209g7
a@2G`;`0W/;00:?5a02Ra<<0YLO809k2`P2Ra/H0W<;309o5aP2H`<80YLg?
0:_;b02O_kh0ZL_=0:74b02O`/H0YLS:0:G9a`2Tb<@0Zl[=0:O9b`2VbL/0
X/W809k5a02UbLL0[Lo>0:W9b02_alT0ZLO70:W=b`2WbLP0//k?0:k8b@2/
c</0YLk:0:G7b0020:o>d00e0:g<cP2[bL/0[lg?0;C@d`2^b/d0/loB0:o=
c@2bd]40[<k=0;3Cc`2he]@0[<K30;_Dd@2bdM@0[Lc?0:o>d02]bld0]=;B
0;;>c`2`c<d0/m3>0;7=d02ccm80]M7D0:c:c02_cLl0/LoA0:g<cP2feML0
/=3=0:o=b`2eclh0]<c>0;?=cP2fd]D0/]3B0:g<cP2kd=40/LW90;kHe`2[
bLL0[Lg:0;GEdP2^blT0^=;A0;?Ad@2_clh0Z/c;0:S<bP2]clh0[lo>0:o;
c02ecm00602acll04`2`c<l0/<k>0;3@c`2`d<l0/<k>0;3=b`2fd<l0_=CD
0<OKfP3CiND0hNg]0>_cm@2[[k00]kVh0?goo03koOX0oooo0?gmo@3lo?`0
5@3oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0O7Ub08b9
NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[4038`:T0:`38`:/0
`KVR0<[3Z@34_J40bL:V0=3;[P31_9l0al:U0<ZoZ`3<`J/0_kFJ0<W0X`3;
`JH0a;ZQ0<k4Z`36_:<0bl>^0<O0YP37`:<0`kbP0<[2Z`37_jX0b/:[0<O0
Y039_Z`0cLF`0<W3Z@37`ZD0blJY0<FoY@3<a:l0bl2^0<W3Z@3;aJl0b/>`
0<o9/`3=ajd0b/FX0<W3Z`3?b;D0eLjd0<c4[@3=aK000P3@b;<03P3=aK00
c/J_0=;;/@3?b:h0d<Zb0<g8/P3?b[H0dLbh0<W4/03EckT0c/Ja0=?;]P3A
bKH0eLfj0P3@akH05P3EcKX0dLVf0=C<]`3Dc[H0cLNa0=K@^P3>ak@0d<Nf
0=cC`P3FcKh0eljo0=K?_03BbkP0dLZg0=39]P3Me/@0e/nm0=39]`3Cc;X0
d/^i0=K?_@3Jdl420=?<^P030=7:^03BbkP0em2m03P0eLjl0100f=:j0=G?
^@3Ie<40gMW=0>OTf`3ZjnD0oOki0:Z/Z@1lPg/0]kjf0;>k/02e_k@0/;Z_
0;6l[P2f`K<0];na102c_K840;Bn/`<0]Knd0`2f`;D20;O1]P0I0;2k[@2k
a[P0^L>h0;:l/@2e_k@0^L6f0;S0]@2na[/0^LBf0<3;_@2c_[00_lZl0;O2
]032cKl0^/Fg0;K1/`2kakT0_lVn0;c6^`2i`kP0_lVn0<G<a032bL40`LS0
0<37_`020<78`0030<?:`P38clL0`LS00080_lJn01@0`<[10<;<``2obL00
am780;c6_@33cL@0b=;90<3:`@34bl<0`LS00<cCb`33b/80a/g50<S?a`35
c<@0`l[20<G<a038clL0`/W10<O>aP80a<_300/0`l[20<W@b034c;l0aLg2
0<?;`03;dlP0`LVn0<C;``30akl0a/g50<C<`@020<K>``030<37_`35c<@0
c=?;0080`l[300X0_lJn0<[Ab@35c<@0`/W10<G<a036cLD0alk60<37_`36
cLH0bM390P34bl<04@38clL0alo40<C<`@2oak`0a/g50<;9`@3:dLT0_<>k
0<?:`P3:dLT0`/W10<O>aP34bl<0`l[20<K=a@38clL0`LS00080a<_300<0
a/g50<C;``34bl<01P34bl<04035cL80`LVn0<gDc037c<D0fN3I0=SNfP3R
j>@0lO[g0:N_/@1ePh<0[lG309Vh/`2M`;`0V[Zg0:6k_02T^K`809jk^@P0
Wkbj102Q^kX40::l^`0N0:S0`02O]kL0WkVh0:S2`@2L^KL0XKjj0:G2_P2O
_[T0W[bj0::o_@2W_kl0Z;fn0:Zo`02R^[X0[LO60:?0_P2Za<<0X[nm0:c:
b02ZalD0[L;30:_0`@2Za<<0ZlW70:g:b02Q_[`0]lo?0:Fk^@2eblT0[/C2
0P2`a/<0>02ablP0//S60;;6a@2bb<H0]<k;0:k;a`2bblP0[l?20;;8aP2c
bLL0]lg;0;G;b@2`a/@0]<[80;K?c02dcLX0/lg:0;C=bP2cbLL0]lg;0;G;
b@2_aL<0/lc90;;<b@2_b<D0/lW70;G;b@2fb/T0//K50;36a02ld]00/<W6
0;O;bP2]`l40^]3>0:[3`02fcl`0[lG30;gCd@2calH0]<S70;?9a`2[`Kl0
]<g:0;;;b02cbLL0]L_90;?7aP2ccLX0[lS50;K<bP2db/P0//_80:k7a02b
b<H0^<k<602db/P30;G;b@D0]<[800T0/lc90;O;b@38e]H0fN7S0>7Yj`3a
nod0X[:b07N;RP2Oa/D00P2G_kh0102La/@0V/C209S0_`2J`<4A09_1`P80
WL320280WlK509c4``2G`Kl0VlG30:38a`2H`;l0X<S709_3``2La<@0X/[:
09c4a02Pa/L0Y<[;09_1`P2MaL@0Y<_:09k1``2Wb<d0XlK:0:C:b`2OalH0
WlW70:?5a`2Zc<h0Yl[<0:;8b@2Xd<l0Ylo>0:;9b02Wc/d0[<[<0:_=cP2Y
d<l0Z/k>0P2[b/`0302`e=@0YLg<0:oAdP2]cm00Zlg>0:g?d02/c/l0[Lo@
0:[9b`2ad=80/<c=0:g;b`80/];A00H0[Lo>0:W9aP2fe]<0ZlW70:o>d02a
d=820;3?d@0T0:k=c`2`d]<0/]CE0:W;bP2acm40[lk@0:_:c02cd]@0/<oA
0:c>c`2ceMH0Zlg>0:O;b@2`d]40/=3?0:o=c`2/b/`0ZlW;0;;@dP2`cm40
^=;C0:_7b02^c/d0/];A0;3>cP2dd]80/]3@0:o=c@2^d<l0Zlg<0;;Dd`2_
dM00[/k=0;GCd`2dd=40//c=602acll04`2acLh0/<k>0;7?c`2acld0/<k<
0;C>c@2md]<0a=SG0=WYj03MjNT0jo?e0;Vm_P2c];H0oooo0?gmo@3oood0
oooo0?gmo@3no_h00P3oool20?clo0030?knoP3oool0oooo00h0oooo0008
0?ooo`0@0?omo`3jn_X0mOOd0>o`lP3Ui^/0h^;T07aiLP2<RGX0WYF40:jV
T`2o]j00al2V0<S1Y`37`:H0aknX0<S0Za00b<2Y01`0aknX0<W1ZP37_jP0
blBZ0<:kX@30^Id0c/N[0<O0Y036^jT0b;jU0=37Z036_J00akfT0<g2[035
^Z@0c/B[0<NoZ036_jD0bL:X0<O0YP3:`Z/0aKfV0<W1ZP39`ZP0bL6/0<No
Z03=aZ`0bL:X0P3:`jT03@37_jP0bl>^0<c5Z`3:`Z/0b<2[0<W1ZP3:`Z/0
c<F[0<_3[03=aK00cLF^0<S0Z@3@b;400P3<a:l01`3@b;40eLff0<c4[@3<
aZh0d<Zb0=G?]`3AbkD00P3@b[@01@3Ab[L0d<Vf0=G=^03Dc;L0eLfj0080
dl^h0140eLfj0=G=^03Fc[T0dlfg0=C>^03@b[@0e<fj0=O@_@3>akD0e/nm
0<o8]P3Gd;d0d/^h0=SA_P3BbkP0e<fj0=7:]`020=SA_P80e<fj00H0dlbi
0=39]P3Ec[`0f]?10=SA_`3BbkTh0=G>_00@0=;;^03Ke<80hM_=0=oLd`3^
kNP0kNkX0<K8``1WK6H0ZkFZ0;:l/@2f`;D0]Knd0;2k[@2b_Jl0/kj`0:nj
[0<0/kfb1@2d_[<20;Fo]0<0]/2e0`2g`KH02P2kaKX0]Knd0;S2]`2kaKX0
_<Ni0;g8^P2jaKL0]l:d0;_6^02e`;820;[5]`0f0<?>`02c_[00_lZl0;g8
^P2iaKL0^<Bf0;[4^@2nb;d0`L_00;g7_02ma;`0`<No0;k5_@32bL40aLc4
0;k5_@31b<00`/W10<?:`P36cLD0`L_20;[4^`39dlX0_<Jm0<WCbP30b/40
_<Jm0<G?aP32bL40bM380;g4_031b<00b<o70<K=a@30akl0a/g50;o6_P37
c/H0`LS00<C;``3;d/X0`l[20<37_`33b/80`l^n0<O?`P34c<40`<Rm0<O?
a036c/<0`l[20<C;``33bl00aLg20P33bl020<G<a0080;c3^`38clL0a<_3
0<O>aP31b<00aLc40<K=a@2oa[h20<K=a@0H0<?:`P30akl0aLc40<O>aP2m
aKX0_lNl0<S@a@34c<40`/W10<G<a03;d/X0`l[20<K=a@33b/80alk60<78
`036cLD0aLc40<O>aP38clL0a<_30<K=a@35c<@0`/W12034bl<04035cL00
`<Rm0<O=``3Bem00f]oK0>3Vi03an_L0^lG405a/K02I[J`0V;:a09^i]`2M
_KX0VkVg0::n_`2M]kP809jk^@P0Wkbj0`2Q^kX50::l^`0L0:2h^02T_[d0
YKnn09fg]P2Wa<80XKjl0:K3`@2R`;h0Y<6o0:c6a@2U_Kd0Ykno0:_3``2/
a/D0Xl2n0:G2`02/a<@0ZL?20::o_@2U_kh0[lW80:g5a@2X`/40Z<G30:k8
a`2]alH0Y/2o0;7;bP80[LK300L0[<G20;7:a`2[`l<0//O80;C9bP2`aLH0
[lO70080[/K60340]/_<0;;7b02`aLH0//O80;O<c@2eb//0/LK70;35aP2a
a/L0[/K60;;:bP2jd]80/<G60;;7b02bb/X0/l_;0;C<c02dcLX0/L[70;C:
b02kdLl0]<[80:o5``2gd<d0[lS50;G;b@2fc<X0/L[70;WBc`2`bLH0]<g:
0;;8aP2cbLL0//S60;O=b`2ec//0]m3=0:W2_`2hdLh0/lW70;77a@2_bLP0
]L[;0;?7b02aaLH0]Lo>0;?=c02`b<P0//K701P0]<[80`2eblT40;C:b00;
0;G;b@2hdLh0a]WG0=KPg`3OiND0k?Gd0;O5aP1KLg<0UkNf09Jn_P2La<@0
0P2J`/80102OalH0V<2o09W1`02La<<@09_1`P040:C8b02F_K`0W<?209c3
`P<0W<C40240VlG409S2`@2Nb<L0W/K609c4a02Tb//0VL2o09o6a@2SalL0
X<S70:36a`2Xbld0YLO90:73a@2Qa<H0XlW:0:G=c02Xb//0XlG60:W;c02W
bl/0Wl?30:?:b@2Xclh0X<O60:[<c@2SalL0Y/[:0:gAd@2/c/l0Zlg>0:K8
b@2]dM400P2/bld03@2bdM<0[m7B0:W;c02_dM80[]3A0:c>c`2cdM40/]3@
0:g;b`2bd]40Zl_:0:o?cP2bd]400P2_clh09`2adM00[/k=0;?Be02ad=80
[Lc>0;3?d@2ddmD0/LoA0:g;c@2_c]00/M3B0:k=c`2be=D0[Lo@0:k@d@2a
dm@0Zlg>0:g?d02cd]@0]MCF0;GCd`2_cLd0/Lo?0:o9bP2geMD0[<k=0;3@
c`2edM80/L_<0:k<c02_clh0/=;A0:c<b`2adM00/=3?0;3>cP2edm<0/m7A
0;7=cP0H0;7?c`0?0;;>c`2`c/h0/<k<0;7?c@2cd<h0^];B0<KJf@3?hN40
h>[Y0>cem02n`/<0TY>E0?3`l03oool0n_[j0080oooo00H0o_kn0?ooo`3o
ool0o?cl0?[jnP3moOdA0?ooo`00203oool0403ooOl0n_[j0?Ggm03_l?80
iNK[0>;Ri01lNG80S8Uj09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038
`:/@0<S0Z@0b0<JoY@3=aZ`0a[jW0<FmYP3@b;40c<6[0<:hW`39_jH0b/6`
0<JnY`34_Yh0b/>V0<c4[`35_:/0`k^X0<NoZ036_ZL0a;bU0<NoZ03:`Z/0
cLF^0<[2Z`3<a:d0aknX0<JnY`3<a:d0c<6]0<_0[039_ZX0c/>_0<c4[@38
`:T0a[jY0<g5[P3@b;40cLF^0<c4[@3=aK00clN`0<_3[03;a;40dLZg0<k8
/P3:a:h0dL^e0<_5[`3<aK80d/^h0=3:]03?bK<20<o7/P070=C<]`3Fc[/0
c<Fc0=K?_@3@bKH0dLZg0<c6/0020=G?^@0D0<c6/03BbkP0dLZg0=C=^`3F
ckd0e<fk0=;=^@3Ac;P0d<^g0=C?^`3FdKd0eM2m0=7<^@3BcKT0eM2l0=KA
_@3Cc[X0e<nk0=7<^03DcKX20=K?_0050=O@_@3Cc;T0dLZh0=;;^@3Fckd0
>03Ec[`02@3Fckl0g]S:0>;Ne@3^jnH0loC_0=gPf@1WK6D0W:BI0;K2]P02
0:nk[`050;O2]02d_k40]l:d0:jiZ`2g`[800P2c_K860;Bn/`80]Knd0P2f
`;D40;O1]P0@0;S2]`2i`kP0^<:g0;Bo/@2h`kD0^<Bf0;C0/P2mbK/0_/Jk
0;c4^@2oak`0^/:g0;g5^P2j`[L0`<Rm0;k6^`80_/Zl00H0`<bn0;o9_P2k
aKX0^/Bi0;k8_@34bl<20<;<`@0N0;c6^`31bl00_LNl0<?=`P2obKh0_/Rm
0<79_P39dLH0`<Rm0<;:_`34c<40`<Rm0<[Ba`34c<40`<Zo0<;<`@33cL80
bmG:0;[4^@38d/L0`<Zo0<?=`P36c/<0`/Zo0<S@a@31bKh0`<Rm0;g5^P3:
d/L0a<c10P31c;h0:P33c/00`<Zo0<;<`@31bl00a<k30<7;`P34c;l0a<c1
0<?;`035cL80`<Rm0<K=a@34bl<0aLc40<S@a@33bl00b=350<G=`P34c<40
b];70<;:_`35cL80aLc40<[Ab@32bL40`<Rm0<_Cb035cL80_<Bi0<K>`@37
cl@0_lNl0<;:_`35cL80`/Zo0<G=`P30b;d0b=350<G<a033b/80_lJn0<78
`0<0a/g500<0`/W10<C;``34bl<01P34bl<04033bkh0cMG:0<kAb03KgMP0
hnGR0?Gkn@3;eM@0Ig=a08^SX`2V`;l0XK^j09nl^P2L^;T0YlG509Fc/`2S
`L4809jk^@P0Wkbj0P2Q^kX70::l^`050:Bn_@2R_;/0Z/C30:>m_02R_;d0
0P2U_l00D02Y_[l0Y[jn0:Fo_P2X`/40X;Zi0:c6a@2U_kh0Z/C30:c1`P2X
`<00Zl?30:o9b02U_kh0Yl700:o9b02^a/H0Z/;40:o7a`2ablX0Z/C30:W3
`P2cc<T0[<G20:o5``2dbLX0[lC50;K;c02_a<D0/<G60;O<c@2]`/<0]<W:
0;O<c@2balP0/<G60;76a`2fb//0^Lg>0;K:b`2ebLX0]/[;0;G:b`2aa/L0
//[:0;C<c02cb<T0/LK70;?7b02fc<X0]L_90:o8a@2ab/L0]Lk;0;?<b@2a
alD0]L_90;;;b02ec//0/lW70;36a02db/P0]lg;0;39aP2_b<D0]/o<0;39
aP2eblT0/lW70;K<bP2aalD0[LK30;SAcP2bc</0]/[;0;G4a`2ealT0/L_:
0:k;b@2abLT0]lW;602db/P30;G;b@<0]<[80180]lg;0;S>c02oeM<0b][I
0>G^k@3[knh0cmSG06MkNP21Xj80V<;00:38b02J`<40W<;309[0`@2D^[/0
X<S709>k^P2MalD@09_1`P0>09c3`P2NaL@0XLS709^n`02TalT0WlG609_1
`P2Na/H0WlK50:C;bP2PalH0Vkno0:K:bP2Pa<820:?7a@1=0:K9b`2Pa<@0
Yl_;0:K8a`2Zc</0Z/c=0:S:b`2Ta/P0YlW80:K8a`2WalH0Zl_:0:k>c@2^
cLl0[<k?0:[<c@2WbLP0]MOF0:;4``2Xb/T0/=;A0:S:b@2adM00[lo>0;7?
c`2bd=00[/c<0:W7a`2bd=00/M7@0:g=c02cdm80[lo>0;;Bd@2]bl/0]M7B
0;3<c@2gdmH0[lg?0;CBe02^c//0^=KD0;7?c@2/b/X0/m7A0;3<c@2_bl`0
]M7B0;3<c@2edM80[l_<0;?Ad@2_cLd0/<k>0:k>c@2_clh0/LoA0:k<c02f
e=@0[<c;0:k>c@2]bl/0/]3>0;?@cP2bc<d0/M7@0:[>c02/c</0]/k@0;[?
dP2he=D0[<k=0;;@d02^c<`0/lo@0;KBd`2bc/l00P2]bl/00`2adM00/Lo?
0;7?c`0F0;7?c`0>0;??d02`c/`0/<k<0;?@cP2idm80`mWG0=3RhP3Lk>`0
iN_[0>;Vi`2EUiH0fMWI0?omoP3mno`30?ooo`050?gmo@3no_h0oooo0?cl
o03moOd04P3oool000P0oooo0100oogo0?[jnP3emo@0ko3b0>GVj`3Rh^@0
O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[4038`:T0
5039`ZH0a[nU0<W1ZP37_jX0aKZV0<ZoZ`3=`Z`0b[nY0<Bl[`37`JT0a;nQ
0<K1Y033_:T0aKj^0<g6]033_JD0bL6Z0<NoZP3:`Zd0bL6/0P36_ZL05@3:
`Z/0b/:]0<W3Z@39`JX0bKj/0<o3/`3;_jl0c/>a0<[2Z`3<aZ`0clNb0<c4
[`39`JX0c<B]0<o7/P3;`jh0c/Ja0<o7/03<a[H0blJc0<c7/`020<o:]P0>
0<_6/P3@bkP0blFe0=7<^03?b;D0dLVd0=?;]P3AbK@0clNd0=C=^`3?bKT0
dljk0<o:]P3Hdkd20=3;]@030=WD_P3?b[H0e<nl0080d/bl00<0c/Rh0=WD
`@3AckX00P3Bd;/01@3@c[L0dLbi0=[E`P3Cc[/0d/fj00<0d/fi00@0eM2l
0=?=]`3Dc[P0dlbi0P3Ec[/00`3Fckd0eLjl0=;;^@0h0=G>_0080>3Hb`3T
gM<0jnKP0?GakP3Ui^40NGig09:JS`2e`;820;2l/0060;S4^02]^J/0];na
0:nj[02jaKD0/Kb/1`2d_[<20;Fo]0<0]/2e0`2g`KH01`2h`[L0^L>h0;Fo
]02kaKX0^LBf0;G1/`2iaKL00P2ia[D04@2naKd0_LBl0<37_`2k`[X0`/W1
0<37_`2naKd0`LS00;g9^`2kakT0_LVk0;k:_030b[l0`L_00;k8_@2obKh0
_<Jk00@0`L_002d0_LNl0<K@a@32c<40aLg20<;:_`37cl@0aLg20<C<`@37
cl@0`/Zo0<?;`033cL80`/c10<7;`02nb;d0a]350;c6^`37dLH0_lVn0<?;
`037cl@0`LVn0<G=`P34c<40bm?80<38_@33bl00`/fo0<C?`@31c;h0am;4
0;o9_P33cL80`<Zo0<C>``33bkh0b=330<;:_`36c/<0a<c10<O>aP33b/80
alk60<79_P33bl000P34c<401`33bl00a/k30<38_@38d<D0`LS00<?:`P35
c<@00P33bl003@35cL80aLg00<?;_P32b[l0alo40<C<`@30b;d0aLg20<38
_@39dLH0`<Rm0<;9`@38clL00P35c<@01038clL0`<No0<;9`@35c<@80<C;
``0@0<SCa@3:d<@0fmkE0>OXh`3^l>d0hnWW07=mO025Ti<0W;Zj09Zf]`2P
^[/0X[bm0:2j^`2K]kP0X<2o09Rj^@P0W[^i202O_;X70::l^`030:>m_02R
_;/0YKnn0080Y;jm01L0Yl720:Fm_`2Z`/@0Y;bn0:k0`P2W_;d0ZL?20:O4
`P2U`/00YlC20:_3``2[`<40Z[o00:o4a@2[`<40[lO70:[4``2ZalD0[<C4
0:o4a@2_a<L0[/K80:W3`P020:k8a`0S0:g7a02/aL80]<[80;;6a`2eb//0
[/?40;K;c02ebLX0/LG60;O;c02aa/L0/lS90;;7b02hc<d0]l_<0;K:b`2g
bL/0]<K80;K8bP2caLL0^<c=0;35aP2fbl`0//O80;W>c`2ba/L0^<[<0;?7
aP2eblT0]/o<0;7:a`2]a/<0/lc90;;8aP2fb/T00P2bblP05P2eblT0]/[9
0;S<b`2cbLL0[/O40;O@c@2`bLH0//_80;77a@2ebLP0/lO60;;8aP2gd<d0
[lS50;;:bP2da/P0^/S;0;W8b`2^b<L0//o=0;G=c@2ea<LM0;C:b00=0;G;
b@2hc/`0^m7?0<[PgP3Hi^H0io3_0>CXi`1dOWd0OIJC09g6`P2Ca/40Vl74
09k1a@0209k1``0409c2``2J`/40WLO509G2_a00Vl7203H0V/;109_2`@2Q
aLD0WL320:73a@2L_l40X/G90:36b@2QaLD0W;jo0:?5aP2UalH0XL?20:?5
a02Ub<@0XLC00:C3a@2[cLh0X<;10:C8a02Tal<0YlO60:O5a`2/b</0Z<_7
0:_;b02Zb<H0[<[80:_7b02Xa/H0[L_;0:W9b02Zc</0YlO60;CBdP2/b/X0
Z/[90:o?cP2`c/h0[l_<0;3=b`2]b/P0]M;@0;;?c@2`c/`0[/c:0;CBd02a
cld0[]3?0;;Bd@2bd=00//k?0;?<d02_b<`20;;>d@090:o>b@2^cLP0/Lo=
0;3=b`2cd<h0]Lo@0;OAdP2bb/`0//c;0080]Lo>00T0/Lk<0;3=b`2heM<0
[L_90;CBd02ccLh0]<k?0:[6a`2fe=@00P2`c/`04P2ed]00/Lk<0;SBd`2Y
bLP0[m?A0;CBdP2fblh0//G90;7;c02`d]40/Lg>0;K@d@2ccLh0/<[;0;;<
c@2dd=40/];A0:o?cQP0/Lo?00/0/m3>0;3>c02`c/`0]=7?0;cFd`38g]`0
enWY0>?cl`3/l>l0SY2?0<W9b@020?ono`050?klo@3no_h0oOgm0?ooo`3m
oOd00P3oool0103no_h0oooo0?ooo`3lo?`@0?ooo`00203oool0403no?l0
n_[j0?Ggm03`lO<0i^O/0>;Ri01lNG80SHYk09jEQ02^YY<0_kNP0<O0YP38
`JL0al2V0<NoZ038`:/H0<S0Z@@0aknX2038`:T40<W1ZP<0b/:]0P3;`jh4
0<c4[`<0cLF`0`3>a[400`3?ak80cLJc0<k7]0020<k7]0<0clRe103@bKH2
0=7:]`<0d/^h00<0d/^i0=?<^P3Cc;X01@3Cc;Y80=G>_00@0=KA^`3Ed;`0
dLbh0=;=^@3Ed;d0dljk0=KA_P3NfLH0h]oJ0>SUh03alNT0lOC[08F;P@2;
ThP0]l:d0;:n/0@0/kfb1`2d_[<20;Fo]0@0]/2e0`2g`KH30;S2]`@0^L>h
0P2ja;T30;_5^P040;g5^P2na[/0_/Jk0;k6^`<0_lNl00@0`<Rm0<37_`30
akl0`<No0P31b<040<;9`@L0`l[2B034bl<0402mbKl0am?90<?=a032c<40
`lg20<38_@34c;l0alo20<_Gb`3Dfm<0hN;M0?;^k@3_ko40PXb>07Z?T02N
_;`809jk^@P0Wkbj102P^[T40:6k^P<0X[bk0P2S_K`40:Bn_@<0YKnn0`2V
`;l0102W`L00Z<300:S0`02X`<020:W1`@<0Z/;20`2]`/<20:k3a0@0[lC5
0`2`aLH30;76a`80//O81`2cb<U80;C:b00@0:k;a`2`b/L0/lW70;S:bP2h
b<P0]LO70;kDdP36gm`0g^OV0>O_l@3VlO<0OXf@07^CU@2N_L00Vl?509K4
a0`0Vl721@2J`<4309_1`P<0W<;300@0WL?409o3``2O`l<0Wl?30P2Pa<@3
0:75a@040:;4a@2SaLH0XlG60:?5aP<0Y<K7102UalP20:K8b@<0YlW:0`2Z
bL/20:_:c0<0[<_=00<0[L_=0:k<cP2^c<h01@2^c<i80;7?c`0F0;3>cP2b
d=00/]3@0;7?c`2`d<l0/M7@0;3@c`2]cL`0[/k=0;;@d02`c<d0_mOG0<KH
f03Pjnd0iNg_0>c`l`2HV9P0c/k>0?Shn03no_h0oOgm0?knoQX0oooo0008
0?ooo`0@0?omo`3jn_X0mOOd0?3al`3Vin`0h^;T07aiLP2=RW/0WYF40:jV
T`2o]j00al2V0<S1Y`37`:H0aknX0<S0ZaP0b<2Y1037_jP70<S0Z@D0bL6Z
0P3:`Zd30<_3[P<0c<B_103=aK020<k6/@80clNb103>ak@20<o8]@@0d<Vf
0`3Ab[L30=;;^0H0dlbj0P3DcK]80=G>_00@0<o8]@3Id[l0e]6m0=;=^P3F
dKh0f=?00=OA`@3Le/H0i^?N0>g/i`3^knL0XjJM08^AQ`2`^:d0/kj`0;:n
/0@0/kfb1P2d_[<30;Fo]0<0]/2e102g`KH20;S2]`@0^L>h0`2ja;T30;_5
^P@0_/Jk0P2oak`20<38_@80`<No0`31b<030<;9`@H0`l[2BP34bl<04035
dLL0`/c30;k8_`32c<40`lg20<?;`038d<D0bm?80=3Gc`3Nhm`0kNoZ0?3b
l@2MXj<0OH^<0:Bi^P2Q_Kh809jk^@P0Wkbj0`2P^[T50:6k^P80X[bk0`2S
_K`30:Bn_@@0YKnn0P2V`;l20:O1`080Z<300`2Y`L430:[2`P80[L;30`2^
`l@30:o4a@@0/<G60P2aa/L20;;7b0H0/lS90P2dbLY80;C:b00@0:o9aP2h
dLh0/lW70:o3`P2ibl/0_lo?0<GEe@3EiND0hNW[0>C`l02DY:@0NXn@09nm
_@2O`/@0V<3009K2``h0Vl720P2J`<4409_1`P80W<;30P2M`l@209o3``<0
X<C40`2QaLD40:?5aP80Y<K7102UalP30:K8b@<0YlW:0P2ZbL/30:_:c0<0
[<_=1P2^c<h20:o=cdT0/Lo?00@0/]3@0;7?c`2`c/h0/Lo?0P2adM002`2_
clh0/]3@0;GCd`2je=<0a]_L0=_[j`3IiND0l_Oj0;>g^P3=cLd0kno_00@0
oooo0P3no_hH0?ooo`00203oool0403oo_l0no_k0?Ggm03_l?80iNK[0>;R
i01lNG80SHYk09jEQ02^YY<0_kNP0<O0YP38`JL0al2V0<NoZ038`:/H0<S0
Z@<0aknX1`38`:T60<W1ZP040<[2[@3;`jh0bl>^0<_3[P@0c<B_0`3=aK03
0<k6/@80clNb0`3>ak@30<o8]@<0d<Vf0`3Ab[L40=;;^0D0dlbj0`3DcK]8
0=G>_00@0=G>^`3@bKH0dljk0=G@_@3?bKT0dlfm0>7Nc`3[j=T0k^gX0?Ce
k`32aK`0QhZ10:ZbY`2ja;T0[[V[0;6m[`<0/kfb1P2d_[<30;Fo]0@0]/2e
0`2g`KH30;S2]`<0^L>h0`2ja;T40;_5^P<0_/Jk0`2oak`20<38_@040<37
_`31b<00`LS00<78`0@0`/W11@33b/9;0<C;``0@0<7;`P2makh0`lg40<K@
a`34c<40`l_00<O?a03=eLX0inKQ0>GWhP3dnOD0[KRd082@S`2K/Jl0WKNf
09nk_0P0W[^i202O_;X20:2j^@H0XK^j00@0X[bk0:>m_02S_K`0Xkfl102T
_[d30:Fo_P<0Y/2o0P2W`L040:W1`@80Z/;20P2[`l<0102]`/<0[/?40:k3
a02^`l@40:o4a@<0/<G60`2aa/L20;;7b0D0/lS90`2dbLY80;C:b00@0;G;
b@2aalD0/LO50;_?cP2jc<`0`m7B0=cVj03MiNP0koWj0:Rh^01mUY<0U[Jc
0:78a`2E_Kd0V<3009g5aa<0Vl720`2L`/<209g3a00409o3``2Pa<@0X<C4
0:34a0@0XLG50`2SaLH30:C6a`80YLO8102Vb<T20:O9bP80Z<[;00@0Z/W;
0:_:c02[b/`0Zl[<102/bld40:k<cP@0[lg?BP2acll20;3>cP0=0;7?c`2b
d=00/]3@0;3>cP2bc/l0]]3?0<KKg03>h>00gng^0>[bm032b<P0/kNh0?Og
m`020?ooo`030?gmo@3no_h0oooo0080oOgm603oool000P0oooo0100ooko
0?[jnP3dm_<0k^oa0>GVj`3Rh^@0O7Ub08b9NP2NUH@0[ZJC0;ngX037`:H0
b<6W0<O0YP37_jP0b<2[6038`:T20<NoZ0H0b<2Y1@39`JX30<[2Z`<0bl>^
0`3<a:l40<g5/0<0c/Ja0`3?ak820<k7]0<0clRe0`3@bKH30=7:]`<0d/^h
0P3Cc;T40=?<^P@0e<fkB03Ec[`0403Gd;d0eLjl0=C?_03Dc[h0dm310=kJ
cP3Xi=P0i^CH0?;ekP3>dLX0I6MN0:R^Y02`^:d0];jc0;O2]02b_[020;>m
/PH0];jc0`2e_k@30;K0]@@0]l6f0`2h`[L30;W3^0<0^/Bi0`2kaKX20;c6
^`80_/Jk0`2oak`30<38_@<0`LS00`32bL460<?:`T`0a<_30100`L_00<;<
`@36d<L0`l[20<;9`@3;d/X0dmSA0=gRf`3_jnX0kno]0<[Ed@1CIV80SZNS
0:2m^@2M^[P0Xkfn202N^kT809nl^PD0XK^j0`2R_;/30:>m_0<0Y;jm102U
_kh30:K0_`<0Yl700P2Y`L430:[2`P<0Zl?30`2^`l@30:o4a@@0/<G60`2a
a/L30;;7b0@0/lS9102dbLY80;C:b00@0;G9b02aaL@0^Lo=0;S<b`32e=@0
eN3R0=gRiP3gn?d0_lo?06=hN@2<[:T0W<G109K3`02Ia/<0W/K609Vl_Q80
Vl720`2L`/<309g3a0<0X<C40`2QaLD20:;6aP80XlG60`2Ta/L30:G7b080
Y/S90`2WbLX30:S:b`<0Zl[<0`2/bld20:g<cP<0[/c>1@2_cLm90;7?c`<0
/<k>00`0/Lo?0;;>c`2bc/l0/Lg>0;G?cP38gMh0c=kN0=[Xj@3[loD0d=KF
08fATP3Vj^/20?ooo`050?clo03kno/0oooo0?ooo`3moOd06@3oool000P0
oooo0100oogo0?Win@3cmO80k^oa0>GVj`3Rh^@0O7Ub08^8N@2NUH@0[ZJC
0;ngX037`:H0b<6W0<O0YP37_jP0b<2[7P38`:T50<W1ZPD0b/:[0P3;`jh3
0<c4[`<0cLF`0`3>a[430<o7/P80d<Rc0`3?b;D30=39]P@0dLZg0`3BbkP3
0=?<^@@0dlbj103DcK]80=G>_00@0=?<^P3HdKl0e<jn0=G?`@3Nf/h0h^3D
0>WVg@3hn>h0gN;K07UnM`2FWY<0/k^`0;K0]@2e_k@0[k^]0;C0/PH0];jc
102e_k@30;K0]@<0]l6f0`2h`[L30;W3^0@0^/Bi0`2kaKX30;c6^`<0_lNl
0`30b;d20<79_P80`LS00`32bL470<?:`T`0a<_30P34c/<03P34c<40`/W1
0<W@b03Ae]00emcF0>7Vh03]jn`0g^;Q06IeLP29XYh0UkJa09fk^@2S`Kl0
VKFf202N^kT809nl^P<0XK^j1@2R_;/20:>m_0<0Y;jm0`2U_kh30:K0_`<0
Yl700P2X`/430:[2`P<0Zl?30P2/a<@20:k3a0<0[lC50`2`aLH30;76a`<0
//O81P2cb<T40;C9bTP0]<[80100]LO70;kBd@2fb/T0`=;B0<_Kf`3MinT0
l?Gi0=KIgP1WO7d0NiNH0:;6a02F`kh0U/C109:o_02La<@0Wl;4202K`L80
0`2J`<40Vl7209_1`P0309_1`PD0W<;30`2M`l@209k4a@80X<C40`2QaLD3
0:;6aP<0Y<K70`2UalP20:K8b@<0YlW:0`2Xb//20:W;c080Zl[<0`2/bld3
0:g<cPD0[lg?0`2`c]180;7?c`040:o?cP2`c/h0/<k>0;3>cP80//k?00d0
]<k?0;G?d034f]P0a=KF0>3^k`3YlO<0g>3Q09NHVP3?dM00n?ck0?ooo`3n
o_h0oOgm00<0oooo00<0oOgm0?ooo`3oool05`3oool000P0oooo0100oogo
0?Win@3cmO80ko3b0>OXk@3Ti>H0OGYc08^8N@2NUH@0[ZJC0;ngX037`:H0
b<6W0<O0YP37_jP0b<2[7@38`:T30<W1ZPH0b/:[0P3;`j`40<c4[`<0cLF`
0`3>a[430<o7/P<0d<Rc0P3?b;D30=39]P<0dLZg103BbkP30=?<^@040=C=
^P3Cc;X0dlbj0=?<^PD0e<fkB03Ec[`0403Ec;/0d<Vg0=O@`03KeLT0fmW=
0>[Zh03emNd0jncV07j5O@28ShL0[kV^0;_5^P2_^Jh0/K^`0;6m[`2c_k45
0;Bn/`<0]Knd102f`;D30;O1]P<0^<:g0`2i`kP30;[4^@@0^lFj0`2la[/0
0`2mak`0_lNl0;o7_0030<38_@<0`LVn1032bL430<?:`P040<C;``33b/80
`l[20<?:`Td0a<_30100`LVn0<C<`@33bl00bM380=3Ec`3Cf=@0hNKR0>gb
kP3Wl>l0MX:2086ET`2M]k@0XL2k0:6o_@2G]K<0Y<31202N^kT809nl^PH0
X[bk0P2S_K`40:Bn_@<0YKnn0`2V`;l30:O1`0<0Z<;10P2Z`/820:_3``@0
[<C4102_a<D30;35aP<0/LK70`2balP60;?8b@D0]<W:B02db/P0402eblT0
^/c<0;_;b`3Dgn40fnKX0>Scm@3Jj>T0OH^<07FCT`2Ta/D0Ukjm09S2`02K
b<D0WLO509c2``2H^kd809_1`P0309[0`@2K`L80Vl720080Vl721@2L`/<3
09g3a0<0W/C5102QaLD30:;6aP030:?7a`2Ta/L0Y<K700<0YLO80`2Vb<T2
0:O9bP80Z<[;102Ybl`40:c;c@<0[Lc>00<0[/g?0:o=c`2_cLl00P2_cLl4
0;3>d4P0/Lo?0P2_clh03P2`c/h0//k?0;;>c`2dc/l0^M7C0;cDeP3:g]d0
e^KV0>O_l@3XjN/0W9bN0<K6aP3oool0o_om0P3no_h30?ooo`80oOgm6@3o
ool000P0oooo0100oogo0?[jnP3dm_<0lO;d0>WZk`3WinT0Ogae08f:N`2N
UH@0[ZJC0;ngX037`:H0b<6W0<O0YP37_jP0b<2[7038`:T40<W1ZPD0b/:[
0`3;`j`30<c4[`<0cLF`103>a[420<o7/P@0d<Rc0P3?b;D20=39]P@0dLZg
0`3BbkP30=?<^@80e<fj0P3Cc;X60=C=^dP0eLjl0100e/fl0=G>_P3Pf</0
g][>0>?Pe`3noOP0inSS09^LU`24SXD0];je0;W3^02Z]:T0/knc0;:n/P2e
`K<0/[j`102d_[<40;Fo]0<0]/2e0`2g`KH40;S2]`80^L>h102ja;T30;_5
^P<0_<Jk0P2mak`20;o7_080`<Rm1031bKh30<;9`@<0`l[20P34bl<20<?:
`Th0a<_30100`l^n0<K>``34c<40cmC=0=?HdP3Oi>00m?Sg0>[/j`2;WY`0
LHF30:Bj^02Q^kP0Wkbj09fk^@2P_[`0V[Rh202N^kT809nl^PD0X[bk0`2S
_K`30:Bn_@<0YKnn102V`;l20:O1`0@0Z<;10`2[`l<30:c4a080[LG50`2_
a<D30;35aP@0/LK70P2balP60;?8b@H0]<W:B02db/P03P2ec//0]/[90=?N
h03Dg=l0k?Cg0>3^k`29Wid0LH^809Nn_@2L`l80V/700:;9b02B^KP0V;nn
0P2L`/<809_1`P80V/310P2K`L8309c2``0309g3a02L`/<0W<;30080WL?4
102Na<D30:75a@<0X/K60P2SalL20:C6a`80YLO8102Vb<T30:S:b`<0ZL_<
0P2Zc<d30:c;c@<0[Lc>0P2^cLl20:o=c`H0/<k@B02acll20:o?cP0?0;7?
c`2bc/l0]<k?0;O?d@2oemT0b=gP0=CWi@3]nOT0j>g`0:bZ[@36`/<0noOh
0?_kn@3nood0oOgm00L0o_kn603oool000P0oooo0100ooko0?_kn`3fn?D0
loCf0>c]lP3YjN/0P7ef08j;O02NUH@0[ZJC0;ngX037`:H0b<6W0<O0YP37
_jP0b<2[7038`:T40<W1ZP@0b/:[103;`j`30<c4[`80cLF`103>a[430<o7
/P<0d<Rc00<0dLVd0<o8]@3@bKH00P3@bKH30=7:]`@0d/^h0P3Cc;T30=C=
^PL0e<fkB@3Ec[`0403FcK`0fm;30>3Hb`3WhmP0mO;Y0>[Yi02h^K@0PhF2
0;6m/`2c_kD0/[jb0;G1]@2`_;00/Kfa0;>o/@2b_[040;Bn/`@0]Knd0`2f
`;D20;O1]P@0^<:g0`2i`kP30;[4^@@0^lFj0P2la[/30;g7_0040;o7_030
b;d0`<Rm0<38_@<0`LVn00@0`/Zo0<;9`@32bL40`/W10P33b/8:0<C;``03
0<G<a034bl<0a<_304H0a<_30100a<bo0<O?a037cl@0emcE0=cQf`3Zkn/0
jN_Z0:^][01^R8D0Yl6n09jg]02S^k/0W[Rg09nl^P2M^kT0WK^k202N^kT8
09nl^P@0X[bk102S_K`30:Bn_@80YKnn102V`;l30:O1`0<0Z<;100@0ZL?2
0:_3``2[`l<0Zl?30P2/a<@30:g5a@<0[lC50P2`aLH40;76a`<0//O80`2c
b<T80;C9bP030;G:b`2db/P0]<[804H0]<[80100]]3=0<SLf`3Egn40i^W^
0>W^lP2U/k@0Li2<0:35_P2ObLL0U;bk0:34a02K_Kh0X<;309k2`P2K`/40
V<2o202K`L8209[0`@80Vl720P2L`/<209g3a00409c2``2M`l@0WL?409g3
a0<0W/C500@0WlG60:75a@2QaLD0XLG50P2Ra/H30:?7a`040:C6a`2UalP0
YLO80:G7b0<0Y/S900@0YlW:0:S:b`2Xb//0Z<[;0P2Ybl`30:[<c@<0[<_=
0P2]c<h30:k=c`L0/<k@00<0/LoA0;7?c`2acll0AP2acll20:o?cP0>0;7?
c`2bc/l0]<k?0;WAd`35f]d0d>GX0>3`k`3Vl_80]KVj0;nj_P3lm_P0ookm
0?clnP3moo`20?ooo`030?knoP3moOd0o_kn0080oooo00<0o?cl0?ooo`3o
ool05P3oool000P0oooo00`0oO_l0?clnP3inoP0loCf0?Kgn`3`l?00P7ib
08j<M`2MUH00[ZJA0<2hX@38`:T20<W2Z0030<S1Y@35_Z80b<2Y01L0b<2Y
1P38`Z`50<W3[@80b/B^0`3;aJl0103;a;40c<Fb0<c5/P3<aK820<g6/`80
c/Nd00@0cLJc0<k7]03>ak@0c/Nd0P3?b;D40=39]P80dLZg0P3BbkP20=?<
^D00e<fk0`3Ec[`30=?<^P030=C=^`3Ec[`0e<fk00L0e<fk00<0eLjl0=C=
^`3DcK/00P3DcK/20=G>_0090=K?_@3Bcl00h]kB0>GSe`3^k^H0kO3Y0<W>
a`1hOgL0[kJ^00H0/[j`102c_k420;C0/P<0]L6c00@0]/:d0;O2]02g`[@0
]l:d0P2h`kD30;W4]P<0^L>h0P2ja;T30;_5^P040;g4_02naKd0_/Fm0;k5
_@80_lJn0P30akl0102oa[h0`<No0<37_`30akl20<78`080`/W100@0`LS0
0<;9`@32bL40`/W10P33b/9;0<C;``0B0<K=a@35c<@0`/W10<78`034bl<0
a/g50<G<a033bl00cm;90=CCcP3Pg=T0jn_[0>K/k02kbLT0LH>309fg]P2N
^;L0WkVh0`2Q^kX20:2j^A<0XK^j0P2R_;/30:>m_0<0YKjk0P2V_k`30:O0
_@80Z<6n0P2Y`[l20:[3`080ZlC10`2^a<820:o5``H0/<K40P2aalD30;;8
aPP0/lW7B02ebLP0402db<L0]l_:0;C8a`2ba/D0]LW80;O;bP2hc</0^/k=
0<GDd@3Egmh0iN[]0>c_m02ob<d0KhB709Vk^P2G`Kl@09_2`@0409c0`02M
`L40WL7109g1`@80W/;21@2O`l<20:34a0<0XLG50`2Ra/H20:?7a`<0Y<S8
0`2Xb<L20:W9b0H0Z/[90P2[blX30:c<b`040:g;b`2^c<`0[/c<0:k<c080
[lg=0P2`c/h80;7=cTP0//k?00`0/]3>0:k<bP2`c/`0/m;=0;SBc`33emH0
dN7P0=o]k@3`l?00bl_;0;6a/@3bl_820?ooo`030?clo03no_h0oooo01l0
oooo00080?ooo`0=0?omoP3oood0moWf0?Kgn@3bloL0kno_08b9P02@SGX0
Yin:0;N_VP38`:/0c/Ja0<o7/P020=38/`030<o7/P3>b;80c/Rb01H0c/Rb
103?b;D60=39]P80dLZg0`3BbkP0103Cc;T0dlbj0=?<^P3Cc;X30=C=^`80
eLjl00@0e<fk0=G>_03Ec[`0eLjl0P3Fckd20=O@_P<0eM2m0`3FdKh20=OB
_`P0em71>03Je<@0103Idl<0f=;20=OA`@3Idl<20=_Ea@030=[Da03Idl<0
f=;200L0f=;20P3Idl<30=SB`P80fM?300T0f]C40>7Nc`3Sgm<0kncS0?7`
j`3Nh=/0K75[0:bcZ`2g_[H00`2la[/60;g7_0<0_/Rm0P2obKh20<3:_`@0
`LVn0P32b[l20<?;`0040<;9`@33b/80`l[20<?:`P80a<_31@35c<@20<K=
a@H0alk60`38clL60<W@b080b]79B`3;d/X04P3:dLT0bm;:0<gDc03?e/h0
c]G=0<_BbP39d<P0c]K;0=3EcP3Si=h0j>OU0?3`l03Lh^80H6i^09FXYP2W
`;d0Z<6n0:W2_`@0Z/?02@2Y`[l80:[3`080[<G20P2]a/<40:k7a0<0/LO5
0P2bb<H70;?9a`80]<[80P2eblT40;O;bP80^<c;0P2icL`0102hc</0^Lg<
0;W=c02icL`20;[>c@X0^lo>B@2mcll03`2odM40_]3@0;k@d02odM40_]3@
0<3BdP37fMT0e>3N0>3Zj@3UkNl0dMWL06=aLP2H[Jh0Xl?20:_?c@0@0:K8
b@80YlW:0P2Xb//30:W;c0030:[<c@2/c</0[<c;0080[<c;0P2]cL`20:k>
c@<0[Lg<0`2^c/d20:o?cP@0/Lo?0P2bd=020;?Ad@040;??d02dd=40]=3A
0;C@d@80]M7B1@2fd]<20;OCe0<0^=CED02je=D03@2nf=L0^MKD0;_He02k
eM80a=[H0=GXiP3Pk^h0j?;c0=[JfP2ATI40h>3P0?clo03no_h00P3oool0
0`3no_h0oooo0?ooo`0N0?ooo`00203oool0403ln_d0oOgk0?cnn@3mooh0
nO[n0?Kfn02=RX<0W9V80;>]U`33_JL0dlbi0=[C`03Ke<80fmC40=cEa@3K
e<@H0=[E`P@0fmG51P3Le/H30=gGa`<0g]S80P3Nf<X30=oIb`L0h=[<0`3Q
fld00`3Rg<h0gmc=0=oLc@020=oLc@@0h=g>203Pg=0i0>7Md@070>CPe03W
hmL0i^;F0>7Md@3Nf/h0h=c@0>CPe00>0>?Od`80i>3D00P0k^[N0>[Xg03e
l^/0j^WT07n1O02Y[ZP0alc60<oFcP<0c=?;1P3=e<`30<kEc@@0cmK>0P3>
eLd30<oFcPH0d=O?0`3Af=020=;Id@<0dmSB103DfM<00`3Ef]@0e=WC0=CI
d`030=GJe0H0e]_E0`3Gg=H20=SMedX0emcF0P3HgML0303Cf=80dMK@0=KK
e@3Nhmd0fn;J0>;Wh03SiN00mOGc0>?Ui01jPh80U::R0<7DdP<0_];A0`2o
dm8:0;kBd@`0_m?B1030e=<30<;Ed`<0`mKD0P34emD20<?Fe0<0a=OE0`35
f=H20<OGeP<0b=SG1P39fMP30<[JfE80bm_J0P3;fMT03P3<f]X0c]cL0<kL
g03;fMT0c]cL0=WWi`3SjNT0joCc0>?]k01ePh<0W;2_0;[BdP31fmX0]]?A
402kemP30;[Fe`<0^mOH0P2lf=T30;kHe`<0_mWH0P30f]T40;oIf0<0`=[I
00@0`M_J0<;JfP32f]X0`][J0P33fm/70<CLg0<0aMgM00<0a]kN0<SMgP38
gMh00P38gMh40<WNg`P0b]oPB039g]l02`39gM`0c>3O0<kRh@3=hN00d^GS
0>7]k@3Vk_00hnS[09FEU@3Cdm<0o_kn0080oooo00<0no_k0?knoP3oool0
803oool000P0oooo0100ooko0?gmn`3noo/0n?[i0?gno`3oool0RHJ10:jZ
WP30^jL0cLRd0=cGa03SgLl0i=kB0>CMd`3TgMD0hmcD603Rg]860>?Od`L0
i>3D0`3UhMD40>GQePL0i^;G1@3WhmP30>STfDH0jNGJ00D0i^;G0>GQeP3W
hmP0jNGJ0>[Vf`020>WUfPh0j>CI0P3YiMX0203^jn80n_O`0>o^j@2KViT0
Z:RV0=WKf03JgmT0emcE1P3FgMD70=ONeP<0f=oG1@3JgmP30=_Pf@@0fn3J
1`3LhM/70=gRg0@0g^?M1`3Oi=h30>3UgdP0gnCN0140h>GO0=oTgP3Oi=h0
hNKP0>;Wh@3Qi^00g^?M0=cQf`3Mi=d0j_7Z0?7flP3Zk>T0TYJE09fVY@3<
f=P0cmgM0<gKf`020<cJfP<0bmWI0P3<f]X80<_If@P0c=[J00<0cM_K0<kL
g03>g=`00`3>g=`40<oMg@D0d=kN0`3Agml40=;Ph080dn7Q1@3EhN470=KR
hU@0en?S0100e^;R0=OSh`3Fh^80e^;R0=OSh`3Fh^80fNGU0>7]k@3`lO<0
iN_[08bHUP2S][@0bMoL0<OMf`3?hn80b]cL2038gMh80<WNg`<0b]kO1@3;
gn000`3;gmh0c>3O0<cPg`030<cPg`<0cN7P1@3>h^420<oShP80d>;R1@3A
hn<00`3Bi>@0dN?S0=;Ti0040=;Ti0H0dnGU103Di^I@0=KViP0?0=KTi@3J
j>T0c]cL0>3^kP3Sknl0jO;a0>c`l@2PXJ<0`L710?ooo`3jn_X0oooo0?[j
nP3oool0moOg0240oooo00080?ooo`0>0?cjo`3no_`0o_ok0?Wkn03in_`0
no_m09VETP2h]:/0d<jo0=WGb03ShM@0inGI0>KSfP3Vhmh20>KRgaP0i^?J
1P3Wi=d=0>SUgPX0jNKO0`3Zin080>WYh@P0jNSS>03ZjN@20>WXh`030>[Y
i03/jnH0jn[U0080jNSS00<0jn[U0>[Yi03ZjN@01P3ZjN@00`3[j^D0j^WT
0>[Yi0020>[Yi080jn[U00T0k>_V0>o^j@3/jnL0[jj/0:BTY03Ogml0h>;O
0>3Rg@3Lg]T00`3OhMh:0>3Rg`<0hN?P203PiN420>3Ug`H0hNKP103SiN8:
0>CVhe80iNOT01<0i>KS0>SZi`3Xj^L0hnGR0>;Th@3Vj>D0inWV0>CVh`3]
l^h0gnCP0>kck`2WZjX0XjNV0=OMg@3Gh=l0eMoP0=WSi03Hh^<0en7R00<0
e^3Q4P3GhN830=SRh`D0fN?T0P3Jhn860=_Th`H0g>GT303Mi^EF0=kWiP0@
0=oUi@3Rj>P0gnGU0=gSh`3Pi^H0i>[Z0>G[j`3Vk>`0k>[]0:j_/@2OZJP0
c=cI0=3Sg`3Chn00e>3P0=OQhQ00en?S203Fi>@30=STi0D0fNGU1`3Ji^H6
0=_Wi`<0g>SX1`3MinP00`3Nj>T0gNOX0=kXj@1F0=kXj@0:0>7Vj@3OinT0
jO7c0=_Th`3/l_80iNWZ0;:b/P32`<40oooo0?Shn080oooo00@0n_[j0?oo
o`3oool0o?cl803oool000P0oooo00`0ooko0?ooo`3ko_L0o_ok0?koo`3o
o_l0]K6`09RCS@28R800Rh^308f=Q@2=S8L208b;Q`80SHb:702<RhLG08f<
R0D0SXf9B02=S8P01`2>SHT0T8n;08j=R@20Og/0IfIR055@C01:BDD03`1>
CDT304m>BP0704i=B`1UIFD0TY:D08b<SP2;Rh/0R8Z708b>R@0208V;R1d0
RXb900<0Rhf:08Z<R@2:S8T00P2:S8UL08^=RP0=08V;R02=Sh`0Q8J306Y/
J@1BE540Bde:04i@C@1?DDh0B4Y905=EE01?DE00IVQW08b@T@0208Z>S`03
08N;S02:SXl0RHf>0080R8b=00@0Qh^<08R<S@28S8d0R8b=2029SHh808R<
S@<0Qh^<3@28S8d308N;S1@0R8b=00<0RHf>08R<S@28S8d0CP28S8d01P2=
TI80PhN806]_L01AEEH0B4a=04U=CP80BTi?00P0Cde@06IVJ026S8`0R9:A
08^EU020RhL0Ri6?08V=S0P0Qhf=2028SXh@08N=S@<0QXb<3@27SHd208R<
S@H0RHf>2028SXh808V=STP0R8b=00T0TI:D08:6Q`21QhL0S9:B08Z>S@2>
T8l0_kfn0?ginP3lo?`00P3oool01@3lo?`0oooo0?[jnP3oool0o?cl0200
oooo00080?ooo`050?cio`3oool0o?oh0?cnn@3jnod00P3oo_l00`3on_L0
ooom0?ooo@060?oooCh0oooo2P3no_hh0?gmo@030?ooo`3no_h0oooo0080
oooo00<0o_kn0?gmo@3oool03@3no_h30?ooo`080?ooo@3lo?`0oooo0?[i
oP3jn_`0oooo0?ooo@3nooX@0?ooo`P0o_oo203nooeP0?ooo`050?gmo@3o
ool0oooo0?gmo@3lo?`00P3oool0103moOd0ooko0?_inP3jn_`20?koo`03
0?cloP3oool0oooo0080oooo5P3no_l`0?ooodP0o_oo0P3oool00`3moOd0
nOWi0?clo0030?ooo`80ooko00H0o_kn0?Khm`3inoX0o_oo0?_kn`3no_`8
0?knoXP0oooo00/0o_ko0?koo`3lool0noon0?cno@3lo?`0ooom0?ono@3n
o_h0oOgm0?_kn`030?knoP030?_kn`3oool0oooo01l0oooo00080?ooo`08
0?omo`3no_h0o_oj0?gon@3nool0o?_o0?kio@3ooOd20?glo`060?gmo`3n
o_l0oooo0?ooo`3no_`0oOgk603mo_l30?kno`/0oooo4P3no_m90?koo`07
0?_loP3in_`0oOko0?gno`3ko?h0o?go0?koo`080?gno`030?koo`3mo_l0
oOko0080oOko0`3nool00`3lo?`0oooo0?glo`020?ono`030?ooo`3moO/0
oook00H0oogo0P3oo_l80?omo`l0oooo6@3no_i80?ooo`D0o_kn00@0oooo
0?knoP3moOd0ooco0P3oo_l01@3knod0oooo0?cjo@3oo_l0oo_o01P0ooko
403ooOh00`3oo_l0oogn0?omoP050?omoPl0ooko2@3ooOi80?ooo`030?gk
o03oo_l0ooko0080ooko00T0oogn0?klo@3oo_l0oogo0?omoP3oo?d0ooko
0?omoP3onoX00P3ooodF0?ono`80oogn203ooO`80?ono@h0ookoFP3ooOh0
1@3lo?h0oooo0?gooP3lool0o_oo0080ooom00@0oogl0?clo03oool0no_k
0P3oool00`3lo?`0oooo0?[jnP0P0?ooo`00o`3ooooo0?ooojX0oooo003o
0?ooool0ooooZP3oool00?l0ooooo`3ooonZ0?ooo`00o`3ooooo0?ooojX0
oooo003o0?ooool0ooooZP3oool00?l0ooooo`3ooonZ0?ooo`00o`3ooooo
0?ooojX0oooo003o0?ooool0ooooZP3oool00001\
\>"], "Graphics",
  ImageSize->{680, 108},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Exploration of some sort has always been an important part of the \
scientific method.  In the last few decades, with the advent of exponentially \
increasing available computing power, scientific exploration has tended to \
become more quantitative.\
\>", "Text"],

Cell["\<\
Increasing numbers fields are using mathematics and \
statistics.\
\>", "BulletedList"],

Cell["Emphasis is on usable mathematics, not proof.", "BulletedList"],

Cell["\<\
When Einstein published his theory of relativity 100 years ago the \
level of computing available was primitive by today's standards.  He worked \
out the bulk of the theory through complex symbolic computations done by \
hand.  A remarkable achievement looking back from today's perspective.  \
Symbolic computations still have an important place in setting up models, but \
nowadays, there is very often a transition point to do more numerical \
quantitative calculations that can be used to explore models and ideas that \
become unwieldy as formulas.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(\(Mathematica\)\(\ \)\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "When Stephen Wolfram designed the first version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " nearly 20 years ago, he had the vision that to do the most effective \
exploratory work with computers, you needed a system that could do both \
symbolic and numerical computations in an interactive environment.  \
Furthermore the system was designed with a strong emphasis on the ability to \
communicate results, through visualization with innovative graphics, through \
technical documents,  and through communication with other programs."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000::0001`2000`400?l0
0000o`00003oo`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0
ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03o
ool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0
ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o
0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0
oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo
0?oooh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00
o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<
0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0oooo
o`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool0
0?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0oooo
S03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?oo
ool0ooooS03oool002P0ooooZ03no_h80?ooo`030?gmo@3no_h0o_kn0080
o_kn0`3ooonX0?knoP030?gmo@3no_h0o_kn0080o_kn00<0oooo0?knoP3n
o_h01@3no_j;0?ooo`H0o_knI03oool002@0oooo103no_ko0?ooool0oooo
@P3oool80?knoQX0oooo000T0?ooo`@0o_kno`3ooooo0?ooo`80o_kn@03o
ool80?knoQX0oooo000X0?ooool0o_knH@3no_h20?ooo`H0o_kn1`3oool0
0`3no_h0oooo0?ooo`2;0?ooo`80o_kn00<0oOgm0?knoP3no_h0?P3no_h4
0?ooo`80o_kn703oool00=00oooo403no_jY0?ooo`80o_kn0P3moOd20?kn
oP030?ooo`3no_h0oooo00D0oooo00<0o_kn0?ooo`3oool0QP3ooom80?kn
oP<0oooo0P3no_hM0?ooo`008P3oool20?knoP<0oOgm00<0o?cl0?knoP3n
o_h0YP3no_h=0?gmo@<0o?clZ03no_h00`3moOd0o?cl0?clo0020?clo003
0?gmo@3no_h0o_kn0080oOgm00<0o_kn0?ooo`3oool00P3oool00`3no_h0
oooo0?ooo`260?ooo`030?knoP3moOd0oOgm00@0o?cl@@3moOd50?clo003
0?gmo@3no_h0oooo01X0oooo000Q0?ooo`070?knoP3moOd0o?cl0?[jnP3i
nOT0n?Sh0?Ogm`2e0?Shn0<0moOgZ03hn?P30?Ogm`080?KfmP3gmoL0n?Sh
0?Win@3jn_X0no_k0?clo03moOd40?ooo`030?knoP3oool0oooo08H0oooo
00@0o?cl0?[jnP3inOT0moOg0`3fm_H00`3gmoL0m_Kf0?KfmP0n0?KfmP80
mOGe00H0m_Kf0?Ogm`3inOT0no_k0?gmo@3no_hJ0?ooo`008@3oool01`3n
o_h0oOgm0?_kn`3hn?P0m_Kf0?Cdm03clo<0Z03alO480?;blP@0lo?c103b
l_:X0?7al@0<0?;blP3alO40lO7a0?7al@3bl_80lo?c0?Gem@3fm_H0n_[j
0?_kn`3moOd0o_kn0`3oool00`3no_h0oooo0?ooo`260?ooo`060?Shn03g
moL0m?Cd0?7al@3`l?00kno_@P3`l?00203_knl0l?3`0?7al@3clo<0mOGe
0?Win@3lo?`0o_kn6P3oool00200oooo0P3no_h01P3lo?`0moOg0?;blP3/
k>`0jNWY0>OWi`80j>SZ00H0j^[/0>KViP3YjNT0j>SX0>GUi@3Zj^ZP0>OY
i080j>[U0`3WjN@0203YjnH0j^cW0>_]j03YjnP0j^cY0>_]jP3Zk>T0jN_X
0P3WjNH02@3Xj^L0i^c/0>G[j@3Vj>D0inOW0>KViP3Vi>D0j>SV0>c]j01`
0>SZj@P0jN[U203YjNT20>W[jP@0j>[Y0P3WjNP70>SZj@T0inWX1`3YjN/0
103Xj>X0inOY0>SXjP3YjN/20>SXjP0;0>WYj`3/k>h0knoa0??im`3fn_/0
nO[l0?koo`3koOX0o_ok0?[on@3koo/00`3no_h40?ooo`030?knoP3oool0
oooo07H0oooo00@0o_kn0?ooo`3no_h0o_kn0P3oool0103moOd0nOWi0?Ge
m@3`l?020>[ZjP0<0>OWi`3Xj>P0inOW0>GUi@3XhnL0j^GY0>_Wj03Vi>D0
iN?T0>OVi03WinD0i^KT>03ZiNT20>_VjP0>0>cWj`3^jNd0lnkb0?Scm`3n
nOd0oogo0?oon`3oo_l0o__o0?glo`3moOd0oooo0?koo`3knolB0?ooo`00
8@3oool0203no_h0no_k0?KfmP3_knl0jNWY0>GUi@3Shn<0iNGW0P3QhN40
1@3Ph>00hn?S0>KViP3Ti>80hN7O0:00hN7Q0P3Ph>020=oOg`080>3Ph03Q
hN40h^;R0>?Sh`3Xj>X0inOY0>GUi`3Ti>H40>?Si@080=oQg03Ph=h0hN3N
0>GSi03YiNH0j>CU0>GQh03Pgm]`0>;Qg`P0h]oV203RhMl20>?Rh0@0h^7O
0P3Qh=h50>CSh@/0hn;P203ShN80403Rh>40hn7R0>?QhP3ShN80h^3Q0>CR
h`3Xi^L0k>[[0??elP3jn_P0oOgm0?ono`3lnoT0oOcj0?_lm`3ooo/30?kn
oP@0oooo00<0o_kn0?ooo`3oool0MP3oool0103no_h0oooo0?knoP3no_h2
0?ooo`0;0?gmo@3inOT0m?Cd0?7al@3Xj>P0iNGU0>7Qh@3Ng]h0h^;R0>CT
i03Qh=h00P3Sh^001@3Qh=h0h>3N0>7Rg@3Rhmh0hN;M03P0hN3N0100h=oM
0>7PgP3Sh^00inKT0>g/jP3dlo40no[h0?kmn`3mo_P0o?cl0?ono`3oool0
oook0?cmm`3jo?T0o_oo4P3oool00240oooo00l0oOgm0?[jnP3dm?@0kNg]
0>GUi@3Ph>00g]kN0=WIf`3MgMd0gmoO0=kNg03If=H0fm[F0>3Of`3Kf]D0
X03Ng>430=oMhP030=kLh@3OgN80h=kS0080hMoT103Rh><01`3Qgn80h=kQ
0=gKgP3KfM`0e]G@0=3?c@3;bL`00P36a<T00`39alX0blW<0<_9c01`0<[8
b`P0b/S92039alX50<[8b`@0bLO:1`3:b</30<W7bPD0b/S;2@39alX02`3:
b</0bLO:0<W7bP39alX0blW<0=3>d@3CdM@0f=SH0>3Ph03Ti>@0jn_]0080
j^S]00@0kng^0?_jn03moOd0o_kn1@3oool00`3no_h0oooo0?ooo`1f0?oo
o`040?knoP3oool0o_kn0?knoP80oooo00X0oOgm0?Win@3_knl0jn_[0>7Q
h@3Ogml0gMgM0=_Kf`3Ogml0fMWI0P3=cLd00`3;cL`0b/c;0<[<b@020<W>
bP030<S=b@3<c//0c<k;03H0c<k;00l0cLo<0<k@c@3@d/l0d]CA0=KHe@3K
gMX0gn7N0>7Sh03Yk^P0hnOX0>GVjP3Si>H0o?oh0?kon03loOL04`3oool0
0240oooo00l0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=gMg`3Hf=P0
];Bb09RGT`1oOWT0N7E^07YgKP1hM6/0X`1kMgH00`1jMWD0NgMf07]gMP02
07ahM`<0OW]f00d0OGYe07]hL`1jMg80NgQc07aiM01QHf00I6EZ06e_O01_
LX<0KG>106idP01]L7l0K6n00700Jg5m201^LgT806eaO@P0KW9n1`1]LGd0
0`1^LWh0KG5m06eaO@0206eaO@@0KW9n00<0KG5l06ibO@1^LWd02P1^LWd0
3@1`M7l0LgN207EiQ01jOXT0Nh::07QoQ`1lPXh0P8>F0821T`28R9@0T96F
0?_kn`3no_h00P3oool0103no_h0oooo0?ooo`3no_ih0?ooo`040?knoP3o
ool0o_kn0?knoP80oooo0180oOgm0?Win@3dm?@0j^[Z0>3Ph03Ng]h0g=cL
0=_Kf`3IfMT0/k>c08N:T@26RI00QHR?08>8SP24R940QXZC08B;T`23RY8h
08B9S@80PhR<0P22Qh/02`23R8`0Q8V=08B9S@25RXh0PHR>08B;U@29SIT0
UYVP0;Zn_@3mooT0oook01<0oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0gMgM0=OGe`2LViT0PX5l085nM@24P7D0RXAh
08^5MjH0QX9f0P27PgL04024PG80QH9c08J3M026Pg@0RXMh09FBP`2UXY<0
/JjO055IG01;E6<0CEQd04UHM`15EW80BUYd04YIMP1<FGa`04]KM@P0C5]l
201=GGL804iNN0@0Cemi2@1@H7X3055QN`<0DV1j1@1CHG/00`1BH7X0Df5k
05ARO00305ARO00=05ESO@1FI7h0EF=m05MVN`1DIGT0FVZ406AcU01^N9/0
OXJM08>9U`3jn_X0o_kn0?ooo`020?knoP80oooo00<0o_kn0?ooo`3oool0
MP3oool0103no_h0oooo0?knoP3no_h20?ooo`0@0?gmo@3inOT0m?Cd0>OW
i`3QhN40h>3P0=[JfP3MgMd0fMWI09JFUP1`MHP0KW>706edQ`1_MXT0LGN=
075iSP80LWZA>01`N8/6079jS@80LGV<00P0N82C08F=Y02:T:P0V9f`09JI
X03ko?h0oooo0?kmoa80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3/
k>`0i>CT0=oOg`3MgMd0f=SH0=WIf@2GUY80Q85j08V5NP2;QGL0THYh09B=
Nj00UY5m202HTgl0402JUGl0ViJ009^FP02JUGl0WYV30:ZUS`2l]j40bLB^
05EOJ017Df/0BER104MLQ`1:HXP0DFV=051VS`1BI9I`04iTS@P0CfB?201@
IXl5055WT0<0DVRA0`1BJ8l305=YT080E6ZA0`1CJI0205AZT@<0EF^B00<0
Ef^@05Q/T@1HK9400P1HK94305U]TP0305Q/T@1IKI80FFfB0080FVjC0`1I
KI803@1HJI@0FVjA05U`T01KLiT0IgbY07R6/`2<UkD0QXnN0?Win@3moOd0
oooo0?knoP3moOd00P3oool00`3no_h0oooo0?ooo`1f0?ooo`040?knoP3o
ool0o_kn0?knoP80oooo0180oOgm0?Win@3_knl0iNGU0>;RhP3Ogml0f=SH
0=cLg03Ng]h0Shn?06ieT@1_MY80M7^G07N0W@1kQ:<0OHJW07b7Y`1mR:Ph
07b7Y@80NhJT1P1lQjD02023SZ`0TIbl09bUaP2b^=00SY:N0?koo`3oo_l0
oogo4P3oool00240oooo00l0oOgm0?[jnP3clo<0k>c/0>CTi03Ogml0g=cL
0=gMg@3Ng]`0UYFA08J3NP29PgL0ShQf0::JQ`2[Xhh0X02/YY080:^US`0@
0:VSS@2ZY8h0ZjF?0:fWT@2b[9H0_;JP0<W3[@3Bc;H0EEaR04A>I`19F8<0
CV:D05A]UP1LMY/0Fg2M05e^YW00G7:S201NLih905mcY@D0H7BV0P1QMJL3
061eY080HGJU0`1RMjH2065fY@80HWNV101SN:L206EgY@80IWRV1`1WNJL5
06QjZ00=06]h[@1YO:H0JX2U06^2[01hS;h0SI_:0:2YaP27T9T0n?Sh0?gm
o@3oool0o_kn0?gmo@020?ooo`030?gmo@3oool0oooo07H0oooo00@0o_kn
0?ooo`3no_h0o_kn0P3oool03`3moOd0nOWi0?;blP3Zj^X0h^;R0=kNgP3J
f]X0f=SH0=[JfP2?Shl0KGVC079nV01lQj<0Qi:`08^H^00208bI^`0308fJ
_@29V;T0RIRi03H0RIRi0`2;V[/508ZI^P08096P_`2LZL/0[;OG0;_3fP2<
Tid0o?oo0?clo03no?lB0?ooo`008@3oool03`3no_h0n_[j0??cl`3[jn/0
i>CT0=kNgP3Lg=`0fm_K0=OGe@2AT8/0S8Qo09>=O`2OV8H0]ZjI0;^`VP2P
0;jfX@P0_kNR0100`[VX0<2gYP2n]J@0`;NV0<Nn[@3BbKP0gMC30>CKbP1L
H6<0CE5Z05EPS@1MKj40GgJP06InY01WNJL0K7^dL01YNZh806Yk/`P0Jgb`
101]OK4406in/P0406mo/01`P;40L82a0720/@80LH6b0P1bP[<30761/P80
LX:c0`1cPk@0101bPk40LhBb07>4/P1cQ;8207B5/`@0MHJd00<0M8Fc07F6
]01fQkD00`1gR;H03@1mQ[l0NHNd07R</@1jT;T0SYkA0:F`gP2d^]@0SI2E
0?Ogm`3moOd0oooo0?knoP3moOd00P3oool00`3moOd0oooo0?ooo`1f0?oo
o`040?knoP3oool0o_kn0?knoP80oooo0180oOgm0?Win@3alO40jn_[0=gM
g@3Kfm/0hN7Q0=[JfP3IfMT0U9BD071lU01hQ9`0QI>]09>Q_02KZLH0Vj[9
09ZYb02JZLXj09ZZb`@0VJW:0P2JZ//0202Q//h0[kkM0<;=j`2oamX0SYFK
0?_onP3oooX0oook4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU
V038`:T40<NoZ0@0b<2Y00<0aknX0<S0Z@38`:T01@38`:T04038`ZX0b/:[
0<_1Z03<`J/0clNb0=SA_`3Mf//0h=kB05eQI019DgL0DfJA05YdV@1VNk00
K7nj06^1/`1XPKMP06Z1]``0Jh2g101/PKP406b1]PD0KH:g1`1^PkP00`1^
Q;H0KhFg06n5]`0506n5]`030726^01aQkT0LHNi00D0LHNi0`1cQkT207B8
^PH0MHVk0P1fR[`307N;_@<0Mhbk0P1hSK`307V>_@0<07V>^`1iSL00O8jn
08NI_`2P[]40/;[N0;c2f02;THl0n?Sh0?knoP3oool0o_kn0P3oool00`3m
oOd0oooo0?ooo`1j0?ooo`0A0?knoP3oool0oooo0?clo03hn?P0lO7a0>SX
j03QhN40g]kN0=[JfP3IfMT0fm_K096AT@1fOIL0OXRS08ZH]@2HYlP00P2O
[m400`2P[]40XK3A0:2^d@0o0:2^d@080:Zje02jaN40aLcV0<g@h@2ATYH0
oook0?kno03no_lB0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[
0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:FH
0<S0Z@@0aknX2P38`:T20<W1ZP0@0<S2ZP3:`Z/0bl6X0<c1Z`3?ak80f=6o
0=gJb`3Pg]80GF5T04UCM`1CIY40FWBI06Ik/01/OkX0Jh6c06R1]f00JX6g
301[P;L406b1^0@0K86f101]P[L606j3^080KhBi1P1_QKL20726^0H0LHNi
0P1bR;X207>7^@<0M8Rj1@1eRK/307J:_0<0Mh^m0P1gS;/307R=_0<0NHjm
00`0NXnl07V=`01lS[h0QiVo0:2^d@2`^]h0_<;H08^AS`3hn?P0o_kn0?oo
o`3no_h20?ooo`030?gmo@3oool0oooo07X0oooo0140o_kn0?ooo`3oool0
o?cl0?Shn03alO40j>SX0>7Qh@3Ng]h0f][J0=WIf@3Kfm/0TI6A07ImU`1n
R:<0RYRe09RWb00209n_d@030:2^d@2Q/=40X:kA03l0X:kA00P0Z[[D0;[5
h@35c>H0cM3Q096BUP3ooo/0o_kl0?knoa80oooo000P0?ooo`0@0?knoP3m
oOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VD
P@2XXX`0^k>L0<BlYIP0b<2Y0`37_jP:0<S0Z@<0bL6Z0100b<:Z0<[2Z`3;
`JP0c<6[0<o7/P3HdKl0gM[;0>3NdP1MHF@0BE=g05=VT@1JM9T0IW^`06ao
^P1[PK<0J86gH01ZPKL;06^0]`D0K86h0`1/PKH506f2]`D0KX>h0`1_Q;T4
06n5]`@0L8Jh101aQkT407:8^P0407>7^@1dR;X0M8Rj07B8^PD0MHVk0`1f
R[`407N;_@0407N<^`1hSK`0N8fl07R=_0@0NHjm00`0NXnl07Z>`@1mSkl0
R9[00:2^d@2`^]h0_<;H08^AS`3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo07X0oooo0140o_kn0?ooo`3oool0o?cl0?Shn03alO40j>SX
0>7Qh@3Ng]h0f][J0=WIf@3Kfm/0TI6A07ImU`1nR:<0RYRe09RWb00209n_
d@030:2^d@2Q/=40X:kA03l0X:kA00P0Z[[D0;[5h@35c>H0cM3Q096BUP3o
oo/0o_kl0?knoa80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYIP0
b<2Y0P37_jP:0<S0Z@@0bL6Z0100b<:Z0<[2Z`3;`JP0c<6[0<o7/P3HdKl0
gM[;0>3NdP1MHF@0BE=g05=VT@1JM9T0IW^`06ao^P1[PK<0J86gH01ZPKL:
06^0]`H0K86h0P1/PKH606f2]`@0KX>h101_Q;T306n5]`D0L8Jh0`1aQkT5
07:8^P<0M8Rj0`1eRK/507J:_0<0Mh^m0P1hS;h307R=_0<0NHjm0P1jSkh0
301jSk`0NXk107f?_`28V/00XJoB0;2jgP2l`]P0Ri6?0?Shn03no_h0oooo
0?knoP80oooo00<0oOgm0?ooo`3oool0NP3oool04@3no_h0oooo0?ooo`3l
o?`0n?Sh0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG07j8
X`2:V;D0V:O80080WjoA00<0X:kA0:6`d@2P[]40?`2P[]40202Z^]@0^/GQ
0<G<iP3=d>40TI:F0?oon`3no_`0o_ko4P3oool00200oooo0100o_kn0?gm
o@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB1
0:RRS02k/i`0a;bUWP38`:T20<W1ZP@0b<2Y1039`JX04038`ZX0b/:[0<_1
Z03<`J/0clNb0=SA_`3Mf//0h=kB05eQI019DgL0DfJA05YdV@1VNk00K7nj
06^1/`1XPKMP06Z1]`P0Jh2g1P1/PKP206f2^@H0KH:g1P1^PkP406n4^@D0
L8Jh0`1aQkT507:8^P<0LhVk0P1dR;X307F9^`D0MXZl0`1gRkd307R<_P80
N8fl0`1iS[d307Z?_P0<07^@_@1kSl80OHno08RJ`02Q[m80/;[N0;c2f02;
THl0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1j0?ooo`0A
0?knoP3oool0oooo0?clo03hn?P0lO7a0>SXj03QhN40g]kN0=[JfP3IfMT0
fm_K096AT@1fOIL0OXRS08ZH]@2HYlP00P2O[m400`2P[]40XK3A0:2^d@0o
0:2^d@080:Zje02jaN40aLcV0<g@h@2ATYH0oook0?kno03no_lB0?ooo`00
803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3J
f]X0UIB?08Z8N`2IU840Z::<0;^cW034_:FM0<S0Z@<0bL6Z0`38`:T50<W1
ZP0@0<S2ZP3:`Z/0bl6X0<c1Z`3?ak80f=6o0=gJb`3Pg]80GF5T04UCM`1C
IY40FWBI06Ik/01/OkX0Jh6c06R1]f00JX6g201[P;L506b1^0<0KH:i1@1]
P[L606j3^0D0KhBi101`Q[P40767^@@0LXRj101cRK/407F9^`<0MXZl1@1g
Rkd307R<_P0307V=_`1iS[d0NHjm0080NHjm0`1jSkh03@1kT;l0Ni2m07^?
`P1nT<00R9[00:6_dP2`^]h0_<;H08^AS`3hn?P0o_kn0?ooo`3no_h00P3o
ool00`3moOd0oooo0?ooo`1j0?ooo`0A0?knoP3oool0oooo0?clo03hn?P0
lO7a0>SXj03QhN40g]kN0=[JfP3IfMT0fm_K096AT@1fOIL0OXRS08ZH]@2H
YlP00P2O[m400`2P[]40XK3A0:2^d@0o0:2^d@080:Zje02jaN40aLcV0<g@
h@2ATYH0oook0?kno03no_lB0?ooo`00803oool0403no_h0oOgm0?Win@3c
lo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^c
W034_:FL0<S0Z@@0bL6Z0P38`:T60<W1ZP0@0<S2ZP3:`Z/0bl6X0<c1Z`3?
ak80f=6o0=gJb`3Pg]80GF5T04UCM`1CIY40FWBI06Ik/01/OkX0Jh6c06R1
]f00JX6g201[P;L406b1^0@0KH:i101]P[L606j3^0H0KhBi0P1`Q[P60767
^@80LXRj1P1cRK/307F9^`<0MXZl1@1gRkd307R<_P80NHfo0`1iS[d307Z?
_P80Ni2o00`0O96n07^?`P1nT<00R9[00:6_dP2`^]h0_<;H08^AS`3hn?P0
o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo07X0oooo0140o_kn0?oo
o`3oool0o?cl0?Shn03alO40j>SX0>7Qh@3Ng]h0f][J0=WIf@3Kfm/0TI6A
07ImU`1nR:<0RYRe09RWb00209n_d@030:2^d@2Q/=40X:kA03l0X:kA00P0
Z[[D0;[5h@35c>H0cM3Q096BUP3ooo/0o_kl0?knoa80oooo000P0?ooo`0@
0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0
RXQk09VDP@2XXX`0^k>L0<BlYI`0b<2Y2`39`JX04@3:`Z/0b<:Z0<[2Z`3;
`JP0c<6[0<o7/P3HdKl0gM[;0>3NdP1MHF@0BE=g05=VT@1JM9T0IW^`06ao
^P1[PK<0J86g0600JX6g201[P;L406b1^0@0KH:i101]P[L406j3^0L0KhBi
00<0L8Fj0767^@1aQkT01@1aQkT00`1bR;X0LhVk07>9^`0507>9^`0407B:
_01eRK/0MHVk07F9^`80MXZl1P1gRkd207R<_P<0NHfo0`1iS[d207Z?_P<0
Ni2o00`0O96n07^?`P1nT<00RI_10:6_dP2`^]h0_<;H08^AS`3hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo07X0oooo0140o_kn0?ooo`3o
ool0o?cl0?Shn03alO40j>SX0>7Qh@3Ng]h0f][J0=WIf@3Kfm/0TI6A07Im
U`1nR:<0RYRe09RWb00209n_d@030:2^d@2Q/=40X:kA03l0X:kA00P0Z[[D
0;[5h@35c>H0cM3Q096BUP3ooo/0o_kl0?knoa80oooo000P0?ooo`0@0?kn
oP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk
09VDP@2XXX`0^k>L0<BlYI`0b<2Y1039`JX80<[2Z`0@0<_0[03:`Z/0bL6Z
0<W3Z`3>b;80em:o0=oIb`3QgM40FemR04YDN01EJ9<0FWBI06Ik/01]P;/0
K8:d06R1]eP0JX6g201[P;L406^0]@P0K86f101]P[L406j3^0@0KhBi101_
QKL40726^0@0LHNi101bR;X0101cQkT0M8Rj07B8^P1dR;X307F9^`D0MXZl
101gRkd0101gS;/0N8fl07R=_01hSK`307V>_@D0NXnn101kT;l0301mT[d0
Nho107nA_`2;WL40XJoB0;6kg`2na=X0Ri6?0?Shn03no_h0oooo0?knoP80
oooo00<0oOgm0?ooo`3oool0NP3oool04@3no_h0oooo0?ooo`3lo?`0n?Sh
0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG07j8X`2:V;D0
V:O80080WjoA00<0X:kA0:6`d@2P[]40?`2P[]40202Z^]@0^/GQ0<G<iP3=
d>40TI:F0?oon`3no_`0o_ko4P3oool00200oooo0100o_kn0?gmo@3inOT0
lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k
/i`0a;bUW038`:T40<W1ZPP0b/:[0100bl2/0<[2Z`39`JX0bL>[0<k8/P3G
d[l0gmW;0>7Md@1LH6<0BUAh05EXT`1JM9T0IW^`06f0^`1/P[@0J86gF01Z
PKL806^0]`@0Jh2e201/PKH406f2]`@0KX>h101_Q;T306n5]`D0L8Jh0`1a
QkT507:8^P@0M8Rj0P1eRK/507J:_0D0Mh^m101hSK`207V>_@D0NXnn1@1k
T;l0301mT[d0Nho107nA_`2;WL40X[3C0;6kg`2na=X0Ri6?0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool0NP3oool04@3no_h0oooo0?oo
o`3lo?`0n?Sh0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG
07j8X`2:V;D0V:O80080WjoA00<0X:kA0:6`d@2P[]40?`2P[]40202Z^]@0
^/GQ0<G<iP3=d>40TI:F0?oon`3no_`0o_ko4P3oool00200oooo0100o_kn
0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0
VIB10:RRS02k/i`0a;bUV`38`:T50<W1ZPP0b/:[0100bl2/0<[2Z`39`JX0
bL>[0<k8/P3Gd[l0h=[<0>7Md@1MHF@0BUAh05AWTP1ILiP0IW^`06f0^`1/
P[@0Ih2fF01ZPKL806^0]`<0Jh2e201/PKH506f2]`<0KX>h1@1_Q;T206n5
]`H0L8Jh0P1aQkT607:8^P<0M8Rj0`1eRK/407J:_0H0Mh^m0`1hSK`307V>
_@@0NXnn1P1kT;l0301mT[d0Nho1082B`02;WL40X[3C0;6kg`2na=X0Ri6?
0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0NP3oool04@3n
o_h0oooo0?ooo`3lo?`0n?Sh0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0fMWI0=_K
f`2ATI40MWfG07j8X`2:V;D0V:O80080WjoA00<0X:kA0:6`d@2P[]40?`2P
[]40202Z^]@0^/GQ0<G<iP3=d>40TI:F0?oon`3no_`0o_ko4P3oool00200
oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J
09FDS`2:R7/0VIB10:RRS02k/i`0a;bUVP38`:T60<W1ZPP0b/:[0100c<6]
0<[2Z`39`JX0bL>[0<o9/`3Gd[l0h=[<0>;NdP1MHF@0BUAh05AWTP1ILiP0
IW^`06f0^`1/P[@0Ih2fF01ZPKL806^0]`80Jh2e201/PKH606f2]`80KX>h
1P1_Q;T50726^0<0LHNi1@1bR;X307>9^`80M8Rj0`1eRK/307J:_0D0Mh^m
0`1hS;h207R=_0<0NHjm0`1jSkh507^@_`<0O97000`0OI:m07^?`@20T/00
Rig10::`d`2a^ml0_/CJ08^AS`3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo07X0oooo0140o_kn0?ooo`3oool0o?cl0?Shn03alO40j>SX
0>7Qh@3Ng]h0f][J0=WIf@3Kfm/0TI6A07ImU`1nR:<0RYRe09RWb00209n_
d@030:2^d@2Q/=40X:kA03l0X:kA00P0Z[[D0;[5h@35c>H0cM3Q096BUP3o
oo/0o_kl0?knoa80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYIP0
b<2Y1P39`JX:0<[2Z`0@0<c1[@3:`Z/0b/:[0<W3Z`3?bK<0f=?00>3Jc03R
g]80G61S04YDN01DIi80FG>H06Ik/01/OkX0Jh6c06N0]UP0JX6g201[P;L6
06b1]PP0KH:g0P1^PkP606n4^@80L8Fj0`1`Q[P50767^@<0LXRj1@1cRK/3
07F9^`<0MXZl1@1gRkd507R<_P<0NHjm0`1jSkh507^@_`D0O97000`0OY>n
07^?`@20T/00S9k20::`d`2b_>00_/CJ08^AS`3hn?P0o_kn0?ooo`3no_h2
0?ooo`030?gmo@3oool0oooo07X0oooo0140o_kn0?ooo`3oool0o?cl0?Sh
n03alO40j>SX0>7Qh@3Ng]h0f][J0=WIf@3Kfm/0TI6A07ImU`1nR:<0RYRe
09RWb00209n_d@030:2^d@2Q/=40X:kA03l0X:kA00P0Z[[D0;[5h@35c>H0
cM3Q096BUP3ooo/0o_kl0?knoa80oooo000P0?ooo`0@0?knoP3moOd0nOWi
0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0
^k>L0<BlYIP0b<2Y1@39`JX;0<[2Z`0@0<c1[@3:`Z/0b/:[0<W3Z`3?bK<0
f=?00>3Jc03Rg]80FUiQ04UCM`1DIi80FWBI06Ik/01/OkX0Jh6c06R1]eP0
JX6g201[P;L506b1]PP0KH:g0`1^PkP506n4^@<0L8Fj1P1aQkT207:8^PH0
LhVk0P1dR[`207F9^`<0MXZl0`1gRkd607R<_P80NHfo0P1iS[d307Z?_P<0
Ni2o1P1lTL0207fB`@0<07jC_P1lT<80P9;008bN`P2R/=<0/[cP0;o5f`2;
THl0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1j0?ooo`0A
0?knoP3oool0oooo0?clo03hn?P0lO7a0>SXj03QhN40g]kN0=[JfP3IfMT0
fm_K096AT@1fOIL0OXRS08ZH]@2HYlP00P2O[m400`2P[]40XK3A0:2^d@0o
0:2^d@080:Zje02jaN40aLcV0<g@h@2ATYH0oook0?kno03no_lB0?ooo`00
803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3J
f]X0UIB?08Z8N`2IU840Z::<0;^cW034_:FH0<S0Z@@0bL6Z303:`Z/0403<
`Jd0bl>/0<[2Z`3:a:`0clVc0=SC`03Pf/`0h]kB05MKGP18DWH0EFRC05]e
VP1VNk00K7nj06^1/`1YP[QH06Z1]`P0Jh2g101/PKH806f2]`@0KX>h101_
Q;T40725^PD0LHNi0`1bR;X507>9^`<0M8Zl0P1eRK/207J:_0@0Mh^m1@1h
S;h307V=_`80NHjm0P1jSkh407^@_`D0O9700`1mT/40301nTkh0O932082B
`02<W/80X[3C0;:lh02oaM/0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0
oOgm0?ooo`3oool0NP3oool04@3no_h0oooo0?ooo`3lo?`0n?Sh0?7al@3X
j>P0hN7Q0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG07j8X`2:V;D0V:O80080
WjoA00<0X:kA0:6`d@2P[]40?`2P[]40202Z^]@0^/GQ0<G<iP3=d>40TI:F
0?oon`3no_`0o_ko4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU
V038`:T40<W1ZP`0b/:[0100c<6]0<_3[03:`Z/0b/B/0<o9/`3Hdl00h=[<
0>;NdP1FFUd0B59f05IYU01KMIX0IW^`06]n^@1[PK<0JH:hF01ZPKL806^0
]`@0K86f201]P[L406j3^0@0KhBi101`QKX40767^@@0LXRj101cRK/407B:
_00407F9^`1fR[`0MXZl07J:_0<0Mh^m1@1hS;h407V=_`0407V>_@1jSkh0
NXnn07Z?_P<0Ni2o1@1lTL0407fB`@0<07jC_P1lT<80P9;008bN`P2S/M@0
/[cP0;o5f`2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?oo
o`1j0?ooo`0A0?knoP3oool0oooo0?clo03hn?P0lO7a0>SXj03QhN40g]kN
0=[JfP3IfMT0fm_K096AT@1fOIL0OXRS08ZH]@2HYlP00P2O[m400`2P[]40
XK3A0:2^d@0o0:2^d@080:Zje02jaN40aLcV0<g@h@2ATYH0oook0?kno03n
o_lB0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0
g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:F00<S0Z@030<Jn
Y`37_jP0aknX00D0aknX2039`JX40<S0Z@@0bL6Z203:`Z/00`39`J`0b/:]
0<[2[@060<[2[@0?0<_3[P39`j/0b/B^0<o8]@3Id/00h=[<0>CNdP1BEUT0
C5Ij059UT01JM9T0IW^`06f0^`1ZP;80JH:h0500JX6g101ZOkH406^0]`@0
Jh2e1@1/PKH706f2]`@0KX>h101_Q;T406n5]`@0L8Jh101aQkT407:8^P@0
M8Rj101eRK/407J:_0@0Mh^m00@0Mhbk07R=_01hSK`0N8fl0`1iS[d407Z?
_P80Ni2o0`1lTL0307j@_P80Oi6o0`20T/003021U;l0P9;408:D`P2<W/80
X[7B0;Blh02oa]T0RY2<0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool0NP3oool04@3no_h0oooo0?ooo`3lo?`0n?Sh0?7al@3Xj>P0hN7Q
0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG07j8X`2:V;D0V:O80080WjoA00<0
X:kA0:6`d@2P[]40?`2P[]40202Z^]@0^/GQ0<G<iP3=d>40TI:F0?oon`3n
o_`0o_ko4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0
g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUP038`:T6
0<NoZ080b<2Y2039`JX40<S0Z@@0bL6Z203:`Z/60<[2[@80bl>^0100b/:]
0<_3[P39`j/0b/B^0<o8]@3Id/00h=[<0>CNdP1BEUT0C5Ij059UT01JM9T0
IW^`06f0^`1ZP;80JH:hD01ZPKL406Yo]P@0Jh2g101[P;D406b1]PH0KH:g
1P1^PkP406n4^@<0KhFg1@1`Q[P30767^@D0LXRj0`1dR;X507F9^`<0MXZl
1@1gRkd407R=_080NHjm101jSkh307^@_`<0O9700P1nT;h307nA_`<0P9;0
00`0PIBo082Ba022U<80S9k20::adP2d_>00_lKI08Z@S03hn?P0o_kn0?oo
o`3no_h20?ooo`030?gmo@3oool0oooo07X0oooo0140o_kn0?ooo`3oool0
o?cl0?Shn03alO40j>SX0>7Qh@3Ng]h0f][J0=WIf@3Kfm/0TI6A07ImU`1n
R:<0RYRe09RWb00209n_d@030:2^d@2Q/=40X:kA03l0X:kA00P0Z[[D0;[5
h@35c>H0cM3Q096BUP3ooo/0o_kl0?knoa80oooo000P0?ooo`0@0?knoP3m
oOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VD
P@2XXX`0^k>L0<BlYH00b<2Y1@37_jP30<S0Z@P0bL6Z0`38`:T50<W1ZPP0
b/:[1@3:`Zd30<_3[P0@0<[2[@3;`jh0bL>[0<[4[P3?b;D0fM;00>7Kc@3T
g]80DUII04aFNP1BII00FWBI06Ik/01]P;/0JX2b06V2^500JX6g0`1ZOkH5
06^0]`<0Jh2e1@1/PKH506f2]`H0KX>h1@1_Q;T206n5]`H0L8Jh0P1aQkT6
07:8^P80M8Rj1P1eRK/207J:_0H0Mh^m0`1hSK`307V>_@<0NXnn0`1kT;l4
07bA`00407j@_P1oTKl0Oi6o07nA_`@0P9;000`0PIBo082Ba022U<80S9k2
0::adP2d_>00_lKI08^AS@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3o
ool0oooo07X0oooo0140o_kn0?ooo`3oool0o?cl0?Shn03alO40j>SX0>7Q
h@3Ng]h0f][J0=WIf@3Kfm/0TI6A07ImU`1nR:<0RYRe09RWb00209n_d@03
0:2^d@2Q/=40X:kA03l0X:kA00P0Z[[D0;[5h@35c>H0cM3Q096BUP3ooo/0
o_kl0?knoa80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT
0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYH00b<2Y
1037_jP40<S0Z@P0bL6Z0P38`:T60<W1ZPP0b/:[103:`Zd60<_3[P0>0<W3
Z`3:a:h0d<Vf0=WB`03Qfld0iMoC059FF@1<EWX0DVF@05YdV@1VNk00KH2k
06Z0/P1YP[Q@06Z1]`80JWnf1P1[P;L206^0]@H0K86f101]P[L606j3^0H0
KhBi1@1`Q[P30767^@D0LXRj0`1cRK/507F9^`<0MXZl1@1gRkd307R<_P80
N8fl0`1iS[d307Z?_P<0Ni2o0`1lTL0207fB`@<0Oi6o0`20T/02086C`@0<
086D_`20T/@0PiG308bN`P2R/M80];cP0<37fP2;THd0n?Sh0?knoP3oool0
o_kn0P3oool00`3moOd0oooo0?ooo`1j0?ooo`0A0?knoP3oool0oooo0?cl
o03hn?P0lO7a0>SXj03QhN40g]kN0=[JfP3IfMT0fm_K096AT@1fOIL0OXRS
08ZH]@2HYlP00P2O[m400`2P[]40XK3A0:2^d@0o0:2^d@080:Zje02jaN40
aLcV0<g@h@2ATYH0oook0?kno03no_lB0?ooo`00803oool0403no_h0oOgm
0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840
Z::<0;^cW034_:F00<S0Z@@0aknX1038`:T>0<W1ZPX0b/:[103:`Zd60<_3
[P0>0<[4[03:a:h0d<Vf0=[C`@3Qfld0iMoC059FF@1<EWX0DVF@05YdV@1V
Nk00KH2k06Z0/P1YP[Q@06Z1]`H0Jh2g0P1/PKP606b1]PH0KH:g101^PkP6
06n4^@80L8Fj0`1`Q[P50767^@<0LXRj1@1cRK/307F9^`D0MXZl0`1gRkd5
07R<_P<0NHjm0`1jSkh407^@_`<0O9700`1mT/4207nA_`<0P9;00`21Tl40
3021U;l0PI?508>E``2=Wl<0Xk;C0;Blh030amX0Ri6=0?Shn03no_h0oooo
0?knoP80oooo00<0oOgm0?ooo`3oool0NP3oool04@3no_h0oooo0?ooo`3l
o?`0n?Sh0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG07j8
X`2:V;D0V:O80080WjoA00<0X:kA0:6`d@2P[]40?`2P[]40202Z^]@0^/GQ
0<G<iP3=d>40TI:F0?oon`3no_`0o_ko4P3oool00200oooo0100o_kn0?gm
o@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB1
0:RRS02k/i`0a;bUP038`:T30<NoZ0D0b<2Y3@39`JX;0<[2Z`<0b/:]1`3;
`jh03P3:a:`0b/B^0=39]P3Jdl40hM_=0>GOd`1BEUT0C5Ij059UT01JM9T0
IW^`06f0^`1ZP;80JH:hD01ZPKL506^0]`<0K86h1@1/PKH606f2]`D0KX>h
1@1_Q;T30725^PH0LHNi0P1bR;X607>9^`80M8Zl1P1fR[`207N;_@H0N8bn
0P1iSKl207V>_@<0NXnn0`1kT;l407bA`0<0OI;100<0OY?2082B`020T/00
0P20T/03086C`@0=08:D`P22UL00PI?508>E``2=Wl<0Xk;C0;Blh030amX0
Ri6=0?Shn03no_h0oooo0?knoP020?ooo`030?gmo@3oool0oooo07X0oooo
0140o_kn0?ooo`3oool0o?cl0?Shn03alO40j>SX0>7Qh@3Ng]h0f][J0=WI
f@3Kfm/0TI6A07ImU`1nR:<0RYRe09RWb00209n_d@030:2^d@2Q/=40X:kA
03l0X:kA00P0Z[[D0;[5h@35c>H0cM3Q096BUP3ooo/0o_kl0?knoa80oooo
000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN
0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYH00b<2Y0P37_jP60<S0Z@`0
bL6Z303:`Z/20<[2[@L0bl>^00l0c<B_0<[4[03;aJl0d<Vf0=[C`@3Qfld0
iMoC059FF@1<EWX0DVF@05YdV@1VNk00KH2k06Z0/P1YP[P0D01ZPKL406^0
]`@0K86h101/PKH606f2]`H0KX>h101_Q;T40725^PD0LHNi0`1bR;X507>9
^`<0M8Zl1@1fR[`307N;_@D0N8bn0`1iSKl207V>_@80NXnn101kT;l307bA
`0<0OI;10P1nTl83082B`0<0PI?10P22U<803022UL00PI?508>E``2=Wl<0
Xk;C0;Fmh@30amX0Ri6=0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool0NP3oool04@3no_h0oooo0?ooo`3lo?`0n?Sh0?7al@3Xj>P0hN7Q
0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG07j8X`2:V;D0V:O80080WjoA00<0
X:kA0:6`d@2P[]40?`2P[]40202Z^]@0^/GQ0<G<iP3=d>40TI:F0?oon`3n
o_`0o_ko4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0
g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUQ`38`:T=
0<W1ZP`0b/:[1`3;`jh04@3<a:l0bl>^0<c4[`3:a:`0blF_0=39]P3Jdl40
hM_=0>GOd`1BEUT0C5Ij059UT01JM9T0IW^`06f0^`1ZP;80JH:h0500JX6g
101[P;L406b1^0@0K86f101]P[L706j3^0D0KhBi101`QKX40767^@@0LXRj
101cRK/407B:_0@0MXZl101gRkd407R<_P@0NHfo00@0NHjm07Z?_P1jSkh0
NXnn0`1kT;l407bA`080OI;10`1nTl83082B`080PI?10`22U<803022UL00
PI?508>E``2=Wl<0Xk;C0;Fmh@30amX0Ri6=0?Shn03no_h0oooo0?knoP80
oooo00<0oOgm0?ooo`3oool0NP3oool04@3no_h0oooo0?ooo`3lo?`0n?Sh
0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0fMWI0=_Kf`2ATI40MWfG07j8X`2:V;D0
V:O80080WjoA00<0X:kA0:6`d@2P[]40?`2P[]40202Z^]@0^/GQ0<G<iP3=
d>40TI:F0?oon`3no_`0o_ko4P3oool00200oooo0100o_kn0?gmo@3inOT0
lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k
/i`0a;bUN038`:T00`36_ZL0aknX0<NoZ0050<NoZ0P0bL6Z1038`:T40<W1
ZP030<S0Z@39`JX0bL6Z00D0bL6Z00<0bL6/0<[2[@3:`Zd02@3:`Zd40<_3
[P80c<B_00h0b/B/0<_5[`3?b[H0fMC10=oLc@3Sgm<0DUII04aFNP1BII00
FWBI06Ik/01]P;/0JX2b06V2^4P0JX6g00<0JWnf06^0]`1[P;L01@1[P;L0
0`1[P;D0K86f06b1]P0606b1]PL0KH:g101^PkP406n4^@0306n5]`1`Q[P0
L8Jh00D0L8Jh00<0LXJi07>7^P1cQkX01@1cQkX00`1dR;X0MHVk07F9^`05
07F9^`<0MXZl0P1gRkd307R<_P<0N8fl0P1iS[d607Z?_P80Ni2o0`1lTL03
07j@_P80Oi6o1P20T/02086C`@<0PYC200`0PiK008:Da024Ul80SZ720:>b
d`2e_N80`<KL08^AS`3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo05l0oooo0`3no_h20?gmo@030?knoP3oool0oooo0140o_kn01<0oooo
0?knoP3moOd0o_kn0?ooo`3lo?`0n?Sh0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0
fMWI0=[JfP2ATI40MWfG07j8X`2:V;D0V:O80080WjoA00<0X:kA0:6`d@2P
[]40?`2P[]401@2Y^M80^/GQ0<G<iP3<cn00T96E0080o_oj00<0o_kn0?oo
o`3oool0403oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0
g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUN038`:T6
0<NoZ080b<2Y2039`JX40<S0Z@X0bL6Z0P3:`Z/60<[2[@80bl>^103:`Zd4
0<_3[P80c<B_00h0b/B/0<_5[`3?b[H0fMC10=oLc@3Sgm<0DUII04aFNP1B
II00FWBI06Ik/01]P;/0JX2b06V2^4P0JX6g1P1[P;L206b1^0H0K86f201]
P[L606j3^0@0KhBi1P1`Q[P20767^@H0LhNj0P1dR;/607F9^`@0MXZl0`1g
Rkd307R<_P80N8fl0`1iS[d507Z?_P<0Ni2o0`1lTL0207j@_P<0Oi6o1@20
T/03086C`@<0PYC200`0PiK008:Da024Ul80SZ720:>bd`2e_N80`<KL08^A
S`3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0640oooo1P3n
o_hC0?ooo`0A0?knoP3oool0oooo0?gmo@3hn?P0l_;b0>SXj03QhN40g]kN
0=_Kf`3Jf]X0fm_K09:BTP1fOIL0OXRS08ZH]@2HYlP00P2O[m400`2P[]40
XK3A0:2^d@0o0:2^d@050:VidP2jaN40aLcV0<c?h02@TID00P3nooX00`3n
o_h0oooo0?ooo`0@0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[
0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:Eh
0<S0Z@D0aknX0`38`:T80<W1ZP<0b<2Y2P39`JX30<[2Z`D0b/:]0`3;`jh3
0<[2[@D0bl>^0P3<a:l03P3;aJd0blF_0<o:]P3Ie<40gmc=0>?Od`1BEUT0
C5Ij059UT01JM9T0IW^`06f0^`1ZP;80JH:hB01ZPKL506^0]`<0K86h1@1/
PKH806f2]`H0KX>h1@1_Q;T40726^0@0LHNi101cQkX407B8^`@0MHVk1@1f
R[`307N;_@@0N8bn00@0N8fl07V>_@1iS[d0NHjm1@1jSkh307^@_`@0O970
00@0OY2n07nA_`1oTKl0Oi6o1@20T/03086C`@@0PYC200`0PiK008>Ea@25
V<<0SZ720:Bce02e_N80`<KL08^AS`3hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo0680oooo1@3no_hC0?ooo`0A0?knoP3oool0oooo0?cl
o03hn?P0l_;b0>SXj03QhN40g]kN0=_Kf`3Jf]X0fm_K09:BTP1fOIL0OXRS
08ZH]@2HYlP00P2O[m400`2P[]40XK3A0:2^d@0o0:2^d@050:VidP2jaN40
aLcV0<c?h02@TID00P3nooX00`3no_h0oooo0?ooo`0@0?ooo`00803oool0
403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?
08Z8N`2IU840Z::<0;^cW034_:Eh0<S0Z@@0aknX1038`:T80<W1ZP80b<2Y
2P39`JX40<[2Z`@0b/:]103;`jh20<[2[@H0bl>^0P3<a:l03P3;aJd0blF_
0<o:]P3Ie<40gmc=0>?Od`1BEUT0C5Ij059UT01JM9T0IW^`06f0^`1ZP;80
JH:hB01ZPKL406^0]`@0K86h101/PKH806f2]`H0KX>h1P1_Q;T30726^0D0
LHNi0`1cQkX507B8^`<0MHVk1@1fR[`307N;_@<0N8bn0P1iSKl307V>_@<0
NXnn1@1kT;l307bA`080OI;10`1oTKl3082B`0D0PI?10`22U<8208>E``0<
08BG`@23ULD0QIS308jQ`P2T/m@0]KgR0<36g02;THl0n?Sh0?knoP3oool0
o_kn0P3oool00`3moOd0oooo0?ooo`1S0?oooaD0o_kn01<0oooo0?knoP3m
oOd0o_kn0?ooo`3lo?`0moOg0?7al@3Xj>P0hN7Q0=kNgP3Jf]X0fMWI0=[J
fP2ATI40MWfG07j8X`2:V;D0V:O80080WjoA00<0X:kA0:6`d@2P[]40?`2P
[]40202Z^]<0^/GQ0<G<iP3<cn00TI:F0?oon`3nooX0o_kn4P3oool00200
oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J
09FDS`2:R7/0VIB10:RRS02k/i`0a;bUN038`:T40<NoZ0@0b<2Y3P39`JX2
0<[2Z`@0bL6Z103:`Z/40<[2[@X0bl>^0`3<a:l03`3=aK00blF]0<_5[`3@
bkL0fMC10>3McP3Sgm<0DUII04aFNP1BII00FWBI06Ik/01]P;/0JX2b06V2
^01806Z1]`@0Jh2g101/PKP406b1]PP0KH:g101^PkP606n4^@80L8Fj1@1a
QkT307:8^PD0M8Rk0`1eRK`507J:_0D0Mh^m0`1hS;h307V=_`80NHjm0`1j
Skh507^@_`<0O9700`1mT/4207nA_`<0P9;01@21Tl4308:D`P<0PiG300`0
Q9O108>Ea@25V<<0SZ720:Bce02e_N80`<KL08^AS`3hn?P0o_kn0?ooo`3n
o_h20?ooo`030?gmo@3oool0oooo05l0oooo103no_h40?oooa00o_kn0`3o
ool04@3no_h0oooo0?ooo`3lo?`0n?Sh0?;blP3YjNT0h^;R0=oOg`3Kfm/0
f][J0=_Kf`2BTY80MWfG07j8X`2:V;D0V:O80080WjoA00<0X:kA0:6`d@2P
[]40?`2P[]401@2Z^]<0^lKR0<G<iP3=d>40TI:F0080oook00<0o_kn0?oo
o`3oool0403oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0
g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUN038`:T3
0<NoZ0D0b<2Y3@39`JX30<[2Z`<0bL6Z1@3:`Z/30<[2[@X0bl>^103<a:l0
3`3=aK00blF]0<_5[`3@bkL0fMC10>3McP3Sgm<0DUII04aFNP1BII00FWBI
06Ik/01]P;/0JX2b06V2^01806Z1]`<0Jh2g1@1/PKP306b1]PP0KH:g1@1^
PkP506n4^@<0L8Fj101aQkT407:8^P@0M8Rk101eRK`407J:_0@0Mh^m101h
S;h307V=_`0307Z>`01jSkh0NXnn0080NXnn0`1kT;l507bA`0<0OI;100<0
OY?2082B`020T/000P20T/03086C`@D0PYC20`23UL<03@24U/@0Q9O108>E
a@25V<<0SZ720:Bce02e_N80`LOM08bBT03hn?P0o_kn0?ooo`3no_h00P3o
ool00`3moOd0oooo0?ooo`1O0?ooo`80oOgm5P3no_h30?ooo`0A0?knoP3o
ool0oooo0?clo03hn?P0l_;b0>WYj@3Rh^80gmoO0=_Kf`3Jf]X0fm_K09:B
TP1fOIL0OXRS08ZH]@2HYlP00P2O[m400`2P[]40XK3A0:2^d@0o0:2^d@05
0:Zjd`2ka^80a/gW0<g@h@2ATYH00P3ooo/00`3no_h0oooo0?ooo`0@0?oo
o`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[I
gP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:Eh0<S0Z@80aknX1P38`:T<
0<W1ZP@0b/:[0P39`JX60<[2Z`80b/:]2P3;`jh40<c4[`80cLF`00h0blF]
0<c6/03@bkL0f]G20>3McP3Th=@0DUII04aFNP1BII00FWBI06Ik/01]P;/0
JX2b06V2^4P0JX6g0P1[P;L606b1^080K86f201]P[L606j3^0@0KhBi101`
QKX20767^@H0LXRj0P1dR;/607F9_080MXZl1P1gRkd307R<_P<0NHfo0P1j
S/0307Z?_P<0Ni2o1@1lTL0307fB`@80OY?20`20T/03086C`@D0PYC20`23
UL<208BFa00<08BG`@23ULD0QIS308nR``2T/m@0]KgR0<77g@2<TY00n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1O0?ooo`D0o_kn00<0
oOgm0?clo03lo?`04@3kno/04`3lo?`0no_k0?[jnP3kno/0o?cl0?Win@3e
mOD0kno_0>GUi@3Ng]h0fm_K0=SHf03GemL0f=SH08n?S`1fOIL0OXRS08ZH
]@2HYlP00P2O[m400`2P[]40XK3A0:2^d@0o0:2^d@050:Zjd`2ka^80a/gW
0<g@h@2ATYH00P3ooo/C0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0
jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034
_:Eo0<S0Z@d0bL6Z2`3:`Z/00`3;`j`0bl>^0<_3[P050<_3[P030<c4[`3;
`jh0bl>^0080bl>^103<a:l20<g5/00>0<_5[@3<a[00d<^g0=[E`P3PgLh0
i>3D059FF@1<EWX0DVF@05YdV@1VNk00KH2k06Z0/P1YP[Q806Z1]`L0K86h
00<0KH:i06f2]`1]P[L01@1]P[L806j3^0D0KhBi101`QKX707:8^P0307>9
^`1eRK`0MHVl00D0MHVl00<0MXZm07N;_@1gRkd01@1gRkd407R<_P80NHfo
0`1jS/0307Z?_P80Ni2o1P1lTL0207fB`@<0OY?20`20T/02086C`@H0PYC2
0P23UL<308BFa00<08BG`@23ULD0QIS308nR``2T/m@0][kS0<77g@2<TY00
n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1R0?ooo`030?kn
oP3moOd0o?cl0080n_[j4`3gmoL04@3fm_H0moOg0?Ogm`3dm?@0l?3`0>[Z
jP3QhN40f][J0=OGe`3De=@0d];B0=CDe02:RXX0MWfG07j8X`2:V;D0V:O8
0080WjoA00<0X:kA0:6`d@2P[]40?`2P[]401@2Z^]<0^lKR0<K=i`3=d>40
TI:F0080oook4`3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3T
i>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUL038
`:T40<NoZ0@0b<2Y2039`JX40<S0Z@P0bL6Z103:`Z/90<[2[@P0bl>^1`3<
a:l0403<a;40c<B_0<_5[`3<a[00d<^g0=WC``3Ofll0hmoD059FF@1<EWX0
DVF@05YdV@1VNk00KH2k06Z0/P1YP[Q006Z1]`0306Yo]P1[P;L0Jh2g00D0
Jh2g00<0Jh2e06b1]P1/PKH01@1/PKH406f2]`D0KX>h1`1_Q;T00`1_QKL0
L8Jh0726^0050726^0<0LXJi0P1cQkX307B8^`0307B8^P1eRK/0MHVk00D0
MHVk0`1fR[`207N;_@<0N8bn00@0N8fl07V>_@1iS[d0NHjm0`1jSkh00`1k
T;l0O8jn07f?_`0207f?_`<0OY3000<0Oi7107nA_`1oTKl00P1oTKl4082B
`0@0PI?11022U<8408>F`@@0Q9O200`0QIS008BFa026VL@0T:?40:Fde@2f
_^80`LSK08^AS`3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo
0680oooo00d0o_kn0?clo03inOT0m?Cd0?7al@3_lNh0k>c/0?Cbm@3_j_00
lNcb0>o]lP3emOL0k>k]00<0lNo`103bl?400`3ako00l_3a0?7_l0030?7_
l00C0?3^k`3^k>d0k>[[0>CSh@3Mfm`0eM?D0=CBd`3=bl`0clg@0<g;cP2:
R8/0M7^E07n9Y02;VKH0UZG609j^d02O[m40Wjg@0:6`d@0l0:2^d@@0XJoB
00P0ZkWD0;_7g`38cn80cM7M096BU`3mo_l0o_kn0?oooA80oooo000P0?oo
o`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2E
U8l0RXQk09VDP@2XXX`0^k>L0<BlYG00b<2Y1037_jP40<S0Z@P0bL6Z1038
`:T80<W1ZP@0b/:[203:`Zd60<_3[PP0c<B_0P3=aK00403<a;40c<B_0<_5
[`3<a[00d<^g0=WC``3Ofll0hmoD059FF@1<EWX0DVF@05YdV@1VNk00KH2k
06Z0/P1YP[Q006Z1]`H0Jh2g0P1/PKP606b1]PH0KH:g101^PkP606n4^@80
L8Fj1P1`Q[P20767^@80LXJi0`1cQkX307B8^`H0MHVk101fR[`307N;_@<0
N8bn101iS[d207Z?_P80Ni2o101mSkl207j@`080Oi710`1oTKl5082B`0<0
PI?11@22U<8408>F`@@0Q9O200`0QIS008BFa026VL@0T:?40:Fde@2f_^80
`LSK08^AS`3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0640
oooo00h0o_kn0?gmo@3kno/0m_Kf0?7al@3]kNd0iNOV0>SXj03/j^d0in;V
0>_VjP3UhnH0inOW0>SZj@@0i^CU0P3WiNH20>KTi@030>SVi`3WiNH0inGV
0080inGV00D0i^CU0>CRh`3Rh>40fm[H0=?Bd0020<_9bP0<0<K4a@38a/L0
aL?408B2Q@1dNiD0OhVT08^I]P2FYLH0WZk@09n_d@2O[M00XK3A?02P[]44
0:6_dP080:^ie02lb>00b<oR0<kBgP2ATYL0oOko0?knoP3ooodB0?ooo`00
803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3J
f]X0UIB?08Z8N`2IU840Z::<0;^cW034_:E`0<S0Z@<0aknX1@38`:T80<W1
ZP<0b<2Y2039`JX50<[2Z`P0b/:]1@3;`jh80<c4[`<0cLF`0100c<Ba0<g5
/03;aJl0c<J`0=3;]`3Je<@0gm_?0>?Oe01BEUT0C5Ij059UT01JM9T0IW^`
06f0^`1ZP;80JH:h@01ZPKL506^0]`<0K86h1@1/PKH606f2]`D0KX>h1@1_
Q;T30725^P@0L8Jh101aQkT0101bQ[T0LhNj07>7^P1cQkX407B8^`@0MHVk
1@1fR[`307N;_@@0N8bn0`1iS[d307Z?_P80Ni2o0`1mSkl307j@`080Oi71
0P1oTKl6082B`080PI?11P22U<8308>F`@D0Q9O200`0QIS008BFa027V/D0
T:?40:Fde@2f_^80`LSK08^AS`3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo0640oooo00P0o_kn0?gmo@3inOT0lo?c0>c/k03WinL0hN?R
0>;RhP80g]cM00@0jNOX0>;RhP3Lg]d0gN7P0P3RhMl60>7PgP030>?Rh03R
hMl0h^7O0080h^7O01<0hN3N0=oNg03NgM/0emGF0<o=cP37aLH0a/C50<;0
`@33`L80_kfn085oP01dNiD0OhVT08^I]P2FYLH0WZk@09n_d@2O[M00XK3A
03/0X:kA1@2Q[m80202/^]D0_<SP0<S?hP3>d]h0TI:G0?gno`3no_h0ooom
4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cL
g03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUL038`:T20<NoZ0H0
b<2Y2039`JX20<S0Z@P0bL6Z1P3:`Z/80<[2[@@0bl>^203<a:l40<g5/00@
0<c4/@3=aK00blF_0<c6/03@bkL0f]C40>3Ld03Sgm@0DUII04aFNP1BII00
FWBI06Ik/01]P;/0JX2b06V2^400JX6g101[P;L406b1^0@0K86f1P1]P[L6
06j3^0@0KhBi101`QKX30726^0D0LHNi0`1cQkX307B8^`80MHVl0`1eRK/5
07J:_0<0Mh^m0`1hS;h207V=_`80NHjm0`1jSkh307^@_`80OHno0`1nT<03
07nA`@D0P9;00`21Tl4508:D`P<0PiG30P23U/4608BG`P0<08FH`025UlD0
Qi[5092Sa02V]MH0][kR0<78f`2<TY00n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`1R0?ooo`0>0?gmo@3inOT0lO7a0>WYj@3Ti>@0g]oQ
0=gMg@3Jf=T0h=oM0=_Kf@3?dM00a/[;0<S>cP3;cL`20<c>c@@0blg<00<0
c<k=0<_=c03;cL`00`3;cL`04`3:c</0b<[90<O9b032`LH0_;_00;Je^P2c
/kD0[jna0;2`/P2^[[00N7Qj07=jU01oRJ@0RiVf09NVa`2O[m40X;3B09n]
d02Q/=40>P2P[]460:6_dP080:bje@2lb>00b<oR0<kBgP2ATYL0oOko0?kn
oP3ooodB0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03N
g]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:Ef0<S0ZA00
bL6Z203:`Z/20<_3[0`0bl>^203<a:l40<g5/00@0<c4/@3=aK00c<J`0<c6
/03Ac;P0f]C40>3Ld03Sgm@0DUII04aFNP1BII00FWBI06Ik/01]P;/0JX2b
06V2^400JX6g101[P;L406b1^0@0K86f101]P[L606j3^0H0KhBi101`QKX5
0767^@<0LXRj0P1cQkX307B8^`<0MHVl1@1fR[`507N;_@<0N8bn0`1iSKl3
07Z?_P<0Ni2o0P1lTL0307j@`0<0Oi710P20T/83082B`0D0PI?10`22U<85
08>E``H0Q9O20P25V<<03025V<00QIO508NJa@2@Xl@0Y[GF0;Noh`31b=/0
S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0G`3oool0
4P3no_h0oooo0?ooo`3moOd0nOWi0?;blP3YjNT0hn?S0=_LgP3Lg=`0g=cJ
0=WIe`2ZZZX0RHf@08:9S`24SI@0PhR>08B9S`80QHZ@00@0Q8V?08>8SP24
RHl0QHZ@1@24RHl04`23R8h0PXN=0825R`1lOXX0NGb507IiPP1cMWl0L7=j
079eO01cMW/0B4]@07=jU01nR:<0RiVf09NVa`2O[m40X;3B09n]d02Q/=40
>02P[]460:6_dP80X[3C00P0[;[E0;g9h@39d><0c];N096BU`3mo_l0o_kn
0?oooA80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kN
gP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYGD0b<2Y4039
`JX80<[2Z`<0bl>/2`3;`jh80<c4[`D0cLF`0100c<Ba0<g5/03<a[00c<J`
0=7<^03Je<@0h=c@0>?Oe01BEUT0C5Ij059UT01JM9T0IW^`06f0^`1ZP;80
JH:h@01ZPKL306^0]`D0K86h0`1/PKH506f2]`D0KX>h1P1_Q;T50725^P@0
LHNi101bR;X407B8^`<0MHVl00<0MXZm07J:_01fR[`00P1fR[`407N;_@@0
N8bn0`1iSKl00`1jS/00NXnn07Z?_P0307^@_`<0O9700P1nT<0307nA`@<0
P9;21P21Tl4208:D`PH0PiG30P24U/@508BG`P<0QIS300`0QYW108FGa@27
V/D0TJC50:JeeP2g_n<0`LSK08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo05l0oooo0P3no_h0403oool0o_kn0?Win@3bl_80jNWY
0>?Sh`3KgM`0fMWG0=_Kf@3Jf]P0U9FG071dO@1^MHD0KGF806ieQ`1`MhT2
075hRP<0L7N9101aN8X2079iR`0C075hRP1_MXP0KWF706]`Q01XKH00IV]n
069XN01PIW@0HVQf06=YM@0m@dl0LWVC07j8X`2;VKH0UjK709n_d@2P/=80
Wjg@0:6`d@0h0:2^d@D0XJoB0`2R/=<0202]^mH0_LWQ0<W@h`3>d]h0TI:G
0?koo`3no_h0ooom4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU
M038`:T@0<W1ZPP0b/:[103;`j`:0<_3[PP0c<B_1P3=aK00403=aK80cLF`
0<c6/03=ak40dLbh0=[Da03Pg=00i>3E059FF@1<EWX0DVF@05YdV@1VNk00
KH2k06Z0/P1YP[Q006Z1]`80Jh2g1P1/PKP206b1]PH0KH:g101^PkP606n4
^@H0L8Fj0P1aQkT607:8^P<0M8Rk0`1eRK`207J:_@80MXZl1P1gRkd307R<
_P<0NHfo0P1jS/0207Z?_P80Ni2o101lTL0207j@`080Oi711020T/85086C
`@<0PYC21@23UL<308BFa0@0Q9O21025V<<03026VL40QIO508NJa@2AY<D0
Y[GF0;Noh`32bM`0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool0G`3oool04P3no_h0oooo0?ooo`3moOd0nOWi0?7al@3YjNT0hn?S
0=oQgP3KfmT0f=SF0=SJf@2?TYL0LGN5075iT01^MiH0N8>O07^6XP80OXVU
00<0OHRT07b7X`1mR:@00P1nRJD207f8Y0<0OXVU0180O8NS07Z5X@1hPYd0
LgfH071jT`1/MXl0JgJ<06]fRP1XLhD0A4mQ079iT`1nR:<0RiVf09NVa`2O
[m40X;3B09n]d02Q/=4h0:2^d@@0XJoB102R/=<0202]^mH0_LWQ0<W@h`3?
dml0TI:G0?koo`3no_h0ooom4P3oool00200oooo0100o_kn0?gmo@3inOT0
lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k
/i`0a;bUM038`:T@0<W1ZPP0b/:[103;`j`80<_3[PL0c<B_203=aK004@3>
a[40cLFb0<g5/03<a[00cLNa0=7<^03Je<@0h=c@0>CPe@1BEUT0C5Ij059U
T01JM9T0IW^`06f0^`1ZP;80JH:h0400JX6g1`1/PKP00`1]P[T0KH:g06f2
]`0506f2]`D0KX>h101_Q;T70725^P030766^`1bR;X0LXRj00D0LXRj00@0
LhVk07B8^`1dR;/0M8Rk0P1eRK`307J:_@L0Mh^m101hS;h207V=_`<0NXk0
00@0NXnn07^@_`1kT;l0Ni2o0`1lTL000`1mT/40OY3007nA`@0207nA`@<0
P9;200<0PI?3086C`@21Tl400P21Tl4408:D`P@0PiG31024U/@408BG`P@0
QIS300`0QYW108FGa@27V/D0TJC50:JeeP2g_n<0`/WL08bBT03hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0680oooo01H0oOgm0?Shn03`
l?00j>SX0>;RhP3Mgm`0g]oJ0=[KeP3IfmX0SI2I079gR`1gOId0O8BY08FB
]028UKL0RiRj08bI^`2;V;X0RYNi08^H^P2<VK/0RYNi0P29U[P308ZG^@0>
08RE]`27U;H0Q8n_07j9Z@1kQZ@0N8>O07Z6X01jQYh0M82H04mKL@1aN980
OXRS08^I]P2GY/L20:2`dP0309n]d02Q/=40X:kA03L0X:kA102Q[m840::`
d`080:fkeP2nb^80b]7T0<oCg`2ATYL0o_oo0?knoP3no_`B0?ooo`00803o
ool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0
UIB?08Z8N`2IU840Z::<0;^cW034_:EX0<S0Z@@0aknX1038`:T80<W1ZPP0
b<2Y1039`JX40<[2Z`T0b/:]203;`jh80<c4[`L0cLF`0100c<Fb0<c6/03<
a[00cLNa0=7<^03Je<@0h]c@0>KOe@1BEUT0C5Ij059UT01JM9T0IW^`06f0
^`1ZP;80JH:h>01ZPKL00`1ZOkH0Jh2g06^0]`0506^0]`0306^0]@1/PKH0
K86f00D0K86f101]P[L506j3^0L0KhBi101`Q[P40767^@0407:6^@1cQkX0
LhNj07>7^P<0M8Rk00<0MHVl07F9^`1eRK/00P1eRK/507J:_0<0Mh^m0`1h
S;h00`1iSKl0N8fl07V>_@0207V>_@<0NXnn00<0Ni2o07b>_P1mSkl00P1m
Skl307j@`00307nA`@1nT;h0Oi6o0080Oi6o0`20T/05086C`@@0PYC21023
U/4408BG`P@0QIS31026VL@03027V/80QYS608VJa@2CXl@0YkCD0;JnhP32
am/0S96=0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0H03o
ool20?knoP0C0?gmo@3inOT0lO7a0>SXj03QhN40g^3K0=_Jg`3Lf]d0f]_E
08f>T01eNXh0NXFS08FE[`2BX<<0VZS;09VWbP2JZ</0VjW<09VWbP0609ZX
b`0B09^Yc02JZ</0V:K909NUb02DX[l0SY^k08RE]`26TkD0QI2`08NB/025
TJ/0Demg06ijU01nRJD0RIJf09VVb02Q[m80X:kC0P2O[m4X0:2^d@P0XJoB
00<0X:kA0:6_dP2Q[m801P2Q[m830::`d`<0Xk7D00T0Y;;E0:fkeP2mbN40
bM3S0<oCg`2ATYL0o_oo0?ooo`3oood04P3oool00200oooo0100o_kn0?gm
o@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB1
0:RRS02k/i`0a;bUJ038`:T40<NoZ0@0b<2Y5039`JX40<[2Z`P0b/:]1P3;
`jh80<c4[`P0cLF`0P3>a[40403<aK80c<J`0<c6/03=ak40dLbh0=[Da03R
g=00i]oE059FF@1<EWX0DVF@05YdV@1VNk00KH2k06Z0/P1YP[Ph06Z1]`H0
Jh2g0P1/PKP606b1]PH0KH:g101^PkP606n4^@80L8Fj0`1`Q[P50767^@@0
LhNj0P1dR;/207F9_0<0MHVk1@1fR[`407N;_@80N8bn0P1iSKl407V>_@80
NXnn0P1kT;l407f?_`80OY300P1oTL4407nA_`80P9;01@21Tl4508:D`P<0
PiK11@24Ul8408FH``@0QYW400`0Qi[208JHaP29V/D0Tj?40:Nde02f_^80
`/OK08bAS@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0600
oooo0P3no_h04`3moOd0nOWi0?7al@3Xj>P0hN7Q0=gOfP3JfMh0g=[M0=[K
e@2>Si40MW^?07^6Y027Uk40V:K90:2^d@2O[M00X:kA0:6_dP2O[M00202P
[]40402N[<l0WJ_>09VWa02BWkl0SIZl08^H^P2:UKD0S9Ne08ZF/01HI7`0
KWZD07j9Y@29U[H0VJK80:6_dP2P[]<209n_dBP0X:kA3P2Q[m860::`d`80
Xk7D0P2T/]D0202]^mH0_LWQ0<W@h`3?dml0TI:G0?koo`3oool0ooom4P3o
ool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03J
fMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUJ038`:T30<NoZ0D0b<2Y
4`39`JX50<[2Z`P0b/:]1@3;`jh80<c4[`P0cLF`0`3>a[40403<aK80cLNa
0<c6/03=ak40dLbh0=_Ea@3Rg=00i]oE059FF@1<EWX0DVF@05YdV@1VNk00
KH2k06Z0/P1YP[Ph06Z1]`D0Jh2g0`1/PKP506b1]PH0KH:g1@1^PkP506n4
^@<0L8Fj0P1`Q[P60767^@<0LhNj0`1dR;/207F9_080MHVk1P1fR[`307N;
_@<0N8bn0P1iSKl307V>_@<0NXnn0P1kT;l307f?_`<0OY300P1oTL4307nA
_`<0P9;01021Tl4608:D`P80PiK11P24Ul8308FH``D0QYW400`0Qi[208JH
aP29V/D0Tj?40:Nde02g_n<0`/OK08bAS@3hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo0600oooo0P3no_h0503moOd0nOWi0?7al@3Xj>P0
hN7Q0=cNf@3JfMh0fmWL0=_LeP2>Si40N7fA07f8YP29VK<0VJO:0:6_dP2P
[]40XJoB0:>ae02P[]40X[3C1@2Q[m804P2R/=<0XJoB09n]d02N[<l0VJO4
09>P`02=V[`0RiRj08ZE]@2<UkD0RYJ`05QTO01^NY@0OXVU08VF]P2IY/P0
XJoB0:2^d`80WjoA:02P[]4=0:6_dPH0X[3C0`2S/M@20:Bbe@080:jle`2n
b^80b]7T0<oCg`2BTiP0o_oo0?ooo`3ooodB0?ooo`00803oool0403no_h0
oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2I
U840Z::<0;^cW034_:EX0<S0Z@80aknX1P38`:TB0<W1ZPH0b/:[203:`Zd4
0<_3[PP0c<B_203=aK040<k6/@0@0<c5/P3=ak40c<J`0<g7/@3Ac;P0fmG5
0>?Md@3VgmD0DUII04aFNP1BII00FWBI06Ik/01]P;/0JX2b06V2^3P0JX6g
101[P;L406b1^0@0K86f1P1]P[L606j3^0@0KhBi101`QKX50767^@<0LXRj
0P1cQkX307B8^`<0MHVl1@1fR[`507N;_@<0N8bn0`1iSKl207V>_@<0NXnn
0`1kT;l207f?_`<0OY300`1oTL4207nA_`<0P9;00`21Tl4508:D`P<0PiG3
1@24Ul8508FH``H0QYW400`0Qi[208JHaP29V/D0Tj?40:Nde02g_n<0`/OK
08fBSP3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0600oooo
0P3no_h05P3moOd0nOWi0?7al@3Xj>P0hN7Q0=cNf@3JfMh0g=[M0=_LeP2?
T980N7fA07j9Y`2:V[@0UjG80:2^d@2O[M00X:kA0:6_dP2O[M00X:kA09n]
d02P[]4209n]d0<0X:kA0100WZc?09f[cP2GYL80TIjn08bI^`29U[P0R9>c
08ZE/`28U:h0Ef=k06ijU01nRJD0RIJf09VVb02Q[m80X:kC0P2O[m4X0:2^
d@`0XJoB1P2R/=<30:>ae0<0Y;;E00P0[[cG0;k:hP3:dN@0cm?O09:CV03n
ool0oooo0?oooA80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYFh0
b<2Y4P39`JX60<[2Z`80bl>/303;`jh80<c4[`P0cLF`103>a[40403<aK80
cLNa0<g7/@3=ak40d/fi0=_Ea@3SgM40i]oE059FF@1<EWX0DVF@05YdV@1V
Nk00KH2k06Z0/P1YP[Ph06Z1]`@0Jh2g101/PKP406b1]P@0KH:g1P1^PkP6
06n4^@@0L8Fj0`1aQkT507:8^P<0M8Rk0`1eRK`207J:_@<0MXZl1@1gRkd3
07R<_P<0NHfo0P1jS/0307Z?_P<0Ni2o0P1lTL0307j@`0<0Oi710P20T/83
082B`0<0PI?11@22U<8508>E``<0Q9O21@25V<<608JIa080Qi[500`0Qi[2
08NIa`2:VlH0U:C50:Ree@2g_n<0`/OK08fBSP3hn?P0o_kn0?ooo`3no_h2
0?ooo`030?gmo@3oool0oooo0600oooo0P3no_h05@3moOd0nOWi0?7al@3X
j>P0hN7Q0=gOfP3Kf]l0g=[M0=_LeP2?T980N7fA07f8YP29VK<0VJO:0:6_
dP2P[]40XJoB0::`d`2P[]40XJoB0:2^d@060:6_dP0@09n]d02N[<l0VJO4
09>P`02=V[`0RiRj08ZE]@2<UkD0RYJ`05QTO01^NY@0OXVU08VF]P2IY/P0
XJoB0:2^d`80WjoA:02P[]4<0:6_dP@0X[3C0`2S/M@30:Bbe@80YK?F00P0
[[cG0;o;h`3:dN@0cm?O09:CV03nool0oooo0?oooA80oooo000P0?ooo`0@
0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0
RXQk09VDP@2XXX`0^k>L0<BlYFd0b<2Y4`39`JX50<[2Z`<0bl>/2`3;`jh8
0<c4[`P0cLF`1@3>a[40403<aK80cLNa0<g7/@3=ak40d/fi0=_Ea@3SgM40
i]oE059FF@1<EWX0DVF@05YdV@1VNk00KH2k06Z0/P1YP[Ph06Z1]`<0Jh2g
1@1/PKP306b1]PD0KH:g1@1^PkP606n4^@D0L8Fj1P1bR;X207>9^`80M8Rk
0`1eRK`307J:_@H0Mh^m101hS;h307V=_`<0NXk00P1jSkh307^@_`<0O970
0P1nT<0307nA`@<0P9;20P20T/03086C`@<0PYC21P23UL<208BFa0H0QIS3
1`26VL@308NJa@0<08RK``27VLL0RY_609BTa@2X]MD0]koS0<?8g02=TXh0
n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1P0?ooo`80o_kn
01H0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0fm[O0=cJg@3Kg=H0Si2B07Qm
T@1mR:H0R9Rb09RVb@2Q[m80X:kA0:6_dP2R/=<0X:kA0:6_dP2P[]40XJoB
0P2P[]430:6_dP0@09n]d02MZlh0VJO409>P`02>Vkd0RiRj08ZE]@2<UkD0
RYJ`05UUO@1^NY@0OXVU08VF]P2IY/P0XJoB0:2^d`80WjoA:02P[]4;0:6_
dPD0X[3C0P2S/M@30:Bbe@<0YK?F00P0[kgH0;o;h`3;d^D0d=CP09:CV03n
ool0o_kn0?oooA80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYF`0
b<2Y5039`JX40<[2Z`@0bl>/2P3;`jh80<c4[`P0cLF`1P3>a[40403=a[<0
cLNa0<g7/@3>b;80d/fi0=_Ea@3SgM40in3F059FF@1<EWX0DVF@05YdV@1V
Nk00KH2k06Z0/P1YP[Ph06Z1]`80Jh2g1P1/PKP206b1]PH0KH:g101^PkP6
06n4^@H0L8Fj1@1bR;X307>9^`80M8Rk0P1eRK`407J:_@D0Mh^m1@1hS;h2
07V=_`@0NXk00P1jSkh207^@_`@0O9700P1nT<0207nA`@@0P9;20P20T/02
086C`@@0PYC21@23UL<308BFa0D0QIS31`26VL@408NJa@0<08RK``27VLL0
RY_609BTa@2X]MD0]koS0<?8g02=TXh0n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`1P0?ooo`80o_kn00h0oOgm0?Win@3alO40j>SX0>7Q
h@3MgmX0fm[O0=cJg@3Kg=H0Si2B07MlT01mR:H0RIVc09NUb080Wjg@00H0
X:kA0:6_dP2O[M00X:kA09n]d02P[]4209n]d080X:kA0140Wjg@09j/c`2L
Z/d0V:K309:O_`2<VK/0RYNi08VD]02;U[@0RIF_05MSN`1^NY@0OXVU08VF
]P2IY/P0XJoB0:2^d`0209n_dBP0X:kA2P2Q[m860::`d`80Xk7D0P2T/]D4
0:FceP080:nmf02obn<0bm;U0=3Dh02BTiP0o_oo0?knoP3no_`B0?ooo`00
803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3J
f]X0UIB?08Z8N`2IU840Z::<0;^cW034_:E/0<S0Z@`0bL6Z303:`Z/40<_3
[0P0bl>^1`3<a:l80<g5/0P0c/Ja0140clNb0<g6/`3=ak40cLNa0<k8/P3B
cKT0fmG50>?Md@3Wh=H0DUII04aFNP1BII00FWBI06Ik/01]P;/0JX2b06V2
^00h06Z1]`L0K86h00<0KH:i06f2]`1]P[L01@1]P[L506j3^0@0KhBi1`1`
QKX00`1aQ[/0LXRj07:8^P0207:8^P@0LhVk00@0M8Rk07F9_01eRK`0MHVl
0`1fR[d00`1gRkh0Mh^m07N;_@0207N;_@D0N8bn0`1iSKl307Z>`00307^?
`@1jSkh0Ni2o0080Ni2o0`1lTL000`1mT/40OY3007nA`@0207nA`@<0P9;2
00<0PI?3082B`021Tl400P21Tl4308:D`PD0PiG31024U/@408FH``P0QYW4
1027V/D03028Vl<0QiW708ZKaP2DY<D0Z;GE0;Noh`33b=`0SI:>0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0H03oool20?knoP0E0?gm
o@3inOT0lO7a0>SXj03QhN40g=kI0=[IgP3KfM`0fmcF08n@TP1hOI40OHRV
08VI/`2IYlX0XJoB0:2^d@2Q[m80X[3C0:2^d@2Q[m80X:kA00H0XJoB0100
Wjg@09j/c`2HY/<0TYno08fJ_02;V;X0RYFe08^F]02:U[00F6Al06ijU01n
RJD0RIJf09VVb02Q[m80X:kC0P2O[m4X0:2^d@P0XJoB1`2R/=<20:>ae0<0
Y;;E0`2U/mH02@2V]=L0/;kI0<3<i03;d^D0d=CP09:CV03nool0o_kn0?kn
o00B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0
g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:EP0<S0Z@@0aknX
3038`:T80<[2Z`@0bL6Z103:`Z/40<[2[@@0bl>^00<0b/:]0<_3[P3;`jh0
1P3;`jh80<c4[`P0cLF`1`3>a[40403=a[<0c/Rb0<g7/@3>b;80d/fi0=_E
a@3SgM40i]oE059FF@1<EWX0DVF@05YdV@1VNk00KH2k06Z0/P1YP[PX06Z1
]`P0Jh2g00<0JWnf06^0]`1[P;L01@1[P;L406b1]PD0KH:g1`1^PkP406n5
]`P0L8Jh101aQkT0101bQ[T0LhNj07>7^P1cQkX307B8^`0307F9_01eRK/0
MHVk0080MHVk101fR[`307N;_@80N8bn0`1iSKl307V>_@80NXnn0`1kT;l3
07f?_`80OY300`1oTL4307nA_`80P9;01021Tl4708:D`P@0PiK11024Ul84
08JG``@0QiS41028VL@408VJa@0<08RKa@29VlT0RI[509FVa02Z^=D0]l3Q
0<C9g@2<T940n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1P
0?ooo`80o_kn01@0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0f]WN0=cJg@3K
g=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_
dPD0X:kA0180XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0SIZl08ZG^@29U;@0
RiJd08ZF/01HI7`0KWZD07j9Y@29U[H0VJK80:6_dP2P[]<209n_dB00X:kA
202Q[m840:2^d@@0XJoB00@0XK3A0::adP2R/M80X[7B0`2S/]<0102T/m@0
YK;D0:Fbe02U/]@20:Jce@<0YkCF00H0[kgH0<3:h`3;d^@0cm?N09:CV03o
ool20?oooA80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT
0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYF00b<2Y
1037_jP<0<S0Z@P0b/:[1039`JX40<[2Z`@0b/:]2P3;`jh80<c4[`P0cLF`
203>a[420<o7/P0@0<g6/`3>b;80cLNa0<k8/P3BcKT0fmG50>?Md@3VgmD0
DUII04aFNP1BII00FWBI06Ik/01]P;/0JX2b06V2^2P0JX6g3P1[P;L206b1
^0@0K86f101]P[L606j3^080KhBi101_QKL70726^0D0LHNi101cQkX207B8
^`80MHVl0`1eRK/507J:_080Mh^m0`1hS;h307V=_`80NHjm0`1jSkh307^@
_`80OHno0`1nT<0307nA`@80Oi6o0`20T/03086C`@H0PYC20P23UL<308>F
`@D0Q9O20`26Ul<508NHa0@0R9W41029V/D03028VlD0RI_908VJa@2EY/@0
Z[SE0;O0h@34bMd0S92A0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool0H03oool20?knoP0D0?gmo@3inOT0lO7a0>SXj03QhN40gMoJ0=[I
gP3Lf]d0fmcF08n@TP1hOI40OXVW08VI/`2HY/T0X:kA09n]d02P[]40XJoB
09n]d02Q[m850:2^d@0B0:6_dP2P[]40WZc?09f[cP2HY/<0TYno08fJ_02:
UkT0RIBd08^F]02:U[00F6Al06ijU01nRJD0RIJf09VVb02Q[m80X:kC0P2O
[m4P0:2^d@P0XJoB0`2P[]450:6_dP@0X[7B0P2S/]<20:Bce080YK;D0`2V
/mD30:NdeP060;2nf@31bn@0bm;T0<oCgP2BTiP0oooo0P3ooodB0?ooo`00
803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3J
f]X0UIB?08Z8N`2IU840Z::<0;^cW034_:EP0<S0Z@<0aknX3@38`:T80<[2
Z`<0bL6Z1@3:`Z/30<[2[@X0bl>^203<a:l80<g5/0P0c/Ja0`3?ak80403=
a[<0c/Rb0<k8/P3>b;80d/fi0=_Ea@3SgM40i]oE059FF@1<EWX0DVF@05Yd
V@1VNk00KH2k06Z0/P1YP[PX06Z1]`d0Jh2g0`1/PKP306b1]PD0KH:g1@1^
PkP306n4^@<0KhFg1`1`Q[P60767^@<0LhNj0`1dR;/207F9_080MHVk1P1f
R[`0101gRkd0N8bn07R<_P1hS;h407V=_`0407V>_@1jSkh0NXnn07Z?_P@0
Ni2o00@0OHno07j@`01nT<00OY30101oTL40101oTKl0P9;0082B`020T/04
086C`@@0PYC21023UL<208>F`@H0Q9O20P26Ul<608NHa0<0R9W41@29V/D0
3029W<H0RI_908VJa@2EY/@0Z[SE0;O0h@34bMd0S92A0?Shn03no_h0oooo
0?knoP80oooo00<0oOgm0?ooo`3oool0H03oool20?knoP0D0?gmo@3inOT0
lO7a0>SXj03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@TP1hOI40OXVW08VI/`2H
Y/T0X:kA09n]d02P[]40XJoB09n]d02Q[m850:2^d@0B0:6_dP2P[]40WZc?
09f[cP2HY/<0TYno08fJ_02:UkT0RIBd08^F]02:U[00F6Al06ijU01nRJD0
RIJf09VVb02Q[m80X:kC0P2O[m4P0:2^d@P0XJoB0P2P[]460:6_dP<0X[7B
0`2S/]<20:Bce0040:Fbe02V/mD0Y[?E0:Jce@@0YkCF00H0/;kI0<7;i03;
d^@0d=CO09:CV03oool20?oooA80oooo000P0?ooo`0@0?knoP3moOd0nOWi
0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0
^k>L0<BlYF00b<2Y0P37_jP>0<S0Z@P0b/:[0P39`JX60<[2Z`80b/:]2P3;
`jh80<c4[`P0cLF`203>a[440<o7/P0@0<k7]03>b;80c/Rb0<k8/P3BcKT0
fmG50>?Md@3Wh=H0DUII04aFNP1BII00FWBI06Ik/01]P;/0JX2b06V2^2P0
JX6g301[P;L406b1^080K86f1P1]P[L406j3^0@0KhBi0P1_QKL60726^0D0
LHNi0`1bR;X207>7^P<0M8Rk0`1eRK`507J:_0<0Mh^m0`1hS;h307V=_`80
NXk00`1jSkh307^@_`80O9700`1nT<0307nA`@80P9;20`20T/03086C`@D0
PYC21@23UL<508BG`P<0QIS31@27V<@308RIa@80R9W41P29V/D03029W<H0
RI_908VJa@2FYlD0Z[SE0;S1hP34bMd0S92A0?Shn03no_h0oooo0?knoP80
oooo00<0oOgm0?ooo`3oool0H03oool20?knoP0D0?gmo@3inOT0lO7a0>SX
j03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@TP1hOI40OXVW08VI/`2HY/T0X:kA
09n]d02P[]40XJoB09n]d02Q[m850:2^d@0B0:6_dP2P[]40WZc?09f[cP2H
Y/<0TYno08fJ_02:UkT0RIBd08^F]02:U[00F6Al06ijU01nRJD0RIJf09VV
b02Q[m80X:kC0P2O[m4P0:2^d@d0XJoB0`2R/=<20::adP<0Xk;C0`2T/m@3
0:Jce@<0YkCF0P2X]ML01P2a_mX0`L_T0<_Bi03@e=l0TY>H0?ooo`80ooom
4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cL
g03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bUIP38`:T:0<W1ZPh0
b/:[0P3;`j`60<_3[P80c<B_103;`jh80<c4[`P0cLF`203>a[440<o7/P0@
0<k7]03>b;80c/Rb0<k8/P3Cc[X0g=K60>?Md@3Wh=H0DUII04aFNP1BII00
FWBI06Ik/01]P;/0JX2b06V2^2P0JX6g301[P;L406b1^0H0KH:g1P1^PkP4
06n4^@H0L8Jh1@1aQkT507:8^P<0M8Rk0`1eRK`207J:_@<0MXZl1@1gRkd2
07R<_P<0NHfo0`1jS/0207Z?_P<0Ni2o0`1lTL0207j@`0<0Oi710`20T/82
082B`0<0PI?10`22U<8508>E``<0Q9K40`24Ul8508FH``<0QiS41@28VLD6
08VJa@80RY_600`0RIc608VKb@29V/D0UZO50:Zhe@2h`N80aL[N08b@T@3h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0600oooo0P3no_h0
503moOd0nOWi0?7al@3Xj>P0hN7Q0=gOfP3JfMh0g=[M0=_LeP2?T980N7fA
07j9Y`29VK<0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB1@2P[]404P2Q
[m80X:kA09j/c`2MZlh0V:K309:O_`2=V[`0RYNi08VD]02;U[@0RYJ`05QT
O01^NY@0OXVU08VF]P2IY/P0XJoB0:2^d`80WjoA802P[]4;0:6_dPD0X[3C
0`2S/]<30:Bce080YKCE0P2V/mD30:NdeP<0Z;GG00H0/KoJ0<;<i@3<dnD0
d=CO09:CV03oool20?oooA80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L
0<BlYFD0b<2Y2`39`JX=0<[2Z`<0bl>/1@3;`jh30<c4[`<0bl>^203<a:l8
0<g5/0P0c/Ja1@3?ak80403>ak@0clVc0<k8/P3?bK<0dljj0=cFaP3Tg]80
in3F059FF@1<EWX0DVF@05YdV@1VNk00KH2k06Z0/P1YP[PX06Z1]`/0Jh2g
1@1/PKP506f2]`H0KX>h1@1_Q;T50726^0<0LHNi1P1bR;X207>9^`80M8Rk
0`1eRK`307J:_@H0Mh^m0P1hS;h407V=_`<0NXk000<0Nho107^@_`1kT;l0
0P1kT;l307bA`00307fB`@1oTL40Oi710080Oi710`20T/800`21Tl<0PI?1
086C`@02086C`@<0PYC21@23UL<408BFa0H0QIS30P26VL@608RIa@80RI[6
1@29V/D308ZKaP0<08VLaP2:W<X0RY_609JWa@2[^MH0^<7R0<G:gP2<T940
n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1P0?ooo`80o_kn
01@0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0f]WN0=cJg@3Kg=H0Si2B07Qm
T@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dPD0X:kA0180
XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0SIZl08ZG^@29U;@0RiJd08ZF/01H
I7`0KWZD07j9Y@29U[H0VJK80:6_dP2P[]<209n_dB00X:kA202Q[m860::`
d`80Xk7D0P2S/]<30:Bce0<0YKCE102W]=H30:Ree`070:Vff02a_mX0`/cU
0<cCi@3@e=l0TY>H0?ooo`020?oooA80oooo000P0?ooo`0@0?knoP3moOd0
nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2X
XX`0^k>L0<BlYF@0b<2Y3039`JX<0<[2Z`@0bl>/103;`jh40<c4[`80bl>^
203<a:l80<g5/0P0c/Ja1P3?ak80403>ak@0clVc0<k8/P3?bK<0dljj0=cF
aP3Tg]80in3F059FF@1<EWX0DVF@05YdV@1VNk00KH2k06Z0/P1YP[PX06Z1
]`X0Jh2g1P1/PKP406f2]`H0KX>h1P1_Q;T40726^0@0LHNi1@1bR;X307>9
^`80M8Rk0P1eRK`407J:_@D0Mh^m0`1hS;h307V=_`<0NXk00P1kSl4307^@
_`<0O9700P1mT/4307nA`@<0P9;20P21Tl<3086C`@<0PYC21023UL<608BF
a0D0QIS30`26VL@508RIa@<0RI[61029V/D408ZKaP0<08VLaP2:W<X0RY_6
09JWa@2[^MH0^<7R0<G:gP2=TI80n?Sh0?knoP3oool0o_kn0P3oool00`3m
oOd0oooo0?ooo`1P0?ooo`80o_kn01@0oOgm0?Win@3alO40j>SX0>7Qh@3M
gmX0f]WN0=cJg@3Kg=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^
d@2Q[m80Wjg@0:6_dPD0X:kA0180XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0
SIZl08ZG^@29U;@0RiJd08ZF/01HI7`0KWZD07j9Y@29U[H0VJK80:6_dP2P
[]<209n_dB00X:kA202Q[m850::`d`<0Xk7D0P2S/]<20:Bce0@0YKCE0`2W
]=H30:Ree`80ZKKH00H0//3K0<;<i@3<dnD0dMGP09:CV03oool20?oooA80
oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0
f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYF@0b<2Y3039`JX<0<[2
Z`@0bl>/103;`jh;0<c4[`P0cLF`203>a[480<o7/P0A0=38/`3>ak@0clVc
0<k8/P3?bK<0dljj0=cFaP3Tg]80in3F059FF@1<EWX0DVF@05YdV@1VNk00
KH2k06Z0/P1YP[P0:01ZPKL806^0]`L0K86h00<0KH:i06f2]`1]P[L00P1]
P[L406j3^0L0KhBi00<0L8Fj0726^01`Q[P00P1`Q[P40767^@@0LXRj101c
RK/0101dR;/0MHVl07F9_01eRK`307J:_@0307N;_P1gRkd0Mh^m0080Mh^m
101hS;h307V=_`80NXk00`1kSl4307^@_`80O9700`1mT/4307nA`@80P9;2
0`21Tl<3086C`@80PYC20`23UL<708BFa00308FGa@25V<<0QIS30080QIS3
1026VL@408RIa@@0RI[61029V/D408ZKaP0<08VLaP2:W<X0RY_609JWa@2[
^MH0^<7R0<G:gP2=TI80n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo
0?ooo`1P0?ooo`80o_kn01@0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0f]WN
0=cJg@3Kg=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^d@2Q[m80
Wjg@0:6_dPD0X:kA0180XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0SIZl08ZG
^@29U;@0RiJd08ZF/01HI7`0KWZD07j9Y@29U[H0VJK80:6_dP2P[]<209n_
dB00X:kA202Q[m840::`d`@0Xk7D00@0Xk;C0:Bce02T/m@0Y;?D0`2U]=D0
102V]MH0YkCF0:NdeP2W]=H20:Ree`<0ZKKH00H0//3K0<?=iP3=e>H0dMGP
09:CV03oool20?oooA80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[
jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<Bl
YEP0b<2Y2@37_jP70<S0Z@P0b/:[00@0b/:]0<W1[039`J`0b/:[0P3;`j`2
0<_4ZP0Q0<K0YP39`jT0c/R`0<_5[`34_JX0b<6_0<g6]039`[80cLF`0<_3
[P3<a:l0clNb0<o7/03<a:d0bl>/0<g5[P3>`K00cl>]0<g1Y`3=a:L0d/V/
0<o5[039`J`0cLFb0<g7/@3;aJl0c<J`0<g7/@3<a[00cLNa0<k8/P3:a:h0
c<J`00L0cLNa00<0cLJc0<k7]03>ak@01@3>ak@0403BakD0clNd0<_3[P3>
b;80e/nl0=_F``3LfLX0in?G055EF01>F7<0EFJB05acW`1VNjX0KWji06]n
^@1/PkDP06Z1]``0Jh2g101/PKP406b1]PD0KH:g1`1^PkP406n5]`D0L8Jh
1`1aQkT307>7^@80M8Rj101eRK/707J:_0<0Mhbk0P1hSK`607V>_@80NXnn
0`1kT;l307f?_@80OY2n101oTKl3082B`0<0PI?100<0PYC2086C`@22U<80
1P22U<8408BG`P@0QIS300<0QYO308NHa027V<@01@27V<@408RIa0P0RI[5
1@2:VlH02`2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3o
ool0o_kn0080oooo00<0oOgm0?ooo`3oool0H03oool20?knoP0D0?gmo@3i
nOT0lO7a0>SXj03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@TP1hOI40OXVW08VI
/`2HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m850:2^d@0B0:6_dP2P[]40
WZc?09f[cP2HY/<0TYno08fJ_02:UkT0RIBd08^F]02:U[00F6Al06ijU01n
RJD0RIJf09VVb02Q[m80X:kC0P2O[m4Q0:2^d@L0XJoB0`2R/M820:>bd`<0
Y;?D00@0YK;D0:Jce@2V/mD0Y[?E0`2W]=H0102X]ML0Z;GE0:Ree@2X]MD2
0:VfeP<0Z[OG00D0/l7K0<?>i03<dnD0d=CO09:CV00E0?ooo`00803oool0
403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?
08Z8N`2IU840Z::<0;^cW034_:EV0<S0Z@80bL6Z203:`Z/30<W1[0<0b/:[
0P39`JX02P3>ajd0bL6Z0<NoZ03:a:h0cLNa0<g6/`3>ak@0d/^i0=G@_@3D
ck`20=?>^`0B0=G@_@3FdKd0eM2l0=C?^`3Fckl0d<Vg0=39]P3?bK<0bL>]
0<W2[`3<aKD0b/:e0<c6/03:a:h0c<J`0<k8/P3<a[00cLNa0P3?bK<60<g7
/@80c/Rb1P3>ak@20<o8]@80dLVf00h0dLVd0<k8/P3Ac;P0gMO70>3McP3V
h]H0E5ML04iHL`1CI900G7>O06Qm[01^O[T0JGfh06V3]200JX6g301[P;L4
06b1^0@0K86f101]P[L606j3^080KhBi101_QKL40726^0H0LHNi0P1bR;X2
07>7^@<0M8Rj0`1eRK/607J:_080Mh^m0P1gS;/307R=_0D0NHjm0`1jSkh3
07^@_`80OHnm0`1nT;h307nA_`@0P9;00P21Tl4808:D`P80PiG31024Ul84
08FH``H0QiS40P28VLD408RIa0P0RI[51@2:VlH02`2;W<X0Rig509NXaP2Z
^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0080oooo00<0oOgm0?oo
o`3oool0H03oool20?knoP0D0?gmo@3inOT0lO7a0>SXj03QhN40gMoJ0=[I
gP3Lf]d0fmcF08n@TP1hOI40OXVW08VI/`2HY/T0X:kA09n]d02P[]40XJoB
09n]d02Q[m850:2^d@0B0:6_dP2P[]40WZc?09f[cP2HY/<0TYno08fJ_02:
UkT0RIBd08^F]02:U[00F6Al06ijU01nRJD0RIJf09VVb02Q[m80X:kC0P2O
[m4P0:2^d@H0XJoB0P2R/=<20::adP<0Xk;C0`2T/m@40:Jce@80YkCF0P2X
]ML20:Ree@<0ZKKF0`2Z]mL01@2c`M/0`lkT0<gDiP3@e=l0TY>H01D0oooo
000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN
0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYFD0b<2Y0`39`JX80<[2Z`80
bL6/0P3:`Zd20<[2Z`<0bL6Z00X0bl>/0<[2[@3<a:l0dL^e0=?=]`3Fck`0
g=G20=_IbP3OgLh0hMo@0`3Pg/l04P3Mfl`0f=K70=WEb@3DdL80eM;10=CA
`03@b[X0clVk0<o9_@39`[P0cLNa0<_5[`3=ak40clVc0<c6/03:a:h0c<J`
0<o9/`D0cLNa0`3>b;850<k7]0<0clRe0P3?ak@03P3BbkP0c/Nd0=?>^`3Q
fl/0iN7E0>KRe`1DEeh0CEIc055TS`1LLil0J7f/06in^@1XO;L0J8:c801Z
PKL;06^0]`D0K86h0`1/PKH506f2]`D0KX>h0`1_Q;T306n5]`D0L8Jh101a
QkT407:8^P0407>7^@1dR;X0M8Rj07B8^P@0MHVk101fR[`407N;_@0407N<
^`1hSK`0N8fl07R=_0D0NHjm0`1jSkh407^@_`0407f?_@1nT;h0OY2n07j@
_P@0Oi6o0`20T/03086C`@H0PYC21023UL<308BG`PD0QIS31@27V<@308RI
a@<0R9W42029V/D608ZKaP0;08^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bB
T03hn?P0o_kn0?ooo`3no_h00P3oool00`3moOd0oooo0?ooo`1P0?ooo`80
o_kn01@0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0f]WN0=cJg@3Kg=H0Si2B
07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dPD0X:kA
0180XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0SIZl08ZG^@29U;@0RiJd08ZF
/01HI7`0KWZD07j9Y@29U[H0VJK80:6_dP2P[]<209n_dB00X:kA102Q[m84
0::`d`040::adP2S/]<0Xk;C0:>bd`@0Y;?D0`2V/mD30:NdeP80Z;GG00@0
Z;GE0:VfeP2Y]]H0ZKKF102Z]mL01@2c`M/0`lkT0<gDiP3AeN00TY>H01D0
oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0
f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYF@0b<2Y1039`JX80<[2
Z`030<W1ZP3:`Z/0bl>^00D0bl>^00T0bl>`0=79]P3Gck`0fM:o0=gF``3P
flP0iN3=0>[UdP3Vi=L00P3Xi]X04P3Vi=P0h^3D0>7Od`3Rh=@0hn7E0=gK
c03Qh<h0gM[90=OD`@3Hdl00eLjl0=39]`3BbKP0c/Rb0<_5[`3<a[00c/Rb
0<g7/@80b/B^00<0c<J`0<g7/@3=ak400P3=ak440<k8/P@0c/Nd103?b;D0
403?ak@0cLFb0=39]P3?b;D0f=?00>3McP3Vh]L0inCM04iAF01;E7<0DVBB
05abX@1WNjd0KH2j06Um^01XP[<P06Z1]`X0Jh2g1P1/PKP206b1]PH0KH:g
101^PkP406n4^@80KhFg1P1`Q[P30767^@D0LXRj0`1dR;X307F9^`D0MXZl
1@1gRkd307R=_0<0NHjm1@1jSkh307^@_`80O9700`1nT;h307nA_`@0P9;0
0`21Tl4608:D`PD0PiG30P24Ul8608FH``@0QiS41028VLD208RIa0P0RI[5
1`2:VlH02`2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3o
ool0o_kn0080oooo00<0oOgm0?ooo`3oool0H03oool20?knoP0D0?gmo@3i
nOT0lO7a0>SXj03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@TP1hOI40OXVW08VI
/`2HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m850:2^d@0B0:6_dP2P[]40
WZc?09f[cP2HY/<0TYno08fJ_02:UkT0RIBd08^F]02:U[00F6Al06ijU01n
RJD0RIJf09VVb02Q[m80X:kC0P2O[m4M0:2^d@H0XJoB1@2R/=<30:>bd`<0
Y;?D0P2U]=D20:Jce@<0YkCF0`2X]ML30:VfeP<0Z[OG0P2[^=P01@2d`]`0
a<oU0<gDiP3AeN00TY>H01D0oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L
0<BlYF@0b<2Y1039`JX90<[2Z`80bl>/02D0bl>^0<[2[@3;`k00c<Ba0<k6
/`3Dbk`0e<fm0=gFaP3Ugm40i^;F0>_Yg03^k>00jnWM0?7^i`3RgmX0clc7
0<:o^P2i]K80][:_0;^g]P33_kh0d=710=_IbP3Nfl`0g]S80=oHa@3Jd[d0
f<je0=gA^@3Ab[L0c/Nd0<c5/P3=a[<0c/Nd0<g6/`3<aK80c/Nd00@0cLNa
103>b;840<k7]0@0clRe0100dLVf0=39]P3@bKH0clZg0=[GaP3MfLd0jNKO
0>_Xh`17BeH0BUEe05EWU`1JLZ00I7Z[06j1^`1[P;T0J8>b801ZPKL806^0
]`H0K86h0P1]P[T606f2]`H0KX>h101_Q;T60726^080LHNi1@1bR;X307>9
^`80M8Rj0`1eRK/307J:_0D0Mh^m0`1hS;h207R=_0<0NHjm1@1jSkh307^@
_`<0O9700P1nT;h307nA_`<0P9;00`21Tl4308:D`PL0PiG30`24U/@608FH
``80QYW41027V<@408RIa@H0RI[5202:VlH208^La`0<08ZKaP2;W<X0Rig5
09NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3m
oOd0oooo0?ooo`1P0?ooo`80o_kn01@0oOgm0?Win@3alO40j>SX0>7Qh@3M
gmX0f]WN0=cJg@3Kg=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^
d@2Q[m80Wjg@0:6_dPD0X:kA0180XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0
SIZl08ZG^@29U;@0RiJd08ZF/01HI7`0KWZD07j9Y@29U[H0VJK80:6_dP2P
[]<209n_dA`0X:kA102Q[m850::`d`<0Xk7D0P2S/]<30:Bce0<0YKCE0`2W
]=H30:Ree`80ZKKH0P2Y]]H30:Zge`<0ZkSH00D0]<;L0<C?i@3=e>H0dMGP
09:CV00E0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03N
g]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:ES0<S0Z@D0
bL6Z203:`Z/30<_3[00P0<[2[@3:`Zl0c<>b0=37]P3DbkX0f=;40>KPe03]
jMh0k>WR0>k]j@3/k>X0b/_=09nPXP1MH6L0D5=J04Y=EP1>DEX0DUAP04i@
G@1;CEX0CDmL0498B01<D540L79a0:6PW038a;/0gMO90=kF``3Bb[<0em2m
0=K?_03Ab[L30<k7]0030<g6/`3>ak@0cLNa0080cLNa1@3>b;830<k7]0D0
clRe0100c/Nd0=;;^03@bkL0dljk0=cIbP3QgM80lNkY0=WEdP18C5L0C5Ii
05AYV01KLj40IG^/06j1^`1[PKX0J8Bc801ZPKL806^0]`D0K86h0`1]P[T5
06f2]`H0KX>h1@1_Q;T50726^0<0LHNi101bR;X407>9^`@0MHVk0`1fR[`5
07N;_@@0N8bn101iS[d307Z?_PD0Ni2o0`1lTL000`1mT/40Oi6o07nA_`02
07nA_`<0P9;00`21Tl4308:D`PL0PiG31024U/@508FH``<0QYW40`27V<@5
08RIa@D0RI[5202:VlH308^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q
0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1P
0?ooo`80o_kn01@0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0f]WN0=cJg@3K
g=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_
dPD0X:kA0180XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0SIZl08ZG^@29U;@0
RiJd08ZF/01HI7`0KWZD07j9Y@29U[H0VJK80:6_dP2P[]<209n_dA/0X:kA
0`2Q[m860::`d`@0Xk7D102T/m@30:Fde@030:JeeP2W]=H0YkCF00<0Z;GG
0`2Y]]P40:Zge`<0ZkSH00H0[;WI0;C2g035d>H0c]GW0=7Eh02CU9TE0?oo
o`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[I
gP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:ER0<S0Z@H0bL6Z203:`Z/0
8@3:`jT0bl>/0<c4[@3<a:l0c/Jc0=C;^P3Ldl@0hMS90>STf@3[j=l0kNcW
0>OWi`2h^Kh0Jfig04U=F@1LHW00FFEm04mKM@19EFl0BeIb04iIM`1>FGT0
CeUl055KOP1?GWd0BUQe04YDK`18CVH0BTeL06a]LP2XZJ@0e]K>0=39]P02
0=K?_0030=7:]`3@bKH0clRe0080cLJc0P3=ak460<k8/P80c/Nd1P3?b;D0
403<aK80d/^h0=;=^P3Je<@0hmoC0>_Xg`3_jnP0VYJE05AHI01?FG`0DfNI
05eeY@1WOJh0K86j06Uo^01YQK@P06Z1]`P0Jh2g101/PKP406f2^@@0KH:g
1P1^PkP606n4^@@0L8Jh101aQkT207:8^PH0LhVk0`1eRK/307J:_0@0Mh^m
1P1hS;h307V>_@<0NXnn1@1kT;l307bA`080OI;10`1oTKl3082B`0@0PI?1
0P22U<8608>E``H0Q9K41025V<<408JIa080QiS41P28VLD408VJa@P0RY_6
102;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0H03oool20?knoP0D0?gm
o@3inOT0lO7a0>SXj03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@TP1hOI40OXVW
08VI/`2HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m850:2^d@0B0:6_dP2P
[]40WZc?09f[cP2HY/<0TYno08fJ_02:UkT0RIBd08^F]02:U[00F6Al06ij
U01nRJD0RIJf09VVb02Q[m80X:kC0P2O[m4K0:2^d@80XJoB1@2R/=<60:>a
e0<0Y;?D0`2U]=D20:JeeP80YkCF0P2X]ML40:Vff0<0Z[OG0`2[^=P20:bi
f@050;G3g@35d>H0c]GW0=7Eh02CU9T05@3oool00200oooo0100o_kn0?gm
o@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB1
0:RRS02k/i`0a;bUF038`:T?0<W1ZPT0b/:[02H0b/>Y0<_3[03=aJh0clNb
0=C<^@3Me<<0j=o@0>oVe`3]j^40no_c0<30_P1YJVh0E5IR05mUM@1HGW@0
C59Z04=IOP16G8<0Bf6804iTS@1?I8l0D6FB055VU@1CJ9L0DFJM05=WW01C
IIL0EVF@05MQQ01?Efh0CE=O05QMH`2o^:D0c/Nd0=G>^`3DcKX0dlbi0=;;
^080clRe1`3>b;800`3?bK<0clRe0<o8]@050<o8]@0A0=39]P3?b;D0dlbi
0=KA_P3PgL`0j^KJ0?CajP3Th=d0EE=D05iQL01BG800DVJH05mgY`1YPK40
K86j06Mm]P1YQK@0801ZPKL806^0]`@0K86h101]P[T406f2]`@0KX>h1`1_
Q;T00`1`QKX0L8Jh0726^0020726^0@0LHNi1`1cRK/0101dR[`0MHVk07F9
^`1eRK/207J:_0<0Mh^m1`1hS;h0101iSKl0NHjm07V>_@1iS[d207Z?_PH0
Ni2o0P1lTL0307fB`@<0Oi6o0P20T/04086C`@<0PYC20`23UL<808BFa003
08FGa@25V<<0QIS30080QIS31026VL@708RIa@0308VJaP29V/D0RI[50080
RI[5202:VlH408^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<
TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`1P0?ooo`80
o_kn01@0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0f]WN0=cJg@3Kg=H0Si2B
07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dPD0X:kA
0180XJoB0:2^d@2N[<l0WJ_>09RV``2BWkl0SIZl08ZG^@29U;@0RiJd08ZF
/01HI7`0KWZD07j9Y@29U[H0VJK80:6_dP2P[]<209n_dA/0X:kA0P2Q[m83
0::`d`L0Xk7D00@0Y;;E0:Bce02T/m@0Y;?D0P2U]=D30:JeeP040:NdeP2X
]ML0Z;GG0:Ree`<0ZKKH00@0Z[OI0:Zge`2Z]mL0Z[OG0P2[^=P30:bif@05
0;G3g@35d>H0c]GW0=;Fh@2CU9T05@3oool00200oooo0100o_kn0?gmo@3i
nOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RR
S02k/i`0a;bUB038`:T80<NoZ0P0bL6Z1038`:T40<W1ZPP0b/:[0`39`J`2
0<[2Z`0I0<_3[03:`jT0b/>Y0<ZoZ@3>a[40clJg0=38_@3PfLl0iMkF0>kZ
g`3dl>D0gMkH08R:Q`1BFEl0Dem]04mNM@17F7H0BUYn04UKP@1?IY80DFRD
05E/V01IL9`0G7>O05edX00205acW`0]05ibY@1MLJ@0FfnQ05U^W@1IKY/0
EfbG051VS`19GhP0@DUD07]nP`32_KL0g<no0=_<]`3GckP0c/^h0<c?_03>
akD0d<Vf0<o7/P3>aZl0d/Nc0=74/@3@`k80e<Ng0<k:/@3@c;<0c/Z_0<g9
[03Ac:l0d<Z`0<o9/@3AbkD0cLjn0=OFa03Sg//0j^?A0??]g`3`l>P0S9:B
059KH014EWh0D66<05e_W@1TN:X0JGna0080JX6e00<0Ih6b06Z1]`1ZPKL0
5P1ZPKL806^0]`@0Jh2e201/PKH506f2]`L0KX>h00@0KXBf06n5]`1_QKL0
KhFg0`1`Q[P50767^@@0LXRj00@0LhNi07B8^P1dR;X0M8Rj0`1eRK/00`1f
R[`0MHVk07J:_00607J:_00407N<^`1hSK`0N8fl07R=_0<0NHjm00<0NXnn
07V>_@1jSkh00P1jSkh307^@_`0307bA`01mSkd0OY2n0080OY2n0`1oTKl5
082B`0@0PI?100<0PYG008>F`@23U/401@23U/4408BG`P@0QIS31027V<@4
08RIa@@0R9W41@29V/D708ZKaPP0Ric700T0RYc408^LbP2=WlL0UJK40:Vg
e02j`^H0a<[P08bAU03inOT00P3oool0103no_h0oooo0?ooo`3no_h30?oo
o`H0o_kn00@0oOgm0?ooo`3no_h0o_kn103oool01@3moOd0o_kn0?ooo`3o
ool0o_kn0080oOgm103no_i60?ooo`80o_kn01H0oOgm0?Win@3alO40j>SX
0>7Qh@3MgmX0f]WN0=cJg@3Kg=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40
Wjg@0:2^d@2Q[m80Wjg@0:6_dP2P[]40XJoB0P2P[]420:6_dP0C0:2^d@2N
[<l0W:[=09NVa@2BXL80SY^m08^H^P27U;@0R9Ja08RD[01GHgT0LGfG07j9
Y@2<VKT0V:G70:2^d@2Q[m@0WZk@0:2`dP080:2^d@80XZ_D00H0XJgC0:6^
d@2Q[]00Wjk=09j]c02N[LX209n^c`<0X:o@0`2Q/=4409n_d@040:2`d@2Q
/M80XK7B0::bd`<0X[7B0P2S/]<30:Bce0<0Y[?E0P2W]=H30:Ree`040:Re
e@2Y]]H0ZKKF0:VfeP<0Z[OG00@0ZkSH0:^ieP2[^MH0ZkWF0P2/^]L30:fk
f0060;G3g@34cnD0cmKV0=?GhP2ATYL0o_ko0P3ooodB0?ooo`00803oool0
403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?
08Z8N`2IU840Z::<0;^cW034_:E80<S0Z@P0aknX2039`JX40<S0Z@@0bL6Z
203:`Z/20<W1[0030<[2[@3:`Z/0bl>/00<0bl>/01@0cLF`0<g5/P3Cc;X0
i=k@0=kJc`3elNP0lNkY0;bi]01MH6L0DUIR059JK@1AGgT0AeMh04UKP`1G
J9<0FfbH05ecY01OMJH0HWRY06Ek[0<0Igf^02h0IWb]06Mk/01WNjh0IGV/
06=gZ@1SN:L0HGJS05aaWP1FJiH0G6^:04MAJP18C5P0W9RG0=OAa@3Cc;T0
f=:j0=;>/`3GdL40d/fj0=;=^@3Ac;H0c/Rb0<o8]@3Ab[X0c/Ng0<_6/`3?
b[H0dL^e0=3:]03?bK<0cLJc0<o8]P3Fckl0e=;50>;NdP3Xh=<0m^gT0?Wd
l02d/kP0C59N05IRLP18FX80E6F@061bX01WNjd0JX2b0P1ZPKD00`1WPK80
JX6g06Z1]`0F06Z1]`P0Jh2g101[P;D806b1]P@0KH:g1P1^PkP206n4^@@0
KhFg0P1`Q[P50767^@D0LXRj101dR;X207F9^`P0MXZl0P1gRkd407R=_080
NHjm1P1jSkh207^@_`80O970101nT;h207nA_`D0P9;01@21Tl4608>F`@H0
Q9O21025V<<408NHa0@0R9W51028VL@408VJa@H0RY_62P2;W<L04@2;WLD0
Ric:08bNaP2EY/@0ZKOD0;W1i@33bMl0Ri2C0?Shn03no_h0oooo0?gmo@3n
o_h0oooo0?knoP3oool0o_kn00L0oooo00<0o?cl0?ooo`3moOd00P3lo?`2
0?[jnP030?knoP3moOd0o_kn00H0oooo00<0o_kn0?ooo`3oool0AP3oool2
0?knoP0F0?gmo@3inOT0lO7a0>SXj03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@
TP1hOI40OXVW08VI/`2HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m80X:kA
0:6_dP<0X:kA01@0XJoB0:2^d@2N[<l0W:[=09NVa@2BXL80SY^m08^H^P27
U;@0RINb08VE[@1HI7X0L7bF07j9Y@2;V;P0V:G70:2^d@2Q[m@0WZk@09n_
d@P0X:kA0P2S[mD00`2R[]@0XJoB0:6_dP020:6`d@030::adP2Q[m80XJoB
00<0X:kA0P2Q[m800`2R/=<0X;3D0:2`dP030:2`dP030:6ad`2R/]<0X[;C
0080X[7B0`2S/]<30:Bce080Y[?E0`2W]=H30:Ree`@0ZKKF0P2Z]mL20:^h
f080ZkWF0`2/^]L30:fkf0060;G3g@34cnD0cmKV0=?GhP2ATYL0o_ko0P3o
oodB0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0
g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:E80<S0Z@P0aknX
2039`JX30<S0Z@D0bL6Z203:`Z/20<W1[0030<[2[@3;`jh0bl>/0080bl>/
01D0c<B]0=37^03Ec[`0hmk;0>WVe@3`k^40lO3[09jNX01JFV80Ff5k05AK
N01>Fgd0CUf604iPSP1IKYd0I7RZ06Ei[01XO[00JGna06Z0/P1[PK<00`1/
P[@0<@1[PK<0K7ng06ao]`1[Ok@0JWja06Um/01XO:h0IGV[065fY@1UNZl0
EV^J05EUQ`11C600KG9f0<30]03Ed;X0fmBg0=3=_03DdKh0emG00=GC_P3@
c[T0d<fj0=7>_@3?c;d0clNl0=38^`3?b;P0dLZj0=C=_@3Fc/40fM760=oF
c@3Xh]H0jnCJ0??Zh`3on?H0a/?:06i_P@1DFgL0D5em04iQR`1IK9L0IWRX
06Yn/@1[P;D0Jh:f06Z1]@1YP;80601ZPKL806^0]`<0Jh2e201/PKH506f2
]`D0KX>h0`1_Q;T306n5]`<0L8Jh101aQkT607:8^P<0M8Rj0`1eRK/607J:
_0@0Mh^m0`1hSK`307V>_@D0NXnn0`1kT;l207bA`0<0OY2n0`1oTKl4082B
`0H0PI?11@23U/4608BG`PD0QIS30`27V<@508RIa@<0R9W41@29V/D508ZK
aP/0Ric70140S9k608^LbP2<W/H0UJK40:Vge02i`ND0`/SN08V>T@3gmoL0
oOgm0?knoP3moOd0o_kn0?ooo`3no_h0oooo0?gmo@020?knoP80oooo00<0
o_kn0?gmo@3moOd00P3jn_X20?Win@050?[jnP3gmoL0n?Sh0?gmo@3kno/0
0P3lo?`01@3jn_X0no_k0?knoP3oool0oOgm04T0oooo0P3no_h05P3moOd0
nOWi0?7al@3Xj>P0hN7Q0=gOfP3JfMh0g=[M0=_LeP2?T980N7fA07j9Y`29
VK<0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB0:2^d@2Q[m850:2^d@0B
09j/c`2MZlh0V:O609>R``2?W;h0S9Vk08RE]@29Uk80RYJ^05UUN`1_NiD0
OHRT08^H^02HYLL0X:kA0:6_e02N[]00WjoA202P[]420:6_dP030:2^d@2O
[m40WjoC00<0WjoC1P2P[]<20:6_e0030::`e@2Q[m@0XJoD0080XJoD00@0
X[3C0:>ae02S/M@0X[7B0`2S/]<40:Bce0040:Jce@2W]=H0YkCF0:NdeP@0
Z;GG0`2Y]]H30:Zge`80ZkSH00@0ZkWF0:bje`2/^]L0[;[G102]^mP0202f
a=h0aM3V0=3Gi`3Cen80TI:G0?kno`3oood0o_kl4P3oool00200oooo0100
o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:
R7/0VIB10:RRS02k/i`0a;bUB038`:T80<NoZ0P0bL6Z0P38`:T60<W1ZPX0
b/:[01<0bl>^0<c4[`3;`jh0b/:]0<c4[`3>a[40cLFj0>;LcP3Wi=<0inSH
0?Khk@2=TI80Fem[05MLL01=EWd0AeEl04UJQP1DJIP0H7JW0080I7Z/00<0
IWb^06Yo]01ZOk@01P1ZOk@0:`1[P;T0Jh2g06^0]`1ZOkH0JWnd06Un/`1X
O[00Igf_05id[P1TN[<0FW:R05abV@15EFh0?DI?08Z<R@3?cL40fM?50>7K
b`3JeL80dLnj0=WG`03He/40d/nl0=KC`03KdlP0f];50=WB`P3Jdl<0g=K8
0>3JcP3Ug]@0jnCL0>gWf`3gl>H0mO3/0;Bb]@1dMX<0Eeeg04mLOP16EGh0
EFZE05mdX@1YOJl00P1[P;D206Z1]@0306Z1/`1ZPKL0JX6g01H0JX6g201[
P;L206^0]@P0K86f1P1]P[L406j3^0@0KhBi0P1_QKL30726^0<0LHNi1@1b
R;X307>9^`80M8Rj0`1eRK/607J:_0D0Mh^m0P1hSK`307V>_@D0NXnn0`1k
T;l307bA`080OY2n0`1oTKl3082B`0D0PI?10`22U<8408>F`@H0Q9O21P25
V<<208NHa0H0R9W50P28VL@608VJa@@0RY_6302;W<L0302<W/H0RY_908bN
aP2FYlD0Z[SE0;W1i@32b=h0RXnB0?Ogm`3moOd0oooo0?knoP80oooo00<0
o_kn0?ooo`3moOd00`3moOd02@3lo?`0n_[j0?Win@3hn?P0m_Kf0?;blP3`
l?00lo?c0?Cdm0020??cl`050?Gem@3dm?@0n?Sh0?_kn`3moOd00P3oool0
0`3no_h0n_[j0?ooo`180?ooo`80o_kn01H0oOgm0?Win@3alO40j>SX0>7Q
h@3MgmX0f]WN0=cJg@3Kg=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@
0:2^d@2Q[m80Wjg@0:6_dP2P[]40XJoB1@2P[]404P2N[<l0WJ_>09RWaP2C
X/<0Sibn08bI^`28UKD0RINb08ZF[P1IIG/0Kg^E07f8Y02;V;P0V:G70:6_
dP2Q[m@0WZk@09n_d@P0X:kA00<0WZk?09n_d@2O[m400P2O[m4209j^dP04
09j/d@2O[M00X:kA0:2^d@D0XJoB00<0X[3C0:6_dP2Q[m800P2Q[m@00`2R
/=D0Xk7F0:>aeP030:>bd`<0Y;?D0P2U]=D30:NdeP<0Z;GG0P2Y]]P20:Vf
eP<0Z[OG0`2[^=P30:bje`<0[K_H0P2^_=T0202fa=h0aM3V0=3Gi`3Cen80
TY>H0?kno`3oood0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c
0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0
a;bUD038`:T>0<W1ZPX0b/:[01P0bl>/0<[2Z`3;`j`0bl>^0<[2[@3:`Zl0
c/Jc0=?;^03TgM<0h=cA0>o]h03dm^/0OXB2059JI@1DG7<0E5en04MFP@1E
IY80GW>P05mgY`1SNZ`0Igj`06V1/@1]Pk@206Z1]`<0JH2f0`1ZPKL206b1
^P<0K86h0P1[P;L03@1/PKP0Kh2d06Il[P1TO[40G7JW05acW@1JKHh0BEE_
0457G@2>RHD0`;^e0=oKc`3OfLT00P3NfLH06P3NelD0h]_90=gGb@3Qfl/0
i^3@0>GRd@3Uh]<0i^CG0>_Xg`3_k>D0moGY0>GUg@2GUiD0FeiU05]RM015
D6`0BUYn05IYT`1NM:<0I7Z[06^1/`1[P;D0JWnf06^0]`1[P[H0Jh:d601Z
PKL806^0]`H0K86f201]P[L606j3^0@0KhBi0`1`Q[P30767^@D0LXRj1@1c
RK/307F9^`<0MXZl1`1gRkd307R<_P<0NHjm0`1jSkh507^@_`<0O9700P1m
T/4307nA_`<0P9;01@21Tl4508:D`P@0PiK11024Ul8608FH``80QYW41P28
VLD208VJaPH0RI[51P2:VlH<08^La`0<08bNaP2:VlT0Rig509JWa@2Z^=D0
^L7U0<;8gP2<TI@0n?Sh0?knoP3oool0o_kn103oool20?knoP080?gmo@3k
no/0nOWi0?KfmP3clo<0lO7a0>o_k`3[jn/20>WYj@80j>SX00P0j^[Z0>c/
k03^k^h0lO7a0??cl`3emOD0n?Sh0?gmoD/0oooo0P3no_h0603moOd0nOWi
0?7al@3Xj>P0hN7Q0=gOfP3JfMh0g=[M0=_LeP2?T980N7fA07j9Y`29VK<0
V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB0:2^d@2Q[m80X:kA09n]d0<0
X:kA0180Wjg@09j/c`2IZ<L0Tj;308nL_P2<VK/0R9Fe08VG/P2:UZh0F6Aj
06mkU@1mR:@0RiRh09RUa`2P[]40XJoD09j^d02O[m480:2^d@80W[7A0P2O
[m001`2Q/=40X[7B0:>bd`2T/M<0Y[?C0:Nde02Y]]H00P2[^=P01P2Z]mL0
Z;GE0:Jcd`2T/m@0Xk;C0::adP80XJoB0P2R/=D00`2S/MH0Xk;C0:>bd`03
0:Bce0<0YKCE0P2W]=H30:Ree`<0ZKKH0`2Z]mL30:^hf080[;WI0P2/^]L3
0:fkf0<0[[cI00P0]lGO0<G@iP3@enL0e=SS09:CV03no_l0ooom0?kno180
oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0
f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYE00b<2Y3@39`JX;0<[2
Z`0H0<c4[@3:`Z/0b/:[0<_3[P3;`k00c<>b0=?:^@3Ldl80i=gE0?7]i03/
jnH0QXZ;05=KIP1EH7H0BEIh04QGP01CIY40GW>P06AlZP1TOjh0J8:c06b3
]@1ZP[80J7j]1P1ZPKL206^2^00306^0]`1ZOkH0Jh2g0080K86h0P1[P;L0
:@1/PKP0JW^W06QjZP1WO[00Ih6d069l[`1KLZ@0FF^K05]/V01=Ceh0BD]G
075bM`2h][L0hn3K0>OSfP3TgM<0iMcC0>_Wf`3Xi=P0iN?F0>CUe`3YjMd0
ko3X0>g^j@3Ti^<0[[:a05UNH@1BFF<0DUi^04UGL@1>GX00F6^C05]`V`1T
O:`0J7na06^2]P1ZPKL0JWnf06^0]`1/PKH0KH>e01P0JX6g201[P;L506b1
]PP0KH:g1P1^PkP506n4^@80L8Jh0`1aQkT307:8^PH0LhVk0P1dR[`207F9
^`<0MXZl1`1gRkd407R<_P80NHjm0`1jSkh507^@_`<0O9700`1mT/4207nA
_`<0P9;00`21Tl4608:D`P80PiG30`23U/4508BG`PD0QIS30`26VL@508RI
a@<0RI[61@29V/D608ZKaPd0Ric700X0S9k608ZKb@2;WLD0UJK40:Vge02f
_^80`LOM08bAU03hn?P0o_kn103oool06`3no_h0oooo0?knoP3moOd0no_k
0?Shn03dm?@0l?3`0>g]k@3[jn/0i^KV0>GUi@3Vi^H0hn?S0>3Ph03QhN40
inOW0>WYj@3WinL0jNWY0>k^kP3bl_80m?Cd0?Ogm`3jn_X0o?cl0?gmo@02
0?knoP@0oooo00<0o_kn0?ooo`3oool0?`3oool20?knoP0G0?gmo@3inOT0
lO7a0>SXj03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@TP1hOI40OXVW08VI/`2H
Y/T0X:kA09n]d02P[]40XJoB09n]d02Q[m80X:kA0:6_dP2P[]400P2O[M02
0:2^d@0B09n]d02N[<l0VZW809FTa@2AW/00SY^m08ZG]`2:V;<0RYJ^05QT
NP1aOIL0OhZV08bI^@2HYLL0X:kA0:6_e02N[]00X;3B202P[]402`2P/=40
Wjo@09j^c`2O[/d0Xk7>0:Rfd`2_^]H0/[gI0;O3g@2iaMl0^lOQ0080_<SR
00P0^LGO0;K2g02c_mT0[;[G0:Zhe@2X]MD0Y[?C0:Fbe0<0Y;7D102T/m@3
0:Fde@030:JeeP2X]ML0Z;GG0080Z;GG0`2Y]]P00`2Z]mT0Z[OG0:Zge`03
0:^hf0<0[;WI102]^mP30:jlf@090:nmfP2gaMl0a]7W0=7Hj03Df><0TY>H
0?kno`3oood0o_kl0180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[
jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<Bl
YE00b<2Y3039`JX<0<[2Z`0C0<c5Z`3:`Z/0b/:[0<c4[`3<a;40d<Nf0=[A
`P3VgLh0k>SM0?KckP2UYJL0Ee]W055KM018EGL0Beb705EWU`1SNJP0I7Z[
06Im[`0206N0]P0306Mn]01YO[D0KH6f0080JX6e101YP;@206Z1]@0506V0
]01XOk<0J7nc06Z1]@1ZPKL00P1YP;H00`1ZPKL0Kh>e06n3]P0206Ik/00O
06Im/`1UN[40HgR]05Y^X`1NKIH0EF>804mJMP13Bf00@4A@06MWK`2OWJ80
_KRl0<g<b03Ddll0fmcG0=_Mf03=cl`0[K6b07b1Q@1@EE/0D5UZ05]VNP1>
G7H0AeQf05EWS@1@II00EFZI06IlZ`1WO[00JX6e06^2^00206Uo^00306^0
]`1/PKH0Jh6c01P0JX6g201[P;L406b1]PP0KH:g1P1^PkP606n4^@80L8Jh
0P1aQkT407:8^PD0LhVk0`1dR[`207F9^`80MXZl1P1gRkd607R<_P80NHjm
0P1jSkh607^@_`80O970101mT/4207nA_`80P9;01021Tl4508:D`P<0PiG3
0P23U/4608BG`P@0QIS31026VL@408RIa@@0RI[61029V/D608ZKaPh0Ric7
01P0S9k608ZKb@2;WLD0U:G30:Fcd02b^]h0_L?I08Z?TP3hn?P0o_kn0?oo
o`3no_h0oooo0?knoP3lo?`0oOgm0?[jnP3hn?P0mOGe0?7al@3]kNd0j>SX
0>GUi@3Shn<30>3Ph00@0=oOg`3MgMd0h>3P0=oOg`3IfMT0gmoO0>7Qh@3U
iND0jn_[0>k^kP3`l?00m_Kf0?gmo@3kno/0o?cl0?knoP<0oooo0P3no_i1
0?ooo`80o_kn01L0oOgm0?Win@3alO40j>SX0>7Qh@3MgmX0f]WN0=cJg@3K
g=H0Si2B07QmT@1nRJL0RIVc09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_
dP2P[]40XJoB0:2^d@0209n]d080X:kA0P2O[M00402M[</0V:O809BQ``2A
W/00S9Vi08bJ]@2;Ujl0F6Aj07=oV@20RjL0S9Vi09RUa`2P[]40XJoD09j^
d02P/=880:2^d@0:09n_d@2Q/=40Xk;A0:Rfd`2`_=H0^LCJ0<;:g`37cn@0
c=CW0<gEj080cmOZ00X0cMGX0<WAi035cN00`/[M0;K4gP2d`]`0/;kI0:bj
e`2Y]m@0Y[?C0P2U/]@30:Bce0<0YKCE0P2V]MH30:Ree`<0ZKKH0P2Z]mT2
0:Zge`80ZkSH102/^MT30:fkf0<0[[cI0P2__MX0202ha^00a]7W0=7Hj03D
f><0TY>H0?kno`3oood0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0
lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k
/i`0a;bUD038`:T<0<W1ZP`0b/:[01P0c<F[0<[2Z`3:`Z/0c<B_0<k6/`3C
b[T0h=O80>gTe@3bk^<0blO406i^MP1IGW80E5en04IEOP1HJYX0GG6S06Aj
[01WO[80JH:h06Z3_01XP;`0JX2l06eo_@1`P;`306^2]PD0JX6e02H0Jh:d
06V0/P1YP;80Jh:f06b3]`1[P[H0JX6g06^2^01TOKH0J7jh06j3^P1]PKH0
Jgnb06en/P1WNjh0IGV/05]e/01FKjD0EVfI05QZSP1FHW`0DUU/04mBH@1;
CEX0ADA904U8C@1:Bdl0A4Q;04I;D@1BFF<0Ff5_05ELK01=FWX0AUAg04UH
O`1>HH`0E6VH061fZ080Igba00P0IX2a06R2]@1[P[P0JX2i06Uo^01/PKP0
K86f06Z0/QP0JX6g201[P;L406b1]PP0KH:g101^PkP706n4^@030725^P1`
Q[P0LHNi0080LHNi0`1bR;X507>9^`@0M8Zl00@0MHVk07J:_01fR[`0MXZl
0`1gRkd807R<_P0307V=_`1iS[d0NXnn0080NXnn0`1kT;l00`1lTL00Ni2o
07bA`00207bA`0<0OI;100<0OY?207nA_`20T/000P20T/03086C`@D0PYC2
1023UL<708BG`PD0QIS31026VL@408RIa@@0RI[61029V/D408ZKaPL0Ric7
00<0S9g808^La`2;W<L01P2;W<L0702<W/H0RY_908^Ma@2CY<80Xk7>0:ng
f`2j`=H0R8f@0?Ogm`3moOd0oooo0?gmo@3no_h0oOgm0?[jnP3kno/0m?Cd
0?;blP3_knl0j^[Z0>KViP3Rh^80gmoO0=gMg@3Ogml0fm_K0=WIf@3Jf]X2
0=cLg00=0=3@d02m_Kd0W9bL08j>SP1oOgl0NWYj07moO`2ATI40/;2`0<W9
b@3jn_X0no_k0?gmo@030?ooo`80o_kn@@3oool20?knoP0G0?gmo@3inOT0
lO7a0>SXj03QhN40gMoJ0=[IgP3Lf]d0fmcF08n@TP1hOI40OXVW08VI/`2H
Y/T0X:kA09n]d02P[]40XJoB09n]d02Q[m80X:kA0:6_dP2P[]400P2O[M02
0:2^d@80Wjg@0100Wjk=09ZYbP2GY<H0U:7308jK^`2>W;L0S9R`05UUN`1e
PI/0PHbX08fJ^P2HYLL0X:kA0:6_e02N[]00X;3B202P[]402@2S/M@0YkCF
0:fjfP2g`]h0`LcR0<cDi`3Dfnd0f=o_0=WPl0020=[Ql@0=0=SOk`3Eg>`0
dMSX0<cCh`39d>00_LcQ0;_:h@2fa=h0/KoI0:bje@2X]]<0Y[?C0:Jce@03
0:Bce080YKCE0`2V]MH30:Ree`80ZKKH0`2Z]mT0102Z]mL0ZkSH0:^hf02[
^=P30:bif@040:fjfP2]^mP0[K_H0:fkf080[[cI0`2__MX0202ha^00a]7W
0=7Hj03Df><0TY>H0?kno`3oood0o_kl4P3oool00200oooo0100o_kn0?gm
o@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB1
0:RRS02k/i`0a;bU2038`:T90<NoZ080b<2Y00D0aknX0<JnY`35_JH0a[jW
0<NoZ0030<S0Z@D0aknX00@0bL6Z0<S0Z@37_jP0aknX0`38`:T00`37_jP0
b<6W0<S1Y`060<S1Y`80al2V0`38`JL30<O0YP80b<2Y00@0aknX0<JnY`36
_ZL0a[jW0P37_jP90<O0YP040<S1Y`39`ZP0bL:X0<W2Z080b<6W00<0bL:X
0<S0Z@38`:T00P38`:T40<W1ZPP0b/:[00<0bL6/0<[2[@3:`Zd01@3:`Zd0
403:aJL0a[nS0<k7[@39`J`0dLRg0=OAa@3/j=l0j^OP0>GVh01RIF`0F5ih
04mHO`15E7l0DfRC065gYP1VO:hP06Z1]`0H06Aj[01RN:X0GgFV05]aX01F
KIT0DVVC04iUSP1=I8d0D62404iNPP1;Fgl0BEUm04QHO019FGd0BUYn04]K
O`1:GhX0CV>>05I[V01MLZ40HgVZ06Qn/01ZP;80Jh2e401ZPKL306^0]@80
K86f0`1[P;D706Z1/`<0JH2b0`1ZPK<606^2]080K8>e0`1[P[@206b3]@H0
KHBf00<0KhJh06j5]`1^QKL0101^QKL00`1_Q[P0LHNh0767^0020767^0P0
LXRi0P1cRKX407B:^`80MH^l0P1fS;d207F;_00307J<^`1eRkX0MXbk0080
MXbk00<0Mhfl07R>_@1iSkh01P1jSkh207^@_`<0O96n101mT[l00`1nTl00
OI:o07fB_`0307jC`0<0OiC100<0OiBo082E`020UL000P20UL03086F`@80
PiK10P24Ul8808FH``80QYW40P27V/D00`26VL<0Qi[408NJa00308RKa@80
Qi[40P2:VlH208^La`80RY_60P29V/D@08^La`0F08NLb`2:W<X0R9_508nQ
a@2K[<X0YkO@0:Bcb029V:/0g=cJ0?kno03ln_d0moGh0?klo`3emoH0l?G_
0?3gk`3/l>l0j>c[0>GYj03SiN80g=kI0=_Mf080gMkH01T0g=_F0=OFdP3O
gmd0fmcN0<O8c@2MX:L0M7R307=gPP1YLh`0IW29069/Q@1PJX<0Hff606Yd
S@1aNi@0Mh6J0865SP2e^;d0i>KS0?gnn03oooX0oock0?olo`3on_l0oOgk
0080ooom00<0o?cj0?ooo`3no_h08P3oool00`3no_h0oooo0?ooo`020?kn
oP80oooo00T0oOgm0?ooo`3jn_X0oooo0?ShmP3lo?X0no_i0?_lm`3loOP0
2`3nnOd0503mn?`0n??g0?7/l03XhnL0h]gQ0=_Ig03GeMH0f=SF0=CFd`2<
U9H0Kgb507V:W027V;80V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB2@2P
[]40<P2O[M80X:kC09ZXb`2GY/L0T9nn096P_@29VK<0HW:<07B0V028Tjl0
Sibl09ZXb`2MZm00W:_B0:BcfP2HZ/h0Wk?>09f`cP2M/=40XK7E09n_d`2M
[Ll0Wk3>0:Bec`2b]m@0][cD0<78fP3<d]h0fN3X0=kRj`3Tj?<0g^;]0:bd
a`2>UZT0L7R;061XN`1HH7<0Eemb06YbQ@21RI`0WjNj0;S3e@2nbMl0^<CL
0;6lf02Z]mL0[;_L0:Nef02V]=L0YkGH0P2V]MH0102U]=D0Y[GD0:Jee02V
]M@30:VfeP80Z[OG0`2[^=P0102]^=H0[[WG0:jie`2^^ML30:njf0@0/;_I
0P2a_=X30;:mf`080;_7g`39dNH0d]SX0=GGh`2ATYL0o_ko0?koo`3moohB
0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL
0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@<0aknX1@38
`:T01037_jP0b<2Y0<S0Z@38`:T20<NoZ0040<S0Z@39`JX0b<2Y0<S0Z@D0
aknX2@38`:T80<S1Y`030<O0YP38`JL0b<6W00D0b<6W0`38`:T50<NoZ0@0
al2V1038`JL00`37`:H0b<6W0<W2Z0050<W2Z0D0b<2Y0P39`JX90<[2Z`H0
b/:]0P3;`jh0403;aJ/0cLJ/0<NoZ03CbkH0f=6o0>7Kc`3VhmX0lO7Y08b>
R`1DF6@0DEQe04QFO@1EIY80GgBQ06AjZ`1WO[8P06Z1]`0E06Qm/P1WOJl0
I7Z/065gZ01NM:<0Fg:N05U`W01GKYP0EVR@05EWS`1CIHd0DVB<055SR`1B
I8`0E6J>05EWS`1HKIX0Fg2M061eY01TNZ/0J7j`0080JWnd4@1ZPKL606^0
]@80JWnd2@1ZPKD506^2]P80K8>g101/PkD806f4]P@0KXFg1@1_Q[P30727
^@H0LXRi101cRKX607B:^`80MH^l0P1fS;d407N=_P<0Mhfl0P1hS[d307V?
_PD0Ni2o0`1lTL00101lTKh0OI:o07fB_`1mT[l607jC`0<0OiC10`20UL82
082E`0@0PIK10P22Ul8208BG`P80QIS32026VL@208NJa@80R9_60P27V/@0
1028VlD0RIc608VLaP29W<H208RKa@P0RY_6402;W<L09@27W<T0Rik908ZM
a`2?XLL0UZK70:2_c02Q[lX0S9Zd0;2e/@3dm_<0nOWg0?GdlP3dl_<0kNg]
0?Oin03Ti^D0j^_]0>?TiP3Ph>80gMgM0=cLg03Ng]h0gMgK0=OGe@3LfmL0
g]kL0=3Ad`2NXJH0N7b506abOP1SJWX0IFio061[Q`1SKXX0IW6=06YeT@1/
Mi<00P1]N9@04@1/Mi<0MgfC07ElS01nQHl0^Kc10?Oin03oood0oOWh0?om
o@3oood0o_kl0?clnP3no_h0oooo0?clo03no_h0oOgm0200oooo00<0o_kn
0?ooo`3oool00P3no_h0203oool0o_kn0?_kn`3jn_X0m_Kf0?[jnP3fm_@0
n_[h0`3gmoD:0?Khl`0E0?Oim03fn?<0lO?^0>[/i`3Qhmh0g=kI0=WGg03F
e=L0eMGE0=3Ad`2;T9H0M7f>07f;Y@2:VKX0V:K90:2^d@2O[M00X:kA0:6_
dP2O[M00XJoB00T0X:kA0180WjgB0:2^d`2KZL`0W:_<09JUa02DXl00TZ6n
07R8XP1YMHd0PHnY09JT`@2KZ<X0X[3C0:6ad`2KZld0YKGG09V/c02O[m42
0::beP0T0:2^d`2S/=80ZKOD0;2nf@2oaMd0b<oR0=ONkP3IhNh0j?3k0=7I
iP2@UZH0G65d07AmVP22RjP0U9fj0:6Za`2U[//0WZO4096J]`26Sj`0L7^A
05AOM@20RZ<0ZkOA0:fkeP2a_m`0[;WI0:BcdP2Z^MX0Y[GF0::adP2U]=D0
Z[WJ0:Nfe@2U]=<0Zk[I0P2Y]]H30:Zge`<0ZkSH102^^ML20:njf0@0/;_I
0`2a_=X30;:mf`080;_7g`39dNH0d]SX0=GGh`2ATYL0o_ko0?koo`3moohB
0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL
0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@T0aknX0P38
`:T30<NoZ0030<S0Z@39`JX0a[jW01T0aknX1038`:T40<NoZ0<0b<2Y0P37
_jP00`36_ZL0aknX0<NoZ0030<NoZ0<0b<2Y0P37_jP20<S0Z@80bL6Z0P38
`:T20<W1ZP<0b<2Y00<0bL6Z0<[2Z`3:`Z/0203:`Z/50<[2[@<0bl>^0100
c<J`0<NoZP38`:/0dLVf0=O@_P3[im/0j>SN0=;Cb`1AF5h0DEU/04iKO@17
F8@0GgBQ06=kZ@1VOJl0JH2f801ZPKL05P1[P;L0JWnf06Un/`1XO[00IWb^
06Ek[01TNZ/0HgVX05mdX`1NLj80GG:Q05aaX01MLZ40GW>R061eY01QMZD0
IWZ/06Mk[@1XO[00JX2b06^0]@1/PKPB06Z1]`0306b1]P1[P;D0Jh2e0080
Jh2e0`1ZOk@706Z1]`P0Jh:h00<0K8>i06f2]`1]P[L00P1]P[L306j3^003
06n4^@1^PkP0KX>h0080KX>h101_Q;T00`1_QKL0L8Jh0726^0020767^@<0
LXRj0P1aQkT607:8^PD0M8Zk0`1eRk`207J:_0<0Mh^m0P1hS;h00`1iSKl0
N8fl07V>_@0207V>_@D0NXnn0P1kT;l207bA`0<0OI;100@0O96n07fB_`1m
T[l0OI:o0`1nTl000`1oU<40P9;0086C`@02086C`@@0PYC21P23U/4308BG
`P@0QIS30P26VL@01027V/D0QYW408JIa026VL@208NJa@<0R9_600<0Qi[4
08RKa@28VlD01@29W<H408ZKaP<0Ric700<0S9g808^La`2;W<L03P2;W<L0
502:WLP0Rik808^Nb02>X<P0T9o609NUbP2JZ</0SYfn08J>T02i_kl0iNOT
0?;ck@3blN`0kNWX0>OUj03XiN`0g]cO0>7OhP3Th^D0gmgP0P3IemX07@3M
fmh0g=[M0=_LgP2XZJd0O86706M]N@1UKWl0I76405e/P`1OKhP0JGRI06ak
W01aP:40MXFV07N6Y`1fQJH0M8>T07:1XP1dPJ<0MX>S07n9Y01lPiH0QXZE
0<c=c`3oooX0nOW]0?_kn`3no_h0oooo0080oOgm00<0oooo0?_kn`3no_h0
803oool00`3no_h0oooo0?ooo`030?knoP080?clo03hn?P0nOWi0?Gem@3a
lO40k^k^0?3`kP3/k>X20?7ak`X0jo3/01D0k?7]0>_`k03Wk>P0h>GQ0=OL
f03Ae]80e<oE0<o=d03>c<l0bLS=08F7T`1dNY00OXNX08VE_@2HY/T0X:kA
09n]d02P[]40XJoB09n]d02Q[m802@2P[]40302O[M80XJoD09f[cP2O[/l0
W:_<09RWaP2IZ<D0T9nl05ASNP22T:X0UJ>n09bYb@80X[7B01<0Y[GD0:Fd
d`2U]MH0X;3B0:6_dP2X]MP0[kWL0;>lf`2ma>00a/gW0=KKkP3Ignl0i^cl
0=gTm02NYkP0GfYn07f7X02T[/T0WZ[@0080Y;3F0P2NZ]020:>_e@0;09fY
c`2KY/80XJc806iiU@1DGg/0QI>^0:Zhd`2X]]40ZKOB0:NdeP2X]ML00P2Z
]mT01@2X]MD0YkCD0:Ree@2W]=@0ZKKF00<0Z[OG102[^=P30:jie`<0[k[H
0`2`^mT30;6lfP@0/[gK00P0^lOO0<WAiP3Bf>P0eMOS096BU`3no_l0o_oo
0?gooQ80oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kN
gP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlY@P0b<2Y1037
_jP30<JnY`030<FmYP38`:T0b<2Y00`0aknX0`36_ZL70<NoZ0030<S0Z@37
_jP0aknX00@0aknX00@0a[jW0<S0Z@37_jP0aknX0`38`:T<0<NoZ080b<2Y
0P37_jP20<S0Z@80aknX0P38`:T20<W1ZP80b<2Y0P3:`Z/40<W1ZPX0b/:[
103:`Zd40<_3[P0@0<[3/@36_jd0d/Zg0=K?_03Nf<P0jnWM0>[[i@1lOWT0
DEe[051NN01AH8T0D6FD061hZ01QO:/0Ih2f06N0^B00JX6g00H0Jh2i06^0
]`1ZOkH0JWnf06Yo]01YO[<206Uo/@80Igba0`1VNk001@1WO;40JGjc06Un
/`1[Ok80JWnd0080Jh2e00@0K86h06Z1]`1ZP;T0JX2i401ZPKL00`1/PKH0
Jh2e06^0]@0406^0]@0506b1]P1ZPKL0JX6g06Z1]`1YP;H00`1ZPKL0101[
P[P0JX6g06Z1]`1ZPKL506^2^0H0KH:g0P1^PkP0101]P[L0KX>h06j3^01^
PkP406n4^@80KhFg00<0L8Jh0767^@1aQkT01P1aQkT507:8^P80LhVj101d
R[/207F;_0@0MX^j0P1gS;/407R=_0<0NHjm0P1jSkh0101iS[d0NXnl07Z?
_01kT;d307bA_P80OI:o00@0O96n07fB_`1mT[l0OI:o101nTl001020Tkh0
PIBo086D_`21U;l408:E`0D0PiK11`24Ul8208FH``80QYW40P26VL<308NJ
a0<0R9_500<0Qi[408RKa@28VlD01028VlD00`29W<H0RY_608ZKaP0308ZK
aQ<0Ric70P2:WLL08P2;W/P0S9k608^Ma@2@WlP0TZ7:08fLa@28TjD0O8JB
0;Rm`@3Uin@0hn;M0>?Og03Rg]l0i=oU0>CPg`3Nf]T0f]KG0=SFe`3KfMX0
g]cO0=KDe`37aLP0Ui^T07UmR01XL7d0HVeo05i]Q01PLHd0J7^K07N;[P1k
SK<0OHne07nA]`21TkT208:D^P80PI>i00X0NXjc07F7[@1hR:`0OXR[07Qo
V@27SIT0a<S70?kon03oool0o?cn0P3oool00`3hn?P0oooo0?gmo@0Q0?oo
o`030?knoP3oool0oooo00<0o_kn00D0n_[j0?Gem@3[jnT0j^[X0>OWi`02
0>SXj0030>CTi03WinL0iNGU00P0i^O/01L0iNK[0>KWk03Vin`0iNK[0>7R
i`3Jfn00dM;G0<c=dP3:b<T0alG60<S7a@35aLL0PHB=07AiS@1lQJ@0S9Fl
09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP090:2^d@0R0:2^d`2R/=<0
WZc?09n]d02N[Lh0VZW:09b[bP2JZLP0OXfT05i/QP2<V[D0ZKOD0:>acP2c
`Mh0//3K0:VidP2^_MX0/L7K0;C2g@2h`]d0_/KM0<O=h`3Cf>`0gN3c0=oU
l`3QioD0`<OI07EmTP1cOIH0V:K10::_d@2R/=<0X:kE0:6_eP@0X:kE0P2O
[M@0402MYlX0UjC609RUa@2?WKX0IWB?06IdSP2IYl40YkK=0:Jcd`2Q[/h0
YkCD0:^hf02U/]80Z;GE0:jkg@2X]ML30:Zge`<0ZkSH0P2/^MT20:jie`<0
[k[H0`2`^mT30;6lfP<0/[gK0P2c_]`0202kaml0bM7V0=;Hj03Een<0TI:G
0?kno`3nool0oOon4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU
2038`:T60<NoZ080a[jW0P38`:T60<NoZ0D0b<2Y0`37_jP80<S0Z@040<W1
ZP38`:T0aknX0<NoZ080b<2Y00@0aknX0<JnY`39`JX0b<2Y0P37_jP01@38
`:T0bL6Z0<S0Z@37_jP0b<2Y00D0aknX0P38`:T01037_jP0b<2Y0<W1ZP38
`:T20<NoZ0@0b<2Y1039`JX20<S0Z@80bL6Z3P3:`Z/40<[2[@@0bl>^0100
b/>c0<k7]@3>ak@0f]?10>GRd`3Xj=h0cm7>059FF@1?GWD0AeMh059UT01L
LZ<0I7^]06J0/@1YP[P0Ignk801ZPKL206Uo^0H0JH2f0P1ZPKL406V0]P03
06Z1]`1[P[P0JWnd0080JWnf101ZPKL00`1XPKL0JX6g06Z1]`0>06Z1]`<0
Jh2e1@1/PKH506^0]`80K86h00<0KH:i06b1^01/PKP01P1/PKP506f2]`H0
KX>h0P1_Q;T30725^P<0L8Jg1@1aQkP00`1dR;/0LhNj07>7^P0207>7^P80
M8Rk00<0MHVl07B9^01eR[T00P1eR[T407J;^P@0Mhbk101hSK`207R=^P80
NHjk101jSk`307f?_@<0OY2n0P1oTKl8082C_P<0PIBo0`22UL0208>F`@<0
PiK00P24Ul4308FH`P0408BG`@25V<80QIS208FH`P<0QYW300@0Qi[408NH
``28VL@0R9W40`29V/D208RIa00408RJ`P29Vl<0RYc408ZLa080RI_300<0
RYc408^Ma@2:VlH01`2:VlH@08^La`0308^NaP28Vl<0RYc40080Ric70P2<
WLT0<@29V/H0Q9:e08>>ZP1iP980XJJ/0=gOg03TiN00f]WG0=gKg03NgMT0
g=_G0=gLfP3Ogml0f][J0<G6b02MWZ80MgQl06acQ@1QJG`0HFb206AbS01Y
NYP0M8JZ07V?]P1lT[/0PiK008FH`P27V/@0RIc608ZMa`29W<H0Qi[408JI
``1mUKL0PiVn07Z=]`1kR[<0RI>g0868XP2:TYl0]kk40?ono`3noOl0oOgo
0?ooo`3kno/0o_kn0?ooo`3moO/0803oool00`3no_h0oooo0?ooo`020?kn
oP0;0?gmo@3inOT0lo?c0>k^k03[jnT0h^;P0>7Qh@3Ph>00hN7S0>;Ri03Q
hN<02`3Rh><0503Qgn80gM_N0=KDe`3>c<l0b<K90<;2`02o`;/0`L:l0<;2
`01nPHH0Mgf;0827X@2AW;`0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB
2@2P[]408`2O[M00Xk7D09n]d02MZlh0Wjg@09n^c`2N[Lh0W:_<09n]a`1c
PI`0IgF@09:P_@2/^]L0ZkWD0;G4f`2nb^80_LcO0;o<g`33cml0c=GT0=GM
jP3KhNd0h>C`0>;VlP3Hgnl0T9VZ06UaQP2;Uk40Y[CA09^Yc02S/mL0WJcC
09j^d02M[Ll0WZk@0080X[;D0100WjoA09j^d02O[m40XJoD09fYc`2IY/T0
U:71092N^`1`OYP0H6n609>R^@2Z^=D0X[3=0:2^b`2U/]80ZKKF0`2Y]]P2
0:Zge`<0ZkSH0`2/^MT30:njf0<0/;_I102a_=X30;:mf`<0/kkL00P0^lOO
0<WAiP3Bf>P0eMOS096BU`3no_l0o_oo0?gooQ80oooo000P0?ooo`0@0?kn
oP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk
09VDP@2XXX`0^k>L0<BlY@P0b<2Y0`37_jP20<JnY`<0aKfV0P34_:D01P35
_JH0a[jW0<NoZ037_jP0a[jW0<BlY@80a[jW0`35_JH01@36_ZL0aknX0<No
Z038`:T0a[jW00<0aKfV00@0a[jW0<FmYP35_JH0aKfX0P34_:L01`35_JP0
aknZ0<S0Z`37_jX0a[jY0<NoZP35_JP00P33^jH01035_JP0a[jY0<JnZ@35
_JP80<JnY`0=0<FmZ036_ZT0aknZ0<JnZ@34_:L0`k^V0<BlY`35_JP0a[jY
0<NoZP38`:/0aknZ0<JnZ@030<FmZ080a[jW00<0b<2Y0<W1ZP3:`Z/00P3:
`Z/00`39`JX0b/:[0<[2Z`060<[2Z`<0b/:]1@3;`jh0403<aKD0al2^0=;;
^03JeL80iN?F0>_/i`1oPXL0FEm[04MHMP18FX80FFjM065gZ@1WO[00KHBf
06Z1]`1[PKdX06Z1]`<0JX2i101YOkP00`1ZP;T0K86h06b1^00306Z1]`03
06Z1]@1WPK@0Ih6d0100JX6g0`1[P;D206b1]P0306^0]@1ZOk@0JWnd0080
JWnd0`1YO[<00`1ZOk@0Jh2e06b1]P0306b1]PD0Jh2e0P1]PK@306j2]@@0
KH6d0P1^P[D206n3]P<0L8Bg00@0LHFg0724]P1`Q;H0L8Bf0P1aQKL02P1b
Q[P0LhNi07B8^P1cQkT0LXJh0765]`1bQ[P0LhNi07B8^P1eRK/507F:^@<0
M8Vh0P1gRKT00`1hR[X0NH^k07Z<_00307Z<_00307Z<^P1iRkT0NH^i0080
NXbj00<0Nhfk07b>_01mSkd00`1mSkd00`1lS[`0OHnm07f?_@0207j@_PH0
Oi:m0P1nTK`2082A_@80PI:n1022Tkl208:C_P0408>D_`24UL00QIK108FF
`@80QYO20P24Ul400`25V<80QYW308JI``0308JI``0308JG`P27V<<0QiS3
0080R9W400D0QiS308JG`P25U/40QYS008NI`@0208RJ`P0408NI`@26V<00
R9[208VK``80RI[50P2:VlH208^La`80RY_6402;W<L0802<W/H0RI_308^M
a@2:VlH0RYg708bObP28VlH0Qi[508JD``1nS;<0NX>R07b3UP27RiH0XJBY
0;^o`036b//0a/S70<;3a@2f^[d0X:FY08N<TP1eO8H0Jg5m069ZM@1QKHL0
GF^606IeTP1eQ:D0Nhfa082B^P25V<80RIk90P29W<H508ZMa`0:08VLaP2:
XL40PYRm08JI``24UL40P8fi08>@/`27TZh0PhnU0<O6c080ooko00<0nOWk
0?ooo`3inOT00P3ooodS0?ooo`0=0?knoP3oool0o_kn0?Shn03bl_80j^[X
0>CThP3MgM/0fm_K0=gMg`3ThnP0f=OL0<o>d`0;0<k=b@070<c;a`39b<@0
`l:n0;bk]`2g][80/kBf0;2b/@020:j`[@0;06mdM`1eOHX0OHRN08fH]P2H
Y/T0X:kA09n]d02P[]40XJoB09n]d02Q[m802@2P[]408`2O[M00X[3C0:2^
d@2N[<l0X:kA0:>ae02R/=<0WJ_>09j/b@2Q[l`0OX^[05UVQP29U;80_<SR
0;S4g034d>H0b=7R0=CMk03Fh>`0dM_U0=_Tk@3Pj?<0`<SE09>KZ01FHgH0
O8RP0:>^bP2LZLT0XJoB0::beP2JZ/h0X[;F0:6bd02R/m40X;7?0080WJk<
01<0X;7?0::cd@2R/m40WJ_B09^YcP2MZlh0UjK7096O_02=VkH0MXBN05MV
O@2;U[80Y[7=0:^fdP2T[ld0ZkKF0:jhf`2Y/mH0ZkGH00@0ZkSH0`2/^MT0
0`2]^]X0[k[H0:njf0030;2kf@<0/KcJ102b_M/30;>ng0090;Bog@2kaml0
bM7V0=;Hj03Een<0TI:G0?kno`3nool0oOon0180oooo000P0?ooo`0@0?kn
oP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk
09VDP@2XXX`0^k>L0<BlY@P0b<2Y00L0aknX0<JnY`34_:D0`[ZS0;ngX02m
]Ih0^k>L0080^[:K00<0^k>L0;feWP2o]j000P32^Z<02@31^J80_kNP0;fe
WP2m]Ih0_;BM0;feWP2n]Yl0`;RQ0<:jX`020<>kY0080<2hX@2m]Ih0_;BM
0;jfW`2o]j00_[JO0;feWP2k/ih20;ZbW@070;feX030^:<0`k^V0<>kYP32
^ZD0`;RS0;feX0020;ZbW@070;bdW`2m]J00_[JQ0;feX02n]Yl0_kNP0<6i
XP020<:jX`0H0<6iXP30^:40_kNP0;jfX@2o]j80`;RS0;jfX@2l]9l0^[:M
0;^cWP2l]9l0_[JQ0<2hX`31^J@0`;RS0;feX02k/ih0_;BO0;feX02o]j00
`KVR0<BlY@37_jP0bL6Z2`3:`Z/20<[2[@H0bl>^0100b/>a0<Jo[03Mel40
iN3<0>WWf`3IfmX0@dMC05=JK@1:FWh0EfRC065eY`1UNjd0JH6a06b4]01Y
O[D0KX2n801ZPKL406Z1]@@0JX6g0P1ZOkH606^0]`0506b1]P1[P[H0Jh:f
06^2]P1ZPKD00`1XP[<@06Z1]`@0Jh2e00@0JWnd06Qm/P1WO;40IGZ_0P1T
NZ/306=iZP0306AjZ`1VO:d0IWb]00<0J7j_1@1WOJh00`1XO:h0JGf_06Yn
/00206Yn/00306Um[`1WNjd0IWZ/00<0J7b^00<0JGf_06Yn/01ZO[00101[
Ok403`1ZO[00Jgna06b0/P1^P[@0L8Bf0765]`1`QK@0KX>b06f2/@1[P:l0
K86`06f2/@1_Q;<0LHJe07>8]`0207:7]P090766]@1`QK@0KhBc06j3/P1]
P[40L8:`0763/@1cQK<0MXRf00@0N8Zh0P1eQkD207B6]00407F7]@1gRKL0
NH^i07Z<^P80NXfh00H0N8^f07N:]@1gR[D0N8^f07V<]`1jSKP207^>^@80
NXfh00@0NHbg07R;]P1hRkH0N8^f0`1jRkH207^<]`D0O8fh00/0OHji07j?
^P1oT;/0P96l086B_@22Tkh0Oi:l082C_@21U;h0PYFo08>F`00208:E_`03
086D_P21Tk/0PI>k0080PYBl00P0PI>k082B^P1oTKT0OY2h082B^P21Tk/0
PYBl086C^`80P9:j00H0PYBl08BF_P26Ul80QiS308VJa@2:VlH308^La`03
08ZKaP2;W<L0Ric700h0Ric700<0Rig508VK``2<W/H00P29W<@07P2<WlT0
R9_508RKa@29V/H0OHbg07n;/@1fOih0LGRB07MnT01_NHD0LG^507AkQ@1e
NhL0MGf:06igR01SJh00GVR1061/QP1QK8P0IgNH07B4Y@1mSJl0PY:f08NF
_@2;V/<0Ric708ZKa`2<WlL0Rik608ZMa@80RIc400D0RYg508^NaP2<WlL0
S9o708JI`@0208^Lb00<08ZIa029V;l0Q9Bf08BE/`2@SiL0e=?I0?ono`3h
mo`0oooo0?gmo@3no_`0ooom8`3oool01P3no_h0oooo0?knoP3hn?P0l_;b
0>OXh`80h>3N00D0gmoO0=gMg`3JfMh0ZJR^08^:T00;08F8S@0D08B7S022
QHX0OH2507QkP01dMg`0KW9n06mcOP1`MG/0MGZ004YAF`1^MhP0OXZT08ZG
]`2HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m8:0:2^d@0409n]d02P[]40
X:kA09n]d080X[3E0340WjgB0:6`c`2T/M<0WJ[<09>P`P1bOId0I6f:08ZD
[@2W//P0^;gA0;W0dP30amL0]l3?09:KZP1ZMHL0JWF;086;Y02M[/P0X;7?
0:>ae02Q[m@0WZcC09^YcP2W]MP0Vj[;09f/c@2Q/=40Xk;C0:6`d@2P[m00
X[7B09n^c`2KZ//0XK7E0:Fef@2FY/P0VZW:09VVaP2=VkP0RINb07R3W`1U
LH/0SIVc0:F`c02T[ld0Yk;B0:jhf`2_^M`0[[SL00<0ZkSH0`2/^MT20:fj
fP80[k[H0P2`^mT40;6lfP<0/[gK0`2c_]`20;Bog@080;_7g`39dNH0d]SX
0=GGh`2ATYL0o_ko0?koo`3moohB0?ooo`00803oool0403no_h0oOgm0?Wi
n@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<
0;^cW034_:D80<S0Z@0A0<NoZ035_JH0`KVR0;feWP2h/9T0/j^D0;2XT@2^
YXl0/JVB0;:ZT`2e[IH0^K6J0;bdW@2m]Ih0_;BM0;ZbV`2d[9D00P2cZi@0
4P2d[9D0]jnH0;ZbV`2m]Ih0_[JO0;feWP2i/IX0]JfF0;B/U@2f[YL0]jnH
0;J^U`2d[9D0/JVD0;2XT`2aZI@0]:bG0;VaW0<0_KFP00/0^;2K0;F]V02b
ZYD0/JVD0;>[UP2e[IP0]ZjI0;F]V02f[YL0^;2I0;^cW0020;feWP080;bd
W@2i/IX0]jnH0;J^V@2g[iX0^;2K0;J^V@2cZiH20;:ZU@0>0;B/U`2f[YT0
^K6L0;ZbW@2i/I`0]JfH0;:ZU@2cZiH0]JfH0;ZbV`2m]Ih0`KVR0<FmYP38
`:T;0<[2Z`L0bl>^0140c<B_0<W2[`3Fd;X0d/bd0>GPc03WiMT0][Nk055G
I`1AEg40C5j405]/V01QMJP0JGna06b2/`1ZP:l0JGfb06in^P0P06Z1]`<0
JH2b0`1YP;@206V0]P80JWnd0P1[P;D406b1]P80JH2d00@0JX6e06Z1/`1X
P[<0J8:c0P1XPk8@06Z1]`@0Jh2e00D0JGjc06Ik/01SN:d0HGJ[05idX`02
05ecXP0505abX@1MLj80GWBS05meY01PMZD0101SNJP4069hY`0806=hY`1T
NJP0IGZY06IkZP1UNZT0HgRW069gYP1PMJ@2065fY@03069gYP1SN:L0HgRW
0080I7VX00`0IGZY06EiZ`1TN:X0I7RZ06EiZ`1WNjd0JGf_06b0/P1^P[@0
JWn/06UnZ`1VNjP206EjY`0@06MlZ@1ZOj`0Jh2]0725]01_Q;<0KX>b06b1
/01ZOjh0J7f/06MlZ`1VNjX0J7ZX06YlZP1^P:h0LH>a07B6]0<0MHNe00/0
L8:`06n1[`1_PJl0Kh6_0722/01bQ;80M8Jd07J8]P1fRK@0MHRc07>6/@03
07:5/080M8Nb0P1eR;<0101dQk80LhJa07:5/01bQK020764[`80LhB_0P1d
QK0607F6/@0407J7/P1hRK@0NHZe07Z;]P80O8fh00P0NXfg07^>^01mT;X0
OY6k07nB_01nTK/0OI2j07b?^@80Nhfe00L0O8jf07^=]@1kSKD0NH^c07R:
/P1gRK40NH^c00<0Nhfe0P1iRk<01P1kSKD0OHng08>D_`25U/40QiS308ZK
aP<0S9g84@2;W<L0802:VlH0RYc408jPb029W<@0R9_308bOa`26W<40R9k3
08NK`02<Vl80Ohfd08></`1jPZH0K7FB06mkT`1VLhH0Ifn406=[PP1PJX<0
H6^7061]S@1VM9L0KG^P06imY01dR:/0Nhnd086C^@28V/00T9o808bKa02;
V<@0Sic80P2:W<805P2;WL<0S9k408bNa02;WL<0RYc208VK`@2<V/T0RiW8
08jLb@28VLD0QiS308VK`@25Uk/0R9^l09:AV@2@SiL0oOco0?ono`3gmoT0
oooo0?ooo@3lo?XS0?ooo`0=0?knoP3oool0o_kn0?Win@3bl_80k>gX0=oO
g@3MgM/0fMWI0=WIf`3Ge]/0VIRN079aM`0806mgSP<0L7R?01@0KgN>06if
S@1ZLXT0IVj506=[PP1SJ7h0IV]o065WM@1PIW@0?DAD06iiS`22SJ/0QI>f
09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dPT0X:kA0200XJoB09f[cP2P
[]40XJoB09f[d02N[=40X:kC09n]dP2P[]40Xk7D0:6^d@2U[m80Y:o?09VR
_`25SjP0Jg>:06e^RP1YKHH0J6f306ifR`20Rj40Uj>m0:2]c@2O[<l0WK3@
09^]d@2O/ML0WZgF0:Bcg02Q[m@0Wjk?0:6`c@80WjgB00@0X:kC0:6_e02Q
[m@0XJoD0P2R/=D0402O/MD0W:c>0:6ad`2JZLX0Tj;109RUa@2BWK/0RiJd
06]gT@1bOYP0SYVe0:B_c@2S[/h0YJoB0:bff@2Z]=P30:^hf080[;WI0`2]
^]X0102_^]P0/;_I0;2kf@2`^mT30;6lfP@0/[gK0P2c_]`30;Bog@080;_7
g`39dNH0d]SX0=GGh`2ATYL0o_ko0?koo`3moohB0?ooo`00803oool0403n
o_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8
N`2IU840Z::<0;^cW034_:D80<S0Z@1A0<NlZ033^jH0]jnJ0;B^V02/YY00
ZJB@09JDO`2QWhX0WYb709nJQP2XXhd0ZJ>=0;N_VP2d[9L0/:FC0;:VUP2U
XX<0XI^;09nHQ@2VX8P0YIf@0;2XU@2c[900]JbK0;6ZSP2bZYL0Y9Z>0:NM
T@2_Yi@0Yin80;2XT`2SVXT0XIj=0:2KQ`2NVH<0Xib90:jTV02`YYX0^JjL
0;2VR`2YX840ZjB809nJQ02PWh/0X9n=0::MR@2VWXL0ZIn40:RRR02YXXl0
[jJE0;:ZU`2c[980]JjA0:jTR`2/XHl0ZZB>0:>MQ@2aZi40YJ2309nIO`2U
WhT0WiR60:JNT@2ZXXl0[jNB0:jVS`2/Y8d0Z:290:>KQP2SVXT0Z9n@0:ZX
S`2_Zi00`;^N0<BmX@37`:@0b<6W0<c6[P38`Z`0bL6/00P0b/:]1`3;`jh0
4037`Zh0dlbj0=[C``3Vh=00inOK07EjO@1DGWL0BEJ004iUT@1LLZ40IWb^
06Un/`1ZPKD0Jh:f06Z1/`1[Pk=906Z1]`2?06^2^01/PKP0JWnd06Um/01V
NjX0HGBO05Y]U`1DK9`0DFR805MVS`1LJ9X0FFJC05QXV`1KKj@0EFn@05M]
W01LLYT0FfjH05a`Y@1MLj@0FG6E05Q[U@1QK:X0EGBZ05Y]U@1QL9T0FW>[
059`XP1ILY00FVf>05IZW`1GJIT0Eg2I04mXX01NLZd0FfbG05]XTP1SLJ80
GG>H065[WP1MKi<0EfjH05ecXP1OLiH0JGZV061eZP1TPJ/0IGZY05eeV`1U
N9T0IFfD06=_U`1ILiH0FFnF071fZ01TOZ<0HWnM069nX`1SMj`0Ig>U06A^
T@1ULiH0Gg2V065aY@1QM9l0J7bQ06MjXP1aPk40MHNi0763/@1]PJH0IW^X
06acY`1YKil0IWVJ06MjV`1^M:@0M7^_06n4/@1bPjl0Kh6U06n2XP1]Oj<0
JGZX06QfY`1dPjh0KGfN06j1[01YMI/0MXF/06J1[P1QO:T0I7:E07=nWP1V
MI`0JGZU06=kW@1PN:H0JWj`06amV`1ZN9D0KG^R06QmVP1_OYd0Ig^N06Im
YP1[PJX0M8>Z07J4Y`1aQ:D0N92b07:7]01cQ:00MH6K08:;]P1eQKH0Mhj`
06j3X01fQJh0LWj`07B4Z01aQZ<0JX6P06n6Z01^P:@0JgVN07=oY`1fOZ80
Jg^O07:6Z`1YOIh0KGbK07=nWP1dP:X0MhNh07n=Z026U;L0Ric708FH``2;
W/H0RIg208^La`2<V/T0602;W<L0202:W<@0RI_308JH`022U;X0O8jd07F7
[@1`PZH0K7jR0P1[Ni`0301ZNY/0Jg^L06moX01fQZL0O8b]082@/@25U/40
QiS308RIa02:VlH0Ric708bMb0X0Ric700H0RY_608^La`2<WLP0S9g808^L
a`2:VlH208^La`0808JL`@23U:P0^/;50?oon`3on_L0oogo0?ono`3lo_/S
0?ooo`80o_kn0100oOgm0?Shn03bl_80jnKZ0>7SgP3Kh=`0f]_O0=gKgP3L
fmH0RhjC071hS@1ZMhX0LGfC07V5W`1lQj<0NXRU0P1kRJ@00`1kRJ<0NXRS
07Z8X`0207Z8X`0C07Z6X01ePI/0L7bF06ahTP1YMi40J7JA06YcTP1[MI00
@diR06ehRP1mS:<0RYRe09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP0Y
0:2^d@0309n]d02P[]40X:kA00D0X:kA0140X;3D09n_d@2O[M00WJc=09ZY
bP2DXl80Sibl08^I]P2<V[D0JGNA07b6X@2FX;/0Xjg80:J_cP2X]MD0ZkSJ
0:njf0030:jie`030:njf02`^mT0/;_I00@0/;_I0P2a_=X30;:mf`@0/kkJ
102d_m/0202mb=h0b];U0=?Ii`3Ef>40TY>G0?kno`3oool0o_kl4P3oool0
0200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0
f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU2038`:T0D035_JH0a;bW0;Zb
W@2^Yi@0VYF20:6LR@2DTH00TXmn096=PP2IUHT0VIJ709nJQ`2NUh@0Y9f:
0:RRS02SVhH0UYAm09><PP2ITh<0THah0:BMT`2XXI40YZ640:bUT`2ZY8`0
WIJ409nGS02cZj00ZjBB0:>MQ`2GT7d0WYN709JAR`2PW900/ZnN0;NaX`2M
UHX0WYJ90:>MQ`2YXXD0ZJ6>09J?O@2DT8@0ZZRL0:j[XP2TX9D0WiN:09bC
PP2FTG/0WIJ40:2HR`2VWhl0Yj6;0:BNQP2PVX@0WIB509ZDR02SWHl0UHmo
09bGQ02LUXH0UY220;6ZX02g/:X0Y9f=09bEP`2MUX<0X9V609N@O@2JTh40
Vi>609ZBQ`2NVXh0]:jP0;:[V@38`:/0bl>/0<JoY@38`ZX0al6Y1P3:`Zd8
0<_3[P80c<B_0100blJb0=C=^`3Qf/X0j^CD0=gMd`1AEUX0BUA]055NR01B
J9L0H7JU06Uo/@1ZOk@0JX6e06^2]P1ZPK<0JX:bB@1ZPKL0S`1[P[P0Jh2g
06Un/`1XO:l0HgRW05e`V`1FJI<0EV6G05=PP`1KIHT0F66<05YSRP1EGi00
DefH05YYU01OKYL0EVR@05mbW@1@HY00DVB805m`RP1PL980Df>D04mVT01U
L8`0H6J605=SUP1IKih0F6R105iYO`1EHHT0G6=m05QWNP1JJX`0Cej705UU
O`1TKhl0Df2<055URP1SIhX0GFV305a[TP1@GhH0Gfj505iYQ@1]NjP0GWBM
06EfZP1DJXl0FFV30866Y01hPJ80F6f<05eaS01XK8T0I7NQ05UaT`1PN9`0
HW>Q065ZT`1SJh80GFb305AVS01OJ8D0G6R0065`Q`1]O9T0L7nX06ilZ`1b
P:d0KgjW06AhW@1RJXh0Iff=05]ZQ`1OKX/0LGNG06]cU`1/P:D0Kh6W06Af
W01TLYD0GFZ:096O_01jRJP0I7BH06AcWP1ULY@0MGZG06UbS`1QMi`0I7RK
06ieS`1WK880J76>06Y`RP1/NHX0I7>B05]YS01XLhL0JgF@065]U`1TMYX0
IVb406iiU@1RLi40JWVH06]fTP1lQJ80O8VY06UkW`1]PJH0K7fA07N2U01[
M9D0NhV`06UlW@1]P:40KgbX06ieT@1[M940LWbO06ikWP1WM9@0IW::07^4
U@2>UJD0PHJJ07J0V`1LJhX0KGZJ075hTP1aMXX0L7R;07>0T`24TZd0NHNZ
08^La`2;W/T0R9_308^Oa02>WlX0S9[901P0Ric70P2:W<@01`29Vl<0QYRn
08>E^`1oTKL0O8jd07Z</01lS;000P1kRjl01@1lS;00Ohnc08>C]`27Uk/0
RYZn0080R9W40P2:VlH308^La`0308ZKaP2;W<L0Ric700P0Ric700<0S9g8
08^La`2;W<L00P2;W<L02@2<WLP0SZ;708jN]@2?UYh0mOCb0?ojnP3ooOl0
n_Si0?koo@0S0?ooo`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>7SgP3Kh=`0
f]_O0=cJg@3LfmH0S8nD075iSP1bOY@0O8RP08JA[@29Uk@00P2:UkL00`2:
V;D0RIVc08ZI]P0208^I]P0D08ZH]@28U[40QI2/082;Y`1lQj<0N8JP07J4
X@1iPZ40N8:M04aGJ`1`Nhd0O8^R08VG]02HY/T0X:kA09n]d02P[]40XJoB
09n]d02Q[m8_0:2^d@80XJoB0100X;3D09n_d@2O[M00WZg>09ZYbP2EY<<0
T9fm08bJ]`2:V;<0Q9:]06A^R@2@V[D0UInj0:ZcdP2U/]80ZkSJ0`2^^ML2
0:njf0D0/;_I0`2a_=X30;:mf`@0/kkJ102d_m/0202mb=h0b];U0=?Ii`3E
f>40TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0
lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k
/i`0a;bU2038`:T0:`36_jD0_kNP0;:/UP2UWX`0XYb<0>3JcP3ooo@0ooof
0?oonP3oo_T0jnSQ0?_gk031_Zl0UY>209NBOP2AS7P0U9:50?onn`3hm^X0
UI:30?ghm03ooo<0XYj50:6LR@2FU7l0V9B80;6/YP3ln>l0j>GF08n<N`2>
Rg`0Yj>G0>;Ng`3nnoH0ooof0?gikP3bk^D0];2U09ZEP@2JUWT0T8V10:jZ
X@3el^d00P3noOT08`3oo_/0al:n09:;Q@2JUhH0oooc0?Sdj`2QWI80UiB3
09NDP@2BS7h0^;6Y0?omn@3Xhmd0UY6;08j:P@3>bL<0nOC`0?onn`3ono/0
oo_`0<o;_`2FTXH0RhQi0;NdY@3kmn`0ooof0?okm@3oo_/0ooSe0;^bZ@33
^Z/0b<2]0<S0Z@3;aJd0bL>Y00D0b/:]203;`jh30<c4[`0<0=7:]`3Ab[P0
g]O70>SRe03CdlT0?TE;04]GL@1BHH`0F6jM06AjZ`1[PK<0Jh2e0P1ZPKD0
0`1YP;80JX6c06Z1]`1806Z1]`2?06^2^01[P;L0JGjc06Ij[@1PMJ@0FFbG
055TSP3AeN40n?oj0?;mm@3gool0look0:Vf_02QZK`0m_oo0<_Aj`1CGhL0
C5f805EVQ03Cgnl0m?co09n]b01CIhP0PY:[0?Cfo`3He^`0H6VD04aIP`2:
TJ<0m_Wo0?_mo`3oo_l0nooo0>ggo`1MIGX0am3I0?Soo`1mQj/0EfN80;k0
c03gool0_LGY05]TQ@3eo_l0nOoo05mXR@1PKYD0EF:G05mbT`22Sil0moWo
0=?Gl01PL8X0koco0??dn01ULIL0Gfn@05a/S@1AFgl0UIZg0?Gko`3@f^H0
PI2U0?_lo`3lool0nOoo0>ojo`2a_^00MH2]06agY@1XLj00HG6B0<kFh`3d
nol0Q9>X08JEZP3hool0dm_X06EeUP1OLID0HW2E06UaU@2Z/<H0loco0:Jb
_P1WMYD0GVjO0;2fc03in?l0[k;505i^R01SLH/0e=KU0?cjo`3gn_l0o?So
0?_no`2Z/L40IVf00?Ono`3cn?l0H6R?05m]TP3`k_`0mo[o0:jfb`2CVjh0
mO_o0=;Gj`1gP9l0KWbS06amV`2b_ll0loco0:nfb@1WLhd0IWJ@06QeU`1O
IY80i^[Y0?Oho`2FU[`0JffC07IjT`39cMH0m?Si0?koo@3joOl0dm_X06M_
QP2_]Ld0m_Oo0?ono`3lool0n?oo0<gKmP2:V;/0Q9G008RKaP28Vl<0SJ76
08bMb02;VLP0602;W<L308^Ma@0508ZLa029Vl40R9[008NI_`26V;h00P28
Ukh01P29V;l0RYW008^J`@2<Vl80SIc308jMa0@0Ric7102:VlH:08^La`0>
08bMb02;W<L0Ric708^La`2=W/T0SYo:096Tc02GYl40RY:O0;nn``3ooOl0
ooco0?ono`3noolS0?ooo`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>7SgP3J
gm/0fM[N0=cJg@3LfmH0SI2E07=kT01jQZ00Qi:^09>Q_P2JYlT00P2KZ<X2
09ZYb080Vj[;01D0W:W;09^Xb02HYLD0Tj3008nJ^02;U[@0QiF_08BB[`27
T;40QY2[05IQM@1bOHl0NhZQ08VF]P2HY/T0X:kA09n]d02P[]40XJoB09n]
d02Q[m80;P2P[]430:6_dP0@0:2`e02P/=80X:kA09j]cP2KZ//0UZG409:O
_`2>W;T0RiVd092N^@1[MI00LWbG09FO^P2MY/<0Y;;?0:VfeP80[[WG0P2_
^]P50;2kf@<0/KcJ102b_M/30;>nfPD0];oK00P0_LSN0<[Bi@3CfNL0eMSQ
09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L
0<BlY@P0b<2Y0500aKjR0;beV`2b[9H0X9V709NAQ@3QgM@0ookj0>GQgP3W
i=d0g]_D0<S5`03oooP0b/O008^8O`2?SH00SH]n0;Je/@3ln_l0gMgE08^9
O@3ono`0oooj09:@N`2FTh80Shil09JCRP3ckn`0ookk0>GRf@2<RWd0VYR<
0?gjl`3oo?/0j>GP0;Zg[P3Kf=40ookk0?Cak02RX9<0SXeh09:?RP3^jnH0
oooj0=;Ac037a/80l>o[0?ono@2g/k80Q81d0=gJd`3oo_/0];6/09:@Q02>
S7l0SX^20=C@c@3oo_/0`Kji092=R035`[d0oooj0?KckP3<b<D0`[jk0?[g
lP3oooP0c<W008N4N`2WY9/0oooh0?gimP3Sgmh0jNCN0>gVgP2k/jH0`;NV
0<NoZP38`:T0b/B/0<_5[@@0b/:]203;`jh40<c4[`0@0<o8]@3DcK/0gmS8
0>7Nc`32`k/0ATeC055OO01?H8h0G7:Q06Mm[P1/P[@0JWnd06Z1]`1ZPKD0
JH2d06Z1/dP0JX6g0900JH2f06^2^01[P;L0JGjc06Ei[01OM:<0EfZE04iQ
R`3Fdm`0oOoi0=_Ui036dm/0b]cP08jKZ`1OIgh0hN[c0?kno`1nQJ40DV62
09RV/`3bmo/0k>go05URO`1@J8@0PXjN0?kmo`3GeN<0GVF?05ERS026S9`0
no_m0?3`n03?c]`0dMSN0=3Ij01CG6d0dmSK0?[no`20QJ80OHVQ0?coo@3Y
l_T0JW:F05EKN`3iool0m?[f06=ZQP1IIHl0GVNB05IUO03Qjn`0ooom0=;A
h@1HHGh0`<OG0?oon02HW[P0GFN005EON01TJX80_;k=0?_no`2S[;D0Q96Q
0?ommP3hn?H0d]WQ0=7Nl@2W]]L0MHB]06mnZ@1WMZ40FfZ90=?Kg@3kool0
P8^Q07n:X03kool0dm_M05i]S01MK9D0GVR;07j3U`3nool0o?km0;2g_`1N
K8L0GVnK0:Va_P3no_l0ZZjj05i]PP1LJh00d]GN0?ono`3Oi>X0g=W/0<oC
g02QZ;P0GfIf0?Oko03lool0H6Ao0::/a@3mn_l0g^3_069YN`27Si`0nooo
0=?Ii`1]MYD0JWNT06EdT`29TJ@0nooo0>CYk`1YLgl0GV]l065XPP1mP9l0
oOo`0?Ofo`1aKi@0M7>B0=_OjP3kool0l?Cg0=SLg`3YkOH0n?oo06]dQ@2V
[;`0o_ko0>SWk@3Ig><0dM[S0;g;iP27UKP0PiBo08ZMb02;W/H0RIg208ZK
aP2@W/dJ08^La`<0Rig50`2:W<8308ZLa0<0Rig50P2:W<@208bMb00408^L
a`2:VlH0RY_608ZKaP/0Ric70P2<WLP208^La`0;08bMb02=W/T0Sj3;09JX
d02KZ/T0Yjk1096AV`3gmOX0oogo0?ono`3mo?l08`3oool20?knoP0@0?gm
o@3hn?P0l_;b0>_VjP3Qhmh0f]oK0=WJgP3KfM`0g=_F08jAUP1eOI80OHRT
08ZH]@2JYlT0XZoB0:>_e@80XJoB01P0XK3A0:6_dP2Q[m80X:kA0:2]d02M
Z/`0V:G709:O`@2@V[d0RiVc08RF/`2<UKH0S9Fb05UTN01bOI40NXRR08ZG
]`2HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m8]0:2^d@@0XJoB01<0X;3D
0:2`dP2P[]40Wjk?09b[c02HYlH0Tj3008nM^P2:V;D0S9Ze08RB[@1MIh00
TI^d09:L]`2N[<T0YkGB0:fheP2^^ML0[k[H00@0/;_I102a_=X30;:mf`80
/kkL0P2c_]X60;Bof`080;g8gP3:d^D0dmWW0=GHh@2BTiL0o_ko0?ooo`3n
o_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0
g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@1@0<6j
WP2i/iT0][2J0:JPT02IUHT0iN3J0?[fl`2h];<0UYF309VGR02DTHP0oocg
0?_jmP3NgM/0i>?O0=cKe`3Zj>T0ooko0:n_Y@22PWH0oogo0?ono@2>SGT0
SXek08^<OP3Hem80oO_l0?ckn@3Lg=@0QXIl0=7Ab@3mo?P0d]3409:@P`2;
RGX0RXMn0;nn_03oo_l0g]gI08R8OP2WYZ40n_[b0>WYg@2GV8X0RHYl0;Ng
[@3mo?L0h=oM08n;O`2WY9d0ookm0?Kbk`3IfM40i^KL0=_LeP3emOD0o__b
09RES02LVI00ooof0?KcjP2/ZJ00TY2408j<P02AT8`0lo;^0?oonP2a/JT0
Y:>N0?oon`3LfmT0U9:C09bIQP2b[IT0_[RR0<FmYP3<aJ/0b<2Y0<K0ZP38
`Z`40<[2[@P0bl>^103<a:l0403:`k00fM;00>GMd03Rg]80ZjbV04UBF`1@
Ggh0DfFE05idY@1WOJh0Jh2e06Yo]P1YP;H0JX6g06V0]01ZPK=806Z1]`1;
06V0]P1[P[P0K86h06Un/`1VNZd0GgBS05MZU@1>HH/0d/oT0?Slo`1nQJ40
E5n<05MVT@1GIIH0EV:B07j9Y@3lo_T0f^3^04mKJ`3Nin`0o?oo09JH/@1M
IXd0CVF707f:V`3lool0dM?P055MQ`1?H8`0QHfP0?gno`3Be]T0G6B804mM
M`1CHX40Deij0<oFgP3en?l0RHbM0<gFg`3eo_T0XZnh05YVSP1AGX00mOom
0?Son`1DGWT0FVND05UQN033cm/0mooi0?oll`3Hf>@0D5Uj09BL/`3mnOH0
j^gf0<gCh@3?e^H0b]7K0?KfoP3gmol0N7f@07j;WP3ooo/0d]OM06mjS01_
P9h0L8J[06V1Y`1/PZT0HGNN06=]T@3Bf=P0nool0080QXfY04<0nool0=;H
f01SKI40GFRE06mfT03Si^/0oooj0?gmo`2UZ;L0JgNA05a_S`2V/;`0nooo
0:^c`01OLHT0G6j60=?Ji03ko?l0RY>H05mUQ`1ULHL0GF^506=^PP3kool0
oOon071bOP3bnOl0oOgo08V>XP1[MX`0RIFU0?Soo`3>e^40JgJB06YhY`1Z
MiX0J6n;0=cNj`3jo_l0d=SK0=;LiP3CfnP0g^3]0?Kol`2l`]80HfN40;_1
c@3iool0gNK_08>:Y01hOi`0M82H0:^jd@1VMXH0ZK>m0?coo`2^[K/0M7RC
07=lX`1iQj80OXb_08VJa@28VlH0Rik608VM`P2;W<L0SI_:01/0Ric70`2:
W<@208ZL`P@0S9g8102;W<L00`2<WLP0Ric708^La`0208ZKaP0308^La`2<
WLP0S9g800T0Ric70P2<WLP208^La`0;08bMb02=W/T0Sj3;09RZd02O[/l0
Zk;<09:EY03FeM/0ooko0?cjo@3oo_l08`3oool20?knoP0>0?gmo@3hn?P0
l_;b0>_VjP3Qhmh0fn3L0=WJgP3KfM`0g=_F08jAUP1fOY<0NhVV08ZG]`2J
YlT20:6_e0040:2^d`2Q[m@0XK7C09n_d`80X:kC01@0WZc?09^Yc02GY<L0
TIk008fJ_02:V;<0QiFb08bE]P2<UK80FFAj075lT01jR:80S9Vi09RVb@2P
[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dRd0X:kA102Q[m804P2Q/MD0X;3B0:6_
dP2P[m00WJc=09RWaP2DXL40T9jk08VG]02>W;L0T9Ze06UcS01iPi`0Tifh
09BR_@2U/lh0[KSF0:jie`@0/;_I102a_=X30;:mf`<0/kkL1P2d_m/20;G0
g0080;g8gP3:d^D0dmWW0=GHh@2BTiL0o_ko0?ooo`3no_`B0?ooo`00803o
ool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0
UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@1@0<K1Y02j]9X0[jZD09jI
QP2CSh<0j>CK0?oonP2i]K80Xj:60:6ORP2ETHD0g]_D0?ono@3`k^l0fMSF
0>[Yi`3oood0m?;c08V:O02:R7T0ooco0?ginP2>RgX0R8Eb0;^k[`3oooX0
hn7T0?ono`3JfM@0S8b20?_kl`3kn_H0Wib9092>N@2KV8D0]kFX0:VUXP3l
n_d0ooom092@R02n_kL0oood0<?2/02GUH00TXml08f;O03oooP0o?gh08J2
MP2HThd0n??`0?oln@3Ph=H0h>;G0>o`j`3oool0gmg>08R6N@2m^jl0oood
0<[8_02GUHH0TI1n0:^ZUP2QX9`0fMSC0?Wil@37akl0Y:BL0?oonP3Qh=h0
SXb=0:6OQP2YYH`0^[BJ0;beV@38`JL0b/:[0<[4[P3:`k030<[2[@P0bl>^
1@3<a:l03P3=aK80f<nn0=oGbP3QgM40XJBM04UCG@1=GGh0Ef^M05meYP1X
O[00Jh2e06Un]@1YP;H0JX6g0P1ZPKE806Z1]`1k06V0]P1[P[P0K86h06Un
/`1VNZd0H7FT05Q[UP1?HX`0d]CP0?Wno`26SZ<0F6B<05=RR@1HJID0EFRC
04eSNP2na/T0nooo0<gAe03kool0c=;R06=[T01LJYL0EFRB08B@Z03kool0
c=?M059TRP1?I940OHVO0?Ojo`3Ce]/0Cef404ePP01DIXh0CEUo0<W?f`3n
o_l0][W20?Gnn`3:eMT0FVYi04]JP`1@GX40looo0?Soo`1?FgD0D5f70::Y
/`3gool0fn7Q0?oomP3;c]L0Gf^A05QRQ@3emOl0m_Sg0=gQk03;dmh0i^ka
0?coo`39b]`0Ff9n08:@Z`3mo_l0eMc/06akVP1^Q:d0MI2k076=]01/Q:P0
GgFJ06=/T`3Bem/0nO[l08:9YP25S:T0o?go0<oDf01IHXT0FF650<C;f`3l
ool0hnCO0?clo`2c]m00HFb805a/QP2Z]/@0lo[o0::[_01JKH/0FVj90=3H
i@3lool0RYFK05m[T@1HJH<0EfN8061[Q`3io_l0oOgk0<C5b@3hooL0[;:n
061[P@1HIX<0T9bb0?Coo`3HhNH0IG2406IdV@1TLI@0KgFG0:j_``3lool0
mOgo0<_Dg@3Af>00n_ck0?Goo`24S:40IVb40080mooo01<0N8BL07b7]01k
R;D0MHB[07:2X`1NL8@0Z;Fm0?_oo`2a/l00Iff=07J2/P1oSJP0QiFh08VJ
a@24Ul80S9o708VM`P2:VlH0RiW801`0Ric70P2;WLD208bNaP0308bMb02;
W<L0Ric700@0Ric700<0S9g808^La`2;W<L00P2:VlH208^La`80S9g82P2;
W<L03P2<WLP0Ric708^La`2;W<L0SIk908jObP2GYl/0Y;;E0:N`c@2QYkL0
][Nl0?ooo@3ooOh0o_co8`3oool20?knoP0?0?gmo@3hn?P0l_;b0>_VjP3Q
hmh0fn3L0=WJgP3KfM`0fm[E08jAUP1fOY<0NhVT08VF]P2HYlP0Wjg@0080
WjgB0P2O[m4209n_d`0E0:2^d`2O[M00W:[=09JTa`2AW/00SIZl08ZH/`28
UKD0S9Bh08bE/P1HHgT0LGb@07Z8XP2<VK/0V:K90:2^d@2O[M00X:kA0:6_
dP2O[M00XJoB02`0X:kA1@2Q[m80502Q/MD0XK7C0:6_dP2P[m00WJc=09VX
a`2DXL40T9jk08bJ]`2AWkX0S9Ja07Z4W@1XLX/0SIN`09BR_02O[LL0[;OE
0:jie`2`^mT0/KcJ0P2`^mT00`2a_=X0/[gK0;:mf`030;:mf`<0/kkL00<0
];oM0;Bof`2d_m/00`2d_m/30;G0g0080;g8gP3:d^D0dmWW0=GHh@2BTiL0
o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[
0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D8
0<S0Z@0[0<:lXP2k]Id0/ZfG0:>NR`2HUHH0inGH0?omm02h]J`0YZ:70:JQ
R`2PVX`0^;>]0?ghm03LfM@0RXN00<71]`3oo?L0fMKA08b;MP2:Qg@0oo_o
0?omo`29Pg<0YZ6>0?oom03Th=d0[:N[0?omoP3Uh]d0Y:6J0?oonP3UhN00
VIB109RCO`2c[YX0noSY0?omm`3ooOX0oooh0:NXVP32`kh0oocc0<K3/P02
09^FPP0S09:?P03oo?L0oooo09J@P02:PgT0al:n0?onn034`[H0Ph=g0=WJ
e03lo?`0^kRY08n;O`3Th=D0oo_b0;2/X@2HU8P0VYN60>CRc@3oooX0ooce
0?oomP3Og=<0/:fT0?gjl`3_jnP0blO60<o<_@3<a[H0_KJT0<JnZ@3<a:l0
bl>^0<_5[`39`Zl00P3:`Zd80<_3[PH0c<B_00h0clNd0=G<_@3Hd<<0gm_@
0:RZY@18DU`0DV:405Q/W`1PMZL0JGna06b1]P1ZOkH0JX2i06^2^080JX6e
B@1ZPKL0S`1[P[P0Jh2g06Un/`1VNZd0GgBS05MZU@1?HX`0d=7S0?coo`2b
]/80YZc60:Nac01SLIP0F6ZJ04mWR@1YN8l0jo3d0?oon03jnOl0O8NU05ic
WP1FJiP0DV>?07j7Y03no_l0dMKL05ATQ@1<HH`0P8^Q0?koo`3[jo<0XZVl
0:6^_P2BWkl0Een30<kBgP3oo_l0noko0?WonP2e_LX0I6n104mKP@1GHX80
m_oo0?Woo`1LHWX0M7nO0?[oo`3Dfnh0T9>R0?ooo@3?e]h0G6jB04eOQ@2_
^<T0o_oo0:R^_01EGVd0aLoA0?KkoP2MX[P0FfJ607jA[`3ko?l0e=_]071n
X`1dRKP0LXZh0768/@1]PJH0I7>J05i[S@3Ae]`0o?oo08B<X`25SJ@0o?oo
0=3Ef`1LJH/0ZJnm0?[no`2m`LX0Zjnj0?Woo`2Y[lL0HFZ706=^S02W/Kd0
nogo0:fba@1OKXd0FfZ70=;Ei03mo_l0_<?90:V^a02U/L40MX6O05UOO`3j
oOl0ooko0?gno`3kooP0ZkBm069/Q@1SL980PXbU0?Ono`3[l>`0ZK2f0;6i
cP2AXK/0J6j>07EeS@3ko_l0kOCj061WN@22QY80o_ok0>7[m01[LXl0SiF]
0?Woo`3?fM/0OhN[07N3]@1hR:`0MXB[06UiV`1/Ni80Zk>n0?Kgn@3If]l0
[K?30:fke@2JZ<<0Pi6d08JG`P2:WLP0SJ3808RL`@2:VlH0TIo>01P0Ric7
00D0RY_708^La`2;W<L0Ric708bMb00308bNaP<0RIc400<0R9_308VLa029
W<@00P2:WLD208^La`80RY_63P2;W<L00`2<WLP0Ric708^La`0208^La`09
08bMb02FY/L0Y[GF0;6jf@2[//@0WZ:U0?cnn@3ooo/0noWl02<0oooo0P3n
o_h0403moOd0n?Sh0?;blP3[i^X0h^CO0=cQg@3Jfml0fmWL0=_Je@2>TIH0
MWjC07^9Y028Uk@0V:O609n]d02P[]<209n_d@0H09n_d02P/=80X;3B09n_
d@2O[M00W:_<09NVa`2AX<40SY^m08ZH/`29U[H0SIFi08bE]01HHgT0LGbB
07^9Y02;V;X0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB:`2P[]460:6_
dP0B0:6ae@2Q/M<0XJoB0:2_d02M[<d0V:O609BQ`@2@W[/0SYbi08bJ]`2?
VK@0PhfV069]P`22SJ<0U:>j09ZX`P2[]]@0[[WG0`2a_=X00`2`^mT0/KcJ
0;:mf`030;:mf`<0/kkL0P2d_md40;Bof`@0]L3L00P0_LSN0<[Bi@3CfNL0
eMSQ09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi
0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0
^k>L0<BlY@P0b<2Y0500`kfS0;fgW`2b[IL0X9j909BAP03Rh=40ooob0;jn
/P2`ZY80[:FB0:>MT@2GT8P0oogg0?Oej@2<RW/0j^WE0?oomP2`[:<0THmf
08b:L`3on_l0ooco096;N`3gl]l0moGY0:FQWP2/Yj/0oogn0=oLe`2XYI`0
oooh0>7MfP2JTXD0VI:00:2KQ`2h/Z80ZJFJ0;>`Y`2WYIH0TY9j0;jl_@3o
ooX0c/Rj09ZCP02FSgd0Thf10?onn`3mnol0V95o09ZBQ`2ZXi/0ooke0=SF
b@2@TH<0oooh0?Wim`2KUh/0Thn40>ORg03oo?P0]:nY09bHS@2DTH80[Z^H
0:j[Y02[Z9l0[J^O0:>QU@2TXYH0ooof0?oonP3oo?T0oo[j0?7YiP2e[:D0
a[b`0<Ro[P36_ZT0b/B^0<O1Z`L0bl>^203<a:l04@3=aK00cLFb0=S?`03M
eLP0hMgB0:na[010C5P0E6N805EZW`1RN:T0JX2b06f2]`1[P;T0Jh6j06^2
^01ZPKL0JX6e04T0JX6g01d0Jh:h06^0]`1XOK80IGV/05icXP1GJYD0CV6;
0=?Bi03mo_T0oook0?cmo`3io_l0RiN_04mPS01;HhT0BUf80<S<e@3ono40
hmo]05MVS`1;J9@0Cf^C05ETS`26Rj/0ooko0=;Ce`1EIGl0CV:70828W@02
0?olo`1`0?konP3lood0bM3R05QLN@3Cdml0o_go0=cOi03Skn<0noko0<_B
i@1JHXH0CUEb0?coo`3mo_l0JF^00>7Wo`3dmol0OH2O08N8Y03mo?l0d]_R
05Q_T@1GKiD0NHRM0?coo`30aMT0JW:70?Coo`3do?l0K7:805]XRP1oU;40
ooom0=GHj@1dOJ@0Nhfm07F:^@1gR[@0M8:Y06YcW01SLH`0cM;H0?coo`24
S9l0PHVL0?[no`3Gg>80NHNR0?coo@3Jg^L0KW>70:N]``3gool0Zk?606=/
R@1RJY40[;2k0?ono`2][/00HFb:065ZQ`3HenD0oogo0?_no`3no?l0o_oo
08B9W`1[K8X0o?[o0?olo`3Cdm/0lO_c0?Soo`2X/<L0H6R=08bB[03nool0
o?cb0?oon`3joOl0Z[_;06miU01dMXd0c]7J0?Klo`23RJ40^[g@0?_mnP2`
]lL0IfZ;09RI]@3go?l0fn;/075fX01lQkD0MXNK07F2Y01^Ni/0Ig6<0;2d
`03ln_/0oooj0?coo@3aool0]L?N08:@/`26Ul80RYg808VLa02>X/L0SIk9
08ZHaaP0Ric700<0RY_708^Lb02;W<L00P2;W<L208^Ma@0308ZLa02:WLD0
RYg500H0RYg5102;W<L408ZKaPP0Ric700H0RY_608^La`2<WLP0S9g808^L
a`2:VlH208^La`0809Z[b@2V]MH0]/7O0;_2e02=Ti<0oOoi0?onn@3oo_lS
0?ooo`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>;Tg`3Mh]h0f]_O0=cJg@3K
f]D0SY6F07EmTP1jRZ<0R9Rb09RWaP2P[m000P2P/=8209n_d080WjoA01D0
Wjo@09j^c`2LZl`0UjK5096P_`2=W;/0RINb08RE]@2=UKT0RiBc05QSN@1b
OI<0NhVT08VF^02HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m80:@2P[]47
0:6_dP0I0::`d`2R/]H0XK7C0:6_dP2P[m00WJc=09RWaP2DXL40T9jk08fJ
^P27UK80Tifh08fG/01KIW`0PHbR08^J/@2KZ/40ZkKD0:jie`2a_=X0/[gK
0;6lfP2`^mT0/KcJ0;>ng0030;:mf`80/kkL0`2d_md40;Bof`@0]L3L00P0
_LSN0<[Bi@3CfNL0eMSQ09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@
0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0
RXQk09VDP@2XXX`0^k>L0<BlY@P0b<2Y0540akfT0<2hX@2aZI@0Y9f;09^E
R@3Vh]T0oooj0<2l^@2d[9L0/j^F0:NPS@2QWXd0alFi0?oonP34a<@0nO[n
0?O]k02LUXH0UI5f08Z8L`3oooX0noWn0=_Kf`3nooD0_[^/09:>PP2/Z9l0
oooh0>7MfP2=RHH0oogh0?Ofl@2GTgP0T8ac09^FPP2GTWl0TH]k09B?O02>
RGH0THah0<34a@3mo_T0c<Rm09^DQ02HTH40THf20?_lm`3lool0X9F109fG
P@2GTWl0k>WR0?omo`37aLX0n_Wg0=_Hc`2IVhH0V9J70<?1]@3oo_P0bLBn
09:;P@2GTH40U8mk08n<N`2DTH00Shai08V6L`2/ZIX0ooga0>_WgP2^ZJ<0
]kJT0;ZgY02l]j40`KfT0<W1ZP37_jP0clB`0<^nZ`3:`Zd0203;`jh70<c4
[`0<0<c3XP3Gcl@0e]7;0=_Ha@30_jd0A4QD05IUS01AKYX0HWRW06Qn[`1Z
Ok@0JWnf0P1[P[P00`1ZPKD0Jh:d06Z1]`0O06Z1]`H0Jh2g1P1/PKP406^0
]a00JX6g00<0JWnf06^0]`1[P;L01@1[P;L0T01/PKH0Jh2e06^0]`1[Ok@0
Ig^^05mdX`1GJYD0D6>;0<SBbP3hool0VZJd086?ZP1hRj`0G7>C04UTO`1>
JX80LFj;0?coo`3bo?40mOoo07f;Y@1DHY40EVRF04aRQ`21QJ80mooo0<OH
g`1?Gh00Cef:07^9Y03gool0f^?R07^;Y01jSZT0KXJP051SL@37eMD0m_oo
08>?W@1;F7P0j^OP0?Woo`1LJXL0DeUm0?ono`3onO/0c]3L0>kmo`2?X/00
FfN?08R>Y03iooP0dmWI06Y_U`1PK9h0EV^:0=gNl`3knod0[[2S0?_oo@2h
a=X0H6nF05e[T025TJ/0oogh0=gOj`1bOId0MXRf07F;^P1fRkH0L8:Z06Me
W01PJ8`0e=KR0?koo`1oQId0Ri2T0?kjm`3XiN00i^Oi0>[io`20Qj<0JVf>
0:VZ_03go?l0[KC7061/TP1IIiH0Zj_50?Woo`2S/;P0FfR;05eZS@3<fN40
nOoo0:j^b029T:`0R9FX06EeS`1IJGT0m?og0?Woo@1MIGP0Lh:I0?omnP3P
inl0FV]k082@X03iool0gN7/08jJ/027X;l0QI2^06akV01[NiD0U9nc0?km
o`2n^Kl0j^S[0?ooo`1lT;D0JWRE07IiS03ln?l0n_Ko07YjU01dO:<0JWRW
06]nW01WMY<0HVj40:Zd_P3gool0^/O=08^KZ`2CX/40R9Ri08RH^P27VKl0
QYS0092RbP2:W<@0Qi_008fQa1P0Ric70`2=W<L00`2=W<D0Rig508^M``02
08^M``0308VLaP2:WLL0Ric70080Rig500<0SIc508bKa02<Vl800P2:VlH4
08^La`80S9g82@2;W<L03P2=W/T0Rig508VM`P2<X<D0Rik608RNa`2:X<T0
V:[@0:ZifP2h`mT0a/cJ08R;T03oool0no_k903oool20?knoP0?0?gmo@3h
n?P0l_;b0>_VjP3Qhmh0fn3L0=WJgP3KfM`0g=_F08jAUP1eOI80NhVT08ZH
]@2HYlP0X:kA0080X:kC01T0WjoA0:2`d@2P/=80WjoA0:2^d@2O[M00W:_<
09NVa`2BWl40SY^m08RI/`28UkH0RYBg08bE/P1II7X0L7^?07j:Y02:UkT0
V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB00T0X:kA0P2Q[m860:2^d@P0
WjoA0P2R/=<20:6_dP@0X:kA00<0Wjg@0:2^d@2P[]401@2P[]4209n]d003
0:2^d@2Q[m80X[3C00<0X[3C0180XK7B0::bd`2R/M80XK3A09f/b`2HYLD0
TYno08nL_02<V[L0SIRd09>M]P2;TjX0GfMl0869WP29U:X0VZBm0:Zed@2^
^MD20;:mf@040;6lf02b_MT0/kkJ0;:mf@@0/kkJ102d_m/80;G0g0080;g8
gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403n
o_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8
N`2IU840Z::<0;^cW034_:D80<S0Z@1@0<NmY02l]9d0/ZZE0:VRT02JU8H0
hMgB0?ommP32_kX0/ZZE0;VaW02^Yi@0X9^80;6_XP3oooL0kno]0?ooo`3H
clX0X9^809nKPP2JUhH0n_Kc0?ono`3mo?P0e]S:09fJR@2DTH80/JfR0?om
m`3Sh=/0THj90=cIdP3oooP0aL:a09JCQ02=RGd0Sh^00;FaYP3Dd<@0ZjRI
09:?P033aL@0o_oi0<_7_02PVHT0WiR809RDR@3oooX0o?km0:VNRP2VWXT0
WIR50<S5_03oo_l0lNob0?onn`32`;@0Y::=0:FRT@2]ZIh0oocf0>oZi02Q
WI@0Ti2109NDP@2MVHh0eM760<S4^02@S800[:RM0?onn03RgMX0UY2@09ZG
R02^ZiX0/ZfI0<2jY03:a:`0b<2Y0<k3[@3Bak<60<_3[PP0c<B_0P3=aK00
403?aZL0d<Rm0=??aP3MflH0cLbh03m3CP1DHhX0DF^N069hY`1XOZl0Jh2e
06Yo]P1[P[P0JX6g06Qo/`1XOk4P06Z1]`80Jh2g2P1ZOkH406^0]a00JX6g
1P1[P;L206b1^080K86f08h0Jh2g06]o]01XO:l0H7FT05M/U`1CIY00dm;P
0?Sio`23QZD0Ff2805EMR`1DHHh0DfB@04aMR@3Bd=d0o?co0<74b`3iool0
i>gl05QTO01CH800Df6608Z7XP3jo_l0bmCM05ENO@1KHXh0OhBR0?_oo`3?
d=@0FV24051IQ01@GHT0FfJ60<[?h`3loOl0OWnM05iSS@3Fe/`0n?oo07^8
Z`1MIHT0moWh0?oomP3dn?l0`/oP06=fUP1FHXX0Ri>Z0?[oo03AfM`0K7BK
06YhZ@1KL8l0[:k50?koo`3]l>T0mogm09ZV_P1LJi@0I7:G08VD/03lnoT0
fMc[07J0X`1jS;X0Mhfl07>8/`1_PJT0JWNQ06MbT03AeMh0o?oo08B<W`27
SYh0oOkh0?kmn03iool0WJnm06YeU@1WJhh0[[700?_oo`2V[kP0GFV105m^
R`2^Zkh0mo_j0:fe^01SJXL0H6N40=OOhP3ioO`0TXnR06IUS@1PIXP0I6^G
061VRP3kool0no[o061PPP1WKI40oogm0?;fo`1WM8D0SYNV0?[jo`3Ge]`0
JG2006YlU01aO9P0M8>R06alW@1aNi@0l?;o0?[ho@3oo_l0g^7Z06n3Z01h
QjH0M7Z@0<S:e`3no_l0`<?B079jS`1ZMY00IG2@08nE]@1^Li00[:o20?Ch
o`2a]l<0K7:807IlW01kS:X0O8b]08ZL`028V/80RI_308fNb@2=X<P0Qi[2
602;W<L408bMb00408bNaP2:WLD0RYg508VLa0@0RYg700@0Ric708^Ma@2:
W<@0RYc40P2:VlH408^La`80S9g82@2;W<L00`2=W/T0Rig508RK``0208ZM
a@0:08VLa02<WlT0VZ[>0:nlg02nbMl0a<[F08jAUP3no_l0oooo0?knoR<0
oooo0P3no_h03`3moOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cK
eP2>TIH0MGfB07^9Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40X;3B
09n_d@2P[]40Wjg@09b[c02GY/L0TYo108jK_@28VK<0R9Nf08ZD]`2<UK80
FFAj071kS`1nRZ@0RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP0A
0:2^d@80WjoA102N[]0209n_d@80XJoB302P[]420:6_dP040:2^d@2Q[m80
XJoB0:6_dP@0X[3C0180XK7B0::adP2Q/=40Wjk=09^Zb@2FXl<0TIjn08jL
^@2<V[L0SiZf096K]02AVK00Ff=h07^3V029U:X0VjFn0:Zed@2_^]H20;:m
f@040;6lf02b_MT0/kkJ0;:mf@@0/kkJ102d_m/80;G0g0080;g8gP3:d^D0
dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0oOgm
0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840
Z::<0;^cW034_:D80<S0Z@1@0<JoY@2o]j00]JfH0:RQS`2PVXX0jnOK0?oo
m02o^k80^K6L0<6iY02h/Y`0YJ2=09jKS03Yim/0oooj0?ckn@2cZih0ZjBA
0:2KQ@2LVHX0oogm0?ono`3]kN<0ZZbF0:JQSP2QVh/0^K>W0?onl`3Vh]T0
Ui>:0;:`Y03ooO40oooj0<K3_P2e/Jh0b/K30?kkmP3oooP0`l6e09VGRP36
al80oooh0=;<_P2WX8h0X9V709fGR@3oooP0oook0:jSS`2[Xhh0YJ2<0:FQ
U@3kmo@0ookm0?Sck@2/Z9`0]:jH0:^TTP2UWI80h]_C0?onn03XiMh0^KN[
0;6_XP3Qg]T0oooh0>SUgP2QWYD0]K:[0?onn`3bk^d0al?40<c8_@3GdlL0
^K>S0;nhY@3:a:h0bL6Z0<RmY`3=`Z`50<_3[PP0c<B_0`3=aK00403@aZd0
cLFh0=?=`@3Lf;l0fMO2059BFP1@G8@0EFZS061fY@1WOJh0JWnd06Yo]P1[
P[P0JX6g06Mn/P1XOk4P06Z1]`P0Jh2g101ZOkH406^0]a00JX6g1@1[P;L3
06b1^080K86f08h0Jh2g06Yo]01YOK00HgNY05]`W@1EJYD0fMKQ0?[ho`2o
_/h0Z:Zo0:^ab`26SJX0DUem08J@/`3lool0lO?o06MWP`2j_=<0m_go0:^b
^01bNH/0XJK60<C2a`3nooT0j>gW0:BZ]P2HWK<0QHNF0?knoP3]k>L0ZJZn
0:Z`bP2T[L`0GVAn0=KEi@3ooOl0[Zfm0:NY`03lood0jO?o05MTSP1HHXD0
nook0?_ol@3RjOT0L7fM069dV01SL9X0T9Ze0?Soo`3EgNP0J76J06]iZP1R
NI/0KgJB0?Gio`3lool0i^oh06UgTP1XNJ@0Hg:I08nJ^03lool0dm[]07B0
YP1gRKL0NY2o07R=^01dQK00KWfX06AbS@3>eMl0nOoo08^HZ@28U:80o?oo
0?koo`3;e><0KH6J06ajX@1/M9T0[[K30?Soo`2_^KX0R9FN0:Ne`03He>80
o_kl0=SLg@2[/<@0R8fQ0=;Fe`3oood0aL7?0;6_a02///00TiRe06IZQ`3n
ool0moGj0:2O/@2j`<h0ooco0<[=g01[LhH0TiVY0?omo`3_jNd0];Bn0;Jo
cP2V//X0NXR[07F4[@1_NYX0^l7?0?_lo`3joOl0/KK:07V;/`1jRZ`0MXBN
08B=WP3TkOH0nOoo0<kGg02d_L80a/cH0>c_oP1dMHL0/;2l0?ono`3HfM/0
]k[10;Fga02[_=P0PiBb08JI^P2:W<@0R9W408bMb@2>XL`0RIc6602;W<L0
0`29W<@0RYg508ZMa@0208ZMa`80RIc700<0R9_608ZMa`2:WLL01P2:WLLA
08^La`0?08bMb02;WLD0RYc408ZMa@29W<@0RYk308nSb02P[m00]L3L0<G=
h039cMP0UiRL0?knoP3oool0o_cm02<0oooo0P3no_h03`3moOd0n?Sh0?;b
lP3[i^X0hN?N0=_Pg03If]h0fmWL0=cKeP2>TIH0MGfB07^9Y02:V;D0V:O8
0:2^d@020:2^d`0I09n_d@2P/=40X;3B09n_d@2P[]40Wjg@09b[c02GY/L0
TYo108jK_@28VK<0R9Nf08ZD]`2<UK80FFAj071kS`1nRZ@0RYNi09RVb@2P
[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP0A0:2^d@80Wjg@102N[<l209n]d0H0
X:kA00<0XJoB0:2^d@2P[]40102P[]430:6_dP<0X[3C00<0XJoB0::`d`2R
/=<00P2R/=<01`2R/M80XK3A09n^c@2LZlX0VJK609BQ`@2@W[/00P2=VkP0
2@2>VKD0SiVb092H[`1KHgP0NH6F08^F[02KYKh0ZkKB0:njeP030;:mf@H0
/kkJ1@2d_m/80;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3n
o_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0
g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@0o0<Fn
Y032^Z<0^k>N0;6ZU`2aZYP0kNOG0?okk@3;aKT0^k>N0;bdW`2j]9h0]:fJ
0:JQSP3Bcl00oocc0?7^i`2`ZY@0]k6I0:RSS`2SWI40ookk0?Wdl@32_k00
ZZZ>0;2YUP2WXXl0`K^[0?oik@3YiMT0ZJFI09bIRP38aK@0oO[e0?_hl`3o
o?T0oooj0?[gl03Acl<0ZjVJ0:2OS@3Ed/T0o?S/0=C>_P2`ZIH0Z:6>0:ZT
U03kmn/0ooof0;N/VP2cZi@0]:nI0:BQT03Th=L0o?Oc0>7Jd02e[il0_kBN
0;R]V@2_YYL0^K6V0=kGc`3oooH0ooke0080ooof00`0jnSO0;bj[P2NW900
^[R/0?Sek03oooX0oogj0?onn03on_00aKna0<6jZ035_jT20<_3[0030<o7
/03;`jh0bl>^0080bl>^203<a:l50<g5/00;0=39^@3CcKd0eM6h0=_F`021
PH40ATm`05][YP1NM:<0IWb]06Yo]01ZOkH00P1ZPKL00`1YP;@0JX6c06Z1
]`0O06Z1]`<0Jh2g0P1/PKP306f2^@@0K86h101[P;L@06Z1]`@0Jh2g101/
PKP206^2]P2>06b1^01[P;L0JGjc06EiZ`1OM:<0Fg2K0=?Fg@3lool0nooo
0?Woo`3_n_l0XZjl06McR@3@g?H0m_oo0:V`bP1TJI<0SYBh0?Koo`3Wl?L0
UYj[0?Sno`3loOl0o?oo0?Woo`3bnol0d=OZ09NL[`3cm_l0oOko0?KkoP3g
ool0ko[o06]dQ@3CeN40o_oo0?Gjo@3hool0k_Co09bX`01[NZD0Hg6F0?Oo
o`3hool0SYNh06akY01XNjD0K7^V08nM^P3/n?l0e=oe07B1[@1^OZl0IG^P
06ehV03<e>T0l?So0;_6f01]OIl0Kh:]071oZP2;V;X0mooo0<oIm01mR[@0
MhVi07J=^@1gS;L0MhRc07B2[`1]OIh0emod0?Glo`2;Vk@0RYZa0?Woo`3V
k?X0OhjU07B;[@1^Ojd0K7VS0:nlc`3^nOd0[kW30:nkb@3cool0o?ko0?_o
o`3go_l0lOOo0;k4fP3@emd0nooo0?cno`3kool0l?cj0:Rd`P1dO8l0n_on
0?koo@3bmo/0moom0>SZo`2IX;`0JWRC09JN]@3inol0oogo0?cno`3eo?l0
dn;i07j=]01dQK<0M8:W09VR/`3jo_l0m_co08ZC/P1oS[L0QIBk07^;[@1l
S:H0U:>f0>7[m`3hool0moco0?Woo`3dnol0Ngj?0;Jib03lool0mo_n0?_o
o`3ho?l0c=gi08^L^P24UkP0S9k608bMb02:VlL0RYg808bObQP0Ric700@0
Qig208NMa028W/D0R9k70P2:WLP208VKb@80RIc40`29W<H00`2:WLL0RIo8
08VOb00@08^La`0@08VLa02;W/P0S9g808^La`2<W/H0Rig308fO``2DYlP0
Z[SE0;[4g@3;d^@0aLSA0:JWZ`3oool0oogn0?onob<0oooo0P3no_h03`3m
oOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cKeP2>TIH0MGfB07^9
Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40X;3B09n_d@2P[]40Wjg@
09b[c02GY/L0TYo108jK_@28VK<0R9Nf08ZD]`2<UK80FFAj071kS`1nRZ@0
RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP0;0:2^d@<0XJoB00@0
X:kA09n]d02O[M00WZg>0P2M[<d209b[c080WJc=00<0WZg>09n]d02P[]40
0P2P[]430:6_dPD0X:kA102Q[m870::`d`0D0:>ae02R/M80XK3?09f/b`2J
YlL0UZ?309:P_@2AW;X0SiZh08jL^@2=V;@0T9Zc08::X@1RJWl0Nh>H08^F
[02LY[l0[KSD0;2ke`2c_]X20;:mf@030;>nfP2d_m/0/kkJ0080/kkJ1P2d
_m/80;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?oo
o`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[I
gP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D90<S0Z@0m0<>kY02m]il0
^[BN0;6ZU`31^ZP0blBb0<2iY`35_JP0`[ZS0<6iXP2n^:00/Z^H0;VdX@3A
bkd0blNk0;jhWP2i/iT0]k2M0;2ZWP3Me/h0clRn0;F`W02n^Yd0_;JP0;F_
V@2m]Z@0c<Fe0<K0/02c[Y/0/JbH0:bZU@2]ZId0bLFi0=SDb03Bc/80_kb]
0:j[V02/ZY<0];:I0;^eY`3>b;P0`[^X0;RbW02j]9h0]ZnL0<o9^@3;aKL0
_[>Q0;^cW02l]Y`0]K2L0<K3]03Id/P0b<6a0<:jY`32]Yh0a[^U0;^`WP2f
[il0/:ZN0;bh[@020=;@a00@0<_8]`2g]:<0[:VF0:j/U`2f]9l0a/>`0<C1
/036`k@0al2h0=;:_`2k]:@0b/>`0<W3[@3;aJd0b/B/0<S0Z@@0bl>^203<
a:l40<g5/00<0<c4/@3Ab[L0d<^g0=C>^03Hd;/0][>Z03e3F@1LJId0GWBS
06Il[@1ZOk@0JWnf0P1ZPKL00`1YP;@0Jh:d06Z1]`0O06Z1]`<0Jh2g1@1/
PKP806^0]a00JX6g101[P;L406b1^02506^2]01[P[H0Jh:h06b1^01ZOk@0
Igf_06AiZ01QMZ<0PXb_092K^`22T:/0SYbf08nO^@1dQ:H0JGRQ08ZKb@26
VkP0LhF[06=dX01PKY/0TZ3508JE/P21T:L0RYV`08bG]`28Tk<0RiRj09:O
`P1oRkD0JgJT09:KaP2?VK`0U9jg08VH]`2=WlD0HVnI08::[`2FWKX0T9bf
08nO^01^N:/0KgnS06AfWP1ZNJ80[K_F09jXb`1bO[00MHJb0722/P1^Ojd0
MH>V09RV`02@Wkh0LGn^07F7]`1^QJh0L7nV096N_P2/]/l0RINd07>5[@1]
P[40KWn[07f9[`2HY;`0U:7307N8]01lTL00O9>o07V?^01hRkH0LX:c06n2
[02<U[T0UJ3007J9ZP20Tk@0Z[?B09bUaP1fR:h0LhV`07f?`@1hRKL0PI2]
09JU^P23SZX0Q8n_09NR_P2IYKd0UZ>d09NV^@2HZ<80OhnY08ZI[02LZKX0
UJ6i09FQ]`2JZkd0R9^l07>2Z`2LY[l0Vj>j0::]b@2AXk40NhV/07V;/@1g
Rk00QIFf09ZV`02OYk`0UJ2f0:2/a02IYl80O8jf086C``1nSKH0Oh^S0;W2
d`2f`=T0Q9:g08RG_P23UKd0QYW107V<]01jRZ`0OHRV0:N_aP2d^Ld0ZKG;
09:M^`1eOZD0RiBk09fXb00209jX``050:J/c02N[ld0Pi>d08ZL`02<W/H0
0P2;W<P00`29W<L0RYg808^La`0G08^La`0508VOa028W/D0R9k508ZMa@2;
W/P00P2<WLP01@2<WLT0S9_208bK`P2:W<80RYc40080RIc400<0RIc608NM
aP2;W<L03`2;W<L03@28Vl<0Rik608^Nb02<WLP0Ric708bK`P2@X<80VZ_9
0;>mf036c^<0eM_Y0:b_]P39bL/00P3ooOh00`3oo_l0oooo0?ooo`0Q0?oo
o`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>7SgP3Kh=`0fM[N0=_Ig03LfmH0
SY6F07EmTP1kRJ@0RYRe09RWb02P[]400P2P[]<06@2O[m40X;3A0:2`dP2O
[m40X:kA09n]d02LZl`0UjK709:O`@2>Vkd0R9Vc08RG]P2:U;L0S9Fb05UT
NP1`Nhl0OXZT08ZG^@2HY/T0X:kA09n]d02P[]40XJoB09n]d02Q[m802@2P
[]450:6_dP0509n]d02N[<l0WJ_>09^Zb`2JZLX0102IZ<T00`2JZLX0Vj[;
09j/c`0209n]d0030:2^d@2Q[m80XJoB00H0X:kA1`2Q[m820::`d`<0Xk7D
01D0XK3?09n^c@2LZLT0V:K309BR_`2CW[`0TIbj092K]`2=VkP0SiZf09>M
]P1aNI00Jg>807^3V02;UZ`0X:[30:jie@2a_=P0/kkJ0;:mf@2c_]X00P2d
_m/00`2c_]X0];oK0;Bof`040;Bof`X0]L3L00P0_LSN0<[Bi@3CfNL0e]WR
09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L
0<BlY@P0b<2Y02h0a/2X0<FoY`32_:@0`K^S0;jfX@2m]J00`;RS0<FmZ033
^jH0aKfV0<>kY031^Z00_;JN0;RbW02m]Z@0_kRX0<6lW`2m]id0^kFO0;Zc
X@2n]jL0^kBR0<2jY032_:80_kRN0<6iXP2o^J<0]k2M0;ffX`2j]Il0`knV
0;JbU`2i]9h0]:nI0;RcW`2c[YX0^kJP0<G1Z02j]YT0^KJG0;ffX`2o^:D0
_[RR0;jfW`30^:40_KNQ0P2o^:D08034^:P0`KVR0;fhV`2n^Yl0]k:O0<Bm
[@2o]j@0a[bS0<c2Z@37_:H0a;VU0<:jY`2k]:80^;:R0;^eY@2l]ZP0^[FO
0;fhXP32_ZD0`;bQ0;ZfV`2h]9T0]K6H0;bgX@2m]JP0aKj^0;nhY@3;aJl0
a/2X0<S2ZP3:a:h0b<:/0`3;`jh80<c4[`D0cLF`0100cLFb0<g7/@3;a[00
eljm0=S=^@3Dck`0DUMM05=PP`1MLj80IWb]06Yo]01ZOkH0JX6g06V0]P1X
Ok<0JX6c801ZPKL0101/PKP0Jh2g06^0]`1[P;L206Yo]P@0JGje0`1ZOkH3
06^0]a00JX6g0`1[P;L506b1^02@06^2]01[P[H0Jh:f06^2^01[P;L0JWnd
06Qn[`1VO:/0IgR^06Uk[@1XOJ`0IgbY065fX`1UNJ/0J7fd06Um^01XOk40
Ign]06Z2[P1ZP:l0HGFZ06eo/@1/OjL0J7fJ06QkYP1]Ok40J7Z/06MlY`1X
OJX0KWne06]l/P1XNZP0L7j[06MiZ@1VOJl0LXJk06em/@1cOk40JWfX06f4
[@1^O;d0N8^e07:5[`1bQ;80M8F`07:2]P1dP[l0LhJa07N8_P1fR;P0MXR^
07N7Z`1dQK00MXRh07R<_P1bRK<0L8Fb07J8/01mRZd0NhZa07V;^`1iSL00
MXNe07j;]@1iRJX0OY2h07R:^P1kT;l0OI:m07fC_020T/00OHg007R=_01o
R[P0OHRe0767/01fS;D0Phjk07j;^01jT;l0OY6k07V:_P1kRkh0OHnc082@
/P1kR;D0NHFe07f:]01hRZh0MhZ[07V=[P1kSk80N8b_07jB/`1oT[<0MXR/
07b;]P1eS:`0NY;007V=`P1kR[<0P8bf082>_@1kT[40O96l07fD_P1nUKl0
MH^b07j@]P20T;80Ohna08:E]P27TkT0QINo086F`@25V<00QY>f08^F]P21
Sk80QYRn08bK`P28V/80PY>o08^Mb`21T[h0QI:l082</P28T[D0PYFc07R:
[P24Ul40PYFo07fA]01lSjl0OXj`08JD^`22T[@0Pi>g08bNaP29V/D0Ric8
08ZKa`2:WLL0RYg5602;W<L208NMa00>08VLa02:W<80S9k4092OaP2BX/H0
U:;709NTaP2FY<L0UJ?609>Sa`2AXLD0SIo508ZMa@29W<@@08^La`0@08VM
`P2;W/H0RYg808^Lb02<VlH0SI_209FTa@2R/Lh0^l?J0=GLkP3GfnH0VibQ
0>o_k`3mno`0ooko0?omob<0oooo0P3no_h03`3moOd0n?Sh0?;blP3[i^X0
hN?N0=_Pg03If]h0fmWL0=cKeP2>TIH0MGfB07^9Y02:V;D0V:O80:2^d@02
0:2^d`0I09n_d@2P/=40X;3B09n_d@2P[]40Wjg@09b[c02GY/L0TYo108jK
_@28VK<0R9Nf08ZD]`2<UK80FFAj071kS`1nRZ@0RYNi09RVb@2P[]40Wjg@
0:2^d@2Q[m80Wjg@0:6_dP090:2^d@@0XJoB00L0Wjg@09f[cP2JZ</0VJO:
09NTaP2FXlD0UJ;40080U:7300<0UJ;409JSa@2GY<H00P2KZL`00`2MZlh0
WZc?09n]d0060:2^d@L0XJoB1P2R/=<01P2O[<`0WJ[:09VWa02EXl00Tijl
096L^P80T9^g00d0S9Zg096L^02=Uk00JG68075iSP1lQ9T0SiZ`0:F_b02`
^mL0/[gI0;>nfP2b_MT0/kkJ0080]L3L00<0/kkJ0;Bof`2d_m/00`2d_m/;
0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00
803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3J
f]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@80b<:Z00P0aKnW0<:j
X`34_:D0a[jW0<BlY@32^Z<0aKfX0<[2Z`80al2V04@0a[nU0<FmYP36_ZT0
a[j[0<>mX`38`ZX0`K^S0<:lY032^Z<0aknX0<W1ZP34_:D0aKjR0<O0YP35
_JH0a;bW0<S2ZP31^j40a/6T0<G0XP34_J40_[NK0<FnY037_jP0aKfV0<Jn
Y`33_:80bL:V0<JkY@35_JH0b<6W0<[3Z@36_jD0aKjT0<BlY@3;`:X0b[j^
0<S0Z@35`:80aL2S0<2jY036_Z/0bKjX0<^oY@37_jP0`k^T0<_4ZP34_J<0
`k^T0<JnY`2l]9l0`KVT0<[2[`37_jX0aknX0<FnY039`ZH0b<6W0<BlY@36
_ZT0aknZ0<K0Z035_jD0b<:X0<W3Z@3;aJd0blF_0<[5/@80bl>^203<a:l6
0<g5/00@0<k6/@3;aJ/0c<J`0=G;_`3Gb[T0e]2f08nBR@1:EFL0EffL069h
Z@1XOK80JWnf06Z1]`1YP;H0J7nc06Z1/b00JX6g0`1[P;L506b1^0<0KH:i
0P1/PKP306^0]a00JX6g0P1[P;L606b1^01K06V3]01[P[@0K8>g06b3^@1[
P[P0K86f06^1/`1[PK80Jh:d069jZP1^Q;D0JGn^06n5]01bR;T0I7Z[06j4
]P1YP;H0K8>e06Z2/01/P[<0KhBk06Ym]`1aQKP0Jh2[06^4[01[P[H0Jh6b
06^3Y@1bRZ`0KhFd06V1/@1aRk00Kh2^07F:]`1_R[L0KHFc07F7]`1`P;40
LXNd072<]01lSlT0KXB]0766]@1fR[d0LXNb07R<_P1hRlD0MX^f07F8`P1e
QkL0NXfg07^>^@1kSKl0Nho207J<_@1eS;P0Mi;107B9]P20S[/0MXNe082D
a`1eR[l0OY3007b9]P1lSkL0NXnl07V=_`1kSl40OY>n07fC_01nT;h0NX^o
07ZB_P1nS;/0P8jk07^D_01kU;d0OH^l07Z:_@1mV<L0Q9G008FEb021TlD0
O92e07Z=]@21TlD0PY;507f>^@1lT[/0OY6l082C_@0208BF_P0[07b?^@1o
T[d0QI_408JD`@20UkL0OIJn08:GaP26U[X0R9Fo07j<^`26WKd0RIo807bB
^`2;W/P0Q9O108RNa`1oT[d0Qi[508:E_`29U/<0RI_308BL`022V;d0Q9:o
08VEa@28VL@0R:3408^M``27VL40TZ7<08RF``29Ul@0QiS408VLaP23U[h0
PiJd08RL_`21VKd0Pi^m08FO^P23VkL0Rijo08ZG``0208jMaP0608ZKaP29
V/H0SYo:08NI`@2;Wl@0Rio2602;W<L04028VlD0RIc408bNa02BX/H0V:K9
09j[c@2T/M40ZKCB0:ffe@2[]]@0ZKCD0:>`dP2N[<l0V:S<09>Sa`2>X<H2
08bMb0@0Ric70P2:VlH808^La`0>08RN``2;W/H0RYg808^LbP2>WLP0Tj76
0:6^cP2b`=X0b]7T0=kTm02n`LX0/[6f0?ono`3noO/20?onob<0oooo0P3n
o_h03`3moOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cKeP2>TIH0
MGfB07^9Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40X;3B09n_d@2P
[]40Wjg@09b[c02GY/L0TYo108jK_@28VK<0R9Nf08ZD]`2<UK80FFAj071k
S`1nRZ@0RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP0<0:2^d@08
09n]d02MZlh0VJO:09JTa`2CXL@0TYno096N_P2?W;`208jK^`0908nL_02A
W[h0TYno09FSaP2FY<L0VJO:09^Yc02N[<l0Wjg@00@0X:kA1`2Q[m80602R
/=<0Xk7D0:>ae02R/=<0XJoB0:2^d@2O[M00W:W909VWa02FY<40U9nm096L
^P2@VkL0SiZf096J]`2=VkP0SiZf07EoV01ZLXT0MWjC08B<X@2JYK/0Z[C=
0;6lf0@0/kkJ0P2e`=`50;Bof``0]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:C
U`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[
jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<Bl
Y@P0b<2Y0100al6Y0<BnYP37`JT0b<2Y0<S1Y`36_jD0b/2W0<c2Z@35_JP0
b<2Y0<>lXP37`:@0`[^O0<BmX`38`:T0aKfX0P36`:P0?P36`:H0b<6U0<6j
W@3:`jL0a;bU0<_0[P3:`:D0b<6U0<BmX`39`JX0al2V0<K1Y033_Z00aL2P
0<RoXP3<`ZL0aK^R0<ZoZ`38_JT0akbX0=76/036^jD0bknW0<RnY@35_Z@0
bL:V0<O0Y03:`jT0b/2W0<^oY`38_:`0a[jW0<[5Y`36`J<0b<:Z0<JnZ@3>
a:/0clBX0<O1Z@3?bK40al6W0<[3Y`3;a:P0akfR0=36[@39_JD0c<2`0<Rm
Z`3?a;00cL:/0<VnZ03:_jT0c/>_0<k3/@38`JD0bL:V0<g8Z`38`jH0blJY
0<[4[036`Jd0b/Fb1`3<a:l80<g5/00=0<k6/@3<aZh0blNZ0<k8/P3BaK`0
eLRg0=7:[@37c;P0ADmH055WUP1LLZ<0IGZ_06Un]@0206^2^00306Z1]@1[
P[@0JX6g01l0JX6g0P1[P;L03P1/PKP0KX>j06n4^`1`QK`0LHJm07:7_P1d
RL00LhRo07:7_P1`QK`0KX>j06b1^01[P;L0JWnf401ZPKL706b1^00406f2
^@1YPk@0JH>d06b3]`80K8>i08/0KH:g06f3]@1]PkD0Jh:d06n4^@1^PkP0
JWnd06n4^@1]PK@0L8Bf06n3]@1bQ[T0K82c07N;_@1`Q;H0Kh>f0724^@1b
QKd0LhJn0768^P1_P/@0MHW606n4[`1cRK00L8Fj07J;`P1^Q[80NXNl07:6
^01_QkD0LhVh07Z:_@1fQ[T0Nho106n:^@1aR[<0MXjd07F9_P1dRL00Mi6d
07B>/`1gSKl0MHZg07Z=b01fR[`0NHji07Z?_P1jS/<0NY3207V?`01iTKl0
M93207bB``1iRK`0PY?707B9_P1oU/X0O8k0086>^`1jTK/0NHo007jDaP1n
U<D0OiBo07Z@^@1oTL40PI;807bE_@24T[l0QIK207RE]`1iUKX0QYS608BF
b01iU/80Pi:m08REb@1nT<00PINl08:H_@21ULL0OiC308FI_022UL00QYK7
08NEa023T[/0RIS108NEa026U/L0PiK108VEb@26V[d0OYFn08RJb028U[/0
Ri?108bHc027V/80QiVm08VK_`27Uk/0RYc408:E`02;WL/0QYS608NHaP2?
V]00QYW108NP_P26W<40RY[=08fId`2;WL/0Pifn08RJ`02?W/L0SY_508nL
aP2;V/<0RIc408NO``27Y<H0RiW608jPd025VL/0QIc808BL`P2:WLD0QiG6
096Kf02:VL@0T9k;08ZKa`2;W<P0Sj3;08JH`02=XL@0RIfn01P0Ric70100
SIk908nPb`2EY</0WJ_>0:NdeP2b_M/0^lOQ0<3:i@31b>D0_lKS0;W2h@2c
_]h0Z[OI0:6_dP2JZ/`0UZK:0P2<WLP408^La`80RY_6202;W<L04028Wl40
Rik608^Nb@2<WL/0TZ7<09ZXc@2]^mP0`]3Z0=WPlP3Ni?80Wj:Y0=WIf`3o
o_`0ooom0?omoP3oo_lS0?ooo`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>7S
gP3Kh=`0fM[N0=_Ig03LfmH0SY6F07EmTP1kRJ@0RYRe09RWb02P[]400P2P
[]<06@2O[m40X;3A0:2`dP2O[m40X:kA09n]d02LZl`0UjK709:O`@2>Vkd0
R9Vc08RG]P2:U;L0S9Fb05UTNP1`Nhl0OXZT08ZG^@2HY/T0X:kA09n]d02P
[]40XJoB09n]d02Q[m802@2P[]4309n]d00809j/c`2KZL`0UjG809:P``2@
W/40SY^k08fJ^P2;V;P208ZG]`0;08^H^02=V[X0SY^k092N`@2BX<<0UJ?6
09VWbP2LZ/d0WZc?09n]d02P[]401`2Q[m820::`d`<0Xk7D00P0X[3C0:2^
d@2N[<l0W:[=09VWa02GYL80Tj6n09:M^`80SiZf0P2@VKH02@2>W;T0RYFa
05aVO`1]MH`0NH6F08jFZ`2T[lD0[;K?0;6lf0030;>nfP030;Bof`2e`=`0
]L3L00D0];oK302e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0
o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN
0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU:038`:T40<No
Z0@0b<2Y2039`JX00`38`:T0bL6Z0<W1ZP090<W1ZP@0b/:[00<0bL6/0<[2
[@3:`Zd01P3:`Zd80<_3[PP0c<B_1`3=aK005P3=a[<0bL:_0<g6/`3?b;D0
c/Nd0=G>^`39`Zl0ZJ:?03m:M`1QL9T0Jh2[06Mm]P1WO/80K83506Ul]01c
Q;00KH>l06Z0^@1ZPKL0Jh:h06Mn]01WO[8206Z1]@P0JX6g0P1[P[P406Z1
]`80JH2f0240IWfa07:9^`1ZP[80Ign]06Mo[`1[QKH0IGjd06V2^P1VOkP0
KhFn07J<_P1iS[d0P96o08bHb02DW/l0Uio@092S``2;WL40RYW408NEaP1n
S/80MXNm06n4^@1[P[@0JH2f06b1]P1/P[@0JGna06b2]01^QK/0IGjg06^3
_`1ZOkH01`1[P;L00`1[P;D0K86f06b1]P0506b1]P@0KH:g201^PkP406n4
^@0406n5]`1`Q[P0L8Jh0726^0<0LHNi00<0LXRj07:6^@1cQkX00P1cQkX3
07B8^`0307F9_01dR;X0MHVk0080MHVk0`1fR[`00`1gRkd0MXZl07N;_@02
07N;_@<0N8bn00<0NHfo07R=_01iS[d00P1iS[d307Z?_P0307^@_`1lS[h0
OHno0080OHno0`1nT<000`1oTL40OY2n07nA_`0207nA_`<0P9;000<0PI?1
082B`021Tl400P21Tl4308:D`P0308>E``23U/40Q9O200H0Q9O21025V<<4
08JIa00308NHa028VLD0R9W500D0R9W51029V/D808ZKaR`0Ric70280S9_6
08bMb028Vl<0QI_208RNa@2:WLL0Ric808jLb`2;W/P0Vj[A0:6^cP2i`m`0
`LSK0=7Gi@3@e^80eMcV0=CFj`3<dN@0aLcN0;g6e`2c_MH0ZkSJ0:>`g02J
Y]P0UJKB08jObP2<WlL0S:3508RL_`2:W<80SYg608fJaP2=W/T0Ric70P2:
VlH04`2:WLL0S9o908bOb@2;W/P0SJ?:08NJa02=WlL0Tj;909j[c@2Z]<l0
_/KI0=SOk`3Vi^H0]KFe0;jn_P3oool0n_[j0?ooo`3no_h0903oool20?kn
oP0?0?gmo@3hn?P0l_;b0>_VjP3Qhmh0fn3L0=WJgP3KfM`0g=_F08jAUP1e
OI80NhVT08ZH]@2HYlP0X:kA0080X:kC01/0WjoA0:2`d@2P/=80WjoA0:2^
d@2O[M00W:_<09NVa`2BWl40SY^m08RI/`28UkH0RYBg08bE/P1II7X0L7^?
07j:Y02:UkT0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB0:2^d@2Q[m80
102P[]430:6_dP80X:kA01X0WJc=09ZYbP2FXlD0TYno08jK^`2=V[X0R9Nd
08nM^P27U;@0RiJf08ZE]@2;U;<0TY^j0868Y@1bNXd0Ifn205mWO01UKH@0
LgZD08B;Y`2IX;d0ZK3=09n/c`2S/=<0XZoB0:6^d@80XZoA00@0XJk@0:>`
dP2O[/l0X:o@0P2Q/<l05@2O[/d0W:_809^Za`2JZLH0V:K009:P^P2BWKT0
T9^g08jI]`2@VKP0Tibm096J^`2DWJh0M7b?06adR@1fOYD0PXbU09NP_@2W
/<l0/[_J0;>nfP070;Bofa00]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3n
o_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYBP0
b<2Y1037_jP40<S0Z@h0bL6Z0P3:`Z/40<W1ZP@0b/:[1P3:`Zd80<_3[PP0
c<B_203=aK020<k6/@0C0=39]P3;a;40c/Nd0<o8]@3<aK80dLZg0=;;^036
_j`0J6n1055LN01PLI`0I7^_06Ao]P1WP;H0JWnd06b0/`1YP;H0J7ne06V0
]P0206Z1]`80K8>g00<0IWfa06Z1]`1ZPKL01P1ZPKL206^2^0@0JX6g0P1Y
P;H01P1^QKT0IGb`06El/01_Q[X0Igjb06^2]P80KXFi01P0NXk0086C`@2=
WlL0UjO809FS_P28U:`0NhJL07MoU01/NHX0NHJI086=Y`29U;@0TIg508^I
aP1mSl40MXZm06f4^01aR;`0IGb^06Z0/@1WOJh0IGb^06n6^P1TOK<606^0
]`80K86h1P1/PKH606f2]`L0KX>h1@1_Q;T40726^080LHNi0P1bR;X407>7
^P80M8Rk0P1eRK`407F9^`80MXZl1P1gRkd207R<_P80NHfo101iS[d207Z?
_P80Ni2o101mSkl207j@`080Oi71101oTKl2082B`0H0PI?10P22U<8208>E
``H0Q9O21P25V<<408JIa0H0R9W50P29V/H408VJa@P0RY_6;02;W<L0<`2<
VlH0S9g808ZMa@27WL@0Rik608ZMa`2=W<L0TZ3=09j^dP2P[m00^LGO0<kD
jP3Fg>X0h^Ka0=?Gh02^/kT0XZBa09:FX@2<Ti/0V:6X0:>]^@2V/LD0Y:o;
0:2]c`2FYLh0VJ_C092Sb`27V/80Rik608jQb@2>WLH0SIc508VJa@2;W<L0
SIk908fPbP2;W/P0RIc608RKa@29W<H0QIVn08nQa`2FYL`0VZS;0:fheP37
d^P0g>?c0=cUkP3=cLd0Ti>C0?;blP030?ooo`030?clo03oool0oooo0280
oooo0P3no_h03`3moOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cK
eP2>TIH0MGfB07^9Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40X;3B
09n_d@2P[]40Wjg@09b[c02GY/L0TYo108jK_@28VK<0R9Nf08ZD]`2<UK80
FFAj071kS`1nRZ@0RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP07
0:2^d@80XJoB00P0Wjg@09j]cP2KZ//0UjK709BQ``2?W;`0SIZj08^H^080
RINd0200QI>`08jI]`2?V[P0NX>P06A^R@1MIh00Hfj006MbQP1/Mh/0K7N=
06I`R@1RK8L0J76>079kV02DXL<0WZ_=0:2]c`2O[<h0Xk3B0:Bad`2R[m80
Y[?F0:Bce02Q/=40WJc=09b[bP2KZ/T0VJS709BS`02@Wk`0TZ2k096L^080
TYfi00`0TIbh09BM^P2DWKX0T9Vf07AlS`1ZLXD0LWZ?07j9W`2>V;40XJ[7
0:bedP2b_M/60;Bofa80]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0
oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT
0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYBP0b<2Y
0`37_jP50<S0Z@d0bL6Z0`3:`Z/30<W1ZPD0b/:[1@3:`Zd80<_3[PP0c<B_
203=aK030<k6/@040<g6/`3;a;40cLJc0<o8]@80c<Fb00X0c/Nd0<o8]@2k
^Jd0DUEN04aIN@1_Q[80GgjZ06B4[@1^R;T0Igfg0`1ZPKL01@1XOkD0Igjb
06^2]P1/PkL0Igjb0100JX6g01`0H7Z]06j7_@1/P[`0J7jh06Yo^01^Q;H0
LXNd086F`@2KZ<X0UZ6o08NBYP1eOhT0KgUk07QnO01nPg`0OH=i0865QP1l
P840MWUn06U]N01OIWT0LW^J08BB^@22T;l0MXfo06El[P1^QKL0Jh:d0P1[
Pk<00`1UOJd0KHFe06^0]`0406^0]`<0K86h1@1/PKH606f2]`L0KX>h1P1_
Q;T30726^0<0LHNi0P1bR;X307>7^P<0M8Rk0P1eRK`307F9^`<0MXZl1@1g
Rkd307R<_P80NHfo0`1iS[d307Z?_P80Ni2o0`1mSkl307j@`080Oi710`1o
TKl3082B`0D0PI?10`22U<8208>E``D0Q9O21P25V<<508JIa0D0R9W50`29
V/H308VJa@P0RY_6;@2;W<L00`2<VlH0S9g808^NaP0208^NaP0a08ZLa02@
WlH0VZS?0:Bbc@2ja=d0e=_^0>3Tl03Ig>D0ZJZ_09fNXP38c<l0g=gQ0>?T
iP3Tj>L0c]C@0::[ZP27T9D0SYRR0:2Y^02M[<d0TZ;608jPb02@Xlh0SIo=
08RKaP2:W<@0SYg408fNbP2<WLT0S9g808fNb@2:WLL0R9_508VLa02<WlL0
T:3409^Yc02T/M40^<?O0<G@i03Bf^L0fn;Z0=7Ig02HV9P0e]KF0?ooo`3j
n_X0oooo0?gmo@0U0?ooo`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>7SgP3K
h=`0fM[N0=_Ig03LfmH0SY6F07EmTP1kRJ@0RYRe09RWb02P[]400P2P[]<0
6@2O[m40X;3A0:2`dP2O[m40X:kA09n]d02LZl`0UjK709:O`@2>Vkd0R9Vc
08RG]P2:U;L0S9Fb05UTNP1`Nhl0OXZT08ZG^@2HY/T0X:kA09n]d02P[]40
XJoB09n]d02Q[m802@2P[]401`2N[Lh0W:_<09RWb02CX/<0T9fm08fJ^P2:
UkL00P29U[H06`24TZl0S9Ze08FAZ`1ZMXh0GVUo065/PP1[MXX0KgZ@075l
TP1fPIL0OXRQ08>=Z022RjP0O8FR07IoW01EHh00OXbY09j/b@2R[ll0XJk@
0:6^d@2MZ/d0VZO:09j[c@2KZ<X0UjC609JSa@0209JS``0B09>P`02@WKd0
TIbj096L^P2@VkT0SYVe08nI]02@V[<0Qi6Z07Z4W@1WKh80KWJ;07Z5V@27
TZP0VJ>n0:Zcd02`^mL0/kkL1@2d_m/C0;G0g0080;g8gP3:d^D0dmWW0=KI
hP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0oOgm0?Win@3c
lo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^c
W034_:DX0<S0Z@80aknX1P38`:T<0<W1ZP@0b/:[0P39`JX60<[2Z`@0b/:]
203;`jh80<c4[`P0cLF`103>a[405P3<aK80blBa0<_4/@3=a[<0clRe0<_4
/@38`Jh0bL:_0<g2[02YYYl0Be9R04UNO@1XQ:/0IXFc06Ao]01YPKd0JH2d
06Z1]@1[P[H0JH2d06Qo/`1YP;@206^2^100JX6g0200KhRn06Am]@1VO;P0
L8C107B5_@20TKl0TJ7509NXa020QYH0N7b807QkP026R8<0Rhf008R9M`2=
S7L0UiJ109VES02OVi00Wi^?09nLT`2GUiD0MWZ305eUN01QJXL0MX^j07jD
a@1VOK40Lh[0065h[P1bRKd0J7j`06Z0/@@0Jh2g101/PKP406b1]PH0KH:g
1P1^PkP506n4^@<0L8Fj0P1`Q[P30767^@<0LXRj0P1cQkX307B8^`<0MHVl
0P1eRK/307J:_0D0Mh^m0`1hS;h307V=_`80NHjm0`1jSkh307^@_`80OHno
0`1nT<0307nA`@80Oi6o0`20T/05086C`@<0PYC20`23UL<408BG`PH0QIS3
1P26VL@408RIa@@0RI[60P29V/D808ZKaRh0Ric703P0RYc408bNaP2;W/H0
Rik608ZMa@2=WL40UZC70:Fbe032b]d0d]WY0=kRk@3Ce=T0U9BF0<[:bP3e
mO<0ooom0?ono`3moO/0n?Wd0?Skm03go?H0i>[V0;>i^@20QHP0RYJ^09FS
`02DY<P0SIk:08nQc`2>XL`0Rig308fP`@2=W/T0RI[508RJ`P2;WLD0SZ36
09:Qb02GYl/0W:c@0:Zed`2]^=@0^lGN0<[Bi@3AfNH0inkd0<kDe02:T8`0
clo?0?ooo`3hn?P0oooo0?[jnP3oool0o?cl0?gmoB<0oooo0P3no_h03`3m
oOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cKeP2>TIH0MGfB07^9
Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40X;3B09n_d@2P[]40Wjg@
09b[c02GY/L0TYo108jK_@28VK<0R9Nf08ZD]`2<UK80FFAj071kS`1nRZ@0
RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP040:2^d@0C0:6_dP2P
[]40X:kA0:2^d@2O[M00WZg>09ZYbP2EY<D0T9nn08fJ^P2;V;P0RINd08RF
/`2<UkL0RIBb08RD[P1aOID0FfQk06AaQ002075nS`0@07Z6WP1oRj<0QI6[
08VE[`2<Uk<0SYVe08^F/P27T[00PY2Z061^R01dPYd0VZS509JS``2EX/@0
XZoB09bYc080VJK801H0UjC609BQ`@2AW[h0Sibl092M_@2AWk`0SiZj092K
^@2?V[H0SiVd09>M]P2@Vk40NX:G05iVN@1aNHh0NhJL08NBZ02CWKH0YJo:
0;6me`2b_MT0/kkJ102d_m/D0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0
o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[
0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D^
0<S0Z@h0bL6Z2P3:`Z/20<_3[0@0b/:]203;`jh80<c4[`P0cLF`103>a[40
1P3>ak@0clRe0<c5/P3:`k00c/Nd0<o8]@80cLJc00P0c;b/0<:kZ`2TYZ40
A59O04mSR01/PKH0KH>l06n6_0<0JX2b00D0KH:g06j3^01/PKP0Jh2g06b1
^00@06Z1]`0P06=m/01ZPKL0L8Fn07B5^`25Tl80V:G708^F[01UKWd0Q8:3
08R7P`2<RH80RhUl09BAP02SWX/0ZjBB0:VRT02`YY`0[jFI0;6YUP2]Yi40
ZZND0;2`Y02IWYX0Jg1c05i/T`1aPZd0Mh^m0725_P1UNkL0JGni0766_`1U
NZl406^0]`@0K86h101/PKH406f2]`H0KX>h1@1_Q;T50725^P<0LHNi0`1b
R;X207>9^`<0M8Rk0`1eRK`207J:_@<0MXZl0`1gRkd507R<_P<0NHfo0P1j
S/0307Z?_P<0Ni2o0P1lTL0307j@`0<0Oi710P20T/83082B`0<0PI?11@22
U<8308>E``80Q9K41024Ul8408FH``H0QYW40P27V/D408RIa@@0RI[61P2:
VlH808^La`80S9g8:02;W<L03@2:W<80Rik608ZMa`2:WLD0Rig3092P`P2P
[//0]L3L0<gCg`3QiO00dM;G08n?T@3Ge]@00P3ooo/0903nooX0oogo0?on
o`3oo_l0n?Sf0?Wim`3moo`0l?;a0=OIf02NY[<0TYZ_092K^@2DX/L0Tj;;
09JXd02J[=00UZK709NVc@2FY/X0UjO;09ZXb`2M[<d0XJk>0:Nde02]^mP0
^l;L0=;HkP3BfN/0h^Sd0>gbmP2e^KX0SY>?0=_Mf03oool0no_k0?knoP80
oooo00<0oOgm0?ooo`3oool08`3oool20?knoP0?0?gmo@3hn?P0l_;b0>_V
jP3Qhmh0fn3L0=WJgP3KfM`0g=_F08jAUP1eOI80NhVT08ZH]@2HYlP0X:kA
0080X:kC01T0WjoA0:2`d@2P/=80WjoA0:2^d@2O[M00W:_<09NVa`2BWl40
SY^m08RI/`28UkH0RYBg08bE/P1II7X0L7^?07j:Y02:UkT0V:K90:2^d@2O
[M00X:kA0:6_dP2O[M00XJoB00<0X:kA0P2Q[m820:2^d@80Wjg@01@0WJc=
09VXb@2CX/40SIbk08^H^02:V;D0RINd08RF/`29U;@0RYFc06mkT`1MJWd0
JWN807>0T@1fPiH0NXNJ08NB[P2BWKT0VjK209bW``80VJC20P2JYL<02@2K
Yl40SYZd07=oV@1`NiL0SIRf09fXb02HXl<0Uj;209BO_`0209FP`00E09>N
_02@VkT0SYVg08nJ^02AW;P0SiZh08nJ]P2CWKP0T9Zc07R3V@1PJ7d0Hf]n
07R1TP1hPiT0R9:[09JP^@2S[lL0/[kH0;G1f`2b_MT0/KoJ00@0];oK502e
`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200
oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J
09FDS`2:R7/0VIB10:RRS02k/i`0a;bU;@38`:T>0<W1ZPX0b/:[0`3;`j`3
0<[2[@P0bl>^203<a:l80<g5/0D0c/Ja00<0c<Fb0=39]P3@bKH00P3<aK80
4`3>ak@0clRe0<k7]03<`;80bL6^0;ZgY02][j`0DUQ`05=NR`1bP[<0MHZg
07B:^`1`Q[L0Jh6b06Z0/P1]P[L0K86h06Yo]P1[P;L0401ZPKL0301ZPK<0
KXBe07R:^02<VL<0WZO608N>X01hNh80QHN608^7O02;Qg/0Ui630:RRTP80
/jbL0180^:jR0<6g[@2o]J/0a[f^0<JkZ@32^ZD0`[bT0;JaW@2][9X0]KJV
07MlS`1EG7H0IgFL06Um/01dR/@0Igfi06Mm]`1/PKP306^0]`D0K86h0`1/
PKH506f2]`D0KX>h0`1_Q;T60725^P80LHJk0P1aQkT307:8^P<0LhVk0P1d
R;/307F9_0<0MXZm0P1fR[`307N;_@D0N8bn0`1iSKl307Z>`080NXnn0`1k
T;l307bA`080OY300`1oTL43082B`P80P9;00`21Tl4508:D`P<0PiG30`24
U/@308BG`PD0QIS31@26VL@308NJa@<0R9W51@29V/H508ZKaPP0Ric70`2<
WLPX08^La`0A08ZL`P2;W/H0RIc608VLaP2>X<H0VJS90:jje033c^@0g>3Y
0=GHg`2DTiP0cL_<0?ono@3in?@0ookj0?gnn@3no?l00P3oo_l07P3mnoh0
n_[l0?gmo`3lo?h0m?Cf0>GVj`2^/[d0S9>U096M]@2LZ/L0XK3?0:Fdd`2V
]M@0ZKKF0:bje`2__MX0/KcH0;>mf02i`m`0a/kU0<kFj`3Ig>d0eMSW0>GX
l@39c=40W9fO0<32`@3Xj>H0ooom0?Ogm`80oooo00<0mOGe0?ooo`3inOT0
9@3oool20?knoP0?0?gmo@3hn?P0l_;b0>_VjP3Qhmh0fn3L0=WJgP3KfM`0
g=_F08jAUP1eOI80NhVT08ZH]@2HYlP0X:kA0080X:kC01T0WjoA0:2`d@2P
/=80WjoA0:2^d@2O[M00W:_<09NVa`2BWl40SY^m08RI/`28UkH0RYBg08bE
/P1II7X0L7^?07j:Y02:UkT0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB
00<0X:kA0P2Q[m820:2^d@0F09n]d02N[<l0W:_:09NVa@2AX;l0S9^j08^I
]P2:V;D0RINd08RF/`2=U[D0NX>P061[P@1PKH00KW^<07:1U023TZT0UjG0
0:2]c@2R[ll0Xk3@0:>acP80Y;;?00/0X:k;09^YaP2JYL40WZW509RS_`1e
P9`0G6N307N2WP2FXKd0T9^g096L^003092K]`0D096M]`2@W;H0SYZd08bH
/P2@V[<0SiVb07n9XP1YM8X0Ifn4075iS01jPYD0O8BG08NAZP2GXKX0Xjo9
0:jje02d`=X0/KgG0;6ofP2d`]d30;BofaD0]L3L00P0_LSN0<[Bi@3CfNL0
e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi
0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0
^k>L0<BlYB`0b<2Y3P39`JX:0<[2Z`@0bl>/0P3:`Zd80<_3[PP0c<B_203=
aK060<k6/@040<[3/03=a[<0d<Vf0<o8]@80c<Fb00l0cLJc0<_4/@3:aK40
bL>[0<NoZ02k]:80[ZZW05iPK`1HHh40L7nV0767]P1fS;/0LhVj06b2]01[
P;D00P1[P;L00`1ZOkP0JX6g06Z1]`0606Z1]`80JH2f101ZPKL206^2^00P
06j2]01iS;L0SYk208nK/`26S9P0NW]m08J3O02?Rgl0V9:60:FOT@2b[IX0
^K:O0<6jY`3;a;80dLRg0=37^03Dck`0c<Nd0<c5/`3=aK80b<2]0<O0[@35
`:`0^[RS0;^h[`2;S8h0B51S05a^TP1YOk00KHBj06Ak/@1[PK<206^0]`H0
K86h0P1/PKH606f2]`@0KX>h101_Q;T50725^P<0LHJk0P1aQkT207:8^P@0
LhVk0P1dR;/207F9_0@0MXZm0P1fR[`207N;_@H0N8bn0P1iSKl407Z>`080
NXnn0P1kT;l407bA`080OY300P1oTL44082B`P80P9;00P21Tl4608:D`P80
PiG31024U/@208BG`PH0QIS31026VL@408NJa@80R9W51P29V/H408ZKaPP0
Ric7102<WLPX08^La`0=08VM`P2;W/H0RYg708ZMa`2DY<P0Y;7A0;[6g03?
enX0h>C]0:6TZ@3?c]<0oO_l0?Kel`020?ooo@050?_kn`3oood0o_cm0?kl
o@3oool00P3no_l20?ooo`0>0?ono`3fm_P0^kk508jFX@2LZ;P0ZKG;0:Fc
cP2c`Mh0]l?K0;c7g@30bn40a<cO0<W@hP3AenL20=OJj@0:0>;RkP38b=00
YjR/0:ZZZP3?cld0ooko0?gkoP3oo_l0oooo0?gmo@@0oooo00<0no_k0?cl
o03oool08P3oool20?knoP0?0?gmo@3hn?P0l_;b0>_VjP3Qhmh0fn3L0=WJ
gP3KfM`0g=_F08jAUP1eOI80NhVT08ZH]@2HYlP0X:kA0080X:kC01T0WjoA
0:2`d@2P/=80WjoA0:2^d@2O[M00W:_<09NVa`2BWl40SY^m08RI/`28UkH0
RYBg08bE/P1II7X0L7^?07j:Y02:UkT0V:K90:2^d@2O[M00X:kA0:6_dP2O
[M00XJoB00<0X:kA0P2Q[m802@2P[]40Wjg@09j/c`2MZlh0VZW809FT``2?
W[d0RYVf08ZH]@0208VG]00<08RF/@2:Tk80IW2;06=^Q01bOi00MhBG08>B
Z@2GYL80WZ_>0:Fbe02W]=H0Z;GG0`2X]MD20:VfeP0:0:bge@2KY/@0VjK2
09^W`@1lR:00H6b206eiS`28UJP0TI^f096K]080TYbe00l0T9Zc08fH[P29
U:X0QI2V07=nTP1UL8@0H6]o06ifR`1hP9D0MWjC07f5VP2@UZ`0VjG00:Nc
c@2]^M<00P2b_]P00`2^_=H0/l7L0;?1g0020;BofaH0]L3L00P0_LSN0<[B
i@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3m
oOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VD
P@2XXX`0^k>L0<BlYB`0b<2Y3039`JX70<[2Z`030<_3[03:`Z/0b/:[0080
b/:[103;`j`70<_3[PP0c<B_203=aK080<k6/@0I0<o7/P3?b;D0b/>`0<c5
/P3>ak@0c<Fb0<k7]03Ab[L0clRe0<W<[@3=bJh0b;fW0<ZlXP2m/iX0[J^O
07EmRP10CG00GWBS07B:^@1mTl@0MH^m06n4^@1^PkX0KH:i06^0^@0806Z1
]`80JH2f101ZPKL206^2^00P07V>_@2AXl/0RINd06efQ@1mPH80Rh^109J@
PP2JTh40[JNK0;RbY036`Jh0c/Vc0=7;/`3Bc;@0dlfe0=C>^03?ckD0d]2i
0=?>^`3Dbk`0eLbm0=?:^`3<aK80b/>`0<W2Y@30_jd0SIFH03];I01PMYl0
JH6a06b4]01XP:h706b1^00306f2^@1]P[L0KH:g00D0KH:g1@1^PkP406n4
^@@0L8Fj101aQ[/0101aQkT0LXRj07:8^P1bR;X307>9^`0307B:_01dR;/0
MHVl0080MHVl0`1fR[d00`1gRkh0MXZl07N;_@0207N;_@<0N8bn00<0NHfo
07R<_P1iSKl00P1iSKl307Z>`00307^?`@1jSkh0Ni2o0080Ni2o0`1lTL00
0`1mT/40OY3007nA`@0207nA`@<0P9;200<0PI?3082B`021Tl400P21Tl43
08:D`P0308>E``22U<80PiG30080PiG30`24U/@00`25UlD0QIS308FH``05
08FH``D0QYW41027V/D708VJaP0308ZKa`2:VlH0RY_60080RY_6202;W<L4
08bMb2P0Ric700/0RIg008bOa`2;W/P0Rik809RXc02[^MH0`/gQ0=GNk@32
a/l0]KRo0?[ioP030?ono`0X0?ShnP3nool0oooj0?kon@3oood0oooo0?kn
oP3moOd0o_kn0?clo03on_P0ookk0?[jnP31a/T0RI>L09>O[`2e`MT0^/GS
0<G=hP38d><0c=?U0=7Gi`3Ff^H0e=KR0<C7d02d];h0UiJN0:n^/`3Kfm/0
ooom0?ono03oo_l0oO_o0?omo`3oool0o_kn0?_kn`3oool0oOgm0?[jnRD0
oooo0P3no_h03`3moOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cK
eP2>TIH0MGfB07^9Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40X;3B
09n_d@2P[]40Wjg@09b[c02GY/L0TYo108jK_@28VK<0R9Nf08ZD]`2<UK80
FFAj071kS`1nRZ@0RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP03
0:2^d@80XJoB00P0X:kA09n]d02N[<l0WJ_>09VXa`2DXl80SYfl08VH]@80
RINd0380R9Ja08NE/01dNiP0GfV206ehS01ePY<0P8fP09RV`@2Q[]40Xk7H
0:Bce02V]MH0Z;OH0:Vhf@2X]mH0Y[GD0:Nfe@2X]mH0Z[GE0:Rcd`2R[L/0
W:S209JR^P28UJP0L7f>05i[N`1MJ7h0HVf306MbR01XLhT0I6n3061[O`1N
JGd0GFQl06McP`1cOhl0MX6C07MoTP1nQY/0S9BY09VO]`2RZ<00Y[;<0;2l
eP2b_]P0]L7K0;?1f`2d`]`0]/CN0:jlePL0]L3L00<0]/7M0;G0g02e`=`0
3P2e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool0
0200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0
f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU8038`:T40<NoZ0@0b<2Y00<0
aknX0<S0Z@38`:T01@38`:T80<[2Z`@0bL6Z103:`Z/40<[2[@@0bl>^00<0
b/:]0<_3[P3;`jh01P3;`jh80<c4[`P0cLF`1`3>a[400`3=a[<0c/Nd0<k7
]0050<k7]00B0<c6/03>b;80c<Fb0<O0[@32^jP0_;FR0;:[V@2WX8h0GfMd
05mWOP1aNil0QI7308:Cb`1eS<80KXZl06Z9]`1^QKT0Jh:f0P1YO[<0101/
P;D0KX6i06n0^01]O[H206N1/P0A06V3]P1]Q;P0Jh:f06b4]01dR[T0OIC0
09jX`@24Rid0Mgb208:3OP2;RGd0TXn00:6NS`2`[Ih0a;f[0<[3/@3@bKL0
0P3Cc;X00`3BbkT0dlbj0=G>_0020=C=^`@0dlbj0P3BbkT0403=`KD0cLJc
0<O9/`22RhH0BUI^06j0/01VOK<0Ih2f06V0]P1XOkD0JX6g06b3^@1ZPKD0
Jh:f06f4^01[P[H406f2]`D0KX>h1`1_Q;T0101_QKL0L8Jh0726^01`Q[P3
0767^@0307:8^P1bQ[T0LhNj0080LhNj0`1dR;/00`1eRK`0M8Rj07F9^`02
07F9^`<0MXZl00<0Mh^m07J:_01gRkd00P1gRkd307R<_P0407V=_`1iS[d0
NHjm07V>_@80NXnn0`1kT;l307f?_`80OY300`1oTL402`1mSkd0Oi71082B
a021TlD0Oi7107j@_P1nTK/0Oi:j08>A`P26U<D0Q9C50080PI?100@0PYO4
086Ha01oU/80Q9C50P23Tl@01`25U/@0QYO508NHa025U/80Q9G008BIa025
V/D00P22Ul801026VlH0R9_608FH``26VL@208NHa0H0R9W51029V/D408ZK
aSP0Ric700l0S9g808ZKaP2<W/H0TJ370::_c`2f`ML0d=SU0=SLi@2FUYH0
j^[Z0?ooo`3no_h0oooo0?gmo@3no_h02P3oool04@3lo?`0oooo0?ooo`3^
k^h0a<C409jNWP2=SHd0VYZJ09fMW@2PX:00W9bL09BDU02GUiL0[Jf]0<K6
aP3emOD0n_[j00<0oooo00<0oOgm0?knoP3oool0:`3oool20?knoP0?0?gm
o@3hn?P0l_;b0>_VjP3Qhmh0fn3L0=WJgP3KfM`0g=_F08jAUP1eOI80NhVT
08ZH]@2HYlP0X:kA0080X:kC01T0WjoA0:2`d@2O[m40WjoA0:6_dP2P[]40
WJc=09RWb02BWl40SY^m08RI/`28UkH0RI>f08bE/P1II7X0L7^?07j:Y02:
UkT0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB00D0X:kA01D0XJoB0:2^
d@2N[<l0WJ_>09VVaP2DXL40SIZj08VG]02:V;D0Q9:_08bJ]`25Tjh0Ef9f
06QcR@1_NiD0OHRT092N^`2MZ/X0Xk;?0:Bcd02W]=@00`2X]MD30:VfeP0I
0:Zge`2[]]H0ZkKF0:VddP2U/<h0WZW709BO_@2;U[80QI2/07Z5U`1eP980
KgZ<06agR@1^NH/0LWf?07F0TP1fPI<0M7nA07V4UP21S:00RYF[09>M]P2M
Yl80Yk7<0:ffd`030;>nfP80];oK6`2e`=`0202mb=h0b];U0=?Ii`3FfN80
TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c
0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0
a;bU8038`:T40<NoZ0X0b<2Y0P39`JX80<[2Z`@0bL6Z103:`Z/40<[2[@X0
bl>^203<a:l80<g5/0P0c/Ja0P3?ak860<k7]080clRe02`0c/Rb0=3:]03?
b;D0blBa0<O0[@34_JX0^kBR0;:[V@2Z[j/0OH:605eTM01QJhH0MXBW08RJ
`P29WlP0OiJo07N?_`1fS[h0M8^m0768^P1^QKT0K8>i06b1^01[P;L0JH2d
06b3]`1^PkP0KX:g0763]@1kSK/0SIk909Z/dP28Sil0O8>=07n0PP29RH40
UY>40:FOS`2g/J40aKna0<c5/`3?b;H0dlbj0=C=^`<0d/^i0`3DcK/50=?<
^P0A0=;;^@3@akH0eLjk0<K3/034al00J6mo04]IO01UNJ/0J86i06b3^@1Z
PKL0Jh:h06b3]`1ZPKD0Jh:f06j5^@1/PkL0101]P[L406j3^0H0KhBi0P1`
QKX40726^080LHNi0P1bR;X407>7^P80M8Rk0P1eRK`407F9^`80MXZl1P1g
Rkd207R<_P80NHfo0P1iS[d307Z?_P<0Ni2o0P1mSkl307j@`0<0Oi7100P0
OiC107jC`01nTl80P9;4086Ca@22U<@0PYG008:E_`<0OiC100H0P9G008:H
`@26W<D0R9k508ZPa`2>X<P308nQb@0<08jPb02=WlL0S9k608^Ma@26Ul80
QIK108BG`@27V/@0RIc708BG`P23U/40RIc70`28VLD208VJaP<0R9W51029
V/D408ZKaSP0Ric700/0RY_608^La`2;WLD0TJ370:Bad@2jaM/0cmOT0<75
cP2b/[80m?Cd0?ooo`020?knoP80oOgm00<0o_kn0?ooo`3oool01`3oool2
0?gmo@80oooo00T0o_kn0?Win@3inOT0inOW0>3Ph03MgMd0iNGU0?7al@3j
n_X00P3oool01`3jn_X0oOgm0?ooo`3oool0o_kn0?gmo@3no_h0;03oool2
0?knoP0?0?gmo@3hn?P0l_;b0>_VjP3Qhmh0fn3L0=WJgP3KfM`0g=_F08jA
UP1eOI80NhVT08ZH]@2HYlP0X:kA0080X:kC01T0WjoA0:2`d@2O[m40WjoA
0:6_dP2P[]40WJc=09NVa`2BWl40SIZl08RI/`28UkH0RI>f08bE/P1II7X0
L7^?07f9X`2:UkT0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00XJoB00D0X:kA
0180XJoB0:2^d@2N[<l0WJ_>09VXb@2BXL80S9Vi08ZG]`2;VKH0QiFb08ZH
]@1gQJ00GFQl06iiS`1fPY`0QY6_09VVaP2R[ll20:JedP@0Z;GE0P2Y]]H2
0:Zge`0H0:^feP2/]mL0ZkKD0:Rcd@2S[/`0VjK409BO^`2@VkL0S9N[08RC
Y`22SJ40OhZN07j9W@20Ril0PXfQ08>>XP29U:P0SiZ^09NR^02OZL80YJo:
0:Zcd02_^=D0/kcK0`2c_]X20;Bofa/0]L3L00P0_LSN0<[Bi@3CfNL0e]WR
09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L
0<BlYB00b<2Y0`37_jP:0<S0Z@<0bL6Z203:`Z/30<W1ZPD0b/:[0`3:`Zd:
0<_3[PP0c<B_203=aK080<k6/@<0clNb1@3>ak@30<o8]@0@0<o9/`3AbkD0
d<Vf0<k7]03=a[<0blBa0<Jo[@2o^:H0/k6L0:b[V@2PXYL0Q8R7069YL@1K
I7D0LWbE08ZE/@80Rio401P0RIc408>H``1lTkl0N92n07R@`01iT<80Oi73
07j@`P21TL80RiW609ZVcP2R[<l0VJ:o08bC[@1kOh80PH>008b<Q02JUhP0
ZZ>A0;^dXP3:`k40d<Vi0=;;^@3Cc;X20=C=^`030=?<^P3BbkT0dlbj00<0
e<fk1P3Cc;X03`3Ed;X0d/^i0=[Ba@3Ec/@0/[:`04QAH01QLiT0HgVb06b1
]P1[P;D0K86f06f2]`1/PKH0KH:g06n4^@0406f2]`D0KX>h101_Q;T40725
^P<0L8Jh0`1aQkT207:8^P<0LhNj0`1dR;/207F9_0<0MHVk0`1fR[`507N;
_@<0N8bn0P1iSKl0101iS[d0NXnn07Z?_P1jSkh407^@_`0407f?_`1nT<00
OY3007j@`0@0Oi710240OYFo07fD`01lTL00OI7307nCa@20UL@0PYC2086D
_`1mU[l0P9O108FLa@2<X/T0TZC809NWb@2L[<d0XK3?0:FfdP2V]m<0YkSD
0:Jge@2T]=D0X;3A09f]c`2KZld0UJ?:09NTcP2BWlT0R9O208FF`@26VL@0
Qi[508JHaP28VLD01@29V/H208RIa@<0RI[51@2:VlHh08^La`0908RIa02=
W/T0RYc409BSbP2W]=@0_/WO0<gEhP2SYk00e]KF0080oooo0`3no_h00`3o
ool0oOgm0?ooo`070?ooo`050?gmo@3no_h0oOgm0?gmo@3no_h00P3oool4
0?knoP<0oooo00<0o_kn0?gmo@3oool00`3oool20?knoRd0oooo0P3no_h0
3`3moOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cKeP2>TIH0MGfB
07^9Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40WjoA09n_d@2P[]40
Wjg@09f/c@2GY/L0TYo108fJ_028VK<0R9Nf08VC]P2<UK80FFAj071kS`1m
RJ<0RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP050:2^d@0D0:6_
dP2P[]40WZc?09f[cP2HY/T0Sijo08^H^P2:UkL0RIJf08NE/P29U;80IW6=
06A_P`1dOiD0Oh^U09:M^`2R[ll0Y[?C0:Nfe@2W]]<30:Ree@<0ZKKF0P2Z
]mL02`2/]mL0[KSH0:fheP2/]mD0Z[GC0:Jac`2Q[<P0Wj[609^U_P2IXk`0
UInh0080Tiff00/0UInh09NQ^P2HX[/0WjW20:>]aP2Z]<l0[[SC0;6je`2b
^mX0];gL0;Fng@020;>nfP<0];oK6`2e`=`0202mb=h0b];U0=?Ii`3FfN80
TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c
0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0
a;bU8038`:T20<NoZ0X0b<2Y1039`JX80<[2Z`80bL6Z1P3:`Z/20<[2[@X0
bl>^203<a:l80<g5/0P0c/Ja103?ak840<k7]0@0clRe00<0cLNa0<o9/`3?
b;D00`3>ak@08`3<aK<0al2^0<>kY02i/IX0/ZbF0:^XU@2PWY40SXn:07Uj
O`1SIG40GFEh06QcQ`1kQY`0RINa09:Q_P2FY/L0UZW:09NYc@2JZ</0X:g@
0:6/c02GW[/0R8fS07j1T01kOXD0OGj208F5N`2@SX40WY^:0:jWU02n]Z<0
cLFb0=;9^03?b;H0e<fk00@0dlbj1@3DcK/60=?<^P0=0=3?/`3Gd<00fLc3
0=K8_@3GdL40T9FA04IDKP1VMj/0IG^]06Mm[`1[PK<0K86f06f2]`0206j3
^00306b1]P1]P[L0KH:g00H0KX>h0`1_Q;T50725^P80L8Jh0`1aQkT307:8
^P80LhNj0`1dR;/307F9_080MHVk0`1fR[`507N;_@<0N8bn0`1iSKl307Z?
_P<0Ni2o0P1lTL0307j@`0<0Oi710P20T/807P1lUKd0OIBn07bC_`1nTl80
OiC308:Da022U<80PYG008VOaP2>X/L0UZS<0:6`d@2/^]L0^<;M0;o6h032
b>00_/_L0;c9fP2jamX0^<CJ0;G1f@2b_]P0[k[F0:fheP2V/=@0XJ_?09^W
c@2HY/d0U:?<08bMb080Qi[50P28VL@508VJa@0308RIa029V/D0RI[500H0
RY_6>02;W<L03@29V/D0SYo:08RJ`P2GY/d0Z[OG0;k9g`3;dn00Si>L0>g]
k@3oool0oOgm0?ooo`3no_h02`3oool00`3moOd0oooo0?ooo`020?gmo@80
o_kn0P3lo?`30?ooo`040?knoP3oool0o_kn0?clo3<0oooo0P3no_h03`3m
oOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0fmWL0=cKeP2>TIH0MGfB07^9
Y02:V;D0V:O80:2^d@020:2^d`0I09n_d@2P/=40X;3B0:2`dP2P[]40Wjg@
09b[c02GY/L0TYo108jK_@29V[@0R9Nf08VC]P2;U;40F6=i06mjSP1mRJ<0
RYNi09RVb@2P[]40Wjg@0:2^d@2Q[m80Wjg@0:6_dP050:2^d@080:6_dP2P
[]40WZc?09f[cP2IYlX0T9k108bI^`2;V;P208ZE/`0608VD/01LIH80JWF9
07R2V`25TJ/0VJC20P2V/m<0102V]M@0YkKE0:Ree@2X]MD30:VfeP<0Z[OG
0P2]^=P01P2^^ML0[k[H0:jie`2]^=H0[;OC0:^fdP<0YJk;00T0Y:g:0:F^
b`2V[l`0ZK;?0:^dd@2/^=80[[WE0;2ke`2a_=P00P2a_=X00`2b_Md0/kkN
0;Bof`030;Bofa`0]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo
0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kN
gP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYBH0b<2Y0P39
`JX40<S0Z@@0bL6Z3P3:`Z/20<_3[0H0bl>^0P3<a:l40<_3[PP0c<B_203=
aK080<k6/@@0clNb103>ak@40<o8]@040<k8/P3?bK<0clRe0<k7]080clRe
0280c/Ne0<c5/`3=_k80bKb/0<>hY02j/Y/0/:ZD0:ZTU02SWiH0W9NC09:A
S`29QhP0NGUk06]/L@1RIFh0GVA`069XMP1UK7`0GfMd069XMP1YKGP0LgIm
07inP024Pgh0RXQk092=O02FTh00Xij;0;:[V031^J@0c/>_0=?;^03Dc;T0
dLZh103Cc;X40=C=^`80dlbj1P3DcK/02P3?c[80em300=G6_`3Nc[l0gM>j
0<_<^P1@F6D0G6RB069hZ@1WOJh206^1/`0406f2]`1^PkP0KX>h06f2^@H0
KX>h0P1_Q;T50725^P<0LHJk0`1aQkT307:8^P80LhVk0`1dR;/307F9_080
MXZm0`1fR[`307N;_@D0N8bn0`1iSKl207Z>`080NXnn0`1kT;l307bA`080
OY300`1oTL43082B`P0P07fF_P1oU/00OiK207nD`@21Tl40Q9G108ZLa02@
WlH0WjW<0:Zee@2g`=l0_lKR0<O=i@3>dnL0d]GX0=3Ah`3Bg>H0c]ST0<[D
h037d>40aLgP0<79gP2j`]T0]KgD0;2ke`2`^mT0ZKKF09n^c`2IYl`0UZG<
09:ScP2=W/T508RIa0<0RI[51P2:VlHk08^La`0<08fNb@28V/80VZW@0:Zg
e`2ka]`0b=3M08V=UP3fm_H0oooo0?_kn`3oool0o_kn3@3oool20?knoP<0
oOgm103oool01P3lo?`0o_kn0?ooo`3oool0o?cl0?ooo`80o_kn103oool0
0`3no_h0oooo0?ooo`0Y0?ooo`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>7S
gP3Kh=`0fM[N0=_Ig03LfmH0SY6F07EmTP1kRJ@0RYRe09RWb02P[]400P2P
[]<06@2O[m40X;3A0:2`dP2P/=80X:kA09n]d02M[<d0V:O809>P`P2?W;h0
RY^e08VH]`2:U;L0S9Fb05QSN@1`Nhl0OHVS08ZG^@2HY/T0X:kA09n]d02P
[]40XJoB09n]d02Q[m801@2P[]404P2Q[m80X:kA09j/c`2MZlh0VJO:096P
`@2>Vk/0S9Zg08VD/02=Uk80SYRa05aSO@1_NY00O8JO08VD/02MZ<H0YkCF
0:Jce@80Y[GD0`2Y]]H30:Zge`80ZkSH00<0[KSH0:jif@2^^ML00P2_^]P0
1`2`^mT0/;_G0;2ke`2_^]P0/;_I0;6lfP2`^mT00P2_^]P00`2a_=X0/[gK
0;>nfP050;>ng0030;Bog@2e`=h0];oK0080];oK7@2e`=`0202mb=h0b];U
0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gm
o@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB1
0:RRS02k/i`0a;bU9@38`:T30<W1ZP<0b<2Y1@39`JX=0<[2Z`<0bl>/1@3;
`jh30<c4[`<0bl>^203<a:l80<g5/0P0c/Ja1@3?ak830<k7]0D0clRe00@0
clVc0=3:]03@bKH0clRe0P3@bKH08P3@bKL0clRf0=?4_@3?`kL0bkn_0<Bl
Y`30^:40^kFO0;F^W02]YiL0YYn?0::JS@2NUX/0VY>909FAR02ASXT0SXZ7
08^7Q029RX@0QXMo08N7O`2;R7l0SH]n092=NP2GUGh0Xin40:bWT`2h/Ih0
aKfZ0=35/`3DbKL0dLVf0=7:]`3Dck/60=?<^P80d/^i0P3Cc;X60=C=^`0@
0=GD^03?b;P0g]780=K9^03Of;`0dm:m09ZNX@12B680H7FT06Qm[01/P;80
Jgnb06f1]01_PkP0Kh:j0723^`D0KX>h0`1_Q;T40725^P@0LHJk0P1aQkT3
07:8^P<0LhVk0P1dR;/307F9_0<0MXZm0P1fR[`307N;_@D0N8bn0`1iSKl3
07Z>`0@0Ni2o0`1lTL000`1mT/40Oi7107nA`@0207nA`@<0P9;20240PI?3
07jE_`1oU;l0OiBo082C_P24U[h0SYk209b[c02W]=@0^koJ0<?7h03?e>X0
f^7d0=_RlP37cm`0WZRb07^5S`1?H6P0A5EM03M8D00eAU00@E5N05IVM@1[
NhX0MhNF09n``P2V]l/0[;cC0:Zje02R/M00WZc?09VWcP2CXLP00P2;W<L0
0`2:VlH0RI[508RIa00208VJa@H0RY_6>`2;W<L208bMb00<08RJ`P2JZM00
ZKKF0;[5f`36c]/0RhnH0?Ogm`3oool0o?cl0?ooo`3moOd0o_kn2`3oool0
0`3moOd0o_kn0?ooo`020?ooo`080?knoP3oool0nOWi0?knoP3oool0o_kn
0?_kn`3moOd20?ooo`80oOgm00<0o_kn0?ooo`3oool00P3oool00`3no_h0
oooo0?ooo`0Y0?ooo`80o_kn00l0oOgm0?Shn03bl_80jnKZ0>7SgP3Kh=`0
fM[N0=_Ig03LfmH0SY6F07EmTP1kRJ@0RYRe09RWb02P[]400P2P[]<0102O
[m40X;3A0:2`dP2P/=820:2^d@0C09f/c@2IZ<T0UJ;4096N`02;W;H0RYVh
08^E^02<UK80FFAj071kS`1nRZ@0RiRj09RVb@2P[]40Wjg@0:2^d@2Q[m80
Wjg@0:6_dP050:2^d@0D0:6_dP2P[]40WZc?09f[cP2DY<D0TJ2o08bK^02=
VkH0S9J_09:J/@2EWK80GfEk07=nU020RZ<0SYVe0:2[b`2X]ML0Y[?E0:Rg
f02X]mH20:VfeP<0Z[OG0`2[^=P20:jif@80[[WG0P2_^]P20;2ke`040;6l
fP2b_M/0/kkL0;:mf`80/KcJ00<0/[gK0;>ng02c_]`00P2d_md20;G0gR<0
]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P
0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=[J
fP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYB@0b<2Y1039`JX20<S0Z@H0bL6Z
303:`Z/40<_3[0@0bl>^103<a:l20<_3[PP0c<B_203=aK080<k6/@H0clNb
0P3>ak@60<o8]@80d<Zd103@bKH08P3@bKL0dLZh0=37]P3BbKP0dLZg0<k8
/P3:a:h0a;fZ0;jiY@2k]Z80^KBP0;F`W02`ZIH0ZjBB0:NPT02TWHd0XYZ=
0:2HR`2QW8P0XIb90:2JRP2RW8`0Y9j>0:NTT@2_[IH0];:I0<:kZ03;`[40
dLRg0=G9^`3DbkX0d<Vg0<o:]`3Bd;/30=C=^`030=?<^P3BbkT0d/^i0080
d/^i0P3Cc;X50=C=^`0A0=G>_03FdK/0e/nm0=C=_@3Fck`0e]:i0=SG``3A
d/d0DU9L05EZU`1RMjH0JWn^06]o/@1]PK@0Kh>h06n2^P1`Pk/0101^PkP4
06n4^@80L8Fj1P1aQ[/20767^@80LXRj101cRK/207B8^`80MHVl101fR[d2
07J:_080Mh^m1P1hS;h207V=_`@0NXk00`1kT;l307bA`080OI;10`1oTL43
082B`P80PI?302@0OY?0086D_`24UL40RYW209BRa`2S/Lh0]/;L0<;=h`3A
e>D0h>Kf0=kVl`2^^/H0I7Em0359C@0`BDd0@emR059aMP1DLgP0F7Ml05Yi
OP1HMg`0Dg9g04]ZK`16IFX0=4mF049JI01VOH/0TZNj0:Jgd@2R/M00WJ[=
09bXcP2AXl/0Sj7908fOa`2:W<@208VK``80RYc4102:VlHm08^La`0=08bM
b02:W<@0UjK=0:Ree@2ka]`0`l_H08b@V@3gmoL0oooo0?knoP3oool0oOgm
0?ooo`020?knoPX0oooo103moOd00`3no_h0oooo0?ooo`060?ooo`030?gm
o@3no_h0o_kn0340oooo0P3no_h03`3moOd0n?Sh0?;blP3[i^X0hN?N0=_P
g03If]h0fmWL0=cKeP2>TIH0MGfB07^9Y02:V;D0V:O80:2^d@020:2^d`04
09n_d@2P/=40X;3B0:2`dP80X:kA01<0WZg>09ZYbP2FXlD0Tj3208bM]`2;
V[T0RiFh08fF/`1II7X0LGb@07n;Y@2;V;X0V:K90:2^d@2O[M00X:kA0:6_
dP2O[M00XJoB00D0X:kA01@0XJoB0:2^d@2N[<l0WJ_>09FV`P2EY<40TJ6k
09NS^`2HXkL0WZJi0:6X^P1YL800MH2F08:<Y`2AW;P0XZg=0:Ree`2W]=H0
ZKSI0:Rgf080ZKKF0P2Z]mL40:^hf080[k[J00@0[k[H0:jie`2_^]P0[k[H
0P2`^mL00`2_^]P0/;_I0;2kf@030;6lfP050;:mf`2c_]`0/;kI0;2nf@2a
_mX00P2b`=/30;;0fR00]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0
oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT
0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYB@0b<2Y
2`39`JX=0<[2Z`@0bl>/103;`jh;0<c4[`P0cLF`203>a[480<o7/P030=38
/`3?b;D0clRe00D0clRe00<0d<Vf0<o9/`3?bK<0103?b;D20=39]`040=3<
[`3?bk00cLV`0<k9/`80d<^g00P0c<Nc0<W4/033`Zd0`L2[0;jlY`2j]j@0
]k:O0;F`W@80]ZnM0100]JZD0;R`V`2j/Yl0^;6Q0;RbY02n^jX0aL:a0<O6
/P3?b;P0e<^l0=?9_@3Bb;`0e<Zn0=;<_03?c;T0d<nj0`3Cc;X30=;;^@04
0=C=^`3Ec[`0dlbj0=?<^P@0e<fk0P3Ec[`0403@bKH0f]?10<g8]@3Fe;l0
eMBo0=OFa03Kf<l0Pgmn04QMRP1IKY/0IW^Z06]o/@1^P[D0Kh>h06f0^01^
PKT406j3^0@0KhBi1`1aQ[/00`1bQk`0LHNi07:8^P0207:8^P<0LhVk00<0
M8Zl07B8^`1eRK`00P1eRK`307J:_@0307N;_P1fR[`0Mh^m0080Mh^m0`1h
S;h00`1iSKl0N8bn07V=_`0207V=_`<0NXk000@0Nho107^@_`1kT;l0Ni2o
0P1lTL0307fB`@<0Oi710P20T/83086C``0F08:D`P25U/@0S9_609NUc02W
]=H0^lOQ0<cGj`3Ih_<0hnOb09ZS[01@GFD0=TU?04=OHP1EMgH0FH9n05R2
OP1LQhd0H8^A06B@T`1VTYD0I92A06:>S`80HXj=00h0JHR:06>0Q01>JG80
>E1N04aNM01oSZ/0WZ_;09fWbP2EYll0TjG=08nQb@2<W/H0RYc408VK``80
RYc4102:VlHl08^La`0=08ZKaP2;W<L0Rig509FTb`2W]=@0_LSN0<79eP2;
SiP0moOg0?ooo`3no_h0oooo0?gmo@0;0?ooo`030?gmo@3no_h0oooo00@0
oooo00L0o?cl0?ooo`3no_h0o?cl0?gmo@3no_h0oooo0080o_kn103oool2
0?knoRd0oooo0P3no_h03`3moOd0n?Sh0?;blP3[i^X0hN?N0=_Pg03If]h0
fmWL0=cKeP2>TIH0MGfB07^9Y02:V;D0V:O80:2^d@020:2^d`0409n_d@2P
/=40X;3B0:2`dP80X:kA01<0WZg>09^Zb`2GY<H0U:7308fN^02;V[T0S9Ji
08fF/`1JIG/0LGb@07n;Y@2<VK/0V:K90:2^d@2O[M00X:kA0:6_dP2O[M00
XJoB00D0X:kA0100XJoB0:2^d@2N[<l0WJ_>09f^b02N[lT0Vj_40:>_a@2Y
]<H0[kS90:nga01gOH/0M7nE08>=Z02AW;P0XZg=0P2W]=H00`2Y^=T0YkKG
0:VfeP030:Zge`<0ZkSH00<0[;WI0;2kf`2`^m/0102_^]P20;2ke`80/[gI
102c_]X20;Bof`80//3K00H0/KoJ0;6of@2a_mT0//3J0;?2f@2d`mXP0;G0
g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803o
ool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0
UIB?08Z8N`2IU840Z::<0;^cW034_:DP0<S0Z@030<NoZ038`:T0b<2Y00D0
b<2Y203:`Z/40<W1ZP@0b/:[103:`Zd80<_3[P@0c<B_00<0bl>^0<c4[`3<
a:l01P3<a:l70<g5/0030<c6/03=ak40cLNa00D0cLNa00<0cLJc0<k7]03>
ak@01P3>ak@;0<o8]@P0d<Vf103Ab[L20<k7]0050<g6/`3<aK80blBa0<[3
/039`Zl00P38`Jh01@39`Zl0b/>`0<c5/P3=a[<0clRe0080d<Vf403Cc;X8
0=C=^`0A0=G>_03Fck`0e<nk0=?>^P3Gd[l0h=[<0=OCb033_kH0?DMA05a[
UP1QNJT0HWfX0725_01aPK`0KH6c0727^@1^Q;H01`1_QKL30726^080LHNi
0`1bR;X307>7^@80M8Rj1P1eRK/207J:_0H0Mh^m0P1hS;h307V=_`<0NHjm
0P1jSkh307^@_`<0OHnm0P1nT;h307nA_`0K07n@_022UL00OYBm07^B^`1m
U;d0P9G0082B`020T<40OYJj08RL_`2JZ/`0Z[SE0;o9hP3Eg>`0gnK^0<?;
cP13Fed0?e]N04IUJ01BN7T0GHJ805n;SP1ST9D0JIJL06^LX`1]WZD0KYnV
0080Kj2W01@0KYnV06fNY@1[W:<0HiRL06NJWP1STYP0HXfD05QmQP0nG6L0
BVAa086HYP2IZL/0Sj75096Sb`2AY<h0Rik808VLa02>X/D0QYVj08ZKaP<0
Ric700<0S9g808^La`2;W<L0>@2;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE
0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3o
ool0;`3oool40?knoP@0oooo4@3no_h04`3oool0o_kn0?knoP3no_h0oOgm
0?Shn03alO40jnKZ0>3Rg@3Jgm/0f]_O0=cJg@3Kf]D0SY6F07InT`1kRJ@0
RYRe09RWb02P[]400P2P[]<0;P2O[m40X;3A09n]d02P[]40XJoB0:2^d@2O
[M00WJ_>09^Yc02IYlX0UZ?608fJ_02<V[D0SYfd05UUO@1bOYH0QI2/08bG
]@2IY/P0X:g?0:6^d@2N[<l0XJoB0:>ae02Q[m@0WZkB09j]bP2O[/d0X[3C
0:>aeP2Q[m80Wjk=0:>cc@2Y^M80[[K=0;Jnd`2e_<h0]K_70;^ob034bLl0
_l;707]nP`1cP9<0PhnU096M]`2Q[<X20:VfeP030:Zge`2Z^=D0Z[SE00<0
ZkWF0`2/^]L0102]^mP0[k[H0:njf02_^]P20;2kf@<0/KcJ102b_MT50;>n
fPL0];oK802e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl
4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cL
g03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU9P38`:T20<W1ZPP0
b/:[1039`JX40<[2Z`@0b/:]203;`jh:0<c4[`P0cLF`0P3>a[460<g7/@80
c/Rb1P3>ak@80<o8]@80d<Vf103?b;D80=39]Pd0dLZg103BbkP30=?<^A00
dlbj203DcK/0403Ec[`0dlbi0=;=^@3Cc[X0f=?00>3Jc03Pg=40fMG<045;
E01JIi<0GgFV069nYP1^PkX0LH6l06j2]01_Q[P606n5]`@0L8Jh0`1aQkT3
07:8^P80LhNi0`1dR;X507F9^`<0MXZl1@1gRkd307R<_P<0NHfo0P1iS[d3
07Z?_P<0Ni2o0P1mSkd307j@_P<0Oi6o01/0Oi2n08:D`P1oU;l0OIBn07nD
_`20UL80PY?108BDa@2<X<<0SZ720:^ieP2obN80f>3c0=OQk@2FXj/0=DA9
04MSI`1AL7<0GH2406N>T`1ZUYT0KIZO07>PYP1gY:X0LjB[07BU[01eYZd0
0P1fYjh0501eYZd0M:F/07>TZ`1^XjL0LJBX06bKX@1/Uih0LiVR06Z<UP1?
KgX0?E]V05]`R`2<XL00U:K:08RJ`P28VL@0TJ;=08FH`02>X/L0RY_6102;
W<L308bMb3P0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bB
T03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo02l0oooo1P3n
o_hE0?ooo`0A0?knoP3oool0o_kn0?Shn03bl_80k>O[0>3Rg@3Jgm/0f]_O
0=gKgP3LfmH0SY6F07InT`1kRJ@0RYRe09RWb02P[]400P2P[]<00`2O[m40
X;3A0:2^d@030:2^d@0X09n]d02N[<l0W:[=09^Yc02EXlH0UjC608nM^P29
Uk40GVf407^7X@25T:`0U9nm09NUb02O[M00Y;;E0::`d`2P[]40W:[=09f]
d@2S/mL0X[3C0:6_e02O[M80X:cB0:Fbe@2_^]X0]L7K0;K2fP34bm/0_lKF
0<79eP3;dMl0]kg9096GY@1jOH`0@TED07>0T`24T:H0TIfg0:6/bP80ZKKF
00<0Z[OG0:Zhe@2[^MH00`2[^MH20:bje`80[K_H0P2_^]P30;2kf@<0/KcJ
0`2b_MT50;>nfPH0];oK8P2e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kn
o`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3T
i>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU9@38
`:T30<W1ZPP0b/:[0`39`JX50<[2Z`<0b/:]203;`jh:0<c4[`P0cLF`0`3>
a[450<g7/@<0c/Rb1@3>ak@80<o8]@<0d<Vf0`3?b;D80=39]PL0dLZg0P3B
bkP00`3Cc;T0e<fj0=C=^P050=C=^P@0dlbi403Cc;X80=C=^`0@0=O@_P3C
c;T0d/fi0=G@_03Hdl00gMO90>?Oe03Xi=/0B55H05ERS01JL9l0HgbU06b1
^01aPK`0L8Bf06j5]`@0KhFg1@1`Q[P30767^@@0LXRj00@0LhNi07B8^P1d
R;X0M8Rj1@1eRK/307J:_0D0Mh^m0`1hS;h407V=_`0407V>_@1jSkh0NXnn
07Z?_P@0Ni2o00@0OHnm07j@_P1nT;h0OY2n101oTKl00`20T<40PYC4082E
`P02082E`P0C086C`@24UL40S9[709BTaP2^_=T0alkX0=SMl03Li>l0NXV@
041DF`16HVH0EWMn06J9S`1aVZ00Lj2U076PYP1dYJ`0MjR_07RW[`0207JW
[P@0MjR_0P1fYjh0401dYj/0MJJ[07FVZ`1aX:H0LYnU07NRZ@1dW:@0I8ZC
04i^N`14Gg80NHfX09:P``2AWlH0RIS308nPc026VlH508^La`<0S9g8>02;
W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<P3oool50?knoQ<0oooo0140
o_kn0?ooo`3no_h0n?Sh0?;blP3[i^X0h>;M0=[Of`3Jfml0gM_N0=_Je@2=
T9D0MGfB07^9Y02:V;D0V:O80:2^d@020:2^d`0309n_d@2P/=40X:kA00<0
X:kA02/0Wjg@09j/c`2N[<l0WJ_>09RVb@2KZ//0VZS5096O^P1oSJL0H6j9
08fH]02>VKL0VZS;0:2^d@2O[M00VjW<09j^d02Q/M<0WjoA09b/cP2MZm80
X:kE0:Jbf02^^=`0]KkO0;k5h@39cnD0d]W/0=3Gg`3FgNL0]kg907j5U@1F
GFl0GFEj07MoUP1@Eg40M86D08B@YP2BW[P0XZg;0:Zge`2Y]]H0ZkSH00@0
ZkWF0`2/^]L20:fkf0040:njf02`^mT0/;_I0;2kf@@0/KcJ0P2b_MT60;>n
fPD0];oK8`2e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl
4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cL
g03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU9038`:T40<W1ZPP0
b/:[0P39`JX60<[2Z`80b/:]203;`jh:0<c4[`P0cLF`103>a[440<g7/@@0
c/Rb103>ak@80<o8]@@0d<Vf0P3?b;D80=39]Q00dLZg0`3BbkP30=?<^A00
dlbj203DcK/0403Fckd0e<fj0=?>^P3FdKd0f=?00=cFb03Rg]<0j>CK04iE
F`1AGHD0EfbI069kX`1ZOk@0LH6l0765]`1^QKL306n5]`D0L8Jh0`1aQkT3
07:8^P80LhVk0`1dR;X307F9^`D0MXZl0`1gRkd507R<_P<0NHfo0P1jS/03
07Z?_P<0Ni2o0P1lTL0307j@_P<0Oi6o0P20T/006020T/80PI?3082Ea020
UL@0P9G2086B_P28Ul80UJ;<0:VddP31b>80dmS[0>?WlP1kQXX0?55D055`
M@1MQ8/0JHnH06nJX@1eXZP0LZ>Z07:TZ`1eYk00M:J_07:R[0P0MJJ]00D0
N:V^07JW[01jZk00O:fb07BUZP02072QYP0:06fNX`1/TiP0EGN003mIJP1e
QZ80R9Fh08ZG`@29V/H0QiW708bMb3l0Ric700`0RY_608^LbP2;WLD0UjS6
0:Zhe@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3o
ool0oooo03L0oooo4@3no_h04`3oool0o_kn0?gmo@3no_h0oOgm0?Ogm`3a
lO40jnKZ0=oQg03Jgm/0f]_O0=cJg@3JfM@0S8nD07AlT@1kRJ@0RYRe09RW
b02P[]400P2P[]<00`2O[m40X;3A0:2^d@040:2^d@<0Wjg@02@0WZc?09^Z
b`2JZLP0U:7109JT`@1EHgh0P8jY09VT`02FY/P0X[;D0:Ngf02U]=D0Xk;C
0::adP2T/m@0YkKG0:NdeP2[^=P0/[gK0;S2g@36c>80e=W/0=cOkP3KgnX0
e]gW08jDXP1FGFd0J72308ZBZ@2@V[<0RiNa05UUO`1dPI@0Q92V09:N^02R
[L/20:Zge`040:^hf02[^MH0ZkWF0:^ieP<0[;[G0`2]^mP30;2kf@<0/KcJ
0P2b_M/50;>nfPL0];oK902e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kn
o`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3T
i>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU9038
`:T40<W1ZPh0b/:[0P3;`j`60<_3[PP0c<B_0P3=aK040<c4[`P0cLF`103>
a[440<g7/@@0c/Rb103>ak@80<o8]@X0d<Vf203Ab[L20=;;^0<0dlbi203B
bkP00`3Cc;T0e<fj0=C=^P020=G>^`P0dlbj403DcK/0403Cc;X0e<fj0=?>
^P3Dck/0fMC10>3Jc03Th=D0in?J05=HG01?FGd0EVVD065iW`1ZO[<0LH6l
0726]`1/Q[L50726^0D0LHNi0`1bR;X307>9^`80M8Rj0`1eRK/507J:_0<0
Mh^m1@1hS;h307V=_`<0NXk00P1jSkh307^@_`<0O9700P1nT;h307nA_`@0
P9;00`1oU<<05021Tl40PiBo092N``2Q[]40_LCN0=ONl@3Lh^h0NhB903mA
D`1BL780H8N<06BCV@1dX:T0LZ6Y07>TZ`1aYZh0LjR`07BY/@1fZ;40MZJ`
201fYjh0401gZ:l0M:F/076RZ@1`XZT0M:J]07BY[`1aYZ`0KZ>Y07JTY01g
X:@0Ggn:03]DJ01^Oi/0RYZn08ZKaP29V/H508^La`<0RY_6>02;W<L0302:
VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?kn
oP80oooo00<0oOgm0?ooo`3oool0=`3oool@0?knoP<0oooo0P3no_h03`3m
oOd0n?Sh0?;blP3[i^X0h>;M0=[Of`3Jfml0gM_N0=_Je@2=T9D0MGfB07^9
Y02:V;D0V:O80:2^d@020:2^d`0309n_d@2P/=40XJoB00L0X:kA02P0WZk@
09j/c`2N[<l0V:O809ZYb01oS:`0H6j;08bJ]@2P[m00Xk;A0:Nfe@2]_=/0
//3M0;2nf`2`^mL0/kkJ0;[6g032cn80am;T0<_Dh`3IhN`0i^gg0=cPj@35
bM80Ifj107IlU027SZP0U9ji08nI]026TZX0QIBY05UXN`1dPI@0QI6W09:N
^02S[/`0ZkSH0:Zge`2[^=P0ZkWF0`2/^]L30:fkf080[[cI0P2`^mT30;6l
fP<0/[gK0`2c_]X90;Bofb@0]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3n
o_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYB<0
b<2Y1@39`JX=0<[2Z`<0bl>/1@3;`jh80<c4[`<0cLF`0`3<a:l80<g5/0D0
c/Ja0`3=ak450<k8/P<0c/Nd203?b;D:0=39]PP0dLZg0`3BbkP00`3Ab[L0
d/^h0=;;^0030=;;^0T0dlbi00<0e<fj0=?<^P3Cc;X01P3Cc;X@0=C=^`0@
0=G>_03Gd;d0dljj0=;=^@3Ie<40hmg?0>KRe`3WhmX0E5QK04mGN`1FJI<0
H7RL06Yn/@1bPk/0L8Jg06b6]`@0L8Jh101aQkT407:8^P<0LhVk00<0M8Zl
07F9^`1eRK/00P1eRK/307J:_0D0Mh^m0`1hS;h507V=_`<0NXk000<0Nho1
07^@_`1kT;l00P1kT;l307bA`00307fB`@1oTKl0Oi6o0080Oi6o0`20T/00
0`21Tl40P9>n07nD`@0207nD``0?08>F`@2;V/40WJ[:0;:mf@3:d>00fN7^
09bY/@10DeL0DVia06:8R`1QSY<0KInV07BT[P1bY:d0LZN_0080MJZb00@0
M:J]07FV[@1iZ[40MZN^1P1eYZd04P1fYjh0LZ>Z07RY/01hZK00MZR_07RZ
/@1cZ:h0LJJ/07J[/@1aXj@0L9fP07^TZP1QQI40?EY/06b1W027UkT0S9[1
08VJa@80RY_60`2;W<L208ZKaSP0Ric700`0RY_608^LbP2;WLD0UjS60:Zh
e@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo03<0oooo503no_h30?ooo`80o_kn00l0oOgm0?Shn03bl_80k>O[0>3R
g@3Jgm/0f]_O0=gKgP3LfmH0SY6F07MoU01kRJ@0RYRe09RWb02P[]400P2P
[]<00`2O[m40X;3A0:2^d@070:2^d@0T09j^c`2M[Ll0Y;;E0:2^d`2P[]40
W:_<07B2W`1XMY40V:K30:^ieP2fa=l0]l?M0;[4g`31bn@0aLcV0<G=i03>
enH0cMOS0=GOj@3UkoP0jO;k0<[Bg@2CVjP0J6mo08:<Y`2@VKH0TY^l08^F
]P25T;00RYRb08^J[@1?Gfh0MH:E08FAY`2CWkT0Xjk<0P2[^=P0102/^MT0
[;[G0:bje`2/^]L30:fkf0<0[[cI102a_=X30;:mf`030;>ng02d_m/0];oK
00@0];oK0P2e`=`30;BofbD0]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3n
o_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlYB80
b<2Y1P39`JX<0<[2Z`@0bl>/103;`jh80<c4[`@0cLF`0P3<a:l80<g5/0H0
c/Ja0P3=ak460<k8/P80c/Nd203?b;D:0=39]PP0dLZg103BbkP30=39]P80
dLZg2`3BbkP80=?<^Q00e<fk0100em2n0=SA_P3Cc[X0d/fi0=WD`@3Qfld0
hmoD0>OSfP1DEEL0DEMi05QZTP1OMi/0JWja07>4_01_QK@0KHNh0P1`Q[P6
0767^@<0LXRj0`1cRK/207B:_0<0MHVk0`1fR[`507N;_@<0N8bn1@1iSKl3
07Z>`080Nho10`1kT;l307bA`080OI;10`1oTKl3082B`080PI?101P0OiFl
082E`020UL80P9G208RJ`P2FYLH0[;[D0<C?i@3LgnP0_lSA02m2B@15HVP0
Fh:706FBU`1^Wj@0LJ:Y07>U[P1dYZd0M:V_07FZ/01cZ:h0LZB[07FTZP1i
YZ`207BU[0@0MJJ]0P1dYJ`00`1gZ:l0MZR_07BV[@0207FW[P0?076SZP1b
Y:/0NJ^b07RY/01cYZX0L:>V07JWZ`1HP8P0>UMW07>5W@27T[00QIK108NH
``28VL@0RY_603`0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M
08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300oooo
0P3no_h00`3moOd0o?cl0?clo00C0?_kn`0C0?clo03kno/0n_[j0?_kn`3j
n_X0m?Cd0>k^kP3Yi>P0gMoJ0=KKe`3Fem/0fMOJ0=WHd`2<Si@0MWjC07^9
Y02:V;D0V:O80:2^d@020:2^d`0309n_d@2P/=40X:kA00L0X:kA02@0X;3A
09f]c`2M[M40WJ_B0:2^d`2LZl`0Xk;?07R6X@1MJH<0RYJ`0;Fof035cN@0
bLoU0<gBiP3Ben/0f=_^0=GMj03Pj?<0hn_f0<C>f028TJ80H6^107IoW02Q
[<`0VJW209>R_`2=V[`0SIZm08RE^028Tk40RYJ^05]XN`1ePYD0QI6W09>O
^@2S[/`20:^hf0040:bif@2/^]L0[;[G0:bje`80[K_H102^_=T30;6lfP<0
/[gK0P2c_]`50;Bof`<0]L3L0P2d_m/V0;G0g0080;g8gP3:d^D0dmWW0=KI
hP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0oOgm0?Win@3c
lo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^c
W034_:DP0<S0Z@L0bL6Z3@3:`Z/40<_3[0@0bl>^203<a:l;0<g5/0P0c/Ja
00<0clNb0<k8/P3>b;801@3>b;800`3?bK<0clRe0<o8]@050<o8]@P0d<Vf
00<0dLZg0=39]P3@bKH00P3@bKH80=7:]`h0d/^h0`3Cc;T30=C=^PP0dlbj
403DcK/0403Cc;X0e<fj0=7<^03Cc[X0fMC10=kHbP3QgM80jNGL05=EE01B
F7X0F6ZB05mgV@1ZO[40LXFm06j4/`1^R;T70767^@@0LXRj0P1cRK/307B:
_0<0MHVk0P1fR[`607N;_@80N8bn1P1iSKl207Z>`0<0Nho10`1kT;l207bA
`0<0OI;10`1oTKl2082B`0<0PI?10180OiFl08:H`@21U/40PIK108bNa02N
[L`0^<CL0<oJk03Oh^L0E5mU045HGP1JOhL0Hi2F06fNY@1cY:/0MjR]07BV
[@1cZ:h207:W[@0407>X[01gZ:d0N:N]07VV[0<0MZN^0P1gZ:l307JW[P03
07BV[@1eYjh0MJN^0080MJJ]0P1hZK003@1cY:/0M:B`07J[/`1_ZJ/0KZJW
07RY[@1RQ8h0Beea07f4WP23U;l0Q9G008NH``2:VlH0102<WLPh08^La`0<
08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0
o_kn0P3oool00`3moOd0oooo0?ooo`0`0?ooo`050?knoP3moOd0o?cl0?_k
n`3inOT00P3hn?PC0?Ogm`80m_Kf00l0mOGe0?3`l03Zj^X0iN3T0=WKeP3B
em<0dM;F0=GCeP3Ee<l0RHbA079jS`1kRJ@0RYRe09RWb02P[]400P2P[]<0
0`2O[m40X;3A0:2^d@020:2^d@0Y0:6_dP2P[]40X:kA0:2^d@2O[M00W:c=
0:Fee`2IZ<l0X[7H0:6_eP2O[M00X:o<09j^b02BW;D0MX2I06YbR@24RZ00
Zk340;g0d`30`M<0a<GG0;bocP2CVJL0Jg>006QaPP24SjD0X:_;0:>_e`2K
Z=D0U:Jl09:S_@2;V[/0RINl08JB^029TkL0RiBc05MQO01ePYD0QI6W09>O
^@2S[/`00P2[^=P00`2/^MT0[;[G0:bje`030:fkf0<0[[cI00@0[kgJ0;6l
fP2a_=X0/KcJ0P2b_M/30;>ng0@0];oK2`2e`=`00`2f`Md0]L3L0;G0g00N
0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00
803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3J
f]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@030<JnY`37_jP0aknX
00D0aknX2039`JX40<S0Z@@0bL6Z203:`Z/00`39`J`0b/:]0<[2[@090<[2
[@P0bl>^203<a:l80<g5/0@0c/Ja00<0c<Fb0<g6/`3=a[<01P3=a[<80<k7
]0P0clRe2`3@bKH80=7:]`@0d/^h00<0dLZg0=;;^03BbkP01@3BbkP80=?<
^P030=;;^@3Cc;X0dlbj00D0dlbj203DcK/80=G>_00@0=C=^`3DcKX0dljj
0=?>^P3Hdl00h=[<0>GQeP3Xi=/0DUII051HO01GJY@0GgNK06]o/P1dQKd0
L8Je06j8^@<0L8Jh0P1aQkT307:8^P<0LhNi0P1dR;X607F9^`80MXZl0`1g
Rkd0101gS;/0N8fl07R=_01hSK`307V>_@0307Z?_P1iS[d0NXnn0080NXnn
0`1kT;l00`1lTL00OHnm07j@_P0207j@_P<0Oi6o1@20T/04086C`@0@08NE
a01lTKh0Pic508>I`02IXlH0]KWD0<kAi03Kgn/0Sj6U04=JH01@LGP0HHbC
06VJX@1dY:h0M:>[07VU[QP0MZN^0100MJJ]07BV[@1eYjh0LjF/07>TZ`1d
X:T0HHVC03mUL020U;L0OH^b092Ia028UL40S:;;08BN``27WL80SIo5>02;
W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool0;`3oool20?knoP0>0?clo03i
nOT0mOGe0?7al@3`l?00kno_0>c`k`3^lnl0j^o[0>k`k@3dm?80kno_0?7_
lP3`k_480?7_l0030?3^k`3ako00lNo`0080l>k_00l0kng^0>_YjP3Vi>D0
fmcG0=CCd@3Dd]<0dM3>0<o@b`3;cm00OhFA07IlU01kRJ@0RYRe09RWb02P
[]400P2P[]<00`2O[m40X;3A0:2^d@0?0:2^d@060:>`d`2P[Ll0Tj3207n<
[01/NYL0Hg6<0P1QKhT00`1YMiX0OH^^09FSaP020:6_dP0?09n]d02MZlh0
WJ_>09RV``2BWkl0SIZl08ZG^@29U;@0RiJd08ZF/01HI7`0MX6E08NBZ02D
X;X0YK3<0080[k[H0P2]^mH0102_^]P0/;_I0;2kf@2`^mT30;6lfP030;:m
f`2b_MT0/kkJ00H0/kkJ102d_m//0;G0g0080;g8gP3:d^D0dmWW0=KIhP2B
TiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0
jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034
_:D80<S0Z@H0aknX0P38`:T80<W1ZP@0b<2Y1039`JX80<[2Z`H0b/:]0P3;
`jh40<[2[@P0bl>^203<a:l80<g5/0@0c/Ja1P3=a[<80<k7]0P0clRe203@
bKH20=7:]`@0d<Vf203Ab[L:0=;;^080dlbi3P3Cc;X:0=C=^`P0eLjl0100
e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1BEUT0D5Ql05MZU01P
N9`0Jgnb07F6_P1`Q[D0KXRi0P1`Q[P30767^@<0LXRj0P1cQkT307B8^PD0
MHVk0`1fR[`307N;_@@0N8fl0P1iS[d607Z?_P80Ni2o0P1lTL0407j@_P80
Oi6o1@20T/05086C`@0@08BB`@21U/<0PIS108nSb02Z]MD0`<CO0=?Ij@39
dM`0=daA04=OH`1URY00K9VO076RZ@1cYJh0LjB[07FT[1T0MZN^00l0M:J]
07FW[P1eYjh0MJJ]07^W/01^VJ80Egn905Q`S01oSk00QI6g08ZG`@26VL<0
RZ7:08JL``29Vl<0>02;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33
b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<03o
ool02@3no_h0no_k0?Ogm`3alO40kNg]0>[ZjP3YjNT0i>KU0>GWiP020>GW
i080i^KT00<0j^SY0>WWj03Vi>D0203Vi>D20>OUiP<0i^CU00h0hMoP0=cJ
f`3DeM00c<_90<O5aP32`Kl0aLK00<S:b@20Q8l0N7fA07^9Y02:V;D0V:O8
0:2^d@80X:kC00<0WjoA0:2`d@2P[]403`2P[]402P2OZm40XZoB0::_dP2O
[<h0WJ[:09n]bP2Q[lX0X[3;09^Yc02O[M020:6_dP80X:kA00h0WZc?09^Y
c02HY/<0TYno08fJ_02:UkT0RIBd08^F]02:U[00F6Al07J1U@27TZP0U:2j
0:F`c080[k[H00<0[[cG0:fkeP2`^mT00`2`^mT20;6lfP80/[gK1P2c_]X6
0;Bofb`0]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo0?kno180
oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0
f]WN0=[JfP2EU8l0RXQk09VDP@2XXX`0^k>L0<BlY@P0b<2Y1@37_jP30<S0
Z@P0bL6Z0`38`:T50<W1ZPP0b/:[1@3:`Zd30<_3[P<0b/:]203;`jh80<c4
[`P0cLF`1@3>a[450<g6/`P0c/Nd203?b;D80=39]P<0dLZg0`3@bKH80=7:
]`X0d/^h0`3Cc;T=0=?<^P/0e<fk203Ec[`04@3DcK/0e<fj0=?>^P3Cc[X0
f=?00>3Jc03UhMH0j>CK059FF@1@F7`0EfZD061hW01[Ok80MHJn0726]@1^
R;T0L8Jh00<0LHNi101bR;X0101cQkT0M8Rj07B8^P1dR;X507F9^`<0MXZl
101gRkd307R=_0<0NHjm1@1jSkh307^@_`80O9700`1nT;h307nA_`@0P9;0
1P21Tl403`23U<80P9G008>K`@2GZLd0/K[I0<O;i03FgNd0Kgb503YGF`1L
OH80JI:H06VHWP1gZK00LjR`07FW[P0I07JW[P0@07NX[`1dYZd0MJN^07FW
[P1fYjh0O:^c07bW/01bVZ@0A61e06j2V`1oS:h0QiFj082C^`2;X//0RIk9
08^Lb3P0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300oooo00l0o_kn
0?[jnP3dm?@0kNg]0>OWi`3Shn<0hN7Q0=gMg@3Ph>00i>CT0>;RhP3Ng]h0
h^;R0>7Qh@3MgMd02`3RhMl04@3Qh=h0h^7O0>7PgP3Mg=X0f=OE0<k?bP38
alD0a<;30;nn_030`K`0`<:o07UmQP1dNXX0NhVT08ZH]@2HYlP0X:kA0080
X:kC00<0WjoA0:2`d@2P[]403`2P[]40102Q[M<0XZkD0:>_e@2S/=<20:>`
dP0F0:6^cP2NZl/0YK?F0:>ae02O[M00WZc?0:2^d@2R/=<0X:kA09^Yc02H
Y/<0TYno08fJ_02:UkT0RIBd08^F]02:U[00F6Al07N2UP27TZP0UJ6k0:F`
c080[k[H0P2^_=L30;2kf@<0/KcJ0P2b_M/50;>nfPH0];oK;@2e`=`0202m
b=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100
o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:
R7/0VIB10:RRS02k/i`0a;bU2038`:T40<NoZ0@0b<2Y2039`JX20<S0Z@H0
bL6Z203:`Z/40<[2[@@0bl>^0P3:`Zd80<_3[PP0c<B_203=aK060<k6/@@0
cLJc203>ak@80<o8]@P0d<Vf103Ab[L20=39]PP0dLZg2P3BbkP40=?<^@`0
dlbj303DcK/80=G>_00@0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3X
i=/0DUII051HO01GJY@0H7RL06b0/`1eQ[h0L8Je06j8^@<0LHNi0`1bR;X2
07>9^`<0M8Rj0`1eRK/507J:_0<0Mh^m0P1hS;h207R=_0<0NHjm1@1jSkh3
07^@_`<0O9700P1nT;h307nA_`<0P9;01@21Tl4408:D`P0?086G`02<X/L0
Wjk?0;g4h03@enX0`<cH0313BP1DMgT0IXfB06ZGW01_X:L0M:Va06nT[01c
Z:h0M:V_01P0MZN^0100MjR_07FV[@1dYZd0MJN^07>U[01hZK00OZZc07jY
/P1OPH/0EFn007Z:Y023T;80PI>k08FJa@2;WL/0SIk<>02;W<L0302:VlH0
Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80
oooo00<0oOgm0?ooo`3oool0<03oool03@3moOd0nOWi0?;blP3YjNT0h^;R
0=kNgP3Lg=`0gmgN0>CRi@3IfM/0c/gB0<c;d03BdmL00P3=c]080<c>c@03
0<[<b`3;cL`0blg<00<0b/c;00h0a/S70<;4``2k_KX0]KJh0;Bc^@2b/;<0
/K6_0:j`[`1^LgT0Nh6?07^9Y02:V;D0V:O80:2^d@80X:kC00<0WjoA0:2`
d@2P[]403`2P[]4209n]e080WjgB00H0XJoB0::`d`2R/=<0X:o@09j/c`2P
[]420:6_dP80X[3C0100Wjg@09^Yc02HY/<0TYno08fJ_02:UkT0RIBd08^F
]02:U[00F6Al07N2UP28TjT0UJ6k0:F`c02`^mT0[k[H0P2^_=L20;2kf@<0
/KcJ0`2b_M/40;>nfPH0];oK;P2e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G
0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03JfMh0f][J09FDS`2:R7/0VIB10:RRS02k/i`0a;bU
2038`:T40<NoZ0@0b<2Y3P39`JX:0<[2Z`@0b/:]2P3;`jh80<c4[`P0cLF`
203>a[420<o7/P@0cLJc203>ak@80<o8]@P0d<Vf2P3Ab[L80=;;^080dlbi
103BbkP40=?<^@`0dlbj303DcK/80=G>_00@0=C=^`3DcKX0dljj0=?>^P3H
dl00h=[<0>GQeP3Xi=/0DUII055IO@1GJY@0H7RL06b0/`1eQ[h0L8Je06j8
^@80LHNi0`1bR;X307>9^`80M8Rj0`1eRK/507J:_0<0Mh^m0`1hS;h307V>
_@<0NXnn1@1kT;l307bA`080OI;10`1oTKl3082B`0D0PI?11@22U<804022
UL00Qig609:Tb02W]M80b]3X0=?Jk01fQi40>eMJ05=oP01UTYD0LJ2V07BV
[@1bYjl0M:Va07:W[@1aYZXH07JW[P0@07NV[P1dYJ`0M:J]07>X[P1cYJ`0
M:F/07ZY/@1oZk@0Pjb^05UgP@1WNHl0OHZZ086A]@22UKl0Qi[508ZKbCP0
Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300oooo00l0oOgm0?Shn03a
lO40j>SX0>7Qh@3Lg=`0f][J0=_Jf03Jf=/0[:^a08^;U@26RI80R8bE07n4
RP23RY002`24RHl308>8SP0>0825R`1kP8H0Nh2307EhP@1cMH40M7An07Ae
NP1cMgX0BDeH06meQ@1kRJ@0RYRe09RWb02P[]420:2^d`0309n_d@2P/=40
X:kA00l0X:kA00@0X[3E0:6_e02P[]<0WjgB0P2N[=401P2O[M80X:kA0:2^
d@2R/=<0Xk7D0:6_dP80X:kA00h0Wjg@09f[cP2HY/<0TYno08fJ_02:UkT0
RIBd08^F]02:U[00F6Al07N2UP28TjT0UJ6k0:Jac@80/;_I00<0[kgH0:jl
e`2a_=X00P2a_=X30;:mf`80/kkL102c_]X40;Bof`H0]L3L0P2f`MdX0;G0
g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803o
ool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0
UIB?08Z8N`2IU840Z::<0;^cW034_:D80<S0Z@<0aknX1@38`:T=0<W1ZP/0
b/:[0`3:`Zd:0<_3[PP0c<B_203=aK080<k6/@<0clNb0`3=a[<80<k7]0P0
clRe203@bKH:0=7:]`P0d/^h0`3Cc;T30=;;^0D0dlbi2`3Cc;X=0=C=^`P0
eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1CEeX0DEUm
05Q[U@1PN9`0K82c07F6_P1`Q[D0KXRi101bR;X307>9^`0307B:_01eRK/0
MHVk0080MHVk0`1fR[`507N;_@<0N8bn00<0NHfo07V>_@1iS[d00`1jSkh5
07^@_`<0O9700`1mT/4207nA_`<0P9;00`21Tl4608:D`P80PiG30100PIK1
08NMa02FY/L0]l7L0<[?h`38cml0=DaB04i`L@1MSHl0JYZN076RZ@1bXZ`0
MJN`07^]]01_Y:X0M:V]601fYjh0401gYZh0M:F/07FW[P1eZ[00LjR^07>U
[01hZK00OJbd08Ne/`1dUid0DfEi07F3X01lRZd0Q9Jn08JI``29V/Hh08^L
a`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3o
ool0o_kn0P3oool00`3moOd0oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a
0>WYj@3Rh^80gMgM0=_Kf`3LfmL0fm_K09FEW@1`LWl0KgB7075hRP1ZLh80
LGf;00P0L7N90`1bNH/3075hRP0>06ieQ`1ZLH<0J79l06=ZO01RIgd0HfIi
06=WL`1QJ780?dMD07=kSP1kRJ@0RYRe09RWb02P[]420:2^d`0309n_d@2P
/=40X:kA00l0X:kA0P2Q[m801P2R/=<0XJoD09n]dP2N[=40WjgB0::`e@80
Wjg@01@0WZc?09f[cP2O[M00XJoB0:2^d@2MZlh0V:K309:O_`2=V[`0RYNi
08VD]02;U[@0RYJ`05QTO01hPiL0R9>Y09JR_02V/Ld0/KcJ0;2kf@80[kgH
0P2a_=X30;:mf`<0/kkL0`2c_]X50;Bof`D0]L3L0`2f`MdX0;G0g0080;g8
gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403n
o_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[IgP3Jf]X0UIB?08Z8
N`2IU840Z::<0;^cW034_:D80<S0Z@80aknX1P38`:T<0<W1ZP`0b/:[0P3:
`Zd:0<_3[PP0c<B_203=aK080<k6/@@0clNb0P3=a[<80<k7]0P0clRe203@
bKH:0=7:]`P0d/^h103Cc;T20=;;^0H0dlbi2P3Cc;X>0=C=^`P0eLjl0100
e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1CEeX0DEUm05Q[U@1P
N9`0K82c07F6_P1aQkH0KXRi0`1bR;X307>9^`80M8Zl0`1eRK/307J:_0D0
Mh^m0`1hS;h207V=_`80NHjm0P1jSkh607^@_`80O970101mT/4207nA_`80
P9;01021Tl4508:D`P<0PiG30100PIS208JL``2O/<h0a<_U0<oBi@2OZKD0
=e1D05MoOP1MSY80JY^P07>TZ`1iZ;80MJF_07FV[@1]X:@0NJb`601fYjh0
401gYZh0MJJ]07FW[P1eZ[00M:V_07>X[P1fZ:l0Njbc07na[P2:[kD0EFYk
06UgTP1gQZL0PYBh08FG_@2<Vl@h08^La`0<08ZKaP2;W<X0Rig509NXaP2Z
^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo
0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3JfmD0
fmgL08jAVP1`MHP0L7R?079lU`1cPYT0NHRO00P0OHRT0`1nRJD207f8Y00?
07j9Y@1kQZ80Mh:N075nS`1`NY<0KgJC06ebS`1^M8X0JgB5041;G@1^NHl0
NhVT08ZH]@2HYlP0X:kA0080X:kC00<0WjoA0:2`d@2P[]403`2P[]4309j^
c`050:2`dP2O[m40WJg?09j^d02P/=80102Q[m820:>ae00@0:2^d@2KZL`0
V:K309:O_`2=V[`0RYNi08VD]02;U[@0RYJ`05QTO01hPiL0RIBZ09JR_02W
//h0/KcJ0;2kf@80[kgH0P2a_=X20;:mf`@0/kkL0P2c_]X60;Bof`@0]L3L
102f`MdX0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B
0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL
0=[IgP3Jf]X0UIB?08Z8N`2IU840Z::<0;^cW034_:D?0<S0Z@d0bL6Z303:
`Z/70<_3[P030<c4[`3;`jh0bl>^0080bl>^203<a:l80<g5/0P0c/Ja103?
ak870<k7]0P0clRe203@bKH80=7:]`030=;;^03Ab[L0dLZg0080dLZg203B
bkP;0=?<^@030=C=^P3Cc;X0dlbj00H0dlbj1`3DcK/00`3Ec[`0e<fk0=C=
^`060=C=^`P0eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>ST
f`1CEeX0DEUm05Q[U@1PN9`0K82c07J7_`1aQkH0KhVj0`1bR;X207>9^`<0
M8Zl0`1eRK/207J:_0H0Mh^m0P1hS;h307V=_`0407V>_@1jSkh0NXnn07Z?
_P<0Ni2o00<0O97007^@_`1lTL000P1lTL0307fB`@0307jC`P1oTKl0P9;0
0080P9;00`21Tl4508:D`P@0PiG30100PIS2092Vb`2Y^=L0`lWQ0=OHjP1Q
JgD0AF5T05n9Q`1XVil0LjBY07NV[P1jZK<0LJ2Z07RW[`1gZ:d0M:N[601f
Yjh0401iZ;00MZN^07BV[@1cZ:h0M:V_07:W[@1eYjh0N:V`086e/@2A^;d0
K86B05m]Q`1ePZ80NHb]082B]P2;Vklh08^La`0<08ZKaP2;W<X0Rig509NX
aP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0
oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3J
gM@0fMkJ08Z>U`1cNXd0LW^H07N4Y026UK@0RY^g00P0S9Vk00@0RYNi08^H
^P2:UkT0RIJh0P2:UkT03P27U;H0Pi2b07b<X`1mRjP0NXBW07IoX01lPil0
NXFI04YFK01aOIL0NhVT08ZH]@2HYlP0X:kA0P2P[]<00`2O[m40X;3A0:2^
d@0?0:2^d@030:6bd02N[ld0WZk?0080X;3A0P2O[m405@2P/=80WZc?0:2^
d@2Q[m80X:kA09n]d02P[]40Wjg@09bZc@2HY/<0TYno08fJ_02:UkT0RIBd
08^F]02:U[00F6Al07R3U`29U:X0UZ:l0:NbcP020;6lfP030;2nf@2__MP0
/KcJ00<0/[gK0`2c_]`00`2d_md0];oK0;Bof`050;Bof`D0]L3L102f`MdX
0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00
803oool04@3no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=_Jg`3K
fm/0UYF@08Z8N`2JUH80Z::<0;bdW@35_JH0a[jW00L0aknX2039`JX40<S0
Z@`0bL6Z00<0bL6/0<[2[@3:`Zd02@3:`Zd80<_3[PP0c<B_203=aK040<k6
/@@0cLJc103>ak@00`3=a[<0c/Nd0<k7]0060<k7]0P0clRe2`3@bKH80=7:
]`@0d/^h00<0dLZg0=;;^03BbkP01@3BbkP80=C=^`@0dlbj103DcK/H0=G>
_00@0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0EEIH059JOP1I
JYD0HGVM06f1]01gR<00LhRg07::^P@0M8Rj1@1eRK/307J:_0<0Mh^m00<0
N8bn07N<^`1hSK`00P1hSK`307V>_@0307Z?_P1iS[d0NXnn0080NXnn0`1k
T;l00`1lTL00OHnm07j@_P0207j@_P<0Oi6o1@20T/04086C`@@0PYG01023
U/403@28VlD0UjO;0;>mf03;e>D0`<kG02e5B@1FNGd0HXjA06^LX`1bXjX0
MjR_07JW[P1eYZd00P1gZ:l00`1dYJ`0MZN^07JW[P0N07JW[P08086a_@2=
^;h0RJ^/05E/M01^Oi<0NhZ[07j=]028Vl<208ZKaP80Ric700<0S9g808^L
a`2;W<L0<@2;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@
0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<03oool03`3m
oOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0g][K0=_Le`2;T9<0Lg^@07^6
Y025Tjd0TZ6n09ZWd@0809ZXb`0409VWbP2JZ</0VZS;09VWbP80VJS900h0
UJC5096P`@2<VKT0R9Fe08JC]@23T;00QY6_08RC[`1EHGT0KGV?07^9Y02:
V;D0V:O80:2^d@80X:kC00<0WjoA0:2`d@2P[]401`2P[]420:6_dPl0X:kA
0P2Q[m820:2^d@0C0:6_dP2P[]40WJ_>09RUb02BWkl0SI^f08ZH]@29TkH0
RiFh08ZF/01HIGH0NHBH08RCZ@2IXkh0Z;7>0;6lfP2c_]`0/;_G0;:nf004
0;>nfP@0];oK>02e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0
o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN
0=cLg03Kf]l0fm_K09JET02:R7/0VYF20:RRS02l]9d0aKfV1P37_jP20<S0
Z@P0bL6Z1038`:T<0<W1ZPH0b/:]0P3;`jh40<[2[@P0bl>^203<a:l80<g5
/0@0c/Ja103=a[<:0<k7]0P0clRe203@bKH20=7:]`@0d<Vf203Ab[L:0=;;
^080dlbi203DcK/40=?<^P@0e<fk603Ec[`0403DcK/0e<fj0=?>^P3Cc[X0
f=?00>3Jc03UhMH0j>CK05EFF01BFWh0FV^F065iW@1]PK@0MhS007>8]`1b
R[X307B8^PD0MHVk101fR[`207N;_@80N8bn101hSK`207V>_@H0NXnn0P1k
T;l207bA`0@0OY2n0P1oTKl5082B`0D0PI?10`22UL0508>F`@0=08VLaP2L
Z/d0]/3K0<WBh`2Y]l00=4eB05]nPP1TT9<0KIjU07>TZ`1gZ:l0MZN^07FV
[@0207NX[`0307BU[01fYjh0MZN^01h0MZN^00P0Ojni08nk_P2B];D0Fg9h
06QiS@1gQZL0OXfd08FH`080RY_60P2;W<L00`2<WLP0Ric708^La`0a08^L
a`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3o
ool0o_kn0P3oool00`3moOd0oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a
0>WYj@3Rh^80gMgM0=_Kf`3MfMX0fmcG08bAU01eOI80OXVW08VG/@2HYl@0
X:gG00P0X:kA00@0Wjg@0:2^d@2P[]40Wjg@0P2O[/l03P2KZ//0UjK7092M
_@2;V;P0RYNi08JC/`29U;80RYFa05MSN`1_Ni40NhVT08ZH]@2HYlP0X:kA
0P2P[]<00`2O[m40X;3A0:2^d@0H0:2^d@80XJoB0P2P[]404`2Q[m80Wjg@
09bZc@2HYLP0TYno08fK]P2:V;D0RI>f08^E^02:U[00F6Ef07V4V028TjT0
VJ>n0:RacP2b_M/0/kkL0;6lf02b_]P0102c_]X40;BofcP0]L3L00P0_LSN
0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?kn
oP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0fm[O0=_Kf`2FUI00RXQk
09ZEPP2XXX`0_;BM0<FmYPD0aknX0`38`:T80<W1ZP<0b<2Y3@39`JX50<[2
[@<0bl>^0`3:`Zd80<_3[PP0c<B_203=aK050<k6/@<0cLJc2P3>ak@80<o8
]@P0d<Vf0`3Ab[L30=39]PP0dLZg2P3BbkP30=?<^@P0e<fk0`3Cc;X50=C=
^aP0eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1FEeT0
DUYn05Y[UP1RNYh0KH6d07N8`01cR;L0LXZj0P1dR;X607F9^`<0MXZl0`1g
Rkd207R<_P<0N8fl0`1iS[d507Z?_P<0Ni2o0P1lTL0307j@_P<0Oi6o1020
T/06086C`@80PYG01P23U/40402;W/H0XJoB0;_5h037d>40Q9:K045JG`1O
QHP0IiBG072QZ01dYJ`0MjR_07JW[P1eYZd0MZN^07NX[`1eYZdP07JW[P08
07f/]P2C_<00W[fo06ElPP1QL8D0Lh2R07f</`23UKd208ZKaP80Ric700<0
S9g808^La`2;W<L0<@2;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33
b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<03o
ool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0gMWJ0=_Le`2<TI@0
MWjC082;Z@2;VK<0VZW60:>`fP0;0:6_dP0A0:2^d@2P[m00X:o@09f/c@2H
YlP0TYno08jK^`2<VK/0R9Fe08^F]02;U[80F6Al071lTP1kRJ@0RYRe09RW
b02P[]400P2P[]<00`2O[m40X;3A0:2^d@0F0:2^d@040:6_dP2P[]40XJoB
0:6_dP80X:kA01<0XJoB09n]d02LZ/d0V:G809:O_`2=VkH0RYRe08VC]P2;
UKP0RYJ`05QUMP1iQ9P0R9>Y09ZT_`2Y//l0/[gK0;>ng02a_=P0/[kH00<0
/kkJ1@2d_m/h0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3n
o_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0
g=cL0=_Jg`3Kfm/0UYF@08Z8N`2JUH80Z::<0;bdW@35_JH40<NoZ0@0b<2Y
2039`JX20<S0Z@h0bL6Z103:`Zd40<_3[P80b/:]203;`jh80<c4[`P0cLF`
1P3>a[420<g6/`X0c/Nd203?b;D80=39]P@0dLZg0P3@bKH80=7:]`X0d/^h
103Cc;T80=C=^`80dlbj1P3DcK/H0=G>_00@0=C=^`3DcKX0dljj0=?>^P3H
dl00h=[<0>GQeP3Xi=/0EUMI059JOP1JJiH0HWZN06j2]@1gR<00M8Vh07::
^PD0MHVk1@1fR[`307N;_@<0N8bn0P1hSK`307V>_@D0NXnn0`1kT;l307bA
`080OY2n0`1oTKl3082B`0D0PI?10`22U<8508>F`@<0Q9O200/0SZ380:Bb
e@2man80a/oP05m`N01;If/0HXV>06VIW@1bXjX0MZN^07NX[`0207FV[@80
MZN^00<0MJJ]07JW[P1fYjh07P1fYjh0201m[;H0T[^o0:C3a@1cQhh0GFb1
06ikW@1jRK00PI>i0P2:VlH208^La`0308bMb02;W<L0Ric70340Ric700`0
RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3n
o_h20?ooo`030?gmo@3oool0oooo0300oooo00l0oOgm0?Shn03alO40jNWY
0>;RhP3MgMd0fm_K0=gIfP3Kg=L0S96D07EmTP1nRJL0RINa09NV``2P[ML0
202P[]40102O[M00X:kA0:2^d@2O[M0209n^c`0>09^Zb`2GY/L0TYno08fJ
^P2;V;X0QiBd08ZE/`2:UK40Ef=k06mkT@1kRJ@0RYRe09RWb02P[]420:2^
d`0309n_d@2P/=40X:kA00d0X:kA0P2O[M050:2^d@<0XJoB00<0X:kA0:6_
dP2Q[m800`2P[]404P2N[<l0VjW<09RUb02BWkl0SI^f08ZH]@29TkH0RiFh
08ZF/01HIGH0NXFI08VDZP2JY;l0ZK;?0;:mf`2c_]`0/KcH0;>of@80/kkJ
1P2d_m/h0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B
0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL
0=_Jg`3Kfm/0UYF@08Z8N`2JUH80Z::<0;bdW@35_JH40<NoZ0@0b<2Y3P39
`JX:0<[2Z`@0b/:]2P3;`jh80<c4[`P0cLF`203>a[420<o7/PH0c/Nd0P3?
b;D40<k7]0P0clRe203@bKH:0=7:]`P0d/^h0P3Cc;T40=;;^0@0dlbi3P3D
cK/J0=G>_00@0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0EUMI
059JOP1JJiH0HWZN06j2]@1gR<00M8Vh07>;^`<0MHVk1@1fR[`307N;_@<0
N8bn0P1iSKl307V>_@<0NXnn1@1kT;l307bA`080OI;10`1oTKl3082B`0D0
PI?11@22U<8308>F`@D0Q9O200/0TJ?90:Bce02man00a=3P04MHH01DLGL0
Hhb@06bMXP1dYJ`0MZN^07NX[`0207FV[@80MZN^00<0MJJ]07JW[P1fYjh0
7P1fYjh0201o[[P0T;Vm0:G5a01mTIP0G6]n06]hV01iQj`0P9:h0P2:VlH2
08^La`0308bMb02;W<L0Ric70340Ric700`0RY_608^LbP2;WLD0UjS60:Zh
e@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0300oooo00l0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3K
g=L0S96D07AlT@1nRJL0R9J`09JU`P2O[=H0202Q[m80102P[]40XJoB0:6_
dP2P[]420:2_d00>09b[c02HYlP0TYno08fJ^P2;V;X0QiBd08VD/P2:UK40
EV9j06ijT01kRJ@0RYRe09RWb02P[]420:2^d`0309n_d@2P/=40X:kA00L0
X:kA0P2Q/=40102P[m00Wjk?09n^c`2N[Lh509f/c@80WZg>00@0X:o@0:6`
d@2Q/=40X:kA0P2Q[m830:2^d@0B09n]d02LZ/d0V:G809:O_`2=VkH0RYRe
08VC]P2;UKP0RYJ`05QUMP1jQIT0RIBZ09ZT_`2Y//l0/kkL0;Bog@2b_MT0
/koI1P2d_m/j0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3n
o_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0
g=cL0=_Jg`3Kfm/0UYF@08Z8N`2JUH80Z::<0;bdW@35_JH30<NoZ0D0b<2Y
3@39`JX;0<[2Z`<0b/:]2P3;`jh80<c4[`P0cLF`203>a[430<o7/PD0c/Nd
0`3?b;D30<k7]0P0clRe203@bKH:0=7:]`P0d/^h0`3Cc;T30=;;^0D0dlbi
3@3DcK/K0=G>_00@0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0
EUMI059JOP1JJiH0HWZN06j2]@1hRL40M8Vh07>;^`H0MXZl101gRkd307R<
_P<0NHfo0P1iS[d307Z?_PD0Ni2o0`1lTL0307fB`@80Oi6o0`20T/03086C
`@H0PYC20P23UL<608BG`P80QIS300T0TZC:0:Fdd`2la]l0`LgM03U;E@1K
N7h0HXfC06fPY01eYZd00P1fYjh207FV[@80MZN^00<0MJJ]07JW[P1fYjh0
7P1fYjh02022[[L0TKVk0:O5a@24VIh0G6Ul06agU`1gQJX0PI2g0P2:VlH2
08^La`0308bMb02;W<L0Ric70340Ric700`0RY_608^LbP2;WLD0UjS60:Zh
e@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0300oooo00l0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3K
g=L0S96D07EmTP1oRZP0RYRb09RWa02Q[]P0202Q[m80102P[]40XJoB0:6_
dP2P[]420:2_d00>09b[c02HYlP0Tj3008jK^`2<VK/0R9Fe08ZE/`2;U[80
Ef=k06mkT@1kRJ@0RYRe09RWb02P[]420:2^d`0309n_d@2P/=40X:kA00L0
X:kA00H0XK3A0:2_d02O[/l0WJc=09b[c02JZLX509VXb@0609ZYbP2KZ//0
WJc=09j]cP2O[/l0Wjg@0P2P[]405@2O[M00X:kA0:6_dP2O[M00W:[=09RU
b02BWkl0SI^f08ZH]@29TkH0RiFh08ZF/01HIGH0NXFI08VDZP2KYL00Z[?@
0;>ng02d_md0/[gI0;>of@050;Bofc/0]L3L00P0_LSN0<[Bi@3CfNL0e]WR
09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0fm[O0=_Kf`2FUI00RXQk09ZEPP2XXX`0_;BM
0<FmYP80aknX1P38`:T<0<W1ZP`0b/:[0P3:`Zd:0<_3[PP0c<B_203=aK08
0<k6/@@0clNb103>ak@40<o8]@80c/Nd203?b;D80=39]PX0dLZg203BbkP4
0=?<^@80d/^h1P3Cc;T<0=C=^a`0eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC
`03Pf/`0iN7F0>STf`1FEeT0De]o05Y[UP1RNYh0KX:e07R9`@1dRKP0Lh^k
1@1fR[`507N;_@80N8bn101iSKl207V>_@80NXnn1P1kT;l207bA`0@0OI;1
0P1oTKl2082B`0@0PI?11@22U<8308>E``D0Q9O20`25V<<0202CXlL0Y[GD
0;_5gP2ja]H0<dE?05mnP`1UT9H0KInV201eYZdP07JW[P08086]]P2D_;h0
Z/S808JKX01IIWT0K7NG07J4Z@20T;@208ZKaP80Ric700<0S9g808^La`2;
W<L0<@2;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Sh
n03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<03oool03`3moOd0
n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0gMWJ0=_Le`2<TI@0MGfB07n:Z02:
V;80VJS50::_f@0909n]d0030:2^d@2O[M00Wjg@0080Wjk?00h0Vj[;09JU
aP2BWkl0SY^k08bI^`28UKD0RYFc08^F/P1HI7`0L7bB07^9Y02:V;D0V:O8
0:2^d@80X:kC00<0WjoA0:2`d@2P[]401`2P[]401`2P[m00Wjk?09f/c@2K
Z//0V:O809JUaP2DXl@0102CX/<07@2EY<D0UZG609VXb@2KZ//0W:_<09j/
c`2O[M00X:kA09n]d02P[]40XJoB09n]d02MZlh0V:G809:O_`2=VkH0RYRe
08VC]P2;UKP0RYJ`05QUMP1kQYX0RYF[09^U`02Z/m00/kkL0;Bog@2b_MT0
]<3J00@0];oK?02e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0
o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN
0=cLg03Kf]l0fm_K09JET02:R7/0VYF20:RRS02l]9d0aKfV1`38`:T=0<W1
ZP`0b/:[1`3;`jh00`3<a:l0bl>^0<_3[P020<_3[PP0c<B_203=aK080<k6
/@@0clNb103>ak@;0<o8]@P0d<Vf203Ab[L00`3BbkP0dLZg0=7:]`020=7:
]`P0d/^h2`3Cc;T00`3DcKX0e<fk0=C=^`0:0=C=^a`0eLjl0100e<fk0=C=
^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1FEeT0De]o05]/U`1RNYh0KX:e
07R9`@1dRKP0Lh^k101fR[`507N;_@<0N8bn0`1iSKl00`1jS/00NHjm07Z?
_P0207Z?_P<0Ni2o00<0O97007^@_`1lTL000P1lTL0307fB`@0307jC`P1o
TKl0P9;00080P9;00`21Tl4508:D`P@0PiG31024Ul8408FH``0809:RaP2Y
]]H0^lKL0;G1c`0`@T`0HH2506NDV@1ZWjD407FV[@0407JW[P1eYZd0MJJ]
07FV[B00MZN^00P0P:be09S0`P2]blT0R9^Q05ISMP1[MYH0MH>X07n?/`80
RY_60P2;W<L00`2<WLP0Ric708^La`0a08^La`0<08ZKaP2;W<X0Rig509NX
aP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0
oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3M
fMX0fmcG08bAU01eOI80OXVW08VG/@2GY/<0X:gG00P0XJoB00@0X:kA0:6_
dP2Q[m80X:kA0P2P[m003P2LZl`0V:O8096N_P2<VKT0RiRj08ND]029U;80
RYFa05MSN`1_Ni40NhVT08ZH]@2HYlP0X:kA0P2P[]<00`2O[m40X;3A0:2^
d@070:2^d@0709j]cP2M[<d0Vj[;09RWb02EY<D0TZ72092O`00308nN_`07
092O`02AX<40Tj;309JUaP2IZ<T0VZW:09f[cP0309n]d00D0:2^d@2Q[m80
X:kA09f[cP2HYLP0TYno08fK]P2:V;D0RI>f08^E^02:U[00F6Ef07^6VP2:
UJ/0VjG00:Zcd02c_]`0]L3N0;>nfP2d`=X40;Bofc`0]L3L00P0_LSN0<[B
i@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3m
oOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0fm_M0=_Kf`2EU900RXMn09ZD
QP2YXXl0_;BM0<JoY@P0bL6Z1038`:T80<W1ZP@0b/:[2@3:`Zd;0<_3[PP0
c<B_203=aK040<k6/@@0cLJc203>ak@40<o8]@030<k7]03?b;D0clRe00H0
clRe203@bKH;0=7:]`P0d/^h103Cc;T80=C=^`@0dlbj103DcK/P0=G>_00A
0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0EEIH059KO01KKID0
I7bN06n3]@1hRKl0MHZg07F=_@1eRK/00`1fR[`307N;_@0407R<_P1hSK`0
N8fl07R=_080NHjm1P1jSkh207^@_`<0O9700`1nT;h207nA_`@0P9;01`21
Tl4408>F`@P0Q9O21025V<<0202DXL/0Z;GG0;G1f@2X^<D0<dYB0621R01Z
UIh0K9jY0P1fYjh01P1gZ:l0MZN^07FV[@1eYZd0MZN^07NX[aP0MZN^0100
LjF/07BV[@1dYJ`0MjJ^07VX/P1fY[00M:J_07JX/@20[kD0X<760;_>dP21
SYH0FVMj06=bT@1iRJd0PI6e>02;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE
0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3o
ool0<03oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0gMWJ0=_L
e`2<TI@0MGfB07n:Z02:V;80V:O40:6^f0080:2^d@030:2^d`2Q[m@0X:kA
00<0X:kA00h0W:_<09NVa`2AW[h0SIZj08^H^P27U;@0RYFc08^F/P1GHg/0
Kg^A07^9Y02:V;D0V:O80:2^d@80X:kC00<0WjoA0:2`d@2P[]400`2P[]42
0:6`d@080:2_d02O[/l0Vj_<09VYbP2HYlP0U:?408nN_@2=V[X208bI^@80
R9Ve01`0RIRe08ZJ]02=VkH0TYfi09JQ_@2IYKl0WJS609VTa02NZl/0XJk@
09j]cP2P/=80WjoC09Z/d02HYlP0T9k108ZG^P27U;H0QiBd08jI]@2<V;00
F6Eh07Z5U`2;UZX0VjFn0:^ed02d_m/0/kkJ0P2e`M]00;G0g0080;g8gP3:
d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0
oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=_Kg@3Kfm/0UIB@08Z7OP2J
U8H0ZJ:?0;bdW@36_jD80<W1ZP@0b<2Y2039`JX40<[2Z`P0b/:]1P3;`jh2
0<c4[`@0bl>^203<a:l80<g5/0@0c/Ja103=a[<80<k7]0X0clRe203@bKH8
0=7:]`80d/^h103Ab[L80=;;^0@0dlbi203DcK/40=?<^P@0e<fk803Ec[`0
403DcK/0e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05EFF01BFg`0FffE
06AlWP1_PkD0N8Vo07F:]`1eSKd407J:_080Mh^m0P1hS;h207R=_0<0NHjm
1@1jSkh307^@_`<0O9700P1nT;h307nA_`<0P9;01P21Tl4208:D`P@0PiK1
1`24Ul8508FH``0809>PbP2V/mD0]<3H0:fmc00_ATh0HX>:06JAV01`X:X2
07JW[P0607NX[`1fYjh0MJJ]07FV[@1fYjh0MjR_601fYjh0401eYjh0MZR_
07FV[@1eYZd0MjR_07FU[`1dY:h0MjVb08^f_@2Wa/T0`=?G07>0R@1OK7l0
IGJD07>3Y`26U[Xh08^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:
g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0`0?oo
o`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3MfMX0fmcG08bAU01e
OI80OhZX08ZH/P2HYl@0XJkH00P0X:kA00<0X:kC0:6_e02P[]400`2P[]40
3P2LZl`0UjK7096N_P2=V[X0RiRj08ND]02:UK<0RiJb05MSN`1_Ni40NhVT
08ZH]@2HYlP0X:kA0P2P[]<00`2O[m40X;3A0:2^d@030:2^d@0>0:6`d@2P
[m00Wjk?09j]cP2HZ<T0V:O8092O`029V;L0RiZi08jK^`2;V;P0RINd08RH
/P29VK<208bJ]@0J08>?Z@1aOIL0IFn:065[QP1NJHD0KGRD082;Z@2HY/<0
X:g=09ZYb02O[/l0W:_<09NVa`2CX<80Sibn08fJ_028UKD0RYFa08RD[01H
IGP0NXFG08^FZP2KYKh0[;KA0;Bof`2c_]X20;G1fd00]L3L00P0_LSN0<[B
i@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3m
oOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0fm_M0=_Kf`2EU900RXMn09ZD
QP2YXXl0_;BM0<JoY@P0bL6Z0`38`:T80<W1ZPD0b/:[203:`Zd50<_3[P<0
c<B_0`3;`jh80<c4[`P0cLF`1@3>a[430<g6/`P0c/Nd2P3?b;D80=39]PP0
dLZg0`3BbkP30=7:]`P0d/^h1@3Cc;T80=C=^`<0dlbj1@3DcK/P0=G>_00@
0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0EEIH059KO01LKYH0
I7bN06n3]@1iR/00MHZg07F=_@<0MXZl0`1gRkd207R<_P0407R=_01iS[d0
NHjm07V>_@D0NXnn0`1kT;l407bA`00407j@_P1oTKl0Oi6o07nA_`@0P9;0
1021Tl4408:D`P<0PiK11`24Ul8608FH``0909BSc02Q[m80/;cF0;71d@0e
BE@0IXB>06B?UP1aXJ/0MJJ]00@0MZN^00<0MJJ]07JW[P1fYjh0601fYjh2
07JX[`80MJJ]00`0MZN^07BU[01fYJd0O:^c09Bk`P2]b/h0_<kB06EbN`1O
KX<0JGVJ07B4Z02:V;dh08^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q
0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0`
0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3MfMX0fmcG08bA
U01eOI80OhZX08ZH/P2HYl@0XJkH00P0X:kA00<0X:kC0:6_e02P[]400`2P
[]403P2LZl`0UjK7096N_P2=V[X0RiRj08ND]02:UK<0RiJb05MSN`1_Ni40
NhVT08ZH]@2HYlP0X:kA0P2P[]<00`2O[m40X;3A0:2^d@030:2^d@0:0:2_
d02O[/l0WJc=09b[c02EY<D0U:?408fL^`28UkH0SIZj08^H^080QYBa01`0
SIVc08VE[`1iQIl0I72805aVO`1RK8D0J7:;06MaRP1aNi@0JG>>06I`R`1O
JhD0MH2L09FS_P2JZ<<0Wjg809FR`P2?W;`0S9Vk08bI^@2;U[@0RYJ`08NC
Z`1FHgH0NXFG08^FZP2KYKh0[;KA0P2d_m/20;G1fd00]L3L00P0_LSN0<[B
i@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3m
oOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0fm_M0=_Kf`2EU900RXMn09ZD
QP2YXXl0_;BM0<JoY@P0bL6Z0P38`:T80<W1ZPH0b/:[203:`Zd40<_3[P@0
c<B_0P3;`jh80<c4[`P0cLF`1P3>a[420<g6/`P0c/Nd2P3?b;D80=39]PP0
dLZg103BbkP20=7:]`P0d/^h1P3Cc;T80=C=^`80dlbj1P3DcK/P0=G>_00@
0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0EEIH05=LO@1LKYH0
I7bN06n3]@1iR/00MX^h07F=_@80MXZl0`1gRkd307R<_P<0NHjm0`1jSkh5
07^@_`<0O9700P1mT/4307nA_`<0P9;01@21Tl4508:D`P80PiK11P24Ul85
08FH``<0QYW400X0TjG=09f[d02X]]<0[[gB04MJJ01NO8H0JI6I06nNYP1d
YJ`0MJJ]0`1fYjh00`1eYZd0MZN^07JW[P0H07JW[P0@07BU[01dYZd0LjF/
07BV[@1fYjh0MJBZ07ZW[@24[kH0Vkk40;K?d`2Y^;d0GVYf05e[Q@1/O9h0
O8^b08RF^cP0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bB
T03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300oooo00l0
oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3Kg=L0S96D07EmTP1o
RZP0RYRb09RWa02Q[]P0202P[]400`2P[]<0XJoD0:2^d@030:2^d@0>09b[
c02GY/L0TIjn08fJ^P2;V;X0QiBd08ZE/`2;U[80Ef=k06mkT@1kRJ@0RYRe
09RWb02P[]420:2^d`0309n_d@2P/=40X:kA00<0X:kA02X0X:o@09j]cP2K
Z//0VJS909BSa02>WK`0RiZi08fJ^P2;V;P0QiFb08ZE/`2=V;H0R9>Y06mj
T01MJ7h0HVb506afS`1aN980M7^E07b3W@1iPi`0QHnX07f7X01lQYl0KGN@
05mYPP1lQYl0V:Bl09RV``2@W[/0R9Fe08NB/P26TJl0RIF_08NAZP1DGg<0
NXFG08bGZ`2KYKh0[;KA0;G0g02d_m/20;G1fd00]L3L00P0_LSN0<[Bi@3C
fNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0
nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0fm_M0=_Kf`2EU900RXMn09ZDQP2Y
XXl0_;BM0<JoY@h0bL6Z203:`Z/20<_3[0`0bl>^2P3<a:l80<g5/0P0c/Ja
0P3?ak860<k7]0P0clRe0P3@bKH40<o8]@P0d<Vf203Ab[L:0=;;^0P0dlbi
0P3DcKX>0=C=^b80eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F
0>STf`1EEUP0Deam05a^UP1TO9h0L8Bf07V:`01fRkP0MHfm0`1gRkd307R<
_P80NHfo0P1iS[d307Z?_PD0Ni2o0`1lTL0307fB`@80Oi6o0`20T/03086C
`@D0PYC20`23UL<608BG`PD0QIS31@26VL@02P2?X</0V:O>0:FbdP2X]lh0
HGB504i/M`1/TY/0KIbR07BU[01eYZd307JW[P0307FV[@1fYjh0MZN^01P0
MZN^0100M:B^07FV[@1cYJ`0M:J]07FX[01eY:X0OZV_08fd^`2XaL/0aM[O
08bIX@1LJ7P0GF^606eoX`21T;L0R9Jk>02;W<L0302:VlH0Ric:08^Ma@2G
Z<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool0<03oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0
gMWJ0=_Le`2<TI@0MGfB07n:Z02:V;80V:O40:6^f0080:2^d@030:2^d`2Q
[m@0X:kA00<0X:kA00h0W:_<09NVa`2AW[h0SIZj08^H^P27U;@0RYFc08^F
/P1GHg/0Kg^A07^9Y02:V;D0V:O80:2^d@80X:kC00<0WjoA0:2`d@2P[]40
0`2P[]40402O[/l0WJc=09VXb@2FYLH0TZ7008VH]`2:UkL0RYRe08FC/02;
U[@0SiZh08RC[`1`N8d0IVj506E]Q01`Ni4207R2V`0407j8X`2:U:l0RiN_
08J@Z@80TI^d0180SYRa082:X`1XLX/0L7ZC08jL]P2=VkH0S9Nc08NB/020
RjL0PhfX08>>Y01BGG40NXFG08bGZ`2KYKh0[;KA0;G0g02d_m/20;G1fd00
]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P
0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0fm_M0=_K
f`2EU900RXMn09ZDQP2YXXl0_;BM0<JoY@d0bL6Z203:`Z/30<_3[0/0bl>^
2P3<a:l80<g5/0P0c/Ja0`3?ak850<k7]0P0clRe0`3@bKH30<o8]@P0d<Vf
203Ab[L:0=;;^0P0dlbi0`3DcKX=0=C=^b<0eLjl0100e<fk0=C=^P3Cc[X0
dljj0=SC`03Pf/`0iN7F0>STf`1EEUP0Deam05a^UP1TO9h0L8Bf07V:`01f
RkP0MXjn0P1gRkd307R<_P<0NHfo101jSkh307^@_`D0O9700`1mT/400`1n
Tl80P9;0082B`002082B`0<0PI?11@22U<8408>E``D0Q9O20`25V<<608JI
a080Qi[500X0R9_509BSbP2T/M<0Xk7<07^=X@11GFT0J8jG072MXP1cY:/0
M:F/0`1fYjh207FV[AT0MZN^0100MjJ`07JV/01bYjd0LjR/07FX[01gYj/0
QJjb09Jk`@2id=H0`mGI07AnQ`1KIWP0Hg:?07:4ZP21T;T0RiVn>02;W<L0
302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0oooo
0?knoP80oooo00<0oOgm0?ooo`3oool0<03oool03`3moOd0n?Sh0?7al@3Y
jNT0h^;R0=gMg@3Kfm/0gMWJ0=_Le`2<TI@0MGfB07n:Z02:V;80V:O40:6^
f0080:2^d@030:2^d`2Q[m@0X:kA00<0X:kA00h0W:_<09NVa`2AW[h0SIZj
08^H^P27U;@0RYFc08^F/P1GHg/0Kg^A07^9Y02:V;D0V:O80:2^d@80X:kC
00<0WjoA0:2`d@2P[]400`2P[]40;02O[/l0Vj[;09NVa`2DXl@0SY^k08^H
^02;VKH0QiFb08NB/02?V[P0Qi:^06ehU01HHgT0JGB:07J1U`1hPY/0OHVS
08^F/P2FXKd0V:>o09NU`02P[/T0Tj6l09>N^P2HY;h0UZ2k08jH/`1dOYL0
KGVA07F1V`22SJT0Qi:^086:Y`1mQj80OHRN059ML@1jQIL0S9N[09bV_`2/
]]40]L3L0;Bof`2e`M/0]/;L@02e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G
0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03Kfmd0fm_K09FDT02:Qgh0VYB60:VRS`2l]9d0a[nU
3039`JX80<[2Z`@0bl>/2P3;`jh:0<c4[`P0cLF`203>a[440<o7/P@0c/Nd
203?b;D40=39]P80clRe203@bKH80=7:]`X0d/^h203Cc;T40=C=^P`0e<fk
903Ec[`0403DcK/0e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05IGF@1C
G7d0G6jF06AlWP1`Q;H0NH[007J;^01fS[h207N;_@80N8bn101iSKl307Z?
_P<0Ni2o1@1lTL0307fB`@80OY?20`20T/03086C`@@0PYC21P23UL<408BG
`P@0QIS31@26VL@408NJa@0908jPb02MZlh0WZc908nQ]`12GV`0GXF<06nL
X@1bXjX0M:F/00<0MZN^0P1eYZdI07JW[P0@07RW/@1fY[00LZN]07:Y[01f
ZJ`0OJZ]08nf^`2Val`0aMSN09n//P1SK7D0HVYm06YiV01hR[80PYBl08fK
`SP0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03hn?P0
o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300oooo00l0oOgm0?Sh
n03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3Kg=L0S96D07EmTP1oRZP0RYRb
09RWa02Q[]P0202P[]400`2P[]<0XJoD0:2^d@030:2^d@0>09b[c02GY/L0
TIjn08fJ^P2;V;X0QiBd08ZE/`2;U[80Ef=k06mkT@1kRJ@0RYRe09RWb02P
[]420:2^d`0309n_d@2P/=40X:kA0080XJoB02/0X:kA09j]cP2JZLX0UJC5
09:Q`P2;V;P0SI^h08ZH]@2:UK<0SIRf08ZE/@1eP9`0GFJ3071kT@1^N940
M82H08B@ZP2BX;/0W:[70:2_c02T/m80Xk;C09n^c`2V]M@0Y;7A09n]bP2O
Z/P0U9nk09:M^@1[Mhd0Hfn706McS@1iPih0OHNR07^5WP1jQI/0DUY_07^6
V02<Uj/0W:Jo0:bfd@2e`=`0];oK0080]/;L@02e`=`0202mb=h0b];U0=?I
i`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3i
nOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03Kfmd0fm_K09FDT02:Qgh0VYB60:VR
S`2l]9d0a[nU3039`JX80<[2Z`@0bl>/203;`jh70<c4[`030<g5/03<a:l0
c<B_0080c<B_203=aK080<k6/@@0clNb103>ak@80<o8]@/0d<Vf203Ab[L8
0=;;^0030=?<^@3BbkP0d/^h0080d/^h203Cc;T40=C=^P`0e<fk903Ec[`0
4@3DcK/0e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05IGF@1CG7d0G6jF
06EmW`1`Q;H0NH[007J;^01fS[h0Mh^m00<0N8bn0`1iSKl0101jS/00NXnn
07Z?_P1jSkh207^@_`H0O9700P1mT/4307jC`P<0P9;00P21Tl4308:D`PL0
PiG300<0Q9K408BG`P24Ul800P24Ul8408FH``@0QYW41027V/D02`28WLP0
Rig509FSb02KZ<P0VZc404YVM01GO8@0KIVL07:SZP1dYJ`0MJJ]0080MZN^
0P1eYZdI07JW[P0@07VU/01eYJl0LJJ/076XZ`1gZZd0PJja09Rn`@2bdmP0
amWM07F0QP1JHf`0JG6606elW@1kS[H0RI_308jJ`SP0Ric700`0RY_608^L
bP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo0300oooo00l0oOgm0?Shn03alO40jNWY0>;RhP3M
gMd0fm_K0=gIfP3Kg=L0S96D07EmTP1oRZP0RYRb09RWa02Q[]P0202P[]40
0`2P[]<0XJoD0:2^d@030:2^d@0>09b[c02GY/L0TIjn08fJ^P2;V;X0QiBd
08ZE/`2;U[80Ef=k06mkT@1kRJ@0RYRe09RWb02P[]420:2^d`0309n_d@2P
/=40X:kA0080XJoB00D0X:kA09j]cP2JZLX0UJC5096P`@0208bJ]`0T08BB
[`28Tk40T9^g086<Z01[M940IVn<06ahT01gPi/0R9B^09JT_`2O[//0Y;?B
0:Bed`2T]=D0Y;KJ0:Fef@2T]=H0YKCE0:Bad`2T/M40Xjk>09FP_P2DX;H0
JWJ<059NMP1RK8L0M7jI07R2V`1jPYT0DEU^07^6V02<Uj/0W:Jo0:bfd@2e
`=`0];oK0P2f`]a00;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?oo
o`3no_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03N
g]h0g=cL0=[IgP3Kfm/0UYF@08^9O@2KUHD0ZZ>@0;feX036_ZT80<S0Z@@0
bL6Z103:`Z/90<[2[@P0bl>^203<a:l;0<g5/0@0c/Ja103=a[<80<k7]0P0
clRe103@bKH00`3?b;D0d<Vf0=39]P060=39]P/0dLZg203BbkP40=?<^@P0
e<fk103Cc;X40=C=^bP0eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0
iN7F0>STf`1DF5T0E5en05a_U`1UOIl0LHJe07b<`01hSKP0N8jm0`1hSK`2
07V>_@<0NXnn00<0O8jn07f?_`1mSkl01@1mSkl0101nT;h0Oi6o07nA_`1o
TKl3082B`003086C`@20T/00PI?100H0PI?11023U/4408BG`P@0QIS31026
VL@00`27V<@0R9W508RIa@0508RIa@0@08JG`P2;W<P0T:7?08fNbP2AXlL0
N8bU04EKJ@1[PXX0JYnU07:W[`1fZk<0Kj>^07FW/01gYk40MZF]07VV[1P0
MZN^0100M:BX07NX[@1eZ[80M:Rc07VX/P2H_LD0ZlC90<oQh`2PZ;D0Gf]k
05ETN@1ZNiD0LhJV082D^@29Vl<0S9k6>02;W<L0302:VlH0Ric:08^Ma@2G
Z<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool0<03oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0
gMWJ0=_Le`2<TI@0MGfB07n:Z02:V;80V:O40:6^f0090:2^d@030:6_dP2P
[]40X:kA0080X:kA00h0W:[=09NUb02AW[h0SIZj08^H^P27U;@0RYFc08^F
/P1GHg/0L7bB07^9Y02:V;D0V:O80:2^d@80X:kC03<0WjoA0:2`d@2O[m40
WjoA0:2^d@2O[M00W:_<09NVa`2BWl40SY^m08fJ^P26Tk<0RiJd08VD/02=
VK<0JgN?065/PP1^NHl0KG^E08:@Z`2EXl00Wjg:0:Bad`2V/mD0Y[?F0:Rd
fP2W]=@0ZKKF0:Zge`2Y]]H0Z;KC0:NedP2S/Lh0WZc909>N^P26TZ`0Mh6J
06=[P01BFf`0DEQX05INJ`0k@Dd0NhJH08bGZ`2LY[l0[KOB0;O2gP2f`Md0
]/;L0;G1f@2e`=`00`2f`Md01@2e`=`0];oK0;Bof`2d_m/0//3K0080]L?N
0P2c`M`20;C2g@040;;0f`2f`Md0]/7M0;K1g@<0]L3L00<0]/7M0;O2gP2d
`]d00P2d`]d30;?1g0<0]<;M0P2e`mh01@2d`]d0/l7L0;?1g02d`]d0]L?N
01P0]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo
000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN
0=_Kf`2FUI00RhUm09^EQ@2ZXi00_KFP0<JnZ@`0bL6Z103:`Z/80<[2[@H0
bl>^203<a:l80<g5/080c/Ja103=aK040<k6/@@0cLJc203>ak@80<o8]@X0
d<Vf203Ab[L20=;;^0@0dLZg203BbkP40=?<^@P0e<fk103Cc;X40=C=^bP0
eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1DF5T0E5en
05a_U`1UOIl0LHJe07b<`01hSKP0N8jm0P1hSK`307V>_@<0NXnn1P1mSkl2
07j@`0@0Oi6o0P20T/08086C`@80PYC21023U/4408BG`P@0QIS31026VL@6
08RIa@80RI[60100RI[508VJaP2;W<P0SYo;08nQa`2:WK/0HgR=05I/NP1_
W:80KijV07NY/01dZK40LjR`07RZ/@1bXJT0NZJ_601fYjh0401fYj`0MJN^
072U[@1hZ[<0RKBk09Zk`P35f]d0/l?3079kRP1JIGL0HG2706n0WP1kSZl0
RIg208^Ma@29V/Dh08^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:
g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0`0?oo
o`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3MfMX0fmcG08bAU01e
OI80OhZX08ZH/P2HYl@0XJkH00T0X:kA00<0XJoB0:2^d@2P[]400P2P[]40
3P2LZ/d0UjG8096N_P2=V[X0RiRj08ND]02:UK<0RiJb05MSN`1`O980NhVT
08ZH]@2HYlP0X:kA0P2P[]<07P2O[m40X;3A09n_d@2O[m40X:kA09n]d02L
Zl`0UjK709:O`@2>Vkd0RiRh08VF]P2:UK<0RiJb08B@ZP1SKhL0IG26075l
TP1kRJ@0SYbg09j/b@2T/M40YkCD0:NdeP2V/mH0YkCG0:Ree@2Y]]H0Z[OG
0:VfeP80ZKOD0180Y[CA0::`c@2IY<00SYZd08J@Z@1hPiL0K7B706Q_O`1S
JgP0?DEB07^6V02<Uj/0W:Jo0:fgdP2g`]h0]/7M0;K2g02e`MT20;G0g003
0;K1g@2e`=`0]L3L00<0]L3L00<0/KoJ0;?1g02d`]d00P2b`=/20;?1g003
0;6ofP2d_m/0];oK00@0];oK0P2e`=`80;;0f`@0/l7L0P2b`=/00`2c`M`0
]<;M0;G0g0020;G0g0030;Bof`2e`=`0]L3L0180]L3L00P0_LSN0<[Bi@3C
fNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0
nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=_Kf`2FUI00RhUm09^EQ@2Z
Xi00_KFP0<JnZ@/0bL6Z1@3:`Z/80<[2[@D0bl>^203<a:l80<g5/0<0c/Ja
0`3=aK050<k6/@<0cLJc203>ak@80<o8]@X0d<Vf203Ab[L30=;;^0<0dLZg
203BbkP50=?<^@P0e<fk0`3Cc;X50=C=^bP0eLjl0140e<fk0=C=^P3Cc[X0
dljj0=SC`03Pf/`0iN7F0>STf`1DF5T0E5en05a_U`1VOZ00LHJe07b<`01h
SKP0N8jm07R=_00307V>_@@0NXnn101mSkl407j@`0<0Oi6o0`20T/06086C
`@@0PYC20`23U/4508BG`P<0QIS31@26VL@508RIa@<0RI[60100RI_308^L
a`2:VlL0S9g908JG`P2<W/80P9>a05mcS01ALW/0MYbU07:QY`1fZjl0KJBY
07:W[@1jZk80MZ:]601fYjh03`1cZ:h0M:V_07>U[022/KL0Vl360;??dP3>
h>80TYfO05QSM`1NJX80JgZG07>3Y@20T[P0S9o908VJa@0i08^La`0<08ZK
aP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn
0P3oool00`3moOd0oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3R
h^80gMgM0=_Kf`3MfMX0fmcG08bAU01eOI80OhZX08ZH/P2HYl@0XJkH00T0
X:kA00<0XJoB0:2^d@2P[]400P2P[]403P2LZ/d0UjG809:O_`2=V[X0RiRj
08ND]02:UK<0RiJb05MSN`1`O980NhVT08ZH]@2HYlP0X:kA0P2P[]<0602O
[m40X;3A09n_d@2O[m40X:kA09n]d02LZl`0UjK709:O`@2>Vkd0RIJf08^H
^02:UK<0S9Nc07N3W@1MJH40K7N=07N2V02:V;<0VZS30:Fcd02W]=@0Z;GE
0:Ree`80YkCG01@0Z;GE0:Zge`2Z]mL0Z[OG0:Zhe@2[^MH0ZKOD0:Jdd@2Q
[<P0UZ:l08fG/025T:H0OXJI07Z3U01dNh/0AdmL07^6V02=V:`0W:Jo0:fg
dP80]/7M00<0]/;L0;G1f@2e`=`0102e`=`20;K1g@80]L3L102f`Md00`2g
`]h0]/7M0;G0g0050;G0g0<0]/7M2@2e`=`20;K1g@<0]L3L00<0]/7M0;O2
gP2e`=`00P2e`=`20;Bof`80]L3L00<0]/7M0;G0g02e`=`03P2e`=`0202m
b=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100
o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0fm_K09JET02;
RGd0ViF50:ZST02m]J00a[jY2P39`JX60<[2Z`P0b/:]103;`jh80<c4[`P0
cLF`103>a[420<g5/0H0c/Ja0P3=a[<80<k7]0P0clRe2P3@bKH80=7:]`@0
d/^h0P3Ab[L80=;;^0H0dlbi203DcK/20=?<^PH0e<fk:03Ec[`0403DcK/0
e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05EIFP1DGGh0G6nG06InX01b
QkH0O8c007R=^01iSkh307V>_@<0NXnn0P1kT;l307f?_`D0OY300P1oTKl3
082B`0H0PI?11@22U<8208>F`@H0Q9O20P25V<<608JIa0@0R9W51029V/H0
4027VL40S9g808RIa@2:VlL0QYO308JG`P29Vl40Nhfa05U/N`1ELGd0N:6W
06jQY01cZZd0LJR]07RZ/`1dXjdH07JW[P0@076X[`1fZk40Nj^_08jg^@2U
a<H0b=gP0::`/`1XLW@0GVR306EcT01bPJ80NH^a08BG`@2:WLP0QiS408jO
bcP0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03hn?P0
o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300oooo00l0oOgm0?Sh
n03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3Kg=L0S96D07EmTP1oRZP0RYRb
09RWa02Q[]P02@2P[]400`2Q[m80X:kA0:2^d@020:2^d@0>09bZc@2GYLP0
TYno08jK^`2<VK/0R9Fe08ZE/`2;U[80Ef=k06mkT@1kRJ@0RYRe09RWb02P
[]420:2^d`0K09n_d@2P/=40WjoA09n_d@2P[]40Wjg@09b[c02GY/L0TYo1
08jK_@2:UkL0RIJf08^F]02;U[80JGF?05m[P`1bOI<0P8^Q09:P_@2O[LX0
YkGB0:Nde02X]MD0Z;GG0:NdeP2X]ML0ZKKF00<0Z[OG01@0ZkWF0:bje`2Z
^=D0Z;KC0::`b`2IYKl0Si^c08^F[027Sj@0QXjQ08:9V`1BFF/0O8NI08fH
[02LY[l0[KOB0;K1g@2e`=`0]/;L0;G1f@@0]L3L0P2f`Md20;G0g080]/;L
0P2e`M/00`2f`]`0]l?M0;K2g0050;G1f`@0]/;L102e`M/20;K2g0030;G1
f`2d`=X0]L7K0080]L7K00<0]/;L0;G1f`2f`]`00P2f`]`20;K1g@80]L3L
00@0];oK0;G0g02e`=`0]/7M402e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G
0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03JfMh0fm_K09JET02;RGd0ViF50:ZST02m]J00a[jY
2039`JX60<[2Z`80bl>/303;`jh80<c4[`P0cLF`2P3>a[420<o7/PH0c/Nd
203?b;D80=39]P80dLZg103@bKH80=7:]`X0d/^h203Cc;T20=C=^Ph0e<fk
:P3Ec[`0403DcK/0e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05EIFP1D
GGh0GG2H06InX01bQkH0O8c007R=^01iSkh207V>_@<0NXnn0`1kT;l507j@
`0<0Oi710`20T/03086C`@L0PYC20`23UL<608BG`P80QIS31P26VL@208NJ
a@@0R9W51029V/H04029Vl<0QYO208NH``2:VlL0SYo;08VJaP26Ul80QIK1
08FAZ@1CJ7/0DG5l07:OY01eZ:/0MJZ^07:T[@1gYk<H07JW[P0@072W[P1g
ZZh0Q[:e09bn_`2le=H0_<kB075kQ01IHF`0HVf;06UfV01jRZh0Q9Jn08VL
aP2;W/T0RY_708jLbCP0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40
`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300
oooo00l0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3Kg=L0S96D
07EmTP1oRZP0RYRb09RWa02Q[]P02@2P[]400`2Q[m80X:kA0:2^d@020:2^
d@0>09bZc@2GYLP0Tj3008jK^`2<VK/0R9Fe08ZE/`2;U[80Ef=k06mkT@1k
RJ@0RYRe09RWb02P[]420:2^d`0G09n_d@2P/=40WjoA09n_d@2P[]40Wjg@
09b[c02GY/L0TYo108jK_@2<VKT0QY>c08bG]@29U;00H6b606UeS@1gPYP0
RIBZ09NU`P2R[ll0YkCD0:Jcd`2W]=@00P2X]MD06P2Z]mT0Z[OG0:^hf02[
^=P0Z[OG0:Zhe@2[^MH0Z[SE0:NedP2Q[lX0VZS209JR_02EXKT0TIbb096I
[P2>UZT0G6=f07b7V@2=V:`0W:Jo0:fgdP2f`Md0]L3L0;K2g02e`MT0]/7M
0`2e`=`20;K1g@040;Bof`2c_]X0/koI0;6me`80/;cF00@0/KgG0;:nf02b
_]P0/[kH2@2c_mT00`2b_]P0/KgG0;:nf0020;>of@030;:nf02a_ML0/KgG
0080/[kH00D0/koI0;C0fP2d`=X0/koI0;:nf0030;BofaD0]L3L00P0_LSN
0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?kn
oP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3Lg=`0f]WN0=_Kf`2FUI00RhUm
09^EQ@2ZXi00_KFP0<JnZ@P0bL6Z1@3:`Z/30<_3[0/0bl>^203<a:l80<g5
/0X0c/Ja0`3?ak850<k7]0P0clRe203@bKH30=7:]`<0d<Vf203Ab[L:0=;;
^0P0dlbi0`3DcKX=0=C=^b/0eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03P
f/`0iN7F0>STf`1EFEX0EEio05e`V01VOZ00LXNf07b<`01hSKP0NHnn101j
Skh307^@_`0307bA`01nT<00OY300080OY30101oTL42082B`0<0PI?11`22
U<8408>E``D0Q9O20`25V<<508JIa0<0Qi[50`28VLD508VJaP0308^La`25
U/40SIk90080RY_600/0RI[508RIa026Ul80S9Vk08>D/012Ffl0EW^406jI
W`1bXjP0LjF/07BY/@0H07JW[P0@076V[P1jZJl0T[Ri0:c8b@3;gMl0UZ>[
05mXM`1TK840I76C07:0X`23UK/0RIc408NJa02;W<L0SIk908^JaCP0Ric7
00`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03hn?P0o_kn0?oo
o`3no_h20?ooo`030?gmo@3oool0oooo0300oooo00l0oOgm0?Shn03alO40
jNWY0>;RhP3MgMd0fm_K0=gIfP3Kg=L0S96D07EmTP1oRZP0RYRb09RWa02Q
[]P02@2P[]400`2Q[m80X:kA0:2^d@020:2^d@0>09bZc@2GYLP0Tj3008jK
^`2<VK/0R9Fe08ZE/`2;U[80Ef=k06mkT@1kRJ@0RYRe09RWb02P[]420:2^
d`0G09n_d@2P/=40WjoA09n_d@2P[]40Wjg@09b[c02GY/L0TYo108jK_@2=
V[X0QY>c08bG]@29U;00FVJ0075mU@1lQid0SYV_09bYb@2V/m<0ZKKF0:Nd
e02X]MD00P2Y]]H20:Zge`80ZkSH0140Z[OG0:Zhe@2[^MH0Z[SE0:NedP2R
/</0WJ_509ZV`02KYkl0UZ2i09FP]P2GWkH0Hf^007f8VP2>VJd0W:Jo0:bf
d@020;G0g0030;K2g02e`MT0]/7M00<0]L3L00P0]/7M0;G0g02b_MT0[k[F
0;6keP2]]m80Z[C?0:^ed080[;KA0P2]]m801P2`_=H0/KgG0;6me`2a_ML0
[k_E0:jje080[k_E01H0/[cG0;2je@2^^=<0[kWD0;2je@2a^mH0/;[E0:ni
e02^^=<0[kWD0;2je@2b_=L0/kgH0;:le`2a^mH0[kWD0:fhe02_^]H0/KcH
0;Bof`2e`=`0]/7M4P2e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3o
ool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0
g]kN0=cLg03JfMh0fm_K09JET02;RGd0ViF50:ZST02m]J00a[jY2039`JX4
0<[2Z`@0bl>/2P3;`jh80<c4[`P0cLF`2P3>a[440<o7/P@0c/Nd203?b;D8
0=39]P@0dLZg0P3@bKH80=7:]`X0d/^h203Cc;T40=C=^P`0e<fk;03Ec[`0
403DcK/0e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05EIFP1EGWl0GG2H
06InX01bQkH0OHg107V>^@1iSkh307Z?_P<0Ni2o0P1lTL0207j@`0H0Oi71
0P20T/02086C`@H0PYC21P23UL<408BG`P@0QIS31026VL@408NJa@80R9W5
1P29V/H0102;W<P0RI[5092Qc028V/8208NI`@0:08^Ma@2:W<@0QiK108fM
`@1lT:/0>UAU06F7T@1aW:<0Kj6X07:Y/1P0MZN^0100N:Rb08Ja]`2Q`<80
^m3A0;2m``1YLX40FFAj06A_S@1_OYl0OXj`08RJ`028Vl<0QYW308ZKaP2?
W/L0SIc3>02;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@
0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<03oool03`3m
oOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0gMWJ0=_Le`2<TI@0MGfB07n:
Z02:V;80V:O40:6^f0090:2^d@030:6_dP2P[]40X:kA0080X:kA00h0W:[=
09NUb02CX<00Sibl08fJ_028UKD0RiJd08^F/P1GHg/0Kg^A07^9Y02:V;D0
V:O80:2^d@80X:kC02h0WjoA0:2`d@2O[m40WjoA0:2^d@2O[M00W:_<09NV
a`2BWl40SY^m08ZG]`2;V;P0RYFc08ZE/@1HI7h0LgnG082;X@2@Vk40Wjc>
0:Nde02Z]mL0YkCD0:VfeP2Z]mL0ZKKF0:Vge02Z]mL0ZkSH0:bif@2[^=P0
[;[G0:fkf02[^MH0Z;KC0:Bbc@2N[<H0UZBn09RT_P2DW[L0UInh09ZR^@1U
KH@0OHRJ08jI[@2LY[l0[;KA0P2e`=`00`2f`]`0]L7I0;K1g@020;G0g080
]/7M00D0];oK0:njeP2/]m<0Z;;;0:>]aP0209nY`P0>0:2Z``2QZl@0XZc5
0:>]aP2X]<`0Z[K>0:^gc`2Z]/h0Yk?;0:Fab@2V//X0Yk?;0:^ecP2X///2
0:J`b@0B0:NabP2Y/l`0ZK?<0:Rbb`2U[lP0Y[390:Rbb`2[]Lh0[;K?0:^e
cP2X///0Y[390:B_b`2W//h0[;OC0;6lf02e`=`0]/7M4P2e`=`0202mb=h0
b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn
0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03JfMh0fm_K09JET02;RGd0
ViF50:ZST02m]J00a[jY303:`Z/40<_3[0P0bl>^1`3<a:l80<g5/0P0c/Ja
00<0clNb0<k6/@3>a[400P3>a[440<o7/P@0c/Nd203?b;D80=39]P/0dLZg
203BbkP00`3Cc;T0d/^h0=;;^0020=;;^0P0dlbi103DcKX<0=C=^b`0eLjl
0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1EFEX0EEio05e`
V01VOZ00LXNf07f=`@1iS[T0NHnn0`1jSkh207^@_`<0O9701`1oTL400`20
T/80P9;0086C`@02086C`@<0PYC22023UL<00`24U/@0Q9O208BG`P0208BG
`P@0QIS31026VL@408NJa@L0RI[60`2:VlL00`29Vl<0QINm092Rb00208^M
``0908VK`@2=Wll0QiS308bL_@1ZOi@0CVYf07FLX`1ZWJ40K:JZ01P0MZN^
0100NjZb09>j_`2/b</0amWK08fHWP1KI7D0H6^706UfV@1hR:X0Q9Bf08NI
_`2:WLD0SJ3808bNaP2=W<<0Sio3>02;W<L0302:VlH0Ric:08^Ma@2GZ<H0
Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool0<03oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0gMWJ
0=_Le`2<TI@0MGfB07n:Z02:V;80V:O40:6^f0090:2^d@030:6_dP2P[]40
X:kA0080X:kA00h0W:[=09NUb02DXL40Sibl08fJ_029U[H0RiJd08^F/P1G
Hg/0Kg^A07^9Y02:V;D0V:O80:2^d@80X:kC01P0WjoA0:2`d@2O[m40WjoA
0:2^d@2O[M00W:_<09NVa`2BWl40SY^m08ND]02?W;`0R9>a08bG/`1GHgd0
LWjF08:=X`2@Vk40WZ_=0:NdeP2Y]]H0YkCD0:Ree@2Z]mL20:Vge00D0:Zg
e`2[^=P0[;WI0:bif@2]^mP0[[cI0:bje`2Y]m@0X[;<09f[a@2FY;h0VZK0
09JR_02GXKX0VZ6k065XPP1nRI/0SYV]09bV_`2/]]420;G0g0050;G1f`2e
`MT0]/7M0;K1g@2e`=`00P2f`Md01@2c_]X0[[WE0:Zed@2MYl00Uj6j0080
TYbe0140Tiff09BN]`2EWkP0Uj6j09fY`@2OZl<0XJg50:2/a02LZ<00VJFm
09ZV_P2LZ<00X:[309fW`02KYKh0VZBm09bV_`0209jX`@0?09fW`02IXk`0
VjFn09fW`02PZ/<0XZc50:6[a02MYl00VZBm09fXa02R[LT0Z;??0:njeP2d
_m/0]/7M0180]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo0?kn
o180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kNgP3L
g=`0f][J0=[Jf02EU8l0RXMn09ZDQP2ZXi40_[JQ0<NoZ0@0bL6Z103:`Z/0
0`39`J`0b/:]0<[2[@060<[2[@P0bl>^203<a:l80<g5/0L0c/Ja103=a[<8
0<k7]0P0clRe203@bKH40=7:]`030=39]P3Ab[L0dLZg00D0dLZg203BbkP8
0=;;^A00e<fk<03Ec[`0403DcK/0e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0
j>CK05=GEP1GH840GW2H06QoX@1fR;P0OXk207jA_01iT;`407f?_`@0OY30
101oTKl4082B`0@0PI?11022U<800`23U/40Q9O208BG`P0508BG`P@0QIS3
1026VL@00`27V<@0R9W508RIa@0508RIa@@0RI[5202:VlH408^La`0:08ZM
a@2>XLT0S:3508nO`@1AH7d0GGB607:KX@1YX9d0MJB/07JU[@@0MJJ]00<0
M:J]07FW[P1fYjh01`1fYjh0501gYZh0MJJ]07FW[P1cZ:h0LZN[076VZP1d
Yj/0MjR]07n`]02L`<00`=;B0;_4b@1TKGh0G6Z405e/R`1eQ:<0PI:m08FF
`@29V/D0S9g80`2;W<L00`2<WLP0Ric708^La`0f08^La`0<08ZKaP2;W<X0
Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM
0=_Kf`3MfMX0fmcG08bAU01eOI80OhZX08ZH/P2HYl@0XJkH00T0X:kA0`2Q
[m805@2P[]40Wjg@09f[cP2LZ/d0UjC4092M_`2=V[`0SIZj08ZE/`2:U[00
F6Aj079oTP1lS:D0RIVc09NVa@2Q[m80WZkB09f]d@2S/mL0WJg?0:2_d002
0:6`c`0>09j]c02M[</0VZW609>R_`2;V[L0R9Nh08VF]P2=V;H0SYNd061Z
Q@1_NI@0PXjX08jL]P2P[Ld20:VfeP030:Zge`2[^=P0ZKKF0080ZkSH00X0
Z[OG0:bif@2/^]L0ZkWF0:bje`2]^mP0[;[E0:VgdP2V//X0XJg70P2KY<40
2P2FX;/0V::k09ZR]`1RJWd0OHRJ08jI[@2LY[l0[KOB0;K1g@2e`=`20;G1
f`030;G0g02d_m/0];oK0080]/7M02/0/KcH0:Zed@2S[/X0Wj?608nDZP2P
Y:d0ZJbc09>EXP27RJ00RHfV096G[@2CUZD0V9nY09fV]`2@VKP0TIZi096J
Z`2HWjT0V9^Z09BT/`2BW[@0SYRc09JN]@2a^/T0TifY09FP]02EW[/0TYV[
09:IZ@2DWJ`0V:2c09bS_`2@VKH0TIbb08fIY`2EVJD0YJZn0:2Wa02b_M/0
/;kH0;C3f02^_M@0^LGO0100]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3n
o_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0
i>CT0=kNgP3Lg=`0f][J0=[Jf02EU8l0RXMn09ZDQP2ZXi40_[JQ0<NoZ0@0
bL6Z103:`Z/60<[2[@P0bl>^203<a:l80<g5/0P0c/Ja0P3?ak840<g6/`P0
c/Nd203?b;D80=39]PX0dLZg2P3BbkP80=?<^Q00e<fk<03Ec[`0403DcK/0
e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05=GEP1GH840GW2H06V0XP1f
R;P0OXk207jA_01jTKd307f?_`D0OY300`1oTKl5082B`0<0PI?11@22U<86
08BG`PH0QIS31026VL@608RIa@80RI[61029V/D808ZKaP@0Ric700/0S9k6
08bOa`2@Y<T0TZ;407Z9YP16GFl0Ji:I06^OW@1dXj/0MJB/07FV[@0207JW
[P0307FV[@1dYZd0M:J]00P0MZN^01D0MjJ^07FV[@1eYjh0LjR^07:WZ`1a
YZX0MJR/07VZ[`28^;`0XlG60<GGe`2CW:<0GfQi05i/Q`1XMiH0NHRW08BE
`027V<<0RY_608bMb02;W<L00P2:VlHi08^La`0<08ZKaP2;W<X0Rig509NX
aP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0
oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3M
fMX0fmcG08bAU01eOI80OhZX08ZH/P2HYl@0XJkH00X0X:kA0P2Q[m809@2P
[]40Wjg@09j/c`2MZlh0V:O609:O`@2@WKl0RYNg08VG]02>V[@0EV9h079o
TP21SjX0RIRe09BSa02MZlh0X[3E09n_d`2N[]80XK7C0:2^d@2Q[m80X:o@
09n^c`2LZlX0UjK5092O_P2:VKH0SY^k08fH]02?VK80Vj>j06Q`Q@1aNI00
R9:[096M]`2P[Ld00P2Y]]H00`2Z]mL0ZkSH0:VfeP020:^hf00:0:Zge`2/
^MT0[;[G0:^ieP2/^]L0[K_H0:bje@2Y]m80Y[;:0:6]a`80VjC100X0UZ2k
09RR^`2JX[L0HVYm07f8VP2>VJd0W:Jo0:fgdP2f`Md0]L3L0P2e`M/0<02e
`=`0];oK0;Bof`2e`=`0]/7M0;:mf@2[]]80Y[7=09NL^@30amT0mO[n0?_o
o`3`lo`0YJRg09FJ[@3go_l0m?Ko0:2UZ`23RiP0SYFa08J=Z@2X/;d0mO[o
0?Oio`2BWk00SiZ`08jF[@2naML0kOKo0;>kaP2CVjh0TIRe09nV^@3eoOl0
l__o09BLZ@27SZ40T9R_08VAY02V[kh0nooo0>S^oP2a^=@0[KSD0;6of@2g
a]/0]<?J0;K1gA00]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo
0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kN
gP3Lg=`0f][J0=[Jf02EU8l0RXMn09ZDQP2ZXi40_[JQ0<NoZ0<0bL6Z1@3:
`Z/50<[2[@P0bl>^203<a:l80<g5/0P0c/Ja0`3?ak830<g6/`P0c/Nd203?
b;D80=39]PX0dLZg2`3BbkP80=?<^Q00e<fk<03Ec[`0403DcK/0e<fj0=?>
^P3Cc[X0f=?00>3Jc03UhMH0j>CK05AHE`1GH840GW2H06V0XP1fR;P0OXk2
07nB_@1jTKd207f?_`H0OY300P1oTKl6082B`080PI?11P22U<8508BG`PH0
QIS31@26VL@508RIa@<0RI[60`29V/D808ZKaPD0Ric700X0S9k608^NaP2C
Yl`0UjO909f[b01=HWD0EgV206^KV`1bXJT0M:>[0`1fYjh00`1eYZd0M:J]
07BV[@0807JW[P0E07JU[@1eYZd0M:J]07>X[P1cZ:`0LjJZ07NX[@1m[;80
U<330:c;c@2ncM00JG9k05eXO01RL8d0LX:S086@/@27V<<0RI[508^La`2<
WLP0Ric70080RY_6>@2;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33
b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<03o
ool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0gMWJ0=_Le`2<TI@0
MGfB07n:Z02:V;80V:O40:6^f00;0:2^d@0C0:6_dP2P[]40X:kA09n]d02N
[<l0Vj[909BSa02EX/@0RiRj08fJ^P2<V[D0F6Al07J2V01lRZL0S9Vi09^Y
c02O[M80WjgD0:2^e@0209n_d`80WZkB0P2N[]003@2LZl`0UZG6096P_`2>
WK`0Tibi09JP^@2MY;H0YZjk07MoS01jPI<0PHVP09BM^P2P[Ld00P2Y]]H0
0`2Z]mL0ZkSH0:VfeP030:^hf00E0:bif@2/^]L0[;[G0:fkf02^_=T0[;[E
0:Zhd`2V//X0XJg709bU`P2KY<40UZ2k09RR^`2KXkP0HVYm07f8VP2>VJd0
W:Jo0:fgdP2f`Md0]L3L0080]L7K0300]/7M0;G0g02d_m/0]L3L0;K1g@2c
_]X0[[WE0:Zed@2LY;/0Vj>`0>C/k`3<d]80n_oo0>ganP27SIT0`<SC0?Wk
o`2k_l80SI:H08:7V`20QIT0^Kk40?coo`3CeN40SiZ`08^CZ027SId0g^;[
0?_oo`3Ffn40TIJY08bA[P29SZ80`/SD0?Woo`2h`<<0RY6K08:8V01mPi<0
_lGA0?_oo`3Lh^h0YJg40:RdcP2b`MP0]<?H0;?1f`2b_M/@0;G0g0080;g8
gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403n
o_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[JfP3Jf]P0UIB?08Z7
OP2JU8H0ZZ>A0;jfX@37_jP20<W1ZPH0b/:[103:`Zd80<_3[PP0c<B_203=
aK080<k6/@@0clNb0P3=a[<80<k7]0P0clRe203@bKH:0=7:]``0d/^h203C
c;X@0=C=^c00eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>ST
f`1DF5L0Ef2105i`V01YP:80MXRh07j>`P1oT[d0NY6m1@1nT<0307nA`@D0
P9;00`21Tl4508:D`P<0PiG31024Ul8608FH``H0QYW41028VLD408VJaP80
RI[5202:VlH608^La`0:08bNaP2<WlL0TjO<09ZZc02Q[l`0OY2T03mMI`1X
TI<0KYfU07>RZP80MZN^0P1eYZd207BV[@P0MZN^01@0MZF]07JW[P1dYZd0
LjR^07FX[01dYJX0NJR^08>`]P2Ma<T0]M7D09j]/P1JHVl0HVb506IeUP1h
R:X0RIRi08ZKaP2;W<L0S9g808^La`80RY_6>P2;W<L0302:VlH0Ric:08^M
a@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0
oOgm0?ooo`3oool0<03oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3K
fm/0gMWJ0=_Le`2<TI@0MGfB07n:Z02:V;80V:O40:6^f0080:2^d@0309n]
d02P[]40X:kA0080XJoB0P2P[]408P2O[M00Wjk=09NVa`2HYlP0U:7309:O
`@2;VKH0Hg6;07B0V022Sjl0SY^m09ZWbP2Q[m@0WZcC09j/d@2T/]L0WJg?
09j`eP2O[m<0WZkB09j^d02M[<d0V:O609JS``2FY<40WJFl0:F/_`2g_LT0
^;c507MnQP20R9D0Q8bS09FN^`2P[Ld20:Zge`030:^hf02/^MT0ZKKF0080
[;WI01H0ZkSH0:bif@2]^mP0[;[G0:fkf02^_=T0[K_F0:Zhd`2W/l/0XZk8
09bU`P2KY<40Uj6l09RR^`2KXkP0Hf]n07f8VP2>VJd0W:Jo0:fgdP2f`Md0
]L3L0P2e`M/0<02f`Md0]L3L0;Bof`2e`=`0]/7M0;Bof`2a_=P0[[WE0:Zd
c@2QZK`0UinZ08^@UP37c=80mo_o0<37d@26S9P0moOo0??gn03Hg=l0fM_X
0>;Tl@3^l_D0nOgn0<S8dP2?U;40RHjR08N;UP3`m?D0nOgl0?[mo`2a]<D0
TYB]09>E[02AUJ40lOOg0?Kln03Cf=/0g^;[0=kPk03[kOT0n?kl0<_BfP2/
]<L0/koG0;C3fP2`_mH0//3K0;G0h100]L3L00P0_LSN0<[Bi@3CfNL0e]WR
09:CU`3no_l0oooo0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??c
l`3[jn/0i>CT0=kNgP3Lg=`0f][J0=[Jf02EU8l0RXMn09ZDQP2ZXi40_[JQ
0<NoZ0H0b/:[0P3;`j`40<[2[@P0bl>^203<a:l80<g5/0P0c/Ja103?ak86
0<k7]0P0clRe203@bKH80=7:]`80d/^h103Ab[L40=;;^0P0dlbi203Cc;X@
0=C=^c00eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1D
F5L0Ef2105maV@1YP:80MXRh07n?``1oT[d0NY6m0`1nT<0507nA`@<0P9;0
1@21Tl4308:D`PD0PiG31024Ul8408FH``H0QYW40P27V/D408RIa@@0RI[6
1P2:VlH808^La`80S9g800`0SIc508fOa`2AYLX0W:c>09f[b02Y^<d0?EEQ
06:3R01YV:00L9nW07FV[@1fYjh207FV[@0307FW[P1dYZd0MZN^00L0MZN^
0100MJJ]07JW[P1dYZd0MJN^07FX[01dYJX0O:V_08Vd^`2Sa<T0_]KJ07V6
SP1OJ7T0I6n;06emW`1nS[80S9Zm1P2;W<L00`2<WLP0SIk908^La`0g08^L
a`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00n?Sh0?knoP3o
ool0o_kn0P3oool00`3moOd0oooo0?ooo`0`0?ooo`0?0?gmo@3hn?P0lO7a
0>WYj@3Rh^80gMgM0=_Kf`3MfMX0fmcG08bAU01eOI80OhZX08ZH/P2HYl@0
XJkH00P0X:kA00D0Wjg@0:2^d@2P[]40X:kA0:6_dP030:2^d@0Q09j_c@2M
[<d0VjW<09VWbP2EY<D0TIjn07R6X`1SLH`0SYVi09FR`P2BWl80WZ[@0:Fa
e`2N[<l0X[7B0:2_d02R/]H0WjoA0:2_d02Q/<l0XJo<0:6/b02Q[LL0YJo:
0;:ib`2f_<`0^ko:0<O;e01cMh80LGR808nG[P2?VK@0XJk>0080Z[OG00<0
ZkSH0:bif@2Z]mL00`2/^MT05@2]^]X0[K_H0:fkf02]^mP0[kgJ0:fkeP2Z
^=<0Yk?;0::^b02MY/<0W:G209NQ_02IXk`0Vj>h06=[OP1mR9X0SYV]09bV
_`2]]m80]/7M0;G0g0020;G1f`0`0;K1g@2e`=`0];oK0;G0g02f`Md0]L3L
0;>nfP2a_=P0Z;??0::/a`2KXKT0T9FX0;Bha03kool0al[I08>9V@2k_LT0
o?oo0?cno@3Gen40fm_U0?koo`3jo_l0[k6m092E/`29SZ80VIbS0?koo@3_
lNh0n?Wn0>7Sl02DUjX0T9B]08N=V@2oaLD0n?kj0?Slo@3Ef=l0fmkU0?kn
o`3kool0][g70:R`a@2a_ML0/L3G0;?2f@2c`M`0]l;R402e`=`0202mb=h0
b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn
0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03Jf]X0f][H09FDS`2:Qgh0
VYB60:ZST@2n]Z40aknX1@3:`Z/30<_3[0<0b/:]203;`jh80<c4[`P0cLF`
203>a[450<o7/PD0c/Nd203?b;D80=39]PP0dLZg0`3BbkP30=7:]`D0d/^h
203Cc;T80=?<^Q00e<fk<03Ec[`0403DcK/0e<fj0=?>^P3Cc[X0f=?00>3J
c03UhMH0j>CK05AHE`1GH840Gg6I06V0XP1fR;P0Oho307nB_@1jTKd607nA
`@80P9;21P21Tl4208:D`PH0PiG30P24U/@308BG`PD0QIS31@26VL@308NJ
a@<0R9W51@29V/H508ZKaPP0Ric70`2<WLP0402=V/@0S9k6092Tb@2L[<h0
Y[7?0;6md`1IK7X0F7=j06BCV`1]W:@0M:F/07FV[@1dYJ`0MJJ]07FW[P1d
YZd807JW[P0@07FV[@1fZ:l0M:J]07FW[P1gZ:d0MZF[07nZ/@2?]kl0ZLK<
0;[=e01SKGL0IFf0069_S`1dQZ`0PYBj08VI_@H0Ric700<0S9g808fNb@2;
W<L0=`2;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Sh
n03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0<03oool03`3moOd0
n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0gMWJ0=_Le`2<TI@0MGfB07n:Z02:
V;80V:O40:6^f00@0:2^d@0>09b]b`2P/=40WZc?09VWbP2HY/T0VZW:08jK
^`1MJhP0NXFS09bWa`2NZld0Wjc>0:Ree`2U/]@20:>bc`80Xk;A00l0Y[CA
0:^gd@2`^]<0];cC0;JldP2h_m80_<;@0<;8e034b=@0RXfL03e3D`1iP9<0
PXbU09FQ^`2Q[/h00P2Z]mL00`2[^=P0[;WI0:Zge`030:bif@0E0:fjfP2^
_=T0[K_H0:jlf@2__MX0[[cG0:^ie02W/l/0XZk809fV``2LYL80V::m09VS
_02LY;T0Hf]n07f8VP2>VJd0W:Jo0:fgdP2f`Md0]L3L0080]L7K0P2e`=`0
;P2d_m/0]L3L0;K1g@2f`Md0]L3L0;>nfP2]^mP0[;OG09bS`02GVk@0YjZk
0?_oo`3Ig>/0PhRK08^>W`3cm_/0nogl08b<U026QXh0o_oo0?_no`2EV:T0
SiBa08Z?XP2d]k`0oOon0=SIf`30`<P0o?ko0;Rlb02=Tj/0SIBT09>KWP3^
loH0nooo08>6S@29RXl0o_oo0?[oo`2Y[kd0Zk;<0;>nfP2d`]`0]/GL0;?1
g02c_]h@0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B
0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL
0=[JfP3Jf]P0UIB?08Z7OP2JU8H0ZZ>A0;jfX@37_jP40<[2Z`@0bl>/0P3:
`Zd80<_3[PP0c<B_203=aK080<k6/@H0clNb103>ak@80<o8]@P0d<Vf203A
b[L40=;;^080dLZg1P3BbkP80=?<^@P0dlbj403DcK/`0=G>_00@0=C=^`3D
cKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0E5QG05QQPP1OLIT0JH2R07N9
^@1oSl<0Oi:m07ZA_@D0Oi710`20T/85086C`@<0PYC21@23UL<308BFa080
Q9O21P25V<<408JIa0@0Qi[50P28VLD608VJaP@0RY_6202;W<L408bMb00@
08fJa02:W<@0T:C909^[c@2^^ML0/KcB07b<V`1:HFT0H8nG06^JXP1cY:/0
MJJ]07BU[01eYZd0MJN^07BV[@P0MZN^0100MJJ]07JX[`1dYZd0M:J]07NX
[@1hYJ/0P:^b09>k``2ab]40X;6i05aVLP1UKH@0JWNI07V;/`25Ukl0Ri[1
1P2;W<L208bMb3P0Ric700`0RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M
08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0300oooo
00l0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3Kg=L0S96D07Em
TP1oRZP0RYRb09RWa02Q[]P0202P[]430:6_dPD0X:kA0240WZo=09n_d02O
[m40VjW>09f[d02MZlh0W:_<07R5Y@1XLhl0RIB`0:Nbd02W]=@0Z[OG0;6o
g02]^mD0[[kG0:jleP2c_mT0^<CL0;o7g035c=h0b<kN0<S;fP35bMD0aLkE
0:>Y]@1SJ7/0JVj7051FL01`NYD0QI6[096P]`2R[ll00P2[^=P00`2/^MT0
[K[J0:^hf0020:fjfP0F0:bif@2^^m/0[[cI0:fkf02^_=T0[kgJ0:jle`2[
^M@0Z;C<0:>_b@2MY/<0W:G209RR_@2IXk`0W:Bi06A/O`1mR9X0SYV]09bV
_`2]]m80]/7M0;G0g080]L7K102e`=`20;K1g@0Z0;G0g02d_m/0Zk_D0:^f
dP2PZLH0TYR^08jBWP3go?l0nOgo08jBWP24RZ00^L380?Kjo@2m_LD0YjN_
0?coo`3Oi^h0T9J/08^@[@2:Sj80bm3F0?Sko`2l_lP0TiFQ0>kbn`3/m?L0
S9>]08fFY`27SiX0_LC>0?_oo`2h_<P0Wj:W0?coo`3Vj_D0Yjc00;6he@2a
_=`0//3K0;?1f`2d`]d0]l;P402e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G
0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03Jf]X0f][H09FDS`2:Qgh0VYB60:ZST@2n]Z40aknX
103:`Z/40<_3[0L0bl>^203<a:l80<g5/0P0c/Ja203?ak800`3@b;<0c/Nd
0<k7]0020<k7]0P0clRe203@bKH80=7:]`/0d/^h2@3Cc;TH0=C=^c00eLjl
0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1DF5L0F66205ma
V@1ZPJ<0MhVi07n?``1oT[d0Ni:n101oTL44082B`P@0PI?11022U<8408>E
``@0Q9K41`25V<<508JIa0@0Qi[51`29V/H00`2:VlL0RY_608ZKaP0208ZK
aPP0Ric7102<WLP02`2?W<H0RI_3096UbP2KZld0[k[H0;W1f02CX;00?e=L
05f<U01YV:00LjB[0080M:F/00<0MJJ]07FW[P1dYZd0201fYjh0401eYZd0
MZR_07BV[@1dYZd0MjR]07RUZ`22Z[80UK_40;G<dP26U9d0GFEb06=[PP1d
PZD0NX^f08FF`@2?W/D208bMb3h0Ric700`0RY_608^LbP2;WLD0UjS60:Zh
e@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0300oooo00l0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=gIfP3K
g=L0S96D07EmTP1oRZP0RYRb09RWa02Q[]P0202P[]430:6_dPD0X:kA0240
X[?A09b/c@2Q/M<0WZkB0:6_e02IYlX0Xk;C09f/b`1dP9X0J7>?09JQ_@2_
^]P0[[cI0;W7hP2faM`0_lkS0<;>i037d^P0c=OY0=7HjP3CfNL0dmOS0<g@
f@37am40N86605mWLP1fNi40TIJd05UOP@1iPZ40P8jY096Q^02R[ll00P2[
^=P00`2/^MT0[K[J0:^hf0020:fjfP0:0:bif@2^^m/0[[cI0:fkf02^_=T0
[kgJ0:jle`2[^M@0Z;C<0:>_b@80WJK300X0V::m09ZT_@2LY;T0I6ao07f8
VP2>VJd0W:Jo0:fgdP2f`Md0]L3L0P2e`M/0102e`=`0];oK0;G0g02e`=`2
0;K1g@80]L3L02P0]LKH0:Jec02T[/T0UYf`092EV`3]lo40nooo09BIW`2=
U:h0PHRB0?3en03dm?h0`L7;0?Smo`3DfnD0SYF_08bC[@2:TJ40e]gU0?[m
o`2][k`0RXfL0<75cP3eo_d0^<;K08nJ[028TJ00RI2P0>;WnP3gn_l0_L35
0?_oo03FfNP0ZZk70;Bjg02a^mh0]/CQ0;;0fP2e`md0];oM402e`=`0202m
b=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100
o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0g]kN0=cLg03Jf]X0g=cJ09FDS`2=
RX40VYB60:bUT`2m]J00b<2Y103:`Zd40<_3[P030<[2[@3;`jh0bl>^00H0
bl>^203<a:l80<g5/0L0c/Ja00<0cLJc0<k7]03>ak@02@3>ak@80<o8]@P0
d<Vf103Ab[L00`3@bKH0dLZg0=7:]`050=7:]`P0d/^h403Cc;X80=C=^cP0
eLjl0140e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1CEeH0Ef1o
061bV01[PZ80N8Zh07n?`P20Tkd0Ni:n07nA_`07082B`003086C`@22U<80
PYC200D0PYC200<0PiK108BG`P24Ul801@24Ul8408FH``@0QYW400<0QiS3
08RIa028VL@01@28VL@408VJa@@0RY_6202;W<L01@2<WLP0Ric708^La`2;
W<L0RY_600<0Ric700h0SY[408nNa`2=Wl<0Wjc>0;c3h02k`mX0VZZi03Q@
FP1MRY00JIRN07:SZ01cYZX0MJN^07JX[`80MJJ]201fYjh307:W[@0=07FW
[P1eYZ/0MjBZ08F]]@2G_LH0[L_;07R:U01OIgh0JW2@07B2Y`1mTKH0R9_3
08VK``1008^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<TY00
n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0G0?ooo`@0o_kn
103ooolA0?knoP0?0?clo03hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3Pg=d0
fmcG08fBU@1gOi@0OXVW08ZH/P2IZ<D0X:gG01P0X:kA01T0XZo?07N5XP1R
KH/0R9:]0;FleP32b>00b<gS0<[?h`3EfND0e][V0=OMj`3Ni?80fn;b0;c5
eP21RY/0CUMX06ekV022Sjl0T9Zm08VD/01EHWD0MH:B08JAY`2FWk`0YK3>
0080[[WG00<0[k[H0;2kf@2^^ML00P2`^mT05P2a_=X0/;_I0;2ke`2a_=P0
/[gI0;6lf02`_=H0[[[D0:Rdc02S[lL0WZS309fW`P2HX[/0VZFk09fU^01T
KGh0OHRJ08jI[@2LY[l0[KOB0;K1g@2e`=`20;G1f`P0]L3L02P0/KoJ0:^g
d@2U/<H0W:Bg09:JY`3Cen80o?oo0;:e_02BW;D0T9J/0;FgaP3oo_l0nOSd
0?koo`38c=P0TYRb08fBZ02<Ti/0nOoo0?Ooo`2MXk<0TiN`09BJZP3bnOl0
loOj09^PYP2BVZL0T9bZ0:jha03kool0moGf0?oln@33d><0ZKK90:fic`2g
`m/0]<3J0;>nfP2d_m/0]/7O402e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G
0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03Jf]X0g=cJ09FDS`2=RX40VYB60:bUT`2m]J00b<2Y
103:`Zd:0<_3[PP0c<B_203=aK080<k6/@80clNb1P3>ak@20<o8]@@0c/Nd
203?b;D80=39]PX0dLZg2P3BbkP@0=?<^PP0e<fk>03Ec[`0403DcK/0e<fj
0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05=GEP1HHH00H7:H06^2XP1hR[P0
Oho2082C_@1kT[h6082B`080PI?11P22U<8208>E``H0Q9O21P25V<<408JI
a0H0R9W41P29V/D408ZKaPT0Ric70`2:VlH408^La`0<08jKa`27VL40U:K:
0::_d@2a^=@0bm7W09>S/00lEE`0G8V?06VHWP1bXjP0LjJZ0P1eYjh00`1e
YZd0MZN^07JW[P0707JW[P0@07BV[@1bYjd0LZN]07FW[P1eYZ/0N:F[08F]
]@2G_LH0ZlW906j2R`1OJX00JW>B07F3Z01oTkP0RIc408^MaD00Ric700`0
RY_608^LbP2;WLD0UjS60:Zhe@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3n
o_h20?ooo`030?gmo@3oool0oooo0300oooo00l0oOgm0?Shn03alO40jNWY
0>;RhP3Ng]h0g=cL0=oKg03JfmH0S96D07InT`1mR:H0RINa09VXa@2P[ML0
602P[]406@2O[/l0Xk3@092M_@1fPId0KGNB08>:Y02W[lH0^KoG0;ZodP32
bM/0^L3B09FL[`1[LhH0GfYn07AoT`2>VJd0Q9:_08VF]P2=UkX0R9>_05QU
N01fPi<0Q8nU09BM^P2U/<h00P2^^ML00`2_^]P0/;_I0:jie`020;2kf@80
/KcJ0P2a_=P04P2b_MT0/KcH0;2leP2_^mD0Z;C<0:>_a`2NZ<<0WJO209RR
^`2JYK/0WJFh06A]OP1mR9X0SYV]09bV_`2]]m80]/7M0;G0g080]L7K202e
`=`0:02d`]d0[k_E0:J`b@2MYKX0U9^]0<_Ag`3kool0aLSA09JR_02BV[40
Wj:e0=oOi`3oool0o?oo0:jd`P2DVkL0T9B]0:N]^@3iool0k_Gk09jS]P2H
W;L0U9V]0<K=e`3joOl0b<oI09JO[P2>VJ/0VZ>d0=cPj`3oo_l0ookm0;K3
eP2Z]lX0/;cB0;K2fP2c_mT0];oK0;G0g02f`Ml@0;G0g0080;g8gP3:d^D0
dmWW0=KIhP2BTiL0o_ko0?ooo`3no_`B0?ooo`00803oool0403no_h0oOgm
0?Win@3clo<0jn_[0>CTi03Ng]h0g=cL0=[JfP3Lg=X0UIB?08f:P@2JU8H0
[:FC0;feX038`:T30<[2[@X0bl>^203<a:l80<g5/0P0c/Ja0`3?ak850<k7
]0<0clRe0`3>ak@80<o8]@P0d<Vf2P3Ab[L;0=;;^100dlbj203DcK/h0=G>
_00@0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0DeMF05QQP01Q
LiT0Jh:R07R:^020T<<0P9>m07^B_P@0P9;01021Tl4408:D`P@0PiG31@24
Ul8608FH``D0QYW41@28VL@608VJa@D0RY_6202;W<L208ZKaP0B08VJa@2:
VlH0Ric708bMb02;W<L0RY_608^Lb026VL<0UJO;0:^ieP30a]h0b]7S08ZH
X@0oEe/0G8V?06VHWP1cY:T0M:N[0P1eYjh00`1fYjh0MjR_07JW[P0707JW
[P0@07BV[@1eYjh0LZN]07BV[@1fYj`0MZF[08>^]@2E_LD0ZLW806IjP`1R
KH<0KGJE07N5ZP21UKX0R9_308jMaT00Ric700`0RY_608^LbP2;WLD0UjS6
0:Zhe@2g`>40`l[M08bBT03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3o
ool0oooo01`0oooo0`3no_hA0?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80
g]kN0=cLg03Nf]/0fM[E08^@T`1eOI80OHRV08VG/@2JZLH0XJkH01P0X:kA
00P0WjoA0:6ad`2Q/=40XJk>09>Q_P1nRJD0KWZD06I`R`80I6j700l0JgF>
07b6W`2?VkD0VJFo09NS_@2>W;L0T9jk08ZG]`28T[D0R9>_05YWNP1gQ9@0
QI2V09NP_@2U/<h00P2^^ML00`2_^]P0/;_I0:jie`020;2kf@80/KcJ01@0
/KcH0;:mf@2b_MT0/[gI0;2leP2_^mD0Z;C<0:B`b02NZ<<0WJO209VS_02J
YK/0WJFh06A]OP1mR9X0SYV]09bV_`2]]m80]/7M0;G0g080]L7K202e`=`0
9P2a_m`0/[gI0:Zfd02U/<H0XjVo0<S?h@3cnOl0fMc[0:6_b@2QZlH0V9jd
0;g1c@3jool0lOSo0:2X^`2PZLH0XjS50<C;g@3bnol0gnOb0:J/`P2TZLH0
W::j0:2W]`3kool0l?Oo0:Vaa02JYK/0Ti^`0;Nmc@3no_l0o?_o0:Zfc02/
^<h0]<3F0;K2fP2d`=X0]/7M4P2e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G
0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03Jf]X0g=cJ09FDS`2=RX40VYB60:bUT`2m]J00b<2Y
0P3:`Zd:0<_3[PP0c<B_203=aK080<k6/@@0clNb103>ak@40<o8]@80c/Nd
203?b;D80=39]PX0dLZg303BbkP@0=?<^PP0e<fk>03Ec[`0403DcK/0e<fj
0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05=GEP1HHH00HG>I06b3X`1hR[P0
P933082C_@1lTkl3082B`0D0PI?10`22U<8508>E``@0Q9O21P25V<<608JI
a0@0R9W41P29V/D608ZKaPT0Ric701<0RY_608VJa@2:VlH0Ric708bMb02;
W<L0RI[508VLa`2@Xl/0UJS90;C0fP3:cn<0dmWW06IgOP18HV<0GHZ@06ZI
W`1cY:T0M:N[0080MJN^00<0MZN^07NX[`1fYjh0201fYjh03`1eYjh0M:J]
07BV[@1fYj`0MjJ/08>^]@2C^l<0Y/S7065hP01TL8H0LGZI07R6Z`21UKX0
QiW108fLa@1008^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:g@2<
TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0G0?oooaT0
o_kn00l0o?cl0?Ogm`3`l?00j>SX0>7Qh@3MgMd0fm_K0=oKg03JfmH0S96D
07EmTP1mR:H0RINa09ZYaP2Q[]P0602P[]402@2P/]H0WJgA09^[c@2P/=80
YKCE0::ad02P[Ld0Wjg:0::_c`020:2]c@0>0:6^cP2O[<`0V:G5092O_P2=
W;/0RYRe08ND]029TkH0RYFa05UVN@1ePY80QI2V09VR_`2U/<h20:njf003
0;2kf@2a_=X0[[WG00@0/KcJ01@0/KcH0;:mf@2c_]X0/[gI0;6me`2_^mD0
ZKG=0:B`b02NZ<<0WJO209VS_02KY[`0WJFh06E^O`1mR9X0SYV]09bV_`2]
]m80]/7M0;G0g080]L7K202e`=`09@2b_ml0]/7O0:jie@2Z]<l0Xj[40:fc
b@31amd0]kkA0:FecP2Y]m80XZc70:J^`@3=eN80bmGQ0:B_a@2W/]00WZG2
0:ngc02ma]D0^lCE0:R_b@2]]=40Z[7=0:>[`02d^ld0_LGH0:NabP2/]]40
Xjg60:bbb038c]h0c<kK0:Rdc02_^m<0]L7I0;K2g02e`M/00P2e`=`00`2f
`Md0]L3L0;G0g00>0;G0g0080;g8gP3:d^D0dmWW0=KIhP2BTiL0o_ko0?oo
o`3no_`B0?ooo`00803oool0403no_h0oOgm0?Win@3clo<0jn_[0>CTi03N
g]h0g=cL0=[JfP3Lg=X0UIB?08f:P@2JU8H0[:FC0;feX038`:T60<_3[P80
c<B_103;`jh80<c4[`P0cLF`203>a[440<o7/P@0c/Nd2P3?b;D80=39]PP0
dLZg0P3BbkP40=7:]`@0d/^h203Cc;T80=?<^Q00e<fk>03Ec[`0403DcK/0
e<fj0=?>^P3Cc[X0f=?00>3Jc03UhMH0j>CK05=GEP1HHH00HG>I06b3X`1h
R[P0P933082C_@1lTkl5086C`@<0PYC21@23UL<308BFa0@0Q9O21025V<<6
08JIa080Qi[51028VL@408VJa@H0RY_62P2;W<L0102<WLP0Ric708ZKaP2:
VlH208^La`0>08ZKaP29V/D0Ric709NYc`2S]=80^/GK0<_Ah@3Hh>/0>TeA
05QfMP1QSY@0K9^Q07BUZP1dYj/207FW[P0307JW[P1gZ:l0MZN^00P0MZN^
00l0MjR_07BV[@1dYZd0MJR/07RW[@21[[@0SKRo0:34`P1VOhH0HG2507=n
W01hQZ/0PIFj08JH`02=W<D0@02;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE
0;O0h@33b]d0S9:@0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3o
ool05`3oool40?knoP@0oooo403no_h0403oool0oOgm0?Shn03alO40jNWY
0>;RhP3MgMd0fm_K0=oKg03Kg=L0S96D07InT`1mR:H0RINa09VXa@2P[MLH
0:2^d@0>09Z/dP2O/MD0Y;CH09n_d`2L[<h0WjoA0:6adP2R/]<0WJgA09j^
d02P/=80X[3C09bZc@2CXL@208nM`00908RF/`28UKD0SINj08^F/P1HIGP0
MH:B08JAY`2EW[/0Y[7?0080[k[H00<0/;_I0;6lfP2_^]P00P2a_=X20;:m
f`80/[gI0P2c_]X0102a_ML0/;cF0:Vec@2T/<P209jX``0:09VS_02KY[`0
WJFh06E^O`1mR9X0SYV]09bV_`2]]m80]/7M0;G0g080]L7K202e`=`08@2b
`=d0]<;O0;:mf@2b_MT0[kWD0:Zdc@2a^=80/KW@0:Rhd@2]^mH0[KSF0:Fa
b`2/]lT0[KS:0:nkd`2Z]MD0/;WH0:jhd@2/]l/0/Kc@0:nie02a^]T0[[OD
0:jhd`2]]LX0[KO@0;6keP2_^]H0Z[?@0:^ed02Z//T0]Kc?0;2leP020;C0
fP050;G1f`2g`md0]<3J0;Bof`2f`Md0402e`=`0202mb=h0b];U0=?Ii`3F
fN80TY>G0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0
lo?c0>_[j`3Ti>@0g]kN0=cLg03Jf]X0g=cJ09FDS`2=RX40VYB60:bUT`2m
]J00b<2Y1@3;`jh30<c4[`<0bl>^203<a:l80<g5/0P0c/Ja1@3?ak830<k7
]0X0clRe203@bKH80=7:]`<0d/^h0`3Ab[L50=;;^0P0dlbi203Cc;X@0=C=
^cP0eLjl0100e<fk0=C=^P3Cc[X0dljj0=SC`03Pf/`0iN7F0>STf`1DF5L0
F660065cV@1/Pj<0NH^i082@``20Tkd0O9>o1021Tl4408:D`P@0PiG31024
U/@308BG`PD0QIS31@26VL@308NJa@<0R9W41@29V/D508ZKaP/0Ric70P2<
WLP208^La`80RY_600h0Ric708bMb02@WlH0VJW:0;C2g038cn80hnOc0:6[
]00aBTh0G8>206JCV@1`WjD0MJJ[07BWZ`80MJN^2P1fYjh0401gYZh0MjR_
07FV[@1dYZd0MJR/07NX[@1o[;80RKBk09Nn^`1aS9<0FfYo07AoW@1hQZ/0
PYBj08RJ`P2>WLI008^La`0<08ZKaP2;W<X0Rig509NXaP2Z^=D0]l3Q0<?:
g@2<TY00n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0O0?oo
oa00o_kn0100oooo0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3Nf]/0
f]_F08bAU01fOY<0OXVW08VG/@2IZ<D0X:gG602P[]40102S/mL0Vj_?09ZZ
cP2M[M420:2`dP0C09b/cP2O[m40Y;CH09n_d`2KZll0WJgA09j/c`2IYlX0
TIo208fK_P2;VKH0RIJf08bF^@29U;00F6Eh07V6UP2:UJ/0UIjk0:Jac`02
0:njf0030;2kf@2a_=X0[k[H0080/KcJ0P2b_M/0502b_MT0/kkJ0;>nfP2c
_]X0/KgG0;2leP2Y]Ld0Y;3809nYa02NZ<<0VJ>l09^V_02NY[T0IFio07f8
VP2>VJd0W:Jo0:fgdP2f`Md0]L3L0P2e`M/80;G0g00V0;G3gP2d`]d0/[gI
0;>nfP2d`=X0[k_E0;2je@2d_]T0//7F0;6ofP2b_ml0/KoL0;:neP2/^<h0
^<CN0;2kf`2b_M/0/;cF0;2le02b_]H0/koI0;>nfP2a_=X0];oM0;:neP2b
_]P0]/7M0;6lfP2`^mT0];oK0:jje02b_]H0]l;N0;K1g@2c_]X0]L3L0;K2
g02c_mT20;G1fa00]L3L00P0_LSN0<[Bi@3CfNL0e]WR09:CU`3no_l0oooo
0?kno180oooo000P0?ooo`0@0?knoP3moOd0nOWi0??cl`3[jn/0i>CT0=kN
gP3Lg=`0f][J0=cLfP2EU8l0SHZ109ZDQP2/YI<0_KFP0<S0Z@@0bl>^103<
a:l20<_3[PP0c<B_203=aK080<k6/@H0clNb0P3>ak@:0<o8]@P0d<Vf203A
b[L40=;;^080dLZg1P3BbkP80=?<^@P0dlbj403DcK/h0=G>_00@0=C=^`3D
cKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0E5QG05QQP01QLiT0K8>S07V;
^@20T<<0PIBn07bC_`80PI?11P22U<8208>E``H0Q9K40P24Ul8608FH``@0
QYW41027V/D208RIa0H0RI[5102:VlH>08^La`0D08bMb02;W<L0RY_608^L
a`2=W/T0Sj3;09bVb@2Y]m80`lkR0=SNk03IgNP0F6E]04UVJP1KQhP0JiRN
07>RZ01fYj`0M:N[07FW[P1fZ:l207FV[@P0MZN^0100NJF^07RW[`1fYjh0
M:J]07FX[01fYj`0NjZ`08Ba]`2A^;D0PIjT05EVNP1cPIh0MhN[086C^@29
Vl<0Sic6@02;W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@
0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool05`3oool30?gm
o@80o?cl503kno/03`3inOT0mOGe0>k^kP3UiND0g]kN0=[JfP3Hf=P0f]KG
0=OHd`2:Si80MGfB07j9Y`29Uk40VJS50:2]e`0H0:2^d@0I09f[cP2Q[m80
Y[CG09j/c`2JZ/`0WjoA09j^d02P/=80W[3D09n_d`2N[]80Wjg@09f[cP2G
Y<H0T9fo08^H^02<V[L0R9Fe08ZD]`29U;00F6Eh07V6UP2;UZ`0Uj2m0:Nb
d0020;2kf@030;6lfP2b_M/0/;_I0080/[gK01H0/kkL0;:mf`2b_MT0/kkJ
0;Bof`2c_]X0/[kH0;2leP2Y]Ld0Y;3809nYa02NZ<<0VJ>l09^V_02NY[T0
IFio07f8VP2>VJd0W:Jo0:fgdP2f`Md0]L3L0P2e`M/80;G0g00P0;G3g@2c
`M/0//3J0;;0fP2f`]`0]l?M0;G1f`2ha=h0]/?F0;6of@2b_ml0/l3P0;G3
g@2c_mL0]l7L0;Bmg02`_]T0/l7K0;G3g@2c`]T0]<?J0;?1f`2c`Mh0/l3P
0;;0fP2d`]`0]L3L0;>ng02d_md0//3M0;?3g@2a`M/20;O2gP060;Bof`2f
`Md0]L3L0;>of@2g`md0]<3J402e`=`0202mb=h0b];U0=?Ii`3FfN80TY>G
0?kno`3oool0o_kl4P3oool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[
j`3Ti>@0g]kN0=cLg03Jf]X0g=cJ09FDS`2=RX40VYB60:bUT`2m]J00b<2Y
103;`jh;0<c4[`P0cLF`203>a[480<o7/P030=38/`3?b;D0clRe00D0clRe
00<0d<Vf0<o8]@3?b;D00P3?b;D80=39]PP0dLZg2`3BbkP90=?<^@P0dlbj
403DcK/h0=G>_00@0=C=^`3DcKX0dljj0=?>^P3Hdl00h=[<0>GQeP3Xi=/0
E5QG05URP@1QLiT0K8>S07V;^@20T<<0PIBn07bC_`L0PYC200<0PiG308BF
a024U/@01@24U/@00`25UlD0QIS308FH``0508FH``D0QYW41027V/D708VJ
a@D0RY_6302;W<L05P29V/D0Ric708bMb02;W<L0RY_608^La`2?X</0TZ?>
0:N`c`33cNP0c]KY0=oUl@2RY[40@E1G05UjO`1OSi<0KY^Q07FTZP1fYj`0
M:N[07FW[P1fZ:l207FV[@P0MZN^0100NJF^07RW[`1fYjh0M:J]07JY[@1f
Yj`0NZV_08:_]@2?^;@0SZ^a059SM`1dPYl0MXJZ07nA]`28V/80S9W3@02;
W<L0302:VlH0Ric:08^Ma@2GZ<H0Z[SE0;O0h@33b]d0S9:@0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool05`3oool01@3kno/0n_[j0?[j
nP3inOT0moOg0080m_Kf00<0mOGe0?Ogm`3gmoL03`3gmoL03`3emOD0l?3`
0>WYj@3QhN40f][J0=GEe@3Cdm<0em?D0=CEd028SI00M7bA07f8YP29Uk40
VJS50:2]e`0H0:2^d@060:>`d`2NZlh0XJkA09n]d02Q[m80Y;;E0P2N[]00
4@2N[]80WjoC0:2`dP2O[/l0W:W;09NTa02DWkl0TIbj08bJ]`27U;@0S9Ji
08^F/P1FHgH0M86A08JAY`2GX;d0Yk;@0080/;_I00<0/KcJ0;:mf`2`^mT0
0P2b_M/05P2c_]`0/[gK0;>nfP2c_]X0];oK0;>nfP2b_]P0/;cF0:Vec@2T
/<P0WjW409jX``2IXk`0VjJl09jV^@1UKWl0OHRJ08jI[@2LY[l0[KOB0;K1
g@2e`=`20;G1f`P0]L3L02P0/l;I0;;1f02d`mX0//3J0;?1f`2e`md0/KoI
0;2nf@2haMH0]L7K0;K3h`2a_^00/KoJ0;K2fP2e_mX0^KoO0;;0fP2c`M/0
/KoI0;70e`2d`mX0/l7K0;G3h02b_ml0/l?L0;?1f`2c`M`0]l;N0;C2g`2^
_MX0/L;N0;C5h@2c_]`0]/7O0;G0g02f`Md0/kkJ0;C0fP2ja^00/koI402e
`=`0202mb=h0b];U0=?Ii`3FfN80TY>G0?kno`3oool0o_kl4P3oool00200
oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0gmoO0=cLg03LgMP0emOG
09FCUP2>RhH0UY>20:bXS`2l]Y`0b/B/103;`jh40<c4[`030<_3[P3<a:l0
c<B_00T0c<B_1@3=aK060<k6/@T0clNb203@b;<70=79]P030=;:]`3@b[@0
d<Vf00<0d<Vf00@0d<Vg0=7:^03Ab[P0d/^h1@3Ab[L20=;;^0030=7:]`3B
bkP0d/^h00D0d/^h203Cc;X00`3BbkT0dlbj0=?<^P050=?<^PP0e<fk0P3E
c[h20=C=_@050=C=^`3Ec[`0eLjl0=K?_@3Cc;T00`3DcKX0103Ec[/0e<fj
0=C=^P3DcKX`0=C=^`0@0=C=_@3DcK/0dljk0=?>^`3Gd[l0gM[;0>CPe03V
h]L0DEIB05USO01SM:00K7nY082?]P28UL80PXk008BE``H0PYG00P23U/44
08:E`0@0PiK11@25V<8608JI``D0Qi[40`28VL@508VJa@P0RYc40`29W<H0
0`2:WLL0RYg508^NaP0208ZMa@0A08ZL`P25V<00R9o908NOb`27W/P0SJ?:
09JXc02R/]<0^/GG0=3Ij03Pi_80a/gG0350A@1>Jfl0GHV:06:HVP1dYJ`0
0P1eYZd407JW[PD0MJJ]1`1fYjh207NX[`<0N:V`00P0S;Bc08ja]`1KMhD0
HWNB07V9Z`1nSK@0QiW108ZMa@80SYg40P2=W<<208^M``0308bNa02=WlD0
RYc403L0RYc400`0Rik608RK``29W<@0UjO;0:Vge02j`]L0bLgI08f=U@3h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00X0o_kn
0?ooo`3oool0oooo0?knoP3moOd0o?cl0?Win@3emOD0l_;b1P3`l?001P3`
l>h0lO7_0?3_k@3`k^l0l_3c0>k/k`P0lNo`0100knoa0>g]k`3YjNT0hn?S
0=_Kf`3EeM<0dM7?0<o?c@3Ad<`0cLg?08F5T@1gO900OhJS08^E^02HY/T0
WjoA402P[]400`2Q[m80X:kA0:2^d@0:0:2^d@80XJoB0180X:kA09n_d@2O
[m40X:kA09n]d02M[<d0UjK709:O`@2>Vkd0RiVf08VF]P29TkH0RiJb05QS
M`1iQID0R92W09^R_`2W//h20;2ke`030;6lf02b_MT0/;_G0080/[gI0`2c
_]X20;Bof`0@0;>nfP2a_=P0[k[F0:ZfcP2Q[LD0XJg709^W`@2KYKh0VjJl
09VT]P1RKWh0OXJK08jF[@2LYkd0[KW?0;K2fP80/L3G00<0/L7J0;Jog02f
_m`0?P2f_m`0202hb=l0bMKY0=7Jj@3Cen80TiBI0?knoP3no_`0ooom4P3o
ool00200oooo0100o_kn0?gmo@3inOT0lo?c0>_[j`3Ti>@0gmoO0=cLg03K
g=L0f=SH09JDU@2>RhH0UY>20:^WSP2l]Y`0b<:Z0`3;`jh90<c4[`X0cLF`
1P3>a[4<0<o7/PP0clVc103@bKH40=7:]`80dL^e1@3Ab[L80=;;^0030=?<
^@3BbkP0d/^h00@0d/^h0P3Cc;T>0=?<^PX0e<fk00<0dlbj0=C=^`3DcK/0
0P3DcK/30=C=^PH0eLjk0P3DcKX`0=G>_00@0=C=^`3Dck`0e<nk0=C?^`3H
dl00g]_:0>GQe@3Xi=T0EEMD05]RO01SM:00KH2Z07b>]025Tl00P93308:G
aPD0PiG31P24U/@508FGa@@0QYW41027V/D608RKaP80RIc71P2:VlL208^L
b0P0S9k60`2;W/T308^Nb00C08^NaP2:WLD0RI_308nRc023VL80RZ39092T
b@2DY<H0[K_H0;_5h03@enL0h>Se0=7Ki@15DUX0BV9V05enP`1TTI@0KJ2T
07BU[00207FV[@@0MZN^1@1eYZd607JW[P@0MjR_0P1hZK003@1oZjh0Qjje
07FEXP1@JGl0MXVW08JF^P23T[/0QIK108fLa@2>WLH0SIo708bNaP2;WLD0
0P2:W<@00`2:WLD0S9k608bNaP0f08bNaP0<08VOb028W/L0RYg509JXcP2[
^=P0^/;I0<K<fP2<SiP0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo
0?ooo`0A0?ooo`0;0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Win@3fm_H0
l?3`0>c/k03YjNT00`3Xj>P20>GUi@040>SXiP3[j^P0inKT0>KUh`80jNOX
203Vi>D0403Xj>X0i^KV0>;RhP3Kfm/0dm?C0<g=b`38b<H0a/K40<K5`036
a/H0P8><07QmT021R:@0SYVi09VWbP2M[M4P0:2^d@80WjoA00l0X:kA09n]
d02M[<d0UjK709:O`@2>Vkd0RiVf08VF]P29TkH0RiJb05QSM`1iQID0RI6X
09^R_`2W//h00P2`^mL00`2a_=P0/[gI0;2ke`020;:mf@<0/kkJ0P2d_m/0
4`2c_]X0/KcH0;2ke`2[]ll0XZk60::^b02LZ<80W:Jo09bW_@2KY[P0HVin
07n7W02<Uj/0VjJl0:fgd02f`]X0//3J0;?1g02e`mh0@02e`=`0202ib=l0
b=GX0=;Ij@3Df>40TiBH0?knoP3no_`0ooom4P3oool00200oooo0100o_kn
0?gmo@3inOT0lo?c0>_[j`3Ti>@0gmoO0=cLg03JfmH0f][J09NEUP2>Rh@0
UY>20:^WSP2k]Id0a[n/1P3:a:h70<_5[`<0c<J`0P3;aJl60<c6/0H0cLNa
2P3>b;880<o9/`<0clRe1@3@bKH30=3:]0030=7;]@3Ab[L0dLZg0080dLZg
103BbkP40=?<^@D0d/^h0`3Cc;T=0=?<^P/0e<fk00<0dlbi0=C=^P3DcKX0
0P3Ec[/20=C=^P030=?<^@3Dck/0e<nk00<0e<nk0P3Cc[X00`3BcKT0dljk
0=?>^`0`0=?>^`80dljj00`0e]?00=kKbP3UhMD0j>CI05IHE@1JHG/0HgBP
06f2[@1iS;@0Oi6o07fAa01oUlL408:D`P@0PiG30`24U/@708FGa@H0QYS6
0P27V/D608RKaP80RI[61P2:VlL808^La`<0Rik900<0RYg808ZMa`2:WLL0
0P2:WLL0402<WLP0RYc409BVc02EYLT0XZo?0;Bne`2m`]H0fMc]0=gSk`3J
h^d0GVed045HGP1KO840H8V?07JUZ`1aXZT307FV[@D0MZN^0`1eYZd507JW
[PP0MjR_00T0NjZb08>`]P21YZl0FgR605abQ`20Tk40Q9>j09FRcP2:VlH0
0P2;W<L01@29W<H0R9_508RKa@2:WLL0S9o903P0Ric70P2:WLL02P29W<H0
UJO=0:^jf`2g`MX0`lSK08b@W03hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo0140oooo00/0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh
0??cl`3/k>`0i^KV0>;RhP030>3Ph0080>GUi`3Ng]h0h>3P0>?Sh`3RhMl0
h=oM0>;Qg`3Sh]h80>;Qg`0@0>;Ri03Ph>80g=cL0=GEe@3>c/h0alO70<?3
`@31`Kl0`/>m0<32_`1jOhD0Mgf=07b6W`2;V;P0VJO<09j]e1@0X:kA102Q
[m880:2^d@80WjoA00l0X:kA09n]d02M[<d0UjK709:O`@2>Vkd0RYRe08VF
]P29TkH0RiJb05QSM`1iQID0RI6X09bS`02X/ll00P2a_=P00`2b_MT0/kkJ
0;6lf0020;>nfP030;Bof`2c_]X0/kkJ0080];oK01<0/kkJ0;:mf@2a_=P0
[;S@0:Fab@2S[lT0WZ[409jX`@2OZ/00WZVk069^OP1nRId0SIR/09^V_02/
]/l0]/;L0;G0g02f`Ml0]l;P0400/l7L00D0^/WN0<WDiP3Bf^L0e=SQ09>D
V0020?ooo`030?ooo@3oool0oooo0100oooo000P0?ooo`0@0?knoP3moOd0
n_[j0?Cdm03/k>`0i>CT0=oOg`3Lg=`0f][H0=_Kf`2FU9D0SX^409REPP2]
ZI00_[RR0<S1[`H0blF_1P3<a[0:0<g7/@80c/Rb1P3>ak@:0<o8]@d0clZf
1P3@bkL20=7<^0040=3;]@3?b[@0clZd0=7:]`<0d/^h0P3Cc;T60=;;^0@0
dlbi303Cc;X<0=C=^`@0e<ni103Cc[X20=?>^`@0e<nl0P3Cc[/`0=C?_00A
0=?>^`3Dck`0e<nk0=;@^`3Fdl00g]_:0>CRe@3WiMT0EUQE05YQN`1RLil0
KX>^07V?]020T/00OYC507^F``21U;l01P22UL0208>F`@H0Q9O21`25V<<2
08JIa0D0Qi[40`28VlD508VJa@/0RY_60P2;W<P05P2;W<L0RY_608ZKaP2:
W<@0Rig508bNaP2>X<P0UJC;09RVb@2X/m40^l?J0<W?g`3Lg^X0i>C^0=ON
j012CeL0>e9H05IiO@1QS980JYVO06fMY`1dY;0307FV[@D0MZN^0P1eYZd6
07JW[PP0MjR_00T0MZRc07f]]`1oZ[00JXnE04QVL@1_QI`0RIVk08JC_@2=
X<X00P2>XL/01@2<WlT0Rik808bMb02<WLP0Ric703P0RY_60P2:WLL02P28
VlD0TjG;0:^jf`2g`MX0`LSJ08^?V`3hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0
nOWi0??cl`3[jn/0hn?S0=oOg`3MgMd20=cLg0080>3PhP3<bm00b<O<0<c;
d03=cLl0blc>0<W;b038b/L80<c>c@0@0<_<d@39b/h0a/O;0<31a@2j^kd0
];Fg0;6b]02_/;80/[B_0:fa/01^MG/0N7n?07j8X@2;V;P0V:K;0:2_eQ<0
X:kA202Q[m840:2^d@0B0:6_dP2O[m40WjoA0:2^d@2O[M00WJc=09NVa`2B
Wl40SY^m08ZH]@29U[H0RI>f08^F/P1HHgL0NXJF08VAZ02LXl00Z;??0P2a
_=P00`2b_MT0/kkJ0;6lf0020;>nfP030;Bof`2c_]X0/kkJ00<0];oK0180
/kkJ0;6lf02^^]80Z;C>0:Jbc02R[/P0XZc70:>^a02S[/80Hfj007j9W@2>
VJd0W:Nm0:bfc`2g`M`0][oL0;JogP2e`>100;?1g0050;g:g@3;dnH0dmWW
0=GHh@2CU9P00P3oool00`3no_h0oooo0?ooo`0@0?ooo`00803oool0403n
o_h0oOgm0?[jnP3dm?@0k>c/0>GUi@3Ogml0g=cL0=[Jf03Lg=`0U9>A092=
Q02PWHX0]K2J0<Jo[@3?akX30=3;]`D0dLbh1P3BcKT20=?>^P<0d/fi1@3C
c[X40=?>^``0e<nl3@3Ed;d30=KA_P80e]300P3FdKh0103FdKd0e<nk0=;=
^@3Ac;P<0=;;^0@0dlbi303Cc;X<0=C=^`030=C?^@3Cc[P0d/fg0080d/fi
00<0dljk0=C?_03Ed;d00P3Ed/400`3Fdl80emC30=OD``0c0=OD``80fM?3
0P3Ge<403@3Kf<L0h^3A0>SVfP3Zimh0EeUH05eTP01SM:00KhF^082D]`27
V/80Qic708>La029Vl<01P2:W<@00`2;WLD0RYc408^Ma@0508^Ma@0408bN
aP2<W/@0S9k408bNa0D0SIo50`2>X<H508nQa`<0TJ373@2BXLP0602AX<L0
TZ7809:Qb02BXLP0TZ;609>Sa`2FY/X0V:S<09j/c`2[^=X0]L3L0<;:g`3>
eND0g>?]0=_PiP31a/X0>dY?045IG@1INWl0H8b?06BEVP1fZ:l0LZ:/07NW
/@D0MJJ]2@1fYjh:07NX[`0;07R/^@1_XJX0OJfa07RQY@1NP8T0C6Mh07R<
Y`2>W/00S:3508nSb02AYLX00P2BY<X00`2EY</0Tj;908nNa@0h09:Qb080
Tj?700X0TJ3709bZc@2`_]/0_LSN0<O=g@2<T9/0n?Sh0?knoP3oool0o_kn
0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0;0?knoP3oool0oooo0?ooo`3n
o_h0oOgm0?Win@3clo<0j^[Z0>;RhP3MgMd00`3Kfm/00`2YZZh0SXnD08J6
T00208J8U00308J:T`23R8`0PhR;00P0Q8V?0100QHVD08B8T`22QY40OX:;
07UmQP1eNH80LWMm075fO01_M7L0LGIj04I?F01]MXD0OHVO08bJ]`2GYLP0
X[7H602P[]420:6_dP@0X:kA0P2Q[m8209n_d@0@0:2^d@2O[M00WJc=09NV
a`2BWl40SY^m08ZH]@29U[H0RI>f08^F/P1HHgL0NXJF08ZBZ@2LXl00Z;??
0;6lf080/[gI00<0/kkJ0;6lf02c_]X00`2d_m/04`2c_]X0];oK0;Bof`2d
_m/0/kkJ0;:mf@2a_ML0[;SB0:Zed@2W//h0Yk7<0:Rbb`2X/lL0Hfj007n:
WP2@Vk40X:_10;2jd`2ja=d00P2ja=l00`2j`Mh0^<CL0;S4g00n0;S4g008
0<7<gP3>eNL0e]cX0=OJh@2CTYL0o_ko0?ooo`3no_hB0?ooo`00803oool0
403no_h0oOgm0?[jnP3emOD0kNg]0>GUi@3Ogml0g=cL0=[JfP3Lg=`0U9>A
09NER@2^[9L0`kjX0=;;^`3Id<L70=cFaPH0gMO70`3Nf<P30=gGa`D0g]S8
103Nf<X<0=oIb`P0g]_<0P3Mf//60=kKc080h=[>0P3Pf/`01@3Nf<P0fmK3
0=WD`@3Gd[l0e<fj0080dlbi00<0d/^h0=7:]`3Ab[L01@3BbkP50=?<^@/0
dlbj3@3DcK/02P3Cc[P0d/fg0=;=^@3Cc[/0e<nl0=OA`@3Je<@0g=K80=kJ
cP3Ofll20>3Ld0@0hMgA<03Qg/l0403Pg=00hMgA0>7Nc`3Qg/l0hn7B0>WW
f`3^jn80l>gV05EIG01TKHX0JgbZ07Z=]@2=X<00VJW;09b/d02I[/d209f/
c@`0WZg>0`2O[/l70:2_d0D0XK3?202R/M030:>bd@P0X[7@01P0XZoA0:>`
d02T/M40Y;7A0:Bbc`2V]=40Z[SE0:fkf02h`Mh0_<KO0=7Ik03Dfn/0g^Sb
0=CQj@22TIH0<TA8049OH`1LOH80IHjB06ZIW`1bY:/0K9jW07V[/P1bXjX5
07FV[@P0MZN^2`1gZ:l0401j[[T0LjF^07NX[@1m[K40MYnU059dP01BJgl0
O9:Z09>VaP2I[<`0WK3@09j^c`2N[Lh0XK3A0:>`dP2R[m4h0::ad00<0:Bb
c`2T/M40Xk3@0:bje`2obN80c=?U0=;Fh@2>TIP0n?Sh0?knoP3oool0o_kn
0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0;0?knoP3oool0oooo0?ooo`3n
o_h0oOgm0?Shn03bl_80jNWY0>7Qh@3Lg=`00P3Jf]X02@3Kfm/0T9FI07Ei
PP1aM8<0L7F806edQ`1`MhX0KgR9079lR008071gR@80LGR;00@0KgJ806]b
Q01WKX00I6]k0P1RJGT0201QIgD0HVYg03m8E`1_NX`0Oh^S08fK^02EXlH0
WjoC402P[]400`2Q[m80X:kA0:2^d@030:2^d@@0Wjg@0`2N[<l00`2O[M00
X:kA0:6_dP0209n_d@0?0:2^d@2O[M00WJc=09NVa`2BWl40SY^m08ZH]@29
U[H0RI>f08^F/P1II7P0NXJF08ZBZ@2MY<40ZKC@0080/[gI00<0/kkJ0;Bo
f`2b_MT00P2d_m/0102e`=`0];oK0;Bof`2d_m/20;G0g00>0;Bof`2c_]X0
/koI0;2leP2^^MD0[KSD0:fgdP2^^=40[[W=06=^P026T:T0VJBj0:Zeb`2j
aM/20<G=hP030<K>h`34c>40`/gQ03l0`/gQ00P0bmCU0=GLk03Nh^d0gMgU
09BCV03no_l0oooo0?gooQ80oooo000P0?ooo`0A0?knoP3moOd0n_[j0?Ge
m@3]kNd0iNGU0=oOg`3Lg=`0f][J0=_Kg@2EU980XInC0;jlY`3Ac;H0g]K9
0>CKeP3Sgm<01P3Th=@0103UhMD0i>3D0>CPe03Th=@:0>GQe@<0i^;F0P3U
hMH>0>KRe`P0in?H00<0i^;G0>OSf03WhmP01@3WhmP02`3Wh]`0in?J0>OS
fP3Vh]L0hmoC0=oLc@3LfLP0fMK50=O@_@3Fck`0e<fj00@0d/^h00<0dlbi
0=;;^03BbkP01P3Cc;T:0=?<^Ph0e<fk00P0dLnj0=;@^`3DdKh0emC30=[G
b03Ofll0hmoC0>GQeP80j>GL103Yi]d20>SUg300j>KJ0100j>CK0>WUfP3Z
i]/0j>KJ0>_Yg@3`kNH0lo3[0?;ak@1@EET0KWNF07^<^P2;Wl@0YKG?0;6l
f02c_]X0//7H1@2d`=X30;G1f`@0]<3J1`2e`M/50;K2g0<0]/;J202g`m/5
0;S4g0P0]l?M00<0]l7L0;S2g@2i`m`00P2i`m`0502lamd0`<_Q0<C?i@3B
en/0emc_0=SNk03Ih^/0VjZa03iBF@0aCU@0E7El05b8R@1QSY<0KYfS06jN
Z01gYk40MjV`06fPY01k[;00MZN^101eYZd207JW[P0307NX[`1fYjh0MZN^
0080MZN^101gZ:l207JW[P@0MjR_0P1hZK002`1eYJl0O[2i07>U[01hZK00
NJF^07ZPZ@1BLWd0A61/08:C[@2EY/00Z;SB0080[kgH00<0/kkJ0;S1gP2j
`n00>02g`md0302j`M/0]l7J0;W3g031bn@0c]GX0=SNjP3JgN80S8f?0?Sh
n03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool02`3no_h0
oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40g=cL00<0f][J
00P0RY6G071hP`1aN8/0MGbH07IoWP1lQjD0NXRS07b:Y0P0OHRT00H0OHNR
07b6X@1jQ9l0MX2K079lU@1^N94206afS`0806meS`1^MXd0ADeR071kT@1h
Qih0Ri^e09JUaP2O[m<@0:2^d@80XJoB0P2P[]4209n]d080WZc?0`2LZ/d0
1@2KZL`0W:[=09f[cP2N[<l0Wjg@0080WjoA00l0X:kA09n]d02M[<d0UjK7
09:O`@2>Vkd0RYRe08VF]P29TkH0S9Nc05UTN01kQiL0RY:Y09fT`@2Y]=00
0P2b_MT00`2c_]X0];oK0;:mf@020;Bof`040;G0g02d_m/0];oK0;Bof`<0
]L3L00<0];oK0;G1f`2c_]X00P2b_MT0302b^mP0/[cE0;:md`1TKh<0U:2j
0:Vcc02ia=X0am;V0=3IjP3Af>P0d][W0=;JiD00dMSZ00P0e]g_0=oUl`3V
j?@0h^?X09FDV@3moOl0o_oo0?gooQ80oooo000P0?ooo`080?knoP3moOd0
no_k0?Gem@3]kNd0iNGU0=oOg`3Lg=`20=_Kg@0609JET@2WYIT0bLNb0=_F
`03Vg]40j^7L0`3Xi=/:0>WUg0<0j^KM0`3YiM`:0>[Vg@<0jnON203Zi]d8
0>[WgPD0j^OP0`3[j>420>_VhP0:0>_Vh03YiM`0i^;G0>7Md@3Mf//0fmS9
0=WB_`3HdKh0eLjk0=?<^@80d/^h00<0dlbi0=C=^P3Cc;T01P3Cc;T00`3D
cKX0dlbj0=?<^P060=?<^PL0e<fk00<0eLjl0=C=^`3DcK/01P3DcK/0203C
d;d0eM:o0=WFa@3Nfl`0hmoC0>STf@3/j=d0kn_R103^jn@20>gZh`030>cY
hP3[j>40k>WP02l0k>WP0100k>OQ0>gYh03]jN00k>WP0>k[hP3bknX0lo;^
0??bl01:CeD0M7nO08VJb02L[]80^<KP0<?:i033bn80`/gO0P33bn8:0<C<
h`@0aLgT0P34c>4;0<G=hP<0a/kS1@34cn<30<G@i0P0a<oS00<0aLgR0<O?
i037cn@00P37cn805039dN@0c]KY0=;Kk03FfNP0d]KR09FLYP16DEL0=dY@
051[LP1IOXH0HXfF066GU`1_XZH0LJ:Y076Q[@1hZ;80MJJ]07Z[[`1aYJ<0
MZN^101eYZd207JW[P0307NX[`1fYjh0MZN^0080MZN^101gZ:l307JW[P80
MjR_0`1hZK00401jZJl0M:F/07NY/P1hZ[<0NJRb07JQZ01kX:H0FGYo04AF
K01ZNY40UZFl0;:neP2la]l0`<[S0<G<iP38c^Ph0<C?h`0<0<K=h034b^00
b=3U0<oFj@3GgNd0h>C]0=oPhP28R8H0n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`0A0?ooo`0;0?knoP3oool0oooo0?ooo`3no_h0oOgm
0?Win@3clo<0j^[Z0>;RhP3MgMd00`3Kfm/02029U9P0KgV5075lTP1kQZ@0
Pi2c08jL`@2;VK`0R9Ri202<VK/0402:UkL0RIJf08ND]023TJh0OH^X07V7
Y01gQJ80MXBO07^1X@1kPYl0C5Ia075mU@1fQI`0SIfg09VXa`2O[m4@0:2^
d@80XJoB00@0X:kA09n]d02O[M00WZc?0P2MZlh209ZXb`80VJO:00@0VZS;
09^Yc02MZlh0WZc?0P2O[m403`2P[]40Wjg@09f/c@2GY/L0TYo108jK_@2:
V;D0RIJf08VC]P2<Uk<0FFAh07^7U`2;TjX0WJC10:Vdd0020;:mf@030;>n
fP2d_m/0/[gI0080];oK00@0]L3L0;Bof`2d_m/0];oK0`2e`=`04@2d_m/0
]/;L0;G0g02e`=`0]L3N0;Fnf`2e_mP0]L3F06A_P`2R[LT0]/;L0<G@iP3C
fnh0f>7`0=OOjP3Ih^T0f^7W0400fn7a00P0gNCd0>K/nP3/k_X0i^O/09JF
V03moOl0o_oo0?gnoa80oooo000Q0?ooo`0?0?knoP3kno/0mOGe0>k^kP3V
i^H0h>3P0=cLg03Lg=X0eMGE09jLW`1FE5T0AD9;040lBP12>d/0B45C02P0
@Si?0P13?DL07P14?TP0AT1<04I0C017@Dd0BdEC051:F01?BeX0=c=402lZ
?P0i=4P0>S9703`eA`0g<400>cE303lgAP0l<d@0>S5603ddB@1:@E80K6A_
0:BNWP3Cc/P0f=?00=cGa03>bK<0eLni0=_E_`3>ak@0dLRi0=G;_`@0d/^i
103Cc;X00`3BbkT0dlbj0=?<^P050=?<^PP0e<fk0200clVi0=G@_@3FdKd0
c/Ve0=SA_P3Ab[L0d/^i0=_Da03Je//0fmO<0>CPe@3WiMT0j^[N0?CdjP3`
lN/0i^OQ0:bW[P21NhD0FE=Q040iB`0j<TL0?SI;03/cB00j<dD0@3UH04@o
E@1ABeL0<R`h02hW>@0g;DH0?39;03L]A@`0>31500@0>C5603XbA`0k<dP0
?3A9400m=TP203/h@`80?3U40P0m>TD203hkAP04048lB010>TH0?cU3040j
A080?cU500X0@C]904<lC00c:d<0F6=e07B:U`21Si`0RY>R08bNZ024Vj<0
RIZR202=VZ<808jKXb00SY^T01@0SibT092MY@2?W:@0SIZR08nLY02AWZH0
RiRP086>UP1EJVd0<TY>03AAE@1ALgD0Egn105^8R`1VUi/0IYVM07:SZP1c
Y:/0M:F/07JW[P80MjR_0P1fYjh407FV[@P0MZN^201gZ:l407RY/0D0NJR`
00/0MjJ^07>RZP1aX:P0LiJJ04e^L`0jEed0DVUa07N:T@2;V:40T9RS09:H
Y005096KY0<0TYbU1@2AVj@309:LY@D0TI^T0`2BW:D00`2AVZ40TY^R09:K
XP0409:KXP0309>LX`2BVj@0TY^T0080TY^T102CW:D409:KY0@0TibU1@2C
VZ@309BKY@0<09BMXP2:W:00Tj:Y09NPZ@2HYJd0Vjjb09ZTYP1LDU/0n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3o
ool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3J
f]X0202;THl0M7^>07b5YP24TZl0Tj:o09VYc@2IYlh0VJS7202JZ</0402K
ZL`0VZS;09JUaP2AX<40S9Vi08ND]024TZl0Pi6^08BB[`27TZh0EEmh06mi
TP1mQj00SIRd09RWb02Q/MD80:2^d@030:6_dP2P[]40X:kA0080X:kA0`2Q
[m820:2`dP0809n_d@2N[]00WZg>09^Zb`2HYlP0UJC509FT``2DXl8209>R
`@0E09FRa02HYLL0VZO909^XbP2IZm40VjgC09f_d`2L[m00Uj[:09:Ua@2>
XKl0Rijl08fK]P2<VKT0QiBf08NE/P1FHWP0NHJF08NDY@2KYkl0Z[GA0080
/kkJ00<0];oK0;G0g02b_MT00P2d_m/80;G0g080]/7M00X0/[gI0;K1g@2e
`=`0]l;N0;2ke`28Tjl0V9na09bS]@2SZ[`0ZK320P2]]<H00`2//lD0Z[73
0:fc_`0O0:fc_`0@0:jcaP2//lD0Zk;50:Vb``2[//80[[C20;:f`@2e^<40
]k[;09jQZP35a<T0`/330<:ob032_lX0`/770;jo`A00`<7600L0`<300<G5
a@3<c<`0^;Rh0<S8b03gmoL0o_kn01<0oooo000Q0?ooo`0?0?knoP3kno/0
mOGe0>k^kP3Vi^H0h>3P0=cLg03Jf]X0g=cL0;>a]P1jMgh0MG9m07UeQ01o
N8X0QWjC02P0QH2D0P28PI<07P29PY@0RX:G08^3V02=QIX0U8bQ09^CZ02X
XkL0Lfj405UCK@1XGg`0KVF207E/R@1dJhH0NFn:07AZP`1fK8L0N6f=07Q]
S`1cJ8H0J5if05YAHP1@B5<0WiND0=?<a03Le/P0clRe0<c6/03Hd[`0d/^i
0=C;_0<0d/^i2`3Cc;X:0=C=^`0P0=KA_P3@bkP0clZf0=7<]P3DckT0eLjk
0>;Kb`3Fc/40g][?0>_Wg03akN@0lNkW0?7`k03GeMH0RXR;03Xi?P1BBed0
Dd]R065IL@1/Hh00L6N607A[RP1eK8T0N6n<07]cVP28Oih0UHfT069JL@1A
B6D0GE5e06AHO01REgT806AIN`D0HeQj0`1TFG/@065FMPP0HEMl0100Ge=g
05iBMP1ODgL0H5Ah065EN@1SEg/0J5b206eQQ`18@5P0@DiN03YBGP0hBUP0
?TiK041KHP0lFEl0@5UP200oF5l803mHGB00?eQO00D0?EIK03mHG@0nEe`0
?EIK03iGG002049KH00903mHG@1ELWH0E75e05amPP1URY00IHjB06VFV`1a
XZL0LjJZ0080LjB[00<0MJJ]07JW[P1fYjh00`1fYjh407FV[@P0MZN^201g
Z:l407RY/0@0NJR`00`0NZVa07RW[`1fYJd0M:>[07JRY@1`VId0I8V?05Ig
OP1:Ifd0A5eT04EIHP16FV<2049IG`/0@eYP0`14Ff4204=JH0H0A5]Q1017
G64404QMHPH0B5aS0P19GF@404QLH`@0BEeT1P1:GF@204]NI@0<04UNH`14
H6<0B65V04ePI`1FJW40EG=e07N;S01jNGl0n?Sh0?knoP3oool0o_kn0P3o
ool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0
oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>U980N7nB0829
ZP29Uk@0VJS509n_d`2O[M@0Wjk=2@2P[]403`2O[M00W:_<09NVa`2BWkl0
SIZj08ZH]@29Uk@0QYBa08RC[`1FH7T0L7ZC07f7X02=V;@0UjK70:2`e00>
0:2^d@80XJoB01<0X;3B09n_d@2M[Ll0WJc=09^Zb`2HYlP0U:?409>P`02?
W[d0S9^j08^J^@2?W;`0T9fm08nL_P2AW/00UZ3309BRa@2JZ</0WJc=0080
VZW:00`0VZW809:Q`027U[D0QiF`08VF]P2:UkT0S9Ne05MSN@1nRi/0RiR[
09JP^@2Z]M420;>nfP030;Bof`2e`=`0/[gI0080];oK202e`=`0202d_m/0
]/7M0;Bof`2h`ml0];oK0;G0g02g`]h0Xjk:0P25SJ0308J>X@0308F=X024
S9l0Ph^N0200Q8^N0P25S9l03P24S:40PXfQ08F=X02;TZ80TYRT09RLY`2I
W:/0Kg9i0;Fe]`2k^KX0^[Nn0;bi`P2k^[l0^K^j402h^Kd01@2m_Kd0]KFe
0;bl_034a<@0h^;R0080oooo00<0o?cl0?ooo`3oool0403oool00240oooo
00H0o_kn0?_kn`3emOD0k^k^0>KViP3Ph>020=cLg0070=gMg`2d/KP0OGZ5
07YfQ@21OHh0Rh>J09B<Y00X09R@Z0D0V8n/01/0Vi:_0:JM^P2`Yl@0`KcB
07E_R@1EC6/0KVB707]`V023N:80PgJQ08EhX`24N9`0QGVO08=fX@22MJ<0
QGRT08QlY023Mi/0NFj>06MLK@1`IVl0aKfk0=7;_@3GdK/0d<Zb0=?=]`3B
bkP03@3Cc;X;0=C=^`0P0=;=^@3Cc[X0fmK00=SC_@3Gd[h0e<nl0=cFaP3Z
i=H0k>SM0>_WgP3km_80hMgN08J1R017@e40DDeN06MRN01_I8H0LfN;07ib
V021M9l0OW6L081cWP22MJ00R7bT08f1/@2MT[X0[JC306QOOP1@A6`0IeZ8
06mQTP1aI988075QTP<0Lf>D0`1bHY<2075QTQ00Ken>00@0L5nE06mNU01_
GY@0KejD0P1^GI<206eLTP<0JeZ>00d0K5^?06]JSP1]G900MFBH07i]X@1V
HGL0D61_04iZM@1GLWd0H7^40625R`1NQh/0I8N=00P0HHR?201PQh`P0627
SP0=0627S01QR8d0HHR=0627S01NQHX0H8N<06>:S`1US940GhB:06ZAUP1^
Uid0K9NM076NY00207BSZ`0307>TZ`1dYJ`0MJJ]00<0MJJ]0`1fYjh307FV
[@P0MZN^201gZ:l507RY/0<0NJR`0`1jZK402@1iZ;00N:N_072OY@1eY:X0
MJ:X06fHWP1XTIL0JI2G06V>U00306F:T0P0IX^A1P1WS98506R=T`<0JHjD
1@1ZT9<306^AU0H0KI2F0P1^TIL00`1]T9H0KY6G06jAU`0406jAU`D0Ki:H
101`TiT0301bU9H0LIVK06fBV01dTIT0QZFZ08J^[P2K]kP0TIRN0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo
0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J
00P0SI>A07MnT@1oR:T0RINd09VXa@2P/=@0XJoF0:6`c`T0XJoB00l0X:kA
09f/c@2HYlP0Tj3008jK^`2;VKH0RINd08RF/`2:UK40F69k071jT`1mQj00
S9Nc09JUaP2O[m<0402P[]40502O[m40WJg?09^Zb`2IZ<T0UZG609>R``2@
WKd0SY^k08fL^@2?W[/0SI^h08VG]02:V;D0Sibl09BO_`2BWKd0UJ>n09ZX
``2LZ/D0VJO40P2GYL802`2CX<00S9Vi08VG/@28U[<0S9Ji08ZE/`1@GG00
MhBD08bGZ`2KYKh0Z[GA0080/kkJ00<0];oK0;G0g02c_]X02P2e`=`02P2f
`Md0^<?O0;G0g02h`ml0]L3L0;6lf02ia>00]/7M0;O3f@2f`]P30;G1e`03
0;K2f02g`mT0^<CJ0200]l3M00`0]koF0;K1e`2d`=P0]<3F0;O4e`2nbM/0
bm;R0=?Ii`3Cen<0TiJK0?Wim`3oood20?omo`030?ooo`3nood0oOon00l0
oOon00<0oooo0?clo03no_h00`3oool00`3lo?`0o_kn0?ooo`0A0?ooo`00
8@3oool03`3no_h0no_k0?Gem@3^k^h0i^KV0>3Ph03Lg=`0g=cN0=cKh02b
[kH0O7V407ijR`2;QY`0Vi>[0:RO^P0X0:^R_@80Zj;101l0ZZ700:VP_@2W
W[/0Zj:o0;N^b`32^MH0b<CE07Q`Q`1KDVl0O7:E08QmY`2@Pk40THBb0963
]02@Q:`0UHRd09J9]`2CQKP0TH>f09>5^02AQ;80S7n]08IjX01_IH00HUMU
0;jf/`35_jl0cLNa0<k8/03@b[80dlbj00<0e<fk00<0dlbj0=;;^@3BbkT0
1@3Cc;X<0=C=^`0P0=;=]`3DckT0cLRb0=C?^@3FdKd0f=G40>gYg@3Xi=T0
m_;Y0?[el@2aZjl0DD]G04i6G@1[HWl0K6:407M]T01mLIT0P7BL08UlZ02=
P:h0T8:c09B7]@2CQ[@0UHRd0:>Ga`2`YLd0_kGG06mTQP1EB7<0MFNJ07a[
X@1mK:08081/Y`0407m[YP20K:L0P6bW081/Y`80Of^V00<0OVZU07eYY01n
Jj<03`1nJj<307i/X080OF^O0`1lJYh0401mJi/0O6ZL07aZW01lJYh0NFNI
07]YV`26M:@0Th:_071[P@1AHg40EGN006>4S@1VRi<0Hi>G06BGVP1YVI/`
06VHWP80JYVO0P1[VZ002P1YV9h0IYFK06NFW01[VZ00KijT07:QY`1_WZ@0
LJ2X07RW[`1iZ;8207FT[P80MZN^101eYZd207JW[P80MJJ]201fYjh807NX
[`H0N:V`201jZK401P1hYjl0MZF]07FT[01eY:`0Lj:X06nNY080KIbR101`
WJ86076NX`H0LYnT1P1cX:D207BQYPD0MJ2V201fXJL707NRZ0@0N:>Y0P1j
XjT607^TZP0<07ZQYP1iYZT0OjR^08NX/@2F^Kl0Y<k=0;?Ad`25SYD0n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3o
ool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3J
f]X0202;THl0MGb?07f6Y`27UK80UjK309j^dP2O[M@0Wjk=2@2P[]403`2N
[<l0Vj[;09JUaP2AW[h0S9Vi08VG]028U[<0RINd08^F/P1IHg`0LG^D07j8
X@2=V;@0UZG609n_d`0;0:2^d@0>0:6_dP2P[]40X:kA0:2^d@2O[M00WZk@
09b[c02IZ<T0UJC509:Q`P2?W;`0S9Vi08ZG]`26UK8208RF/`0;08VG]02<
V[D0SIRd07n:YP1`NiL0J7B:05eYO`1KIgl0JgNA086<Z02?V[H00P2BWK/0
2@2:VK00RIB`08RC/`2;U[80EfAg07Z6UP2:UJT0WZS10:^fdP030;Bof`03
0;G0g02c_]X0]L3L00T0]L3L00<0]/7M0;S3g`2c_]X00P2f`Md00`2b_MT0
]L3L0;G0g0030;?1f`D0//3J802d_ml0402g`M`0]/;L0;C2g02c`M/0]<?J
0;g:g@3;dnH0e=_[0=KJi@2;Si80o_oj0?oon`3ooOh0o_co0?ooo`3mooX@
0?goo0040?gmo@3oool0oooo0?ooo`80oOgm503oool00240oooo00l0o_kn
0?_kn`3emOD0k^k^0>KViP3Ph>00g=cL0=[Jg03Lfn00];6h085mR`24P940
THbS0:6H/`2]Y<40:02aZ<D0502bZLH0/j[50;>Za@2bZL@0/:S00;B/a030
^<l0c<CK0=C>fP20NHT0I5ac08AiV@2<P:H0UXVe09^>_02LS;/0WHjg09^<
]`2IRKH0VHVh0P2IRKX0302GQkP0UHFf09B6]`2?Pj/0K69m06iTK`2m][00
al6a0=7;/`3;aJ/0d/^i0=?<^P80e<fk00<0dlbj0=;;^@3BbkT01@3Cc;X<
0=C=^`0P0=WB_`3Ac;H0dljj0=_F`P3Og</0h]kB0>OTf`3hmO00kn_Z07Ye
N@1;AE<0GE=/071UQ`1hK9@0N6^F08f0[02AQJ/0ThN_09V<]`2FRKD0UHRf
09R;]`2IS;L0X9Bl0;6Vd02k/M<0b/3K07I[R@1LD7P0OVjO089aY@25M:P8
08Md[080QW>[0`27M:`208IcZa40QG:Z1026LZD408EaY00@08AbXP23LJ40
Q7:V08EcY`23LJD0QgFU09J5/@2VUKl0QgnF05Q[N@1FNh<0H8N>06VDVP1]
XjD0L:Z[07>VZS40MJB/00@0Lj:Z07BSZ`1gYZh0MjJ^0P1dXj/02`1fYJd0
LjR^07:W[@1eYjh0MjVb07FU[`1dY:h0MjJ`07ZY/`1gZ:l0MZN^00@0MJJ]
201fYjh807NX[`P0N:V`0P1iZ[4807ZY/@08086[]`1mYk<0OJNc07n[]01m
ZK80MjJ^07RW[@1n[K<307bY[`D0OJZ`1@1nZk4907n//P80P:fc1021[;<8
08:]]0@0Pjje1P24[kH208F`]`80QZjf1P27[kL0302;/[T0PZfc08Va^@2H
]/00X/380:g@dP30f=X0S8nF0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0
l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SI>A07MnT@1oR:T0RINd09VX
a@2O[m<0X:kE0:2_cPT0XJoB00l0Wjg@09b[c02GY/L0TYno08fJ^P2:V;D0
RINd08RF/`2:UK40F69k075kU01nR:40SYVe09NVa`2P/=@02P2P[]420:6_
dP80X:kA0P2O[M002@2N[Lh0Vj[;09JUaP2CX<00Sibl08fJ^P2:UkL0RiJd
08ZH]@0208bJ]@0F08NB[P1hQ9h0Ig>=05m[P`1OJH80Hfj206YeR@1aO980
K7J?05iXP`1IHgh0JW>@0829YP2<V:h0SiZf08VD/P2:Tk00FfIj07j:VP28
TjL0WJC00:^fdP<0];oK00<0]L3L0;>nfP2e`=`02@2e`=`01@2c_]X0]/7M
0;>nfP2c_]X0]/7M0080]L3L00<0];oK0;G3gP2e`mh00P2e`mh20;C2g@03
0;?1g02b`=/0/l7L01l0/l7L00X0]/7M0;O2gP2e`mh0/l7L0;C2g02lb=h0
b=?W0=;Kk03Ff^<0T9BG0P3ooo/0103oo_l0o_co0?ooo`3nooX@0?ooo@03
0?knoP3oool0o_kn00@0oooo00<0n_[j0?ooo`3oool0403oool00240oooo
00l0o_kn0?_kn`3emOD0k^k^0>KViP3Ph>00g=cL0=SHf03Jf]`0];6h085n
R@25PI80ThjU0:>J]@2`YlH0:02cZ<P04@2bZL@0/j[50;B/a02d[<@0/j_2
0;R`a@34_=40d<SM0=C>f01oNHL0HEQ]07mdTP2:OZ80UhZe09f=^P2JR[L0
WHjg0080VX^f00l0WHji09f=^P2KRkP0Vh^h09f=^P2EQkX0V8^i09jB^01X
GWL0Ng5l0;be[`32_JT0cLV^0<o8]P3Ab[P00P3DcK/00`3Cc;X0d/^i0=?<
^P040=?<^Pd0e<fk0P3Ec[/04@3Gd[l0f]O60=gIc@3dlNX0moKd0>CRh`1W
HF/0DDYJ06QPN01cJ8X0MVVD08mo[02DQ;40TX:_09R9/02IR[<0WXnj0080
WHfj00/0WXnj09b=]P2RTkX0[Z;60;^ac039_mL0Mff605e?L`1lK9/0QGBX
08YjZ`0808MdZ`<0R7F/1029MZdA08Qe[080R7>^1029M:l208Ye/00@08Qe
[027M:`0R7Ba08Ue]029MK80SGZb09n=_`2aWll0RH6H05MZN01HOhH0H8V?
06fJX01`YjX0LZb^076TZ0P0MZF_201fYJdP07JU[`0507NV[P1dXj/0Lj:Z
07FT[01gYZh00P1fYJd02P1hYjl0LJJ^076V[P1eZ[80MZRa072RZ`1dYJ`0
N:V`07BU[01gZ:l207JW[P<0MJJ]1`1fYjh807NX[`P0N:V`0`1iZ[4207ZY
/@0407^Z/P1jZK40NJR`07VX/080NZVa00P0PZZf082X]01mYk<0OJRa07fY
/P1nZ[<0OJZ`07VX[PH0OZZc0P1oZk@3082[]0X0PJbe0`22[KH608J^]PL0
Qjng1@28/;P608Va^@@0R[2i102;/KX0302=];/0R;>j08bb^`2N^/D0/<_D
0;SGfP34f=T0ShbC0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3o
ool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WY
j@3QhN40gMgM0=_Kf`80f][J00P0SYBB07QoTP20RJX0RINd09VXa@2O[m<0
X:kE0:2_cPT0XJoB00l0X:kA09b[c02GY/L0TYno08fJ^P2:V;D0RINd08RF
/`2:UK40F69k075kU01nR:40SYVe09RWb02P/=@02P2P[]420:6_dP80X:kA
00P0Wjg@09j/c`2LZl`0V:O809BQ`@2?W;`0S9Vi08^H^080RiJd00P0QI>^
08bJ]@27TZh0L7bF05eYP@1OJh40K7N=07AoU@80MX6G00l0Mh:H07^5WP22
S:D0OHNR06I`R`1?FG@0KGZ=08:>Z02;U;<0RI>^05AOL`1jQYH0Ri>X09fT
`02[]]800P2d_m/20;G0g0030;>nfP2e`=`0]L3L00P0]L3L00H0/kkJ0;O2
gP2f`Md0];oK0;>nfP2d_m/20;K1g@D0//3K00<0/l7L0;G3gP2e`mh0802d
`mX0402d_MX0];oK0;?1gP2b`=/0/l7K0;_7g`38d>D0dMS[0=;Fh@2CUiX0
oOki0?gln03no?d0o_co0?knoP3lo_T@0?kno0030?clo03moOd0oOgm0080
oooo00<0o?cl0?knoP3oool04P3oool00240oooo00l0o_kn0?_kn`3emOD0
k^k^0>KViP3Ph>00g=cL0=gNf@3MgM/0/k6d07ikQ020O8/0SXVO09nF/@2]
Y<40:02bYlD20;2WaP80/JS50240/JS30;J^aP32^]40cLGL0=?<g020Mh`0
HEMb089gV@2@Q:`0W8bi09f=_02KRkX0UhNf09V9^02LS;T0WXnj09b=^02I
RKH0VXZg09f=^P2HS;X0UXVg09R;^@2KSkD0Jf5i09J=TP33_Jl0`[jS0<_4
/P3?b;H0dlbj0=G>_03DcK/00P3Cc;X00`3DcK/0dlbj0=?<^P0>0=C=^`0P
0=7:^03LeLD0em710>WUf@3VhmX0n?Oe0=cJg@1JFEl0E4aQ06=JM@1eJhd0
PGBO08alZ`2APJh0U8F`09n?]P2NSkX0VXZg09V9^02HR;L0WHfl09j>^`2K
S;L0XY>l0:nSa`2o]M00b/3H07U/R01LCG@0NVZK08EdZP27M:/908Mf[@L0
QWF/4027MZd00`27Lk00R7Ba08Qd/@0508Qd/@0@08Uh[`27MJl0QgFc08Uf
]P28M[@0S7Zd09j>_`2bX/l0R82E05MYM`1JPHP0GXV?06bIW`1]XZP0M:V_
07bX/@P0MJJ]:01fYjh00`1gZ:l0MZN^07FV[@0207FV[@0507BU[01eYZd0
MjR_07FW/01dYZd00`1eYjh00`1hZ[40N:^_07:UZ@0<07JW[PP0MjR_201h
ZK0407VZ/@0407VX/01jZK40NjZb07^Z/P<0NZVa00L0NjZb07VX/01m[;@0
Ojjf07b[/`1kZ[00O:^a0080OZfc00<0O:^a07f//P1m[;80101m[;800`1n
[K<0P:fc082]/`03082]/`L0PJjd1022[kD708F`]`0308Ja^026/KL0Q[6g
0080Q[6g1`27/[P508Rc^@0308Zc^@2;];X0RkBj00@0RkBj00d0S;Fk08N`
]P2:^[h0SKJl09Rf_P2Zald0]MGD0<CHe`2BT9D0n?Sh0?knoP3oool0o_kn
0080oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0
o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0S9:@07Im
T01nQjP0R9Jc09RWa02N[]80WjgD09n^c@P0Wjg@00L0X:kA09n]d02LZl`0
UjK709:O_`2=V[X0RYRe0080R9Jc00L0RYFa05QRN`1aNi@0OXRQ08fH]02G
Y/L0X;3D00X0X:kA0P2Q[m802@2P[]40Wjg@09j/c`2MZlh0VJS909NTa02A
W[h0S9Vi08ZG]`0308^F]00I08^I]023SZX0L7bF065]Q@1TL8H0LGb@07F0
U01aO8h0OHVS08VE[`2?VkD0RiNa08JBZP23SjL0OXZR07J2V01FHg@0IFn8
07Z3X029Tjh0EF1d07f6U`2?Uj`0WJC00:^fdP020;Bof`030;G0g02f`Md0
/kkJ00X0]L3L00@0]l;N0;K1g@2g`]h0]/7M0P2c_]X01@2e`=`0]/7M0;S3
g`2g`]h0]/7M00<0]L3L0P2f`MdP0;K2g00@0;Rof`2g`=d0]l;N0;K1g@2h
a=h0`<_Q0<gDi`3Dfnd0e=ST09>FV`3oood0ookl0?klo`3oo_l0o?cn0?cn
na80oooo0P3no_h20?ooo`030?gmo@3oool0oooo0140oooo000Q0?ooo`0?
0?knoP3kno/0mOGe0>k^kP3Vi^H0h>3P0=cLg03If]@0f]_F0;>a]020OHH0
Q82?09:=X@2RVK@0[jK302P0/jS602D0]:[?0;>YcP2cZL`0/ZS:0;:Yb02f
[LX0`[WD0<g4g`3Ebn<0PGNB061EM@21MId0TH6^09R8^@2IRKX0W8bm09j=
``2LRkl0Vh^l09^;^P2LS;T0WXjk09f=_02KRkX0V8fg09b@_P2EQkX0Wi;0
08QmW`1]Hfh0[JJL0;^gWP39`[00cLJd0=;;^@3Ec[`0e<fk0080dlbj203D
cK/00`3Ec[`0e<fk0=C=^`060=C=^`0C0=SA`@3Dc;l0i^3B0>CPe@3im_40
hn7R06UXKP1=BeH0J5mj07U_T@1oM9`0SH2^09N7]P2HR;D0XY:i09b</02M
SK`0W8bm09f<`00209b;_`0;09Z:^`2IRKP0Y9C10:nSb@31]]@0akgF07MZ
R01MCWT0OFbR08Yf/@25LJ`02027MJl208Ug/@0308Qf/027MJl0QgF_01<0
QgF_2027MZ`04028N:L0QGBX08Ie[027MJl0QgJ]08al[@2OT;T0/jG908b3
V01GJGD0F7n60628T01`Vj80L::Y07BV[@1lY;0807>X[PP0LjR/801cZ:h0
101`YJT0LZN[07BY[@1cZ:`207:WZ`0307>X[01eZZh0MJJ]0080MJJ]00D0
MJN^07FX[01bYJT0LZFY07NZ[P0707JW[P0307NX[`1fYjh0MZN^0080MZN^
201gZ:l807RY/0@0NJZa00@0NJR`07ZY/@1lZk<0O:^c0P1kZ[801@1lZk<0
OJbd07Z//`1hZ[40MjZ^0080NJb`00<0NJZ^07Z[[`1l[K401@1k[[8307b_
/`D0OZfc0`1o[[@4082_]@@0PK2f1@21/KD308:b]P<0Q;6d1`25/[D608Jc
]P80QkBg1P28]KP03028^;`0QKRk08Nd^@2I_<80Z/c>0;;Fe032f=D0SXj@
0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303n
o_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_K
f`80f][J00P0S9:@07ImT01oR:T0R9Jc09VXa@2O[m<0X:kE0:2_cPP0XJoB
0100X[3C0:2^d@2M[<d0V:O809>P`02>Vk/0RiVf08ZH]@29Uk@0RYFa05QR
N`1aNi@0OHNP08fH]02FYLH0WjoC2P2P[]420:6_dP080:2^d@2O[M00WZc?
09f[cP2HYLD0U:7108nL_02:UkL208ZE/`80RiJd00P0SYVe071kU`1MJH<0
Ig>;07=nU01eP9@0OhZL092K[@80Uj;000l0V:>o09RT_P2FX[X0T9bb08NC
Z@20SJ00P8^M065[Q01QJXL0NXBO051HK@1mQYL0TYZa09ZQ_@2[]]800P2d
_m/00`2e`=`0]/7M0;>nfP0:0;G0g0040;S3g`2`^mL0/kkJ0;K1g@<0]L3L
00<0];oK0;FofP2e_mX0102f`=/20;FofR00]L3L0P2h_m/03P2f_m`0];oK
0;O1g030b=l0bm;U0=?Hj`3Ff^H0Si:G0?ooo`3oo_l0o?[o0?omo`3lnol0
o_om403no_l20?gmo@040?ooo`3no_h0oooo0?ooo`80o_kn4P3oool00200
oooo0100o_kn0?gmo@3kno/0mOGe0>g]k@3UiND0gmoO0=cLg03Jf]`0fm_K
0;>b/01oO8<0PgjB096;Y`2QV;<0[ZJn:02bZLP20;:YaP80/ZW800`0/JS5
0;J]b033^m80clOL0=??g@21NHh0H5Md085eV`2?PZd0VXZi09^;^02MS;T8
09b<^`0<09^;^P2KS;L0V8bd09fA^@2VV/00NW2908V4R02`[Z80_kRX0<S1
/@3Ab[P0e<fk0P3Cc;X20=C=^PT0eLjl00@0e<fk0=?<^P3Ec[`0eLjl0P3D
cK/04`3Fckd0e]300=oLb`3RhLl0j^_M0?ckm`1gLG/0FDmW06YLO@1eIXd0
PgBK0962Z`2FQk80VHVf09b<^`2MSK`0Vh^l09^;^P2LS;/00P2KRkX0302L
S;/0VXZi09b<^`2RT/40[jC<0;jedP38_]H0MF^405i@M01mKIh0QW>[08Qe
[BP0R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;2Qb02:PYL0
F6ag05MnQ@1RRi40KYVP07:UZ@1bYjd0NJF^@01fYjh00`1eYZd0MZN^07JW
[P0907JW[PP0MjR_101hZK0407VX/0P0NZVa101kZ[800`1kZ[00O:^a07b[
/@0507b[/@@0Ojbb1@20[K<7086^]0@0PZne1023/;H00`24[kH0QK2g08F`
]`0608F`]`L0Q[6h1027/[P408Rc^@0308Zc^@2;];X0RkBj00D0RkBj0P2:
]K/02P2<]K/0U[g20:_:c@2idM<0amGF08VBT@3hn?P0o_kn0?ooo`3no_h2
0?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?kn
oP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40
OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h90:2^d@0609n]d02LZl`0UjK709:O
_`2=V[X0RYRe0P29Uk@01`2:UK40F69k075kU01nR:40SIRd09NVa`2P/=@0
2@2P[]40302Q[m80X:kA09n]d02P[]40XJoB09j/c`2JZ</0UjC409BQ`@29
U[H0SIZj08ZE]@80RiJf00/0RIBd07j6V`1NIW/0JgJ<07EoV01bOYP0QI>^
09BR_@2MZlP0X:o@0:6`d@020:>`d00=09n]bP2HY/<0TIbh08^F/P21SjT0
PHfU06M_QP1BFF`0@4MI08B;WP2:TZD0WZVm0:^fdP020;K1g@80]L3L00<0
];oK0;K1g@2e`=`04`2e`=`20;K1g@<0]L3L00<0];oK0;G0g02e`=`0102e
`=`00`2d_m/0]L3L0;G0g00F0;G0g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0
_LSN0<_Bi@3DfN`0eMWT092DU`3no_`0ooom0?omo`3oo_l0o_ko0?konbX0
oooo000P0?ooo`0@0?knoP3moOd0no_k0?Gem@3]kNd0iNGU0=oOg`3Lg=`0
f][L0=_Kf`2c/[00Ogb308=nTP2ARjL0XIRc0:jV_RP0/ZW80P2bZLH20;:Y
b00<0;6Xa@2f[LP0`k_B0<o7g03Ccmd0PGV>061GM021MI/0Sh:]09Z:^@2K
RkP0WHbi202LS;/02`2JR[T0VHVf09^>^@2OT[d0YY[20967XP1hLgT0ZJJM
0;^dY035_Zh0d<Vg00<0e<fk0P3DcKX90=G>_0040=C=^`3Cc;X0eLjl0=G>
_080e<fk01<0e/nm0=[DaP3JelP0k^cO0?;bj02f];D0G5IT06ILM`1cIHP0
PgBK08ioYP2HRK80VX^f09Z:]`2LS;/0WHfl09^;_02KRkX0W8bk0080Vh^j
00`0W8bk09Z:^@2LS;/0XY;10:nTc02n]M80b;kF07E[Q01ND7@0OFfN08Ic
Z`28MJdX08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`XLP0
RX:G05Q/M`1GOXD0HX^A06jIX01bYJT0LZN]07VU[TH0MZN^0P1gZ:l407JW
[PP0MjR_101hZK0407VX/0P0NZVa101kZ[8607b[/@80OJbb101o[;84082]
/`H0PJjd1P22[kD408>`]PH0QK2g2026/KP208Nb^@@0Qk:h1028/kT608^d
^P80S;Fk0P2:]K/02P2<]K/0U[g20:_:c@2idM<0amGF08VBT@3hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3o
ool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP08
08jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h90:2^d@0609n]d02L
Zl`0UjK709:O_`2=V[X0RYRe0P29Uk@01`2:UK40F69k075kU01nR:40SIRd
09NVa`2P/=@02@2P[]40:02Q[m80X:kA09n]d02P[]40XJoB09j/c`2JZ</0
TYno096N_P29U[H0RiRh08RC/`2:UKD0SYVg08JA[`1VKX<0Ifn406mjT01d
OYL0QI6[09RV`@2MZlP0YK?@0:Bce02U]=D0YkCD0:Jcd`2S/Lh0W:[709JQ
_@2AW;P0R9J`08FAZ@20R9l0KWF803a3EP1iP9<0SIFX09fX_02[]]820;K1
g@80]L3L00<0];oK0;K1g@2e`=`05P2e`=`20;Bof`80]L3L1P2f`MdH0;G0
g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3DfN`0eMWT092DU`3n
o_`0ooom0?omo`3oo_l0o_ko0?konbX0oooo000P0?ooo`0@0?knoP3moOd0
no_k0?Gem@3]kNd0iNGU0=oOg`3Lg=`0f][L0=_Kf`2c/[00Ogb308=nTP2A
RjL0XIRc0:jV_RP0/ZW80P2bZLH20;:Yb00<0;6Xa@2f[LP0`k_B0<o7g03C
cmd0PGV>061GM021MI/0Sh:]09Z:^@2KRkP0WHbi202LS;/0302KRk`0V8Rg
09b?^`2MT;`0YIS30:bQ_`1[IFl0WibG0;F^WP31^ZX0cLJd0=?<^P80e<fk
0P3DcKX90=G>_00I0=C=^`3Cc;X0eLjl0=G>_03DcK/0eLjl0=O@_P3Le/X0
h]kB0>gZh@3`kn/0Hf5V05QAH`1]HX80P76H0921ZP2GR;40WHjg09b=^02K
RkP0W8bk09f=_02LS;/0Vh^j09b<^`0209^;^P0<09b<^`2JR[T0W8bk0::B
`@2_Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0
QgB/08Qd/@28M;40QWF/08ak[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^
VJ00LZFY07:W[@1iYJi507JW[P<0MjR_0`1fYjh807NX[`D0N:V`0`1iZ;08
07ZY/@D0NjZb1@1lZk4307f//P<0Ojbb1@20[K<5086^]0H0PZne1@23/;H5
08F`]`P0Q[6h0`27/[T308Nb^0D0R;>i1@2;];X308be^`80R[Fk00X0S;Fk
09Jm`P2[b/d0^];D0<OEeP2:Ti80n?Sh0?knoP3oool0o_kn0P3oool00`3m
oOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Sh
n03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0
V:W509n_d`2Q[mH0XJk>2@2P[]401P2O[M00W:_<09NVa`2BWkl0SIZj08ZH
]@80RINd00L0RYFa05QRN`1aNi@0OXRQ08fH]02GY/L0X;3D00/0X:kA00T0
Wjg@0:2^d@2P[]40WJ_>09VWbP2BWkl0T9fm08^H^02:UkL00P28Tk401`2;
U[@0LWfK05iVN`1_NY00MX2I07j:Y02HXkl00P2T//l00`2W]]D0YkKG0:Rg
f0020:VfeP0=0:Fcd02O[LX0VZG109FP_02AWkX0R9B^08^CZP21Qid0ADaO
07^2U@2AVJh0VjJj0:^fdP020;K1g@80]L3L00<0];oK0;K1g@2e`=`0402e
`=`00`2f`Md0]L3L0;G0g0020;G0g0<0];oK0P2f`Md40;G0g080]/7M602e
`=`0402e`M/0]L3L0;?1g02c`M`0]/;L0;g8gP3;d^D0e=W/0=GIi02@U9L0
o_kl0?ooo@3ooOl0ooko0?kno`3noo/Z0?ooo`00803oool0403no_h0oOgm
0?_kn`3emOD0kNg]0>GUi@3Ogml0g=cL0=[Jg03Kfm/0/k:`07mlP`23OY80
TH^W0:6H/`2^Y[hX0;:Yb080/ZW60P2bZLP0302aZ<D0]Zg80<>kdP3?am`0
dloM085iSP1PEg@0PGFK08n2[@2JR[T0Vh^h09f<^@P0W8bk00`0WXjo09V9
^02KS[`0VXfk0:BG``2fZld0L6Yh09JBS`2^YiL0_;FU0<_4/P3Cc;X20=G>
_0030=G>^`3DcKX0eLjl00P0eLjl0P3DcK/20=G>_00A0=C=^`3Ec[`0f=6o
0=oHcP3Zi]d0j^OR0<2n_`19AU40JF5i07AXS029NZD0U8F`09V:]@2LSKP0
Vh^h09Z:]`2KRkX00P2LS;/0402KRkX0W8bk09^;^P2KRkX0W8bk09Z:^@2L
S;/0XY;10:nTc02n]M80b;kF07E[Q01ND7@0OFfN08IcZ`28MJdX08Qd[`0@
08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`XLP0RX:G05Q/M`1GOXD0
HX^A06jIX01bYJT0LZN]07VU[T@0MZN^101gZ:l207JW[PP0MjR_1P1hZK02
07VX/0P0NZVa1P1kZ[8407b[/@@0OJbb0P1o[;86082]/`@0PJjd1P22[kD6
08>`]P@0QK2g2026/KP408Nb^@80Qk:h1P28/kT408^d^P@0S;Fk00`0RkJl
08Ze^`2<]K/0U[g20:_:c@2jd]@0amGF08ZCTP3hn?P0o_kn0?ooo`3no_h2
0?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?kn
oP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40
OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h90:2^d@0609n]d02LZl`0UjK709:O
_`2=V[X0RYRe0P29Uk@01`2:UK40F69k075kU01nR:40SIRd09NVa`2P/=@0
2`2P[]404`2O[M00X:kA0:2^d@2MZlh0V:K909FRa02>Vk/0RiRh08VG]02<
UkD0RiJb08>>ZP1LIh<0J7>907AoU@1mQj00TYjh0:2^b@2R/<d00P2V]M@2
0:Nfe`80Z;GE00d0YK?@0:2^b`2KY/80Uj:n09:P^`2<V;80Ri>Z08N=X`1E
G6l0PXVL08jFZ`2KY[X0ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M0;G0g00@
0;G0g0030;K1g@2e`=`0]L3L00@0]L3L00@0]/7M0;G0g02e`=`0]/7M102e
`=`00`2d_m/0]L3L0;G0g00F0;G0g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0
_LSN0<_Bi@3DfN`0eMWT092DU`3no_`0ooom0?omo`3oo_l0o_ko0?konbX0
oooo000P0?ooo`0@0?knoP3moOd0no_k0?Gem@3]kNd0iNGU0=oOg`3Lg=`0
f][L0=_Kf`2c/[00Ogb308=nTP2ARjL0XIRc0:jV_RP0/ZW80P2bZLH20;:Y
b00<0;6Xa@2f[LP0`k_B0<o7g03Ccmd0PGV>061GM021MI/0Sh:]09Z:^@2K
RkP0WHbi202LS;/0302MSKh0VXZi09V<^P2IRk`0YIS60;BXc023O8`0S8R7
0:RQT@2h/J40bL:`0=;;^@80eLjl00<0eLjk0=C=^P3Ec[`0203Ec[`20=C=
^`0?0=G>_03DcK/0e<fk0=K?_@3Id/00h]_A0>STf`3dl>d0Lg5f05iJJ`1`
Ih@0P7BL08alZ@2FQ[<0VHVf0080Vh^h00H0VXZg09^;^02LS;/0W8bk09^;
^P2LS;/209^;^P0<09b<^`2JR[T0W8bk0::B`@2_Y<`0_[GB0<RneP1eJh@0
GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak
[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^VJ00LZFY07:W[@1iYJi407JW
[PX0MjR_201hZK0207VZ/@H0NZVa201kZ[8207b[/`@0O:^a101m[;86082]
/`H0PJjd1022[kD608>`]P80Q;6g1025/;L808Ja^0@0Qk:i1P28/kT208Vd
^P@0RkBj102<]K/0302;][`0R[Fk08be^`2F_L80Zl[=0;[Be038e]L0RY>B
0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303n
o_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_K
f`80f][J00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPT0X:kA
00H0Wjg@09b[c02GY/L0TYno08fJ^P2:V;D208VG]00708ZE/@1HHW/0LG^D
07j8X@2=V;@0UjK70:2`e0080:2^d@0409n]d02P[]40X:kA09n]d080X:kA
00H0W:[=09RVb@2CX<80RiRj08VF]P28U[<208bG/`0K07Z6X01IIGl0KgVB
07R2V`24T:X0WZW50:Bbc`2Q/<l0Z[WJ0:Nfe`2V]MH0YkKG0:Ree@2W]=@0
Y;;?09n]bP2LYl<0Uj:n092N^@2CWkT0TYVc08nEZ`1KHGL0OXBJ08VAYP2O
Z/00ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M0;G0g00C0;G0g0D0]/7M0P2e
`M/30;K2g080]L7K00<0]<3J0;G0g02e`=`05P2e`=`0402e`M/0]L3L0;?1
g02c`M`0]/;L0;g8gP3;d^D0e=W/0=GIi02@U9L0o_kl0?ooo@3ooOl0ooko
0?kno`3noo/Z0?ooo`00803oool0403no_h0oOgm0?_kn`3emOD0kNg]0>GU
i@3Ogml0g=cL0=[Jg03Kfm/0/k:`07mlP`23OY80TH^W0:6H/`2^Y[hX0;:Y
b080/ZW60P2bZLP0302aZ<D0]Zg80<>kdP3?am`0dloM085iSP1PEg@0PGFK
08n2[@2JR[T0Vh^h09f<^@P0W8bk00`0VXZi09^;^02IS;P0Vhjl0:RKb@2b
YlT0TX^K08F1PP2UWXh0]JjN0<S1[`3BbkT20=G>_0030=G>^`3DcKX0eLjl
00P0eLjl0P3DcK/03`3Ec[`0e<fk0=C=^`3Fckd0f]?10>;Ld03Xi=/0kn_Z
04a9DP1WHWH0LfZ908IjXP2APJh0VHVh09^;^P0209b<^`80W8bi0P2KRkP0
402KRkX0W8bk09^;^P2KRkX0W8bk09Z:^@2LS;/0XY;10:nTc02n]M80b;kF
07E[Q01ND7@0OFfN08IcZ`28MJdX08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26
MJ`0S7^_09j?^P2`XLP0RX:G05Q/M`1GOXD0HX^A06jIX01bYJT0LZN]07VU
[T<0MZN^2P1gZ:l807RY/0<0NJZa1@1jZK4807^Z/P<0O:^c0`1lZk4507f/
/PD0P:fc1P21[[@508:_]@D0Pk2f0`24/KL308F`]`P0Q[6h1@27/[T508Rc
^@<0RKBj0`2;];X508be^`80RkJl00X0SKJl09Jm`P2/blh0^];D0<SFe`2:
Ti80n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<
0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0
fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>2@2P
[]401P2O[M00W:_<09NVa`2BWkl0SIZj08ZH]@80RINd00L0RYFa05QRN`1a
Ni@0OXRQ08fH]02GY/L0X;3D00P0X:kA00<0Wjg@0:2^d@2P[]400`2P[]40
8`2LZ/d0UjG8096N`02<VK/0RYNg08RF/`28Tjl0RIF_06eiT@1SKhL0KgVB
08:>Z02?VkD0WZc70:Rfd`2V]M@0Z;OH0:Fee`2W]]L0Z;OH0:VfeP2X]MD0
Y[CA0:6_c02MZ<@0VJC009BR_`2CW[X0UYfg09NM]@1NI7X0OhFK08fE[02N
ZKl0ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M0;G0g00C0;G0g080]/7M00@0
]L3L0;Bof`2d_m/0/koI0`2b_]P0102c_mT0]<3J0;G1f`2e`M/H0;G0g00@
0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3DfN`0eMWT092DU`3no_`0
ooom0?omo`3oo_l0o_ko0?konbX0oooo000P0?ooo`0@0?knoP3moOd0no_k
0?Gem@3]kNd0iNGU0=oOg`3Lg=`0f][L0=_Kf`2c/[00Ogb308=nTP2ARjL0
XIRc0:jV_RP0/ZW80P2bZLH20;:Yb00<0;6Xa@2f[LP0`k_B0<o7g03Ccmd0
PGV>061GM021MI/0Sh:]09Z:^@2KRkP0WHbi202LS;/03P2JR[L0WHji09V<
]`2MT;`0Yi[60;R]c`2DSY`0Pgmn0:>LS02d[Id0al2^0=;;^@3Ec[`0e<fk
0P3DcKX90=G>_00?0=C=^`3Ec[`0eLjl0=C=^`3Cc;X0e/nm0=_D`P3Rg<`0
jnOL0=WEdP1;B540IV5g07Y`TP29OJD0UXJc00D0W8bk00D0W8bi09^;^02K
RkP0Vh^j09b<^`0209^;^P0<09b<^`2JR[T0W8bk0::B`@2_Y<`0_[GB0<Rn
eP1eJh@0GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0QgB/08Qd/@28M;40
QWF/08ak[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^VJ00LZFY07:W[@1i
YJi207JW[PX0MjR_201hZK0407VZ/@@0NZVa201kZ[8407b[/`80O:^a1P1m
[;84082]/`H0PJjd1P22[kD408>`]P@0Q;6g0P25/;L808Ja^0H0Qk:i1028
/kT408Vd^P80RkBj1P2<]K/208^f_00:08ff_02G_/<0[<_>0;[Be038e]L0
RY>B0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0
303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM
0=_Kf`80f][J00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPT0
X:kA00H0Wjg@09b[c02GY/L0TYno08fJ^P2:V;D208VG]00708ZE/@1HHW/0
LG^D07j8X@2=V;@0UjK70:2`e0080:2^d@0309n]d02P[]40X:kA0080X:kA
01<0Wjg@09^Yc02FY<L0Tj3208jK_@2;V;P0RINd08NB[P29UJd0GVZ206]g
S@1dP9X0RYJ`09^V`P2Q[l`0YkKE0:Rgf02U]ML0Y;CF0080Z;OH00l0Z[OG
0:VfeP2W]M80X[3=09fXa02IY<00UZC109:M^@2CV[@0V9jf069XOP23RIl0
T9R_09^V_02[]]800P2f`Md20;G0g0030;Bof`2f`Md0]L3L01@0]L3L00H0
];oK0;:mf@2a_=P0[k[F0:^gd@2Z]]020:Vec`040:^gd@2^^]@0/[kH0;C0
fQP0]L3L0100]L7K0;G0g02c`M`0/l7L0;K2g02mb=h0bm;U0=CIk03EfN@0
T9BG0?kno03oood0oogo0?ono`3no_l0o_ok:P3oool00200oooo0100o_kn
0?gmo@3kno/0mOGe0>g]k@3UiND0gmoO0=cLg03Jf]`0fm_K0;>b/01oO8<0
PgjB096;Y`2QV;<0[ZJn:02bZLP20;:YaP80/ZW800`0/JS50;J]b033^m80
clOL0=??g@21NHh0H5Md085eV`2?PZd0VXZi09^;^02MS;T809b<^`0<09b=
^02NSkP0V8bd09b?^P2TUl80_kCD092:V025PH00XY^;0;>/W037`:h0d/^i
0P3DcK/20=C=^PT0eLjl0180e<fk0=G>_03Ec[`0e<fk0=?<^P3Gd;h0fmC2
0>CNcP3Xi=P0blO404a9DP1`Jh40NW2B0965[@2FQ[<0W8bm09^;_02JR[T2
09^;^P<0Vh^h0100Vh^j09b<^`2KRkX0Vh^j09b<^`2JR[T0W8bk0::B`@2_
Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0QgB/
08Qd/@28M;40QWF/08ak[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^VJ00
LZFY07:W[@1iYJi007JW[PL0MjR_00<0N:V`07NX[`1gZ:l00P1gZ:l807RY
/0@0NJZa101jZK4807^Z/P@0O:^c1`1m[;800`1n[K<0P:fc082]/`02082]
/`@0PJjd1`22[kD508>`]P@0Q;6g1`26/KP808Nb^@0308Rc^P28/kT0R;>i
0080R;>i1029];X708be^`0=08ff_02;][`0RkJl08ff_02G_/<0[<_>0;[B
e038e]L0RY>B0?Shn03no_h0oooo0?knoP020?ooo`030?gmo@3oool0oooo
0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0
hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_
eP2Q[/h90:2^d@0609n]d02LZl`0UjK709:O_`2=V[X0RYRe0P29Uk@01`2:
UK40F69k075kU01nR:40SIRd09NVa`2P/=@0202P[]400`2O[M00X:kA0:2^
d@020:2^d@0T09n]d02KZL`0UZC709BQa02=V[`0R9Fe08VG]02;Uk40SIVa
05IRN01_Ni40NhNQ08ZE/@2OZ/H0Y[CA0:Jee02W]]L0Y[KH0:Ngf@2W]]L0
Z;OH0:Zge`2Y]]H0YkGB0:6_c02MZ<@0V:>o09BR_`2FXKd0UYfg09RN]P1S
JGl0P8JL08^CZP2KY[`0ZkKB0P2f`Md20;G0g0030;Bof`2f`Md0]L3L01@0
]L3L00`0/kkJ0;2ke`2]^=@0ZkKB0:B`bP2R[/P0X:c609n[a@2R[/P0Z;C>
0:jje02b_]PH0;G0g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3D
fN`0eMWT092DU`3no_`0ooom0?omo`3oo_l0o_ko0?konbX0oooo000Q0?oo
o`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21
OXD0PgjD09><Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00<0;6Xa@2f[LP0
`k_B0<o7g03Ccmd0PGV>061GM021MI/0Sh:]09Z:^@2KRkP0WHbi202LS;/0
302MSKX0V8Ri09^=`P2LS/40[j;=0;fcc02;QXd0QH9m09nHR02d[Id0b<6_
0=7:^080eLjl0P3DcKX80=G>_00@0=C=^`3Ec[`0eLjl0=G>_03Cc;X0e<fk
0=K?_@3Id/00i=o<0>GOd@3=b/D0C4IB07I]S020MIl0SGjY09Z;/P<0W8bk
102KRkX00`2LS;/0Vh^j09b<^`0209^;^P0<09b<^`2JR[T0W8bk0::B`@2_
Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0QgB/
08Qd/@28M;40QWF/08ak[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^VJ00
LZFY07:W[@1iYJhh07JW[P0307FV[@1fYjh0MZN^00T0MZN^201gZ:l407RY
/0@0NJR`1@1jZK4707^Z/P@0O:^a101m[;800`1o[;80P:fc082]/`06082]
/`L0PJjd1022[kD408>`]P0308B_]P25/;L0QK2g00D0QK2g1026/KP408Nb
^@0308Nb^028/kT0R;>i00D0R;>i00<0R[>i08^d^P2;];X01@2;];X408be
^`@0SKJl00`0S[Nk08ff^P2=][`0Ukk30:[;d02jd]H0amKI08VCU03hn?P0
o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?oo
o`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[J
fP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h80:2^d@80WZc?
00h0W:_<09RWb02CX<00SY^k08ZH]@28U[<0RINd08ZE/@1HHW/0LG^D07j8
X@2=V;@0UjK70:2`e0P0X:kA00@0WZc?09n]d02P[]40X:kA0P2P[m003P2L
Zl`0UjK709:O`@2>Vk/0SYVi08ZC/P2:Tk00SIB`05]RO01dNY@0PHfU092L
]P2O[LX0YkCD0P2X]ML00`2W]]D0Z;OD0:Zhe@030:Zhe@0=0:Vdd02T[l/0
WJS409VT`02GXk/0Tijj09JO_02EWkP0H6al07f9U`2?Uj`0WZG10:^fdP02
0;K1g@80]L3L00<0];oK0;K1g@2e`=`0402e`=`20;G1f@0B0;C0fP2f`Md0
];gJ0:fgdP2/]/l0W:Jo09VU_`2AV;80T9J`09nS_P2HW;L0Y:_70:Zed@2^
_=L0/[gI0;>nfP2e`=`0]/7M502e`=`0402e`M/0]L3L0;?1g02c`M`0]/;L
0;g8gP3;d^D0e=W/0=GIi02@U9L0o_kl0?ooo@3ooOl0ooko0?kno`3noo/Z
0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M
0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2bZLP0
302aZ<D0]Zg80<>kdP3?am`0dloM085iSP1PEg@0PGFK08n2[@2JR[T0Vh^h
09f<^@P0W8bk00`0Vh^h09b<_@2HR[d0Wi720;BXd034^]80NgIl08b9Q02P
VHT0]ZnO0<W2/03BbkT20=G>_0030=?<^@3DcKX0eLjl00L0eLjl0100e<fk
0=G>_03Ec[`0eLjl0=?<^P3DcK/0e/nm0=SA_`3KeLD0i^3B0=CAc01<AU80
MFb;085fX02?Oj`0UHJ_0P2LS;/709^;^P0?09b<^`2KRkX0Vh^j09b<^`2J
R[T0W8bk0::B`@2_Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0R7F]02P0
R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;2Qb02:PYL0F6ag
05MnQ@1RRi40KYVP07:UZ@1bYjd0NJF^?P1fYjh207NX[`@0MZN^201gZ:l4
07RY/0@0NJR`101jZK4607^Z/P80O:^c101lZk4407f//PH0P:fc2021[[@6
08:_]@@0Pk2f1P25/;L608Ja^0@0Qk:i1P28/kT208Vd^PH0RkBj1P2<]K/4
08ff_00<08jg^`2=][X0SKJl09Nn``2Zbm00^];F0<OFf@29Ti@0n?Sh0?kn
oP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0
oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0
202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>202P[]4209n]d00>
09b[c02HYlP0Tj3008jK^`2:V;D0RINd08RF/`2:UK40F69k075kU01nR:40
SIRd09NVa`2O[m<80:2^d@<0XJoB0140X:kA0:2_d02O[/l0Vj[;09NVa`2A
W/00S9Vk08^H^02:UK<0S9Fb08bF/@1KHW`0M7^E086=Y@2@W;H0Wjg:0:Nd
e0020:Ree`0C0:RgeP2X]m@0Z[SE0:Zhe@2[^MH0Z[SE0:Vdd02T[l/0WZW5
09VT`02GXk/0Tijj09NP_@2EWkP0H6al07f9U`2?Uj`0WZG10:^fdP020;K1
g@80]L3L00<0];oK0;K1g@2e`=`0402e`=`0502b_]H0]/;J0;K2g02d_m/0
[kSE0:Rbc@2T[/L0UJ2f08fD[P2AV:/0S9:P0:Z^^@2U[;H0W:>c09fW`02[
^MH0/[gI0;>nfP2e`=`0]/7M502e`=`0402e`M/0]L3L0;?1g02c`M`0]/;L
0;g8gP3;d^D0e=W/0=GIi02@U9L0o_kl0?ooo@3ooOl0ooko0?kno`3noo/Z
0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M
0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2bZLP0
302aZ<D0]Zg80<>kdP3?am`0dloM085iSP1PEg@0PGFK08n2[@2JR[T0Vh^h
09f<^@P0W8bk0100VXZg09j>_@2GRKX0XiK40;N[c`33^/d0MG1d092=QP2S
W8`0^;6Q0<_4/P3BbkT0eLjl0=C=^`3Cc;T0eLjk203Ec[`0403DcK/0eLjl
0=G>_03DcK/0dlbj0=C=^`3Fckd0f=6o0=_Ea`3Ugm<0fmSA04a6D01fKHX0
P7FO0961[P2GR;<909^;^P0?09b<^`2KRkX0Vh^j09b<^`2JR[T0W8bk0::B
`@2_Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0R7F]02P0R7B_0100QgB[
08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;2Qb02:PYL0F6ag05MnQ@1RRi40
KYVP07:UZ@1bYjd0NJF^?@1fYjh307NX[`<0MZN^201gZ:l507RY/0<0NJR`
1@1jZK4507^Z/P<0O:^c0`1lZk4507f//PD0P:fc2021[[@608:_]@D0Pk2f
1@25/;L608Ja^0D0Qk:i1@28/kT308Vd^PD0RkBj1P2<]K/508ff_00<08jg
^`2=][X0SKJl09Nn``2Zbm00^];F0<OFf@29Ti@0n?Sh0?knoP3oool0o_kn
0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3n
o_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40N7fA
07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>2@2P[]403`2O[M00W:_<09RWb02C
X<00SY^k08ZH]@29Uk@0R9Jc08ZE/@1HHW/0L7ZC07f7X02=V;@0UjK709n_
d`080:2^d@80X[3C0180XJoB0:2^d@2P[m00X:o@09b[c02GY/L0TIo208^J
^`2;V[T0RYNg08bG/`2:UK40FF=n07AnU`22SZH0TIfg09n]bP2X]MD20:Vf
f0030:RgeP2X]m@0Z[SE0080ZkWF00h0Z[SE0:Vdd02T[l/0WZW509ZU`@2G
Xk/0U9nk09NP_@2EWkP0H6al07f9U`2?Uj`0WZG10:^fdP80]/7M0P2e`=`0
0`2d_m/0]/7M0;G0g00@0;G0g00D0;:neP2g`md0]/;L0;:mf@2[]=40Xjg8
09NR^02;UZX0TiR/0<C:eP3cn?/0noom0?Ooo@3Uk_D0[KG80:^dd@2b_MT0
/kkJ0;G0g02f`MdD0;G0g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_B
i@3DfN`0eMWT092DU`3no_`0ooom0?omo`3oo_l0o_ko0?konbX0oooo000Q
0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/
ZP21OXD0PgjD09><Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00<0;6Xa@2f
[LP0`k_B0<o7g03Ccmd0PGV>061GM021MI/0Sh:]09Z:^@2KRkP0WHbi202L
S;/0302KRkP0WHfj09b?^`2XW<@0_kCB0:nW]P21OG`0Shf10:NPT02l]JD0
cLJd0=?<^P80e<fk00<0dlbi0=G>^`3Ec[`01`3Ec[`20=C=^`0?0=G>_03D
cK/0e<fk0=C=^`3Ec[`0em2n0=oHcP3OfLd0gmcC06EPIP1aJH40PWNO08mo
[02IRKH0VXZi00<0Vh^j00<0W8bk09^;^P2KRkX00P2KRkX03`2LS;/0Vh^j
09^;^P2LS;/0VXZi09b<^`2RT/40[jC<0;jedP38_]H0MF^405i@M01mKIh0
QW>[08Qe[@0X08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`
XLP0RX:G05Q/M`1GOXD0HX^A06jIX01bYJT0LZN]07VU[S`0MZN^101gZ:l2
07JW[PP0MjR_1P1hZK0207VX/0H0NZVa101kZ[8407b[/`80O:^a1P1m[;84
082]/`P0PJjd1P22[kD608>`]P@0QK2g1P26/KP608Nb^@@0R;>i1029];X4
08^d^PH0S;Fk1P2=][`208jg^`0:08ff_02G_/<0Z/_@0;_Ce`37e]T0RI>D
0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303n
o_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_K
f`80f][J00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPT0X:kA
00l0Wjg@09b[c02GY/L0TYno08fJ^P2:V;D0RINd08RF/`2:UK40F69k071j
T`1mQj00SIRd09JUaP2O[m<02@2P[]420:6_dP0A0:2^d@2P[m00X:o@09b[
c02HYlP0TZ;308bK_02:VKP0RINd08VG/P29UJl0F69m07AnU`22SZH0TIfg
0:2^b`2X]MD00P2Y]]P00`2Y^=L0ZKSE0:^ieP030:^ieP0=0:Zed@2U/<`0
WZW509ZU`@2HY;`0U9nk09NP_@2EWkP0H6al07f9U`2?Uj`0WZG10:^fdP02
0;K1g@80]L3L00<0];oK0;K1g@2e`=`0402e`=`0502e`MT0]l?M0;>nfP2a
_=P0ZkG@0:2Z``2>VJd0RYFW0=KHi03io?l0o?oo0>?Xj`3Rj^d0m?co0;k7
f02_]lh0/[gI0;>nfP2e`=`0]/7M502e`=`0402e`M/0]L3L0;?1g02c`M`0
]/;L0;g8gP3;d^D0e=W/0=GIi02@U9L0o_kl0?ooo@3ooOl0ooko0?kno`3n
oo/Z0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2b
ZLP0302aZ<D0]Zg80<>kdP3?am`0dloM085iSP1PEg@0PGFK08n2[@2JR[T0
Vh^h09f<^@P0W8bk00/0W8bi09^;^02QU;l0/:C80<c2fP2@RI40RhR309:@
P`2^YiL0`KZZ0=39]`030=C=^`030=?<^@3Fck`0eLjl00L0eLjl0P3DcK/0
3P3Ec[`0e<fk0=C=^`3DcK/0eLjl0=K?_@3JdlT0fM?50=oMd02LV9D0FeAT
08EkWP2<O:T0U8Bc0P2JR[T209^;^P80W8bk0`2KRkX03`2LS;/0Vh^j09^;
^P2LS;/0VXZi09b<^`2RT/40[jC<0;jedP38_]H0MF^405i@M01mKIh0QW>[
08Qe[@0X08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`XLP0
RX:G05Q/M`1GOXD0HX^A06jIX01bYJT0LZN]07VU[S`0MZN^2P1gZ:l807RY
/080NJZa1P1jZK4607^Z/P@0O:^c1P1m[;8207j]/`@0P:fc2021[[@408:_
]@H0Pk2f0P24/KL408F`]`@0Q[6h1P27/[T208Rc^P@0R;>i1029];X408^d
^P@0S;Fk1P2=][`208jg_@80S[Nk00X0S[Nm09Nn``2Zbm00^m?G0<OFf@29
Ti@0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<
0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0
fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>202P
[]40402O[M00WZc?09b[c02GY/L0Tj3008fJ^P2:V;D0RINd08RF/`2:UK40
F69k075kU01nR:40SIRd09NVa`2O[m<80:2^d@0D09n]d02P[]40XJoB0:2^
d@2Q/=40X:o@09^Zb`2FYLH0Tj;108bK^P29V;D0QiF`08ZF/02;Ujl0FVAm
07AoU@23SjL0TYjh0:6_c02Y]]H20:Zgf@0C0:Vhe`2Z^MH0ZkWF0:^ieP2/
^]L0ZkWF0:Zed@2U/<`0Wj[609ZU`@2HY;`0U9nk09NP_@2EWkP0H6al07f9
U`2?Uj`0WZG10:^fdP020;K1g@80]L3L00<0];oK0;K1g@2e`=`0402e`=`0
502g`md0]L7K0;6lf02a_=P0ZK?>09bW_@2=V:`0WZZj0?ooo`3ko?l0^K_8
09fR]P2RZ<00][kE0;c4f@2d_Lh0/[gI0;>nfP2e`=`0]/7M502e`=`0402e
`M/0]L3L0;?1g02c`M`0]/;L0;g8gP3;d^D0e=W/0=GIi02@U9L0o_kl0?oo
o@3ooOl0ooko0?kno`3noo/Z0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]
kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV
`@0X0;:Yb080/ZW60P2bZLP0302aZ<D0]Zg80<>kdP3?am`0dloM085iSP1P
Eg@0PGFK08n2[@2JR[T0Vh^h09f<^@P0W8bk00/0W8fh09f>^@2WVl40_;7?
0<_2e@1mMg/0S8V009^JR02f[il0a[n_0=;;^@030=C=^`030=C=^P3Fck`0
eLjl00L0eLjl1`3DcK/02`3Ec[`0e/o50=[Da03If<@0blRo04m9D`1kLXl0
SGjW09>3/02IRKP0VXZi0080Vh^j0P2LS;/309^;^P0?09b<^`2KRkX0Vh^j
09b<^`2JR[T0W8bk0::B`@2_Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0
R7F]02P0R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;2Qb02:
PYL0F6ag05MnQ@1RRi40KYVP07:UZ@1bYjd0NJF^>`1fYjh:07NX[`P0N:V`
0`1iZ[4507ZY/@H0NjZb1@1lZk<507f//P<0OZfc0`20[K<8086^]0D0PZne
1@23/;H308Ba]`<0QK2g1@26/KP508Nb^@<0R;>j0`28/kT508Vd^P<0RkBj
1@2<]K/508ff_0<0S[Nm00`0SkRl08jg^`2>]kd0V;o40:[;d02kdmL0amKI
08ZDU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo
00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gM
g@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h8
0:2^d@0709n]d02N[<l0WJc=09VXb@2DXL40Sibl08^I]P0208VG]00708ZE
/@1HHW/0LG^D07j8X@2=V;@0UjK70:2`e0080:2^d@0D0:6_dP2R/=<0X[3C
0:6_dP2Q/=40X:o@09^Zb`2FYLH0Tj6n08nM^02=VkH0SYZd09:L]@2DWkD0
HFUn07MoTP24T:P0TYjh0:6_c02Y]]H20:Zgf@030:Zif02Z^MH0[;[G0080
[;[G00h0ZkWF0:^fdP2U/<`0Wj[609^V`P2IYKd0UJ2l09RQ_P2FX;T0H6al
07f9U`2?Uj`0WJC00:^fdP80]/7M0P2e`=`00`2d_m/0]/7M0;G0g00@0;G0
g00D0;G1f`2d`=X0/[gI0;:nf02U[lP0VJBj092K[@2f`]80n__f0=gNh`2S
YKX0Yjc<0:V^e02X/M80/K_D0;:mc`2b_MT0/kkJ0;G0g02f`MdD0;G0g00@
0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3DfN`0eMWT092DU`3no_`0
ooom0?omo`3oo_l0o_ko0?konbX0oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd
0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0
[jK102P0/ZW80P2bZLH20;:Yb00<0;6Xa@2f[LP0`k_B0<o7g03Ccmd0PGV>
061GM021MI/0Sh:]09Z:^@2KRkP0WHbi202LS;/02`2LSKP0XY>l0;6Ub@36
_=L0ZJ6`089lO02>S800Xj:>0;ffYP3;a;@0dlbj00<0e<fk00<0e<fj0=K?
_03Ec[`01`3Ec[`80=C=^`0<0=G?``3Ke/80e=Bj0=WHaP1lN7T0He]b08en
Y@2CPk00V8Rg09V9^02JR[T0Vh^j0P2LS;/309^;^P0?09b<^`2KRkX0Vh^j
09b<^`2JR[T0W8bk0::B`@2_Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0
R7F]02P0R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;2Qb02:
PYL0F6ag05MnQ@1RRi40KYVP07:UZ@1bYjd0NJF^>P1fYjh:07NX[`P0N:V`
101iZ[4407ZY/@H0NjZb1P1lZk<407f//P@0OZfc0P20[K<8086^]0H0PZne
1023/;H408Ba]`80QK2g1P26/KP408Nb^@@0R;>j0P28/kT608Vd^P80RkBj
1P2<]K/408ff_0@0S[Nm00`0SkRl08jg^`2>]kd0V;o40:_<d@2kdmL0amKI
08ZDU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo
00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gM
g@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h8
0:2^d@80Wjg@00h0WZg>09^Zb`2GY<@0TIjn08fK^02;VKH0RINd08^F/P1I
Hg`0LWbE07n9XP2>VKD0V:O80:2`e0P0X:kA0`2Q[m804@2P[]40XK3A0::a
dP2O[/l0Vj[;09bX`P2KYkl0WJO009fX_P2SZl00YJbo06YaP`1kP9<0Q92X
09>O^@2R/<d0Z[OG0080ZkSJ00<0Z[WH0:^je`2/^]L00`2/^]L03@2[]]80
Y[7=09nZaP2KY/80VJFm09FP_02HXKh0UZ2i061/O01mRIL0SiN/09fT`02[
]]800P2f`Md20;G0g0030;Bof`2f`Md0]L3L0100]L3L01@0]<3J0;G1f`2d
_m/0/koI0:F_b02LYk/0T9b/0;g9e`3moOd0cLgE09JL[02LY/40YK3@0:Zg
e`2X/ll0[KWA0;:mf@2c_]X0]L3L0;K1gA@0]L3L0100]L7K0;G0g02c`M`0
/l7L0;K2g02mb=h0bm;U0=CIk03EfN@0T9BG0?kno03oood0oogo0?ono`3n
o_l0o_ok:P3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0
g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/40:02bZLP20;:Y
aP80/ZW800`0/JS50;J]b033^m80clOL0=??g@21NHh0H5Md085eV`2?PZd0
VXZi09^;^02MS;T809b<^`0:09j?^P2VUl00^k3B0<c2f`21NHH0ShV909BB
Q@2UY900`KZZ0<g6]P<0e<fk00<0eLjl0=C=^P3Fck`0203Ec[`70=C=^`0=
0=?<^P3CcKl0f=>m0=CD^03FeL00`;bi04m7G029Nil0T86/09R8]`2IRKP0
VXZi09^;^P0209b<^`<0Vh^j00l0W8bk09^;^P2KRkX0W8bk09Z:^@2LS;/0
XY;10:nTc02n]M80b;kF07E[Q01ND7@0OFfN08IcZ`28MJd0:028M:l04027
M:/0QgB/08Qd/@28M;40QWF/08ak[`2NSkX0/:7808Z2U`1HK7L0Egj506:;
T@1^VJ00LZFY07:W[@1iYJhh07JW[PL0MjR_00<0N:V`07NX[`1gZ:l00P1g
Z:l807RY/0@0NJZa101jZK4407^Z/PL0O:^c00<0OJbd07f//P1m[;800P1m
[;8407j]/`L0PJjd2022[kD508>`]P@0Q;6g1`26/KP508Nb^@@0R;>j1`29
];X00`2:]K/0S;Fk08be^`0508be^`D0SKJl102>]kd0302?^;`0S[Nk08jg
_@2H_l@0ZlcA0;_Ce`38emX0RYBE0?Shn03no_h0oooo0?knoP80oooo00<0
oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3h
n?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07QmT@1oR:T0R9Nd
09RYa@2O[m<0XJoF0:6^cPX0X:kA00h0X:o@09f/c@2IY/H0Tj3008nM^P2=
VkP0RYRe08^F/P1IHg`0LWbE07n9XP2>VKD0V:O80:6ae@X0X:kA0P2O[M00
402Q/=40Y;?D0:Bce02Q/=40Y[390:Nbb02]]L`0[;C90;6hb`2a]/T0LWR8
07b2T024T:P0Tini0::`c@2Z]mL20:^hfP030:Zif02[^]L0[;[G00<0[;[G
00d0ZkKB0:Jac@2PZlL0VjK209VU_@2EX;`0V:6n09JP^@1QKGd0OHVG08nG
[02MY<00ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M0;G0g00@0;G0g00D0;C0
fP2g`md0]L3L0;>of@2Z]<d0XZg108jJZP2e`Ld0ooko0=SKhP2BVj@0W:Vi
09j]`P2IZL80Y[CA0:Zed`2b_MT0/kkJ0;G0g02f`MdD0;G0g00@0;G1f`2e
`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3DfN`0eMWT092DU`3no_`0ooom0?om
o`3oo_l0o_ko0?konbX0oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3U
iND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0[jK102P0
/ZW80P2bZLH20;:Yb00R0;6Xa@2f[LP0`k_B0<o7g03Ccmd0PGV>061GM021
MI/0Sh:]09Z:^@2KRkP0WHbi09^;^P2NS[/0VXZg09b<^@2MT;`0VHbj09R:
^`2LS[l0X9S10:bUaP37_m@0[:N]08B1O02?Rgl0Wib=0;BaX03<aK<0dLZh
0=K?_@3Ec[`0dlbj0=C=^a80eLjl0180dm2o0=3<`03Bcl00dm6h0=CC]@28
QGH0J5mb08n1/P2CPk@0UXJc09j?^02KS;<0W8fd09N8/@2RT[l0Vh^l09^;
^P2LS;/209^;^P0<09b<^`2JR[T0W8bk0::B`@2_Y<`0_[GB0<RneP1eJh@0
GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak
[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^VJ00LZFY07:W[@1iYJh`07JW
[P0307FV[@1fYjh0MZN^00H0MZN^201gZ:l707RY/00307VX/01jZK40NZVa
00H0NZVa1`1kZ[8407b[/@@0OJbb00<0Ojbb082]/`20[K<01@20[K<4086^
]0D0PZne1`23/;H408F`]`P0Q[6h1027/[T00`29/[P0R[>i08Zc^@0508Zc
^@@0RkBj1@2<]K/808ff_0L0S[Nm00`0T;Nl08jg^`2?^;h0VKk40:g<d@2k
dmL0b=KI08VCU03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo
0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0
hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_
eP2Q[/h;0:2^d@0>09j/c`2KZL`0UjG809>Qa02@W/40SYNh096L^P1DH7P0
MXFJ086@Y@26U[00X:kA09b[dP2T[]420:6^d080XJkA01L0Wjg@0:2^d`2Q
[m@0Ujc70:6fe@2O/]<0WZkB0:JceP2]^=P0/[cE0;G0e02o_lL0`l?=0<73
c`2k_L`0_/7B0;_1d@1fO8`0O8:B08B@Z02CWkT0Y:o=0:fhf0020:bif@04
0:bje`2/^]D0[K_H0:fkf080[k[F00d0[;OC0:NbcP2QZlH0WJO209^R_P2H
WkT0Vj>h09VQ]01SJgh0OhNJ08nG[02NY[d0ZkKB0080]/7M0P2e`=`00`2d
_m/0]/7M0;G0g00@0;G0g00C0;K2g02e`M/0]L7K0;>oe`2^^]80YK7909ZV
_02BW[@0mOCl0?_ko`2UY[P0S8jU09^Q^`2EW;H0UZ:j0:ZfcP2Z]M40[k[F
0;Bof`020;G0g080]/7M4@2e`=`0402e`M/0]L3L0;?1g02c`M`0]/;L0;g8
gP3;d^D0e=W/0=GIi02@U9L0o_kl0?ooo@3ooOl0ooko0?kno`3noo/Z0?oo
o`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_K
f@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2bZLP03P2a
Z<D0]Zg80<>kdP3?am`0dloM085iSP1PEg@0PGFK08n2[@2JR[T0Vh^h09f<
^@2KRkX0VXZi0P2LS;T209R;]`0<09Z=^`2OT/00XIVn0;jedP35_]00PWf1
08N4O@2DT8@0Xj2A0;nlZ`3>akD0d/^i0P3Ec[`00`3Cc;X0e<fk0=G>_00A
0=G>_00?0<g;]P3Ie/L0e]?40=3>^@3Ad;@0cLZi06=KIP1[Gh<0TX:_09N7
]02JRkH0UXNb09n@^`2LS;T0Vh^h0080Vh^j00l0W8bk09^;^P2KRkX0W8bk
09Z:^@2LS;/0XY;10:nTc02n]M80b;kF07E[Q01ND7@0OFfN08IcZ`28MJd0
:028M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak[`2NSkX0/:7808Z2U`1H
K7L0Egj506:;T@1^VJ00LZFY07:W[@1iYJhf07JW[PP0MjR_201hZK0207VZ
/@H0NZVa201kZ[8207b[/`@0O:^a101m[;86082]/`H0PJjd1022[kD608>`
]P80Q;6g1025/;L808Ja^0@0Qk:i1P2:/kT608^d^P@0S;Fk1P2=][`808jg
_@80SkRn00`0T;Nl08nh_02?^;h0VKk40:g<d@2kdmL0b=KI08VCU03hn?P0
o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?oo
o`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[J
fP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h;0:2^d@0@09n]
d02MZlh0VJO:09JTa`2DX/D0TI^n08VD/P1WLhd0LH2E08>BZ@2CXkd0TZ72
0:2^d`2P[Ll0XJk@0:6^d@80Wjg@01L0X:kA0:6_dP2Q[m80YKGG0:>ce@2N
[Lh0/;gM0;S4gP2h`mL0c=GV0<kFh`3@dm`0al_G0;^nc@2PXkH0N7f@05aS
M@0i@580N7n?08B@Z02CWkT0Y:o=0:fhf0020:bif@0C0:bje`2/^]D0[K_H
0:fkf02`^mL0[k[F0:bgd`2W//h0XZc709fW`P2KX[h0VJ2j09bT^@2IXK@0
Hf]n07n7VP2?Uj`0WZJm0:^fdP020;K1g@80]L3L00<0];oK0;K1g@2e`=`0
402e`=`30;G1f`0@0;C0f02`_=@0Z;C<09jZ`P2GXkT0b<S@0?coo`3Phn`0
VYjZ08J<VP2GWZh0XZ^l0:jfb@2[]]80/;_G0;Bof`80]L3L0P2f`MdA0;G0
g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3DfN`0eMWT092DU`3n
o_`0ooom0?omo`3oo_l0o_ko0?konbX0oooo000Q0?ooo`0?0?knoP3jn_X0
m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2R
VKP0[jK102P0/ZW80P2bZLH20;:Yb00O0;6Xa@2f[LP0`k_B0<o7g03Ccmd0
PGV>061GM021MI/0Sh:]09Z:^@2KRkP0WHbi09b<^`2FQ[D0WXjk09f=^P2F
RKD0VHbh09b?^P2TUl80]:_:0<o7g`2XXZh0PWio092<P`2MVX/0/k2O0<C1
/03Ab[P0dlbj0=G>_0030=C=^a80eLjl0180e]6k0=3:^P3GdLD0d/fj0=SD
^`3?b[L0]jn]05aAH@1lKY80VHZc09N7]02UULH0UhJj09Z:^`2MSKX0UXNb
09^;^P2LS;/209^;^P0<09b<^`2JR[T0W8bk0::B`@2_Y<`0_[GB0<RneP1e
Jh@0GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0QgB/08Qd/@28M;40QWF/
08ak[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^VJ00LZFY07:W[@1iYJhe
07JW[PP0MjR_201hZK0307VZ/@D0NZVa201kZ[8307b[/`<0O:^a1@1m[;85
082]/`H0PJjd1@22[kD508>`]P<0Q;6g0`25/;L808Ja^0D0Qk:i1@2:/kT6
08^d^PD0S;Fk1@2=][`808jg_@<0SkRn00`0T;Nl08nh_02?^;h0V[o50:g<
d@2kdmL0b=KI08VCU03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3Y
jNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC
0:6_eP2Q[/h90:2^d@<0XJoB0100Wjg@09f[cP2JZ</0V:K909bVb@2JYL<0
M82J06QgSP27UJl0TZ:l09VXb@2Q[m@0Wjk?0:6`d@2R/M80XK3A0P2P[]42
09n]d00Y0:B]eP2X/]H0]KkK0;_3f038dN00f>7Z0=GLi03FgN<0^/7A08:9
V`1HGg80GF=i07R0U`21RIh0De]^07J1T`24T:P0Tini0:F`cP2]^=P0[K[J
0:bif@2/^]L0[K_F0:fkf02^_=T0/;_G0:njeP2/]m<0Yk;>0::/a`2NZ<<0
W:>o09VP^P2LY;T0VZ:e06=[OP1oQiX0SiN/09jV_@2[]]800P2f`Md20;G0
g0030;Bof`2f`Md0]L3L0100]L3L102e`M/03`2b_]H0[;S@0:Fab@2OZl<0
W:2[0=gQjP3kool0loSk0<kCeP36bm40i^[e0<S;fP2/]m<0/KcH0;Bof`02
0;G0g080]/7M4@2e`=`0402e`M/0]L3L0;?1g02c`M`0]/;L0;g8gP3;d^D0
e=W/0=GIi02@U9L0o_kl0?ooo@3ooOl0ooko0?kno`3noo/Z0?ooo`008@3o
ool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2][:X0
PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2bZLP0702aZ<D0]Zg8
0<>kdP3?am`0dloM085iSP1PEg@0PGFK08n2[@2JR[T0Vh^h09f<^@2OSk`0
UXJe09f=_02LS;/0VHbh09b?^P2NT[P0[Z;80<S0e`2]Y[H0QH26096<R02F
TXH0YZ>B0<Fo[`3<a[H50=C=^`80eLjl00<0e<fk0=G>_03Ec[`03P3Ec[`0
4P3GdkP0c/Vf0=;<`03Dc/00d<^g0=7<^03?bK/0WIJ@05Q<I022M9D0TX>^
09Z9_@2KR/40VhZn09Z:]`2SU;/0Vh^j09b<^`80Vh^j00`0W8bk09Z:^@2L
S;/0XY;10:nTc02n]M80b;kF07E[Q01ND7@0OFfN08IcZ`28MJdX08Qd[`0@
08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`XLP0RX:G05Q/M`1GOXD0
HX^A06jIX01bYJT0LZN]07VU[S@0MZN^201gZ:l807RY/0@0NJZa101jZK48
07^Z/P@0O:^c0P1lZk4607f//P@0P:fc1P21[[@608:_]@@0Pk2f1024/KL2
08F`]`P0Q[6h1P27/[T408Zc^@H0RkBj1P2<]K/408ff_0P0S[Nm102?^;h0
302@]k`0SkRl08nh_P2J_lD0[LcA0;_Ce`38e]T0RI>D0?Shn03no_h0oooo
0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3o
ool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A
07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPX0X:kA0P2Q[m80:02P[]40
Wjg@09f[cP2LZ/d0UJ;409JS``2FY;l0DEmi08NE/02FY<40Wjc<0::_d@2Y
^=T0Y[GF0:Bce02S/]40X[7@0:>bd@2Y]]H0[[_K0;Nkh02oa>80alcR0=CJ
j03Eg>@0hn[`0=gTk02KWjX0G6Mk06ehSP23SJH0RiF`08bF/@29Tj`0Ef=i
07V6V@24T:P0U:2j0:F`cP2^^MT20:fjfP040:fkf02]^mH0[[cI0:jlf@80
/;_G00d0[KSD0:Rcc`2R[<L0WZS309bS_`2IX;X0W:Bi09ZR]@1SJgh0OhNJ
08nG[02NY[d0ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M0;G0g00@0;G0g00B
0;Bof`2e`=`0]L7K0;K2g02d`=X0/KgE0:^gc`2W/l/0X:Rk09fU/P3:dmP0
l__j0?Woo`3io_l0o?ko0=GFj02^^MD0/[gI0`2e`=`20;K1gA40]L3L0100
]L7K0;G0g02c`M`0/l7L0;K2g02mb=h0bm;U0=CIk03EfN@0T9BG0?kno03o
ood0oogo0?ono`3no_l0o_ok:P3oool00240oooo00l0o_kn0?[jnP3dm?@0
kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_
Y/40:02bZLP20;:YaP80/ZW801h0/JS50;J]b033^m80clOL0=??g@21NHh0
H5Md085eV`2?PZd0VXZi09^;^02MS;T0WHfj09V9^02LS;/0Vh^j09^>^P2M
TKT0YIZl0;nde03>b=H0PG^508b6QP2>RX40X9f>0;B^WP38`[80dlfm0=K?
_@3Ec[`20=C=^`040=G>_03DcK/0e<fk0=C=^a00eLjl0180dlnd0=G@_03A
bkd0em730<o:]`3Hdkd0`KbX0=3;^02AQi00KF9c09:4Y@2CPk80WHc209N6
^P2IRKH0VHZc09^;^P2LS;/209^;^P0<09b<^`2JR[T0W8bk0::B`@2_Y<`0
_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0R7F]:028M:l04027M:/0QgB/08Qd
/@28M;40QWF/08ak[`2NSkX0/:7808Z2U`1HK7L0Egj506:;T@1^VJ00LZFY
07:W[@1iYJhd07JW[PP0MjR_201hZK0407VZ/@@0NZVa201kZ[8407b[/`H0
OJbb0P1n[K<4082]/`@0PJjd1P22[kD608>`]P@0Q;6g1P26/KP808Nb^@80
R;>j102:/kT408^d^PH0S;Fk1P2=][`808jg_@@0SkRn00`0T;Nl08nh_02?
^;h0V[o50:k=dP2le=P0bMOJ08VCU03hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0
n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG
]02HZLD0WjoC0:6_eP2Q[/h80:2^d@0309n]d02P[]40X:kA00<0X:kA02H0
Wjg@09j/c`2O[<h0WZ_;09bYb@23TJh0EF>0092N^`2U/]80Y[?C0:^je`2Y
^=D0[;[G0;6og02b`=/0/kkJ0;O3g@2obnD0b/cS0=OJk@3Mh>l0g>?]0>S_
n@2k`Ll0LGJ9075fS024TZ`0Sifh09:P_@28Tk40QY6]08^G/@1JIW`0LWnB
08FAZ@2DX;X0YK3>0:jif@80[K[J01<0[K_H0:fkeP2^_=T0[[cI0;6lf02`
^mL0[KSD0:Rcc`2S[LP0WZS309fT`02JXK/0W:Bi09ZR]@1TK7l0OhNJ08nG
[02NY[d0ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M0;G0g00@0;G0g0030;Bo
f`2e`=`0]L3L0080]/;L00d0/koI0;2le02^^]80Z[?@09nZ`02RZkX0ZK:k
0<?:e03;cm/0a<KK0:f]a`2`^mL0/kkJ00<0]L3L0P2f`Md00`2d_m/0]L3L
0;G0g00>0;G0g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3DfN`0
eMWT092DU`3no_`0ooom0?omo`3oo_l0o_ko0?konbX0oooo000Q0?ooo`0?
0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0
PgjD09><Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00O0;6Xa@2f[LP0`k_B
0<o7g03Ccmd0PGV>061GM021MI/0Sh:]09Z:^@2KRkP0WHbi09V9]P2KRkX0
W8bm09^;_02JSKT0X9Bj0;>XaP38_]L0Z:6X08AnP02BSHL0UY:60:nZU`36
`Jh0blJc0=G?_`3Fckd0eLjl0=C=^`020=G>_0<0e<fk403Ec[`04P3EckT0
e<fj0=?<^P3Ec[h0f]?10<c5/P3Hd[`0blF_0<g6_026OGh0KfAe08n1Y02H
R;D0VXZi0:6A`02HR;D0Vh^j09b<^`80Vh^j00`0W8bk09Z:^@2LS;/0XY;1
0:nTc02n]M80b;kF07E[Q01ND7@0OFfN08IcZ`28MJdX08Qd[`0@08MdZ`27
M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`XLP0RX:G05Q/M`1GOXD0HX^A06jI
X01bYJT0LZN]07VU[S<0MZN^201gZ:l807RY/0D0NJZa0`1jZK4807^Z/PD0
O:^c1@1m[;8307j]/`<0P:fc1@21[[@508:_]@H0Pk2f1@24/KL508Ja^0P0
Qk:i0`28/kX308Zc^@D0RkBj1@2<]K/608ff_0P0S[Nm1@2?^;h0302A^;d0
SkRl08nh_P2J_lD0[/gB0;cDf039emX0RYBE0?Shn03no_h0oooo0?knoP80
oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn
0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07QmT@1o
R:T0R9Nd09RYa@2O[m<0XJoF0:6^cPP0X:kA00<0Wjg@0:2^d@2P[]40102P
[]40:@2O[M00Xk;C09VXb@2O[/l0WJ[:07F2XP1XLi40VZG30:^fe02e`md0
]/CN0;_7h@2obN80`LcR0<K>i@3<e>T0dmW_0=[NjP3Kgn/0i^ch0=KMk@2>
UJP0JG6808RA[P2LYL@0Tj6n08fJ^P29U[H0QiBd08nJ^02@W;H0G6Qn07N4
U`25TJT0U:2j0:Jac`2^^MT0[[_K0:fjfP2^_=T0[[cG0080[kgJ00l0/KcH
0;2ke`2^^MD0Z;??0:>]b02OZL@0WJC009ZQ^`2MYKX0VZ:e06A/O`1oQiX0
SiN/09jV_@2[]]800P2f`Md20;G0g0030;Bof`2f`Md0]L3L01<0]L3L00<0
]/7M0;G1f`2e`M/00P2c_mT03@2[]]H0]/7M0:Vec@2W//H0[[K;0:Z`b02f
^mP0/KKD0;:mf@2d_m/0]L3L0;Bof`2e`=`00P2f`Md00`2d_m/0]L3L0;G0
g00>0;G0g00@0;G1f`2e`=`0/l7L0;?1g02f`]`0_LSN0<_Bi@3DfN`0eMWT
092DU`3no_`0ooom0?omo`3oo_l0o_ko0?konbX0oooo000Q0?ooo`0?0?kn
oP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD
09><Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00M0;6Xa@2f[LP0`k_B0<o7
g03Ccmd0PGV>061GM021MI/0Sh:]09Z:^@2KRkP0WHbi09V9]P2LS;/0Vh^l
09f=_P2LSk/0[:340<6gdP2g[/<0OgUk08n:QP2<R7d0ZJ>C0;bgX`3>bKD0
eM2m0=?<_03Ec[`00P3DcK/20=G>_080dlbj4@3Ec[`04P3DcKX0e/nl0=C=
^P3@bKH0e/nl0=O@_@3BbkP0clRe0<k:/@33_Jl0Mfia071TN02>P:<0UHJa
0961/02MSKh0Vh^j09b<^`80Vh^j00`0W8bk09Z:^@2LS;/0XY;10:nTc02n
]M80b;kF07E[Q01ND7@0OFfN08IcZ`28MJdX08Qd[`0@08MdZ`27M:`0R7Ba
08Qd/@26MJ`0S7^_09j?^P2`XLP0RX:G05Q/M`1GOXD0HX^A06jIX01bYJT0
LZN]07VU[S80MZN^201gZ:l807RY/0H0NJZa0P1jZK4807^Z/PH0O:^c101m
[;8407j]/`80P:fc1P21[[@408:_]@H0Pk2f1P24/KL408Ja^0P0Qk:i1028
/kX208Zc^@H0RkBj102<]K/608ff_0P0S[Nm1P2?^;h0302A^;d0SkRl08nh
_P2J_lD0[/gB0;cDf039emX0RYBE0?Shn03no_h0oooo0?knoP80oooo00<0
oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3h
n?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07QmT@1oR:T0R9Nd
09RYa@2O[m<0XJoF0:6^cQ00X:kA02@0WJc=0:Fde@2U]=D0WJ[<0:Bad`1i
Q:@0GVV708fH]02b_]@0_/WO0<KAi@38d>D0cMCW0=OLk`3NhO80g=o`0>C[
m@3<d^00SIBW05UPNP1mQZ<0Yk;B09VVb02HYlP0UJC508fJ_028UKL0RYFe
08fH]P28TZd0EV5e07V4UP26TZX0UJ6k0:Jac`2_^]X20:jkf`040:jlf@2^
_=L0[kgJ0:nmfP80/KcH00d0[[WE0:Vdd02S[LP0WjW409fT`02KX[`0WJFj
09ZR]@1TK7l0OhNJ08nG[02NY[d0ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M
0;G0g00@0;G0g0030;G0gP2e`=`0]L3L0080]L3L00`0]L7K0;C0fP2e`M/0
]lGO0:Nec`2__MP0/kkJ0:fhe02d_m/0[KSD0;S3g`2d_m/20;G0g0050;Bo
f`2e`=`0]/7M0;K1g@2d_m/0402e`=`0402e`M/0]L3L0;?1g02c`M`0]/;L
0;g8gP3;d^D0e=W/0=GIi02@U9L0o_kl0?ooo@3ooOl0ooko0?kno`3noo/Z
0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M
0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2bZLP0
8@2aZ<D0]Zg80<>kdP3?am`0dloM085iSP1PEg@0PGFK08n2[@2JR[T0Vh^h
09f<^@2LS;T0Vh^j09V9^P2PT<40XIC00;R]c`38_]L0X9NZ08Z5PP2@RhD0
Wi^?0;2[V03;a[00blJb0=_D`P3Ab[X0e<fk0=?<^P3DcK/0e/nm0=G>_002
0=?<^Q80eLjl0140d<Vf0=WC_@3Hd[`0dLZg0=G>_03Ab[X0e/nm0<o<Z`3D
ckT0b<6i061FG`1jKHL0S7fV09V9^P2GQ[`0Vh^j09b<^`0209^;^P0<09b<
^`2JR[T0W8bk0::B`@2_Y<`0_[GB0<RneP1eJh@0GU1d07e]WP26Lj/0R7F]
:028M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak[`2NSkX0/:7808Z2U`1H
K7L0Egj506:;T@1^VJ00LZFY07:W[@1iYJh`07JW[PL0MjR_201hZK0807VZ
/@0307Z[/P1kZ[80NjZb00D0NjZb201lZk<00`1m[;@0OJbb07f//P0207f/
/P@0OZfc1`21[[@508:_]@@0Pk2f1`24/KL00`25/[P0Q[6h08Ja^00208Ja
^0P0Qk:i1028/kX708^d^PD0S;Fk102=][`708jg_@P0SkRn00d0T;Vo096h
_@2@^Kd0T;Vo09Zoa@2^cM80_=CH0<WGfP2:U9D0n?Sh0?knoP3oool0o_kn
0080oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0
o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07Qm
T@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPP0X:kA0`2Q[m830:2^d@80XJoB
02@0WZk?0:2_d02N[<l0X:g@0:>`dP2PZl/0U9nm07AmVP1RKH40QhnT0:R`
``2g_]00_lGE0<?6e@2e]l@0WZ2]06ifP`1WKX00QHbV0::]c@2Q[]40W:[=
09^[c02EZ<H0TIk008nL_P2<VK/0RIBd08^D/@2<UZl0GFEj07^4U@26TZX0
UJ6k0:Jac`2_^]X20:jkf`040:jlf@2^_=L0[kgJ0:nmfP80/KcH00d0[[WE
0:Vdd02T[/T0WjW409jU`@2KX[`0WJFj09^S]P1TK7l0OhNJ08nG[02NY[d0
ZkKB0080]/7M0P2e`=`00`2d_m/0]/7M0;G0g00@0;G0g080]L3N00@0]L3L
0;Bof`2d_m/0]<3J0P2e`M/02@2a`=<0^LSM0;2nf02b`=d0[kkK0;?2g`2^
_]P0//;K0;Bof`020;K1g@050;Bof`2e`=`0]/7M0;K1g@2d_m/0402e`=`0
402e`M/0]L3L0;?1g02c`M`0]/;L0;g8gP3;d^D0e=W/0=GIi02@U9L0o_kl
0?ooo@3ooOl0ooko0?kno`3noo/Z0?ooo`008@3oool03`3no_h0n_[j0?Cd
m03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh
0:nV`@0X0;:Yb080/ZW60P2bZLP0702bZLH0^:o:0<Bld`3?am`0e];P07]c
R01SFWL0PWJL08n2[@2IRKP0WHfj09f<^@2KRkP0WXjm09R;^@2RUL40XiNk
0<6gc`2_ZK<0Pgn00969O02KThH0[JJF0<:kZ`3@bKT0e/nm0=G>_03Cc;XP
0=G>_00:0=G>a03BcKX0eM2j0<K0]01?Ae80SH:R08]n[02EQkX0VXZg09b<
^@80Vh^h00/0W8bi09Z:]`2LS;T0XY:o0:nTc02n]M@0b;kF07E[Q01NCgH0
OFfN08IcZ`0Y08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`
XLP0RX:G05Q/M`1GOXD0HX^A06jIX01bYJT0LZN]07VU[R00MZN^101eYZd=
07JW[PP0MjR_1`1hZK000`1iZ;00NZVa07ZY/@0507ZY/@@0NjZb101lZk<0
0`1lZk40OJbb07f//P0507f//P0307n//P20[K<0P:fc00D0P:fc1021[[@4
08:_]@0308>^]@24[kH0Q:nf00D0Q:nf1025/;L508Ja^0L0Qk:i102:/kT8
08^d^PD0S;Fk202=][`708jg_@@0T;Nn102A^;l0302A^;d0TKZn096j`02J
_lD0[/gB0;gEf@3:f=/0RI>D0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0
l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07QmT@1oR:T0R9Nd09RY
a@2O[m<0XJoF0:6^cQP0X:kA00@0UjG0082>Z@1ZN9<0Hg6<0P1PKXT06`1/
NYD0O8ZU09NUb02LZ/d0XJoB0::`d`2P[]40WZc?09^Yc02HY/T0TZ2m08fJ
^P29V;L0QiJe08ZH]@2:U[00Ff=j07b2V027TZP0Uj6j0:Rcc`2`^mT0/KcJ
0;2kf@2__MP0/;kH0;6lf0030;:mf@0=0:nke@2Y]Ll0XZk809jZa02KZ;/0
V:Bl09bV`@2HXkL0Hfmm07j:UP2@V:/0WjK20:fgdP030;K0f`030;O1g02d
_]T0]/3K03T0]/3K0P2e_mX20;C0fP0<0;K2fP30b=l0bm;U0=?Hj`3EfN@0
TIFH0?kno03oo_`0o_co0?ono`3oool0oOoj:P3oool00240oooo00l0o_kn
0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0
Thb[0::I^02_Y/40:02bZLP20;:YaP80/ZW801T0/ZW60;R_bP34_=<0clOL
0=GAg`1kLhP0HeYg089fW02?PZd0VHVh09f=^P2LRkP0W8bi09^;^02KS[`0
WY6l0;6Vb03:`MH0TXfD08N3PP2CRgh0Xib<0;N`X038`K40dLZj00<0e<fk
803Ec[`02@3Dc/80e<nl0=KA^`3Abkd0NG9i075WPP2:OJP0TH>d09V9]P03
09^;^00;09b<^@2JR[L0W8bi0::B_`2_Y<`0_[GD0<RneP1eJh@0GTmf07e]
WP26Lj/0:@28M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak[`2NSkX0/:78
08Z2U`1HK7L0Egj506:;T@1^VJ00LZFY07:W[@1iYJhP07JW[P@0MJJ]301f
Yjh607NX[`P0N:V`0P1iZ[4607ZY/@H0NjZb101lZk<607f//P80OZfc1P20
[K<6086^]0@0PZne1P24[kH608F`]`@0Q[6h1P27/[T208Rc^P@0R[>i202;
];X408be^`H0SKJl202>]kd208nh_P@0T;Nn102A^;l0302A^;d0TKZn096j
`02J_lD0[/gB0;gEf@3:f=/0RI>D0?Shn03no_h0oooo0?knoP80oooo00<0
oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3h
n?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07QmT@1oR:T0R9Nd
09RYa@2O[m<0XJoF0:6^cQP0X:kA0240XZo?09j[b`2MZ/X0XJk>0::_c`2P
[Ld0Wjc<0:6^cP2KZL`0Wjg@0:6_dP2P[]40Wjg@09j/c`2KZL`0V:K909:P
_@2=V[X0RIRg08NF]@2:V;D0RYJ`05]SNP1lPYP0Qi:X09NQ^P2X/ll0/;_I
0;6lfP2`^mT0[kgH0;2nf02a_=P00`2b_MT03@2_^mD0ZKG?0::^b02MZL<0
W:Vl09RT_02KYL00V:>i069^O01lR9H0SYJ[09fT`02/^=800`2e`M/00`2f
`]`0/koI0;G1f`0j0;G1f`0?0;G0g02c`M`0//3K0;K2g02mb=h0b]7T0=?H
j`3Df><0TIFH0?kno03oo_`0o_co0?ono`3no_l0oOoj02X0oooo000Q0?oo
o`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21
OXD0PgjD09><Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00J0;:YaP2h[lX0
a;cC0<o7g03EdMl0NW:7069IMP22MY`0Sh:]09V9^02MSKX0W8^h09b<^@2J
R[L0Vhjj0:>F`@2n/m<0_[G807iiO@2<RH@0VI:20:nXV035_Zh0clRh0=;;
^@3Cc;X20=C=^b00eLjl00X0dlfo0=KA_@3GdkX0gMO70;2ZZP1EC640QWZN
08]nZP2FQ[<0VXZg0P2KRkP02`2LS;T0VXZg09b<^@2RT[l0[jC<0;jee038
_]H0MF^405i?MP1mKIh0QW>[02T0R7B_0100QgB[08Md[028M;40R7Ba08Ie
[02<Njl0WXnj0;2Qb02:PYL0F6ag05MnQ@1RRi40KYVP07:UZ@1bYjd0NJF^
801fYjh307FV[@d0MZN^1@1gZ:l807RY/0<0NJZa1@1jZK4607^Z/PD0O:^c
1@1m[;8307j]/`D0P:fc1P21[[@508:_]@D0Q:nf1P25/;L508Ja^0D0Qk:i
0`28/kX308Zc^@P0RkBj1@2<]K/508ff_0P0S[Nm0`2?^;h3092g_PD0TKRo
00`0TKRm096j_P2A^/00V[o50:k=dP2meMT0b]SK08VCU03hn?P0o_kn0?oo
o`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0
oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jB
T@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/hH0:2^d@030:6^d02S/=80
Xk3B0080XJk@00@0Xk3B0::_d@2P[Ll0Wjg@0P2Q[m80402O[M00WZc?09j/
c`2KZL`0V:K909:P_@2=V[X0RIRg08NF]@2:V;D0RYJ`05]SNP1lPYP0Qi:X
09NQ^P2X/ll30;6lfP030:nmf02`_]P0/[gI00<0/[gI00d0[k_E0:Vec`2R
[/P0WZ[409fZ_@2HY;`0VjG009^V_01RKWh0O8RF08fEZP2NYL40Z[SC0080
/l7L0P2d`]d00`2b`=/0]<;M0;C2g@0h0;?1g00@0;O2gP2d`]d0//7N0;71
f`2d`]`0_LWQ0<[Bi`3BfN`0dmOR092DU`3no_`0ooom0?klo`3oo_l0o_ko
0?konbX0oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cL
g03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0[jK102P0/ZW80P2bZLH2
0;:Yb00G0;:YaP2h[lX0a;cC0<o7g03Dd=h0NW:7069IMP22MY`0Sh:]09V9
^02MSKX0W8^h09^;^02LS;T0VXfi0;2Tc033^=H0VI6P08F1P02?S8<0XY^;
0;ZcX`3>akL00`3Cc;X20=C=^R00eLjl00X0dljk0=OB_03JeKl0h]g:0=KA
c@1ABEH0Ng2>08IjXP2CPk00VHVf0P2KRkP02`2LS;T0VXZg09b<^@2RT[l0
[jC<0;jee038_]H0MF^405i?MP1mKIh0QW>[02T0R7B_0100QgB[08Md[028
M;40R7Ba08Ie[02<Njl0WXnj0;2Qb02:PYL0F6ag05MnQ@1RRi40KYVP07:U
Z@1bYjd0NJF^801fYjh207FV[@h0MZN^101gZ:l807RY/0@0NJZa101jZK46
07^Z/PH0O:^c101m[;8407j]/`@0P:fc1P21[[@608:_]@@0Q:nf1P25/;L6
08Ja^0@0Qk:i1028/kX208Zc^@P0RkBj1P2<]K/408ff_0P0S[Nm102?^;h2
092g_PH0TKRo00`0TKRm096j_P2A^/00V[o50:k=dP2meMT0b]SK08VCU03h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn
0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/2
0=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/hH0:2^d@08
09n]d02Q[m80XJoB09n]d02N[<l0Wjg@0:2^d@2O[M020:6_dP0F0:2^d@2O
[M00Wjg@09n]d02LZ/d0UjG809:P_@2=V[X0RIRg08NF]@2:V;D0RYJ`05]S
NP1lPYP0R9>Y09RR^`2Y]=00/KcJ0;:mf`2a_=X0/;kI0;6of@80/[gI00l0
/kkJ0;:mf@2_^mD0Z[K@0:B`bP2P[<H0Wj_109ZV`02NZ<<0X:_106=_O`1n
RYP0SYJ[09nV`P2Z^=<00P2c`M`20;C2g@030;;0f`2c`M`0/l7L03P0/l7L
0P2d`]d02P2b`Mh0/L7K0;C2g02mbN40b];W0=;Ik03Cen80Si>F0?kno03o
ood20?omo`030?kno`3noo/0oooo02T0oooo000Q0?ooo`0?0?knoP3jn_X0
m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2R
VKP0[jK102P0/ZW80P2bZLH20;:Yb00J0;:YaP2h[lX0a;cC0<o7g03Ccmd0
NG66069IMP22MY`0Sh:]09V9^02MSKX0W8^h09Z:]`2NS[/0WI2k0;JZcP31
]m00O7Ao092=R02CTH80[JJF0<>l[03Ab[P0dlbj0=C=^`3Ec[/20=C=^R00
eLjl00X0dljj0=OB_P3Mf<@0h=_80>;Ne@1XHFP0K69k08=gW@2?Oj`0UhNd
0P2LS;T02`2KRkP0VXZg09b<^@2RT[l0[jC<0;jee038_]H0MF^405i?MP1m
KIh0QW>[02T0R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;2Q
b02:PYL0F6ag05MnQ@1RRi40KYVP07:UZ@1bYjd0NJF^9P1fYjh>07NX[`P0
N:V`101iZ[4407ZY/@@0NjZb1P1lZk<207f/]0@0OJbb101n[K<4082]/`@0
PJjd1P22[kD208>`]P@0Q:nf1025/;L608Ja^0H0Qk:i1028/kX608^d^PP0
S;Fk1P2=][`808jg_@@0SkRn1P2A^;l209:i`00<096h_@2A^[h0TK[009Zo
a@2^cM80_MGI0<[Hf`29Ti@0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0
oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03b
l_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W5
09n_d`2Q[mH0XJk>602P[]402P2N[=40WjgB0:6_e02R/=D0XJoD09n]dP2P
[]<0X[3E0:2^d@2Q[m840:2^d@0B09bZc@2GYLP0TZ2m08fJ^P29V;L0QiJe
08ZH]@2:U[00Ff=j07b2V028TjT0V::k0:Vdd02a_=X0/[gK0;6lfP2`_]T0
/KoI0P2b_MT03`2c_]X0/[gI0;2leP2/^=80Yk?=0:B`bP2S[lD0Wj_50::[
b02T[/L0Hfmo07j:VP2>UZ/0WZG20:ZhdP030;?1f`030;C2g02a_mT0/l7K
03X0/l7K00/0/l7L0;71f`2a`M/0]<;L0;c8gP39dN@0d]W[0=CHh`2@U9L0
oOgk0?ooo@020?omo`030?gmo`3noo/0oooo02T0oooo000Q0?ooo`0?0?kn
oP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD
09><Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00J0;:YaP2h[lX0a;cC0<o7
g03Ccmd0NG66069IMP22MY`0T8>^09V9^02MSKX0W8^h09^;^02LS;T0Y9O2
0;J[c@2h[l@0NW=j096?P`2IV8@0]k2N0<S1[`3BbkT0dLZh0=C=^P3Fck`2
0=C=^R00eLjl00X0dljj0=KA_P3NfLH0gmW90>7MdP28PX@0GeI[081dV02<
O:T0UXJc0P2LS;T02`2KRkP0VXZg09b<^@2RT[l0[jC<0;jee038_]H0MF^4
05i?MP1mKIh0QW>[02T0R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<Njl0
WXnj0;2Qb02:PYL0F6ag05MnQ@1RRi40KYVP07:UZ@1bYjd0NJF^9@1fYjh>
07NX[`P0N:V`1@1iZ[4307ZY/@D0NjZb1@1lZk<307f/]0<0OJbb1@1n[K<3
082]/`D0PJjd1@22[kD308>`]P<0Q:nf1@25/;L508Ja^0H0Qk:i1@28/kX5
08^d^PP0S;Fk1P2=][`808jg_@D0SkRn1@2A^;l309:i`00<096h_@2A^[h0
TK[009Zoa@2^cM80_MGI0<[Hf`29Ti@0n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm
0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28
Uk@0V:W509n_d`2Q[mH0XJk>602P[]402@2R/=D0WjgB09n]dP2Q[m@0X:kC
09f[d02N[=40X[3E09n]d0030:2^d@80XJoB00d0W:[=09NUb02BX;d0SIZj
08VH]`27U[D0RYRe08ZF/01KHgX0O8:H08VDZP2IXk`0ZKC@00<0/[gK00<0
/KoJ0;6of@2c_]X00`2c_]X03@2b_]P0[k_E0:bhdP2Y]Ll0Z;C:0:Jbc02X
/Lh0Z;;;065/OP20S9`0TIV`0::YaP2`_=@00P2ha=`20;W5g@030;O3f`2i
aMd0^LGM03P0^<CL00`0^L?L0;S4g02fa=h0]/GL0;W5f`31c>00cMCV0=GK
j`3GfnH0T9BG0?gmn`3oood20?ono`030?gmo`3noo/0oooo02T0oooo000Q
0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/
ZP21OXD0PgjD09><Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00H0;:YaP2h
[lX0a;cC0<o7g03Bc]`0N725069IMP22MY`0T8>^09V9^02LS;T0W8^h09^;
^02LSKP0Z9c40;V^d02RVJ`0Pgeo096?P02RXXX0_[NU0<g6]03Cc;X0d/^h
0P3Ec[/00`3Cc;T0e<jh0=G>_00O0=G>_00:0=;=^P3Fd<00g=K80>?Mc`3P
g=00WYRH05Q?I01mLIL0RWZW09F5/P80W8bi00/0Vh^h09Z:]`2MSKX0XY:o
0:nTc02n]M@0b;kF07E[Q01NCgH0OFfN08IcZ`0Y08Qd[`0@08MdZ`27M:`0
R7Ba08Qd/@26MJ`0S7^_09j?^P2`XLP0RX:G05Q/M`1GOXD0HX^A06jIX01b
YJT0LZN]07VU[R@0MZN^3P1gZ:l807RY/0H0NJZa0P1jZK4607^Z/P@0O:^c
101m[;@207f//PH0OZfc0P20[K<6086^]0@0PZne1023/;H208B_]PH0QK2g
1026/KP608Nb^@H0R;>j102;];X808be^`H0SKJl202>]kd608nh_P@0TKRo
102B^L00302A^;d0TKZn096j`02J_lD0[/gB0;gEf@3:f=/0RI>D0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo
0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J
00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cQP0X:kA0P2L[<h0
102O[m40X[;D0:>ce@2P/=8209n_d@0309n]d02P[]40X:kA00<0X:kA01<0
W:[=09NUb02BX;d0SIZj08VH]`27U[D0RYRe08ZF/01KHgX0O8:H08VDZP2I
Xk`0Z[GA0;:mf`2c_]`0/[gK0;6ofP2b`=X0];oK00<0/kkJ0180/koI0;:n
f02`_=H0[[[D0:bhd02]^=@0[[OD0:fgd01SKX00R9BT09bT^`2_]]<0_LGL
0<K>i@35cN@0a/kU0<O?iP34c><j0<K>i@0<0<K>h`34cnD0a<oU0<?>i034
cn<0cMCV0=KLjP3Nh^h0f]kY096EV03lo?X0ooom0P3oo_l00`3no_l0o_ok
0?ooo`0Y0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3L
g=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080/ZW6
0P2bZLP0702bZLH0^:o:0<Bld`3?am`0d/kL07Q`Q@1QF7D0PWJL0923[P2I
RKP0W8bi09b;^02KS;L0WXnj0:RLa030]MD0SHBG08J0P02GUHH0Z:R>0<6j
Z03?b;H0eLjl0=?<^@3Ec[/0e<fj0=7;]@3EckTP0=G>_00:0=7<^@3Fd<80
f]C80>SReP3Sgm<0YZ2P05I=HP1jKY@0R7RU09B4/@80W8bi00/0Vh^h09Z:
]`2MSKX0XY:o0:nTc02n]M@0b;kF07E[Q01NCgH0OFfN08IcZ`0Y08Qd[`0@
08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`XLP0RX:G05Q/M`1GOXD0
HX^A06jIX01bYJT0LZN]07VU[R@0MZN^301gZ:l707RY/0P0NJZa00<0NZ^b
07^Z/P1kZ[801@1kZ[8507b[/`@0OJbd1`1n[K<00`1o[[@0PJjd086^]005
086^]0D0PZne1023/;H708F`]`D0Q[6h1027/[T708Rc^P0308Vd^`2;];X0
RkBj0080RkBj202<]K/408ff_0L0S[Nm202?^;h00`2@^Kl0TKRo096h_`02
096h_`@0T[W000`0TKRm096j_P2A^/00V[o50:k=dP2meMT0b]SK08VCU03h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn
0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/2
0=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/hH0:2^d@80
XK7C00@0WjoA09b/cP2L[<h0WJg?0P2O[m400`2P[]40XJoB0:6_dP0209n]
d00D09j/c`2KZL`0V:K909:P_@2=V[X0RIRg08NF]@2:V;D0RYJ`05]SNP1l
PYP0RIBZ09VS_02Z]M40/[gK0;>ng02b_M/0/KoJ0;;0fP2d_m/30;>nfP80
]<3J00d0/koI0;:nf02_^m<0/[gI0;>lf@2`^]<0IW63092L[02Y/LP0_<;R
0<S?hP3Af>/0d=OZ0080dMS[00<0cmKY0=7Hj`3Af>/0>03@enX0303Af>/0
dMW^0=7IkP3@f>d0d=S[0=KLk03Pi?00inWe0=cPj`2BUYT0o?cj0?ooo@80
ooko00<0o_ko0?kon`3oool0:@3oool00240oooo00l0o_kn0?[jnP3dm?@0
kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_
Y/40:02bZLP20;:YaP80/ZW801H0/ZW60;R_bP34_=<0clOL0=??g@1gKh@0
HeYg085eV`2>PJ`0VXZi09^;^02MS;T0VXZi0:6A`02WW<H0_KC?07mjP02;
R7l0WYR:0;2ZW035_Z`0dLZh0P3DcK/0103Ec[`0e<fk0=G>_03DcK/P0=G>
_00:0=O@_@3Dc[h0g=W:0=oMcP3YimX0Z:BQ05UAH01gKHP0QgRS09F6/@80
VXZi00`0W8bk09^;^P2LSKP0XiBo0;6Vb030]]40b<3G07E/Q`1MDGT0OVfQ
08MbZ`2;LjdX08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2`
XLP0RH6F05M[MP1GOXD0HhbB06jIX01cYZX0LZN]07VU[QP0MZN^101eYZd=
07JW[PP0MjR_1`1hZK000`1iZ;00NZVa07ZY/@0507ZY/@@0NjZ`1@1lZk47
07f//P@0P:fc1@21[[@708:_]@@0Q:nf2025/;L508Ja^0L0Qk:i102:/kT5
08^d^PP0S;Fk1`2=][`408jg_@@0SkRn102@]kh8096h_`@0T[W000`0T[Vn
09>j_`2C^[l0Vl740:k=d02oe=L0b]SI08ZBU03hn?P0o_kn0?ooo`3no_h2
0?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?kn
oP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40
OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h80:2^d@80Wjg@102P[]420:6_dP<0
X:kA0`2Q[m8:0:2^d@030:2^d`2Q[m@0X:kA00<0X:kA0180W:_<09NVa`2B
X;d0SIZj08VH]`26UK@0RINd08VE[`1LI7/0OXBJ08VDZP2IXk`0Z[K@0;:m
f@2c_]X0/[gI0;6of@2b`=X80;Bof`0:0;:mf`2h`ml0/;_G0;O1g01YLh`0
WZVo0;c4f@35cN80f=oY0=WPjP80f^7[0P3Kh^`R0=[Qj`0@0=WPjP3JhN/0
fN3Z0=[Qj`3Kh^`0f=oY0=ONj03Kh^`0f^;_0=OMj@3KgnX0gn;[0>3PjP3J
gNH0g>3[0=_Oj`P0fn7_00d0g^;[0=cPj@3KgnP0fmoX0=gQjP3QiNh0i^[c
0>S/m@3Vi^H0UYJF0?_kn`3oool0n_[j02d0oooo000Q0?ooo`0?0?knoP3j
n_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><
Z`2RVKP0[jK102P0/ZW80P2bZLH20;:Yb00F0;:YaP2h[lX0a;cC0<o7g03C
cmd0Mfn406=JM`21MI/0SX6/09Z:^@2KRkP0WHbi09Z:]`2PT;l0Z9g70;bc
cP1kMWd0SX^20:2JS02b[9h0a[n]0=;;^@80e<fk00@0eLjl0=C=^`3Ec[`0
e<fk803Ec[`02P3DcKX0eLno0=cIbP3ShM@0i^CH0:^WY01FCUd0MV^908Mh
X`2DQK0209Z:^@80W8bk00X0W8fh0:>D_`2aY/P0`;KA0<S0e`1eK8L0GE5i
07i]X@27LZ/0Rg>]:028M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak[`2N
SkX0/:7808V1UP1GJgH0Egj506><TP1^VJ00LjJZ07:W[@1iYJhH07JW[P@0
MJJ]301fYjh607NX[`P0N:V`0P1iZ[4607ZY/@80NjZb101kZ[0407b[/@H0
OJbb0P1n[K<4082]/`@0PJjd1P22[kD208>`]P@0Q:nf2025/;L408Ja^0H0
Qk:i0P28/kX408Zc^@@0RkBj1P2<]K/808ff_0H0S[Nm102?^;h4092g_PP0
TKRo102B^L00302B^Kh0TkZo09>j_`2K`L@0[/g@0;oDe`3:f=T0RY:D0?Sh
n03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0
oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80
f][J00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPP0X:kA0P2O
[M040:2^d@80XJoB202P[]400`2Q[m80X:kA0:2^d@050:2^d@030:2^d`2Q
[m@0X:kA00<0X:kA0180W:_<09NVa`2BX;d0SIZj08VH]`26UK@0RINd08VE
[`1LI7/0OXBJ08VDZP2IXk`0Z[K@0;:mf@2c_]X0/[gI0;6of@2b`=X80;G0
g0080;K1g`2d_m/0/kkJ0;K0f`24SZL0SiZ`09^V^P2V[/<20:^c`080[;C1
0P2]]L8R0:bd`@0@0:^c`02/]<40Zk?00:bd`@2]]L80Zk?00:Zb_`2^]/<0
/;O70;BjaP2c]l80XJB[0<71b@30`lX0_/780;g1bPP0_L;800X0_/780;g0
a`2m`<L0_L370;k1b030`lX0`lK=0<C7cP2o_kl0^;Rh0P3oool00`3moOd0
no_k0?[jnP0[0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oO
g`3Lg=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb080
/ZW60P2bZLP0702bZLH0^:o:0<Bld`3?am`0dloM07M_Q01SFWL0PGFK08j1
[02JR[T0Vh^h09f<^@2KRkP0Whnn0:VNb02j/Lh0MFmi09:?R02TWY00][2P
0<S1[`3Cc;X0eLjl0=C=^`3Ec[`0dlbj0=G>_03DcK/P0=G>_00H0=?<^@3G
dL40g=S<0>KTe`3UhmL0YZ:Q05A;G01fJh/0QWNR09B5/02JR[T0Vh^j09f=
_02LS;/0W8fh0:>D_`2aY/P0`;KA0<S0e`1eK8L0GE5i07i]X@27LZ/0Rg>]
:028M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak[`2NSkX0/:7808V1UP1G
JgH0Egj506><TP1^VJ00LjJZ07:W[@1iYJhH07JW[P<0MJJ]3@1fYjh507NX
[`P0N:V`0`1iZ[4507ZY/@<0NjZb0`1kZ[0507b[/@D0OJbb0`1n[K<3082]
/`D0PJjd1@22[kD308>`]P<0Q:nf2025/;L508Ja^0D0Qk:i0`28/kX308Zc
^@D0RkBj1@2<]K/808ff_0H0S[Nm1@2?^;h3092g_PP0TKRo1@2B^L00302B
^Kh0TkZo09>j_`2K`L@0[/g@0;oDe`3:f=T0RY:D0?Shn03no_h0oooo0?kn
oP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0
o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07Qm
T@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cQ80X:kA1P2O[M070:2^d@0309n]
d02P[]<0XJoD00@0X:kA00d0W:_<09NVa`2BX;d0SIZj08VH]`26UK@0RINd
08VE[`1LI7/0OXBJ08VDZP2IXk`0Z[K@00<0/kkJ00<0/KoI0;;0fP2e`=`0
1`2e`=`01P2ia>00]L3L0;c7h`2g`md0Y[3908VDZP80PHbR00<0PXfQ08>>
XP23SZ809P23SZ801024Sj<0PXfQ08>>XP24Sj<208:=X@0908NBYP2@UjT0
Vj6_09NKYP1XJg00]KJj0;^l_P2d^;T0][Zk00P0^K^j1@2j^Kh30;^j_`06
0<G5a@3Vi^H0oooo0?[jnP3oool0oOgm;03oool00240oooo00l0o_kn0?[j
nP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[
0::I^02_Y/40:02bZLP20;:YaP80/ZW801L0/ZW60;R_bP34_=<0clOL0=??
g@1gKh@0HeYg085eV`2>PJ`0VXZi09^;^02MS;T0Vhbg09f=_02YW/T0]jk=
079/N02DTHX0Yj6C0;RbXP39`[00e<fk0=G>_0020=C=^`030=?<^P3Fckd0
eLjl0200eLjl00X0eLjk0=SB`P3Lf<`0i^CH0>OTf`2ASHh0FE1U07Q]S`26
Mj80U8F`0P2KRkX0302MSK`0W8bk09b=^02SU;l0/JK80<2fd@38`=L0MFb7
05eAN@1nKJ40Qg:[08]c[BP0R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<
Njl0WXnj0;2Qb029PIH0Ef]f05MnQ@1SS980KYVP07>VZP1bYjd0NJF^601f
Yjh207FV[@h0MZN^101gZ:l807RY/0@0NJZa101jZK4407^Z/P80NjZ`1P1l
Zk4407f//P@0OZfc0P20[K<6086^]0@0PZne1023/;H208B_]PP0QK2g1P26
/KP408Nb^@@0R;>j0P2:/kT608^d^P@0S;Fk202=][`608jg_@H0SkRn0P2@
]kh8096h_`H0T[W000`0T[Vn09>j_`2C^[l0Vl740:k=d02oe=L0b]SI08ZB
U03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0
o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3K
fm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h@0:2^
d@030:6_dP2P[]40X:kA00D0Wjg@202P[]400`2P[]<0XJoD0:2^d@030:2^
d@0B09b[c02GY/L0TZ2m08fJ^P29V;L0QYFd08VG]029UJl0G6Ak07j4VP2:
UJ/0VZBm0:^gd@2c_]X0];oK0;>nfP2b`=X0/l7K202e`=`20:fkeP060;O2
gP2`_=H0_/[T0;6ke02d_]L0]/3I0`2d`=XU0;G1f`0@0;C0fP2e`M/0]<3J
0;C0fP2e`M/0]<3J0;G1f`2kan40b=7R0=CKj`3Df><0TY>H0?gmo@3oood0
o?ki0?kon`P0ooom1P3ooOl20?klo`080?Shn03oool0o_kn0?gmo@3oool0
o_kn0?ooo`3inOTZ0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU
0=oOg`3Lg=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Y
b080/ZW60P2bZLP05`2bZLH0^:o:0<Bld`3?am`0dloM07M_Q01SFWL0PGFK
08j1[02JR[T0Vh^h09f<^@2KS;L0W8bk0:NKb@2cZL/0MFmm09:?RP2YXiD0
^KBQ0<W2/03DcK/0eLjl0080e<fk00<0dlbj0=K?_@3Ec[`0803Ec[`02P3F
ck`0f=;20=gIc@3Xi]X0kN[S07=^LP1QEfl0N6bB08QiY02FQk8209b<^`0<
09f=_02LS;/0WHji0:>D_`2aY/P0`;KA0<S0e`1eK8L0GE5i07i]X@27LZ/0
Rg>]:028M:l04027M:/0QgB/08Qd/@28M;40QWF/08ak[`2NSkX0/:7808V1
UP1GJgH0Egj506><TP1^VJ00LjJZ07:W[@1iYJhN07JW[Ph0MjR_201hZK04
07VZ/@@0NZVa101kZ[8607b[/@H0OJbb101n[K<6086^]0H0PZne1023/;H6
08F`]`P0Q[6h1P27/[T408Rc^PH0RkBj1P2<]K/808ff_0@0S[Nm1P2?^;h2
092i_`H0TKRo202B^L0209>j`@0<09:i_P2C^[l0TkZo09_1a02^cM00_mCG
0<[Hf@2:TY@0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A
0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Q
h@3MgMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0
XJk>402P[]40102Q/=40X:o@09n^c`2N[Lh409f/c@<0WZg>0P2O[/l30:2_
d0030:2^d`2Q[m@0X:kA00<0X:kA0180W:_<09NVa`2BX;d0SIZj08VH]`26
UK@0RINd08VE[`1LI7/0OXBJ08ZEZ`2JY;d0ZkOA0;>nfP2d_m/0/kkJ0;;0
fP2c`M/80;G0g0060;K4g`2e`mh0]<;L0:nke@2f`]`0/koI0P2h`]d00`2d
`]d0/l7L0;?1g00V0;?1g00?0;C2g@2c`M`0/l7L0;C2g@2c`M`0]<;M0;_9
i03;dnH0d]WY0=SLi`2>Si@0oooo0?oon`3oooX0o_oi00`0ooko103ooOh0
1@3oool0oOgm0?clo03oool0o?cl02d0oooo000Q0?ooo`0?0?knoP3jn_X0
m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2R
VKP0[jK102P0/ZW80P2bZLH20;:Yb00L0;:YaP2h[lX0a;cC0<o7g03Ccmd0
Mfn406=JM`21MI/0SX6/09Z:^@2KRkP0WHbi09^<]@2LS;/0YIW90;2Vb`1m
MXH0SHV60:ZTUP2i]:40b<6_0=?<^P3Ec[`0e<fk0=G>_03Cc;X0eLjl0=C=
^b00eLjl01P0e/nl0=SB`P3Rg]<0jnSO0>[WhP1JEE/0J5ig07Q/U02:NjH0
UhRc09f=_02LS;/0WXjm09b<^`2MS[T0Y9G00;6Vb030]]40b<3G07E/Q`1M
DGT0OVfQ08MbZ`2;LjdX08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_
09j?^P2`XLP0RH6F05M[MP1GOXD0HhbB06jIX01cYZX0LZN]07VU[Qd0MZN^
3P1gZ:l807RY/0D0NJZa0`1jZK4507^Z/PD0O:^a1P1m[;8507j]/`D0PJjd
1P22[kD508>`]PD0QK2g2026/KP608Nb^@D0R;>j1@2;];X608be^`P0SKJl
1@2>]kd508nh_P<0T;Vo1@2A^;l809:i`0<0Tk[100`0T[Vn09>j_`2C^[l0
Vl740:k=d02oe=L0b]SI08ZBU03hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh
0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02H
ZLD0WjoC0:6_eP2Q[/h@0:2^d@0509n^c`2N[Lh0WJc=09^Zb`2JZLX00P2I
Z<T01`2HYlP0VJS909ZYbP2KZ//0W:_<09f/c@2O[/l00P2P[m000`2P[]<0
XJoD0:2^d@030:2^d@0=09b[c02GY/L0TZ2m08fJ^P29V;L0QYFd08VG]029
UJl0G6Ak07j4VP2;UZ`0VjFn0:^gd@030;Bof`80/l7K202e`=`0202b`=X0
/KoI0;?1f`2ha^00^<?O0;G0g02c_]X0];oK0P2d`]lV0;?1gP030;;0g@2d
`]l0/l7N0080/l7N00/0//3M0;C2g`2jb>D0b];U0<oFiP3Ff^D0Si2E0?on
o`3mo?X0ookj0?gln0080?omo`80ooko0`3ooOh30?ono`070?ooo`3kno/0
oooo0?ooo`3hn?P0oooo0?Win@0[0?ooo`008@3oool03`3no_h0n_[j0?Cd
m03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh
0:nV`@0X0;:Yb080/ZW60P2bZLP05P2bZLH0^:o:0<Bld`3?am`0dloM07M_
Q01SFWL0PGFK08j1[02JR[T0Vh^h09f<^@2KS;D0W8bk0:6Ea@2]X/X0QWnA
08N3P02YXiD0]k:N0<Jo[@3BbkT20=C=^`040=G>_03DcK/0eLjl0=C=^b00
eLjl01P0em2m0=_Ea@3Vh]L0k>WP0=_Hd`1>BE00Jf5l07a_VP2=OZT0VHZe
09j>_@2LS;/0WHfl09b<^`2MS[T0Y9G00;6Vb030]]40b<3G07E/Q`1MDGT0
OVfQ08MbZ`2;LjdX08Qd[`0@08MdZ`27M:`0R7Ba08Qd/@26MJ`0S7^_09j?
^P2`XLP0RH6F05M[MP1GOXD0HhbB06jIX01cYZX0LZN]07VU[Q`0MZN^3P1g
Z:l807RY/0H0NJZa0P1jZK4607^Z/P@0O:^a1P1m[;8607j]/`@0PJjd1P22
[kD608>`]P@0QK2g2026/KP608Nb^@H0R;>j102;];X608be^`P0SKJl1P2>
]kd408nh_P@0T;Vo102A^;l809:i`0@0Tk[100`0T[Vn09>j_`2C^[l0Vl74
0:k=d02oe=L0b]SI08ZBU03hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3o
ool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;b
lP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0
WjoC0:6_eP2Q[/h80:2^d@80XJoB102P[]4209n]d00609b[c02JZLX0V:O8
09JUaP2DXl@0Tj;30P2BXL8209BSa00809JUaP2HYlP0VZW:09f/c@2N[Lh0
Wjk?0:2^d`2Q[m@40:2^d@0B09b[c02GY/L0TZ2m08fJ^P29V;L0QYFd08VG
]029UJl0G6Ak07j4VP2;UZ`0VjFn0:bhdP2d_m/0]L3L0;Bof`2c`M/0]<;L
202e`=`01@2c`m`0/l7K0;6of@2c`M`0//3K0080];oK00<0^LCP0;K1g@2f
`Md00P2e`=`20;Bofb80]L3L00<0];oK0;K1g@2f`Md00P2e`=`02@2c_]X0
]L3L0;c7h`37dn<0d][W0=CHh`2BTiP0oogo0?oko`020?onoa40o_kn00@0
oOgm0?clo03moOd0o?cl;@3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]
0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/40
:02bZLP20;:YaP80/ZW801H0/ZW60;R_bP34_=<0clOL0=??g@1gKh@0HeYg
085eV`2>PJ`0VXZi09^;^02MS;T0Vhbe09b<^`2PU<@0[:7908b5U`23Og`0
ZJ>E0;JaW@35_Z`0dLZh0P3DcK/0103Ec[`0e<fk0=G>_03DcK/P0=G>_00;
0=[C`03OfLT0j>CI0>_Xg`3;b<<0BTE<06aRO@22MJ00Sh2[09^<]`2OSkh0
0P2MSK`02`2LS;/0WXnj0:FF`@2aY/P0`;KA0<S0e`1eK8L0GE5i07i]X@27
LZ/0Rg>]02P0R7B_0100QgB[08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;2Q
b029PIH0Ef]f05MnQ@1SS980KYVP07>VZP1bYjd0NJF^701fYjh<07NX[`L0
N:V`201iZ[400`1jZk80NjZb07^Z/P0507^Z/P0307b[/`1lZk40O:^a0080
O:^a101m[;8707j]/`0307n^]021[[@0PJjd0080PJjd1022[kD708>`]P03
08Ba]`25/;L0QK2g0080QK2g2026/KP408Nb^@L0R;>j00<0RKBk08^d^P2;
];X00P2;];X408be^`L0SKJl202>]kd508nh_P@0T;Vo102A^;l809:i`0@0
Tk[100`0T[Vn09>j_`2C^[l0Vl740:k=d02oe=L0b]SI08ZBU03hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3o
ool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP08
08jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h80:2^d@80XJoB102P
[]4209n]d00609RWb02GY/L0U:?409:Q`P2?W[l0SYfn0P2=W;d02P2@Wl00
TJ3109>R``2EY<D0V:O809^Zb`2M[<d0WZg>0:2^d`2Q[m@40:2^d@0B09b[
c02GY/L0TZ2m08fJ^P29V;L0QYFd08VG]029UJl0G6Ak07j4VP2;UZ`0VjFn
0:bhdP2d_m/0]L3L0;Bof`2c`M/0]<;L202f`Md02@2__mP0]<CM0;G3g@2_
_MP0]<;M0;K1g@2f`Ml0]L3N0;S2g@020;O1g2D0]/3K00<0]KoJ0;O1g02g
`M`00P2g`M`02`2d_]T0]/3K0;c6h@39eND0f>3]0=?GhP2CTi/0oO_o0?ok
o`3ooOl0ooco00P0o_ok00<0oOon0?koo`3nool00`3nool01@3mooh0o?km
0?ooo`3oool0o?cl0080oooo00<0n_[j0?ooo`3lo?`0:P3oool00240oooo
00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085n
Q@23OY@0Thb[0::I^02_Y/40:02bZLP20;:YaP80/ZW801`0/ZW60;R_bP34
_=<0clOL0=??g@1gKh@0HeYg085eV`2>PJ`0VXZi09^;^02MS;T0WXjm09R8
]@2NSkP0ZI[30:ZL_`1[H740ZjBN0;JbV@33_:`0c<Bg0=?;_P3DcKd0e/no
0=C=^P3Bc;H0eLng603Ec[`04`3DcK/0dlbj0=?<^P3Ec[/0e<fj0=?<^@3C
cKL0eLni0=O@_P3Tg/h0jNOJ0?3_jP24PHP0FeI/071VR@20Lih0UHFb09V9
]P2LS;T00P2NS[/02`2LS;T0WHfj0:BD`@2bZ<X0`;OB0<[0f01gKHP0Ge1i
07e/X025LZX0R7F]02P0R7B_0100R7F/08Md[028M;40R7Ba08Ie[02<Njl0
WXnj0;6Rb@25OI80Ef]f05QoQP1SS980KIRO07:UZ@1bYjd0NJF^401fYjh4
07FV[@P0MZN^201gZ:l407RY/0@0NJR`201jZK4407^Z/P0307^Z/01lZk40
O:^a00H0O:^a1`1m[;84082]/`D0PJjd1`22[kD408B_]PD0QK2g2026/KP7
08Nb^@@0R[>i1@2;];X708be^`@0SKJl102>]kd408nf_@P0T;Nn202A^;l4
09:i`0P0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn
0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/2
0=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h80:2^d@0H
0:6ae@2O[m<0WjgB09n]dP2P[]40WZc?09bYc02IY/T0UZG4096P_`2@Wkh0
SIbk08VF]P2:UkL0S9Vi08VF]P2@Vk/0SYVi08nJ^P2CW[`0UZ6o09VT`P2K
Y/@0Wj[60P2NZ]00202N[<l0X:kA09n_d@2J[Lh0Uj[;09JYb@2CX<00Sibl
0P29V;L02P28U[<0S9Rb05eUO01oQI/0SIR^09bV_`2/^=80];oK0;K1g@2e
`=`20;?1fcT0]L3L00l0]/7M0;G0g02e`=`0]/;L0;C0fP2f`]`0_<SR0<[B
i@3BfNT0e=SQ09:CU`3no_h0ooom0?ooo`3mo_l0@P3oool00240oooo00l0
o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23
OY@0Thb[0::I^02_Y/40:02bZLP20;:YaP80/ZW801L0/ZW60;R_bP34_=<0
clOL0=??g@1gKh@0HeYg085eV`2>PJ`0VXZi09^;^02MS;T0VXZi09f=^P2M
S[T0ZI[30:^M`@1dJ7`0WYJD0;2[V032^jT0c<Fc0=C=_@020=C=^`030=G>
^`3Dc[P0e]2j01P0eLjl00<0e<fk0=?<^P3DcK/00P3Ec[/03P3Cc;T0e<fj
0=O@_@3RgLX0h=[:0>o]h@3ZjND0FUMP05YBJ@1jKY80R7^V09J6/`2JR[L0
W8bi0P2NS[/02`2LS;T0WHfj0:BD`@2bZ<X0`;OB0<[0f01gKHP0Ge1i07e/
X025LZX0R7F]02P0R7B_0100R7F/08Md[028M;40R7Ba08Ie[02<Njl0WXnj
0;6Rb@25OI80Ef]f05QoQP1SS980KIRO07:UZ@1bYjd0NJF^401fYjh407FV
[@P0MZN^201gZ:l407RY/0@0NJR`201jZK4407^Z/PH0O:^a201m[;8207j]
/`@0P:fc1021[[@608:_]@80Pk2f1024[kH408F`]`H0Q[6h2027/[T208Rc
^P@0R[>i102;];X608be^`H0SKJl102>]kd408nf_@P0T;Nn202A^;l409:i
`0P0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0
o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?oo
o`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[J
fP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h80:2^d@030:2`
e02O[m<0WjgB0080Wjg@01d0WJ_>09ZWbP2GY<H0TZ7008nN_@2:VKP0RiRh
08fJ^P2;V;P0RIJf08bG]`2?V[H0RiJb08:=Z@1dOi/0IG2<05iYQ@1TL8X0
KGVC07f7ZP2LZL/0YkCF09j[c@2O[/l0X;3A09VYbP2EYLH0T9jk08fJ^P02
08RG]P0:08FC/028U:h0FF5h07n5V`2=V:h0W:Jo0:bhdP2d_m/0]/7M0;G0
g080/l7K>@2e`=`03`2f`Md0]L3L0;G0g02f`]`0]<3J0;K2g02lb>80b];U
0=;Ij@3Df>40TY>G0?knoP3oood0oooo0?gno`120?ooo`008@3oool03`3n
o_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2][:X0PGj508=n
U02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2bZLP05`2bZLH0^:o:0<Bld`3?
am`0dloM07M_Q01SFWL0PGFK08j1[02JR[T0Vh^h09f<^@2IRKP0WXjk09f>
^@2SU;l0Zic308IiT`26OH80/jbR0;nhY@3:`k00d/^h0080e<fj00<0e/nl
0=O@_@3DcKX0603Ec[`30=C=^`0?0=G>_03Ec[/0e<fj0=K?_03Id[l0g]S8
0>KReP3]j^<0c/c=04i:F01/I7`0OG6E08enZ@2HR;D0W8bi0080WHfj00`0
WXjk09b<^@2NS[/0Y9C10;:XbP30]m80b/3H07M]R01OD7T0OFbP08EbZP28
MJdX08Qd[`0@08Qe[027M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2aX/T0QGfB
05M[MP1HOhH0HhbB06fHW`1bYJT0LZN]07VU[Q00MZN^0`1eYZd807JW[PP0
MjR_1@1hZK0307VX/0P0NZVa1@1kZ[8507b[/@P0OJbb0`1n[K<3082]/`D0
PJjd1@22[kD308>`]P<0Q:nf1@25/;L508Ja^0P0Qk:i0`28/kX308Zc^@D0
RkBj1@2<]K/608ff_0D0S[Nm0`2?][d8092g_PP0TKRo1@2B^L0809>j`@0<
09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0
o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?oo
o`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40
N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>202P[]40202P/=@0WjoC09n]
d02O[M00WZc?09^Yc02GY<H0U:730P2=W;/0202;V;P0R9Fe08NE/P28U[<0
RYFc08RC/@1fP9T0JWB=0P1OJH806P1VL8T0K7J?06afS`1ZM8d0HV^805YU
P@1^NID0TIbj0:6^cP2S/=80WZ_=09JSa@2CW[`0SYbi08RG]029V;D0QI>^
08FAZ`1FGWD0OXBJ08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L0P2c`M/i0;G0
g00?0;K1g@2e`=`0]L3L0;K2g02d`=X0]/;L0;c8hP3:d^D0d]WY0=CHh@2B
TiL0o_kn0?ooo@3oool0oOko0480oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd
0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0
[jK102P0/ZW80P2bZLH20;:Yb00L0;:YaP2h[lX0a;cC0<o7g03Ccmd0Mfn4
06=JM`21MI/0SX6/09Z:^@2KRkP0WHbi09^;^P2KRkP0WXnj09^<]`2XVL80
Vhf^07=XMP2_YZL0_KJS0<K0ZP3>b;80e<jh0=K@^P3Ec[/0e/nm0=?<_1P0
eLjl00<0eLjk0=C=^P3DcK/00P3Ec[`0303DcK/0em2n0=_D`P3Th=@0k>SM
0?GakP24PHP0EU9S07=ZQ`1mLIL0ThB_09Z:]`<0WHfj00`0WXjk09b<^@2N
S[/0YIG20;:XbP30]m80b/3H07M]R01OD7T0OFbP08EbZP28MJdX08Qd[`0@
08Qe[027M:`0R7Ba08Qd/@26MJ`0S7^_09j?^P2aX/T0QGfB05M[MP1HOhH0
HhbB06fHW`1bYJT0LZN]07VU[Q00MZN^0P1eYZd807JW[PP0MjR_1P1hZK02
07VX/0P0NZVa1P1kZ[8407b[/@P0OJbb101n[K<2082]/`H0PJjd1022[kD4
08>`]P80Q:nf1P25/;L408Ja^0P0Qk:i1028/kX208Zc^@H0RkBj102<]K/6
08ff_0H0S[Nm0P2?][d8092g_PP0TKRo1P2B^L0809>j`@0<09>j_`2B^Kh0
T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm
0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28
Uk@0V:W509n_d`2Q[mH0XJk>202P[]405`2P/=@0WjoA0:2^d@2O[M00W:[=
09RWb02DXL<0T9fo08ZI^02:UkL0RiRh08RF/`24TZl0RYFa08B?Z`1aOIL0
GVUm06E`Q01/Mh/0L7^A075lTP1dOiD0NhJL0080PXfS01D0QHnX06ihT`1P
JHH0O8FT09VTa02MZ<P0VZC7096L^02;VKH0QYBa08RF/`25Tjh0QHnX05AL
L@1nQIP0SIR^09bV_`2/^=80];oK0;K1g@2e`=`00P2c`M/i0;G0g00?0;K1
g@2e`=`0]L3L0;K2g02d`=X0]/;L0;c8hP3:d^D0d]WY0=CHh@2BTiL0o_kn
0?ooo@3oool0oOko0480oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3U
iND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0[jK102P0
/ZW80P2bZLH20;:Yb00L0;:YaP2h[lX0a;cC0<o7g03Ccmd0Mfn406=JM`21
MI/0SX6/09Z:^@2KRkP0WHbi09b<_@2JR[L0W8fh09^;^02PT;d0YiRo07U]
Q@2;PH`0^kBT0<Jo[@3;a;40dlfg0=K@^P3Cc;T0eLjl0=C<_aP0eLjl00<0
e/nl0=C=^P3DcKX00P3DcK/03@3Ec[h0fM;20=oHb03Xi=T0jNKO0>CRh`1<
BE@0HEab07=XRP28NJ80VHRe09b<^@2NS[/00P2MSKX0302NS[/0WHfj09j>
^`2UUL80/ZS:0<2gdP3:`=P0Mff805m@N@1mK:00QG:Z08Qe[BP0R7B_0100
R7F/08Md[028M;40R7Ba08Ie[02<Njl0WXnj0;6Rb@25OI80Ef]f05QoQP1S
S980KIRO07:UZ@1bYjd0NJF^5P1fYjh807NX[`P0N:V`0P1iZ[4607ZY/@P0
NjZb0P1lZk<407b[/@P0OJbb101n[K<6086^]0H0PZne1023/;H608F`]`H0
Q[6h2027/[T408Rc^PH0RkBj1P2<]K/408ff_0H0S[Nm0P2?^;h6092g_PP0
TKRo202B^L0:09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;
TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<
0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0
fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>202P
[]40;P2P/=80WjoA09n]d02M[<d0VZW:09FTa@2AW/00SIZj08^H^027U;@0
QYBa08bG]@2?V[H0QY:/071lU01LIWl0JGB806YeR@1`Nhl0NHBJ08F@YP2<
UZl0SIN`08^E[P2:UJ/0SIN`092J/`1lQZ40Ig2=07IoW02AV[T0U9fl08fI
/`29U;00OhfX082>Z@21SJL0PHbR05AKKP20QIP0SIR^09bV_`2/^=80];oK
0;K1g@2e`=`20;?1fcT0]L3L00l0]/7M0;G0g02e`=`0]/;L0;C0fP2f`]`0
_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?ooo`3mo_l0@P3oool00240
oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ
085nQ@23OY@0Thb[0::I^02_Y/40:02bZLP20;:YaP80/ZW801`0/ZW60;R_
bP34_=<0clOL0=??g@1gKh@0HeYg085eV`2>PJ`0VXZi09^;^02MS;T0Vh^l
09f=^P2HRK@0X92m09Z:^`2VU/<0TH>T06QLM02/Xi`0`k^`0<W2/P3?b;D0
eLni0=;;^03Ec[h0elo2603Ec[`04@3Fck`0e<fj0=C=^P3DcK/0e<fm0=O?
`P3Ne/T0iMg@0>SUgP3kn_H0UI:I051<G@1^IH80OG6E09:1[@2KR;H0W8bi
00<0WXjk00`0Whnl09j>^`2OSk`0YIG20;:XbP30]m80b/3H07M]R01OD7T0
OFbP08EbZP28MJdX08Qd[`0@08Qe[027M:`0R7Ba08Qd/@26MJ`0S7^_09j?
^P2aX/T0QGfB05M[MP1HOhH0HhbB06fHW`1bYJT0LZN]07VU[QD0MZN^201g
Z:l807RY/0<0NJZa1@1jZK4807^Z/P<0O:^c0`1lZk4807f//PD0OZfc1@21
[[@608:_]@D0Pk2f1@25/;L608Ja^0P0Qk:i1@28/kX508^d^PH0S;Fk1@2=
][`508jg_@<0SkRn1@2@]kh8096h_`P0T[W02`2C^/40302C^[l0T[Vn09:i
`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0
oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3h
n?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SY:A07QmT@1oR:T0R9Nd
09RYa@2O[m<0XJoF0:6^cPP0X:kA00L0X;3B09n_d@2O[/l0W:_<09RWb02B
XL80SY^k0080RiRh02D0RYNg08RC/@2;U[80R9B^071lU01PJh40Ig:806ah
SP1gPiT0Q92X08fI/`2CWkT0Uj:n09ZU`@2KY/@0VJFo09JR_02EXK/0VJFo
092J]@1cOIP0K7JA086;YP29Tjh0R9B^07j<Y`1lRZ@0O8RP07f8WP1AF6/0
P8FH08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L0080/l7K>@2e`=`03`2f`Md0
]L3L0;G0g02f`]`0]<3J0;K2g02lb>80b];U0=;Ij@3Df>40TY>G0?knoP3o
ood0oooo0?gno`120?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU
0=oOg`3Lg=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Y
b080/ZW60P2bZLP0702bZLH0^:o:0<Bld`3?am`0dloM07M_Q01SFWL0PGFK
08j1[02JR[T0Vh^h09f<^@2JR[/0WXjk09Z;]P2NS[d0VXVm09n?`02PTKX0
MfV:08QmP@2g[J/0aknd0<_4/P3CcKL0d/^h0=G>_03Gcl8H0=G>_00A0=G?
^@3DcKX0dlbi0=C=^`3Fckl0fm?60>CLd@3]iMX0m_?^0>GSi01BCeP0HEab
075XQ`27Nj<0UHB`09b9]`2LS;T00`2NS[/0302PT;d0Whnl0:2@_@2UUL80
/ZS:0<2gdP3:`=P0Mff805m@N@1mK:00QG:Z08Qe[BP0R7B_0100R7F/08Md
[028M;40R7Ba08Ie[02<Njl0WXnj0;6Rb@25OI80Ef]f05QoQP1SS980KIRO
07:UZ@1bYjd0NJF^501fYjh807NX[`P0N:V`101iZ[4407ZY/@P0NjZb101l
Zk<207b[/@P0OJbb1P1n[K<4086^]0H0PZne1P23/;H408F`]`H0Q[6h2027
/[T608Rc^P@0RkBj1P2<]K/608ff_0@0S[Nm102?^;h4092g_PP0TKRo202B
^L0<09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3o
ool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3J
f]X0202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>202P[]408P2O
[m40Wjo@09j]cP2KZ//0UZG6092O_P2=V[X0RYNg08^H^02;U[H0SIRf08VD
/01cOiL0H6^106E`Q01fPID0M8:L08:@ZP2CXK`0W:[709n/c02Q[]00Xk3B
0:>`d`2U]=<0XK3?0:6_c02JZ<D0UJ2l09BP^P1mQj00E5ig07=mUP1kQj42
07b8XP0:07Z6WP1lQ9T0CeIX0826UP2=V:h0W:Jo0:bhdP2d_m/0]/7M0;G0
g080/l7K>@2e`=`03`2f`Md0]L3L0;G0g02f`]`0]<3J0;K2g02lb>80b];U
0=;Ij@3Df>40TY>G0?knoP3oood0oooo0?gno`120?ooo`008@3oool03`3n
o_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2][:X0PGj508=n
U02CS:/0XYVh0:nV`@0X0;:Yb080/ZW60P2bZLP0702bZLH0^:o:0<Bld`3?
am`0dloM07M_Q01SFWL0PGFK08j1[02JR[T0Vh^h09f<^@2KRk`0WHfj09n@
^`2HR;L0WHc209Z9_@2QTKh0XI>g06EIH`2YWZ80`kZc0<S1/@3BbkP0dlbi
0=G>_03DcKdH0=G>_00A0=G?^@3DcKX0dlbi0=G>_03Gd<00g]K90>WQeP3c
jn00lO3[08Z8R@1EDUd0IV5h07]aT`2=PJT0VHRe09j;^@2LS;T00P2NS[/0
3@2OSk`0XI6n09n?_02PT;d0YYK30;:XbP30]m80b/3H07M]R01OD7T0OFbP
08EbZP28MJd0:028M:l04028MJ`0QgB/08Qd/@28M;40QWF/08ak[`2NSkX0
/J;908EmTP1GJgH0F7n606><TP1]V9l0LZFY07:W[@1iYJhD07JW[PP0MjR_
201hZK0407VZ/@@0NZVa201kZ[8407b[/`L0OJbb201n[K<00`1o[[@0PJjd
086^]002086^]0@0PZne1`23/;H00`24/KL0QK2g08F`]`0208F`]`@0Q[6h
1`27/[T808Rc^P0308Vd^`2;];X0RkBj0080RkBj102<]K/708ff_0D0S[Nm
102?^;h4092g_PP0TKRo202B^L0<09>j`@0<09>j_`2B^Kh0T[W009c1a`2_
c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo
0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80
jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W509n_
d`2Q[mH0XJk>202P[]40;P2O[m00WZk?09f/c@2JZLX0UJC308nN_@2<VKT0
RYNg08jI^@22SJd0SIRf08RD[P1XLX/0I6n507AoT`1`Nhd0QiNa09>R_`2P
[lh0YKCC0:Fde@2U/mH0Z;KK0:VggP2U]MT0YK?F0:>bd`2R/<d0X:k909fY
`@2<V:h0NXFK059LM@1VLXX0LWjH07R4WP1gPi/0NX:G04iEI`1oQID0SIR^
09bV_`2/^=80];oK0;K1g@2e`=`20;?1fcT0]L3L00l0]/7M0;G0g02e`=`0
]/;L0;C0fP2f`]`0_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?ooo`3m
o_l0@P3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL
0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/40:02bZLP0402bZL@0
/ZW60;:Yb02bZLP0/ZW60;R_bP34_=<0clOL0=C@gP1hL8D0HeYg085eV`2?
PZd0VXZi09^;^02MS;T409^;^P@0W8bk00/0PG>G06aPMP2j/[00c/Vc0<K3
Y03Dd;D0c/Rh0=O@bP3Ec[/0dlbi0=?<^P020=C=^`<0e<fm203Ec[`20=C=
_@80dlbl01H0dlbj0=C=^`3Cc;X0dlbj0=O>_@3FcK`0eLjk0=SC`03HeL@0
hMoB0>k^iP3^kNP0g=GM04LoCP1WGGH0MVZ>089cWP2EQ[40UhRa0::C^P2N
S[/0Whnl0P2NS[/0302OSk`0WXjk0:2@_@2VU/<0/ZS:0<2gdP3:`=P0MVb7
05m@N@1mK:00QW>[08Qe[BP0R7B_0100QgB/08Uf[P28M:l0QgB/08Mf[02<
Njl0WHfl0;:Rc`24O940EVYe05V0Q`1TSI<0KiZQ07>VZP1bYjd0Mj>/201f
Yjh407FV[@P0MZN^1`1gZ:l207RY/00307NX[`1fYjh0MZN^00`0NZVa101k
Z[800`1kZ[00O:^a07b[/@0507b[/@@0OJbb101n[K<00`20[K<0PJjd086^
]005086^]0@0PZne1023/;H408B_]PD0QK2g1`26/KP408Nb^0@0R;>i00<0
R[>i08^d^P2;];X01P2;];X708be^`@0SKJl102>]kd408nf_@D0T;Nn2`2A
^;l409:i`100Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^C
U@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0
o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3K
fm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_eP2Q[/h90:2^
d@0B09n]d02LZl`0UjK709>P`02=V[X0RYRe08RF/`24TK@0RiRh08fG/P1[
MX`0I6n5075lTP1/NY@0QYB_09NTa02O[<`0Y[?C0P2W]=@00`2X]MD0ZKKF
0:Ree@020:VfeP0D0:Rfd`2W]M80Y[CA0:6_c02FY;l0S9Ze07^3VP1TK8<0
De]`04iFJ@1FGFl0FF1`03Y1D@1nQY<0SIR^09bV_`2/^=80];oK0;K1g@2e
`=`20;?1f``0]L3L00L0];oK0;G0g02f`Md0]/7M0;6keP2man80^L?N0080
]/3K01P0/[cG0;FofP2e_mX0]KkK0;BmfP2g`=d0/kcI0;S1gP2a^]L0_LKS
0;BmfP2g`MX0]KoH0;O1g02f`=/0^/CO0;>lf@2f_m`0];gJ0;G4f`2__]D0
]lGO0;2nf02e`M/20;S4gP030;Bof`2e`=`0]L3L00L0]L3L00l0]/7M0;G0
g02e`=`0]/;L0;C0fP2f`]`0_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom
0?ooo`3mo_l0@P3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3O
gml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/40:02bZLP0
402bZL@0/ZW60;:Yb02bZLP0/ZW60;R_bP34_=<0clOL0=C@gP1hL8D0HeYg
085eV`2?PZd0VXZi09^;^02MS;T409^;^P@0W8bk00h0Vhbg079UP@1jL7T0
`[^a0<k9/`3Fd[T0eM2l0<o9^@3BbkP0e<fj0=G>^`3DcKX0dlbj0=C=^`80
eLjl203DcK/50=G>_0<0eLjk0180f<nn0=;;^@3Fckd0eM2m0>OTe@3WiMT0
l?3X0?Cck`1ZHVl0CTEH07=XQP1nLYP0T86/09^;^02PTK`0VX^d09j>^`2O
Sk`209j>^`0<0:2@_@2NS[/0X92m0:JF``2bZ<X0`KSC0<[0f01fK8L0Ge1i
07e/X026Lj/0R7F]:028M:l04027M:`0RGJ^08Qd[`27M:`0QgJ/08el/02N
S[d0/Z;?08EmTP1GJgH0FH2706><TP1^VJ00LZFY07:W[@1hY:d807JW[P@0
MJJ]201fYjh707NX[`@0N:V`00<0MjR_07VX/01iZ;001P1iZ;0407ZY/@@0
NjZb1P1lZk4607f//P@0OZfc1P21[[@608:_]@@0Pk2f1024[kH408F`]`H0
Q[6h0P27/[T408Nb^0@0R;>i1P2;];X808be^`H0SKJl102>]kd408nf_@@0
T;Nn1P2A^;l209:i`0@0TKRo102B^L0@09>j`@0<09>j_`2B^Kh0T[W009c1
a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0
oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03b
l_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W5
09n_d`2Q[mH0XJk>2@2P[]404@2O[M00W:_<09NVa`2CX<00SIZj08ZH]@28
U[<0RIJi08ZG]`25SjX0HFb206MbR01`NY<0NHNQ08nM^P2MZ/X0XZo?00<0
YkCD00<0Z;GE0:VfeP2Y]]H00P2Y]]H0502Y]m@0Z;KC0:Rfd`2T//l0VjW4
09:P^`29Tj`0O8BK071hS`1WKh@0I6ao061WN@0l@e<0O8BA08fH[P2LY[l0
[;SB0;Bof`2f`Md0]L3L0P2c`M/<0;G0g080];oK0P2e`=`01@2ha=h0]L7K
0;:nf02c_mT0]/;L0080^<CN01T0]L7K0;O3f`2ha=`0]l?K0;S4g02e`MT0
/[kF0;O3f`2c_mL0]/;L0;C0fP2kan40/KgG0;>nfP2ia>00]L3L0;K1g@2d
`]d0[kgH0;C2g@2g`md0]/;L0;>of@2e`M/0]/;L00T0]L3L00l0]/7M0;G0
g02e`=`0]/;L0;C0fP2f`]`0_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom
0?ooo`3mo_l0@P3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3O
gml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/40:02bZLP0
402bZL@0/ZW60;:Yb02bZLP0/ZW60;R_bP34_=<0clOL0=C@gP1hL8D0HeYg
085eV`2?PZd0VXZi09^;^02MS;T409^;^P@0W8bk0100XI7209N8[`1dJ800
Rh690<k7_`37`Zl0dlnf0=WE^P3Cc;T0eLjk0=C=^P3Cc;T0eLjk0=K?_03D
cKX0d<Vf0P3Cc;X40=C=^`80eLjl203DcKX04@3BbkT0f=6o0=cGa03Qg/d0
j>CH0>k[i03gm_80THn@0599GP1]Hg`0O76C08=gW`2IRKH0VHVh09n?_02P
TK`0WXjk00<0Whnl00`0X92m09n?_02PT;d0YYK30;>Yb`31^=<0b/3H07I/
Q`1OD7T0OFbP08IcZ`28MJdX08Qd[`0@08Qe[@29MZh0R7B_08Md[028Mjd0
SWfa09j>_@2cXm00QWjC05Q/M`1IP8L0HhbB06fHW`1bYJT0LZN]07VU[PP0
MZN^0`1eYZd807JW[PL0MjR_0`1hZK00101iZ[40N:V`07RY/01hYjl407VX
/0H0NZVa1@1kZ[8507b[/@H0OJbb1@1n[K<5086^]0H0PZne1@23/;H308B_
]PD0QK2g1@26/KP308Nb^@<0Qk:h1@28/kT508^d^PP0S;Fk1P2=][`508jg
_@<0SkJm1@2@]kh5096h_`<0T[W00`2A^;l509:i`100Tk[100`0TkZo09:i
_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3m
oOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY
08RG]02HZLD0WjoC0:6_eP2Q[/h90:2^d@0B09n]d02LZl`0UjK709>P`02=
V[X0RYRe08RF/`2;V;X0R9Jc07R2W@1LIgd0KWV?07=mUP2:V;<0VJO40:Ba
d@2V/m<0Z;GE0P2W]=@00`2X]MD0ZKKF0:VfeP020:VfeP0D0:Vge02Z^=D0
Z[SE0:Vge02Q[lX0VZS308jH/@26T:T0Ph^R07V1UP1eOI00L7V:04Q?G`20
QiL0SIR^09bV_`2/^=80];oK0;K1g@2e`=`20;?1f`d0]L3L01/0];oK0;>n
fP2c_]X0[kgH0:jle`2e`mh0]lGP0;2nf@2]^mH0[[cG0;2nf@2__]<0//7F
0:fld@2b`MH0[[gB0;C3f02c`]L0[[gB0;;0fP2__ML0/KoI0;2nf02^_=L0
/KoJ0:fkeP2`_]T00`2c_]`01@2f`Md0/[gI0;:nf02e`M/0]l?M00T0]L3L
00l0]/7M0;G0g02e`=`0]/;L0;C0fP2f`]`0_<SR0<[Bi@3BfNT0e=SQ09:C
U`3no_h0ooom0?ooo`3mo_l0@P3oool00240oooo00l0o_kn0?[jnP3dm?@0
kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_
Y/40:02bZLP0402cZ/D0/ZW60;:Yb02bZLP0/j[70;R_bP34_=<0clOL0=C@
gP1hL8D0HeYg085eV`2?PZd0VXZi09^;^02MS;T409^;^P@0W8bk00P0VXVo
09R8]`2BPjX0LFAn08UoR03Ec/H0eM2j0=7>[`80fM:o00H0eLjk0=?<^@3D
cKX0e<fj0=K@^P3Idkd20=C=^`@0eLjl0P3Fckd06P3BcKL0dljh0=?>^03C
c[P0dljj0=;=^@3Cc[X0e<nk0=G?_`3GdL40h]o@0>OSe`3bknP0n?Cc0;Nb
^01GE5/0JEmj07I[R`20M9X0Sh:]09f=_02LS;/0VHVh0::B`@2OSk`0X92m
0P2OSk`0302PT;d0Whnl0:2@_@2VU/<0/jW;0<6hd`3:`=P0Mff805m@N@1m
K:00QG:Z08Qe[BP0R7B_0100R7F]08Uf[P28M:l0R7F]08Qg[@2>OK40WXjm
0;6QcP25OI80F6ag05V0Q`1TSI<0KIRO07:UZ@1cZ:h0NZJ_201fYjh207FV
[@P0MZN^201gZ:l607RY/0@0NZVa101kZ[8207ZY/@H0NjZb101lZk4607f/
/PH0OZfc1021[[@608:_]@H0Pk2f0P24[kH608F`]`@0Q[6h1027/[T208Nb
^0H0R;>i102;];X808be^`H0SKJl1P2>]kd208nf_@H0T;Nn102A^;l409:i
`080TKRo1P2B^L0@09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WG
fP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?oo
o`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3M
gMd0fm_K0P3Jf]X0202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>
2@2P[]40402O[M00W:_<09NVa`2CX<00SIZj08ZH]@28U[<0RIJf08RF/`1Z
M8l0HFb207F0UP1mQj00U::m09j[b`2W]=@40:Ree@80ZKKF00<0Z;GE0:Vf
eP2Z]mL00P2Z^=D04P2/^]L0ZkWF0:Jdc`2P[/T0VJ>n092J/`29Tj`0PXZQ
08>;X021RI`0D5UZ07f4UP2=V:h0W:Jo0:bhdP2d_m/0]/7M0;G0g080/l7K
3@2e`=`0202d_m/0/[gI0;2ke`2__ML0ZkWC0:Rfd02Z^=80[K_E0P2^_=H0
4P2[^M<0Z[SB0:Rfd02X]]00[K_E0:bje02[^M<0[;[D0:jleP2X]]40/;kH
0:ZhdP2/^]@0ZKOA0:ZhdP2[^M<0YKC;0:F^c@80[kSG00D0];oK0;:mf@2e
`M/0]/;L0;6me`090;G0g00?0;K1g@2e`=`0]L3L0;K2g02d`=X0]/;L0;c8
hP3:d^D0d]WY0=CHh@2BTiL0o_kn0?ooo@3oool0oOko0480oooo000Q0?oo
o`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21
OXD0PgjD09><Z`2RVKP0[jK102P0/ZW80100/j[50;:YaP2bZLP0/ZW80;>Z
a`2h[lX0a;cC0=38g@3Dd=h0N72506=JM`21MI/0Sh:]09Z:^@2KRkP0WHbi
102LS;/409^;^P0@09^:_P2OS/80U8Be08ioZ01aI7h0R7n40<S2]P3Je[d0
eLjn0=SA`@3HdKl0em2n0=O@_@3BbkP0d<Vf0=K@^P@0e<fk103Ec[`00`3C
c[P0e<ni0=G@^P020=C?^`0E0=G@_@3FdKh0f=?00=_Hb@3Xi=P0j>CI0?;_
j03elO00eM3G04]5D`1KE6H0KF6507]_U@2=PJT0VHbh09^;^P2QTL00WXjm
0:2@_`2OSk`0X92m0080Whnl00`0XI6n09n?_02QTKh0YiO40;>Yb`32^M@0
bl7I07M]R01OD7T0OFbP08EbZP28MJdX08Qd[`0@08Qe[@29MZh0R7B_08Qe
[@28Mjd0SGb`09b<^`2^W//0Pg^@05IZM@1JPHP0IHjD06nJX@1cYZX0LjR^
07ZV[`h0MZN^201gZ:l507RY/0D0MjR_1P1jZK4807^Z/P80O:^c101lZk44
07f//PH0OZfc0P1o[[@4086^]0@0PZne1P23/;H208Ba]`H0QK2g1P26/KP4
08Nb^@H0R;>i0P29];X408^d^PP0S;Fk102=][`608jg_@80SkRn1P2@]kh6
096h_`X0T[W04P2C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0
Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0
303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM
0=_Kf`80f][J00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPT0
X:kA00l0Wjg@09b[c02GY/L0Tj3008fJ^P2:V;D0R9Jc08ND]02:V;<0G6Io
06]fS01hPiT0R9:]09RV``2Q[/h00`2W]=@00`2X]MD0ZKKF0:VfeP020:Re
e@040:Zge`2[^=P0ZkWF0:Zhe@80[;[G0100Z;KA0::`b`2Q[LL0VJ>n09>M
]P2;UZ`0SYV]096I[01KHgH0OHJG08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L
0P2c`M/=0;G0g0050;>nfP2`^mL0[KSD0:B`b02[]ll00P2S[lL01P2W/l/0
Y;380:Fab@2R[/H0X:_709bW``80Y:o;01@0Z;??09jYa@2Q[<P0Y[7=0:Nc
c@2T/<X0X:c40:B`b02Q[L<0W:Rn09^W_@2NZkh0YJc80:V`c02W/L`0[;KA
0;2leP2e`=`0]l;N0;?1g0T0]L3L00l0]/7M0;G0g02e`=`0]/;L0;C0fP2f
`]`0_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?ooo`3mo_l0@P3oool0
0240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0
[JbZ085nQ@23OY@0Thb[0::I^02_Y/40:02bZLP0402cZ/D0/j[70;:Yb02b
ZLP0/j[70;V`b`35_M@0d<SM0=C@gP1hL8D0HeYg085eV`2?PZd0VXZi09^;
^02MS;T409b<^`@0Vh^j0100VHVh09J6]`2OS/80UhNf0962Z@1XG780P7In
0<_3`03Gcl@0fM740=K>`@3Fckl0g=G50=cE``3Fck`0e<fj203DcK/00`3A
c;H0d/fg0=C?^`020=C?_00E0=OA`@3Je<@0gMO90>CQf03Wi=/0l>gX0?[f
m@3Ac=<0BT=C05]CJP1/Hh00NfnG0965[@2FRK@0VXfh09^;^02NS[/0Y9C3
09n?_P2OSk`0XI6n0080X92m00`0XI6n0:2@_@2QTKh0YiO40;BZc032^M@0
bl7I07M]R01OD7T0OVfQ08EbZP28MJdX08Qd[`0@08Qe[@2:Mjl0R7B_08Qe
[@28Mjd0S7^_09V9^02YVLH0PWZ?05M[MP1JPHP0IXnE06nJX@1cYZX0LjR^
07ZV[`d0MZN^201gZ:l607RY/0<0MjR_0P1hZK0507ZY/@<0NJR`1@1kZ[83
07b[/`<0O:^a1@1m[;8507j]/`<0Ojjd0`21[[@508:_]@D0Pk2f0`24/KL5
08F`]`H0Q[6h1@27/[T508Rc^@<0RKBj0`2;];X808be^`D0SKJl1@2>]kd3
08nh_PD0T;Nn1P2A^;l:09:i`1<0Tk[100`0TkZo09:i_P2B^L00W<770:o>
d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3Y
jNT0hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC
0:6_eP2Q[/h90:2^d@0609n]d02LZl`0UjK709>P`02=V[X0RYRe0P28U[<0
3`2;VK@0EV1i079mT`1kQY`0SYRc09ZXa@2U/]@0YkCD0:Jcd`2W]=@0ZKKF
0:Zge`2Y]]H0Z;GE0:VfeP020:^hf0<0ZkWF0140[;[G0:Rfd@2S/L`0WZW5
09ZU`@2KYL00UInh09NR^02HXkL0I6ao08>;WP2=V:h0W:Jo0:bhdP2d_m/0
]/7M0;G0g0020;?1f`d0]L3L00D0/kkJ0:jie@2[]]80X:_109jY_`0209RS
^@0B09fX_P2LYkd0V:>i09BO]@2CWKP0UInj09RR_@2DW[T0VZBo09nYa02L
Y/40VJ>n09bW_@2GX[P0WJRn08nJ[P2AW:h0UJ2b0P2AWJd0202HWk80V9jd
0:>[`P2V/<T0];kI0;>nfP2b`=/0]L?P2@2e`=`03`2f`Md0]L3L0;G0g02f
`]`0]<3J0;K2g02lb>80b];U0=;Ij@3Df>40TY>G0?knoP3oood0oooo0?gn
o`120?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb00@0;>Za@2c
Z/L0/j[90;>Zb@2cZ/L0^K3;0<Fme03@b=d0e=3N07Q`Q@1SFWL0PGFK08n2
[@2JR[T0Vh^h09f<^@@0W8bk102KRkX0402KS;D0XI:m09N7^02NSL40V8Rg
08j0Y01/GgT0J5a`0<>j/`3HclH0gmK=0=S@a@3Hd<<0f]?30=G>_P3BbkT4
0=K?_@<0eLjl01/0e<fk0=3>^@3Bd;/0e=6n0=GB`@3Ge<D0fmO;0>7Md@3V
h]L0knkY0>g/j03elo@0]k:h04U3D@1GCfL0KfF707idV@2:OJP0UHRc09J9
]02JS[H0XiBo09f>^@2NS[/0WHfj0:2@_@2QTKh00P2PT;d0302QTKh0X92m
0::B_`2XV<D0]:[<0<>je@3;`MT0Mff805m@N@1nKJ40QG:Z08Qe[BP0R7B_
0100RGJ^08Yg[`29MK00R7F]08Qg[@2:NJd0UHFd0:FE`P24O940F6ag05^2
R@1VSiD0KYVP07:UZ@1bYjd0NZJ_301fYjh807NX[`P0N:V`0P1iZ[400`1j
Zk80Njbc07b[/`0307b[/`<0NjZb00<0NZVa07^Z/P1kZ[800P1kZ[8407b[
/`80O:^a1P1m[;8407j]/`@0Ojjd0P21[[@608:_]@@0Pk2f1024/KL408F`
]`H0Q[6h1P27/[T408Rc^@@0RKBj0P2;];X808be^`H0SKJl102>]kd408nh
_P@0T;Nn1P2A^;l:09:i`1@0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2n
dmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo
0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0
hN7Q0=gMg@3Kfm/20=[JfP0808jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_
eP2Q[/h90:2^d@0609n]d02LZl`0UjK709>P`02=V[X0RYRe0P28U[<02P29
Uk40Ef5j079mT`20Rj40SYRc09fZbP2W]=L0Z;GE0:Nde02X]MD20:Zge`80
ZKKF0P2[^=P00`2/^MT0[;[G0:^ieP020:bje`0@0:VgdP2T//d0Wj[809^V
`P2LZ<80Uj6j09RS^@2GX[H0H6]o07n7VP2=V:h0W:Jo0:bhdP2d_m/0]/7M
0;G0g080/l7K2`2e`=`09@2f`Md0]L3L0;:mf@2]^=@0ZKC@0:B[_P2?UZT0
VJ2c09NN/@2@UjX0UIb_08fDY`2@UjX0SIBV08^BY027SZ00Uij`08V@XP2>
UJL0S9>U0:^ba02@UZ`0SYFX08nFZ@27SZ00SiJV0869UP2<U:40QHfH08V?
V`2?Uj@0Z:no09jV^@2^^=40/kkJ0;6og02a_]h02@2e`=`03`2f`Md0]L3L
0;G0g02f`]`0]<3J0;K2g02lb>80b];U0=;Ij@3Df>40TY>G0?knoP3oood0
oooo0?gno`120?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oO
g`3Lg=`0fm_M0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:nV`@0X0;:Yb00@
0;>Za@2cZ/L0/j[90;>Zb@2cZ/L0^K3;0<Fme03@b=d0e=3N07Q`Q@1SFWL0
PGFK08n2[@2JR[T0Vh^h09f<^@@0W8bk102KRkX0402LS[40UhR_09j>_@2H
Qk/0VHRl09Z:]`2?P:L0M6J905A;AP2LThh0f<o80>;Id03Ne//0g=C70=cE
a@3NelL20=[C`@80fM;00P3HdKl20=O@_P0J0=GB_`3Ge<40f]O60=cIbP3P
g=00iN7F0>gYgP3bk^D0lo;`0>g/jP1oOH00CdaE061IJ`1^IH80NFnD08Qm
Y`2GR[H0UHRc09nC^`2JS[H0XiBm0:2A^P2LSKP0Y9C10:2@_@2QTKh20:2@
_@0<0:6A_P2PT;d0XY:o0:RHa@2dZ/`0`k[E0<_1f@1gKHP0Ge1i07i]X@25
LZX0R7F]:028M:l04028MJd0RWN_08Ue/028MJd0QgJ/08Uh[02CPk80XY:o
08InT`1JKWT0G8>:06F>U01]V9l0LJBX07:W[@1jYZl<07JW[PP0MjR_1`1h
ZK001@1iZ[40NZ^b07^//`1m[[D0OZnf0080P:ng0P1o[[H207j]]@80OJbd
101kZ[8407b[/`L0OJbb1@1n[K<407n^]0L0PZne1@23/;H408Ba]`@0QK2g
1026/KP708Nb^@0308Rc^P28/kT0R;>i0080R;>i1029];X708be^`P0SKJl
1@2>]kd408nh_P@0T;Nn102A^;l709:i`00309>j`@2B^L00T[W00080T[W0
502C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo
0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J
00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPT0X:kA0100Wjg@
09b[c02GY/L0Tj3008fJ^P2:V;D0R9Jc08RF/@25Tjd0FfIl079mT`27TZP0
SINb09j[b`2W]=L0Z[OG0P2Y]]H20:Zge`050:Ree@2Y]]H0[;WI0:^hf02/
^MT00`2/^]L04@2]^mP0Z[SC0:FccP2Q[<X0VZG109VT`02CWkT0Uj6j09RS
^@1PJgl0O8NK08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L0080/l7K2`2e`=`0
4P2f`Md0]L3L0;:mf@2/]m<0Z;??09nT]`2`]LP0nOko0>W^o`2NXkH0PhRK
08bAY02i_]40n?oo0>;Yl@3BfN40mOco0;6h`080RI2H00P0i^ge0;Bic@28
SJ00QX^N0=[Pl03goOl0YZbh0=7HhP80nOoo00L0n?oo0?Clo`2b^l`0[;O=
0;>nfP2e`^80/KkP00T0]L3L00l0]/7M0;G0g02e`=`0]/;L0;C0fP2f`]`0
_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?ooo`3mo_l0@P3oool00240
oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ
085nQ@23OY@0Thb[0::I^02_Y/40902bZLP40;>Zb@0@0;>Za@2bZLH0/j[9
0;>Zb@2dZlP0^K3;0<Bld`3?am`0eM7O07UaQP1TFgP0PGFK08j1[02JR[T0
Vh^h09f<^@P0W8bk0P2JR[T03`2KRkX0W8bk09^;^P2IRKP0UhNf09J6]@23
Mid0HUMg05iEIP2VX:80fMG:0>7Nc@3KfL@0gmg80>7Kb`020=gGa`80h=[<
0P3KeLL04@3OfL/0gmg@0=oMd03ShMD0inGI0>WVg@3^jn@0m?7Z0?KckP3B
bm<0H5QU0517G01^I7l0LFF907eaV@2:OJP0U8Nc0080WXjk0P2OSk`01P2P
T;d0XI6n0:6A_P2QTKh0X92m0:6A_P80X96l00/0XY>n0:6B_@2SU;d0ZI[3
0;F[c@34^mH0cL?K07M]R01OD7T0OVfQ08Md[00A08Qe[@P0R7B_3028MJd4
08Uf[P0408Yg[`28MJd0RGJ^08]h/080RGJ]00/0TGje09^8_`2ESkd0Eeij
06AmQ01ZTY40IYRI07FW/01bXZh0MjJ`07FV[@0707JW[P@0MjR_101fYjh0
701gY[00N:Rb07FW/01i[[@0N:fc07>U[01hZJh0NjZ`07RX]01m[;@0Pjjd
08Va/`2?]kT0TKVk09Bk`P2H`<P0V[_009joa02K_/@0TkZo092i_`2@^l40
S;Vo08:a]`28Z[@0QZbe08>^]@1l[K8207R[[`0;07Z[/01kZ[00O:nc07b]
/P1m[[<0NZ^`07j_]021/;H0O:^a08:a]`20[K<01`21[[@408:_]@@0Pk2f
00<0Q:nf08F`]`25/;L01@25/;L408Ja^0@0Qk:i1027/[P408Rc^@0308Zc
^@2;];X0RkBj00D0RkBj102<]K/808ff_0@0S[Nm00<0SkJm092g_P2@]kh0
1P2@]kh;096h_`@0T[W0602C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kC
f039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0
503oool20?knoP060?gmo@3hn?P0l_;b0>WYj@3QhN40g=cL0`3Jf]X0202>
TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>202P[]4209n^c`0?09f/
c@2HYlP0U:7308jK_@2:UkT0R9Fg08^I]P2<Uk<0FFAj07F0U022SJ40TYjf
0:2`bP2T]M40ZKKF00<0Z[OG0`2[^=P01@2/^MT0[[WG0:njf02_^]P0[[WG
0080[k[F0100ZkKB0:Jac@2P[<80WJW109ZT_`2GXK`0VJ>l09NR^01TK7l0
OhRI08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L0P2c`M/80;G0g0030;K1g@2e
`=`0]L3L0080]/7M02<0];oK0;2ke`2/]m<0XJc209:M[`2obMD0n?oo0=kS
j@26RI00PH6=0?3^o03jo_d0^[cA0:nba@3koo/0alg90863W024QYl0nOoo
0>_[l`2:RI/0R8VK0=OLhP3kool0XZB`0;Zj`P3noo/0kO?c0=oVl03Ni_/0
^<;K0:fic`2__]<0^/KN0;Bof`090;G0g00?0;K1g@2e`=`0]L3L0;K2g02d
`=X0]/;L0;c8hP3:d^D0d]WY0=CHh@2BTiL0o_kn0?ooo@3oool0oOko0480
oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0
fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0[jK102H0/ZW80P2cZ/T0402dZlH0
/j[70;B[bP2dZlX0]Jc90;Zac036_]D0d<SM0=GAg`1hL8D0HeYg085eV`2>
PJ`0VHVh09^;^02LRkP809b<^`0X09Z:^@2KRkX0W8bk09b<^`2KRkX0VXZi
09R8]`2GQkH0THB`09J:/01iKX`0EdiQ06IOI`2_ZJT0f]GA0>7LeP3Pf/h0
i^3D0>OQe@3Rg<h0hmg?0>[TeP3/i]P0j>;B0>?Qe@3XiM`0l>gV0>k[iP3a
kNX0nOGd0=3<c@26PHD0DTYI05=:G@1`IWl0Mfb<07U]T`2@Q:`0UhZe09R;
]P<0WXjk0P2OSk`20:2@_@0@0:6A_P2PT;d0XI6n0:2A_02QT[d0XY>n0:6B
_@2SU;d0ZI[30;F[c@34^mH0cL?K07M]R01OD7T0OVfQ08Md[140R7F]2028
M:l:08Qe[@H0RGJ^00@0RWN_08Qe[@29MZh0RWN_0P29MZd02P2?O;<0V8Fl
09Z>_P1RHh80HgV40628R01XVY/0K:6W07FU[`1fYJl607JW[PP0MjR_0P1f
Yjh0:01iZK<0N:Rb07JX[`1cZ:h0M:N[07RY[P1n[K<0OJZ`08Rc^P2>]kd0
U[bo09k0`P2Wa/P0/<oB0;?Be`2_cMD0/<c=0:o;c02]bld0Z/W;0:G8bP2O
aLH0Vl?509S0`P2I`<D0SkRl08Jc]P24]KT0PkBh07j^/P1nZk40PZfd07^/
/@1m[[<0PK:g07f^/`1m[;80Ojjd07^Z/01o[[@6086^]0H0PZne1023/;H6
08F`]`H0Q[6h1027/[T408Nb^0@0R;>i1P2;];X608be^`P0SKJl102>]kd6
092g_PP0TKRo0P2B^L04096h_`@0T[W0602C^/40302C^[l0T[Vn09:i`02L
`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool0503oool20?knoP060?gmo@3hn?P0l_;b0>WYj@3QhN40g=cL
0P3Jf]X02@3Kfm/0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cP09
0:2^d@0?09n]d02LZl`0UjK709:O`@2<VK/0RIJh08RE]`29Uk@0RYFa05MQ
NP1dOiD0PXfS096M]@2P[l`0Y[GD00@0Z[OG0P2[^=P20:bif@040:jie`2_
^]P0[k[H0:njf080[k[F0100ZkKB0:Jac@2Q[L<0WJW109ZT_`2GXK`0VJ>l
09NR^01TK7l0OhRI08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L0P2c`M/80;G0
g00X0;K1g@2e`=`0]L3L0;G0g02f`Md0];oK0;6lf02^^MD0Xjk409fX_02C
W:/0e=[V0?Wmo`2k_/D0ZJVa0?ono`3`nOP0QHZN08j@Y@3ho_X0k?;`0822
U`2NWk@0n_km0?_lo`2c//80MgV80=gPi@3jo_l0Wj6]0;Fe_`3koOX0c]?F
09jT/02U[L@0Z[C?0;G1f@2`_m@0/koI0;G0gPT0]L3L00l0]/7M0;G0g02e
`=`0]/;L0;C0fP2f`]`0_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?oo
o`3mo_l0@P3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0
g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/408@2aZ<L60;:Y
b0030;>Zb@2cZ/D0/j[70080]:_:00`0]:_80;Zac035_M@0d<SM0=GAg`1h
L8D0HeYg081dVP2>PJ`0VHVh09Z:]`2LRkP809b<^`80Vh^j0`2LS;/0902K
RkX0VXZi09Z:^@2HRkT0Rgj/0923[P2?PjT0KfB405I<I01PEfP0T8RE0<>o
_03IeM80j^OR0>[Wh03Yi]d0k>[N0>cZg@3WiMP0lno/0>_Wi03]jNX0in;V
0;Ja^01/IW80BdEC05I?G`1XGWL0LVN507icU@25NIl0T8B/09R;]P2GR[D0
WY:j09j>^`@0Whnl102PT;d03`2RT[l0XI:m0:6B_@2RTkh0XI:m0:>D_@2Y
V/<0]J_=0<BkeP3=`m/0Mff805m@N@1nKJ40QgB/08Qe[@0808Md[0P0R7F]
2029MK0808Qe[@H0RGJ^0`2:Mjl208Qe[@0=08Yg[`2:Mjh0RGJ]08ej/@2C
P;L0W8Fi07ifW@1CHWD0IXV?06FEV@1/WZD0L::[07NV[P0507JW[P/0MjR_
00h0MZRa07>U[01hZ[40NJb`07NX[@1jZZh0Pjjd08be^@2K_/80Y/S:0;??
dP2oemT0b=_O0<SIh080aMKN01P0b=[J0<?Ee`30e=D0_mCE0;WAd`2abl`0
[LW:0;3<c@2Qb<L0X<S809_5a02@_[h0R[Nj08Nd^@26/KL0QJjd07j]/`1j
ZJl0NjZ`07VX[P1kZ[00P:ne07n^]01n[K<5086^]0H0PZne1@23/;H508F`
]`H0Q[6h1@27/[T308Nb^0D0R;>i1@2;];X608be^`P0SKJl1@2>]kd5092g
_PP0TKRo0`2B^L03096h_`D0T[W0602C^/40302C^[l0T[Vn09:i`02L`LL0
[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool0503oool20?knoP060?gmo@3hn?P0l_;b0>WYj@3QhN40g=cL0`3K
fm/0202>TY40N7fA07n8Z@28Uk@0V:W509n_d`2Q[mH0XJk>202P[]40402Q
[m80Wjg@09b[c02FYLH0TIk008fJ_02:UkL0RIJf08^F]P29U;00Ef5l07F0
UP23SJH0TYjh0:6^cP2X]mP30:Zge`<0ZkSH0P2/^MT0102^^ML0[k[H0:nj
f02_^]P20:njeP0@0:^fdP2V/Ld0XJg309fY`@2KYL00Uj6l09ZT_@2GX[P0
I6ao07n8V@2=V:h0W:Jo0:bhdP2d_m/0]/7M0;G0g080/l7K202e`=`0:02f
`Md0]L3L0;G0g02e`=`0]/7M0;G0g02b_MT0/;_G0:Rcb@2V/LL0UYjc096H
ZP3Tj?@0m?On0>CUi`3jo?T0bMCF0867W@26S:80eMgO0?coo`2KVZX0_Kc<
0?_kn@3bm_L0kNok08:4T03Ohn@0o?oo0:2R[P2SYK40o?oo0>3Uj@2MXk40
YJc60;6je`2g`md0/l;I0;>nfP2f`N490;G0g00?0;K1g@2e`=`0]L3L0;K2
g02d`=X0]/;L0;c8hP3:d^D0d]WY0=CHh@2BTiL0o_kn0?ooo@3oool0oOko
0480oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03K
fmd0fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0[jK102@0/ZW8102cZ/T0402c
Z/D0/ZW60;>Zb@2cZ/T0]:_80;V`b`34_=<0clOL0=GAg`1hL8D0HeYg085e
V`2>PJ`0VHVh09^;^02LRkP@09b<^`0P09R;]`2KS[`0VXbm08n1/P2<Ojd0
SX:X07Q]S@1SFG80C4EE059;F`1RG6P0NWAn096<TP2QW:00ZJFV0:fYZ02E
T9L0Pgj505UCG`12>d/0D4QM061HL01WGWT0LVV607a`U022MY`0R7bT09B7
/P2KS[X0Vhji09^?]`2ISKD80:2@_@0?0:6A_P2RT[l0XI:m0:6B_@2SU;l0
XY>n0:>D_@2YV/<0]J_=0<BkeP3=`m/0Mff805m@N@1nKJ40QgB/0140R7F]
2029MK0808Qe[@@0RGJ^102:Mjl0102;N;00RGJ^08Uf[P2;N;0208Yg[P0:
08ai/02?O;<0VWfe09F6/@1@EG80Hgn=06bGWP1XVIh0L:6X07FV[@@0MZN^
301gZ:l08P1k[K@0N:Za07V//01iZZh0Ojba08Vb]P2C^K`0YlS=0;WCe03;
h><0d^CX0=SSj@3Gg^H0`/KA0:FW]02KWJX0LWJ206idP01cNHD0OXJA08^E
W`2JY:h0ZkS10;[7d02bbll0Z/K90:C3aP2P`lD0Vl?509Fn`P2=^;h0R;>i
08Vf_022[kD3086^]080Ojjd00<0OZfc086^]021[[@00P21[[@608:_]@H0
Pk2f1025/;L608Ja^0H0Qk:i0P27/[P608Rc^@@0RkBj1P2<]K/808ff_0H0
S[Nm102@]kh8096h_`@0T[W00P2A^;l609:i`1P0Tk[100`0TkZo09:i_P2B
^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo01@0oooo0P3no_h01P3moOd0n?Sh0?;blP3YjNT0hN7Q
0=cLg0<0fm_K00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPT0
X:kA00l0Wjg@09b[c02GY/L0Tj3008jK^`2;V;P0RYRe08^F]P2<UK80F69m
07V0VP26T:T0TYfi0:2]c`2Y]mX00P2Z]mL30:^hf0<0[;WI01H0[[WG0:nj
f02`^mT0[k[H0;2ke`2_^]H0[;OC0:NbcP2Q[L<0WJW109^U`02HX[d0VZBm
09RS^@1TK7l0OhRI08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L0P2c`M/80;G0
g00X0;K1g@2e`=`0]L3L0;G0g02f`Md0]L3L0;Bof`2b_MT0/;cD0:J`b@2H
WkT0TIN_0::X^03lool0o_om0?kon02EXjH0SYJ]08R>Z02^]Kd0o?oo0;Zj
a033`/X0ooom0;Vo_@3kool0/;>l0=SJf@3nool0Wj6]08V=V@3kool0k_?i
0:F[^`2[//h0/[_J0:njeP2c`M/0]/7O0;S2i@T0]L3L00l0]/7M0;G0g02e
`=`0]/;L0;C0fP2f`]`0_<SR0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?oo
o`3mo_l0@P3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0
g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/40802bZLP50;>Z
b@<0]:_:0100/j[50;>Za`2dZlX0]:_:0;B[b02j/L`0aKgD0=38g@3Fd^00
NG6606AKN021MI/0Sh:]09Z:^@2KRkP0WHbi3`2LS;/08@2MSK`0W8ff09V:
]@2FQ[D0W8bm09Z:^`2=OZT0S7fT08]mX026O9l0MVb?06UOP@1UG7T0HEQc
05Q@I`1ABEh0D4UK05E<G`1JDFH0IUad06mUP01bIhL0N6f?081dVP25NIl0
SGjY09N8/`2MSKX0WXjm09R8]`2JR[L0YIK10:>D_@090:6A_P0>0::B_`2R
Tkh0XY>n0:>D_`2RTkh0Y9Fn0:ZKa02eZld0a;_F0<g3f`1gKHP0Ge1i07i]
X@27M:`A08Qe[@P0R7B_2028MJd408Uf[P@0RWN_00@0RgR`08Yg[`2:Mjl0
RgR`0`2;N:l02@2=N[40VGZc09N3]P1^JI40D61i07BDX@1XTiX0Lj:X07>U
[00407JW[P@0MjR_00<0MZN^07NX[`1gZ:l00`1gZ:l207RY/00Q07>TZ`1h
ZJh0NJZ_07^X[@2:/kD0WL320:c:c02me]X0d]oU0=gXkP34bmD0QHBB04e9
FP0o=d`0AcmD04i6F`1HDVh0FE=_05QDK`1FDVd0DDiY04]8H`15AEl0@d=M
05]SL020RYH0X[2k0:Znb@2S_/L0W;o509Joa@2@^l40S;Fk0080Qk:h00D0
R;>i08:_]01lZJh0OJfa086a]@04086^]0@0PZne1P23/;H208Ba]`@0QK2g
1026/KP608Nb^@80R;>j1P28/kT208Vd^P@0RkBj102<]K/608ff_0P0S[Nm
0P2?^;h4092g_PP0TKRo2P2B^L0J09>j`@0<09>j_`2B^Kh0T[W009c1a`2_
c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo
0?ooo`0D0?ooo`80o_kn00L0oOgm0?Shn03bl_80jNWY0>;RhP3MgMd0fm_K
0080f][J00P0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cPT0X:kA
00l0Wjg@09b[c02GY/L0TYno08fK^02:V;D0R9Ja08ZE/`2=Uk80Ff9l07V1
V028SjT0U9fj0:2]c`2Z]]`00`2[^=P30:bif@80[K[J00@0[k[H0;2kf@2`
^mT0/;_I0P2`^mL0402/]m<0Yk;>0:6]``2MZL40VjG009RR_@2JY;d0V:>i
06A/O`1oR9T0SIR^09bV_`2/^=80];oK0;K1g@2e`=`20;?1f`P0]L3L00<0
]/7M0;G0g02e`=`0102e`=`08@2d_m/0/KgG0::^b02IXkh0SiF]0826UP3<
dML0o?om0>g`i`2:V9/0RI6V08V?Z@2BV:H0n?_o0>OXk03Lfn00oOcj08J>
T03GfnH0j>_d0>;Th@3nool0XZBa0864T`3an?l0nooo0:V__`2V[LT0]KkM
0;G0g02d`]`0/[gK0;>mh0090;G0g00?0;K1g@2e`=`0]L3L0;K2g02d`=X0
]/;L0;c8hP3:d^D0d]WY0=CHh@2BTiL0o_kn0?ooo@3oool0oOko0480oooo
000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I
0:f/ZP21OXD0PgjD09><Z`2RVKP0[jK10200/ZW8102cZ/T40;B[bP0@0;F/
a`2e[<T0]Jc;0;F/b`2f[LX0^k;=0<NoeP3Bb]l0eM7O07UaQP1TFgP0PGFK
08j1[02JR[T0Vh^h09f<^@/0W8bk00<0Vh^j09b<^`2LS;/00P2LS;/00`2H
RK80X96l09f=^P0209Z:]`0L09F6/@2JRk@0T86X08Yn[029OJ/0R7fX08Ej
Y020MId0Ng6F07Y`T`1lLYD0OgBD07mdUP20MIL0QGVM08QlXP28O:@0S7nZ
09J9]@2FQk80Vh^h09^;^P2MSK`0X92o09n?_02PTK`0X96j0:2@_@@0XI6n
0`2RT[l03`2QTKh0Xi?00::C_P2RTkh0Y9G00:>D_`2TUKh0ZY_40;F[c@34
^mH0cL?K07M]R01OD7T0OVfQ08Md[00908Qe[@P0QgB/2028M:l808Qe[@H0
RGJ^102:Mjl208]h/0<0RgR_00T0SGZa09=j/@2DP;D0RGf]05EEN@1UMXX0
LiBM072MX`1bYjd00`1fYjh507NX[`0307JW[P1gZ:l0MjR_0080MjR_0`1h
ZK004@1gYZh0NjZ`082]/P2<]KT0VK^m0:_7bP39g>00f^W/0>;Tl01nOHd0
@CaB04m6H@1UFWP0KV>307I[R`1gK8`0OW6L0080PGBO0100OW6L07aaV@1m
LYX0O76I07Y`U@1_IX<0FE=_04I4G01@EF/0NhJH0:2f``2W`lh0VK_409Fl
``2B^L00R;6g0P23[[@00`20[K80P;2d08:b]P03086^]0D0PZne1@23/;H3
08Ba]`<0QK2g1@26/KP508Nb^@<0R;>j1@28/kT308Vd^P<0RkBj1@2<]K/5
08ff_0P0S[Nm0`2?^;h3092g_PP0TKRo2P2B^L0K09>j`@0<09>j_`2B^Kh0
T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`0D0?ooo`80o_kn0140oOgm0?Win@3dm?@0k>c/0>CT
i03Ogml0g=cL0=_Kf`3Jf]X0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF
0:6^cP080:2^d@0@0:2^d`2O[M00W:[=09NVa`2BX;d0SI^f08ZH/`29Uk40
SYRc09:L]@1NIW/0N82E08N?YP2DWKX0Xjk>0:^hf`80ZkSH0`2/^MT30:fj
fP0F0:njf02`^mT0/;_I0;2kf@2a_=P0/;_G0:bgd`2X/ll0XJg309fY`@2K
YL00V::m09ZT_@2HXkT0IFf00829VP2=V:h0W:Jo0:bhdP2d_m/0]/7M0;G0
g080/l7K3P2e`=`20;Bof`0P0:Jac@2/^=80U9jg092HZ`24RYP0koCj0?co
o`3loo/0`/g?08^BY027SJL0QX^O0>?Vk@3nool0oOon0>7Pi@22SI<0Y:Zj
0?cno`3kno/0o_kn0:FW]025Ri/0f>;[0?_oo`2_]L<0XJS20;6je`2c_mT0
/l;I0;>nfP2d_ml90;G0g00?0;K1g@2e`=`0]L3L0;K2g02d`=X0]/;L0;c8
hP3:d^D0d]WY0=CHh@2BTiL0o_kn0?ooo@3oool0oOko0480oooo000Q0?oo
o`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21
OXD0PgjD09><Z`2RVKP0[jK10200/JS7102bZLP40;>Zb@0@0;B[aP2dZlP0
]:_:0;B[bP2e[<T0^[7<0<Jne@3AbMh0e=3N07Q`Q@1RFGH0P7BJ08f0Z`2I
RKP0VXZg09b;^0P0W8bk202KRkX0802NS[l0VXZi09^;^02JRkH0Wi2k09R9
]02LS;T0W8bk09V9]P2GQk@0Th>`0961[P2BPZl0ThB_09:3[P2?P:/0QgZU
09>6/@2?PZd0S7nZ09N:]P2JSKT0UXVe09Z=^@2LSKH0XiBo0::B_`2IRKP0
W8bk0:FEa02RT[l0WXnj0P2OSk`20:2@_@<0XI6n0P2RT[l03`2STl00XY>n
0::C_P2TUL00XiBo0:BE_P2[W<D0]J_=0<BkeP3=`m/0Mff805m@N@1nKJ40
QgB/08Qe[@0@08Md[0P0Qg>^2P28MJd608Uf[P0408Qe[@29MZh0RWN_08]h
/080RWN^00X0RgR_08ai/02;N[00T7fe099o]P1gJYH0EEUb06j6TP1]V9h0
KjJ[0P1fYjh607NX[`80MZN^0P1gZ:l307RY/00E07VZ/@1lZJl0OZV`08N`
]P2P`lL0/Lg@0<gPi03Ul?@0b];E05E@I01@B600H5Ee07QYT01nKiX0P7>N
08QmY`2:OjL0SGf^08mo/02APK80T82_0080T82]0180S7n[08UlY`26NJ@0
Q7RP08AhWP1iKi40FEE`04M9H01VKh00UJ:b08nd_02I`<L0TKRo08Ra]`29
];X0QkBi08Fb]`20/;@2086^]0H0PZne1023/;H408Ba]`80QK2g1P26/KP4
08Nb^@@0R;>j1028/kT408Vd^P80RkBj1P2<]K/408ff_0P0S[Nm102?^;h2
092g_PP0TKRo2P2B^L0L09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H
0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0D
0?ooo`80o_kn0140oOgm0?_kn`3fm_H0kno_0>SXj03Shn<0gmoO0=cLg03K
fm/0SY:A07QmT@1oR:T0R9Nd09RYa@2O[m<0XJoF0:6^cP080:2^d@0@0:6_
e02O[M00W:[=09RWaP2EXl00Tj6l09:P^P2CXK/0VZFk09jY_@1VKX40Nh:D
08J>X`2EWkP0Y:o=0:^hfP80ZkSH0P2/^MT40:fjfP040:njf02a_=X0/KcJ
0;2kf@80/KcH0100[KSD0:Rcc`2Q[L<0WJW109^U`02HX[d0VZBm09RS^@1U
KH00P8VJ08fH[P2LY[l0[;SB0;Bof`2f`Md0]L3L0P2c`M/;0;G0g0030;K1
g@2e`=`0]L3L0080];oK0200[;[G0:>^bP2HXkL0Qi2O0;O0b@3kool0hnK[
0=oRi`3iool0/;K208R9Y@2:S:D0`<C=0?Omn@3jo_d0blkE096JZ`2<TZP0
fmc^0?ono`3lo?h0YZRe08F<W032c=D0nooo0<K<f02]]L`0/K_F0;6me@2c
`]L0]l?M0;K1g`T0]L3L00l0]/7M0;G0g02e`=`0]/;L0;C0fP2f`]`0_<SR
0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?ooo`3mo_l0@P3oool00240oooo
00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085n
Q@23OY@0Thb[0::I^02_Y/40802`YlH40;6Xa`@0/ZW80100/JS30;6Xa@2b
ZLP0/ZW80;:YaP2h[lX0`k_B0<k6f`3Ccmd0Mfn4065HM@1oLiT0S7nZ09R8
]`2IRKH0VXVf202LS;/509^;^P<0VXZi00T0VhW309N6_02MSK`0U8F`09Z;
]P2MSKX0VhZn09N6_02IR[<00P2HRK80502IR[<0UhRc09B5/02EQ[40V8Vd
09N9^P2APk@0UHRf09V<^P2FRKD0VHbh09jA_@2KS[T0Wi2g09N8/@2OT;/0
X92o09b<^`2MSK`0Vh^h102NS[/00`2OSk`0X92m0:2@_@020:6A_P0@0::B
_`2STl00XY>n0:>D_`2TUL00XiBo0:FF_`2[W<D0]J_=0<BkeP3=`m/0Mff8
05m@N@1nKJ40QgB/08Qe[@P0QW>[2027M:`808Mc[P`0R7F]1029MZh01026
Lj/0R7F]08Yg[`2:Mjl208Uf[@0:08]h[`2<NK00QG^_08Ug/@2DO;P0T7b]
05eHMP1FJ7@0M9nU06VSY`L0MjR_00<0N:V`07JW[P1fYjh00P1gZ:l207RY
/080NJZa02P0QK2g09:j`P2Oa<X0]mKK0<OOh`3Ql?<0`<S;04Q;D01CBF80
KV5o07i_UP25M:40SWj_0963]P2=Q;<0T8Rg09V9^P2HR;T0UhNh09V9^02J
R[L0VHVf09R9]02GR;<0TXRj09>7]`2@P:d0SGbV08inXP23N9H0IF1g04I4
F@1NPh/0RJjf09Fl``2>]kd0R[Fk08Fb]`23/;D0P;2d1`22[kD508>`]P@0
Q;6g1`26/KP508Nb^@@0R;>j1028/kT408Vd^PL0S;Fk1@2=][`808jg_@@0
SkRn1`2A^;l809:i`00309>j`@2B^L00T[W00080T[W0702C^/40302C^[l0
T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80
oooo00<0oOgm0?ooo`3oool0503oool20?knoP80oOgm00l0nOWi0?;blP3[
jn/0iNGU0>7Qh@3Ng]h0g=cL08jBT@1hOI40OhRY08RG]02HZLD0WjoC0:6_
eP2Q[/h0202P[]404@2Q[m@0WjgB09f[cP2JZLP0VJO409ZX``2LZ/@0Wjk5
0:NbaP2]]LP0KgR907j5U`28Sj80UInh0:F`cP2/^M/0ZkSH00<0[;WI0`2]
^]X01@2^^m/0/;_I0;6lfP2a_=X0/;_I0080/KcH0100[KSD0:Rcc`2R[/@0
WZ[209^U`02HX[d0VZBm09RS^@1UKH00P8VJ08fH[P2LY[l0[;SB0;Bof`2f
`Md0]L3L0P2c`M/80;G0g0060;Bof`2e`=`0]/7M0;K1g@2e`=`0];oK0P2c
_]X0802X]MD0ZKC@09:M[`2EWjT0e]oV0?[oo`36bM80WZ6Z0?[no@3bm_l0
WZ2i08Z;Y`2PY:l0noom0?Sno030am40Uj:f09>H]@2d]LX0n_Wo0?ooo`2_
/Kh0RY6Q0;o<e03jool0b]7K0:Zba`2`^]<0]L7G0;C3f02f`]X0/kkJ2@2e
`=`03`2f`Md0]L3L0;G0g02f`]`0]<3J0;K2g02lb>80b];U0=;Ij@3Df>40
TY>G0?knoP3oood0oooo0?gno`120?ooo`008@3oool06P3no_h0n_[j0?Cd
m03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2/ZjT0P7f408AoU@2DSJ`0XiZi
0:jU`02^Y[d0/:O20:bS`P2TV[d0Z9k30:fSa@2VWKX0[ZJn0:^R_@2[X[l0
[ZG40P2ZXL00202]Y<40Z9nn0:bRa02VWKX0[JC10:RO_02/Xl00YYfj0P2Y
X;d0502ZXKh0YIbi0:^R_`2ZX<80ZIo10;2Vb02YWl40YYfj0:VP_@2WW[d0
ZJ2k0:nW_P2YX[@0[ZJk0:^S^`2[X[l0ZZ320:VP_`2_Y/D0Zj:m0P2/Y;`0
3P2bZ/40^k?;0<:jdP39a<P0LVah06=KL`1dJ8`0RWfX09R;]`2BPj`0Vhbc
09b<^@2KRkP0VXZi0P2KRkX0EP2JR[L0V8Vd09N8/@2GR[D0U8Nc09:4]@2H
R[/0ThJd0964[`2CQjl0TXJ^09:6ZP2CQjd0V8bd08]nZ@2ER;<0SX:Z09>7
[@2CQj/0U8F/09B3]`2EQ;X0ThB_09R9]02FQKT0U8Bc09>5Z02BQZ`0UHVa
09B7/P2FR[80THF]09B8[P2ERK40UhZe09N9[02HRK@0UHFb09n?_P2HQk/0
V8Re09j@]02DQJ`0UXFa09Z9/`2KRk80UXJ]0::B^@2FQZd0VhZd09b;]`2H
SKP0XiS309jA_@2OT[h0X9>n0:>F`@2RTk`0[9g60;>/c@34^mH0cLGJ07U_
RP1LD7H0OVjO08IeZ`26LjX0R7>[089`X025M:00O6ZL08Ib[@1mJjL0PG2T
085bV`22LIh0QG:Z089aWP21KZH0PVnW081_W023KjX0Pg6Q085`W025LZT0
Pg2W0P22LIh05`20K:L0QW:]085_X@24L:/0R7F/08=aY@27MJT0Pg2W08Mc
[P24L:d0Qg>`08=aX@27MJT0QWBT089`XP29MjT0PW2P08IdZ023LJ40PFf/
08Qd/@1nJZD0OfbT0080Pg2X02X0R7B_08A`Z`29MZh0SWfa08al[@2AOK80
TGZb065HQ@1KK800OJBS07:W[@1gZK00MZN^07^Z/P1n[KD0M:N[072UZ@1f
[K00NjR]07VVZ`1jZZh0Nj^_07NWZ`1mZ[00R;2h08^a^P2O_LL0ZLG90<SL
f`3Cgmd0j>k^0<71b`17@UP0CTQT075QSP1nKY/0Rg^Z0961/02CPk@0UHFf
09R7^`2IR;`309V9^080VXZi102KRkX209Z:^@0@09V9^02GQkH0Th>b08mo
[P2;NjX0HEal04a@J`1lSih0UkS108Ra]@26/kP0Pjnh08F_^`24/KL0PJjd
08:]]080Q[6h00@0PJjd082_]@23/[P0Q:nf1`25/;L408Ja^0@0Qk:i00<0
Qk:h08Rc^@28/kT01@28/kT408^d^PP0S;Fk1@2=][`708jg_@0308nf_@2@
]kh0T;Nn00H0T;Nn1`2A^;l809:i`200Tk[100`0TkZo09:i_P2B^L00W<77
0:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3o
ool0oooo01L0oooo0180oOgm0?_kn`3gmoL0l_;b0>c/k03Vi^H0hN7Q0=kN
gP2;SYd0Mgj@08RDZP29V[@0UJK409j]cP2QZLd0ZJgB0:2/dP2Q[M<20::^
e00E0:2^d`2O[M80WjgB0:2^d`2N[]80XK7C0::ad02X]<h0Yk;60:ffa@2]
]L00^L3:0;^o`P2n`LP0Oh>?07b3U@24SjD0Tini0:6ab`2Z^]@0[[WG00<0
[k[H0`2`^mT00`2a_=X0/;_I0;6lfP040;:mf@0>0:jje02Y]Ll0XZk409jZ
`P2LY/40VJ>n09NQ^P2JYK/0HFUl0829VP2=V:h0W:Jo0:fid`2e`=`20;K1
g@80]<;L202e`=`80;Bof`0;0:nceP2[/<d0X:Nj0:nga03do?l0m_go0:Za
a02HW[@0aLcD0?Woo`3Pinl00P2FWJD04`3Uk?@0nOoo0;2g_`2RYl@0WZBj
09jU]@3?en80mOgo0;Flc02DV[00/KKC0?Soo`3Ni_40];cA0:jhd`2g`^00
/l7N0;K4gP2a`MP02@2e`=`03`2f`Md0]L7K0;G1f`2f`]`0]<3J0;K2fP2l
b>00b];U0=;Ij@3Df>40TY>G0?knoP3oood0oooo0?gno`120?ooo`008@3o
ool0703no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0f][L0=_Kf@2/ZjT0
PGj508AoU@2CS:/0XYVh0:fT_`2^Y[h0Yiji0::I]P2UW;T0WYFd09bC/02T
VkH0Xi^c0:VP^`2OU[40XYVd0::I]P2RVK@20::I]P0Y09jE/P2TVkH0X9Nb
09jE/02RVK@0WiJa09fD[`2RVK@0Vi:]0:>K/`2OU[40YIbi0::I^02SV[T0
XIRe09nF/@2MUJd0XIRe0::I]P2SV[D0Xi^c0::I]02OU[<0Y9^j0:6G^@2V
WKP0WYF`0:fT_`2XWkX0Ying0:BL/`2/Y;T0_;G70<6ka`1[I7H0E4]V07]_
T`1mL9/0RgjZ09J9]@2IR[D00P2JR[L309^;^P0g09V9]P2FQk80U8F^08Ym
Z02FRK@0Sh:^08UlZP2=P:`0THF]08UmX`2=PJL0SH2[08IiY021M9l0Sh:]
08QkYP2:OJP0RGbW08YmZ02;Oj<0R7Z[08n1/P2@Q:`0Sh>Y08QkZ@2?PZh0
Rh2P08]nZ@26NJ@0RWfX08QkYP2?PZd0T8>^08]nZ@2=P:/0S82T0965[@2=
PJT0RGbW09:5/@2>PJ`0RgnU09J:/02BPj`0SGjW08enY@2EQZd0RW^R09J7
[P2EQZl0UhRa09N<]02GS;H0XIBo0:RKaP020:6D_`0I0:FF_`2[W<D0]:g>
0<BkeP3=aMX0NFn:05a@MP1mKIh0QGBZ08EbZ@20K:L0OFZQ07]YV`1lJYh0
MVFK07UXWP1mK:00NFVH07UYVP1fI:00OfnN079QV01mK:<0MfND07MUW`02
07m_WP0=07aZY01nK:H0LV:A085aX01iIj40MF>M08=cXP1kJ:00Q76X08Ab
YP1iIiT0QWBX07eZX@0207m/Y00h07m^XP1iJ9h0MFBH089aY@1jJId0OfjR
07IUV`1jJId0Nf^H07UYUP1mKYT0Q7FP07a]V021LYd0MVJC08QhY@2;MZl0
RGR/08YjZ`29MZd0Tgjg07eaX@1KHWh0GgQo072PY01kZjl0Q[Jj07b[/@1k
Z[00PK2f07ZY/@1hYjl0NjR^07bY[`1jYjd0O:V_08F`]`2;/k/0TkS10:73
c02ccm<0bN7S0=OVj@3MinT0ZJbe03`iBP1=A5l0MFb;081`W@29NJH0TX:a
09F5]02EQKH0UXJg09R7^`2IR;`209V9^0<0VXZi1P2KRkX209b<^`0@09Z:
^@2GQkH0U8Bc0921Z020NIX0CUA/05IYN023Y:d0RkBj08:a]`21/[T0P:ne
086`]P22[kD0Ojbb086^]080Q[>i00<0P:ne08F`]`25/;L01025/;L608Ja
^0@0Qk:i1P28/kT208Vd^P@0RkBj202<]K/408ff_0H0S[Nm0P2?^;h6092g
_PP0TKRo2P2B^L0P09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WG
fP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0G0?oo
o`0@0?knoP3lo?`0n_[j0?Gem@3`l?00j^[Z0>GUi@3Shn<0XZB`08R>WP23
SjD0Ribj09R[c02KZll0Y;7D0:J^dP80XZkD01H0XJoD0:2^d`2O[M80X:kA
0:6_dP2S/M@0Y;?D0:Zge`2]^=@0]l;H0;W2d`2maM80_/G?0<G9dP34aLT0
ZZfd061TL01`MhT0RIBZ09JR_02Q[lX0[[kH102_^]P20;2kf@80/KcJ00<0
/;_I0;:mf`2b_MT00`2b_MT03P2^^]@0ZKG?0::^a02NZ/80W:K109^U`02I
Xk`0VjJl069ZO@20RIX0S9N]09^U_P2/^=80];oK0P2e`=`20;?1fa00]L3L
0200/KOI0:bcd02Z//L0Z;720;c5e02ob=T0Y:c10:>[`P2SZ[`0^l;D0;Ro
d@2W[/00YJbn0;k5e`3:dN<0[KC60:^bcP2Z//T0Xj^n0;JocP3;e><0[;C7
0::Z`@2^]M40_lOB0;[1d`2/]</0/K[G0;O2hP2a_m`0]L?M0;;2f@T0]L3L
00l0]/7M0;G1f`2e`M/0]/;L0;G1f`2f`]X0_<SP0<[Bi@3BfNT0e=SQ09:C
U`3no_h0ooom0?ooo`3mo_l0@P3oool00240oooo01l0o_kn0?[jnP3dm?@0
kNg]0>GUi@3Ogml0g=cL0=[Jg03KfmT0[JbZ085nQ@24OiD0Thb[0:2G]P2[
X[d0[:>n0:JM^02BRZ40UHfR09VAYP2BRZ40VI6X09J>YP2GSjL0VY:Y09^C
ZP2ESJ@0VI6Y09>;X`2GSjL0UXjU0080T8RP05L0Vi>[0928X02CRj<0Th^S
09B<Y02@R:00U8bQ08b4V@2LU:/0V92X09fE[@2JTZT0ShNL09J>X`2DS:@0
TXVT09R?[02PUkH0UXf/09:9YP2BRJ@0T8RP09:;W@2HT:D0UHfT08f5W@2R
V[80VY:W0:JP[P2WXJ/0[ZNi06INL`1BBV80I5]h07M[S`22MYh0S7n[0923
/@2HR;D0VHVf09^;^P2LS;/0Vh^j09R8]@2CQ:l0Sh2Y08YnYP26NZ80P7BL
0924[024N:00OW:H081eU`1oM980NfjL089eX021MI/0NFj@07]`TP1nLYP0
PgJQ07a_W@20MI<0PgJQ08=fXP23N9X0P7FG08MjY@1oLi/0OgF@07iaW021
MId0PgNM081dW023Mil0O6nJ08UmY@24N9h0QGVQ08EiW@20M9P0R7fO08Ej
VP2;P:80S82V07a`UP1kLI<00P26O9h208AjW00T07idUP22N9X0RGnQ0967
ZP2HS[<0X9Bl09b?^P2SU/40YYW40:FF_`2[W<<0]Jk?0<Fle`3=aMX0NFn:
05a@MP1mKIh0Pg:X08=`Y`22KZd0MV:O079QV01]GH`0LfB?06]OQ`1^HHd0
LVBG07ASU`1fI:00HE5n07YYW`1/Fhl0LF:;06mNU01cI8l0MfNH0P1bH9`0
?`1iJIP0K5b9079QU`1fII/0NFZE07a[X@1oKZ@0MfJJ07IVU@1bHXl0MfND
07IVU@1aHI80MVFI07ATU@1aH9@0LF6B07ATU@1hIi/0MFFF075PU01`Hhh0
MVVD06YMR01aI900Jej:071ST@1kKY`0MFRF08EaYP24LZH0Rgf`08im]02;
NK<0Rgf`06YVR@1:CfD0IXB<07fPYP24[K40R;Fj08Fe^@28]KX0TKW108:X
/@27/[/0RkJo08Ze_02?^;h0VKk60:C5c02cd=H0a]oV0=7Uh`3Ij>/0eMkW
07n1T012?E@0HUUh07IZSP20M9X0SWj]09>3/P0209R8]`0509N7^02HR;T0
VHVj09V9^P2IRKP00`2JR[T409^;^P80W8bk01<0WHfl09j>_@2NS[d0WXjm
09f=_02LS;/0Y8fk08ajY02CQj/0HfEn04mOK`1lVZD0OZV_07b]/@1k[;40
P[6g08Fd^P22/KL0PJjd0080PZne00<0PJbc08F`]`25/;L00`25/;L608Ja
^0D0Qk:i1@28/kT308Vd^P<0RkBj202<]K/508ff_0D0S[Nm0`2?^;h5092g
_PP0TKRo2`2B^L0P09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WG
fP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0H0?oo
o`0?0?knoP3moOd0n_[j0?KfmP3alO40kNg]0>[ZjP34aLT0Qh^F08^F[02A
X<40UjK?0:6cf`2M[M40WZc?0080X[3C01H0XJoB0:2^d@2O[/l0XK3A0:Bc
e02V]MH0/K_F0<;<i@32b]l0b<oQ0<S>g03>d]/0_l;909JIWP1fMgT0UiZO
07MkQP1nQIL0QhnV09BP^P2R/</0Z[[D0`2_^]P30;2kf@<0/KcJ00<0/[gK
0;:mf@2b_MT00P2b_MT0402^^]@0ZKG?0:>_a@2OZl<0WJO209^U`02JY;d0
W:Nm06=[OP21RY/0SIR^09bV_`2/^=80];oK0;K1g@2e`=`20;?1f`P0]/7M
202e`=`0202e`>00[k[H0;2le02/^L`0Y[?40:Vfb@2[]ll0[KWC0P2Z]<l0
5P2Y/lh0[[SC0:VccP2W/L`0/[cG0;6keP2_^]H0/;cF0:^hb`2Z]lP0[K[;
0:Nda`2]^M<0ZKC@0:febP2e_M@0];_H0;W2h@2h`n<0[kgJ0;?1f`2d`mP8
0;K1g@0@0;G0g02g`]h0]/;L0;G1f`2g`md0]L7K0;K2fP2lb>00b];U0=;I
j@3Df>40TY>G0?knoP3oood0oooo0?gnod80oooo000Q0?ooo`3Q0?knoP3j
n_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Jf]`0fm_I0:f/ZP21OXD0Q7nE09:;
ZP2OU[D0ZZ6l0:BK^P2NUK00W9BY08R2T02ESi/0XYbZ09B=W`2ARJ00SHFM
09><WP2<QID0Qh2@08j6V`2=QI`0S8FG08AnS029PIH0S8BI09VAYP20N8d0
QGfB08Z2U`1oMh`0RX:G07mkR@2@S9/0R8BE08V4V02=R9`0PWj?08j:V@2D
T9h0ZZJe09RDY@2<Qih0QX2J08R2W02?RZ00Pgn>08Z6U02<RI@0Qh>A08b7
V`2?RZ00Q7nC08b8U`2RWjH0^KNj0;>_`01OFfX0BT=E06=LKP2ITJP0QgbJ
07eaU@2?Pj/0UHFb09R8]@2KRkX0W8bk09^;^P2GQk@0T86/08YkY01oLiT0
O76C081eU@1jKi40OW:F07Q/T023NI@0X9N/07IZTP1gJhl0MF^60967W`2L
TZX0MVb7071TR01hK9@0NG6807Q^T@1hKY<0RX6L07M^R@1mLiH0M6^:075Y
OP1dJX`0L6N407A[QP1iL8/0M6Z<07idUP1eK8/0NG2;07Q]U@1fKHP0N6n<
07I]RP1lMHL0Ng:=07AZS`20MYP0OGR>09VDZP2@Rj80PG^E07MaR`21O9<0
UY6W092;X@2;PYl0SHBS09Z>]02KS[T0YIS40::E`02SU;d0[9g40;J_d035
_=L0c/KK07U_RP1LD7H0O6bM089aY`20KJ@0MF>M07IUW01TE8D0KEn3089h
T@2?QIh0Jf2206UNR01VFH@0IEN:06eRQ01PE7`0Ge=i06mUP01UFH40IU]k
06MJQ@1]Gi80J5Z;069FNP1ZGh40I5N206eQR@1ZH7/0NFVJ071OT`1fIIT0
MVJC06]MP@1]Gh80LF:9071QS01SEX40IUYn06aOR`1[GhD0KF67065DP01/
H8@0J5^608V0W`2=PjD0Jf6406QNP`1YGh@0PGNL08QnX`1bJ8d0OFZH08Me
Y`27NJh0S7ng08Mh/@2?O[@0SWj[07U[S`1@EVh0G6^008FO[P2A][l0Sk^n
09Jo`@2C^k/0Wl;409o4bP2M`/P0XlW<0:g?d@2edmD0a=cN0=3Si`3Ch^D0
en7P0:Za]`13@U80BTAP06]OQ@1fIi80QgRS08n0Z`2DQ;<0UXJe0080V8Rg
0P2HR;T00`2IRKX0VXZk09Z:^@0209Z:^@<0Vh^j1@2LS;/509f=_00@09j6
^02SRk/0XXfh09R:[P1ZIh@0Cea_07:>V@26[K@0O:^a07f//P20[kD0Pk:h
08:a]`22[kD0Q:nf08Va^@@0QK2g1P26/KP608Nb^@@0R;>i1029];X208^d
^PP0S;Fk1P2=][`408jg_@@0SkRn102@]kh8096h_``0T[W0802C^/40302C
^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?kn
oP80oooo00<0oOgm0?ooo`3oool06P3oool03@3moOd0no_k0?Ogm`3dm?@0
l_;b0>[Zj02;SYD0T9J/09jXb`2BWlT0X:oH0::df02S/m@00P2Q/=405P2Q
/<l0Xk;A0:Jdd@2[^MH0/KoJ0;G3gP36bml0cM;U0=KLjP3Lh>`0dmKO0:FV
Z`1kO7h0[:b^0=WKfP3Gfmh0S92K07j4U027SjH0V:Bn0:FccP2[^]L20:nj
f0<0/;_I0`2a_=X00`2b_M/0/kkL0;>nfP030;:mf@0@0:jje02Z]]00Xjo5
09n[``2LY/40VZBo09ZT_@2LYkd0Hf]n0829VP2>VJl0WJO00:fid`2f`Md0
]l;N0;K1g@80]<;L402e`=`0202a_]h0/;kK0:jleP2`_mH0/L3E0;2oeP2a
_mT0[kgH0P2b_M/05P2`^mT0/[gK0;2kf@2a_=X0]/7O0;2kf@2a_m`0/KoJ
0;70e`2`_m@0[;_@0:^jd@2c`M`0[;[G0;>mf02g`=d0]KkM0;K1h@2e`>00
/KoJ0;G4f`2ea=T90;G0g00?0;K1g@2e`M/0]L7K0;K2g02e`M/0]/;J0;c8
h03:d^D0d]WY0=CHh@2BTiL0o_kn0?ooo@3oool0oOko0480oooo000Q0?oo
o`1h0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21
OXD0Q7nE09:;ZP2OU[D0ZZ6l0::K^P2LU[00Q82A0;Zg`P3oo?l0o__o0>;N
k02@S9/0RhJM08F1T03Kf>40mO;m07agR`27PYP0hMg/0>WVk@20O8/0RhNF
0>_WmP21OH`0NgN60?olo`2i]L@0b/KE0?omo`3lnOl0i^;`0;Nc`@1mNHL0
R8BB0<C1c03oo?l0o__o0?[go`3Lf>H0SXZK07YfQ@3:am80o_co0?gko03o
o?l0]K:m0?cho`2ASIh0RHFD0;Fb_@3ln_l0ooko0?gjo`2RWjP0EE9K0>OQ
j`3kmOl0oOKo0;^ab@23NI@0TX:_09N7]02KRkX0W8bk09^;^P2GQk@0Sh2[
08MhX@21MiX0a[gJ0>gUo@1fKHP0NW6@079YR02d[<40o_So07ieTP1UGG@0
al3@0?olo`3onol0m>gm08^3VP2OU[<0o_Oo09nF/@1`Ih@0a[kC0;2Y^`1]
I7l0/j_30?olo`24O9@0oo_o0?olo`3on_l0oOGo079ZPP3ZhoD0blGA075W
RP3;a=@0oo[o08MoU`3oo?l0Zj>h07Y`T`2?Qil0j^Ob0P3oo?l00`3>b]/0
MW:30<O3dP020?olo`0D0<c4f`2GSZT0ShBV0:>G_`2SU/80Wi:m0:VJ`@2/
W/80]Zo@0<Jmf03>a]/0NFn:05a@MP1lK9d0P6nU07eZX@1dI9D0IUV507=X
RP3Jd>P20?olo`1>0?Wao`2AR:<0HUMe0::F^P3on_l0LfV108=iT@3mmOl0
fLk/0?ojo`2^Y;l0I5Ql05iCM@1VGG80nO3o0=?9i037_MH0kNGb06UMQ@1c
IY80J5^906IJPP3]h_l0bKoH06EJNP1SEgl0_;7?0?ojo`1KD780k>?h0<Fl
d@1SF7X0M6]l0=[?k@3nn?l0ooco0?Wco`1XHG40XY^[0?ggo`3oo?l0i=oV
089bU`22LYl0PW6W08Yk]02@Pk/0Sgjd08efZP2CNJT0QgBR05mGP01;D6h0
MX^N09Vg`@2K_/00ZL_:0:W9a02acM00^]KI0;oKg030f=X0b]kO0=g[k03G
gn80^[o206m_M`0m>dT0HUUd079SRP22L:00RWRZ08QhY`2JR[T0UHFf09J6
]`2GQkP0V8Ri0`2IRKP309Z:^@<0Vh^j202LS;/209f=_00A09j>_@2QTl@0
WH^m09f7]P2OR;@0WHfb07=^S01CFg00N8VI08N]]P22Z[80OJZ`07f//P20
[kD0Q;6g08F`]`27[kL01025/;L408Ja^0H0Qk:i0P28/kX408Rc^@@0RKBj
1P2<]K/808ff_0H0S[Nm102?^;h4092g_PP0TKRo102B^L0X09>j`@0<09>j
_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn
0P3oool00`3moOd0oooo0?ooo`0G0?ooo`0@0?knoP3oool0oooo0?ooo`3m
oOd0no_k0?Win@3hn?P0moSb0<W:cP2>TJ80TYVe0:bff@2Y]mX0YkOH0:fn
fP80/;kI01H0/;kH0;C0fP2ha=`0`<_Q0<SCi`3=f>`0g^3/0>?Ul@3Qi>d0
a<C<08n@U02VYZP0emOG0=WIe`3MgM/0emSJ08^>U`21QiL0RI6V09>M^02Q
[<P0[kgJ0`2`^mT30;6lfP<0/[gK00<0/kkL0;>nfP2b_MT00P2c_]X03P2_
^mD0ZkOA0:Faa`2OZl<0W:K109ZT_`2JY;d0W:Nm06=[OP20RIX0SIR^09bV
_`2/^=80]L3L0P2f`Md20;C2g100]L3L00H0/KkN0;G3h02a_mX0//3J0;C2
g02a_mX20;?1g00H0;?1f`2a_mT0[kgG0;?1f`2d`]`0/l7K0;C2g02__ML0
]<;O0;C2g@2a_mT0/l7K0;6of@2b`=X0]L?N0;C2g`2c_]`0];oO0;:mg@2d
_ml0]L3N0;K1g@2fa=h0//7H2@2e`=`03`2f`Md0]L7K0;C0fP2f`]`0]<3J
0;G1f@2kaml0b];U0=;Ij@3Df>40TY>G0?knoP3oood0oooo0?gno`120?oo
o`008@3oool0g`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M0=cL
fP2][:X0PGj508AoU@2BRjX0X9Nf0:^R_@2TW[X0Ui6[09F@YP3QgN`0dLkI
0:^X/@3jmol0d/oH08=mU`1kMhH0`;g40?SeoP23OY80P7^A0<2lbP3knO`0
Ph2;09^HX`3ooOl0/k2k079_NP3nnol0^[O20;Vf`@3lnOl0W9VP0<g:e@3o
oOl0UY>N0;>`^`3oo?l0iN;Y0:bY/036`lX0o__o0=WFg`25PXT0^KNl0?on
o`2i^;H0_KW70:6MZ`3ooOl0XYnZ09BAVP3hmOh0lNke0<G2b@39al`0`Ko4
08J3RP3]j_<0WYRT0<W3d@3oo?l0WIJV0961[P2FQ[<0Vh^j09b<^`2KRkX0
UhNd08n0Z`26Mj00LfV;0;jfcP3nmol0K6Ai06QONP1gKXT0m>kl0?ono`2B
Rid0PW^;0?ojo`3FdMP0ShZA0=[Dh03^ioL0JV=e0?SeoP2n^Ld0I5me0=[F
i03ThN`0K6Mk0:jZ^`3oo_l0J61e0?olo`3IeMH0[ZV_0;B]_@1[HgP0g=KT
0=cGf`21NiL0ooko0<:md@1_JH<0n_Sm0;Nc`@1/IHH0hmo]0?omo`2l^L@0
XIf/0=cGj`2?RYh0lNgl0;Vf`@2c/;T0ooSo0<:jd@2BQjL0Wi>k0:>F`P2Q
U;l0Z9W00:bN`P2f[m00aKcG0<k6f`1iKhX0G51f07a/W@1oKZ@0O6VP06mR
SP1VFgd0`;O<0?oko`2_Z;P0RX>E0<k:f03mn_l0O7F7089jTP3ooOl0RhFC
0;jhaP3oo?l0Mfn70;Vba03ilol0QgnF08b4V`2BS9H0noKm0;J__`2XXK40
oogo06MLNP1TF7h0JUf806IJOP3IcnL0eLcO069HL`1SEgd0Z:2e0?olo`1_
IX40dlgG0=K@fP1OEW40_;Nk0?oho`39`]@0SHFJ0;Zbb@2DS:@0i=cc0;ff
aP2OVJ<0mO3f0=?:i@26Mih0RGN[08aj]02:Nk80T8:e08ei[P2IO[D0UWRd
08]dZP1gK9L0Bdi_04MCJ@1fR9@0W[:i0;[?dP37e=`0a=7I0<WFgP3Bg>D0
_LK?08B6TP1@CU/0@Sa:0559H@1aIX@0NffA08AcX02AOk40U8:d09b<_@2?
P[000`2HR;T01@2JR[/0Vh^j09Z:^@2IRKP0VXZi00@0Vh^j0`2LS;/00`2M
SK`0W8bk09f=_00309f=_00C09j>_@2OSkh0XI7009VA`02KSkl0Y9;20:J@
`@2SSK/0W8ba07aeU01IEW40MY:N086Q[027[KH0PJjd07f//P22[kD0Q:nf
08>[/`0308F`]`D0Q[6h1@27/[T308Rc^P<0R;>i1@29];X508be^`P0SKJl
1P2>]kd508nh_P<0T;Nn202A^;l509:i`2P0Tk[100`0TkZo09:i_P2B^L00
W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo01L0oooo0P3no_h20?ooo`0T0?knoP3moOd0o?cl0?clo03g
n?80o_kn0;g0a`2?TZ<0Vj6g0;2jd`2d`=X0_<SP0;g9g`2nb^00`/gQ0<O?
hP3<eNH0e=_[0=[Rk`3OiO<0j>W^0>3QiP2XZJd0XjBX0<K6b03Ogml0hn?Q
0=WIe`3DeM00fmgL08nBV@1lPY00QXbR09ZT_`2Y]=80[K_H0P2`^mT30;6l
fP@0/[gK00<0/kkL0;>nfP2b_MT00P2c_]X0402`_=H0[;SB0:Ncb@2Q[LD0
WjW409fW`P2MYl00Wj[006A/O`20RIX0S9N]09^U_P2[]m40];oK0;G0g02d
_m/20;;0fQ00]L3L0P2e`mh0202d`]d0]L?N0;;0f`2b`=/0]/CO0;C2g@2h
amh0]LCK0P2c`]T01`2b`MP0/L3G0;?2f@2ea=/0//3K0;K4g`2a_mX00P2b
`=X0102e`mh0//3K0;?1g02e`n020;C2g`050;C2g@2d_m/0]<3J0;G1f`2b
_]P02@2e`=`03`2f`Md0]L7K0;G1f`2f`]`0]<3J0;K2fP2lb>00b];U0=;I
j@3Df>40TY>G0?knoP3oood0oooo0?gno`120?ooo`008@3oool0B@3no_h0
n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0g=cN0=cLfP2][:X0PGj508=nU02B
RjX0XIRg0:bS_P2WXK/0VI>]08j9X02?RZ00S8RI07]hP`2n^l80ooko081i
V025PI00]K>h0?omo`2AS:00NGB;08j:V03no?d0Xj2Y0;Nd_@3ooOl0inC]
07ejP`3nnol0]K:k0:6NY`3oo_l0VIRN07mnQP3dl_d0`/3;0=?BfP3mo?l0
ViZO092=WP23PHl0^kW40?ono`2k^/00XJ2V0?ono`2QX:H0PGjA08V7U@3i
n?l0^;Nl0;Vi^`3oo_l0_;_30:VW]02b/KH0IF9[04m;FP1lMh/0J6=g07I_
P@3onol0^kG10920[@2FQ[<00`2KRkX0V`2HR;D0T86/08MhX@1iL8l0XYZ_
0?ojo`2ESid0L6R00;N_a`3lm_l0oocg0:FN[P2CS9`0oo_o09RAX@1aJWX0
ShRH0?oio`2MUZH0_kg00>3Lj`1[IgP0lo3g0?omo`2YYK@0[:Vd0?kmn`1X
HgX0hn3[0=WGfP1XIF`0K6Mk06USO@2i]L@0ooko0:bW^`3ooo/0NGF606]T
P`3Th^D0e=7L08^5X@3oo_l0aKk>07mgS027OYT0OWFD085hU`2DRjH0L6Qm
07E^OP3]io40g=GW09bA[`2MTKT0Y9O30::E`02QT[T0[Z330;J_d035_=L0
cLGJ07U_RP1LD7H0O6bM07m^Y01jIih0JUj<06MNN`3hl_l0hmc/065JN@1K
E7H0Ee9V0>o]l03DcMd0KfMn0?_fo02aZkL0m_3n0<K0bP1ID6l0NG2;0?ki
o`3onol0n_?o0?omo`3oo?l0SHJH09F>X03oo?l0RX:G06aSPP1MDgP0GUEd
0;^daP3lm_l0Ieii05M<M02<Q9T0o?Sg08j5XP2c[[D0oOSo06ELN@3dl>l0
h=S]06iQS01dIi<0LVFC071ST@1eJ9<0NVnA06MMMP31^</0oOco07]`TP2:
MZT0U7nh08Qj[`2=PK40TH2d08mg/@2BNk<0T7ba08IdYP22MJ00LFV>05A?
K`15AEl0?SiF05=BI01GEVP0BTQM03TgC@0m>E80CdUU06EJN01fJ8T0OFjI
08QgX`26MJ80UX:c095m/02LS;d0UHRf09N;^@2IR;`0V8Nk09V9^P2KRk`0
Vh^j09Z:^@2JR[L0Vh^h00<0Vh^j0`2LS;/209f=_00309b<^`2MSK`0WXjm
0080WXjm01<0Whnn0:2@_`2QTL00Vi:m09fA_`2OSl00Xho20:6=_P2UU<00
Wi2g07ebU01MKWh0LhZH08FU/025[KD0P:fc08:_]@27/[T0RK6i0080QK2g
1P26/KP408Nb^@@0R;>j0P28/kT608Vd^P@0S;Fk202=][`608jg_@H0SkRn
0P2@]kh8096h_`H0T[W0:02C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kC
f039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0
5`3oool20?knoP<0oooo0`3no_h0803ooo/0o?gh0?gmo@37b<`0SI2I0:NZ
^@2k`=<0_/GH0<G=h03:dn@0d]WY0=WOk@3KhNd0g>3[0=[MiP3Ig><0[Znc
08R9R`33a<H0l?;a0>?Ui03Xj>H0fm_I0=kNg03If]@0fM_J08b?UP21Q9<0
S9:X09RR_@2S[/`0[;WI0P2`^mT20;6lfPD0/[gK00T0/kkL0;:mf@2b_MT0
/kkJ0;Bof`2a_ML0[KWC0:Zfc02U/LT00P2T[/T02P2S[LH0Xjk406I^P@20
RIX0SIR^09bV_`2/^=80]L3L0;K1g@2e`=`20;?1fa00]/7M00<0]/;J0;:n
f02e`M/00P2e`=`01P2g`]h0]/7M0;C0fP2`_=H0]L7K0;S4gP80]/;L0180
^<CN0;O3g@2e`M/0/koG0;W5g`2f`]`0]l;N0;G0g02iaMl0]<3J0;C0f02e
`md0//3J0;?1f`2c`]T0/;kH0;>of@2e`=`:0;K1g@0?0;O2gP2f`]`0]/;L
0;O3g@2e`M/0]l?K0;g9h@3:d^D0d]WY0=CHh@2BTiL0o_kn0?ooo@3oool0
oOko0480oooo000Q0?ooo`190?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cL
g03Lg=h0g=cJ0:f/ZP21OXD0PgjD09><Z`2QV;L0[JBo0:NR^@2LU[00TH^W
08AnV025P9H0XIf[0>o]lP3oo_`0OgRG089nS`2TXZL0oogo09fH[P25P9L0
N7B20>o^k03;b<l0`;g40>3Mi03lnOl0UiBK0?omo`2h]K`0X9fT0?ono`2c
/[P0]KBl0?omo`2d/[d0h=oW0>k]l`2:RHh0RHFP08Z6W@22P8h0i>;]0>;Q
j@2TXZd0oogo0:^X^@1nNY<0Ogb=0?ono`2o_kl0^k^i0?ono`2JV:D0/:fn
0;6`^01QGfd0A3mE05aFLP1[I8<0_kKA0?ceo`31^lT0Sgn/09J6/`0309^;
^P2;09V9]P2APZd0R7VR07]bT@2DSIl0oogo09nIY@1kLhX0oo[o0:fX[`3o
o_D0[ZNi09R@Y@3mmOl0UXfX071WPP1[Hg/0ooWo0;2Y^`2UYJD0oogo08B2
S`3oo_l0f=SJ0=?Ag02^[KD0oook06URP@3Dd=l0h]oV09>@V`2ARjD0M6f>
0;2[`@3oo?l0k^cj0>OXh01cL840J6>30=[Jg03OgNP0UI6Z0?gnn02QUk80
PgRH08UmX`23MZ40P7>N07IZT01dJHT0/JO20?gho`3Ug^h0U8VW09^?]`2T
Ul<0ZIc70:RI`02/W/40]Zo@0<Fle`3=aMX0NFn:05eAM`1lK9d0OVfS07YW
WP1aIIL0I5]h0?olo`2UX;@0GeJ107Q^X03EcnT0iNGU0?kjo`1UH7L0ooco
0>cXm`3mnOl0Y:2_05iFO@1LEGL0`;k30?7]oP1LF6T0Xj2Y0?omo`1^JGl0
Qh:H0?gjo`3SgN/0_;?>09N=/01PEg@0Z:6a0?olo`24NiH0ShB^09bG[@3o
ood0ViBe0:BQZP3ooOl0Heam0?ono02c[/@0M6NC079UT`1^H940LfJD06AH
P01UFWX0ShJK0>kVl`3kool0PGRE08UcY02DOKD0Th:f08Im[02?PK@0Th2h
08]o[`2APK80T7j^08ihZ@2>N:L0RG>Q07eZU`1lJiL0KF:006QMN`1/Hh80
M6Z=07E[T01iK9L0Pg:O08EbX00208ai/00>09V5^P2COk00VHNg09J6/`2C
Q[@0U8^h09R7^`2GQ[X0V8Ri09Z:^`2JR[T0VHVh09Z:]`2LS;T309^;^P80
W8bk102MSK`00`2NS[d0Whnn09j>_@0209f=_00B09j>_@2OSkh0WI2k0:6A
_P2QTL80XHo30::@`P2PT;l0Wi2i09nC^@1UL880KWn?07RDX01nY:d0P:fc
08:_]@24[kH0QZjf1`26/KP508Nb^@@0R;>j1`29];X00`2:]K/0S;Fk08be
^`0208be^`P0SKJl102>]kd708nh_P03092i_`2A^;l0TKRo00D0TKRo202B
^L0Y09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0O0?ooo`0Q0?gmn`3o
oo/0nocf0?oon`3WinL0][Nl09>EXP2UZ;/0^;o?0;k6d`36c=P0b/kI0<;5
cP2d]KX0XjBY09VHW@3?d=80o?go0?Oin03_lO00j^c[0>3Rg`3Lg]/0f]cI
0=_LeP3Lg=X0S8nD0823TP2:T:H0V::m0:Jac`2c_]h0/;_I00<0/KcJ0`2b
_M/00`2c_]`0/[gK0;>ng0020;:mf@0@0;>nfP2d_m/0/[kH0:jje02/^<h0
Z;C<0:Rbc@2Y/lh0Z;;;0:Nbb01XL8<0P8VJ092K/@2OZL80[k_E0;O2gP80
^<?O0P2fa=h80;O2gPP0^<?O0200^<?I0;W3g02la^40]l3M0;W2g`2j`n00
];kI0;_5h02i`^40^/?R0;W2h@2g`=l0^<7P0;[3hP2h`N00]l3O0;[5f`2j
a=d0^<;M0;c6h@2f`=/0^/CO0;S2f`2mb=h0]lON0;;2f@2faMX0^LSM0;O6
g@2iaMl0^LCP0;S3h@T0]l;N00l0^<?O0;O3g@2g`md0^<CN0;K2g02ha=`0
_/[R0<[Bi@3BfNT0e=SQ09:CU`3no_h0ooom0?ooo`3mo_l0@P3oool00240
oooo04T0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[Jg03KfmT0[JbZ
085nQ@23OY@0Thb[0::I^02^YL00ZjC609RB[P2DSj<0Q82>0<_:d03kn_l0
ooko0;^j_`21O980OWZ90;Vf_`3ln_l0hMoT07UfO`22OXd0`[gC0>c/hP3N
g>40_k_:0;Fa_`3OgMh0o_gi0;>`^@1mN8h0o_kn0?ooo`3inO/0jNS]07mn
Q03:bM40oOco08J4S`28QIX0R8FH08>0T@31_l`0ooko07]jO`3oool0_;bl
07mlS`25Pi40fMOR0>?Ri`2/[:h0ooko0:ZY[`2/Zk<0[:Ze05eKJ019AE@0
NWN20?Cbm`3oo?l0lN[j09N?Y`2@PJ`0UXNb0080Vhbg07`0VX^f09R9]02B
Pjh0RW^V07Y_VP1dK8<0o_Wm0;B`[`39`ll0kNGl079[O@3Vh>X0c/[K07A_
Q@3ooOl0[j^l075XU@1/I8/0i>7/0=GCf01bKXD0oO_o0<71``3mo?l0O7V:
0?;_o`3If=d0oOob06UTN`2e/[/0no[f0?ooo@3oo?l0YJ2d09:?VP3noO/0
gmgX0?Gbo`3RhNL0M7:00:bZ]`3no_l0PGn=0?glo`2g//P0OgVE07mgW020
N:40MFfB07afT03ThN`0ooko0?Wao`2_Y/<0WY:h09jA_`2SULH0ZIc80:JH
_02]Wl00]k3?0<JneP3AbMh0MF^405eAM`1mK:00P6nV07eZXP1`HYD0JEin
0>kVm@3CbmX0Fe=[06AJO02[X[l0ZjBf0:NR]P1`IiH0cLSN0?Gcm03UgoT0
o?So09jKY01OEHL0MFj?0?[eo`2RX:<0^[Vg0?Wdo`1IDGX0HE]g0?klo@3X
i?80h^3S0?ono`2>RYP0ShbG0?Wgn03oo_l0oogo0?olo`3no?l0[JVh08=n
U03ooOl0R8F@0>gYnP3=bm00KV2A07=VT@1[GhD0K62606QLPP2o]=80oo[o
0?onnP2fZ]00QgZU08=bYP2?OKL0TGni0960]`2?OK40Th6a0`2CPKD03@2B
P;@0T7jb08il/02<NZh0RWR/08IfY`25MJH0Q7BU08EeYP27MjP0RWZ[08in
[`2@P;400`2FQ[L209N7^0<0V8Ri00@0VHVh09Z:^@2JR[T0VXZi0`2KRkX0
0`2LS;/0Vh^j09b<^`0209b<^`<0WHfl1@2NS[d409n?_P80X92m0P2OSk`0
3@2PT;d0XI6n0:>C`02TU<40Vi6d05ICL01lRI`0NIZQ07JZZ01d[jd0PKBg
08R`^025/;L00`26/KP308Nb^@0308Rc^P29/[P0R[>i00H0R[>i102;];X5
08be^`P0SKJl1`2>]kd00`2?][d0T;Nn092g_P06092g_PL0TKRo202B^L0X
09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?kn
oP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0O0?ooo`040?knoP3oool0
oooo0?knoP80oooo00T0k>c/0<o?c`2/[:`0Y:BT09fMW@2NWYh0[jn_0<c<
c03[jn/00P3oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0fm[F
0=[JfP2<TIL0OhND08NBYP2IXkh0Yk;@0;2kf@030;6lf080/[gI2`2c_]X0
402__ML0ZKOB0;2ke`2X/ll0ZKG?0;:ne01RKGl0QY:R09VR`@2Z/m80_<GR
0<C;i`34bnD0a<cS0<G;h`34b^0P0<G=i0060<C;i@35c>H0aLgT0<C<h`36
c^<0bM7X0P34bnD@0<?>h0040<;=g`33c^00a<oQ0<?>h080`/gO00X0aM3R
0<OBi03JhN/0f=oY0=_Oj02?TYL0o?go0?gmo`3mno`0ookl@P3oool00240
oooo04T0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[Jg03KfmT0[JbZ
085nQ@23OY@0Thb[0::I^02^YL00ZZ3209nI]@2ET:H0RXJD0?omo`3Wi^`0
XZ6V07imP`1nNHd0Og^:0>?Pj`3floX0n_On0<?0b`1bKWd0ZZFi0?oonP3b
koH0^;C5092<VP3^k>l0ooom0;jka01lMhh0m_Kh0<W9b`2VYJX0n?Om0:BS
Z`2f]Kd0m_Co0:VW/P26Pi@0PGj?08F3T@3:b=D0no[o08J5R`3hmo`0d<oD
08R5V01oO8d0e]CO0>[Yk`2IV9d0o_go0=?Bf02FUId0YjBe05UDJP19A5/0
YZ6e0?olo`2bZk/0PWZB085gVP2@PJ`0UXNb0080Vhbg07d0VX^f09V:]@2C
Q:l0S7fX081eX01cJh<0oo[o0=C?d`3on_l0Z:2g07E]PP3GdMl0fMKQ06eY
NP3kn?l0`ko=06iVS@1`JHX0e]?J0>OUiP1WHG/0h=cZ0?Kdn@3/jO80M6n3
0;B_a@3jmoh0oooh06MPPP2]Z;`0oogo0:JS[P2AS:<0OGJE08V4VP3mn_l0
ZJJ_089mT@3imo`0/:bk0;Vea03ooOl0QH2D0>o/m@3QgN`0NWF907YdSP1e
Kh/0N7:<09bHZ@3mn_l0c<[;08n8VP2ARJ40U8R/09b?^`2SU/@0Y9O20:FF
_@2]Wl00^;7@0<JneP3@b=d0M6Z305eAM`1mK:00PG2W07m/Y01dI9D0M6V;
0<:icP3fk?l0LVJ<05eAP@1REh80HEMl06=LK01NDgd0clSJ0>[Vi@1MEFX0
_kW70?gho`1REh80JEn40;nfd@3RgN@0em?B0=K?h@1REh40H5Ih0?[doP31
_=80EU9P0=oKj@3Qg?<0O7N>0?olo`2UXK00GUQb065IKP3Uh>L0b<7C08Em
U03onOl0Xif[0;ngcP3hl_h0MFZ:06MJQ@1_HI80Jej:06MLO03on_l0i=c[
09J=WP1hK900NfnG08in[@2>OK<0RgVc09:1^02BP;@0UH>e095o/`0209:0
]00309>1]@2BP;@0TX2d0080T7jb00P0TH6b0920/@2@P;40TH6b09:2/`2D
Q;D0UXJg09N7^080UXJg0`2GQkP309R8^@@0VXZi0P2KRkX609b<^`80WHfl
1@2NS[d509n?_PD0X92m00/0XY:o0:>C`02TU<40Y9Rn08AoW`1OIg`0NYNO
06jNWP1f[:`0Pk>g08F]]@0408Ja^0<0Qk:i00<0R;>j08Zc^@2:/kT0102:
/kT608^d^P@0S;Fk1P2=][`808jg_@80SkRn1P2@]kh8096h_`X0T[W0:02C
^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool08@3oool00`3no_h0oOgm0?gm
o@020?ooo`030?Win@3no_h0o_kn00<0oooo0P3no_h04@3moOd0oooo0?gm
o@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_Kf`3Kf]H0f][J08bAU`1oQi@0Qi:V
09VS_P2W/]00/;_I0080/KcH0`2b_MT80;>nfP<0];oK0100/;kH0;2nf@2f
`Md0[k[F0;G1f`2`_=80GVUm09BO/@2[/lX0^l?J0<_Cj03AfN`0d]W[0=?J
k03Cf^X0d]WY803@fNX0203@f>/0d=WZ0=3Ij03@fNP0d=OW0=7Hj03@enL0
dm[Z403BfN/0403Af>X0d]W[0=;Ij`3BfN/0d=OY0=7HjP3Cf^`0e]g_0=gT
kP3YkOH0h>G[08jAUP3nool0oooo0?ono`3oooe20?ooo`008@3oool0=@3n
o_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0f][L0=_Kf@2][:X0PGj508=n
U02CS:/0XYVh0:jU`02_YLL0YIbi09F@Y`2@S9d0mo?o0<W6c`1nOHD0WIbT
08AoT`2KUjH0oogo0<2ma033`<L0lo3k09FAX025P9@0m??a0?omo`2RWK40
PGf<0<[7cP3oo_l0_;S6089mU03LfN00gmcS08>0R@3ooOl0_kc708N3T@3^
j_P0j^Kd0:>O[@21OH/0XIjY0?Odo`3]j_D0Q86<0080gmcU0180T8^O08b8
V@34`<h0o?Wo08f:T`32_lP0n?Gn0<K3c02VX[00HEe^08AoU@2XXkL0oo_o
07YcP`20N900WI>e0961[P2GQk@309^;^01o09Z:]`2EQK80Sgn/08=hX`1d
JhH0gmWU0?cfo`3dkOl0Ng:=06mWO`2g/<80oo[o06mXN03RgN<0fmGO07Q^
T01dJhP0^kJl0?chn@1_JHD0^;C50?omo`3=bMP0N7>:07agSP3oo?l0o?[k
06mUR02GSjH0ooco09NAW`1aJH40Mfj=071XP03onol0[jbc07IbP`3oo_l0
]k?409NCY03oo?l0U8nV0:FQ/03jm?l0bL?A07QbP01nMhL0[JJf09F?V`3m
mol0[ZV`07igQ`2WWkH0UX^[09fA^@2WV/H0Y9O20:RI`02aXlL0^;7@0<Jn
eP3?am`0LfV205eAM`1mK:00PW6X089_Y`1oKZ@0Jeb508EkU03hk_l0`KGI
06MKP`1TFWd0Zj:o0=C>g01iKi80ZjBf0?ginP1WH780[ZRd0?olo`1]HXX0
I5R6089hVP3lm_l0ooko0;F^`01XGHP0GU=k0=_Cj03Hd>L0IV1^0=O@h03o
n?l0JV600?kfo`2^Y[d0J5j106MNO@3HdN40j>3e069JL@3lm_l0]Jk007ac
TP3ekOl0em3P07E]Q@1[HH@0WiFg06aTO03ck?`0`K[:06eUNP2ERZX0PWJJ
08MhX`2?O[80TX6g09F4^`2@OK@0SWb`095o/`2BP;@0Th6e09B2]P0309F3
]`0309B2]P2FQ[L0UXJg0080UhNh102HR;T409N7^080V8Ri0P2IRKX309Z:
^@<0Vh^j1@2LS;/309f=_0@0WXjm1P2OSkh0402QTKh0X92m0:2@_@2PT;d0
XI6n0::B_`2STl00Y9C10:NH_`2[XL<0Feed0767U01_UiT0N:RZ08>`]@27
[KH308Ja^0<0Qk:i0P28/kX508Zc^@H0RkBj1@2<]K/508ff_0P0S[Nm0`2?
^;h5092g_PP0TKRo2`2B^L0X09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0
_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?oo
o`0P0?ooo`030?knoP3moOd0oOgm0080no_k00<0o_kn0?ooo`3no_h0203o
ool0403moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0fm[F0=[JfP2<TIL0
OhND08NBYP2IXkh0Yk;@0;6lfP2a_=P30;:mf@H0/kkJ0`2d_m/30;G0g00=
0;C2g02b`=/0];oK0:jie@2e`M/0/KgE06iiS@2PZkd0^lCC0<O@g`3CfnP0
f>3]0=SPj`020=[Qj`030=WPjP3Jhn`0f^?/01h0f^?/00P0fn?^0=WQk03J
hn`0fnC]0=[Qj@3Ih>H0gNCZ0=[Qia00gN7]00@0g>3/0=gQk@3Nh^h0gN7]
0P3Lh>`02P3Nh^h0h>C`0>O[m03/lOL0f]gR09RIWP3nool0nOWi0?ono`3o
ooe20?ooo`008@3oool0B@3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
f][L0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:jU`02[X/40ZJ2m0:2H/02G
TZP0al?D0?Gao`3Who40nOOo0:nZ_P3AcMh0mo?o09^HX`2IUZ40noOo0=gI
jP2>RId0gM[Q0?kjo`2FTJL0UI2T0:JS[P3kn?l0`ko>08n:X@3Ac]T0nOKo
0>gYm`3jm_l0];2o09>?WP2^Z[T0nOGo0?_ho`3[j?<0moCo0?kjo`2j]/@0
SXZH0=oKjP3jm_l0TXfS09bGZ`2i]LH0ooco0:^W]@2NVjH0jnSc0?kko`3_
k^`0jNO/0:^X/@1`JW@0n_Gl0>oZl@3ZhO80jMog09>3/02GQk@00`2KRkP0
O@2JR[L0UhNd09>3/026NjH0PWVH0<[2e`3onol0Ying07mfU@24NiX0^[7<
0?oho`28P9L0d/cJ0>cUm@2=PjP0PgZI0;:/^03oo?l0T8NV09B<Y03on_l0
_;C;085hU@24NiP0cLGJ0?olo`1lLhh0SHJF0?oko`3oo?l0oo_o0?K^o`28
PI40j>;/0?K`nP3Vg_<0ooco0;2X_@2ARJ40oo_o0<2ff025OI@0a[o?0?ol
o`3ajoT0jN?_0>KPkP25OXh0fmCV0?_co`3/i_@0l>Sm0:fR`02SUkd0Yi[5
0:BG`P2XVL80/:780;Rad037_mL0clOL075WP01MDGL0OVfQ08=bZ@24LJT0
Off[08AdY@1^H840ZIng0?ojo`3/hoH0jN;Z0?oln`3SfO40LFF=09fC[P3o
nol0eL_T0?ojo`3^iOP0LfJA07EWW01aI8l0akkC0?olo`2SVK40LVFC07EX
UP34^MT0oo_o0?omo`3on_l0akoF06mVP@3aj_`0eLgT075WR@1bII00]jg6
0?[`o`1^I7l0m^km0=36g`1aIHd0XYNi0?olo`3km_d0gm[P0?ojo`1lM8`0
/ZW40?gfo`3Pf^@0n^oo0:bQ``2:Nj@0Sgn^08mn/P2@OkD0UH:i09J3^P2C
PKD0U8:f0080UH>g0P2FQ;P209F3]`80UHFf102FQ[L209F5]P80UhNh0`2H
R;T309V9^P80VXZi0`2KRkX509b<^`<0WHfl0`2NS[d509n?_P<0X92o0P2Q
TKh0102PT;d0XI6n0:6A_P2RT[l20:>C`0080:FF_`2cYLT0Q82K06=`P01f
UIX0Mj2R07nX[P27[;@308Ja^0<0Qk:i0P28/kX408Zc^@H0RkBj1P2<]K/4
08ff_0P0S[Nm102?^;h4092g_PP0TKRo302B^L0X09>j`@0<09>j_`2B^Kh0
T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`0P0?ooo`030?gmo@3no_h0oooo0080oooo0P3moOd2
0?ooo`040?knoP3moOd0oOgm0?knoP<0oooo00l0oOgm0?Shn03alO40jNWY
0>;RhP3MgMd0fm_K0=_JeP3Jf]X0S96G0828U@28TjL0VZBo0:Rcd@2a_=X0
0`2b_MT30;>nfPD0];oK0`2e`=`20;K1g@0;0;;0fP2a_mT0^<?O0;O2gP2e
`=`0]L7K08B?Y@29U:P0WJJe0:>/^`2Z/L400P2[/l020:bb_P030:Z`_02[
/kh0Zk>n01h0Zk>n00P0[;Bo0:Zb_@2]/kl0[[C00;:f`@2d^Kl0]kc00:6U
Z100`<3800<0_ko70<30b030`<P00`2o_lL02P30`<P0`/;:0;o2a`2o`/L0
a<G:0;^l`03oool0n_[j0?ooo`3oo_a20?ooo`008@3oool0B@3no_h0n_[j
0?Cdm03]kNd0iNGU0=oOg`3Lg=`0f][L0=_Kf@2][:X0PGj508=nU02CS:/0
XYVh0:jU`02aY/@0[:?00:VP^`2NUK00V92X0<k9g@3Fd^<0aL7@0::J[`3:
`]L0c<GG09fFZ02DSIl0^K;40<_3f02_Yk`0_;G50=K>h`2NUZh0YIfd09nH
ZP3?b=P0`;S=09fE[@2d/<40b<CE0<_7f02j]/L0XYfa0:6L/02GTZH0XYfa
0<W5d`3Pg>X0fmOV0<6mc02NVZ/0XIb`0;Vdb03>bMd0Y9ne0:2K/@2_Z/00
dLcP0:bX^@2QWJ`0[JVg0=GBg@3Wi^80cL_@092:V01ZHg<0R8:@0<_3dP3D
bn00/JO209F5/P2HR;D0102KRkP0NP2IRKH0UXJc08j1[@2;Oj<0_K;@0=K<
i`2<PJ40S82T08QlX02IS[00`[SC09F9[`2^Xl40`kSF08QkZ@29OJD0UhfV
0<:ge@2FS:h0QgjM0=O>j`2VWK`0QgfP08j4YP2FSJP0gMGZ08MnV`2<Q9/0
_KK80;ffaP2n]//0`k_B07mgSP2m]/P0_;G50<RofP2[Y;@0SHBO08b3XP34
_=<0[jC<08QoWP29P9/0ZZ:j0=C<h`3Oen`0a[kE08ElU`2LTk80`;KI0=gF
j03=aM`0Vi2^0:2D^02RU[h0YY[20:ZKa02]W/D0^;7@0<Noe`3>a]/0L6Io
05eAM`1oKZ80Pg:Y08IcZ`21KJ`0P6nU07m`V@1kKHh0RWfI0<:icP3Rf^L0
]Znf07mcU`1ZG8d0Sh:]0;N/cP2i[M40]Z_=07eaU@1mKj@0NV^R07AVU`2<
PJ<0e<_N09R=[@1hJYl0NVbQ09R<]02eZl@0^[720:BK[P1hKHd0NfnC0:nT
`P2]X/80OG2K07AVV@2OU;H0_K7E07mcU`2ZX;P0[jC407maXP1eJ9<0RH6H
0;jgb@3Ke>@0a[kE075WR@22Mil0/ZS:0=;:hP2l/M<0U8R^08amZ02DQ;<0
TH2d0960]P2EP[T0TWng102EPkL0102FQ;P0UH>g09F3]`2EPkL509J6]`<0
UhNh0`2HR;T309V9^P80VXZk0`2KRkX309b<^`D0WHfl0`2NS[d509n?_PD0
X92o1@2QTKh02`2RT[l0Xi?00:>C`02WV<<0/:370;2WaP1QIWX0LhVD07FH
W01iX:D0Q:Va0080Q[6h0`27/[T308Rc^P@0R[>i102;];X608be^`H0SKJl
202>]kd408nh_P@0T;Nn202A^;l409:i`300Tk[100`0TkZo09:i_P2B^L00
W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo0240oooo0P3no_h40?ooo`030?_kn`3lo?`0o_kn00<0oooo
0180oOgm0?clo03oool0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=_J
eP3Jf]X0S96G0828U@28TjL0VZBo0:Rcd@2b_M/20;:mf@<0/kkJ1P2d_m/2
0;G0g0<0]/7M00`0//7H0;?1f`2d_m/0^<?Q0;>nfP2g`md0Xjg608nJ/023
Rj00QHfR08J>X`24S:4208F;X@80QHbO8024S:402025SJ00QHbO08J<XP2:
Sj<0UIRY09bP[02JWJ@0JFaa402i^;d0102h]k`0^KRm0;Vh_@2i^;d20;Rg
_0060;Vh_@2j^Kh0]kRl0;Vj_P34aLL0i>CV0P3oool00`3oood0o_kl0?oo
o`110?ooo`008@3oool07@3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
f][L0=_Kf@2][:X0PGj508=nU02CS:/0XYVh0:jU`02cZL@0[J;00;6Xa@2]
Y<<0Yijk0:6H/`2WX[P0YZ6e0:>K/`2VW[H0Y9bd0:>K/`2WWkL0YYjf0080
Ying02X0Y9bc0;2X`02RVK@0[JFm0:>K/`2VW[D0Zj>k0:NO]`2ZX[X0Y9bd
0:fU_02WWkH0ZJ6h0:nW_P2[XkX0ZJ6h0:JN/`2ZX[L0Y9ba0:VQ^02]YK`0
/Z[10:FM]@2_Ykl0/JW10:ZR^P2/Y;`0[ZJn0:VQ^02g[l@0]:fm0<Bnc035
_lT0Lf^005iELP1kLI<0PgRJ08b1X`2FR[80S7n]09R8]`2IRKP209^;^P1l
09b<^`2KRkX0VXZi09V9^02ER;@0S82X09>7[@2?PjL0TXJ/09>7[`2>PJ`0
THB_0965Z@2CQKH0S82X09N;/@2=Ok@0UhZh09B9Z`2@Pjh0T8BX09:6ZP2J
S[@0TXJ/09B8/02AQJ/0ThRZ09V>[P2BQK<0SX6/09V=/`2>PZH0UHV_09V=
]@2=PJT0V8bd09R>Z@2HS;80UH^T09B8[02LT;H0VHj/09V<^02ISK40WI6g
09B8[02AQZP0W96c09V>/02CQjd0VXjf09V<]`2MU:l0WIBa09fB]02ZW/@0
Y9S00:RLa02[W<D0[Ik50;Vbd@38`=P0c/KK071VO`1MDGL0OfjR08AcZP28
MJd0QgB/085^Y@23LZH0O6^O07MVVP1nKYl0NVfK07a_V`24M:D0NFRO07i]
Y01jJY/0NVZI08EeXP27MjP0PW2/08Ie[020KjH0P72M08]mX022Lih0OF^W
07aZY024MJ00OW2Q085eW@23Mil0N6ZO08Ig[P24MjD0QGNX07m_[@28Mjh0
QWNP085aWP25MJ@0PG>F08enZ@22LJP0QgNV089fW022MJ<0PG:Y089dZ@2;
OZ`0NFbH07maY029N[D0QGRS08YmZ@2@P:d0T82_09>3]02EQ;P0Th2g095n
]@80U8:f0P2EPkL409J4^080UhNh0P2FQ[L0102GQkP0V8Ri09V9^P2IRKX2
09R8^@80VHVj102JR[/209^;^P<0W8bk1@2MSK`309j>_@<0Whnn1P2PT;l2
0:6A`0<0XI6n102RT[l02@2STl00YIS40;2Ob@2j[<d0LgB906QjQP1cU9T0
NJ2U08:Y/00208Ja^0<0Qk:i0`28/kX308Zc^@D0RkBj1@2<]K/608ff_0P0
S[Nm1@2?^;h3092g_PP0TKRo1@2B^L0`09>j`@0<09>j_`2B^Kh0T[W009c1
a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0
oooo0?ooo`0O0?ooo`030?gmo@3oool0oooo0080o?cl0`3moOd30?ooo`80
o_kn103oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0fm[F0=[J
fP2<TIL0P8RE08RCY`2JY;l0ZKCB0;:mf`040;>nfP<0];oK1P2e`=`30;K1
g@080;?2f@2e`md0[k[F0;>ng02d_md0]L3L0;W3gP2b_=D20;G1f`040;Fo
fP2d_]T0];gJ0;Nnf`80^;oL802f`=/0202g`MX0]/3K0;[1gP2oa>40c=3Y
0=SKkP3De^80T9>J603oo_l0203no_l0oooo0?Gem@3oool0o_kn0?ooo`3k
noT0ooom@P3oool00240oooo02<0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0
g=cL0=[Jg03KfmT0[JbZ085nQ@23OY@0Thb[0::I^02^YL00/jW40;FZb02b
YlL0Zj730;6Wb@2ZXKh0ZJ2k0:RS^@2^YL80ZZ6n0;6Xa@2bZLP0[:?20:nV
``2]Y<40[:?00;2Wa02_Y/<0Z9nj0;J]b0020;:Ya00@0:bS_P2`Yl80/j[5
0;2W`P2^YL00]:_60;R_bP2cZ/D0[jNo0;:Z`P2cZ/L0[ZG20;:Ya02dZlH0
/JS30;B[aP80]jk90140/j_30;N^b@2dZlP0^K3=0;J]b02j//T0bL;B0<[4
dP3GdMl0Mfn705E;L01lKiX0RWfX09>6/P2DQ[L0VHRo09Z:^@0209^;^P<0
W8bk0P2KRkX0N@2HRkL0W8nk09>6/P2BQK00Wi:m09R;]`2CQ[@0VXfk09N8
[`2NSL40VHVf09R9/P2LRkl0UhNf09b>/P2GQkH0V8bb09^?]`2LSk/0V8^g
09b?^`2PTkh0VXjf09F9[`2KSL00UhVj09R;^@2IS;P0W8nj09F8]02MT;h0
V8Zk09^?]@2FR;T0XIJh09jA_@2PTkl0W96c09^=_P2OTkT0VHfe0:6E_@2R
U[h0W8nj0:6D_`2XW<@0Vhne0::F_02LT[D0XINl0:VM``2WVl<0XIFm0:BH
`02ZVl80/jC;0;Vbd@39`MT0clOL071VO`1NDWP0OfjR08=bZ@28MJd0S7V`
08Md[028M:l0OVbX08Me/`24L[00P6j/085a[`21L:@0QGB[085_Z`28M[00
Rg^/085aX027MZd0QG>_08EdZ025Ljd0RgZa07e]W026MJ/0SGZj08Id/026
Mj80Q7:`08Uh[025M:P0QgBd08Qe]@22LJL0R7N^08ej_026MJ`0Pg>P08ak
/@2:N;80Rg^X08em[P23LJd0S7b[08]j/026M;00Sgbl08=a[@2<Njl0T82_
091o]@28M[@0S7jc09:4]`2?O[80SGb`09B3]`2EQ;P0TWnf09B1^02DP[H0
0`2EPkL209J4^080UhFi102FQ[L209N7^080V8Ri0`2IRKX309Z:^`80Vh^l
0P2KRkX209b<^`H0WHfl0P2NS[d409n?_PD0X92o0`2QTL000`2QTKh0XY:o
0::B_`050::B_`090:2D`P2^WlX0]ZK:092<X`1QLGh0LI2E07JMXP20ZJl0
Q[6h00<0Qk:i1028/kX208Zc^@H0RkBj102<]K/608ff_0P0S[Nm1P2?^;h2
092g_PP0TKRo1P2B^L0`09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H
0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0O
0?ooo`030?[jnP3oool0oooo00D0oooo103no_h50?ooo`0?0?gmo@3hn?P0
lO7a0>WYj@3Rh^80gMgM0=_Kf`3Kf]H0f][J08bAU`20R9D0R9>W09^U`02Y
]=80/[gK00<0/kkJ0`2d_m/:0;G0g0080;;1f02e`md0]l;N0;O2h02ia>80
]L3N0;Jog02g`M`40;?1g0040;G0g02f`Ml0]/7O0;K1gb00];oM00P0/l7K
0;>nfP2g`=l0_/GR0<[@jP3Cf>/0eMWR08fAU1P0o_kl00P0o_cm0?ono`3l
n_/0oooo0?_kn@3oood0oOgk0?oooD80oooo000Q0?ooo`170?knoP3jn_X0
m?Cd0>g]k@3UiND0gmoO0=cLg03Jf]`0fm_I0:f/ZP21OXD0PgjD09><Z`2R
VKP0[ZG00;BZ``2aY/@0[:710;R/d02]XlH0]Jc;0:nV`@2bZ/80[jK50;F/
b`2_YLL0/jW<0;6WbP2^Y<H0/j[90;:Yb02cZL/0[jK50;R_c02`Yl@0/ZW6
0;:Yb02cZ/L0/j[50:nVa@2g[//0]Jc90;ZacP2]Y<40]Zg80;V`b`2f[LP0
]:[<0;F[c@2h[lh0]Jc;0;^bc`2e[<T0^:o:0;J]b02k/l/0]Zg80;V`c@2h
[lh0^k;?0;fec037`=80dlgK0=OBf01hLH40IUel081dVP2?PjT0UHV_0:2@
_@2GQkP00`2KRkX509b<^`0`09J9]@2GR[P0VXfk09^>_02KS[X0V8^g09b>
_`2JS;l0X9:f09V8_02QT[d0VHZa0:>Ca02GR;<0XI>f09n?_P2LSKH0XI:m
09V9^02STl@0WXjm09f=^P2NSkX0XiBo09V<]`2VVL@0Vhng0::F_02LT;@0
XIFi09nC^@2PTkh0XY;10:NFc@2NSkP0YYK709f=_P2XVL00Xi;60:>D_@2T
V;h0WY:j0:>F`@2QU<00WY6l0:>G_`2WVkl0Y9Vi0P2UV/@03@2VVL@0XYG0
0:bPb02[WlL0Z9W00;2RaP2i/]40b/;J0<o7g01`IWl0GU9h07m^XP23LZT0
0P28MJd0=`27Ljh0QG6^08ij]@23LZP0Q7BU08QhZ@26MZL0QWBX08UgZ`27
Ljh0QW:]08EcX`29MjL0R7F]08Ue/02<NZ`0RWJc08Ib[`2=N[80R7Ba08ag
_02;Mk@0S7^W08ek]`28N:T0RWZ[08mm]`2<N[@0SGf/08UiZ02;NK<0SGZb
09:1[P2<N;<0RWFf09:0]02>Nk<0SGVf091n[P2>N[T0TX2d08mnZP2AP:X0
Sgf]08ek[@2@Oj/0TH6V08am]P2?P;T0Th:i09B3^@2CP[H0TH2d09F3]`2G
Q;/0202FQ;P209N7^0H0V8Ri0`2IRKX209Z:^`<0Vh^l00@0Vh^j09b<^`2L
S;/0W8bk0`2MSK`00`2NS[d0WHfl09j>_@0209j>_@<0Whnn1@2PT;l40:6A
`0P0XY:o00T0W9?20:fNb@2iZLd0XYje06AbO`1[RXl0KIJJ07VUZ026/KP0
0`27/[T308Rc^P0308Vd^`2;];X0RkBj00D0RkBj1@2<]K/408ff_0L0S[Nm
202?^;h00`2@^Kl0TKRo096h_`05096h_`P0T[W0<@2C^/40302C^[l0T[Vn
09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo
00<0oOgm0?ooo`3oool08@3oool01P3no_h0oOgm0?ooo`3no_h0o?cl0?kn
oP<0oooo103no_h20?ooo`0?0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_K
f`3Kf]H0f][J08bAU`20R9D0R9>W09^U`02Y]=80/kkL00<0/kkJ0P2d_m/;
0;G0g0080;;1f02`_]P0^/GQ0;:mf`2c_]`0]/7O0;Fnf`2f`=/20;71fP04
0;;2f`2c`m`0]<;M0;?1g080//3K802c`md0202eaM`0//3J0;S3g`2ob>D0
bM7X0=3Fi03HgN<0T9JD403oood70?kno0030?gmn`3noO/0oOcj0080ooom
00@0o_kl0?gmn`3no_`0oOgk@P3oool00240oooo0100o_kn0?[jnP3dm?@0
kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_
Y/40/JS71`2bZLP00`2bZLH0/j[70;>Za`060;>Za`L0]:_80`2e[<T20;J]
bP<0]jk;0`2g[/T20;R_bPH0^K3;00d0^[7<0;bdc030^=00bL7I0=;:hP3B
c]`0NgN805mFL@23NIh0T8>_09B7]@2HR;T0Whnn0080Vhbg0P2LSKP409b<
^@0309b;^02LR[X0W8Zj0080W8bm00<0VXZi09V<^02MT;`00P2KRk`00`2L
S;/0WHfl09j>^`0209n?_00909n@^`2PT;d0WXjk09n?_02PTK`0Wi2k0:2A
_02QT[/0Wi2i00<0XI:m0P2RTkh40:>D_`<0Y9G00`2UU/40102VUl80YYO0
0:JG`02VUl020:NH`@<0Z9W20140YiS10:VJ``2XVL80Z9W20:ZKa02YV/<0
Zic50;6Rb`2i/<d0c<CK0<k5f01]Hg`0HU=j07a[W`24L:/0RGF`08Md[007
08Qe[@0908Uf[P2:Mjl0RWN_08Yg[P29MZd0R7JZ08UgZ`2:N:X0RWV_0080
RGR^00L0RgZ`08Yi[@29N:`0RgZ^08im/@2>Nk<0SGZb00<0S7V`0P2=Njl0
102<NZh0SW^b08ik/P2>Nk8208ml/`<0T7fd00@0T7jb095o/`2AOk<0TGnc
0`2BP;@209>1]@<0U8:f0`2EPkL00`2FQ;P0UH>e09J4]P0209J4]P<0UhFg
00@0V8Jh09N7^02GQkP0UhNh0P2HR;T309V9^P<0VXZi0P2KRkX609b<^`80
WHfl102NS[d709n?_P030:2@_@2QTKh0XI6n00D0XI6n202STl00402ST[l0
ZIg30;j`d@2fY/00JVak06N4RP1_UY/0P:6X08B]/`2:/kT0RkBj08Vb^02:
/kT0RkBj08Zc^@2<]K/408^d^PD0S;Fk1`2=][`408jg_@@0SkRn102@]kh4
096h_`03092g_P2A^;l0TKRo00D0TKRo>02C^/40302C^[l0T[Vn09:i`02L
`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool06P3oool20?knoP<0oooo1@3moOd30?knoP@0oooo103no_h0
3`3oool0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=_Jf03Jf]`0SI:H
0828U@29U:P0VjFn0:Zfd0020;>nfPL0];oK>02e`=`0202e`MT0]/;L0;K1
g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo00l0o_kn0?[jnP3d
m?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I
^02_Y/401P2bZLP20;>Zb@H0/j[7202dZlP40;F/b@<0]Zg:0`2g[//20;N^
b@<0^:o:1P2i/</02`2j/L`0_;C<0;ngc`38`=P0d<SP0=C@gP1dKh<0Jf9m
07idU`2AQ:l0UHRf0080Vh^j102KRkP0702JR[L0VXZi09Z:^@2JR[T0X8jn
09j<_02LS;/0WXjm0::B_`2RUL00XiNo0:6E^`2ZW/H0ZIg50:RLa02VV/80
Y9S00:6E_@2PU;`0Wi>k0:6A_P2LS;T0WXjk0:>D_`2QT[d0WXnj0::C_P2V
Ul820:6B_@<0XY>n0`2SU;l40:BE`080YIK10P2VUl820:JG`0<0YiS1102X
VL803`2YV/<0Z9W20:VJ``2ZVl@0ZI[30:^La@2aX//0^k;?0<S0e`3Ab=/0
KfEn06AEO01kJYh0QG:Z08Qd[`0608Qe[@80RGJ^00D0R7B_08Qe[@28MJd0
R7F]08Yg[`0208]h[`0:08Yg[P29MZh0RGJ^08Yg[`2<NK40SGZb08]h[`2:
Mjh0RGJ]08ai/@80SGZb00D0S7Va08ai/02=N[40SW^b091m]00208ik/P<0
Sgbc0`2@OK@4095o/`80TX2d0P2CPKD409B2]P80UH>g0P2FQ;P409J4]P80
UhFg0P2HQ[P209N7^0<0V8Ri0`2IRKX209Z:^@<0Vh^j1@2LS;/309f=_0<0
WXjm1P2OSkh20:2@_`H0XI6n0P2RT[l80:>C`00@0:>B_`2YWL<0_[3A0;j^
b01]Kgh0I8>806bDUP1lWJ@0Q:fc08Zc^@2;];X0RK:h08Zc^@2;];X0R[>i
08be^`@0RkBj102<]K/608ff_0H0S[Nm102?^;h4092g_PX0TKRo0P2B^L0h
09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?kn
oP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0I0?ooo`H0o_kn4@3oool0
3`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0fm[H0=[Jg02=TYP0PHVF
08VDZ02KYKh0Z[K@0;>nfP060;BofcX0]L3L00P0]L7I0;K2g02f`Md0_LOR
0<_Cj03CfNT0em[S096BUV80oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]
k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD09><Z`2RVKP0[jK1
00D0/ZW80`2cZ/T50;>Za`L0]:_81@2e[<T30;J]bP@0]jk;00@0]jk90;R_
bP2h[lX0^:o:102i/</04@2j/L`0^K3;0;Zac02k//d0^k?;0;jfcP35_MD0
c<CL0=3<f`27PYH0H5Mb08EkW@2?Pj/0UHRd09j>_@2IRKP0WXjm00@0WHfl
0P2LS;/02@2MSK`0VXZi09n?_02SU;l0Y9Fn0:FI_`2bYlT0^Zo?0;R]c@02
0;V^c00?0;Z_c@2i[/h0]J[<0;2Ua`2ZW/80Yi^o0::C_P2VUl80Z9W40:>D
_`2OSk`0XI6n0::B_`2NS[/0XI:m00<0XY>n102SU;l30:BE`0<0YIK10P2V
Ul80102VUl00YiS10:NH`@2WV<450:RI`P0?0:ZKa02YV/<0ZI[30:^La@2Y
V/<0Zic50;6Rb`2n]M@0a;cD0=C;h01_IGh0IEIm07]ZWP26Lj/0QgB/00D0
R7F]0`29MZh06@29MK00R7B_08Qd[`29MK00RgNb08ah/`2;Mk80RGF`08mj
]@2=N;<0RWF`08Ud[`2;M[40SWVd08mj]@2>NK@0S7Va08ik/`2?O;@0SW^c
08ej/P2<NK40SW^c08ml]02>Nk800`2?O;<4091m]0<0TGnc0`2BP;@209>1
]@<0U8:f0`2EPkL209J4^0<0UXBf0`2GQKL209R6^0@0V8Ri0P2IRKX209Z:
^`0409Z:^@2KRkX0Vh^j09^;^PD0W8bk0`2MSK`409j>_@@0Whnn102PT;l5
0:6A_P<0XY:o202STl00302RTkh0ZIo40;jac`35]m00KG1o0660P`1YTY@0
NibS08B]/`2:/kT0RkBj08Vb^080RkBj00<0R[>i08be^`2;];X00P2;];X5
08be^`D0SKJl1P2>]kd508nh_P<0T;Nn2P2A^;l309:i`3P0Tk[100`0TkZo
09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h2
0?ooo`030?gmo@3oool0oooo01T0oooo0P3no_h20?gmo@80o_kn203oool2
0?knoPL0oooo00h0oOgm0?Shn03alO40jNWY0>;RhP3MgMd0fm_K0=_Jf03J
f]`0SI:H0869UP29U:P0W:Jo0:Zfd0H0];oK>`2e`=`0202e`MT0]/;L0;K1
g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo00l0o_kn0?[jnP3d
m?@0kNg]0>GUi@3Ogml0g=cL0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I
^02_Y/40102bZLP40;>Zb@@0/j[71`2dZlP50;F/b@<0]Zg:0`2g[//20;R_
c0<0^:o:0`2i/</50;Zac00=0;^bc@2k/l/0_KG=0<:jdP38`=P0al?D0:nZ
`01=A5l0QgjM08n3Z@2DQk80WXjk09Z:^@0309^;_00M09b<_@2LS;/0Vh^j
09b<^`2MSK`0Whnl09n@^`2XW<80]jc>0<2ed`36_]H0c<CL0<o7g`3>amL0
c<GG0<W1eP34_=<0_kO?0;^bc@2g[//0]Jc;0;:Vc02VV/00WI6i09jA_02Q
U;l0XIC009nB`02NTKl00`2RTkh30:>D_`@0Y9G00`2UU/430:JG`P<0YiS1
0`2XVL830:VJ``0=0:ZKa02YV/<0ZI[30:^La@2ZVl@0Zic50;2QbP2m/mD0
a;_F0=77g`1/HWd0I5En07e/X00208Md[0@0R7F]1029MZh408Yf/@0>08]g
/P2;Mk@0RWJc08Yf/`2;MZl0SGRa08eh/`2;M[40S7Nb08mj]@2>NK@0RgJa
08ai/@2=N[8208ik/`0408ml]02>Nk<0SWZe08ij]@<0Sgbc0`2@OK@2095n
]@80TGnc0`2BP;@309>1]@80U8:f0`2EPkL309J4^080UXBf0`2GQKL309R6
^080V8Ri0`2IRKX309Z:^`<0Vh^j0`2LS;/509f=_0<0WXjm1@2OSkh50:2@
_`@0XI6n102RT[l80:>C`00<0:>D_`2/X/L0_[7?0<Vke01]L7l0Ggj106RA
T`1kWZ@0Q:fc08Zc^@2;];X0RK:h0`2;];X00`2<]K/0RkBj08^d^P0608be
^`@0SKJl1P2>]kd608nh_P80T;Nn2P2A^;l409:i`3P0Tk[100`0TkZo09:i
_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo01T0oooo1@3no_h00`3oool0o_kn0?knoP030?gm
o@<0o?cl0P3no_h70?ooo`0>0?gmo@3hn?P0lO7a0>WYj@3Rh^80gMgM0=_K
f`3LfmT0fm_M08fBV021RIH0RIBX09bV_`2Z]]050;Bofc`0]L3L00P0]L7I
0;K2g02f`Md0_LOR0<_Cj03CfNT0em[S096BUV80oooo000Q0?ooo`0?0?kn
oP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kfmd0fm_I0:f/ZP21OXD0PgjD
09><Z`2RVKP0[jK100@0/ZW8102cZ/T40;>Za`@0]:_81@2e[<T50;J]bP<0
]jk;0`2h[l`20;R_bP<0^K3;0`2j/L`0102k//d0^[7<0;Zac02k//d20;bd
c00=0<2hd034_=@0a;oE0<G0eP1XH7P0K6>009:6ZP2ERK40W8bi09b<^`2L
S;d0Vh^l09b<_@0209f=_00<09^;^02MSKX0X92m0:JJ`P2^X/H0^Zo=0<S0
f03Bb]l0c<GG0:bX^@2=RIX0N79n0P1fL7h03@1jLhD0QWjC09N?YP2WWkL0
/Z[20;BYb@2fZld0/JG90:JJ`02OTk/0Wi:m0:2C_`2QU<800P2RTkh30:>D
_`<0Y9G00`2UU/430:JG`P80YiS30P2WV<430:RI`P<0ZI[30P2ZVl@00`2Y
V/<0ZY_40:bMaP020:^La@080;2QbP2h[]40`k[G0<Voe`1_IH00HE9k07m^
XP27M:`508Qe[@@0RGJ^0`29Mk405@28Mjh0RGR_08ak/@2AP;H0U8>i09J4
]P2IQkT0VhVk09R6^P2FQ;P0UH:i09B1^02AO[D0T7jb08il/02;N:l0S7V`
08ml]02AO[H0T7fe08mk]P0208ml/`<0T7fd0`2AO[D309:0]0<0Th6e0P2D
P[H309F3]`<0UXBh0P2GQKT309N5]`<0V8Jh0P2IQkT309V9^P<0VXZk0P2K
Rk`209^;^P<0W8bk1@2MSK`309j>_@<0Whnn1@2PT;l30:6A`0@0XI6n102R
T[l80:>C`00<0:>D_`2^Y<L0`;GC0<Jhc`1]LGd0GGn106RBT@1kWZ80Q:fc
08Zc^@2;];X0R[>i0`2;];X708be^`H0SKJl102>]kd608nh_P80T;Vo1P2A
^;l209:i`0@0TKRo102B^L0h09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0
_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?oo
o`0M0?ooo`80o_kn0P3lo?`00`3kno/0n_[j0?Win@020?Win@040?[jnP3m
oOd0oOgm0?knoP@0oooo0100o_kn0?ooo`3moOd0n?Sh0?7al@3YjNT0h^;R
0=gMg@3Kfm/0g=_I0=_Kg@2=TYP0PHVF08ZEZ@2LY[l0Z[K@1@2d_m/l0;G0
g0080;G1f@2f`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2ATYIR0?ooo`008@3o
ool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_Kf@2][:X0
PGj508=nU02CS:/0XYVh0:nV`@030;:Yb0D0/j[90`2cZ/L50;B[b0@0]Jc9
102f[LX40;N^b`<0^:o<00<0^K3=0;V`b`2i/</00P2i/</30;Zac080^k;=
00<0^[7<0;^bc@2l/lh00P2l]<`06`2n]/h0`KWA0<G0e`2n^M00YYjf05I=
J02=PZ80ThN]09V:]@2MSK`0W8bm09^;_02LS;/0WXjk09f=^P2LSKP0XI:m
0:NH`@2^Y<H0`k[G0=?;hP3<aMD0Z:F`07ijR01_JgX0O7R908=oS@0208B0
SP0=089nS@1nNX/0MW6506mZOP1[IWX0Rh6J09fC[P2/XKl0[Z?50:ZN`P2U
VL40XIBo0:6D`0040:>D_`<0Y9G00`2UU/430:JG`P<0YiS3102XVL830:VJ
``80ZY_400l0Zic50:ZKa02ZVl@0[Ik70:bMaP2[W<D0[j390;BZc`30]m@0
`KO@085fU01LCGH0OFbP08IcZ`29MZd00`28MJd508Uf[P0H08Qf/029N:l0
RWV_08el/02CPk80Vh^h0:FF`@2[W<L0[j750;6Rb@2cY</0/:7:0:bMb02V
Ul80XI6n09j>^`2LR[X0UhFg095o/@2>O;00Sgfa091m]02@OKD0Sgbd102@
OK@3095n]@03099o]P2BP;@0TX2d00<0Th6e0`2DP[H209F3]`<0UXBh0`2G
QKT209N5]`<0V8Jh0`2IQkT209V9^P80VXZk102KRk`409b<^`<0WHfl1@2N
S[d309n?_PD0X92o102QTL030:6A_PD0XY:o202STl00302RU[h0/:W;0<Nm
f02m/LL0Jg5m0622P`1UTI00O9nS08F^]02:/kT0RkBj08Zc^@<0RkBj1P2<
]K/608ff_0D0S[Nm1@2?^;h3092i_`D0TKRo0`2B^L03096h_`D0T[W0>02C
^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool05`3oool20?knoP80oooo00P0
o_kn0?gmo@3lo?`0no_k0?Win@3hn?P0m_Kf0?Gem@80m?Cd0P3emOD01@3h
n?P0nOWi0?[jnP3lo?`0oOgm00<0o_kn00l0oooo0?gmo@3hn?P0lO7a0>WY
j@3Rh^80gMgM0=_Kf`3LfmT0fm_M08fBV021RIH0RYFY09bV_`2[]m40102d
_m/m0;G0g0080;G1f@2f`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2ATYIR0?oo
o`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_M0=_K
f@2][:X0PGj508=nU02CS:/0XYVh0:nV`@020;:Yb0H0/j[90P2cZ/L60;B[
b080]Jc91P2f[LX30;N^b`<0^:o<0P2i/<d30;V`b`<0^[7<0`2k//d09@2j
/L`0^k;=0;fdc`2m]Ld0_;C<0;fec@30^=00`[cF0;Zec032^]80MVj6079W
Q@2;Oj<0V8Vd09j>_@2LS;/0Vh^j09b<^@2NSkX0Wi2i0:6B^@2/WL@0]jW=
0<JneP3Gcn@0_;K408F2R@1dLGP0OW^408>1SP23P940RhNH08f9VP2?Ri`0
TXjO09>?X02DT:400P2CSj00201lMHL0MFf207YbR@2CRZD0ZIo10:VOa02S
V<00Y9W30`2SU;l30:BE`0@0YIK10P2VUl840:NH``<0Z9W20`2YV/<20:ZK
a080Zic500h0ZY_40:^La@2^WlP0[9g60:^La@2_X<T0/JK>0;V`c`2l///0
WiBb05M8L@1gIYX0QG:Z08Uf[@80R7F]1P29MZh0602:NK00S7^a09:1]@2M
SKX0Zic50;NYc030/]<0`kKD0<Fme@32^]80`;OB0;jedP2k//l0]Jc;0:jT
aP2ZX<80Xi:n0:6@_@2LRkP0V8Jf09B2]02AOk<0Sgfa08ik/P<0T7fd0`2A
O[D2099o]P80TX2d0P2CPKD409B2]P80UH>g0P2FQ;P409N5^@80UhFg0P2H
Q[P409V7^@<0VXZk0`2KRk`209b<_@<0W8bk0`2MSK`509j>_@<0Whnn102P
T;l60:6A`080XI6n1P2RT[l80:>C`00@0:NK``2e[]00c/CO0:nS^@1VK7P0
HH>406JBT@1nXJD0QJjd08^d^P2<]K/0R[>i08^d^P2<]K/0RkBj08ff_0@0
S;Fk1P2=][`608jg_@@0SkRn102@^Kl4096h_`@0T[W00P2A^;l609:i`3P0
Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo01L0oooo0P3no_h20?ooo`08
0?gmo@3kno/0n?Sh0?KfmP3bl_80lO7a0>k^kP3/k>`20>_[j`090>g]k@3^
k^h0lO7a0?;blP3emOD0n?Sh0?_kn`3moOd0o_kn0080oooo00h0oOgm0?Sh
n03alO40jNWY0>;RhP3MgMd0fm_K0=cKf@3Kfmd0SY>I0869UP2:UJT0W:Jo
0:^gd@<0];oK?P2e`=`0202e`MT0]/;L0;K1g@2man80bm?X0=?Ij@3Gf^<0
TI:FHP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL
0=_Kg@3KfmT0[JbZ085nQ@23OY@0Thb[0::I^02_Y/401`2cZ/T00`2dZlX0
]:_80;B[b0050;B[b0030;F/b@2f[LX0]Zg:00D0]Zg:102g[//20;R_c0<0
^K3=0`2i/</20;Zac0@0^k;=02l0^[7<0;^bc@2m]<l0_[K>0;bdc02m]Ld0
_kO?0;fgd@34_mH0^;380:nW_`1EBVP0PWJJ09V:]@2PT;l0YIG20:BD`@2U
U/40ZI[30:^L``2aXlL0`;;F0=32i@3Ne^/0_;G508F2R`1bL7D0Ph6608R7
S`27QI80UY>T09fJ[`2OW;40XYnb0:BQ]02TXK80XYn`09nMZ`2MVjT0WiVW
09jGY`26OY<0KFEm07acT02OUKP0ZZ3509nD_0030:>D_`80Y9G0102UU/43
0:JG`P<0YiS300@0Z9W40:RI`P2XVL80Z9W20P2YV/<30:ZKa080Zic500h0
ZY_40:^La@2^WlP0[9g60:^La@2_X<T0/:G=0;>Zb@2k/L`0]Z_905A5KP1a
H9@0Q76X08Uf[@L0RGJ^01L0RWN_08el/`2AP;H0W8bm0:nPb`32]=L0cl;N
0=?7g`3AaM/0XIf/08j:V@1hM8D0K6Mk06aWO@1bKH@0O7J@08=mU`2OS[P0
XY6k0:BC_`2QT;d0VhVi09F3]@0209:0]0<0T7fd0P2AO[D3099o]P0409:0
]02CPKD0Th6e09>1]@<0U8:f0P2EPkL309J4^0<0UhFi00<0V8Jj09N5]`2H
Q[P00P2HQ[P309V7^@0409Z8^P2JR[/0VXZk09Z:^`80Vh^l0`2LS;d309b<
^`80WHfl1P2NS[d209n?_P<0X92o1`2QTL000`2RT/40XY:o0::B_`050::B
_`T0Xi?00100[J790;Zce@3Bb><0XiN]065XLP1PPX<0Ii>B082VZ@25[[@0
RkBj08be^`2:/kT0RkBj08be^`2;];X0SKJl102<]K/408ff_0L0S[Nm1@2?
^;h4092i_`@0TKRo2`2B^L0i09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0
_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?oo
o`0G0?ooo`80o_kn01D0oooo0?knoP3lo?`0n?Sh0?Cdm03bl_80k>c/0>[Z
jP3Vi^H0i>CT0>?Sh`3Ti>@0iNGU0>OWi`3[jn/0k^k^0?7al@3fm_H0nOWi
0?clo03no_h00P3oool03`3moOd0n?Sh0?7al@3YjNT0h^;R0=gMg@3Kfm/0
g=_I0=_Kg@2>TiT0PXZG08ZEZ@2LY[l0ZkOA0;Bof`070;G0g0030;K1g@2e
`=`0]L3L03H0]L3L00P0]L7I0;K2g02f`Md0_LOR0<_Cj03CfNT0em[S096B
UV80oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03K
f]l0fm_K0:f[[021OXL0Q7nC09>=Z@2SV[L0/:S000@0/j[7202dZlP50;F/
b@<0]Zg:0`2g[//00`2h[l`0]jk90;R_bP020;R_bP<0^K3;00<0^[7<0;V`
b`2j/L`00P2j/L`30;^bc@@0_;?>0P2m]<l30;jed00J0<2hd02o]ll0^K79
0;jfcP2GSjL0H5Q`07M_Q`2YXKT0ZIg;0:fRc@2cZ=00]jg?0;fdc`37_mH0
eLkP0>3Jj02d[kH0PG^507MaO@24OXX0R8:@09F>WP2UW[00[JFj0;F]a02f
[/D20;N_aP0B0;J^a@2d[<<0/JW00:nW_P2XXK<0Yj2b0:NP/02PVJT0P7R=
07A/Q02BRJP0XiVl09f@_02TUl80Y9S00:RI`02OT;L0Z9W00P2VUKl0102V
Ul00YiS10:NH`@2WV<430:RI`P030:VJ``2XVL80ZI[30080ZI[30`2ZVl@0
0`2[W<D0ZIg30:ZNa0060:ZNa00>0:fQa@2aY/P0/jS80;2Ua@2ISK40DTE`
08IhZ@20LZL0S7R]08MdZ`28MJ`0RGJ]08Qe[@29N:l208aj]00G09N6_@2M
T;h0^:g?0<W1f03AbmT0emCM09ZGXP1PGVT0JF5f06iVN`1dK8<0Mfn607Ua
R01hL8P0M6b406mWO`1VGG80Ieef07]`SP2DRJ/0Vhng09N:^02CQKP00P2>
P;D0202DQ[/0SGbc08mm]`2CP[T0T7ne09>1]@2AOk40Th6e0`2DP[H309F3
]`0509J4^02DPkL0UHBh09J5^@2GQ[X00P2HQk/209N6^P80V8Jh00<0VHNi
09Z8^P2JR;`00P2KRKd00`2LR[h0VXZi09^;^P0209^;^P@0W8bi00<0Vh^j
09b<^`2MSK`00P2NS[d0102OSkh0WXjm09j>_@2OSk`80:2@_@L0XI6n202S
Tl004@2UUL80WXnj0:6B_@2QT[d0Wi:m0::E`@2QU<80YIS60;2Vb038^mL0
f<cR0822SP1QMWT0HXB506jDU`26Z;40RkBj00P0S;Fk1`2=][`408nf_@P0
T;Nn202A^;l409:i`400Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0
bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo01X0
oooo02@0oOgm0?Win@3dm?@0k^k^0>[ZjP3Yj>d0gmoQ0=oMgP3RhMl0h=oM
0>3Lf`3Rg]l0h]gQ0>CSg`3ViN40jn[X0?3^k`3clO80m??a0?[im@3ooo/0
o_og0?kon@3jn_X0loCh0>WZkP3Qh^@0g^3M0=WLe@3LfmT0f][L08bAU`24
S9T0RYFY09ZT_@2]^M<K0;G0g0@0];oK8P2e`=`0202e`MT0]/;L0;K1g@2m
an80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo00l0o_kn0?[jnP3dm?@0
kNg]0>GUi@3Ogml0g=cL0=_Jg`3Kfm/0[J^/085nQ`24Oi<0ThfY0:>J]`2`
Z<00102cZ/L70;B[b0D0]Jc9102f[LX20;N^b`80^:o<102h[lX20;V`b`H0
^[7<0P2k//d40;bccP<0_KC?0`2n]M006P2k/l/0_kO?0<>kd`2aZL40]Jg5
09R@Z01RFW80PGVA0;F[c@2n]M@0`KSE0<Ble03Bbmd0fM?Q0<>mb@2SWJL0
OGN307UcO`27PHl0U8fM09bEY@2[Y;H0^;350;ngc031^M00`[[A0P33^m80
5032^]40`;S?0;jfc@2l]</0^;370;F]`P2_Z;X0ZjBf0:nW_029PIT0H5Md
081gUP2SU/40WI6i0:6E_@2TUK`0YiRo0:FF_`2YV/<0YiK0102WV<420:RI
`PH0ZI[30P2ZVl@20:^La@H0ZYk40`2[WlD01`2aYLT0/JK80:jSa@2]XLD0
Jen705e@O02=Ok000`2:Mjl09@2<NK40S7^b08Qg[P2=O;<0Vh[10:JIa@2m
/ML0c<;M0=WBi037`Ll0H5eX069NK01iMH@0MVj507]cR`21NI40Q7bD08Mo
U`29P9/0R7nJ08ElU`2=Pi`0QgfF07I[R@1WG7h0Kf>908EhX`2DQkD0UXRi
0963]P2:O:l0TH2f0960]`2?O[D0Th:h09B2]P2AOk40102DP[H209F3]`80
UXBh0`2EQ;P409J5^@0409F4^02IR;D0VXVf09Z8^0<0VhVi0P2JR;P00`2J
R[/0VXZi09Z:^@0209Z:^@0409^;^P2KRkP0Vh^h09b<^`80WHfl102NS[d0
0`2MSK`0X92m0:2@_@040:2@_@P0XI6n0P2RT[l80:>C`080XI6n00h0YiS3
0:BE`02QU;l0XIBo0:2C_`2VVLD0^k;A0<_1g039`MH0KG5l06=hN`1TR8P0
NInR08>X/0H0S;Fk202=][`208jg_@@0SkJm202@]kh8096h_`@0T[W0@02C
^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool06@3oool09P3no_h0no_k0?Kf
mP3_knl0jNWY0>KViP3Ng^00h>3P0=oNg03Kf]P0g=_I0>7PgP3Pg]l0g=[M
0<[;c@2f]kT0XZ>W09^LX@2PXJH0/[>g0<o@dP3XjN/0oOki0?Wim`3hn?P0
k>c^0>OWj@3Vi^H0fmgJ0=cNf@3LfmT0fMWK08^@UP24S9T0RiJZ09^U_P2]
^M<0];oK402e`=`0102f`Md0]L3L0;G0g02e`=`20;Bof`@0]L3L102f`Md2
0;G0g0P0]/7M00@0]l;N0;K1g@2f`Md0]/7M502e`=`0202e`MT0]/;L0;K1
g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo00l0o_kn0?[jnP3d
m?@0kNg]0>GUi@3Ogml0g=cL0=_Jg`3Kfm/0[J^/085nQ`24Oi<0ThfY0:>J
]`2`Z<000`2cZ/L70;B[b0H0]Jc90`2f[LX30;N^b`80^:o<0`2h[lX30;V`
b`D0^[7<0`2k//d30;bccP<0_KC?102n]M006@2m]Ld0`KWA0;ZbbP30^=00
]jo70:JN]P2KTj/0MFf506MPLP24OHl0XY^[0:^U/`2PVZH0ShVC07mjP@1e
L7L0P7V908b5U@2GT:80W9FW0:VQ]P2i/LP0_[K=0<Bld`33^m800`34_=<0
2033^m80`[[A0<6id030^<l0`[[B0<2hd02j//L0]:c10P2cZl00202BRZ80
FE5Y08UmX`2MTKL0WY:h0:2D^P2ZVl@0YYO01@2WV<430:RI`PD0ZI[30`2Z
Vl@20:^La@@0ZYk4102[WlD20:fQb@0^0;6Ub@2_XlL0[j?709B8[01JCWH0
JEf508ik/`2EP[X0TX6g08mn/P2EQKH0UhZh0:6D`02eZ=@0`;KA0=;8h03V
gO00_KO505aFI01`K7/0MW65079]P`21N9<0R7nJ08j5XP2BRJH0U8^X09J=
[02GSZd0UHb[08n5X02DRJL0TXNU08^0X01iKI40IEUm06mSR@2>PZX0UXVg
0922/`2@Ok<0TH2f09:1]`2AP;H0T7jb09F3]@<0U8:f0`2EPkL209J4^0<0
UXFi0P2EQ;P209J5^@0509N6^P2HQk@0V8Nd09V8]@2JRKH00`2KR[L00`2J
RKH0Vh^l09^;_00309^;_0<0Vh^j0`2MSK`309j>_@80WHfl1@2PT;d80:6A
_P<0XY:o202STl00402PT;d0Xi?00:FF`@2RTkh0X9>n0:6D_`2TV<00/:C<
0<Fle`3Fc^D0Y:6b05mYLP1RNgl0J8^=07nVZ`25[;<508be^`P0SKJl0`2>
]kd308nf_@P0T;Nn202A^;l509:i`400Tk[100`0TkZo09:i_P2B^L00W<77
0:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3o
ool0oooo01P0oooo02L0o_kn0?_kn`3gmoL0l?3`0>[ZjP3Ti>@0h>3P0=cJ
f`3NgM/0fMWG0=WJe@3Ng]`0emOG0;fn`P2XZJh0Qh^D07b0R`1fNXH0NWf<
07f0S`1lP8`0PXJA08fAVP2m_/<0iNKZ0?Gem@3dm?80inOU0=[Jf03NgM/0
e]CE0=[Ie`3GemT0RHjD08>;V02<Uj/0W:Jo0:jje02d_m/0402e`=`20;K1
g@040;G0g02d_m/0];oK0;Bof`@0]L3L102f`Md:0;G0g0<0]/7M5@2e`=`0
202e`MT0]/;L0;K1g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo
00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Jg`3Kfm/0[J^/085n
Q`24Oi<0ThfY0:>J]`2`Z<000P2cZ/L60;B[b0D0]Jc91@2f[LX30;N^b`<0
^:o<0P2h[lX30;V`b`D0^[7<0`2k//d30;bccP<0_KC?0`2n]M020;nfd@0<
0<2hd032^]80_[K>0;bdc02g[lL0/Z[20:nW_`2OUjl0T8ZF07egP`1`JWH0
M6ij0P1jM8002P1oNHD0RH>?08j6V`2GSj@0XIV^0:fU_02n]/d0a;cD0<:j
dP34_=@30<Bld`@0`k_B0140`[[A0<2gdP34^mH0`;S@0;jfc@2g[l@0_[K;
0;bdb@2?R9X0IEak09:8ZP2MTKD0X9Bj0:>G_`2ZVl@0XI:k0:RI`P020:NH
`@<0Z9W21@2YV/<30:ZKa0<0Zic50`2ZW/@50:^Oa@0L0:^Nb@2/WlX0[Z;:
0:nSb@2VV[h0[Z?508MlWP1DBF/0PW:Q09Z:^@2WV<<0YiS10:ZN`P2eZ/X0
`;GC0<RofP3Je>80h]cX0;2Z]P1KEF40LF]i07M_Q01lM8`0S8>P09B;ZP2K
T[40XYVh0:FK_@80YYbn0180Y9Zm0::H^`2RUkL0WI:b09N<[02JSjl0WY>c
08n4Y01eJXX0IU]k07U/U`2CQ[80TX:a08mn/P2DPkT0SWfc095o/`2GQKT2
09B2]P<0UH>g0`2FQ;P209J6]`@0UhNh00<0V8Ri09V9^P2IRKX00P2IRKX5
09Z:^@80Vh^j00<0W8bk09b<_@2MSKh00`2MSKh309f=_0D0WXjm102PT;d8
0:6A_P@0XY:o202STl00402SU;l0Xi?00:2@_@2PT;d0XIBo0::F_P2YWL40
^ZkB0<_6g03Ac^40MG^7069cNP1ROX40L9>G07nVZ`29/[P408be^`P0SKJl
102>]kd208nf_@P0T;Nn202A^;l609:i`400Tk[100`0TkZo09:i_P2B^L00
W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo01P0oooo02L0oOgm0?Shn03bl_80k>c/0>GUi@3Ogml0g=cL
0>3Og@3Kf]P0f]_F0=gOg03De]D0/kNj08fBV01fNX<0L7V:06ifR@1aNHh0
NH6H07n7WP1oQi`0PXZM08RAXP29RiX0QHNC0<G6bP3/k^/0h^?N0=oNfP3K
fMX0f]GI0=KEd`3CdmD0QX^A08::U`2=V:`0WJO00:jje02d_m/0402e`=`2
0;K1g@040;G0g02d_m/0]L3L0;G0g080]/7M402e`=`50;Bofa<0]L3L00P0
]L7I0;K2g02f`Md0_LOR0<_Cj03CfNT0em[S096BUV80oooo000Q0?ooo`0?
0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Kf]l0fm_K0:f[[021OXL0
Q7nC09>=Z@2SV[L0/:S000H0]:_81@2e[<T50;J]bP<0]jk;0`2h[l`20;V`
c@<0^K3;0`2j/L`50;^bc@<0_;?>102m]<l30;jed0<0_kKA00@0`KWA0;jf
cP34_=@0^[;:0P2o]ll01@2WWkL0[ZJn0:6JZP2ITZ80THZJ0080SHJH00T0
SXJK0969WP2ESJ80XYZa0:ZR^@2f[/D0`KWA0<>kd`30^=000P31^M430<Bl
d`80`k_B0`34_=<03`38_mX0_[G@0<Fle`35_MD0aKgD0<6icP2h/L<0a[o?
07M_Q`1]I840VHna0:6E^`2PTkh0Z9_60:6B^`040:RI`P<0ZI[31@2ZVl@3
0:^La@80[9g61@2[WlD30:bPaP0K0:NK``2aYLd0Zio70:^Oa@2/X<@0ZYo1
0:JK^`22MiD0Ge5e089gV@2/XL40^k7<0;Zbb@36_m40em7O0=gGi@34_/P0
T8ZD05]EH@1bK7X0NgB6081hT02?QZ<0ShFW0:FJ_02[X<80/:G70080/JG9
0180/:C80:nSb@2]XLL0ZIk00:bQ``2YW/00WiBd09bA/@2RUkD0V8f[085f
U01JCW80M6R@08inZ`2DQ;D0T7nc09:1]@2GQKT409F3]`<0UXBh0P2GQKT0
102EQKH0UhNh09R8^@2HR;T209N7^080V8Ri0`2KR/0209^:_P<0Vh^l0P2K
RkP0102LS;T0W8bk09b<^`2LS;d209f=_P<0WHfl00<0WXjm09n?_P2OSkh0
0P2PT;l40:2@_@P0XI6n102RT[l80:>C`00@0:>D_`2RT[l0X92m0:BD`@2T
Ul80XiNm0:nTa034^ML0e];Q0:JZ]P1LJW<0IWf306J5R01iWj80OZN[08Ze
^`@0S;Fk202=][`408jg_@H0T;Nn202A^;l809:i`480Tk[100`0TkZo09:i
_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo01L0oooo00P0oOgm0?[jnP3emOD0k^k^0>SXj03R
h^80g]kN0=_Kf`80fm[H01h0gmoM0=CFe@2//K@0Q8^C07=kR01bNHT0LGfE
07R4WP21S:P0QY6_08VD/P2;U[80RiNa08^G[`2BUjd0TIJY08>7TP2WZjh0
emWH0=WGf03FdMD0e<oE0=3?c@3=cLl0PXN=08::U`2=V:`0WJO00:fid`2d
_m/@0;G0g0030;K1g@2e`=`0]L3L0080]L3L0P2f`Md00`2g`]h0]/7M0;K1
g@040;G0g0X0]/7M1`2e`=`00`2f`Md0]L3L0;G0g00>0;G0g0080;G1f@2f
`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2ATYIR0?ooo`008@3oool03`3no_h0
n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm[O0=_Kf`2]Zj`0PGj708AoT`2C
SJT0XiZg0;2X`0050;B[b0<0]Jc91P2f[LX40;N^b`<0^:o<0`2i/<d20;V`
b`<0^[7<1@2k//d30;bccP<0_KC?102n]M030;nfd@0I0<2gdP2o]ll0_[K>
0;ngc`36_]H0_KG=0;Vab@30^=00[:Bl0:jV^`2[XkX0Y9bc09fE[02LU:`0
XIVa0:RP^02/Xkh0]Jg50;Vab@2o]ll0`[[B0;jfcP31^M00b<3G0<Bld`02
0<>kdP@0`[[A0P33^m803037_mL0`KWA0<BkeP33^]D0`KWA0<Jnd`37`=80
`[_;0;B]_`1BBV80SHBS09jD^@80XiK100@0YIW10:JJ`02XVL80Z9W20`2Y
V/<50:ZKa0<0Zic50`2/WLH40:^Oa@D0[:3601X0[j?90:jRbP2YWLD0/ZK<
0:FJ_02VVk/0XIJd08f2X01`IX40JV1i089jS`2PVJ/0/:Zh09jKYP1nNh@0
HEe[06QTLP1fLX<0NW:708=kT`2CR:H0VHj^0:jSa@2/XL<0[jC60;6Ub@80
[j?701<0/:C80;2TbP2`Y<X0/:C80:^O``2^X/H0[Z?50:JK_@2VVk/0Yibl
0:6F]P20MID0G51d07]/U@2GQk@0TH6b09J5^@2GQKT0TX2d0080UH>g0`2F
Q;P309N5^@0409J6]`2GQkP0V8Ri09N7^080UXJg00X0UhNh09R8^@2GQ[X0
VHRl09b<_@2OSl00XY;10:>C`02TU<40Y9G00P2RTk`0102QT[d0X96l09n?
_02MSK`209b<^`<0WXjm0P2OSkh20:2@_`040:6A`02PT;d0X92m0:2@_@P0
XI6n1@2RT[l80:>C`00@0::C_P2QTKh0Whnn0:>C`P2SU/40Z9c00;ned03D
b^80d<gH071iP01NLgP0HH2306jAU@22Yjd0QJjd08Re^P<0S;Fk202=][`5
08jg_@D0T;Nn202A^;l809:i`4<0Tk[100`0TkZo09:i_P2B^L00W<770:o>
d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo01L0oooo02P0o?cl0?Shn03bl_80jn_[0>CTi03Ph>00gMgM0=_Kf`3J
e]D0gMcJ0=GEe@2a]KP0PhZB06afPP1^NHd0N8>I07f;YP29Uk@0U:7109NT
aP2IY/P0VjS809VWa02EXkh0V::m092J/`2GW[00SiFQ09bOYP35a<T0c/c?
0<[5b@37a/@0a/K807j3R@21RIH0SIR/09bV_`2]^M<0];oK602e`=`30;K1
g@80]L3L0`2f`Md80;G0g0D0]/7M4`2e`=`0202e`MT0]/;L0;K1g@2man80
bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]
0>GUi@3Ogml0g=cL0=_Jg`3Kfm/0[J^/085nQ`24Oi<0ThfY0:>J]`2`Z<00
102dZlP40;F/b@D0]Zg:1@2g[//20;R_c0@0^K3=0P2i/</20;Zac0H0^k;=
0P2l/lh40;fdc`<0_[G@0`2o]]420<2gdP0A0;fec@32^]80`[[B0;ngc`2n
]/h0`;S@0<:jdP31^M40^k?:0;B/``2aZL00]:c40;F]a@2d[<@0]jo70;^c
b`30^=000P32^]401P35_M@0a;cC0<Bld`36_]<0_KG:0<Fme0L0a;cC0100
_KG:0<c4f`30^=00`KSC0<Fle`2n]/h0b<3E0<_4eP3Ccmd0MFf207I]RP2J
T;D0YI[40:6D_`2YWLD0YIVo0P2XVL820:VJ``H0ZY_40P2[W<D40:bMaP80
Zio51P2/X<H00`2`YLD0Zj320;2TbP020:fQb@0D0:ZN`P2VVkd0WY>a09N>
[@2<Pj00QGbG07adS01[IW`0Heib06YVM`1aKG`0MG26079]Q020NY@0RH2M
09:9Z02QU[P0/JK80:bQ``2`YLL20;6Vb0050;2Ua`2_XlL0/JG90;:VbP2a
YL/00P2aYLT03P2`Y<P0[Z;60:jRaP2`Y<P0[J750:NK_`2_Y<80Ng2@06]L
P`25MJ80U8Be09>2]P2EPkL0Th6e0P2EPkL209J4^0@0UhFi00<0UhNf09R8
]`2HR;L00P2GQkH02@2HR;L0Vh^j09j>_@2NT[X0XYJn0:RL`P2_XlL0]:S<
0;J[c@020;J[b`090;FWb`2dY/X0/J;90:fNa`2YV/<0YYO20:>C`02QTKh0
XI700080X92o0P2OSkh30:2@_`80X92m202QTKh60::B_`P0Xi?00100XY>n
0:6A_P2OSkh0Y9C30:NJa@2g[<h0clGN0=K=h02VYJ/0GVU]069nO`1TQhT0
N9fS08J[/`29];X0QKFi0P2<]K/808ff_0H0S[Nm102@]kh8096h_`P0T[W0
A02C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool05`3oool01P3jn_X0m_Kf
0>o_k`3Xj>P0hN7Q0=gMg@80fm_K00/0gMWJ0=cJf`2j^kl0RHjD079jQ`1^
NHd0MX:L086?[02EXl00VjW60:6^d0020::_d@0B0:>`dP2R/<d0Wjg:09ZY
aP2P[/T0UZ:l08fE[01oQID0PHB=0:NVZ`36a<D0_kjl0<30`P1kP8H0P8RE
08fH[02LY[l0[KWC5@2e`=`01`2d_m/0/[gI0;6lf02`^mL0/KcH0;:mf@2c
_]X00P2d_m/00`2c_]X0/[gI0;6lf0080:njeP060;2ke`2a_=P0/KcH0;:m
f@2c_]X0];oK4P2e`=`0202e`MT0]/;L0;K1g@2man80bm?X0=?Ij@3Gf^<0
TI:FHP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL
0=_Jg`3Kfm/0[J^/085nQ`24Oi<0ThfY0:>J]`2`Z<00102dZlP40;F/b@@0
]Zg:1@2g[//30;R_c0<0^K3=00<0^[7>0;V`b`2j/L`00P2j/L`30;^bc@03
0;bccP2k//d0_;?>0080_;?>0`2m]<l40;jed080_kKA0`30]m830<6id@09
0;ngc`32^]80`[[B0;ngc`31^M40`[[A0;ngcP2n]/d0`;S?00<0`KW>00T0
`k_@0<6id034_=<0`KW@0<Fme036_]<0`;S=0<Bld@36_]<01033^m820<:j
d@80`k_B0140al3@0<6icP35_MD0`[WD0<>je@37_mL0aKgD0<g6f03;b=<0
[j^l065HM@2HS[<0Y9W40::E`@2XW<@0YIVo0:RI`P030:VJ``<0ZY_400<0
Zic50:ZKa02[W<D00P2[W<D30:bMaP030:fNa`2/X<H0[:3600D0[:3601X0
[J770:bQ_`2/XL40Zio30;2Tc02[WlL0[Z;80:bQ``2WW;`0WiFh09^A/`2A
QjT0QWnN085kU`1lMY00NgF?07eiT020O9L0R86P08f6Y`2KTK@0Y9Zm0:bP
a02^XlD0/:;30;2Ua@80/ZO90P2`YLL0502bY/X0/JG90:nSa`2`Y<P0/ZK:
0:nSa`2`Y<X0/jO=0:jRb02ZW/@0/JG;0:ZP^`2^Xl40KEn306eNR@2@P:l0
SGb`09V7^`2FPkX0UH>g0`2FQ;P309N5^@0L09R6^P2HR;L0V8Rg09V9^02H
R;L0VHVh09b<^`2RT/40YiO60;>Xb02h[L/0`;GC0<Nmf03;`MX0bl7I0<[1
eP38_m@0b;[K0<FgfP31/mL0^jgA0;FVc@2`XLX0Zic70:VIaP2STl80XY;1
0:6A`080X92o0P2OSkh00`2PT;l0XI6n0:6A_P050:6A_PP0XY:o2@2STl00
402RTkh0Xi?00:>C`P2[VlX0/jKA0<Jkf`3CbN40a;_<07MfN`1WMGH0HGmo
06bBT`1oY:X0QJZb08Ze^`26]k/708ff_0P0S[Nm00<0SkRn092g_P2@]kh0
0P2@]kh8096h_`P0T[W0A02C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kC
f039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool0
5`3oool0403inOT0mOGe0>k^kP3Vi^H0gmoO0=cLg03Jf]X0fMWI0=oJgP3J
f=/0YZN/07=gP01aN8P0NXFK08>A[P2HYlP20:>acP0E0:Bad@2W]=H0ZKKH
0:VfeP2X]]<0YkGB0::ed`2P/Ll0VZO709JO_02AUjd0OX:>07ioP`2JVYP0
^[Vg0;bl_P1jOhD0P8RE08fH[02KYKh0[;SB01@0]L3L00P0];oK0;:mf@2`
^mL0[KSD0:bgd`2[]]80[KSD0:njeP80/KcH00<0[k[F0:fhe02[]]80202Y
]=001`2X/ll0ZKC@0:^fdP2]^=@0/;_G0;:mf@2d_m/04@2e`=`0202e`MT0
]/;L0;K1g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo0100o_kn
0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[Jg03Kfm/0[JbZ085nQ@24Oi<0
ThfY0:>J]@2`Z<00]:_81`2e[<T30;J]bP80]jk;0`2h[l`30;R_bP80^K3;
1P2j/L`20;^bc@H0_;?>0P2m]<l30;jed0030;jfcP2o]ll0_kO?00D0_kO?
1031^M480<:jdP@0`k_C4034_=@04035_M80a;cC0<>kd`33^m<0`[[B0<>k
dP38`M<0c/OG0=;?f03@c=/0EdmW09R>/02RU[`0Yi[50:ZKa02XVL830:NK
``80Z9c40`2YWLD00`2YWL<0ZYk40:ZNa0050:ZNa0030:^Oa@2/X<H0[:36
00D0[:360`2^X/P20:nSb@80[Z;800L0[J770:RM_`2TVK/0WY>e09N<[P2C
R:X0THJX0080TXNY00D0VXjb09jB]P2TV;`0ZYk20:jRaP030;2Tb100/JG9
00X0/jW;0:nVa@2aY/H0Bd1R08]oX`2<OjX0UHFf09B3]`2EQ;X0UXFk0P2F
QKT07`2EQ;P0UHFf09J6]`2GQkP0ThNi09Z<_`2EQKH0WH^k09n>^P2XV;l0
]JO:0;Z_c@3C`]80d/CC0=cAg`3Hd=l0blGC0<2jb02d[Kd0/JRi0:jZ^@2h
]<D0^kK:0;bdc02n]M80_[?E0;JZcP2aYL/0[ik:0:bMb02TUl800`2MT[`0
2`2NTkd0Wi:m09n?_02OSk`0Xi?00:BD`@2OT;/0WXnj0:6B_@2RTkh0XY:o
00H0Xi?000@0XY:o0:2A^P2UU/40Z9W40P2QT[d04`2TU<40X92m0:JF``2Q
UL<0XYO20:FJa02bZ<d0_kKC0=G@i03Dd]d0Ogj305McMP1POX00K8j@07ZP
X`25[;40R[>i08bd_02>];d0102=][`408jg_@@0SkJm202@]kh8096h_`@0
T[W0B02C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Sh
n03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0
oooo0?ooo`3oool0o_kn0?gmo@3inOT0lo?c0>[ZjP3Shn<0g]kN0=cLg080
fm_K00P0g=oH0:fa]027SId0Jg>8079nU025TJL0UJ2l0::]c@<0YkCD0P2X
]MD30:VfeP0@0:Zge`2V/m<0XZg;09ZV`02?Vk<0PhnU07V4V01aO8h0LWUo
07IkP@1CEf00PHNC096HZ02LYkd0ZkWD0;;1gQ00]L3L0200]kkH0;FofP2a
_mX0[;cF0:BdcP2S/L/0Yk?;0:6]``2QZlH0X:[30:Rcb@2Y]Ll0ZKKF0:Fb
dP2S/lX0W:jj09n/c02GYL80WZc60:2/a02IYK/0VZJn0:2/a02LZ<80WJK3
09jWa02T[LX0XJg70:Vec`2b_]P0[;SB0;6ofA00]L3L00P0]L7I0;K2g02f
`Md0_LOR0<_Cj03CfNT0em[S096BUV80oooo000Q0?ooo`0?0?knoP3jn_X0
m?Cd0>g]k@3UiND0gmoO0=cLg03Jf]`0fm_K0:f/ZP21OXD0Q7nC09B>ZP2T
VkH0/:S000H0]Jc9102f[LX30;N^b`<0^:o<0P2h[lX30;V`b`D0^[7<0`2k
//d50;bccP<0_KC?0`2n]M060;ngc`80`;S@1031^M480<:jdP@0`k_C4034
_=@04035_M80a;cC0<>kd`34_=@0`k_C0<Bld`39`]@0d<WI0=CAfP3Gdn80
JF5i08b2Y02YWL<0XYG00:^La@2YV/<20:NK``<0Z9c40`2YWLD60:ZNa080
Zio51P2/X<H20:fQa`P0[Z;800H0[J;40:^P`P2XWKl0YIZl0:>H^P2RUkT2
0:>H^P050:JJ_P2XW<00Zio30:jRaP2`Y<P00P2aYLT00`2`Y<P0/JG90;6U
b@0>0;6Ub@090;F[c@2g[/d0]jc<07=XR01_HhL0SH2[09J6]@2EQ;P0UHBj
00<0UXFi02H0UhJj09N7^02GQkP0V8Ri09Z<_`2BQ;D0WHfl0:JE`@2/W<<0
_[3A0<>ie03Kdn/0fMKQ0<K4d@2UYk<0MWf705YSK01IHfd0EemZ051HH`1D
HFT0CeUR059JI@1YK7/0R8NI09fH[`2^YL00_K?>0;BTb@2fY/d0[io60:^J
a02ZVlH0X9>o09^@^`2QV<D0XI700:6A_P80Xi?000@0XI6n0:>C`02TUL00
X96l202RT[l0102TU<40WXjk0::B_`2STl020:FE`P0B0:2@_@2RT[l0WI:m
0:RKaP2]W/D0aKOH0=79h03Pg^`0ZJbe05mVK01LN7/0IX>707BFV01oYJP0
R:nd08be^`2=]Kd0SK>l102=][`408jg_@@0SkJm202@]kh8096h_`@0T[W0
B02C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo
0?ooo`3oool0o_kn0?gmo@3hn?P0lo?c0>[ZjP3Rh^80g]kN0=cLg080fm_K
00P0e=KA09>FV`1eNXd0LWZA082<Y02@W;@0Wj[60:Nae080YkCD0`2X]MD3
0:VfeP0@0:Zge`2W]M80Y:o=09fY``2DX;P0R9BZ07j9W@1gPYH0MG^7075g
P`1=DEd0OXBB096HZP2KY[`0Z[SB0;;1gQ00]L3L0200^L?L0;C0fP2`_]T0
Z[SC0:ZhdP2S[lL0TYZ_09FL[`2DW;<0Uinb09fU^02PZl40XJc809bWa@2H
Y;X0TJ6^092G/@2EWK@0Ri>X08fEZ02AW:h0SYV[08bGZ`2<Ujd0UYjc08fE
ZP2BV[40VZFk0:B^a`2Y/l`0[k_E0;G1fa00]L3L00P0]L7I0;K2g02f`Md0
_LOR0<_Cj03CfNT0em[S096BUV80oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd
0>g]k@3UiND0gmoO0=cLg03Jf]`0fm_K0:f/ZP21OXD0Q7nC09B>ZP2TVkH0
/JW100@0]Jc91@2f[LX30;N^b`@0^:o<00@0^:o:0;V`b`2i/</0^K3;1@2j
/L`30;^bc@D0_;?>0`2m]<l40;jed0@0_kO?1030^=030<6id@P0`[[B1@33
^m<@0<Ble00A0<Bld@33^m80a;cD0<Ble033^m<0aKgD0<_4eP3Ab]X0emCM
0=SDh`1nMXh0PWRJ0:ZNa02RUL00ZY_40:VJ``2WVl<00`2XW<@40:VMa@@0
ZYk4102[WlD40:bPaP@0[J771`2^X/P00`2_XlT0[Z?50:jSa@060:jSa@<0
/:C85@2aYLT01`2f[<h0_kKE0;jcd@2VVkT0DTMY08]oY`2DQ;<0102FQKT0
4P2GQ[X0V8Ri09R8^@2HR;T0VHVj09N7^02OSkh0WXfi0;6QaP2n/Ll0e<cT
0=_FjP2k^/X0RiFN06=`N01>HFP0EFab05YfNP80E75g0140HWn505UiN01N
O7`0IGn006EhOP1JIfl0DEYS061TL01iNhP0Zj6l0;>V`P2eY<H0/Ic30:^I
``2XV<D0X9C409J>_@020::B`@060:6A`02OSkh0Whnn0:BD`@2WUl@0Xi?0
0P2TU<40102STl00XY:o0::B_`2STl020:BD`@040:FEaP2PT<40Y9C30:BD
``80X92o0180XI6n0:BD`@2YW/P0[j?70<>dd`3@`]T0jN7`0:R[]01ULWX0
HgIl06>0Q01aT9<0OZ6U08J]/P2:/kL0SKJl08fe_@2</[/308ff_0D0S[Nm
0`2?][d8092g_PP0TKRo1@2B^L1809>j`@0<09>j_`2B^Kh0T[W009c1a`2_
c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo
0?ooo`0A0?ooo`0;0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03clo<0
j^[Z0>;RhP3MgMd00`3Kfm/02@34a/D0OH6:06abR01jQ9l0RiNa09VW`P2W
/]80Yk7E0:Nde0030:Ree@@0ZKKF0100Z[OG0:Vge02W/]00XZg909ZV_P2@
W;80Qi:X086<X01nQIP0MW^>04]@H`1mPYD0TYV/09^V_02Y]m40//;L402e
`=`0802d`=X0^<CN0:fkeP2/^=80W:Jo09:I[02HWZh0TI>R0::X^02Y/Kh0
TYZU096HZP2FWKL0TYVe09FM/P2:Tj80RXbK0:>U]02[[k/0RY6K08B:UP2]
]L80WjRg096JZ`27SIT0S9:N09:JY`2HWk40WjNl0::Z`@2h`]d0]KoJ402e
`=`0202e`MT0]/;L0;K1g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240
oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[Jg03Kfm/0[JbZ
085nQ@24Oi<0U8jZ0:BK]P2aZL400`2e[<T50;J]bP<0]jk;0`2h[l`20;V`
c@<0^K3;0`2j/L`50;^bc@<0_;?>1@2m]<l30;jed080_kKA0`2o]ll50<2h
d080`KWA2032^]860<>kda00a;cD0100a;cA0<>kdP34_=@0a;cD0<>kd`34
_=<0blCF0=;;f`3Jen00fmOV085iT@25Nid0XiNm0:VLa`2ZVl@0YiS10`2X
W<@30:VMa@80ZYk60`2ZW/@50:^Oa@<0[:361@2]XLL00`2_XlT0[Z;80:jR
b0030:jRb080[j?900<0[Z?50:nTaP2`YLL00`2`YLL0102_Y<H0[Z?50;6U
b@2aYLT40;2Tb180/JG900T0]Zc>0<:if036_=L0a[cG04i3H@22MY`0TH6`
09J5^`2HQk/00P2FQKT309R8^@0X09R8]`2IRKP0V8Jf0::A_@2aXLH0`KCB
0=?;hP3Ge^@0WZ:]06YcNP1CIfh0EVec05MdN01DMGX0Egf005n8RP1PRHd0
FX>706J>T01SRh/0HhJ806R7RP1^S8h0KhR<06MlP@1LLG@0CeMT06a]O`2K
Tj/0]jS90;FPb@2/VLH0[9[:0:ZLc@2STl00Y9C10:>C`02QTL00Whnn0:2@
_`80XY;1202QTKh00`2PSl<0Xi;60:BDa@020:2@_`0C0:BD`@2XVL@0[9g8
0;6WbP38_M/0el[N0>OMj02]Z[40IFic05aaMP1UPXP0KHbA07^LX@27[;80
R[>g08be^`2>]kd0SKJl08bb^`0208ff_0H0S[Nm0P2?][d8092g_PP0TKRo
1P2B^L1809>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0
n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0;0?kn
oP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80j^[Z0>;RhP3MgMd00`3K
fm/0202X[:l0N7b807EkU@21RZT0TIbj0:2^b`2Y]]P0YJkE0`2X]MD30:Vf
eP80Z[OG0100ZkWF0:Zhe@2Y]=00Y:o;09jZa02FX[X0T9Zc08^F[02;TZ`0
Q8ZR05AJLP1nQ9X0TYR^09bW_@2Y]m40//;K402e`=`0202g`]h0[K_F0:nk
e@2Y]Ld0Yjo609RM/02UYkH0k^ci0P3ho?l05P3XkoD0Z:ni09:GZP2?U:X0
PHJI0;_1c`3hmOh0ooko0?cko`3fmo`0g=oT0?Slo`3Kh^`0PHNC0?Slo`3l
ool0nOgo0?Woo`3Wk_l0[[K=0;6hdP2`^MH@0;G0g0080;G1f@2f`]`0]/7M
0;g7hP3;dnP0dmWY0=OJh`2ATYIR0?ooo`008@3oool03`3no_h0n_[j0?Cd
m03]kNd0iNGU0=oOg`3Lg=`0f][L0=_Kf`2][:X0PGj508AoT`2ESj/0YIbg
0;:Z`P050;J]bPD0]jk;0`2h[l`30;V`c@80^K3;0`2j/L`50;^bc@<0_;?>
1@2m]<l30;jed0<0_kKA1@30^=030<6id@H0`[[B2033^m<B0<Ble00@0<Bl
d@34_=<0a;cD0<>kd`32^]80a;cC0<c5e`3DcMd0g=WR0>WUm01]IGd0T8JX
0:2D^P2ZWLP0Zic50:NH`@80Z9c40`2YWLD30:ZNaPD0Zio50`2/X<H50:fQ
a`<0[Z;800<0[j?90:jRb02^X/P00P2^X/P20:nSb@030;2TbP2aYLT0/JG9
00@0/JG900@0/:C80:nSa`2_XlL0[j?71P2`Y<P@0;6Ub@0;0;F[c@31^=D0
bl7J0<k4g01PEW40MVZ>08em[02FQK/0V8Nk09J5^@2FQ[L00P2HR;T209N7
]P0B09Z:^@2VUL40[Yk50<6ddP3AbN00bLSF09bU[01NKG80EVU]05aeO01M
N7l0H86806N<TP1XTID0II2F06ZEV`1dWjD0L9RR0P1eWJD03P1_UYd0K9>H
06jEVP1[TiD0I8b>076?T@1RNGl0DUi/06aZPP2NTk<0[Yk50:RE`P2aVlX0
YYO20P2TUL020:FE`P030:>C`P2QTL00XY;10080XY:o102STl020::B_`0H
0:2Ba@2TU/L0WY6o09jA_@2VVL@0ZIg30:^O``2dZ<`0a;kH0=G=hP3]io<0
ZZR]06Q]L01/OX00FGIj06>8T01gVZ00PZN]08bc^02<]K/0R[Fk08^f_02=
][`0SKBk1P2>]kd208nh_PH0T;Nn202A^;l809:i`4X0Tk[100`0TkZo09:i
_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo0140oooo00/0o_kn0?ooo`3oool0oooo0?knoP3m
oOd0n?Sh0?;blP3Zj^X0h^;R0=gMg@030=_Kf`0809:EVP1hNh`0OH:O08N@
[`2FY<40Y;;?0:Vff02W/mT20:Ree@<0ZKKF0`2Z]mL0402[^MH0Z[SE0:Vd
d02T[l/0Wj_509VU_`2EWkX0Tiff09:L]`2BVKD0H6J00826WP2?Ujh0WJO0
0:bhdP2b`=X@0;G0g00P0;:mf@2e`mh0/;cF0:jjdP2MYK`0WjBg0=WKjP3o
oOl0eMWT0<?8cP3kool0lOKj09>GX`1mOY00`lGD0?_mo`3oo?l0jnS_0>CS
j03gn?X0o_oo0?Sko`2VZk40P8B=0>CVi@3lool0iNS]0>7Ul03Mi?H0[[K=
0:nie02f_m`@0;G0g0080;G1f@2f`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2A
TYIR0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
f][L0=_Kf`2][:X0PGj508F0U02ESj/0YIbg0;:Z`P040;J]bP@0]jk;102h
[l`30;V`c@030;ZacP2j/L`0^[7<0080^[7<0`2k//d50;bccP<0_KC?1@2n
]M030;nfd@030<2gdP30^=00`;S@0080`;S@1031^M450<:jdPP0`k_C4`34
_=@04034_=40a;cC0<Ble033^m<0`[[B0<Jne@3?b=X0fM;R0>7Ni`3[ioH0
FU9Z09R>/02UVKl0YYW40:fNa`2ZVl@40:VMa@<0ZYk600<0Zio70:^Oa@2[
WlD00P2[WlD40:bPaP@0[J77202^X/P20:nSb@80/:C:202aYLT00`2`Y<P0
/JG90;6Ub@030;6Ub@80/:C8402aYLT02@2eZld0`[WF0<o5g@3?a]T0LFMo
06iSQ@2=OJX0UHBj09R8^@0209J6]`0]09R8^@2HR;L0UhNf09V9^02NS[d0
Z9Ro0;V[c03<a=`0`l;@07f6S@1CIFT0EVmc05]iN`1NNh<0IhR?06b?U@1a
V9l0NJ:X07nX[P21ZK40O:B/07fU/@1nY[80OJNc07ZU[P1cWjP0LYnU076P
YP1_WZ@0K9FG06jDU`1eTYX0H7:004mEJ`1nNYD0/J?40:nN`P2bXlX0[Yo6
0:RI`P2VUl00YiS30:FE`P2STl00Y9C100<0Xi?00P2TU<430:>C`00H09nB
`02TUl<0X9>n0:BH_P2/XL<0[jC40;jdc`3Bb><0gmg[0=WIi@2TZJl0HVe_
06AhN@1PO7l0J8^?076HW`21YZh0R:nf08ff_02;][`0RKBj08Ze^`2=][`0
S[Fl1@2>]kd308nh_PD0T;Nn202A^;l809:i`4/0Tk[100`0TkZo09:i_P2B
^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0
n?Sh0?;blP3YjNT0h^;R0=gMg@3Kfm/20=[JfP0808jAV01gOHd0OXFQ08^F
]02O[LX0YKG?0:FbdP2Z]mX40:VfeP<0Z[OG0140ZkSH0:bje`2Z^=D0ZKC@
0:B_b`2OZ/H0VZG109RR_@2FX;/0Tini09JP^@1SJh80OhNN08fE[02LY[l0
[KWC0;;0f`0@0;G0g00P0;G1f`2d`=X0/KoJ0:RdcP2U[lP0WjJi0::X^03@
d^40QhZI08V=UP2d^[X0nooo0<_>e`22Q940lO?o0?coo`30`/h0QHRA096D
V`3[k_<0nooo0?coo`3Si^d0P8>:0<W:c03hnOd0`LC;09bR[P2//lH0[;?=
0;Fnf`2b_M/@0;G0g0080;G1f@2f`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2A
TYIR0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
f][L0=_Kf`2][:X0PWn608F0U02ESj/0YYfh0;:Z`P020;J]bPH0]jk;0`2h
[l`30;V`c@80^[7>0`2j/L`30;^bc@D0_;?>0`2m]<l50;jed0<0_kKA0P30
]m820<2hd0H0`KWA1032^]880<>kda@0a;cD00<0a;cA0<Bld`34_=@00P34
_=@02`39`MP0eLkP0=oHj03Wi>d0aL7@05mGK`2JT;80ZIg30:FH``2[W<D0
[9g600<0ZIg50`2ZW/H20:^Oa`80Zio51P2/X<H20:fQa`T0[Z;80P2_XlT3
0;2TbPD0/:C86`2aYLT02`2f[<l0a[gJ0=;9gP3Ec=d0LfYo06aQP@2@P:d0
UHBj09R8^@2FQ[L0UhNh0080VHVh01H0V8Rg09f=_02TU<40]jW<0<FkeP3I
e>P0WZ:]05ASJ01GL7@0FGYo05j5RP1XSiH0N:6W07^V[01kZ:h0O:V_07jY
/024[;@0Q:Ze08>`]P1nZk40Ojbb0P22[kD05P21[;D0O:N`07FPZ@1hXJL0
LYfS06jGW@1dVJ40Li2H05YZM`1OIGD0RhRK0:^M`02cYLP0/ZC80:bMa02Y
V/40YiS10:FF`@2TUL00Y9C10:>C`02RT[l20:6A_P0K0::B_`2STl00Y9C1
0:2D_02WVl40[J750;FZbP2k/L`0b;kF0=W@h`3Kd^<0alS=09NOXP1OKW40
GgMi05akOP1XRhl0LYNM08J[/@29[kP0Rk>k08^f_@2:]k`0RKJk08^f_02>
]kd0SkJm00@0S[Nm102?^;h4092g_PP0TKRo202B^L1<09>j`@0<09>j_`2B
^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3o
ool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0
oOgm0?Shn03bl_80jNWY0>;RhP3MgMd0fm_K0P3Jf]X0202AU9/0NX2@0868
Y02>VKL0X[3;0:Fec`2S//l0Z;GG0`2Y]]H30:Zge`80ZkSH0100[;[G0:^i
eP2Z]M40YK3<09nZaP2JYL40V:6n09NP_@2EXKL0U:6d061[O`1nQY/0SYJ]
09bV_`2/]m<0/l7N402e`=`0802a^m@0]l?M0;;0f`2]^mH0X:k809VU_@2I
XKH0QXfP08F:WP1mQ8h0[[Jh0??in@3HgN40YJRa0?coo`3al_@0SIFX08fF
Y@3?en80mOco0<[?e@3Oh^T0nOco0;Fe_@32`/X0o?oo0<K:eP2RZKT0[;C9
0;2leP2a_m`0]<7Q402e`=`0202e`MT0]/;L0;K1g@2man80bm?X0=?Ij@3G
f^<0TI:FHP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0
g=cL0=[Jg03Kfm/0[JbZ089oQP25P9@0UHn[0:JM^02cZl<01`2g[//40;R_
c080^K3=0`2j/Lh30;Zac080^k;=1P2l/lh20;fdc`H0_[G@0P2o]]430<2g
dPL0`KWA1@32^]880<>kda@0a;cD0100a;cA0<Bld`34_=@0a;cD0<Fme@3<
a=/0fM;T0>CMk@3[j?40UI6P06mWO`2ISk40Yi_10:ZMb02VUl00Zic50`2Y
WLD20:ZNaP<0Zio71`2/X<H00`2]XLL0[Z;80:jRb0050:jRb0030:nSb@2]
XLL0[Z;80080[j?9102`Y<X30;6Ub@070;:VbP2aYLT0/JG90;6Ub@2`Y<P0
/JG90;2Tb0030:nSa`030;2Tb02aYLT0/JG90100/JG900/0^:kA0<c3h03D
bn00g]GV06aSMP1]HX80U8Ba09B3^@2GQkP0UXJg09N7^00209Z:^@0U09V9
^02PT;d0Z9S50;nddP3Cbn<0Xj:b06A]M01IK700Ggeo05ImPP1/Uih0M:BX
07b//01iZZl0OJjc07n`]@1oZk@0PZff08B/]P1n/[00O[2_086a/`22[k80
Pjbb08N^]@29[[L0QZRb086U/@1kXjd0MjJ/076QY@1/V9T0MIBG06j1Q`1E
H6H0PgJD0:6C]0020;JXb`070;BVbP2cY</0/J;;0:nPb`2]WLX0[9c90:ZJ
a`020:RHa@0K0:ZJa`2/W<T0[Ig:0;>Wc@2h[=00`;GE0<VofP3Ab=d0i=_/
0>7IiP2g[k`0K71a061/K01PMGP0GWf006R?U01eW:40PjR^08V//P2>];d0
SKFm08^f_@2;^;h0RkRm08bg_@2>]kd0T;Nn00@0S[Nm102?^;h4092g_PP0
TKRo202B^L1<09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;
TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<
0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0
fm_K0P3Jf]X0202>TiL0Nh6?08J=Y`2?V[H0Wjg80:Ngd02Y^M<0Z;OF0`2Y
]]H20:Zge`<0ZkSH0P2[^M@03P2[]]80Y[7=0:2[a`2JYL40Uj2m09JO_02F
Y[H0U:6b05iYN`1oQiX0TIV^09bV_`2[]]80]<;O402e`=`0802k`]`0]KoJ
0;2nf@2[^mD0YKG?09ZX`P2<V;00Q92V08fCZ@2g_l`0lOWl0?Woo`3DfMd0
YjZa0?Slo`3Ri^D0QiJ]09:N]02AWJd0SYRT08B;U@2e^L80o?oo0=_Kh`2S
YK40nogo0=7Gi@2Y/<<0Y:o50;>of@2a`=d0/L3O402e`=`0202e`MT0]/;L
0;K1g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool00240oooo00l0o_kn0?[j
nP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[Jf03Kfm/0[:Z_085nR@25PI00UY6W
0:JM^02bZLH00`2f[LX20;N^b`<0^:o<00@0^:o:0;V`b`2i/</0^K3;0`2j
/L`00`2k//d0^[7<0;^bc@020;^bc@<0_;?>00<0_KC?0;bccP2m]<l00P2m
]<l30;jed0030;nfd@2o]ll0_kO?0080_kO?1030^=000`2n]/h0`KWA0<>k
d`020<6id@0A0<:jdP31^M40`;S@0<>je@32^M@0a[gH0;jedP37_]T0`KWA
0<NoeP36_]<0al;F0<G0e034_m<0aL3F0<G0e`33_]D00P32_=H02034_=<0
`[[A0<NoeP35_M@0`k_B0<:jd@30^<l0a[kE0P34_=460<>kd00@0<>ne02m
^<h0al;I0;jid03:aM/0d<cM0=cHi`3]jOL0lngg05eFIP23NI@0Y9Rl0:NJ
a@2XVlH0ZI[10:fO``@0ZYk4102[WlD40:bPaP@0[J77102^X/P40:nSb@05
0;2Tb02_XlL0[Z;60:nSa`2`Y<P00`2aY/P02P2bY/`0/:C:0;2TbP2aYL/0
/:C80:fQa@2^X/H0/JG90;6Ub`2`Y<X20:jRb0040;2Tb02aYLT0/ZK:0;:V
bPP0/JG900@0/JC20;BVa`2aY/P0/:C80P2aYLT06`2^Y<H0/:O60;Zdd03?
aml0f];W0>7Hj`1=@e`0NVb?0961/02FPkX0V8Jh09R6^P2HQk/0VhZn09^;
_02HR;D0X9Bl0;>Wc@3A`=80^KO506QiP@1ELWP0E7=h06F6S@1aV9l0Mj:X
082]/`07086^]0@0PZne1023/;H04@25/;L0Pjje07nZ/@1nYZh0Nj>[07JN
YP1aUj00KI>L069cN`1@GFH0Oh:C0;6/`P2eZlH0_:o=0<6ce02hZ/d0^:kA
0080^JoA01D0^:k@0;N^c@2h[lh0_KCC0<6he`3@_]H0d/?H0=O<g@3Nf^P0
gMgU0;>k_P1iQHD0EVER05ahN`1NO7h0I8>606n>T`1jVj80QJN`08V^]`2;
/KX0102=][`408jg_@0308nf_@2@]kh0T;Nn00H0T;Nn2`2A^;l409:i`500
Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3o
ool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP08
08bET01kPY@0Phb[09>N^P2O[LL0ZKSI0:Ref02Z^=<30:Zge`80ZkSH0`2/
^MT0202/^]L0ZkWF0:^fdP2V/Ld0X:c609^W`@2HX[/0Uj6j0P2GX[P01P1S
Jh00OXJK08jFZ`2MZ;h0[KWA0;?1fa00]L3L0200]<;M0;?1g02c_]X0/kcI
0:>Za02OYK/0SiBW0:2V]P3km?/0o?_o0?[no`3Vk_/0W:Jb096HXP3nool0
n?Ki08ZGZ02;VZl0SYbf08BB[@26TJL0XJNe0?ono`3jm_<0UI^Y0?koo`3`
ko@0X::g0:jgeP2a_mX0/[gI0;[0i100]L3L00P0]L7I0;K2g02f`Md0_LOR
0<_Cj03CfNT0em[S096BUV80oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]
k@3UiND0gmoO0=cLg03Jf]P0fm_K0:bZ[`21OXT0QH6@09JAY`2VWKP0/ZW6
0080]Zg:0`2g[//30;R_c0@0^K3;0P2j/L`60;^bc@80_;?>1P2m]<l20;je
d080_kKA0`2o]ll50<2hd0030;ngc`31^M40`[[B0080`KWA0P33^m<03@32
^]80b<3H0;fec@33^m<0aKgE0<Fme03@b=d0em3R0=;;f`3AcM`0e=3O0=??
h03=bMX00P39a=P02@37`]P0a;oE0<Jne@33^m80`[[A0<2hc`36_]D0b<3G
0<6id0090<Bld`0@0<:md`31_=80`;_A0<K1e@3AcMh0eM7P0>STlP3Zio80
XI^W069KK@2;PI`0X9Bh0:JJ`P2YWLD0[9g40:^M`@<0ZYk41@2[WlD30:bP
aPD0[J77102^X/P40:nSb@030;2Tb02_XlL0[Z;60080[Z;600P0[j?70;2T
b02`Y<P0[:360:nSb@2`Y<X0[Z;60:nSa`80/JG900@0[j?70;:Vc02aYL/0
/:C:0P2`Y<P00`2aYLT0/:C80:nSa`080;6Ub@0P0;:Ta@2cYLP0/:C80:jR
b02_XlT0[j?70;2Vb02e[</0`KcC0=38g@3Ug_00aKc?04a2F`2:O:00SGf/
09^8_`2JR;X0VHNi09R7^`2JRKd0Vh^l09Z:]`2TV<00^:cB0=;5e`2EUj@0
FFac05MfN`1LOhD0KI2F07FNY01nZk06086^]0H0PZne1023/;H0:026/KP0
Q:nf08>^]@23Zk<0PZZb07jV[P1hX:P0MI^T07FBV01]QXd0FVYg05QML023
OiH0/JW10;ned034^]D0`[OE0<>heP35^]P0akgH0<VofP3=`mh0d/SQ0=K<
i@3Gc^40g=GU0<g;f@2XZ[H0NX6905MUJ01GIfL0Jgem061oP@1WQXT0LI>E
07bOX`25Z:h0RJjf08bb^`2>];d408ff_0@0S[Nm1P2@]kh8096h_`80T[W0
102A^;l409:i`500Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ
08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo
00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gM
g@3Kfm/20=[JfP0808bET01kPY@0Phb[09>N^P2O[LL0ZKSI0:Ref02Z^=<2
0:Zge`<0ZkSH0`2/^MT0402]^mP0[;[G0:^fdP2V/Ld0X:c609^W`@2HX[/0
Uj6j09NR^02HXkT0Hf^007j6V`2>UZ/0WJRn0:fid@2c`M/@0;G0g00P0;2n
f@2fa=l0[k[F0;6je`2//ld0X:Jl09FL[`35bm/0oo_o0?Ken`2e^L@0RI6N
082:UP2;TY`0hnK]0?ono`2h_ll0R96R08^FZP29U:P0PHRJ0:R/]`3ko?l0
l>k_08J<VP3gnoh0oOko0:NZ_@2U[//0[kgG0;C0fP2e^md@0;G0g0080;G1
f@2f`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2ATYIR0?ooo`008@3oool0403n
o_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0f][H0=_Kf`2/ZZl0PGj908J2
T@2FTJL0YYfh0;>Za`2f[LX30;N^b`@0^:o<0`2i/</30;Zac0D0^k;=0`2l
/lh50;fdc`<0_[G@0P2o]]420;ngc`H0`;S@00D0`KWA0<:jdP32^]80`KWA
0<:jdP020<Ble00C0<>kd`2o]lh0b<3G0<Noe03Bbmd0dL[J0=gGi@3CcMT0
hmgY0=cIi03Lf>H0f]KT0=OCh@3Fd^40eM7P0<o;fP37`m80b/;I0<Bld`02
0<Fme0040<>kdP32^]40`KW@0<Fme0P0`k_C00`0_k[A0<O2f031_=00bLGF
0=C@gP3ThN`0inC]0>OTj`1KE6@0LVZ109>8YP2NT[H20:VMa@040:bMa02[
WL40ZYk40:ZNa0H0Zio50P2/X<H60:fQa`<0[Z;81@2_XlT0102_Y<H0[j?7
0;2Tb02`Y<P30:nSb@040;2Tc02aYLT0/ZK:0;6Ub@80/:C80P2cYl/20;6U
b@<0/:C80P2aYLT00`2`Y<P0[j?70;6Ub@070;6Ub@0P0;:Ta`2cYLT0/:C:
0:nSb@2`Y<X0[j?70;:XbP2l/m80cLWH0=kGi`3Sg>`0ShJK065GLP24MI`0
UhNf09V6_@2KRK/0VXRj09R7^`2JR[/0Vh^j09f=^P2ZW/H0_[;H0<Flc@1_
MH40DFQ`05YmP@1VRi40MYfR07ZUZ`21/KD5086^]0H0PZne1@23/;H308F`
]`0U08Ja^027[kL0QJfe082X/01mYJd0Mj>V072GW01]Ri<0K82;06=_O@1C
FFT0GUma08J5U`2VXKD0/:^o0;jic@3:aMT0cLWJ0<W5eP30_<d0^KG40:BX
/`25S9H0HFYc05ERJP1QLWT0J7f206AmP@1ROX40K8nA07FHVP20YZT0RJjd
08^b]`2<]K/0S[Jn08ng_`0308ff_0D0S[Nm1@2@]kh8096h_`<0T[W00`2A
^;l509:i`500Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^C
U@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0
o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3K
fm/20=[JfP0908bET01kPY@0Phb[09>N^P2O[LL0ZKSI0:Vff@2Z^=<0Z[OG
00<0ZkSH102/^MT0402]^mP0[;[G0:^fdP2V/Ld0X:c609^W`@2IXk`0Uj6j
09NR^02HXkT0Hf^007n7W02>UZ/0WJRn0:fid@2c`M/@0;G0g00P0;6of@2h
a^40/KcH0;6je`2]]m80X:Ro09VP/`3<dnD0oooo0;o0a029T9P0PHVD09BN
ZP25SIX0ZZji0?gmo`3cmOl0Yj^g08R<U`27SYP0TYVQ0<_>e@3no_l0g]gU
08R?W`3XkO00o_oo0;Bic02U/<`0[[kE0;G1f@2j`>0@0;G0g0080;G1f@2f
`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2ATYIR0?ooo`008@3oool03`3no_h0
n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0f][H0=_Kf`2/ZZl0PGj908J2T@2G
TZP0Yiji0;>Za`030;N^b`<0^:o<0P2i/<d20;V`b`<0^[7<1@2k//d30;bc
cPD0_KC?0`2n]M030;nfd@D0`;S@0`31^M430<:jdP0?0<6id@32^]80`k_C
0<Ble033^m<0akoD0<S1d`3?b=P0em7M0>;LiP3Yhnd0kn[a0>cWkP3Zio80
i>7/0080hMkY00`0fmSS0=;>g03?bmT0d/kL0<o7gP39`MP0c<CK0<W1f031
^M00a[kE0<W1f030^<l20<>kd`040<Ble033^m<0`k_C0<:jdP80`k_C0100
aL3G0<6ld03<b=T0d/kL0>;Oj03]j_40lNke08^8S`1GCfH0QGbG09N<[02R
U[X0[:380:VMa@2ZVl80[Ik51@2[WlD30:bPaPD0[J771@2^X/P60:nSb@04
0:nTaP2`YLL0/ZK:0;:VbP80/JG;00/0/ZK<0;:VcP2dZLT0]:W90;J[c@2h
[Ll0]Z_=0;>XbP2bYlT0/jS:0;6Vb0020;2Ua`030;2Tb02aYLT0/ZK:00X0
/JG90200/Z?:0;>Tb`2aYLd0/ZK>0;:Vc02aYLT0]jk=0<Bkf03DdMX0hmgY
0>3Ij@1HCVH0M6V908YkY02EQKH0VXNn09b:^P2KRK/0VHVj09Z:^`2LS;/0
Wi2k0:bPaP31]MT0Z:Bc05iXLP1HLgX0GXJ806ZCU`1lYJ/0P:fb07b]/P@0
PJjd1P22[kD808>`]P0>08B_]P25/;L0Q[6h08N_]`25[KD0PZZb07JVZP1d
XJH0N9nT07BEW01/Qhh0L8N=06f0Q`1LKgD205QOJ@0F05UPJP1KHV`0G6=[
05aSJ`1KHVX0FV5Y05EWJ`1LKg<0H7Ej061iOP1QOH40HH2506V:T@1fVIl0
O:BV08:Z[029/;D0S;Fi08be^`29];X0RkJl08bg_P80SKJl1P2>]kd4092g
_PP0TKRo102B^L02096h_`H0T[W0D02C^/40302C^[l0T[Vn09:i`02L`LL0
[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b
0>WYj@3QhN40gMgM0=_Kf`80f][J00P0S9F@07^2U023S:/0U9nk0:2^b02Z
^MX0ZKKI0:^ie0<0ZkSH0`2/^MT20:fjfP080:fkf02/^]L0[;OC0:NbcP2Q
[LL0VjO109VS_02GXKX209RS^@0606A/P@1oQi`0SYJ[09fX_P2]^M40/l7K
402e`=`0802c`M/0]l;N0;G0g02c_]X0Z[C?0:>]aP2LY;T0[KG80?koo`3`
mOP0/k[20;g7d@3DgN`0U9^[09VO[`3=d=l0o?[o0?gko`3DeMX0`/K90=[N
h@3lool0nO_o0:b^_@2>UjP0e=cO0?Wlo`31a]X0Y[7=0:Zjd@2`_=80^;oL
402e`=`0202e`MT0]/;L0;K1g@2man80bm?X0=?Ij@3Gf^<0TI:FHP3oool0
0240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[Jf03Kfm/0
[:Z_089oRP26PY40Ui:X0:NN^@2dZlP00P2g[//30;R_c0<0^K3=0`2j/L`3
0;^bc@D0_;?>0`2m]<l50;jed0<0_kKA0P30]m830<2hd0D0`KWA1032^]83
0<>kd`0I0<Ble03;`mP0d<WI0=kHi03]io40l>_b0>cVl03AbmL0UHnK06iW
M`1WH700HEYZ06iWM`2CS9`0_KK60=?=f`3Ecmd0e<cQ0<[2e`36_]<0b/;G
0<S0e@31^Lh0`[[?0<Jnd`020<Ble00F0<Fme@34_=@0`k_C0<>kd`34_=@0
a[kF0;njd03Ccn00d/kL0>?Pj@3Zinh0k>W`0;>`^@1?C5L0M6^80927YP2K
T;80Z9c00:^Oa@2ZW/@0Zic30:fNa@<0Zio51@2/X<H30:fQa`D0[Z;81P2_
XlT20;2TbP80/:G70P2aY/P0402bYlT0]J[<0;V^d02l/M<0_[G@0<>je@37
_]T0b;oL0<Flf@30]m@0_KCC0;^bd@2fZl/0]:W90;:Wb@2aY/P20;6Ub@03
0;:VbP2aYL/0/JG900L0/JG90200/Z?:0;:Sc02_Xl/0/:C:0;:VbP2dZLT0
_[G@0<g5g@3HeM`0l>[f0:JO/@1AAf80Og>G09>3/02GQkP0VXRl09^9^@2L
R[X0VXZk09^;_02LS;/0Wi2k0:bPaP2o/mL0TI2N05e[MP1OOX<0HX^?06jI
W`1lYjd0P:ne07R[[`@0PJjd1022[kD608>`]P80Q;6g0`23/;H01024[kH0
QK2g08F`]`27[kL208J^]P0:08:]/`1lYJ/0Mj2T07BMW`1`V9P0K9>B06R?
SP1[Q8P0Ih6206=mOP80H7Yk0`1PNWT02`1MNg/0H7j006>2Q@1YRXl0LiJL
07NLY01kXZT0OjN_08Ra]@29/[H0RkBh00@0R[Fk00<0RkJl08jg_@2>]kd0
102>]kd208nh_P@0T;Nn202A^;l:09:i`580Tk[100`0TkZo09:i_P2B^L00
W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh
0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bET01kPY@0Phb[09BO^`2P
[/P0Z[WJ0:ZgfP2/^]D20:^hf0<0[;WI0`2]^]X0402^_=T0[K_H0:bgd`2W
//h0XJg709bX`P2IXk`0V::k09RS^@2IY;X0I6b107n7W02>UZ/0WJRn0:fi
d@2c`M/@0;G0g00P0;C0fP2b_]P0]L3L0;G0g02[]]80[;K?0:>^a02JYKT0
`LK:0?Ono`3doOl0mooo0>gfo`2a^L`0XjZm09JM/037a]@0m_Ko0?Wjo`3l
oOl0o?oo0?3do`3;dN40WJ:f09BP]P3;e=d0m?So0<[@iP2[^M@0/L7H0;?2
e`2h_m`@0;G0g0080;G1f@2f`]`0]/7M0;g7hP3;dnP0dmWY0=OJh`2ATYIR
0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0f][H
0=_Kf`2/ZZl0PWn:08J2T@2GTZP0Z9nj0;B[b0040;R_c0<0^K3=00<0^[7>
0;Zac02j/L`00`2k//d50;bccP<0_KC?1@2n]M030;nfd@<0`;OB1P31^M45
0<:jdP<0`k_C00X0aKgE0<Noe`3Cc=h0fmCT0>oYm@3[iNl0g=KP079/NP1:
@eD0ETiU0P1SFg<03`1[Hg/0KVIn05]CJP1<A5/0Iemf09::W`36_]<0eLgR
0<k6f`38`=D0c/KK0<[2e`34_=40aKgB0<>kdP020<Bld`80`k_B01<0a;cC
0<NoeP39`MP0e];S0=??gP3Qg^T0jnS_0?;_mP37a<l0Ad=B06EPM027OJ00
ThV/0::F^P2ZW/80Z9c20:^Oa@2^WlH0[9g400H0[:360P2]XLL60:jRb0L0
[j?90`2`Y<X02@2aYLT0/:C80;2Ua`2aY/H0]Z_90;jdc`37_MH0cL?L0=;;
g@020=S@i@0=0=;:h@3=aM`0cLGM0<RofP32^M@0_kCB0;bac`2h[Ld0]:W;
0;:Wb@2aYLT0/JG;0;2TbP080;6Ub@0P0;>Tb`2bXlX0[J770:jRaP2dZLT0
_;;=0<[2f@3Id^@0kN[c0>3Jj01>AUh0LFF908MjY@2HR;L0UhNf09Z8^02K
RKT0W8Zj09^;_02LS;/0WHfj0:2A_02[WlD0_[;F08V;VP1OKGP0Ggf506F>
TP1dWjD0OJR^08:_]@1m[[<3086^]0D0PZne1@23/;H308Ba]`80QK:h0P24
/KL04025/;L0Q[6h08Ja^027/[T0Q:Vb08R^]`24[K<0Ojb_07b/[P1hZ:P0
M::P06bJV01cUYP0L9>E06b?T@1YS8h406V=S@0806b?T@1^U9D0LiVL07JM
XP1jXJH0OjR^08N_]`2<]kh308Ze^`0508^f_02<]kd0SkRn08jg_@2=][`0
1@2>]kd308nh_P<0T;Nn202A^;l:09:i`5<0Tk[100`0TkZo09:i_P2B^L00
W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh
0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bET01kPY@0Q8f/09BO^`2Q
[lT0Zk[K0:ZgfP2/^]D40:bif@<0[K[J00T0[[_K0:jlf@2]^mP0[;OC0:Rc
c`2R[/P0W:S209ZT_@2HX[/00P2IY;X01P1TK840OhNL08jFZ`2MZ;h0[KWA
0;?1fa00]L3L0200]L7I0;>of@2d_m/0]L3L0;:mf@2`_=H0ZKG=0:Faa`2S
ZkP0[;?30<[Ah@36cn00Zk?60:J^``2X/lT0Y[3909jU]`2QYkL0_<3<0<oC
gP36b]H0/KO70:2X_@2V/<T0WZc70;:lb038c]X0^;oI0:Zge`2a`m/0/L3G
0;JmfQ00]L3L00P0]L7I0;K2g02f`Md0_LOR0<_Cj03CfNT0em[S096BUV80
oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Jf]P0
fm_K0:f[/022OhX0QX:A09RCZ@2XWkX0]:_800<0^:o<0`2i/<d20;ZacP80
^[7<0P2k//d60;bccP80_KC?1P2n]M020;nfd@@0`;OB1@31^M460<:jdP80
`k_C01d0a;cD0<W1f@3>a]h0fM;T0>?Mj`3_jOD0blG?04e7E@1DC640JF1m
07U_T@1kLI@0Q7ZM08IlWP22N9X0QWfL08V0W`1jLHh0HeYg059:G`2JTZL0
bl?H0=38g@3:`]L0bL7F0<c4f@39`MH0b<7C0<W2e0030<[3e@0>0<g6f03B
bmd0e/oQ0=KBh@3]jOL0l>gf0>o/l`2k^<40Ad=B065LL`1lMY80TXN_09Z@
]@2YWL<20:VM`@030:ZNa02^WlH0[9g400D0[:360`2]XLL50:jRb0L0[j?9
102`Y<X0602aYL/0/ZK:0;BYb`2i[/`0`kWB0<o6f`3Id>40gmOV0>KPk03Q
fnT0g]SV0=oHj03NenT0eloT0<o7gP3<a=/0a[cG0<>heP2n/m40^Zo?0;J[
c@2dZ<`0/ZK<0;6Ub`P0/JG90180/jC;0;BUc02aYLT0]:W;0;jcd@3;`MT0
fM;R0>KPkP3Vh_00Rh>H04e4H`24Mj80Rgf^09n?`02APK00WXfj09^9^@2M
Rk/209b<^`0<09f=^P2QT[/0[:360;jce@2:S9/0H6ii061nQP1YTYH0MYnU
08:Z/P20[K<0PK2f0P21[[@608:_]@@0Pk2f1024/KL00`23/[P0QK:h08Fb
^00208Fb^00>08Ja^027/[T0Qk:i09:g`029/;L0Pjjd08Nd^@1o[k<0OJZ_
08B]/`1nYJ`0NJ2W07ROYP1gWZD307NNX`80MYjP00D0O:>X07nVZ`23ZZl0
Qk2f08Zc^@0208be^`0408^d^P2;][d0SKFm08fe_@80S[Nm00<0SkRn092g
_P2@]kh0102>]kd408nh_P80T;Nn202A^;l:09:i`5@0Tk[100`0TkZo09:i
_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3m
oOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bET01kPY@0Q8f/
09BO^`2Q[lT0Zk[K0:^hf`2]^mH30:bif@<0[K[J0P2^^m/0202^_=T0[K_H
0:fhe02X/ll0XZk809fY``2JY;d0V::k0P2IY;X01P1UKH80P8RM08jFZ`2M
Z;h0[KWA0;?1fa00]L3L00H0]l?K0;K2g02e`=`0]L3N0;G0g02`_]T20:jm
e00H0:^cbP2a^M00Yjo60:^cbP2c^m80/[cE0;6me@2]^M<0[[gB0:Faa`2`
^<l0[K?;0:jdc02c^]@0[KWC0:ZhdP2^_M`0ZKC60:jea@2`]m@0[kgP0;C5
g`2d`]`0^l7Q402e`=`0202e`MT0]/;L0;K1g@2man80bm?X0=?Ij@3Gf^<0
TI:FHP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL
0=[Jf03Kfm/0[J^`089oRP27Pi80V9>Y0:RO^P2e[<T00`2h[l`20;V`c@<0
^[7>00@0^[7<0;^bc@2k//d0^k;=0`2l/lh00`2m]<l0_;?>0;fdc`020;fd
c`<0_[G@00<0_kKA0;jed02o]]400P2o]]430<2gdP030<6hd`31^M40`KWA
0080`KWA1032^]804P33^m<0`[[B0<:jdP33^m<0`[[B0<Fme@3<a=`0e<cT
0>;Kk@3`j_P0e<kJ04DoB`1OF6P0KfMo07meV027O:H0T8F_0966/080TXN_
02@0ThV^09>9[02?QJP0S8:U085iSP1PF6d0KfMl0;6Y_P3Bb]l0clOL0=;:
g`3Cbn00d/_K0=C=g@3Ec]h0e/oO0=O@h03Ke>@0hM[Z0>KOk`3]jOL0jnSc
0>gZl@2TXJP0?S]606AOL`1mMi<0TX^]09fB_02UV/80[J770:VM`@2^X/H0
Z9c00:bMa02^WlH40:bPaP@0[J77102^X/P80:nSb@@0/:C:01P0/JG=0;>W
c@2j[m40a;[E0=78g@3Ne^D0imoZ0>_Tk036`LP0UHnI06MQK@1JE600GUMW
06aUM@2=QYP0/:Rm0<VofP36_=L0`[OE0;jcd`2j[m40]j_?0;BXcP2bY/`8
0;6Ub@0B0;>Ub@2fZ<`0]Z_=0;bad@3:`=/0fM3U0>CNk03_jO<0[JVh04Hn
EP1oMIP0RWf[09B6^@2BPKD0YIG209R7/`2KR[L0WH^k0P2LS;/0302MSKX0
XI:k0:fQa@2o]=H0RXbK061^N@1UPh/0KYFL07>LXP24[;@0OjZa086`^0L0
PZne1@23/;H408Ba]`03086`]P22/KL0QK:h0080QK:h0`26/KP02`24[K<0
R[Fk08Jc^025];X0QkBj08N_]`2?/K/0SZji08Z^^P29[KT0Qj^g0080QJZc
00H0QZ^d08R]]@29[[H0R;2h08Va^@2:/kT208be^`<0SKJl00@0SKFm08jf
_P2>][h0SKFm0P2=];/00`2>]K`0T;Nn08jg_@0308jg_@@0SkRn1`2A^;l8
09:i`00309>j`@2B^L00T[W00080T[W0E02C^/40302C^[l0T[Vn09:i`02L
`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0
l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0S9F@07^2U024SJ`0UJ2l0:6_
b@2/^m`0ZkSK0:fkeP<0[;WI0P2]^]X30:jkf`0@0:jlf@2]^mP0[KSD0:Rc
c`2R[/P0WJW309ZT_@2IXk`0VJBj09ZU^`1UKH80P8RM08jFZ`2MZ;h0[KWA
0;?1fa00]L3L0200]<3H0;C0fP2f`Md0];oM0;6og02c`M`0]L?M0:bkdP2b
^mP0[kSE0;Flf02f_ML0];_E0;Fof02a_ML0//3J0:Jld`2a`]`0[K_H0:^d
d`2i_ml0/;WH0:nmf02``=X0[K_N0;>oe@2i`M@0]KkM0:nmhP2ca>00/l7K
0;Nmga00]L3L00P0]L7I0;K2g02f`Md0_LOR0<_Cj03CfNT0em[S096BUV80
oooo000Q0?ooo`0@0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Lg=X0
fm_K0:bZ[`23P8/0R8BC09NBZ02WW[T0]Jc90;R_bP<0^K3;0`2j/L`40;^b
c@80_;?>0`2m]<l30;fec@80_[K>0`2o]ll40<2hd0D0`KWA1`32^]804P33
^m80`[[A0<>kd`32^]80`[[A0<FmdP3?b=P0fM?Q0>?Pi`3[ioD0G5A[05U@
K`1dJ8h0Q7RP0962Z@2KS;<0Wi2k0:2A_0<0XI:m00h0Wi2k09f>^@2LSKP0
Sh>Y09F9[@1]HX@0DDQS08AlT`38`M<0fMGS0=3=f03DdmT0e]GK0=cKh@80
gmkT00/0i>?Y0>WXkP3Xind0l^gc0<[5c01XHW00CdML07I]R023NI/0ShFZ
09fB^P030:VM``030:ZNa02[WlD0Zio500H0[:36102]XLL40:jRb0@0[j?9
202`Y<P02`2fZ<`0]JW=0<Nng@3>bm`0g]gR0>[Xj`3Ac]T0JV9i044fF01>
@fD0G55c0080HUMi00`0GeAf05M<KP1?A6H0EDaO08n6V`2n]<`0a;[C0;F/
b@2n]M@0^JoA0;BZc02gZLd20;FWb`0U0;>Ub@2`X/D0]:K90;NYc02aXlH0
/:SA0;Zce@32_M@0b/KE0=SEgP3ThNX0k^_f0<6mb`14=UL0K5j208]kZ02C
P[H0VHRn09f<`02LS;T0WHji09f;^`2LR[X0W8bm09b<^`2LS;T0XI:m0:jR
b02m/MD0SXNI05i`NP1NPhT0K96G07ZQZ01n[[80OZnd08F]]@0408:_]@@0
Pk2f00<0Q:nf08F`]`25/;L01@25/;L408Ja^0@0Qk:i00<0Qk:h08Rc^@28
/kT01@28/kT00`2:/kT0RkBj08^d^P0508^d^P@0S;Fk1@2=][`708jg_@03
08nf_@2@]kh0T;Nn00H0T;Nn2`2A^;l409:i`5P0Tk[100`0TkZo09:i_P2B
^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0
n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bBTP1mPhl0R8nY09FP
`02Q[l`0[K_F0:^ieP2^^MT30:njf080/;_I0`2a_=X0402`_]T0[kgH0:fh
e02X/ll0XZk809fY``2KYL00VZBo09ZV_P2FXk@0I6ij07n8V@2@Uk40WjG5
0:bgd`2e`M]00;K0f`080;;0g@2b`=/0/l7K0;g9g`39eND0d=SS0=CIg@2A
UIIR0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
g=cJ0=_Kf`2/ZZl0Ph2;08R4T`2HTjT0Z9nj0;J]bP040;V`b`80^[7<102k
//d30;bccP<0_KC?0P2m]Ld30;jfcP<0_kO?1030^=040<6id@H0`[[B0P33
^m<20<:jd@0A0<>kd`32^]80`[[A0<Jnd`3@bMT0fM?Q0>CQj02d/;h0Dd]R
06mVQ@1oLiT0T8B/09j?^02OT;L0XI:m0::C_P2SU;l00P2TUL006`2SU;l0
XY>n0:6B_@2MTKT0W92f09F9[@24NiX0J61h05UAIP1oN8X0_;S70=[GhP3P
gNP0h]oZ0>3Mj03Wi>l0k^_f0=WFh@2e/[d0J69^05]EH`1IDV@0N72708Im
VP2<PZ@0XiVn0:FJ`P020:VM``80ZYk400<0Zio50:bPaP2/X<H0102/X<H5
0:fQa`@0[Z;8102_XlT80;2Tb00;0;V[c032]mL0aKcI0=cHj@3ViN/0_K[1
04@mC`1?AV<0Ie^106mSR@1eJHl00P1fJY003P1gJi40MVZ@07=WS@1bIH40
ETaW05A:I@2ERjH0_[?A0;nfd`2i/<d0^k;?0<6ef@2fZ/h0]JW=0P2l/M<0
8`2g[<h0^Jk>0<2ee@33_=d0a;kH0=KAi@3Nf^P0j>G`0>k[mP2`[;/0?CQ<
06IHN@22M9P0U8Ba09J5^@2IR;`0Vh^l09V9]P2JRkH0WH^k09b:^P2LS;d0
W8bk09b<^@2QT[d0[Z;80;jbeP2>QiT0GW1j05j3R@1/TIL0NZ6X07j^/P1n
[k@0QJfe00@0PZne1023/;H608F`]`H0Q[6h1027/[T608Rc^@80RKBj1P2;
];X608be^`@0SKJl1P2>]kd208nh_PH0T;Nn202A^;l209:i`0@0TKRo102B
^L1H09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3o
ool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3J
f]X0202<TY80OH>?08R?Z@2EX<00XJo<0:fkeP2[^MH0[[WI0P2_^]P30;2k
f@<0/KcJ0100/;kI0:nmf02]^=@0Z;??0::^b02MZL<0VjG009ZT_`2IYKd0
V:Ff06E^O@20RIX0SiJ`09nV``2/]m<0]<3H@02e`M/0202d_md0/l7N0;C2
g@2mbN40bMCV0=3Hh`3Cf=h0TI:FHP3oool00240oooo00l0o_kn0?[jnP3d
m?@0kNg]0>GUi@3Ogml0g=cL0=cLfP3Kfm/0[J^`08>0R`28Q9<0V9>Y0:RO
^P2f[LX00`2i/</30;Zac0<0^k;=0`2l/lh40;fdc`040;fec@2n]/h0_[K>
0;jfcP@0_kO?0`30^=050<6id@D0`[[B0`33^m<04`32^]40`k_B0<>kd`33
^m<0`k_B0<Jnd`3Ab]X0fmGS0>CQj025PHl0EDeT085hU`29OJ<0VHfe0:BE
_P2PTKP0XY>n0:>D_`2TUL001@2UU/406@2VVL@0VXjf09R</P2MT[@0UXf/
08AkUP1[Hg/0EDeT04m;G01YIGH0PWj?081lS@1[IgP0FUIW04i:F`16@U<0
JV1h075WP023NI@0UhbZ09Z?[`2MTKD0ZIg30:RL`P2YWL<00P2ZW/@20:^O
a@D0[:361P2]XLL30:jRb0D0[j?91P2`Y<P20;6Ub@0:0;F[aP38_]T0f];Y
0>;Nk`3:a]@0@Ce<05I=J01]HHL0Nf^H085aWP80Q7BQ03@0Pg>P08EeXP25
MJ80Pg>P085bV`1oL9L0LFF905U>L01ZGgd0Yifh0;fec@34_=@0`KSG0<Ro
gP38_m`0`KSE0<2ge035_=L0bl;M0<o6h@3Fc^<0gMKX0=oIi`3^j?@0k>Kd
09RAX`15?E@0HEQc08AfVP2BPjX0VHVf09N7^02JRKd0W8bm09Z:]`2KS;L0
WXbl09f;^`2LS;d0WHfl09f=^P2RTkh0[j?90;jbeP2>QiT0GW1j05j3R@1/
TIL0NZ6X07j^/P1n[k@0QJfe0`22[kD508>`]PD0QK2g1P26/KP508Nb^@D0
R;>i0`29];X508^d^PH0S;Fk1@2=][`508jg_@<0SkRn1@2@]kh8096h_`<0
T[W00`2A^;l509:i`5P0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0
bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140
oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q
0=gMg@3Kfm/20=[JfP0908bBTP1mPhl0R8nY09JQ`@2Q[l`0[K_F0:bje`2^
^MT0[k[H00<0/;_I102a_=X0402`_]T0[kgH0:jie@2Y]=00Xjo909jZa02L
Y/40VjG009VU_`2KZ;T0IFim0829VP2>UJl0WjK30:bgd`2e`MU00;?1g008
0;G0gP2f`Ml0]<;M0;g9h@39e>H0dMWV0=CHh@2ATYMR0?ooo`008@3oool0
3`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I0=[JfP2]Zk00Q86<
08R4T`2HTjT0Z9nj0;J]bP020;V`b`<0^[7<0`2k//d30;bccP<0_KC?0P2n
]M030;jfcP<0_kO?1030^=060<6id@@0`[[B1033^m<20<>kdP80`k_C00d0
`k_B0<Noe03Ab]X0fmGS0>7Ni`1jMX@0HEU`08=iV`2=PJL0WI6i0:>D_@2Q
T[/0XY>n0080XiBo0P2TUL020:FF`@0C0:JG`P2OSk`0Y9G00:FI`@2MTKL0
ThN[09B:[02DRjX0Rh:O08=kT`1cJh<0JF5i06YRNP1[Hg/0KVIn07UaR@26
OYH0R7fO09B9Z`0209R=[`040:FI_@2[Wl<0Yi^o0:^Oa@80ZYk40P2[WlD4
0:bPaPD0[J771@2^X/P60:nSb@030:nSa`2`Y<P0/:C800<0/:C800`0/JG9
0;:VbP30]/l0b<3G0=oKk03[ioH0DdmP05A;IP1ZGX@0QgNV08MfZP2=O;02
0960]080T7nc01h0SWfa08]j[P26MJT0QWJW07e]VP1oLiT0HeQj04m5H021
Mhl0^;350<>ne037`]H0bLCH0<c7f`3BcN40dLgN0=??h03Lf>T0iMo[0>?M
j@3dk_X0a/3>05iGJ@18@5P0I5]j08QnX@2?P:L0UXNb09V9]P2IRKX209f=
_P0B09b<^`2MSKX0WXbl09f;^`2LS;d0WHfl09f=^P2RTkh0[j?90;jbeP2>
QiT0GW1j05n4RP1]TYP0NZ6X07j^/P1o/;D0QZjf0P22[kD608>`]P@0QK2g
1P26/KP608Nb^@@0R;>i1029];X408^d^PH0S;Fk1P2=][`408jg_@@0SkRn
102@]kh8096h_`@0T[W00P2A^;l609:i`5P0Tk[100`0TkZo09:i_P2B^L00
W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gm
o@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh
0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bBTP1mPhl0R8nY09JQ`@2R
/<d0[[cG0:bje`2_^]X30;2kf@<0/KcJ0P2b_M/0402`_]T0[kgH0:jie@2Z
]M40YK7;0:2/aP2OZL@0WZS309ZV`02NZkh0I6el0829VP2=UJ`0WjK30:fi
d`2g`mU00;?1g0080;G0gP2f`Ml0]L3L0;c8h03;dnP0dmWY0=OIi@2BTYYR
0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I
0=[JfP2]Zk00Q86<08V5U02HTjT0ZJ2k0;N^b`030;Zac0<0^k;=102l/lh3
0;fdc`<0_[G@0P2n]/h30;ngc`<0`;S@1P31^M460<:jdP@0`k_C0P33^m80
3P33^m<0a;cD0<>kdP37_m@0d/_K0=cFi03LfN80O7R706MOM`22N9X0ThN_
09nB_@2TUKh0YIJo1@2TUL030:FF`@0;0:ZJa`2UUL80XiBo0:JJ`P2XW<@0
X9Bj09N=/02ERjh0THRW08n6Y@2<Pj800P2:PJ000`2;PZ40SXFT0968Y`02
09V=/`060:FI_`2[WlD0Zio50:^Oa@2XW<80[:360`2[WlD40:bPaP@0[J77
1@2^X/P60:nSb@80/:C:00<0[j?70;2Tb02aYLT00`2`Y<P03@2bY/X0/jO;
0;fcc03?am`0f=CS0:>O[P1=AEd0LFF908AdX`27M:/0Sgjd091o]@2AP;H0
0P2@OkD20960]P0a091o]@2CP;P0RgZ`0961/P25MJ80PG:I07Y_S`1LDVd0
CD=L085mS02^Z[T0d<cJ0=C@gP3Fd^00gM[U0>7Nj@3RgnX0g]KS0;:Z^@1V
GFh0A3]@05Q>J@22MiT0R7bR08n2[@2EQ[40VHVf09Z:^@2KRkX0W8bm09b<
^`2KRkX0W8bi09j<_02MRk/0WHfn09f=_02MSKX0XY>n0:nSb@2o/mL0ShRJ
05maN`1OQ8X0KI:H07ZQZ01n[[80Ok2e08J^]P0608>`]P80Q;6g1025/;L4
08Ja^0H0Qk:i0P28/kX408Rc^@@0RKBj102;];X408be^`H0SKJl1P2>]kd4
08nh_P@0T;Nn202A^;l:09:i`5X0Tk[100`0TkZo09:i_P2B^L00W<770:o>
d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3Y
jNT0hN7Q0=gMg@3Kfm/20=[JfP0808fCT`1nQ900RI2Z09JQ`@2R/<d0[kgH
0:fkf02`^m/20;2kf@<0/KcJ0`2b_M/20;2nf@0>0;2ke`2/]m<0Z;C>0:B`
bP2S[LP0XZc709nZaP2S[lD0HV]l07n8V@2<U:/0WjK20:bhd02g`mU00;?1
f`080;FofP2e`M/0]<3J0;_6g03:d^D0dmWW0=OIi@2BTYYR0?ooo`008@3o
ool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I0=[JfP2]Zk00
Q86<08V5U02IU:X0ZJ2k0;N^b`020;Zac0<0^k;=0`2l/lh40;fdc`<0_[G@
00<0_kKA0;ngc`2o]ll00P2o]ll30<2hd0H0`KWA1P32^]850<>kd`80`k_B
0P34_=@03033^m80akoD0=7:fP3KeN<0g]_T07YfQ@1UGGD0QWbN09R<]02P
Tkh0YIK10:>D_@P0YYO201T0XiBo0:ZKaP2XVL@0XiBo0:>G_`2RU[h0XIFm
0:FI`@2NT[H0X9Bh09fA]@2HS;00VXjb09nC]`2RU[X0XiNk0:RI`P2YV/<0
[Yo80:fNa`2ZVl80Zic30:bMa02^WlH0Zio500D0[:360P2]XLL60:jRb0L0
[j?90`2`Y<X04@2_XlL0/:C80;6Ub@2`Y<P0[j?70;2Tb02bY/X0]:S<0<>j
e@3EcN80g=SV07A`P@1PEg@0N6^F08QfZP2CO[L0Th2g0080U86h0P2CP;L3
09B1^00K09>0^02EP[X0RgZ^08alZ`2<OJP0Og2G081eU`1eJX`0FE5V04Y3
E@19@U@0IEi`081iR`1mMXH0If1`05QAH@0l<dP0B3iF05mEL01kL900OW:F
08IjXP2DQk<0ThJb09V9^02KRkX0W8bk00<0Vh^j0180W8bk09f=_02OSKd0
WXbl09f=_P2NS[d0WXjk0:>D_`2`Y<X0_k?G08n8VP1OLG/0GhB:06fBV01j
XJP0OZjb07n`]@26[[H508>`]P<0Q;6g0`25/;L508Ja^0D0Qk:i0`28/kX3
08Rc^@D0RKBj0`2;];X508be^`D0SKJl1P2>]kd508nh_P<0T;Nn202A^;l:
09:i`5/0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn
0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/2
0=[JfP0808fCT`1nQ900RI2Z09NR`P2S/Lh0[kgH0:jlf@2`^m/40;6lfP<0
/[gK0140/kkL0;6ofP2`_]T0/KcH0:njeP2[]m40ZKG?0:VccP2X//d0Yk;@
0:RdbP1QJW/0PhbM092H[`2RZLD0[[[B0;W6f@100;S4g0080;W4fP2jaM/0
^<CJ0;o:gP3=e^L0e]cX0=SKi02BTIMR0?ooo`008@3oool03`3no_h0n_[j
0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I0=[JfP2]Zk00Q86<08V5U02IU:X0
ZZ6l0;R_c0020;Zac080^k;=102l/lh30;fdc`<0_[G@0P2o]]430;ngc`<0
`;S@1P31^M460<:jdPH0`k_C0P33^m803034_=@0`k_C0<>kdP36_]<0dL[J
0=[DhP3PgNP0NGF406ALM029Oj40Uh^c0:2C_P80XiBo102VUl840:NH``0H
0:ZI``2YV/<0YYO00:NH`@2[W<D0Z9_60:FH``2WV/D0ZIg30:NK`@2TV;h0
YIVo0:VM``2VV/00Y9Rn0:NK`@2[W<<0]:G<0:fNa@2WV;l0[Yo80;6Rb`2]
W/L0Zic51@2/X<H30:fQa`D0[Z;81`2_XlT40;2TbP0C0:nSa`2`Y<P0/JG9
0;2Tb02_XlL0/:C80;:VbP2eZLd0`;OF0=38g`3>b]P0NWJ705iDMP25MJ@0
SWVb09Em]`2@O[80TGnc09:0]00309>1]@0J09:0]02AOk<0TWnf09:0]02M
Rkl0T82a0920[`2=OJX0QWJS081cWP1jKi40Mfb>075VR01UFWX0F4e]05M<
K01QEW@0J5ek07MYS01mKi<0P76H08MhX`2BPZl0Sgn^09N7]P2MSK`209^;
_080Vh^j01@0W8bk09j>_@2NS[d0WXjm09n=_@2NS;`0WHfn09j>_@2NS[/0
XiBo0;2TbP2o/mL0ShRJ05maN`1OQ8X0KI:H07^RZ@1o[k<0Ok2e08J^]P@0
Pk2f1024/KL208F`]`H0Q[6h1027/[T408Rc^P80R;>i1P29];X208^d^PH0
S;Fk102=][`608jg_@H0SkRn0P2@]kh8096h_`X0T[W0G02C^/40302C^[l0
T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80
oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn
0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0SI>C07j4T029
T:X0Uj;20:>acP2__MP0[[cI0;6lg0<0/KcJ0`2b_M/20;>ng080/KoJ00@0
/kkJ0;6lf02_^mD0[KWC0P2^^=<0202^^ML0[KWA06A]OP2<UJH0WJFl0:nf
dP2ha=`0`m3S@036c^D02033c^00aM3R0<G@hP39eND0emo/0=kRk@3MgND0
TY6FHP3oool00240oooo0100o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL
0=_Kf@3Jf]X0[J^`08B1S029QI@0VIBZ0:ZQ_02h[l`0^[7<0`2k//d30;bc
cP@0_KC?0P2n]M030;nfd@<0_kO?0P30^=070<6id@@0`[[B1`33^m<04@34
_=@0a;cC0<>kdP34_=@0`k_C0<>kdP36_]<0d<WI0=[DhP3Kf><0NWJ506MN
N@27OJ00U8R`0:6D_`2QT[d0YiS30080Y9G000<0YIK10:JG`P2VUl800`2V
Ul802P2YVL00Z9Ro0:VJ``2YV/<0Z9W20:JIa02XVlH0Yi[50:ZK`P2[W<<2
0:VJ`@070:fNa@2/WL@0ZY_20:bMa02/W/80Zig10:NI_@020:jOaP030:ZK
a02_X<T0[9g800@0[:36102]XLL40:jRb0P0[j?9102`Y<X0:02_XlL0/:C8
0;6Ub@2`Y<P0[j?70;2Tb02cYl/0]JW=0<>if`3?amh0f]KT071XO@1QEGT0
R7RY08mj/`2CNkD0U8:d09>1/`2BP;80TGna09:0/P2DP[@0UH>e09J4]P2H
Q[P0UXBf09F3]@2BP;80UhNh0961/P2CPk@0S7b]08YjZ@25MJ@0Q7BQ08=c
X01nKY/0Og2K089cWP20LI`208QhY@0809B4/`2DQ;D0VXZk09R8^@2OSkh0
VHVh09^:_P2KRk`209^;^P0D09f=^P2OSkh0WXjm09Z:^@2OSKd0WXbl09j>
_`2NS[d0WXjk0:>D_`2`Y<X0_k?G08n8VP1OLG/0GhB:06fBV01kXZT0Ojnc
07n`]@26[[H408>`]P@0Q;6g1`26/KP508Nb^@@0R;>j1`29];X00`2:]K/0
S;Fk08be^`0508be^`D0SKJl102>]kd708nh_P03092i_`2A^;l0TKRo00D0
TKRo202B^L000`2C^/40T[W009:i`00209:i`5`0Tk[100`0TkZo09:i_P2B
^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`03
0?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0
n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808fCT`1nQ900RI2Z09NR
`P2S/Lh0/;kI0:jlf@2a_=`30;6lfP80/[gK0`2c_]`20;6ofP0>0;>nfP2b
_MT0/KgG0;2leP2a^mH0/[cG0;:mf`2a_MD0J76209FN[`2Y/LP0^l;N0<C@
iP3?g>e00=3GjP080<gIj@3@g>`0d=c/0=CPkP3Pj?<0iNWb0>7Ri`2DU9IR
0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I
0=[JfP2]Zk00Q86:08V5U02IU:P0ZZ:j0;R_bP030;^bc@80_;?>0`2m]<l0
102m]Ld0_[K>0;jfcP2n]/h30;ngc`D0`;S@1@31^M470<:jdPP0a;cD0140
a;cC0<>kdP33^m<0`k_C0<Bld`38`=D0dL[J0=[DhP3Nf>80O7F506QPN028
OZ00UXZb0:2C_P2RUL00XYJn0:FF_`030:JG`0<0YiS100<0Z9W20:NH`@2X
VL800P2XVL830:VJ``040:ZKa02XW<@0Z9c40:RLa080ZIg50`2ZW/H30:ZN
a080Zio50`2/X<H40:fQa`D0[Z;81`2_XlT80;6Ub@050:nSa`2aYLT0/:C8
0;2Tb02aYLT00P2`Y<P0202fZ/h0_kWE0<g5g03DcMl0LfV106IJOP27MjH0
Sgjb102CPKD209B2]P<0UH>g00@0U8Be09F5]P2EQKH0UHFf0`2FQ[L0102G
QkP0TH6b0920/@2?Ok0208em[P0308in[`2@P;40TH6b0080UXJe00@0UhNf
09R8]`2JR[T0Vh^j0P2LS;/0102KRkX0W8bk09b<^`2LS;/309f=_00B09j>
_@2NS[/0WHfl09j>_@2OSkh0WI2l0::F_P2`Y<P0_kCF08j7U`1NLW/0H8J9
06jCV@1lXjP0P;2d086a]@28[[L0Q:nf1`25/;L408Ja^0@0Qk:i00<0RK:h
08Zc^@2:/kT01@2:/kT408^d^PP0S;Fk1@2=][`708jg_@0308nf_@2@]kh0
T;Nn00H0T;Nn202A^;l709:i`600Tk[100`0TkZo09:i_P2B^L00W<770:o>
d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3Y
jNT0hN7Q0=gMg@3Kfm/20=[JfP0808bAU@22R9H0RI2Z09VR_`2X]<h0/;oF
0;6lf02a_=`40;:mf@D0/kkJ1`2d_m/0202d`mX0/l;I06IbR02Q[<00_<CG
0<G<gP3Df^X0f^3`:03JhN/01P3Mi^l0en3Y0=_Tk@3Kh^`0fmoZ0>3Sk080
fmkW403KhNl0203IgNT0gN7/0=KJh`3Sio00incb0>gbmP3Mh^D0SiFEHP3o
ool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kf@3J
f]X0[J^`08B1RP29QI@0VIBX0:ZR^P2h[lX00P2k//d30;bccP<0_KC?102n
]/h20;ngc`H0`;S@1031^M460<:jdP80`k_C2034_=@04034_=<0`k_B0<>k
d`33^m<0a;cC0<S0e@3Ab]X0f]CR0=kHhP1lMHD0J61h08QnX02FR[80X9>n
0::E`02RU[h40:JG`080YiS11P2XVL820:VJ``80ZY_40P2XW<@30:VMa@<0
ZYk60P2ZW/@30:^Oa@<0[:36102]XLL40:jRb0H0[j?90P2`Y<X80;6Ub@05
0:nSa`2aYLT0/:C80;2Tb02aYLT00P2`Y<P0202fZ/h0_kWE0<g5g03DcMl0
LfV106IJOP27MjH0Sgjb0`2CPKD309B2]P<0UH>g102EQKH209J6]`80UhNh
00<0V8Ri09N7^02FQ[L00P2EQKH0102FQ[L0UhNh09R8^@2HR;L209V9^080
VXZi00<0Vh^j09b<^`2LS;/0102LS;/209f=_080WXjm0100WXjk09j>_@2N
S[d0Whnn09f@_02RU[h0/JG90<2ee`2>QiL0GW9k0626R@1^TiT0O:>X082`
]021/KD0R:jg1P25/;L608Ja^0@0Qk:i1P2:/kT608^d^PP0S;Fk102=][`6
08jg_@80SkRn1P2@]kh8096h_`P0T[W0HP2C^/40302C^[l0T[Vn09:i`02L
`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0
l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0S96E08:8UP29T:X0VJ:o0:Rd
cP2`_mH0/KcH0;6lg0<0/[gI1@2c_]X60;Bof`80]L3L00P0/;kH0;K5g024
T:P0SYV_09bT^@2SZ[d0[[G80:fbaBP0[;C100P0ZkG10:bd`@2`^<<0][g7
0;Bh`@2RYJ`0_l;90<C5bQ00_L;800P0_;o80<?6c`2o`/T0_/760;o2a`2n
`/D0`/K70;k2`f80oooo000Q0?ooo`0@0?knoP3jn_X0m?Cd0>g]k@3UiND0
gmoO0=cLg03KfmT0f][J0:f[/024PHX0RHFD09ZEZ@2ZX[X0^:o:0;^bc@<0
_;?>102m]<l30;jfcP<0_kO?1@30^=050<6id@D0`[[B0`33^m<80<Ble00@
0<Bld`33^m80`k_C0<>kd`34_=<0b<3E0=7:fP3Je>80g]SR07aeQ@1XH7P0
R7jP09J:/P2PTkh0XiK10:>G_`<0YYO00`2WV<450:RI`P<0ZI[30P2ZVl@0
102XW<@0ZIg50:VMa@2YWLD40:ZNaP040:ZNa02[WlD0Zio50:^Oa@@0[:36
0`2]XLL50:jRb0D0[j?90`2`Y<X80;6Ub@050:nSa`2aYLT0/:C80;2Tb02a
YLT00P2`Y<P0202fZ/h0_kWE0<g5g03DcMl0LfV106IJOP27MjH0Sgjb0P2C
PKD309B2]P@0UH>g0`2EQKH309J6]`80UhNh1@2IRKX209Z:^`0309^;_02K
RkX0Vh^j0080Vh^j1`2LS;/309f=_080WXjm0100Whnl09j>_@2OSkh0X92o
09jA_@2RU[h0/JG90<2ee`2?R9P0GW9k0626R@1^TiT0O:>X082`]021/KD0
R:jg1@25/;L608Ja^0D0Qk:i1@2:/kT608^d^PP0S;Fk1@2=][`508jg_@<0
SkRn1@2@]kh8096h_`P0T[W0H`2C^/40302C^[l0T[Vn09:i`02L`LL0[lkC
0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3o
ool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WY
j@3QhN40gMgM0=_Kf`80f][J00P0S96E08:8UP29T:X0VJ:o0:RdcP2`_mH0
/KcH0;:mg@80/[gI1P2c_]X50;Bof`<0]L3L00P0]<;M0;S6h@2W/ld0R9:[
08J@Z@26SZD0R8jV08:8WRP0PhjR00P0Q8bO08^DY@2@UjL0W::^09VMYP1Y
K740][Nk0;Zk_A00^K^j00P0]KBj0;Je^`2i^;d0]kJk0;fm_`2l_;`0`/;2
0>KViV80oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cL
g03KfmT0f][J0:f[/024PHX0RXJE09ZEZ@2[Xk/0^K3;00<0_;?>0`2m]<l2
0;jed080_[K>0`2o]ll50<2hd0H0`KWA1032^]840<>kd`P0a;cD0100a;cC
0<>kdP33^m<0`k_C0<Bld`38`=D0dL[J0=[DhP3OfN<0O7F506UQN@29Oj40
Uh^c0:6D_`2TUl80XiNo0P2VUl030:NH`@D0Z9W20`2YV/<30:ZKa0<0ZIg5
0`2ZW/H20:^Oa`<0Zio50`2/X<H40:fQa`H0[Z;8102_XlT40;2TbPP0/JG9
00D0[j?70;6Ub@2`Y<P0/:C80;6Ub@020;2Tb0080;JZcP2o^MD0cLGL0=C=
g`1cJH40Ie]o08MgYP2@Ok<409B2]P<0UH>g0P2FQ;P209F5]P<0UXJg1@2G
QkP209R8^@0409V9^P2JR[/0VXZk09Z:^`X0W8bk0`2MSK`309j>_@0@09n?
_02NS[d0Whnn0:2@_`2NTKd0XiNo0;6Ub@30]ML0ShRH05ibN`1PQXT0KiBJ
07bSZ020/;@0PK6e08R^]`@0QK2g1P26/KP608Nb^@@0R[>i1P2;];X808be
^`H0SKJl102>]kd408nh_P@0T;Nn202A^;l809:i`6@0Tk[100`0TkZo09:i
_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?oo
o`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3m
oOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bAU@22R9H0RI2Z
09VR_`2Y]Ll0/;oF0;:mf@2b_Md50;>nfPL0];oK102e`=`0202b`=d0/kkJ
0;_6hP2[]]80/[cG0;K0f`2g_]P0^L3J:02e`M/0202f`=T0`<SO0<[Ai03D
f^P0e=SQ096EV03koO`0o_kl403oood00`3oo_l0oO_n0?ono`020?omoP03
0?ooo@3in?H0ooom0680oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3U
iND0gmoO0=cLg03KfmT0f][J0:f[/024PHX0RXJE09ZEZ@2[Xk/0^K3;0080
_;?>0`2m]<l30;jed0<0_kO?0`30^=080<6id@H0`[[B1033^m<80<Ble00@
0<Bld`33^m80`k_C0<>kd`34_=<0b<3E0=7:fP3Je>80gmWS07aeQ@1YHGT0
RGnQ09N;/`2QU;l0Y9O20:BH`0<0YiS10`2XVL850:VJ``<0ZY_40P2[W<D2
0:VMa@<0ZYk60`2[WlL20:^Oa@<0[:360`2]XLL60:jRb0H0[j?9102`Y<X8
0;6Ub@050:nSa`2aYLT0/:C80;2Tb02aYLT00P2`Y<P0202fZ/h0_kWE0<g5
g03DcMl0LfV106MKO`28N:L0T7nc0`2DP[H309F3]`<0UXBh0`2FQ[L309N7
^0@0V8Ri00<0VHVj09Z:^`2JR[/00`2KRk`309^;^P<0W8bk1@2MSK`309j>
_@80Whnn0100Whnl09n?_P2OSkh0X92o09jA_@2SUkl0/ZK:0<6ff02?R9P0
GW9k0626R@1_U9X0O:>X082`]022/[H0R:jg1025/;L408Ja^0H0Qk:i0P28
/kX408Zc^@@0RkBj1P2<]K/808ff_0H0S[Nm102?^;h4092g_PP0TKRo202B
^L1T09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3o
ool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3J
f]X0202<TID0PXRF08V@ZP2JXl00ZKG?0;70e`2b_MT0/kkN0`2c_]X90;Bo
f`@0]L3L00P0]l;P0;>ng02g`]h0^<?O0;K1g@2i`]l0/[_H0;Jog2P0/l7L
00P0]l3M0;c6g`3;dnP0dMOU0=GIhP2@TID0ooom0?oona00ooko00P0oO_l
0?_inP3oo_l0ookl0?ckn@3oo_`0o_gk0?cknF80oooo000Q0?ooo`0?0?kn
oP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03KfmT0f][J0:f[/024PHX0RXJE
09^FZP2/Y;`0^[7<00@0_KC?0`2n]M000`2o]]40_kO?0;ngc`030<2hd0P0
`KWA1P32^]850<>kd`P0a;cD0100a;cC0<>kdP33^m<0`k_C0<Bld`38`=D0
dL[J0=[DhP3OfN<0OGJ606UQN@29Oj40V8bd0::E`02UV<<0YIW10P2WV<43
0:RI`PD0ZI[30`2ZVl@30:^La@@0ZYk60`2[WlL00`2/X<P0[:360:bPaP02
0:bPaP<0[J771P2^X/P60:nSb@D0/:C:202aYLT01@2_XlL0/JG90;2Tb02`
Y<P0/JG90080/:C800P0]Z[>0;nie@3=aM`0e<gO07=YP@1WFgl0R7RW0960
]0D0UH>g0`2FQ;P00`2GQKT0UXJg09J6]`0309N7^0D0V8Ri00<0VHVj09Z:
^`2JR[/00`2KRk`309^;^P80W8bk1@2MSK`309j>_@<0Whnn0100X92m09n?
_P2PT;l0XI7009nB_P2SUkl0/ZK:0<6ff02?R9P0Gg=l0626R@1_U9X0O:>X
082`]022/[H0RJnh0`25/;L508Ja^0D0Qk:i0`28/kX308Zc^@D0RkBj1@2<
]K/808ff_0H0S[Nm1@2?^;h3092g_PP0TKRo202B^L1U09>j`@0<09>j_`2B
^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3o
ool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0
oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202<TID0PHNE08V@
ZP2JXl00ZKG?0;70e`2c_]X0/kkN1P2d_m/20;G0g0<0];oK1@2e`=`0202d
_m/0]l;N0;>nfP2jaN40/[gI0;O2gP2c_]X0]l;N:02c`Mh0202g`]h0_<KQ
0<_Cj03AenL0eMWR09BEV@3oood0o_gi403ooOl20?ooo@030?ono03noO/0
ookl0080oogn00<0ooko0?ooo`3oool0H03oool00240oooo00l0o_kn0?[j
nP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kf@3Jf]X0[J^`08F2R`2:QYD0ViJZ
0:bT_02j/L`00`2m]<l30;jed080_kKA0P2o]ll20<2hd0P0`KWA1P32^]86
0<>kd`P0a;cD0100a;cC0<>kdP33^m<0`k_C0<Bld`38`=D0dL[J0=[DhP3O
fN<0OGJ606UQN@2:P:80V8bd0::E`02UV<<0YIW10P2WV<420:RI`PH0ZI[3
0P2ZVl@40:^La@<0ZYk60`2[WlL20:bPb0<0[:360`2]XLL60:jRb0H0[j?9
1P2`Y<X80;6Ub@050:nSa`2aYLT0/:C80;2Tb02aYLT00P2`Y<P0202fZ/h0
_kWE0<g5g03DcMl0LfV106MKO`28N:L0TH2d102EPkL309J4^080UhFi0P2F
Q[L209N7^0H0V8Ri0P2IRKX209Z:^`80Vh^l102LS;/609f=_080WXjm102O
Skh0402PT;d0Whnn0:2@_`2QTL00Wi:n0:BH`02bY/X0`KKH08n8V01OLg`0
HHN:06nDVP1mY:T0PK6e08:b]P29[kP208F`]`H0Q[6h1027/[T408Rc^P80
R[>i1P2;];X408be^`P0SKJl1P2>]kd608nh_P80T;Nn202A^;l809:i`6H0
Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3o
ool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP08
08bAU@21QiD0RI2Z09ZS`02Y]Ll0/L3G0;>nfP2d_ml50;Bof`<0]L3L0P2d
_m/60;G0g0080;>of@2ha=h0]<3J0;G1f`2b_MT0]<;M0;?1g02d`]dX0;G0
g0080;K2g02nb^80b];W0=GKj`3EfN@0UIJK0?omoP3oo_`@0?knoP040?oo
o@3oool0oOgm0?gmo@80oooo00<0oOgo0?ooo`3oool0H@3oool00240oooo
00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kf@3Jf]X0[J^`08F2
R`2:QYD0ViJZ0:bT_02j/L`00`2m]<l20;jed0<0_kKA00@0_kO?0<2hd030
^=00`;S@0`31^M400`32^]80`KWA0<6id@020<6id@@0`[[B1`33^m<90<Bl
e00A0<Bld`33^m80`k_C0<>kd`34_=<0b<3E0=7:fP3Je>80gmWS07efQP1Y
HGT0RX2R09R<]02RUL00YYW40:FI`@2WV<400`2XVL830:VJ``030:ZKa02Y
V/<0ZY_40080ZY_40`2[W<D0102/WLH0ZYk60:ZNaP2ZW/H20:^Oa`<0[:38
0`2/X<H20:fQa`L0[Z;8102_XlT70;2TbP030;6Ub`2aYLT0/JG900H0/JG9
00D0[j?70;6Ub@2`Y<P0/:C80;6Ub@020;2Tb0080;JZcP2o^MD0cLGL0=C=
g`1cJH40J5b008UiZ02AP;@409F3]`80UXBh0`2GQKT0102FQ[L0UhNh09N7
^02GQkP309R8^@0309V9^P2KRk`0Vh^l00<0Vh^l0P2LS;d00`2MSKh0WHfl
09f=_00709f=_0<0WXjm0`2OSkh04@2PT;l0X92m09n?_P2PT;l0XI7009nB
_P2TV<00/ZK:0<:gf@2?R9P0Gg=l0667RP1_U9X0OJBY086a]@22/[H0RJnh
00L0Q[6h1@27/[T408Rc^PL0RkBj1@2<]K/808ff_0@0S[Nm1`2?^;h00`2@
^Kl0TKRo096h_`05096h_`P0T[W0202C^/400`2D^l80Tk[109>j`@1N09>j
`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3o
ool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo
0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202<
TID0PHNE08V@ZP2JXl00Z[K@0;70e`2c_]X0];oO102d_m/;0;G0g0070;K1
g@2e`MT0]/;J0;G1f@2b_]P0]/CN0;?1f`020;;0fbP0]/3K00P0/;kH0;k:
h035cN00e]g]0=CFhP2BTiP0o?[m0?onoa00o_ok0P3koO`01P3nool0oOon
0?_loP3nool0oOko0?koof80oooo000Q0?ooo`0A0?knoP3jn_X0m?Cd0>g]
k@3UiND0gmoO0=cLg03Lg=X0f][J0:bZ[`24PHX0RhNF09bGZ`2/Y;`0^K3;
0;fdc`2n]M000P2o]]420;jfcP80_kO?00/0_KG<0<>kdP32^]80`k_C0;fe
c@33^m80`[[?0<>lcP32^M@0_kO?0<6id0020<Bld@0A0<6id030^=00a;_F
0<Jne@33^m80aKgD0<Bld`35_M@0akoF0<:jd@35_M@0_[K=0<S0e`33^m80
`[[A0<Bld`31^M000P33^m807P36_]<0`k_B0<2hd032^]80akoG0<W1f03>
amT0gMKX0=gGh@1nN8H0JF5h08MlW02ISK<0XiNo0:NH`@2XVL00YY[20:BH
_P2XW<80Y9Rn0:VMa@2XW<@0Zio70:JJ`02VV/80[J790:ZMb02VV/80Yi_1
0:VM`@80ZYk40200Zio30:^Oa@2/X<H0ZIg50:bPb02ZW/@0/jO=0:ZN`P2[
WlL0ZYk60:^Nb@2bYM00ZYk60:nSb`2^X/P0[j?70:fR`P2^X/P0[Z7=0:jR
bP2_Y<@0[ZBo0:jS``2_Xl/0/:G70:jSa@2bYlT0/jS:0:nTaP2`YLL0/jS:
0:nTaP<0/:G501T0[Z?30;:Wb@2aY/P0[J;40;:Wb@2^Y;l0]:W90;6Ub`2`
Xlh0[Z7<0;2TbP2_Y<@0^:k90<>jf@3>a]d0eLkN07E/P@1UFWX0RGbX09:1
]@2EQ;P0Th>d09R8]`2?Ok00VXZk0080UXFi00h0TX:c09b<^@2HQK`0VXNn
09R5_@2EP[X0VHJn09Z7_P2HQ[X0WH^m09b;]`2JRKH0VHNg09Z8^080WXfj
00X0W8Zj09f;_@2OSKd0XY6n09N7]P2QTL00WHfn09^=_P2FRKL0Wi:m0P2N
SKL05`2NSkX0YIG209n?_P2KS[X0XYG109nB_@2QTKh0X92m0:6A`02RT[l0
Wi:m0:BH`02bY/X0`KKH08V;V01SLG`0IXF:06jEVP1lYJT0Qjje08F`]P25
/[P0QK2f0080Qk:h0P26/KL04028/kT0RKBj08Rc^@2:/kT0R[Fk086a]@26
/kP0Q:ne08ff_02;];X0R[>i08Zg_025/[L0QkBi08Zg_024];H208Jf^00D
08Fe]`2<^Kh0Q[>h08Jc^02:]k`0RkJl08Ze^`29];X0S;Nm092e_@2</kX0
TK[008jj_@29]KP0S;Rk08jg^`2=][P0TkFo09:g_`2A^;d308nh^P0F092h
^P2@]k`0TKJl096h_@2B^Kh0SKBi09:g_@2F^l40T;Fk09>j_`2A^[`0UKfo
096h_@2@]k`0UKc109:g_`2@]Kd0UK[209>l_P2A^K/0UKfo096h_@80UKc1
00`0TKJl09Bi`@2B^;T0U;bl096j_02?^kh0UL3609Bla02C^L80UKW509Bj
_@2A^K/209:k_`0D09>l`02C_<80TKRo09Bi`@2A^K/0Tk^m09:k_`2@^Kd0
TKRm09>h`02G^L80V;W209:i_P2@^K/0S[bl08Zj^P2<_;`0TKg009Bm``2B
^<4209>j`@0=09Jk`@2D]k/0U[Vm09Rm``2C^/40TKRo092g_02E_<40T[Vn
09Bi_`2H_L<0U;Vo09:g_@0209Rk`@0708nb^02F^l40T;Fk09Vna02C^;h0
T;Nl09Bk`00209>h_P0N09:i_P2G_/<0T;Nl09>h_P2E^;h0UKJm09Jh`@2G
^/00UK^n09Bl_P2C_;h0Tk^m09>j_`2D^L40SkVh09>k_@2F^<40UKG209Ni
a@2E^/80T;Vk092l^`2H^L80UKRn09Nm`02?]kL0T[bk09O0`P2>]KX0UKc3
202C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo
0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J
00P0S96D08:8UP2;TjX0VjC10:Zfd02a`=L0/koI0;Bog@@0];oK?02e`=`0
202e`M/0_LOP0<[Bi@3Df^X0e=SQ096BU`3oool0ooomNP3oool00240oooo
00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=cLfP3Jf]X0[:Z_08B1
RP2;QiH0W9N[0:bT_02j/L`00P2n]M000`2o]]40_kO?0;jfcP020;jfcP0B
0;ngcP31^M00_;C<0;Vab@2k/l/0_;C<0;jfc@2l]</0`KW>0;jed030^=00
_kO>0;Zba`2k/lP0`[[A0<>kd`30]m80_kO>0P31^M00<`2o]lh0_[K=0<>k
dP2m]L`0`KW@0<Fme02k/lX0`;S?0<NoeP2n]/d0`;S?0<W1f030^<l0_[K;
0<Bld`38`=P0a;cD0<2hd033^m00c<GG0=?<g03OfN<0MFin06]SN`2?Q:H0
UHV_0::F_P2XW<@0X96h0:FI`@2WVl<0XiNm0:FI_`2YWLD0XiNo0:NK``2Y
WL<0ZYk60:FI`@2VV/80ZIg50:bPaP2[WlD0YY[00:VM``2VV/00Z9c20:VM
``2]XLT0[:380:BH_P020:VM``0@0:^P`P2]XLD0YYZn0:RL`02ZW/80[J;4
0:VN`02aY/H0/jS80:jRb02_X/d0[j?;0:fR`P2^Xl40[jC60;6Uc@80[Z;6
00@0ZIg10:jRaP2`Y<P0[J750P2`Y<P08P2cZ<X0Yibn0;>XbP2_Y<H0ZIk0
0;2Tb02cYl/0Z9c00:jS``2_Y<H0[J770;6Uc@2cYll0[j?90:bQ``2bYlL0
^k;A0<W1f@3?b=X0L6In06QMO`29O:X0SGnb09>2]P2BP[<0UHFf09N7^02B
P[<0TX6e09F5]P2HR;L0Sgn^09B4]@2CPk@209R8^@0]09B4]@2IRKP0Vh^h
09B4/@2HR;D0UHFb09^;^P2NS[d0UXJe09N7]P2OSkh0VXZk09b:^P2MSK`0
WXjm09V9^02IRKX0VXfk09b?^`2BQK40WHji0:2@_@2LS;T0VHVh09^;^P2O
T[h0X9>o09Z=^@2QTKh0X92m0:6A`02RT[l0X9>n0:BH`02cYl/0`[OI08V;
V01SLG`0IXF:06jEVP1lYJT0Qjje08F`]P25/[P0QK2f0080Qk:h0P26/KL2
08Rc^@0:08Nb^023[[@0Qk:h08Nd^@2;^;d0RKBj08Vb^027/;H0RK:h08N`
]P80R[>i00L0RK:h08^d^P2>]kd0RkBh08J_/`24[K<0S;Fk0080RkBj0100
R;6g08fd^`2=];/0Rk:i08jd_@2:/KP0S;Fk08^d^P2;]kX0SKJj08N`]02?
^;`0TKO008Za^02</kP0SkJk0P2=][P0202<]KT0S[Nk08bc^02?][/0TKRm
09:i_P2?][/0S;>h0P2=];T01@2<]KT0S[Nk096h_@2=];T0T[W00080T;Nn
00D0TkS0092g_02B^Kh0TkZo096h_@0208fd^@0<092g_P2=];/0T;Rj096h
_@2A^[h0S[Zm08ji_`2@]kh0T[O009>e_`2B]K/0UKRn0P2B]kd0102@]Kd0
SkBl09Bi`@2F^<42096h_@0F08nf^`2>]k/0SkJm096h_`2B]kl0T;Fm09>h
_P2A^;d0TkZo09Bl_P2C^[l0SkJk092e_@2D^L40S;>j09Fl``2?][/0U[_1
09:g_@28[k@0T[W008je_080T;Nl0`2?][/2096f_00;092e^`2?];X0Ukc2
09:g_@2G_<80RK2e09Bk`02B^Kh0TKRm096f_02B^Kh00P2>]KX0202A^;d0
T[Nm09Fj`02F^Kl0UK[208je^P2?][/0TKRm0P2@]k`03@2>]k/0T;Vo09>i
_02E^/00T[No096e`@2B]/80T;Nn08nh_02A^[`0S[>k09>h_P2;/kD00P2@
^K/00`2?^;`0V/78092f_`0809>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0
_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?oo
o`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY
0>7Qh@3MgMd0fm_K0P3Jf]X0202<TI@0PXRF08^CZP2KY<40Z[K@0;70e`2c
_mT0];oM102d_m/l0;G0g0080;G1f`2man00b];U0=CJjP3Df>40TI:G0?oo
o`3oooej0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3L
g=`0g=cJ0=[JfP2/ZZl0Q86:08^7UP2LUj/0[:Bl0;Zac0020;nfd@0:0;jf
cP2o]ll0_[K>0;jfcP2l]</0^k?:0;ZbbP2d[<@0/j_30;F]a0<0^k?:00X0
^[;90;^bc@2f[/H0]Jg40;^cb02m]LX0^[;90;ZbbP2n]M00_kO?0P2i/LT0
3P30^=00^k?;0;jfcP2k/l/0`KWA0;^cb`30^=00_;C<0;R`b030^=00_kO?
0;Vab@31^M40aKgB0P33^m803`31^M40^k?:0;jfb`38`M40cLOE0=C>fP1g
L800IUif08MmW`2CQjd0VXjf09b@^02QUK/0WI6g0:>G_`020:6E_@040:BH
_P2VV/00XYJl0:RLa080YIW100h0Yi_109jB^02OTkT0YY[00:>G^`2VV[h0
XiNm0:RL`P2TV;h0YIVo0:JJ`02ZW/@0Zio50:NK`@<0XYNg00l0Z9fm0:JK
^`2[X<00ZYno0:JK^`2ZWkl0Y9Rl0:NK``2]XLL0[J;40:^P`02YWL40YY[2
0:VM`@2SUk/00P2WVkl03P2[WlD0[J770:NK`@2bY/`0Zio30:RL`02WVkl0
XYJj0:nSa`2XW<00X9Bh0:NK_`2ZW/80Yi^o0P2]XLD0;02XW<00ZIg10:fQ
a@2UVKd0^JoA0<2hd03?am`0K6Al06=GN`25N:H0RWb_08n1]02DQ;D0SGf^
09J5^@2@P;40U8Bc08alZ@2EQK@0UhNf09B4/@2?Oj`0RgbW08n0Z`2APZd0
S7fV08n0Z@2IR[<0UXJg09^;^P2@P:d0Sgn^09J6]@2EQKH0UhNf09Z:]`2K
RkX0U8Bc09b<_@2FQ[D0VHbh08n2[@2GR[H0V8^g0P2HR;L00`2GQkH0UXJe
09Z=^@0209^>^P0B0:>F`P2QTKh0XI6n0:6A`02RT[l0X9>n0:BH`02cYl/0
`[OI08Z<V@1SLG`0IXF:06jEVP1lYJT0Qjje08F`]P25/[P0Q[6g0P27/[P2
08Ja]`0K08Rc^@27/[P0QK2f082]/`26/KP0R;2h082X/020Zk80Q:nf08J^
]P24Z[<0OjJ]08F//`24Zk80PjR`08V^]P2<[[L0Rjff08V[]021Z:l0R:nf
08FZ/P26Zk<0Q:Va08Z_]`29[[H0Rk2h0080R:jg01X0SKBk08V`]`25[;<0
RK:h08Ra]@27/;@0Qk:h08be^`2D^l80S;>j08R_]02<]KT0Qk>f08>_/P25
[[@0SKBk08F//`2?][d0S;Fk08B]/`2A^/00R[6h08V`]@20Yj`0SKBi08^b
]`80R:nf0P2?][d0902?/[P0V;g308Z_]@2>/kT0SKBk08J]]02>]K`0QZne
08^b^@27[[D0R;6g08Ze^`2<]K/0TKRo09>e_P2?/;T0T[>j08f^]@26Yjh0
S[6g09>e_P2B];d0U;W108nd_02B^Kh0S[Fj08bc^02:/KH0Qjje08J]]029
/;L0SKBk08fd^@2F^l40V;_109Be_P80TK:k01D0Rjff08V[]02A^;d0QZfb
08nf_@2;/[T0R[6h08bc^P23ZZl0SKBi08J]]02:/KP0T;Nn08je_028[kH0
S;>j08nf_@2</kX0S[Fl08V`]`27[[D00P2A^;l08`26[K@0S;>j08V`]`29
/;L0QZfd08Za^028[KD0RJjf08J[/`2A][h0R:fe08Zf^@2?^;`0U[g408nd
_02:[kL0SkJm08^d^024/;<0SZnf08Z]/`27[KH0S[Jn08ng_`2;/KX0R[6f
092e^`2;];X0QJjb08ff^P29/[@0RK6c096h_@2>];d0TkW400P0Tk[100`0
TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3n
o_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0oooo
0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bAU022
R9H0Ri>Z09^T`@2Z]]00//7H0;>of@2d_md30;Bofcd0]L3L00P0]L7K0;g7
h03:d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0oooo000Q0?ooo`0@0?knoP3j
n_X0m?Cd0>g]k@3UiND0gmoO0=cLg03KfmT0f][J0:bZ[`25PX/0RhNF09bG
Z`2]YKd0^[7<0;nfd@<0_kO?00@0_[K>0;^cbP2g[lH0]:c30P2[Y[`30:^V
^P0<0:bW_@2i]</0/jk50:jY`02^ZKl0Z:>g0:FQ/P2XY;D0[ZVm0;B_a@2a
[<<0/j_20`2d[<<0A02/Y;/0]jo60;N_aP2`Z;l0/Z[10;F]a02d[<<0ZJ6h
0:^S^P2cZl80]:c30;Vab02l]<T0_kO>0;jfc@2l]</0]Jg20;:[_@2j]<80
_kW50<K3cP1_JgX0GEE]08EkW@2BR:d0VHfc09Z>]02HS;00V8f_09J:/02J
SKP0V8bd09V=/@2TVK/0WI6e0:>G_`2MTKT0W92d09fB/P2MT[@0WY:h09Z>
]02HSJl0X9Fc0:>G_@2MTKL0VXjb0::G^@2PUKL0X9Bh09jB^02MTKL0UXb^
09jE]02HSjh0V8n/09jE]02OU[D0X9Jh0:FK_P2RUkL0XYNi09jB]P2WVkl0
ZYo10:FJ_02WVkl0XiNm0P2OU;H0E`2KT;80XYJj0:FI_@2TV;h0Z9c20:>G
_`2UVKd0XiNk0:6E^@2MTKD0Wi>g09B9Z`2JSk40Y9Vk0::F^P2WVkl0Yibn
0:^P`P2^XlD0XIJh09^?/`2WVkl0Y9fl0;Zec02f[/<0I5ad069HN`1gJYH0
S7n]08f0[02BP[40S7b]08im/@24M:<0RgbU08QiX026Mj80RGVX08IiY@24
Mj80QGRS08AhX021MI/0SH6Y09F9/@26NZ80QgVZ08aoZ`28O:@0RgjY08f0
[P28NZ/0S7n[0924[02IRKH0Th>b09F5]P29O:P0SX:X08YnXP25NZ80QgbW
08YmZ@27NZH0SH2[08j1[02FRK@0UhZf09Z:]`2QTL00XY:o0:6A_P2QTL00
XY:o0:2C_P2TV<00/jO;0<:gf@2:S9T0Hg5l06J5RP1_UY/0O:FY08N^]@25
/;H0QK:h08Ja]`0208Nb^01Z08Ja]`27/[P0Qk:h08Ja]`23[[@0Ojnc07bU
Z`1oY:`0OZ>[08>Z/@1lYJ/0Nj:Y07fRZP1jXJH0Nj:W07fRZ01nXjT0Q:J_
07nQZP21Xj`0P:6Z086V[01lXJL0MibR07bSZ01oYZ/0PZV^07ZQYP20Yj`0
QJfe08N]]P1lXJT0OZ>[08Z/]@20YJ/0O:6W08N^/`1oZjh0PJZ`08V`]`2:
[kL0R:fe08>X[P1iXJ<0OJJX07bUZ@1mXZP0QjZ`086V[023[;00QK6d07bS
Z024Yjd0PjJZ082SY`23YZ`0MibR086V[029[[@0R:fe08BY/@2@/KX0QjRa
08^]]P25Z:h0OJ:X08J[/@1lXJL0OJBY082R[020YJh0QZfd08^b^@29/;L0
SkBj08b_]@2;[;<0PJBX08JY[@28Zk40RJbb08NZ/026Zk40S;>j08be^`2;
/[T0Qjbb08JY[`24Yjd0P:>Y07fRZ021Z:d0QJf_08Fa]02:/KH0Rjff092^
^02:Z;80PjB[07jQY`24ZZd0Oj:V08>X[P25Z[00QJbc08:Y/080OjBZ00D0
Oj:V08JY[`1oY:X0PZN]08BY[`0208:W[@0;08>X[P24Zk00QJba08F//@28
[k@0OZ>Y08N//P1lXJL0QZ^a07jSZ@1jWjD00P23YZ`07@1kWZ@0R:^a07jQ
Y`21YZ`0QJba08:^[`24[K40Rk:i08Z_]`2;[KH0QJZb07fTZ@20ZJ/0S:Zb
08RY/P26Zk<0OjR^082Y[`29/;L0RJjf08Z[/P1oZ:`0OjJ[07ZRY022Z:/0
SK>f08jc^`2@][l0T[S300P0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2n
dmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo
0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0
hN7Q0=gMg@3Kfm/20=[JfP0808bAU022R9H0Ri>Z09bU`P2Z]]00//7H0;>o
f@2e`=h20;Bofch0]L3L00P0]L7K0;g7h03:d^D0e=[Z0=CHh@2ATYL0oooo
0?oooGX0oooo000Q0?ooo`0@0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cL
g03KfmT0f][J0:bZ[`25PX/0RhNF09fH[02]YKd0^k;=0;jfcP80_kO?05d0
_kO>0;bdb`2g[lH0[jNn0:ZR]`2QW;00ViNX09JBX@2OVjX0XYj]0:BO/`2^
ZKl0Y9jh0:FP]02PW:d0VIFT09fIZ02PW:/0Wi^Z0:FQ/P2XXkL0ZJ6f0:RP
]@2WWk@0Z:2e0:NO]02RVZl0Xi^`0:RP]@2TWk<0YZ6e0:BO/`2NVJd0XYfa
0:NR]P2YY;P0/Jc00;VaaP31^M00^;370;:Z`@2_Z;X0ZZ>c0:fW/`2^ZK00
/Znh06UUL`1ED6H0OWFB08IlWP2;PJ<0SH:T08b1X@2;PYd0R7jQ08b1Z@2A
Qj`0ShJS09B;YP2FSJ`0TXN_09B:[`2CRZT0S8BL08b3WP2@QZP0TXR]09B;
ZP2CRj80U8Z]09F;[@2FSJ`0TXVV08j5XP2HSjh0VY2b0967ZP2GSJl0RGnQ
08MnV`2BRJH0THRU08n5Y`2ISk@0UHZb09:9YP2JTJh0UXfZ09bC/P2OUKL0
VY2b09fC]@2HS[000P2>QJ00102BRJH0SXFT09>9Z`2NU;H20:2F^@0<09V?
/@2JT;80ShJU08j5Y02CRZL0T8NT08j5XP2<Pih0TXVX09^B/@2SV[T0Yijm
0P2LTk80A@2GSZd0T8NV09ZE[02QW;00[JVh061HK`1FCF`0M6VA07a`V024
N9`0R7^V08AgY@27NJX0PgJQ07]`T024NIL0O72F08EhYP1oLYh0Q7NR07ea
V@1kKi<0OW:F07]_U@20M9`0QGRS08EhYP1oLi/0OG:D07mcU`1oLYd0PWFQ
08UmX`2:Oid0T86Z08emZP2=P:h0R7bT07icT@24NiH0NW2C089gXP1oMIX0
OWBG08=iV`1oM9H0S82T09Z;]02PT;d0Vh^j0::B_`2QTKh0XY;10::B_`2P
Tkh0YIW10;>Wb`32]mT0RXbI06=aO01VQHX0KiJK07bUZ@27[[D0Q[6g08Fb
^026/KL0Qk:h08Rc^@0308Nb^00d08B_]@20Zk40MJFW07RMX`22WjL0OIZR
07RKX@1gWZ<0M9VO07FCV`1`TiD0KY6C076DUP1bV9/0MifP07:GW@1jWjD0
LIJL06jAT`1bUIL0MYVK06nEUP1^U9D0M9bL07FMW@1iXJ40MijU07^PZ020
XJP0P9jV07JCV`1eU9T0OIjS07JIW@1oYJH0PZR[08:W[@1nXj/0P::[07VJ
X@1bU9H0N9NI06jFV01gV9d0O9NN07jMXP1mXjH0N:6S07RKW`1lVIl0MI6E
07NDV080NIJJ00X0NYVN07^JW`1lWJ80QjR]08NU[@2;ZK40OifU07ZHX01g
UY/0O9^P0P1dTiH0;P1jUIh0OIZR07nPY`26ZJl0RJbb092c^@22XjX0OYnV
07JLW@1fVI/0LiFG072BU01iW:00PjV/08>/[P21[jl0P:F[08BW[@24XjP0
NYNM07>?T`1iUYX0OYfP07VKW01nZZ/0Pjb`082W[P24YZl0Oj2Y07nPY@1e
V9X0LiNE086MX020WJ40OIjS07fPYP1lWjD0NY^P07ZGV`1kUiX0NIJL07ZG
W@1mW:40NiZO07fLX@1oX:D207^LX@0C07bOX`1jWJ40NYfQ07VJW`1mWZ<0
PZ6V07ZIWP1iV9d0O9^P07BAU`1lUih0OIRO07RCVP1hUi`0NY^P07NMX022
YJL0QjZ^08JY[`02086S[00C07fNY@1iV9d0OIbO07fJXP1fU9`0NIZQ07bO
X`1nXJD0PJBZ07nPY`1kW:<0MYVM07VKW@1lVih0OIZN086PX`29Z[40S[>l
092f`@0809>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0
n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?kn
oP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K
0P3Jf]X0202<TI@0PhVG08^CZP2LYL80ZkOA0;;1f02d`=X0]L3N1P2e`=`2
0;K1gCP0]L3L00P0]L7K0;g7h03:d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0
oooo000Q0?ooo`0`0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03KfmT0
f][J0:bZ[`25PX/0S8RG09fH[02^Y[h0^k;=0;jfcP2o]ll0_kO>0;fec02h
/<L0[jNn0:JN/`2PV:d0THfL09RDXP2MVZ<0YZ>/0:FRZ`2PW:/0UI2T09nJ
/@2FTZ40ThnM09NDW`2]Z[<0[jbe09^HX`2GTj40V9BS09VBXP2FSil0Ui2P
09J?W`2PVJT0VI:R0::KZ`2TWJd0Ui>R0P2CSih0UP2IUJ@0ThnN09>?WP2S
Wjh0ZjNf0;B/`@2h/<L0/Z[10;2X_@2TWJl0UY2N0:>NY@2a[;80_[_207Eb
O@1KEfP0LFb307ieTP2>QJ80P7NB08=kT`22NXl0QWfJ08UoY028OZ00R82G
08EnT02CRZD0ShFX08^1Y01lM8`0QWn?08j6V`24NiP0PWRJ08R0V02:Q980
Rh6S08V0W@2>QYh0RH6H08b4V`26OYH0R7nL08n5Y`24NiP0QgjI09F=Y02R
VZl0VY:Y08V0V`2?QJL0S8:W08^2W@2;PiX0Th^P09B<Y02ES:/0W9:d09F<
Z`26OIP0RX>E0:FN/02ESJ80RH6H09B<Y02?QZ40S8>P09F<Z@2=Q9l0QgjI
08MoU`2:PYT0O7B;08EmTP22NXl0RX>E08f5VP2LU:`0Vi:_0:FK_@2HS[00
Uhj[08R0V02=QIX0T8bK09VFX@2GU9d0FEET0559H@1]I8<0L6N407adS021
MI/0OW6M07a_W@1eJHd0N6j609jEZ02:Oid0MVVD07=XT01bJ8/0MFb;08j5
X02HSjX0QgjK07Y`TP1dJXd0LfRB07A[RP1gKhH0KfMo079XRP1mLiP0Ng:?
07mhRP28O:00QGRS089eX@1iKY00NG6609fFYP27OYT0LVN?075/P`1dKhD0
NWF;07mgSP2=Pih0RgfQ09^<]`2STl@0XY:o0:6A_P2RT/40Xi?00:2C_P2U
VL40/jO;0<:gf@2:S9T0I79m06J5RP1_UY/0O:FY08N^]@26/KL0Q[>i08Ja
]`80R;>i0`27/[P07@23[[@0OZV_07^YZ@1^SI80M8RA07b@V@1aSY@0L9JI
06b=TP1aRY40KHN606^5QP1^RX/0LY2B07BCU@1TQXP0KY6E06f@U01[QHH0
OiVJ08ZVY`1nVY/0LHn?06J6Q@1jVYT0LI>B07^QY01cU9T0MI:H0080MhjD
07/0N8nE06j:S@1aSi40O9BF07fIW01jVj00P:>Y07JIW`1]RXh0P9FH096Q
X@1fV9X0I7f207R9T@1nTYT0KHb?06jAT`1eTYH0NHbC07J8S02L[k<0S9nS
07N<S`1_Qh/0NY:F07RAU@1iTYH0N9NL07JEVP1gU9X0N9BH06n8S01bRXh0
JGj107N<S`1iR8d0NhjD08:JWP26XjL0OijQ08RY[P1mWZD0O9fT07>AT@1d
T940KhV:07N?T@21VYh0N9NI07:IV01jY:80PZFW07^JW@1dSI80MHR>08:D
V02FZ:`0U:RY07jCU01cUiL0NIbN07bOY@20XjT0KXnF07>@U01iTi80PIZF
09V][020UIH0PIZO07FBV01aSY@0Mi2E07N<S@2CYjH0V:^a07bAUP1dRHh0
Lh^?07><T01dSI40L8b?07ZFV@1cT9@0MY>G096]/@1gTiL0N96F06n6S01f
SI<0LHF<0728S01dRHh0MHR>07J7SP1_P8L0OIFI06Z6R@1hUiT0O9BD07nK
W01nWJ80P:>Y07RIX01cSYD0QiZN09FTY`1lVIl0MY6H072<T01mUYX0OiRL
07ZGV`21X:D0M9FJ07B>S`1kTiD0U:VZ08^NXP20V9`0RJJ/08Z]/`2A]l00
202C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo
0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J
00P0S96D08>9U`2;TjX0W:G20:^gd@2b`MP0]<3J0;G0gPD0]L3L0`2f`Mdh
0;G0g0080;G1f`2man00b];U0=CJjP3Df>40TI:G0?ooo`3oooej0?ooo`00
8@3oool08P3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I0=[JfP2/
ZZl0QH:;08b8U`2MV:`0[ZJn0;bccP2o]ll0`;S?0;ngcP2j//T0/Z[10:RP
]@2NUZ/0VI6V09NEX03<bm<0o?_o0?ooo`3oo_l0hn;Z08n<W@2CT:D0ShfH
0<K5c@3_k_@20?ono`0n0?3_m@36aLd0ShfH09>=V@37`Ld0ooWo0<c6dP2?
RID0SHNC0=?=f@3Idml0Ti2K08V6T@3;b=<0m_?n0;nla`39a]40o?Wo0=3=
f02/Y;T0[JFj0:VQ]P2SVk00UHjN0:RR[P3RgN@0ooco0?ooo`3ooOl0a/;@
07YeR@1iM8/0OgN?07]cRP3on_l0ooWo08InUP1mLiH0`[WF0?ojo`33_LT0
N72508EkW@1nMI@0RX>E0>WSk@3nn?l0ZJ6i08MnW@2j//L0oogo0<6he@26
OYH0PW^=0<2ib@3onOl0`;W;081hT01oMY<0VYJU0=oKj@3nnol20?omo`0T
0=C@gP2NVJl0OgVC081hS`2YX[@0noGo0>;Kk@2IT:/0R7nN089iUP2:PYT0
_;K00?ggo`30^/H0b<;@0?Wbo`31^Lh0Th^R081hS`23Ni00Q7f?0>KOl@3m
m_l0[:Jd0>3JiP3onol0o?Ko0?olo`3nmol0YIbg09R>/@2QUkX0S8>N08N0
TP3onOl0o_go0P3oo_l09`3kn?l0OGV:08^3VP3on_l0gMOU07Q]S`1kKiL0
LfJA06mTQ02g[kh0mnoj0;^abP1cIhl0LVV40:>K/P3Ug^h0ooco0?oio`3o
o?l0gMKX07M_QP1gKI00Jf=j0?oio`3oo?l0KfJ109J=ZP3onol0g]WO07eb
TP22MY`0NFfE079YQP2g/Kd0m_7h0;Vab01^IX/0o?_o0?ono`020?olo`0E
0?_bo`2dYlD0VHZc09^9^`2RT[l0XI6n0::B`@2STl00X9>n0:FI`@2cYl/0
`[OI08Z<V@1TLWd0IhJ;06nFV`1mYZX0R:nf08Ja]`26/kT0Q[6g0080R;>i
09d0Qk:h08Rc^@26/KL0PJbb07bW[@1`WIX0MI6D0;O4c03ao_l0[LK:06Z<
S@1YQhT0Z[o40?_oo`3iool0mooo0?3oo`3=hN80Ni>E06f6RP21WJ00fN?U
0?Koo`3gool0joWj0;?1`P1hR8P0c=kN0?;oo`28[:`0N9JH0728S02IZjl0
looo0<cNhP1aQXT0ZlG40?Soo`2ealT0NIJJ07BGV`1UR8`0MXjB0<gGf@3o
ool0R:BU07B6RP3iool0jOKl07J@T@1^S8`0Mhb?0;>l``3coOl0l?[l0?Go
o`3Ul?80TInR0=;Qi03bool0VJ^]07JHVP1`Si80K8R;07VAT`3[ool0m?oo
08F@TP3bo_h0o?oo0?Kno`3bool0eN[[09B`/`23Y:T0MIRN076DVP2fa/H0
k_cm0?Soo`3iool0iNkc0;2o`P2;Xj<0L8f;07:FUP1YQhL0P9>G0;K1a@3U
kO00nooo0?Woo`3`n_T0[Ko108VNX@1[Qh/0LXnE06j9T02FZJd0c][H0?_o
o@3hool0k?[j0;C6bP1gRi80LHF<0:Ni_@3Ulo<0n?oo0?Koo`3VlOD0//33
06imP02>WJ00kooo0=W]kP1^PX<0Lh^=0:Jk_P3Ik_40N8^?07:4R02JZJh0
l?go0<kKh@2CXZD0l_oo0?Koo`3dnol0n?oo0>klo`1kT940YKnn0?Woo`2g
bLT0O9RK07>FVP1UQX/0NI6E0=3Jg03oo_l0Sjja06n8S01mTI80kooo0>kn
oP24VIX0Khf?07FHVP2]^k`0i_7c0??moP3hool0dn;U08^SY`25YZ/0RZne
00P0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0
o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?oo
o`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[J
fP0808fBU@23RIL0S9B[09bU`P2[]m40//7H0;C0fP2e`=h40;G0g0@0]/7M
>02e`=`0202e`M/0_LOP0<[Bi@3Df^X0e=SQ096BU`3oool0ooomNP3oool0
0240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kf@3Jf]X0
[J^`08F2R`2<R9L0WIR/0:jV_P2l/lh00P30^<l06P2n]/d0^;370:jV^`2S
Vk00VY:W09F=XP3Yj?00o_go0?[jnP3MgM/0l_;b0?glo`2<RYP0SHZM0=;A
e`3noOl0oooo0>WYj`3Xj>X0oooo0?glo`3Ad=H0Qh:90:VTZ`3ooOl0hMcS
0P2:QH`0V`3im?/0o?On08J3RP28QH`0g=WP0?omo`2[Z:l0_;W00?omo`37
a</0XIV^0:NO]02SVk00V96S09ZCX`3@b]@0oogo0?;]l@3;bl/0g=_P0?om
o`31_Lh0MG2607E]PP1oN8X0ooWo0?olo`1mMH`0PWRJ09jE/03onOl0l>_b
07QaP`1iL8l0NW6>08^4U03ooOl0nO?m08MoUP1mM8l0_KK60?ojoP2k//d0
QWjE081iR@2j]<00ooco0;Ra`@1oMhh0VY6/0?OenP3ooOh0m_Ga0>?Rg@3`
kn/0ooko0??`n`2HU:<0OWJ;09fGY@3oo?l0gmWW08=kT`24NiX0QGbG09F>
X03on_h0oogo0;Nb^@2ITid0ooco0?;[n`1iLX@0Q7f?07mhR02<QY@0ooco
0?G_n`1nN880fmKM0?omo`3/ind0hMcP0>OQk@2PUk80WiFj09V?]027OYT0
QX2<0?ojoP3oool0hn?Q0=oNg03CdMH0JVId09><WP3onOl0g=ON07EZR01_
HhT0L6B<08f3WP3nm_l0ooco0:ZQ]P1_HhT0WIVW0?cio`3oo_l0`/6o0;2_
Z`3Qgn00o__o0>?Pj`1`JHP0JFEd0?ono`3nnol0HEa`09F@Y`3ooOl0fMSF
07Y`R`1eJHd0MFV?08n7W`3nnOl0oogo0:NS]01/IHL0oooo0?clo03KfMX0
fmKL0>OOkP2[W[X0V8Vb0:>A``2RT[l0XI6n0::B`@2STl00XIBo0:FI`@2d
Z<`0`[OI08Z<V@1TLWd0IhJ;06nFV`1mYZX0R:nf08Ja]`26/kT0Qk:h00@0
R;>i08h0Q[6g086//P1kYZ`0L9ZF072:R`2d_L@0m_oo0:c1a01ZRXT0JH>4
0:^m`@3on_d0knW]0=kLg`3Hg=l0^lG706YiO02;WZ80ioco0?olo`3/j^d0
gM_N0?ShnP3If]`0O8210=CJfP3jool0S:j]06j:R`1bQHT0UJ>V0??no`3D
hnH0Ig]j0:Vo_@3moOl0]/730729S@1XRhd0K8j@0:Bi_03nool0oo[k08RP
X01]N7`0no_o0?Woo`1]PX<0JXB30;_=c`3lool0n_ko0>7UiP3Uj^d0mooo
09JPX@2jaLL0m?oo0<3>c`1SQHH0J8N906Z6Q`2N/k@0m?oo0<_EeP1bN7P0
o?oo0?_jmP3SiN80fnGT0<CFeP29Xj@0R:NZ07fPYP1[T9P0]KVj0?koo`3]
jo00h]gS0?gko`3lool0fNCV07nAT@1VR8L0MI:@0;O9b`3iool0ooko0>;P
h`3Shn<0o_oo0?coo`2ma//0MXV@06f4S02@Y:/0io;f0?ono`3cjNL0fMkJ
0?Ooo`3Dh^D0LX>:08BEW03dool0nOoo0;o4`02m`/D0nooo0?Ooo`24SXl0
MX:20??oo`3dool0L81o06n1P`30d]@0m?oo08fKWP1`Ngl0/[_00?Soo`2]
];X0TYjN0?Woo`3bm_T0gMkR0=OKgP3GhN80KH1n0;36``3lo?`0^<;307:<
S@1VRH/0JXb>0:Nj_P3nool0ooOk08^][P1[QHH0Kgmo0P3iool02`1mShl0
N9BE07fQX@3kool0lOGf0;jo`@3IgN00n?oo0;gBe@2?[[40S;:e00P0Tk[1
00`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?oo
o`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0
oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808fB
U@23RIL0S9B[09bU`P2[]m40//7H0;C0fP2e`=h40;G0g0@0]/7M>02e`=`0
202e`M/0_LOP0<[Bi@3Df^X0e=SQ096BU`3oool0ooomNP3oool00240oooo
00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kf@3Jf]X0[:Z_08F2
R`2<R9L0WIR/0:jV_P2l/lh00P30^=00=@2l]<`0]Zk50:ZR]`2NV:H0TXbF
0=SCfP3ooOl0j^O`0:FR[@2PW:X0W9RW0<>ocP2?RiX0_KW80?olo`3jmol0
]K6o09jJZ@2KUjH0[ZZh0?Odo@3ooOl0/Znf08V6S@3ooOl0k^_f08B1S02`
[KH0n?Gl0?omo`2_[;D0PX250>[Xj`3nnol0U92N0<2lbP3nnol0a<?109F@
Y`2HUJ00UiBO08n:WP2>RY/0oogo0?gkoP2/Z;H0XYnV06QUKP3knOh0ooko
075]OP1bJhd0NWB>0080ooko02L0PGbB08AjW@22MiD0imoZ0?okn03JfML0
fm[P0=_Kf@3Ogmd0oo[o0<g6f027OY/0NW6>0;Vga@3no_h0_K[507egT@1k
MI40_KW70?_ioP2i]/40M71n0>gZl@3noOl0d<gH09>;X02@QZ40SXBM0<c5
e`3ooOl0inOU07Q_S02KUJ40ookm0=kIg`24O9<0OGBA08^4U03_jn`00P3n
oOl0mP2h//00OWJ=0>CMk@3onoX0fMWI0=[Gj03PgNP0gMcJ0?ono`38a=80
P7b=0=WFg`3oo?l0[JVj09V>[P2VV/00YYZn0:BJ]@2IT:d0S8:U089jTP3o
o?l0oooo096?W02PVj80CTQD04]2H@2=QId0oOco0=SGg01/HY@0If5k07Aa
O03XiO00oogo0?klo`2a[K/0J69n0>[Zj03ooOl0ZZ>e079XP@1dJXD0JF5f
0=?@f`3oo_l0/:Vi06UPN`3oo_l0n_Wd06MPO`2>R:80ooom0=CCf`1cIiD0
KVF007QbO03]j>`0oogj0?omn02aZkT0K6690?clnP3nnol0MW2:07Y_V@27
Nj/0T8:c09N:]P2SU;d0Xi?00::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:g
f@29RiP0Hg5l06N6R`1_UY/0O:FY08R_]P27/[P0QkBj08Jc^@25/[P0R;>i
08Vd^P28/kT0RK:h08B]/@1kY:P0KiRN06V=S@2]`[d0mooo0:fo`@1TR8P0
Hh:50:fj`03iool0[L7005n3P@1MRhP0F8:006f7QP3Zk_40oo_o0;_EeP1o
WZ00MiJI08BKX@2O^;d0JhV90=3OhP3oo?l0S:VW06Z8RP1QQ8H0RJ6S0?co
o`3?h]h0Gh9n0:Vl``3ioOl0/<;606J4Q01SPGl0RI^K0?[mo`3ooOl0ooco
08jIW`1QPh@0l_oj0?_nm`1UNWd0ZKNj0?ooo@3So?P0UK>a07^GVP22WJ@0
V;K008RV[P1iSY<0nooo0?_em`3Cf^00dNKQ0=CMf03aiNT0o_ko096c]01V
Q8@0oogo0?_oo`22W9d0OZN]08V^]`2;[;<0PJVY07VLWP1dS9H0^[o50?kn
o`2d_lD0Kh^<07>AT@2nbm40o?oo0;Jm``1UPhD0Z;Rg0?_oo`3]moH0V[:d
07RGVP1cSi<0V:^_0?7mn@3oo?l0Zjfi06imQ03_k_@0o?cn0<CFeP1mVIX0
OIZH08JOX`2R_/80K8R90;6o_`3nool0^lK:06V<T01]RHd0/lO80?_oo`2c
^;/0IWUm0>?ZlP3noOl0OY6;07^7Q`3`nOP0o?oo0;g1a01/MGX0^LK<0>ol
o`2S/K@0UJ2V0?_oo`3:gmX0HXN0072?T@1SQ8T0K8Z<0;6h_P3nnol0/<;6
0627Q01RQH40T9^M0?oho`3onol0o_oo09:U[01[QhP0JHb60?ojo`3ooOl0
LYVD07^MW`1dSI@0^MOG08BRXP1WQ880OY2B0?;mo`3_o?l0QjFW08Na/0P0
Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3o
ool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP08
08bAU024RYP0SIF/09bU`P2[]m40]<?J0;G1f`2d_md80;G0g0040;C2g02c
`M/0//3J0;;0f`80]<;M00<0]<;O0;?1gP2d`=X00P2d`=X30;G1f`80]/;L
00@0]L3L0;Bof`2c_]X0];oK102e`=`30;G1f`050;K2g02g`md0]/;L0;C0
fP2b_]P00P2e`M/20;C0fP@0]L7K0P2f`Md0102e`=`0]/7M0;K1g@2f`Md:
0;G0g0080;G1f`2man00b];U0=CJjP3Df>40TI:G0?ooo`3oooej0?ooo`00
8@3oool0N03no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I0=[JfP2/
ZZl0QH:;08b8U`2NVJd0[ZJn0;bccP2n]/h0aKgE0;^cb`2f[/D0[ZJk09ZC
X`2LUZ00o?On0?[go`2ZYk80ZjNf0::N[`2NVJd0WIVX08V5T`3RgnX0oogo
0<_8d@2TX:l0XYfa09^FZP2FTZ40`Kk70?gko`3KfMh0RHJ=0?Seo03mn_l0
QH:;0=3=e03ooOl0moGj0=;?f026Q8T0noWl0?omo`2<R9H0_KW70?kko`3E
e=80ZJBj09jKY02>Ri@0RXJG0:fY^03ooOl0inGV0:FR[@2WY:/0FEIO0=GC
f03knO`0SXZK07aeU`1hLhX0o?[m0?ono`24OiD0QgfP08EjVP2j//40ooko
0?cjn`3DdmT0f=SH0?ooo`3oo?l0X9R]085hU@25O9T0^KO50?ooo`2j]l80
PG^G07]dT`2j]/@0oogo0;Re_P2PWJP0oogo0?GdnP2IUJ@0U8bT08j3X`2<
PIl0RX:G0?3]m03oood0TXZR0::LZ03ooOl0g]WO07igQ`1mMHX0clWG0?ol
o`3ThnT0ooko0;bfa020N900^kC40?ono`3gmoT0eM?Q0=ODg@80ooko0>00
UY:Q07EaPP3Nfn@0oogo0:fY^P2MT[80Z9c20:RL`02VW;L0VY6^08b2Y@22
NY80oogo0?gmo`2@SY/0VYFL05UCG`1>AF@0SXJN0?ooo`3Cd]L0Jf>:06aW
N`3;b=<0ooco0>?Ok@3mnol0[Z^f096;Y@3oo_l0e=3N07Q`R01dJHT0Q7VI
09B<X`2j]l00m_Kf0>GNkP1TFgP0o?[k0?oonP1[I8<0T8ZT0?kno03If>00
LFN<07E]Q03@b]H0ooco0>CPh@3oo_/0]Jnm06YPQ@3oool0o?Wo07A`OP20
N900PgZI09V=/`2GR[D0Whnl0:>C`02RT[l0XY;10:>C`02PTkh0YIW10;>W
b`32]mT0RH^H06=aO01WQX/0KiJK07fVZP28[kH0Qk:h08Nd^P26/kT0Q[6h
08Vd^P2:]K/0R;>i08Vb^024[K40O:FY07:GW`1/Rhd0/<2o0?coo`2`_/40
JHJ:06N3Q`2`^L80o_oo0:ni^`1ZOH40J86506Z3Q`2AXjD0mOgo0>OWi`1m
VId0MiZL07nPY@1eT9L0MY:F06N7QP3Ah><0o_On092RY01]P8H0J8B709FT
Y`3nnOd0dMgI06F2OP2]^/80o?oo0;2n`@1SNg/0OiNG0=[ZjP3enO`0jn_]
0?kno`2BWJ<0GGan0?Koo03oooX0Jh230=?Ni03jnOL0Z/2m07RJV`2@[k80
QZ>[07VJX`1hVJ00MXnC0<_EeP3ooOh0inkd0<oRgP3HhM`0ooco0>g`m`1X
RX/0I8210?kko`3lool0Q9jO086Z/02;/;T0SZnf08:ZZP1jWIl0MHfG0;W1
``3fnOh0]/G:06b;S@1]S8h0Pi2F0>kamP3dnO`0K8B60=7Og`3goO/0_Lc9
07nKW020XjL0MiJK07J:T@2/_k/0o?_o0<_BfP2EYjT0o?oo0>CXj@22W9/0
PJBX08NVZ01gTiL0MiBJ06f;S@3Bh^40o?go0:B_/`1/SY00IX:609JZZ`3l
ool0e=cN06j3QP37d=L0o?_o08fPVP2S[J`0nOoo0>kdm03`mOP0O8B70<kG
g03gool0T9jQ08bKX03nool0fN?R07>7Q@1bPHP0LHZA06N5Q`2`^kl0ooko
0;2n`@1QOW`0P9ZI0=oZk03hmo`0k>[]0?gno`2EZK00IX:506B7P`80oogo
00/0K9>@07BFV01dSiP0M8j?06R0PP1fQHP0SiBH0?kno`3an_l0S:V]08Vg
]@0809>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh
0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3o
ool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3J
f]X0202<TI@0Q8ZH08fE[02LYL80ZkOA0;C3fP2e`M/0];oM202e`=`0102d
`]`0/l7K0;;0fP2c`M`30;C2g@030;?1g02f`]`0]/;L00H0]/;L00@0]/7M
0;G0g02e`=`0]L3L0`2f`Md00`2e`=`0]L7K0;C0fP020;>of@040;C0fP2f
`]`0]l?M0;S4gPH0]L7K0P2d`=X50;K1g@/0]L3L00P0]L7K0;g7h03:d^D0
e=[Z0=CHh@2ATYL0oooo0?oooGX0oooo000Q0?ooo`3o0?knoP3jn_X0m?Cd
0>g]k@3UiND0gmoO0=cLg03KfmT0f][J0:bZ[`25PX/0S8RG09jI[@2_Ykl0
_;?>0;ngc`31^M40_KG=0;J^aP2XX;D0WYNW0:fW/`3oo?l0h]oX09jJZ02S
W[80Yj:i0::M]02@S9d0Ti2K0?gko`3oo_l0WibU0:JR/`2TWkH0ViJ]09>?
X02BSiP0ooko0?KcnP21Oh@0gmgR0?ono`2LVYl0m?;g0>k/l@3>bm80o__o
09bJW`3mnoh0k^_b07]gQ@2n^/P0oogo0?Ofm03onol0ooko0=OEfP2>RYP0
Z:Bb0?cjn`3Ui>80[JZc0:VV[@1KF640cL_@0?ono`2KUjP0LV^<07E`Q`3n
o?d0o_go08J1U`26O9l0R7fO0968W@3jmO`0kngb07UhP02GUY/0n_Wo0?;/
nP2:PYX0QgjM08MnV@2b/;h0oOco0;Ve``25Oi/0O7FD0;Nc`@3no?l0/:ff
0;Re`03mnol0b/SC08n:WP2@QjH0WI6i08IjWP24O9<0`l370?cmn02e[[h0
WINS0?olo`3Lemh0NgEo0;J`_03oo?l0cLOE0;Je^`3oo_l0`;[8081hT02;
PiP0n_Gk0??cm@1nO8T0Ti2I0?cjo@3[j>l0OgZ>07]fRP3Nfn80ooco0;6/
`02QU[H0ZYk40:ZN`P2XW[T0Vi:_08^1Y022NY80oogo0?ooo`36a=40aL37
0:^U[`12>EP0SHFL0?ooo`3Hem`0Heid0;6^^@3mn_l0a<3A0:n[^P3mnol0
ZjRa0;F`aP3oo_l0]k?407M^S@1hK9@0^joE0?oio`3lnOl0oooo0?ceo`1e
K8T0ooko0?oon`1XHH00SXRR0?ooo@3Lfn<0JV9i0;J`_P3on_l0`kc<0;Ja
^03onoX0/J^g06aRQ@3oo_l0oO_o0;Ne^P2k]Kl0_[O908b1W`2ISKD0YiO8
0:>C`02RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0RH^H06=aO01WQX/0
L9NL07fVZP28[kH0Qk:h08Re^`28/kX0Qk:i08Vd^P2:]K/0R[>i08Vb^024
[K40NjBX07BDW`1`S900/[jn0?cko`2e_/D0KHR?06R1R02_]/00o?[m0=KE
fP2i_LH0[KJo09>MYP2^^Kl0mOoo0;W3`P1jVj80OZFZ082UZ`1jUil0K8V=
06f=S03@h^80oogo0<;:c@2_^;l0[Kk50<;:c@3on?`0f=kJ06n5PP2/]Kh0
n_ko0:jh^@1^P800`=;D0?Ooo`2Y/K<0eM_K0?[ooP2AW:80GGYn0?Woo@3o
ooX0JWn20?Goo`3ooO`0QING001X07bRY@24Yjd0PjB]08:T[@1dUid0LY2B
0:2^[`3loOl0b/oC071oO02f_kX0ooco0<?<d`1YRhd0Ih>40?ono`3lool0
Qj6R08B]/`2>/k`0T;6h08B/[01jWIl0MHfG0;G0_03iool0[;o5076GVP1V
RHd0MHB;0=KGf`3nool0TZ6V0?Soo`3iood0RYfK07fOX01eWZ@0OInX07>:
TP1bRhD0nOco0??mo`2R][@0nOoo0;W3`P1hVY/0O:V_08:SZ020WZH0L8jH
06f<S`3Hj>P0n?Wk09jY[@1_TI<0LhnC092TY@3loOl0emoQ06AnO`2^^Kl0
ooko0:Zi]03<eM80n?oo0:fg^03hool0VIjQ0>GZk@3co_l0MhJ908nSY03m
o?l0j^c[0;Bi_02d]/80Y;:m06Z6R@2`_l80nOko0;2h^P1cOX00`m7D0?Go
o`2Z];D0e]cL0?cno@2BZK40JH:606J6P`3oo_l0o_ko06jBT01dTiP0Kh^F
0764R01lRXd0]K[00?Seo03im_l0d]_R08j[[`25/k<809>j`@0<09>j_`2B
^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3o
ool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?ooo`3no_h0
oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202<TI@0Q8ZH08fE
[02LYL80ZkOA0;C3fP2e`M/0];oM202e`=`0102f`]`0]L7K0;G1f`2e`M/3
0;G0g0030;Bof`2e`=`0]L3L00H0]L3L00@0]/;L0;G1f`2e`M/0]L7K0P2f
`]`00`2e`M/0]<3J0;K1g@030;K1g@P0]L3L102d_m/40;K1g@`0]L3L00P0
]L7K0;g7h03:d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0oooo000Q0?ooo`2b
0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03KfmT0f][J0:bZ[`25PX/0
S8RG09jI[@2_Ykl0_KC?0<6id02n]/h0`;S@0;J^aP2XX;L0XIZ/0:fW]@3o
nol0i^?/09bHY`2UX;H0Y9jh09^E[`2HU:D0SHZC0?ono`3no?d0UiBM09nJ
[P2QVkD0VI>]092;W`2>Ri@0o_cm0?omo`27Q8/0aL?80?omo`34`/D0ooko
0<6na@2UXZT0oogo0<S6b`3oo_l0g]_R08V5T`33_ld0ooco0=kMf`30_<X0
lNob0?ono`2c/;/0ZJJa0?ooo@3Yj>H0ZZN`0:^X/@1LFF80c/cA0?ono`2J
UZD0LFZ;07agS@3oood0ooko08Z5V`2;PJ@0RGfQ07meT03Ke>@0oogo08f;
UP2k^[l0oogo0<Noe025O9T0RH2O089jTP2f]<40ooko0;Ve``1oNID0O7FD
0;Nc`@3oo_l0^;Fn0;^h``3oo_l0_[c:08f8WP2DRZd0THB_08f1Y`21NI40
`Kk50?[kmP2n^<@0V9:P0?olo`3OfN<0X9^Q0?kio`3Xh_00R82E0;bk``3m
o?l0^[C008QoVP22NY80fM?M0?ono`2>S9L0`;g40?ono`33`</0OGR?08=n
TP3Kf=l0oogo0;:]`@2TVKT0Zio50:ZN`P2YWkX0VY6^08Z0X`21NI40ooco
0?ooo`3imol0oogo0?_eo`1?AV<0S8BK0?Win`3Hf=X0RXNB0?olo`3MfNL0
Mg:90:^V^P3oo_l0[JZa0:fX_03mo?l0/jnn07Q_S01eJI40RWfX09jD]P2C
SZ80TY6I09VAYP1VGG`0noWl0?gln01VGh00ShVS0?ooo@3Ddm/0SXRB0?ok
o`3PfN/0OGF=0;2Z^03oo_l0/:Zf06YPPP3in?d0ooko0?Odn`80oo[o0:d0
Uhb/09V=]@2KRkX0Xi?00::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:gf@29
RiP0I79m06N6R`1`Ui`0OJJZ08R_]P27/[P0R;Fk08Vd^`28/kX0R[Fk08be
^`29/[P0Qk2f08:Y[P1iX:D0L92K06f9S@2`_;`0nO[n0;>na01XQH/0HWf4
0:fg`@3ooOh0ooko0?Woo`3^nol0[[g40;2m``3hool0^/?207FFW`1bVJ00
MIZR07ZGW`1aSY80K8b;0<[Mf`3onol0nOoo0?Glo`3_ool0l_[m0?oko`3D
f]H0Ih1l0:nj`03koO`0^;jn0;6k_@3eool0_/c?06ahN03Eh=`0n?om08nJ
X01SOh<0n_ol0?kkmP1[P8D0l_oo0?ono`1oSHh0O:6Y08BV[`1nWjP0Oj6Z
08:XZ`1eU9H0NHf>0>_emP3bmo/0Mh600>3YiP3lool0UJJ]06f@TP1ZQ8D0
ooko0?coo`29Xj@0QZne08nd_@2A/[T0Q:b/07ZMW`1dS9H0/l2i0?Soo`2_
a<T0J8jA06f@U01aP8L0h>7U0?[ln@2BWjL0n?oo0?Omo@1mT8h0O9nQ06fH
WP1bU9d0LHNB06f4OP3nool0m_ko0:k1_@3amo<0_<G407^JW@1gXJd0MYVO
07fKY@1cTI/0JHR;0<cLg03in_`0YK2d06nAT`1_S900U:RY0?koo`3Fg^00
IH6209NVZ`3mo?l0]l>o0?[ooP3AgMd0OHb?0?3ko@33alP0o?km0?Soo`1Y
OGh0SJ6R0?[ko`3lool0mOoo0?Woo`3;g^D0Kh^>0:Vi^@3foo`0_;fo0;Vh
_P3iool0_<k@06QlNP3EhMd0o_om08fV[@1[PXP0JHN70?_lo`3ko_l0KY2A
07:?U@1WQHl0TIZO0??jo`020?Woo`040=WTj02@YJX0S[2b096j_PP0Tk[1
00`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?oo
o`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0
oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bA
U024RYP0SIF/09bU`P2[]m40]<?J0;G1f`2d_md80;G0g0040;K1g@2e`=`0
]L7K0;C0fP80/koI0P2b_]P20;6lf0<0/[gI0`2c_]X00`2c_mT0/[kH0;:n
f0030;>of@040;6me`2`_=H0[[WE0:njeP80/KcH00D0/;_G0:njeP2_^]H0
/;_G0;:mf@020;>nfP070;:mf@2a_=P0/KcH0;:mf@2c_]X0];oK0;G0g002
0;K1g@`0]L3L00P0]L7K0;g7h03:d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0
oooo000Q0?ooo`0@0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03KfmT0
f][J0:f[/025PX/0SHVH09nJ[P2`Z<00_KC?0<:jd@80`[[B0?l0]Jg50;B/
``2OV:X0ViBT0?olo`3el_/0VIFS09RCY`2KUZd0Ui:X092<V`2=RY<0inGZ
0?klo@2b[kH0VIFV09RCZP2ET:L0TXjO0:fZ/@3no?d0inC_08j;U02n_<40
ooko0?[hn`3oo_l0ViRQ08^8T`3dlOX0moGj0?ono`35`/T0RXJD0;nkb@3m
n_l0`l;008B1S02d/[<0oogn0=_Hh`2ZYk00ookl0>7PgP2ZYk00[:Vb05]H
H`3>c=40oO_l09B@W`1_J8L0Lfj20?onnP3oo_l0PWj?08n6Y@2?PjL0QGZJ
0:>K/03oo?l0_[g50?7`mP3knOl0Vi>[08^2X@29P9d0O7B90;Vg`P3oo_l0
_K[507QbS01hLXh0^;C20?omo`2j]l80X9bZ0?omo`3OgN/0PgjD08Z1X028
O:00RWnQ07M_QP3Jen00oooo0::LZP2OVJL0oo[o0>kYl03VhNL0o?On0:2I
Z@21NI40_;[50?cko`33_LT0ShJS08QoWP2WXJl0ooko0<;1b@3ak_D0n_On
09JBX`22NiX0Qh:H0=gKh03oo_l0[JRl0:FJ^P2[WlD0ZYk20:RN^@2JTJh0
Rh6T089jTP3onol0oOgm0:f[]P2d[kD0Pgf704LnF`2>QYd0oooo0=kNh03^
j?80m>kh09RAX`1WGW/0]Zk50?ghoP2e/;L0U8bT0?gmn`3Ed]/0KfMn07U^
T01bIX`0L6J906mYP`1^Jgh0JF5h06QNP03oo_l0oook06]TQ@2BS:H0oook
0=kMh`3ZiN`0n?;n09bD[01]HhD0/jbn0?oko`2f/;`0KVB60?_kn`3nnol0
Ui>R09fD[`2VW;l0SX:Z09V<]`2SU;l0Xi?00::B_`2RT/40Xi?00:2C_P2U
VL40/jO;0<:gf@29RiP0I79m06N6R`1`Ui`0OJJZ08R_]P27/[P0R;Fk08Ze
_029];/0S;Fk08^d^P28/KL0QJbc07jUZP1dVj00KY2I06F3Q@2^_[d0o?oo
0:jm`01NPH<0HH230:nna@3ooOh0`lc;08^OX027XjH0MiFG09>VZP3fool0
g=_P07JAV01_TYP0LiBK06f8S`1`S900IHF20=7ThP3ooOl0VJVY07B6RP1Y
Ph@0WJ^/0?Wgn03DhMX0H7mi0:Ri`03nooX0dMGD0?Ooo`3Jind0P9:F06n1
P@3Ch]l0mool08nNY@1UPHD0o?oo0?onn`1]QHT0bmgQ0?ono`2GYJH0Li6I
07FBVP1nVJ80NYVN07NJW01bUYH0N9:C0;O9b`3kool0/kVi0?Woo`3Uk_<0
Mi2E06B7R`1dS8h0o_oo0?[no`29Xj@004T0Qk2f08jc_02@/KP0Q:b/07VL
WP1eSIL0//6j0?Soo`2a`lL0JH^=06F4Q`1iQX`0m?Gi0?_oo@1lSID0h>W^
0?_oo`2Q/K00JHR:07BKX01ZR900M8R?09FUXP3jmoh0g>7U09Z]Z`3lool0
gn3R07F=T@1aTI`0NIRM06n:U@1_RiH0JhR<0=CTi03nool0X:^_06f@TP1`
SI40U:RY0?kmo`3Egn00IXJ508:EV@3oo_l0n?on0?Wmo02Y^k/0JH:60;g?
d@3hnO/0ooom0=GOh01YPh@0U:>V0?Oko03Hi>00T:VS09:WZP21WJ40HX20
0;>n`03hooX0eMGE0?olo`3NiNd0OY>F06f7Q03Dhn00nogj092Y[P1[OX@0
JH610080o?oo00/0K8R906n6S01XRI00h>7V0?[oo`3Hi^L0VkBa07bLV@1o
YZD0Rk6d09>f_00809>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WG
fP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?oo
o`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3M
gMd0fm_K0P3Jf]X0202<TI@0Q8ZH08fE[02LYL80ZkOA0;C3fP2e`M/0];oM
2@2e`=`01@2d_m/0/[gI0;2leP2]^M<0[;S@0080ZkO?0P2[]M00102/]]40
[KOB0:nie02`^]D20;6kePD0[kWB00<0[[SA0:fgd02[]Lh00P2]]m801@2/
]]40ZkG@0:VccP2Y/lh0Z[C?0080[;KA0P2]]m801`2/]]40ZkG@0:bfd@2^
^=<0[kWD0;6lf02c_]X03P2e`=`0202e`M/0_LOP0<[Bi@3Df^X0e=SQ096B
U`3oool0ooomNP3oool00240oooo0300o_kn0?[jnP3dm?@0kNg]0>GUi@3O
gml0g=cL0=_Kf@3Jf]X0[J^`08J3S02=RIP0WiZ^0;2X`02n]M00`k_B0;ng
cP34_=@0^;380;R`a`2XX;D0VY>U0=WBhP3ooOl0dm3I09FBW@2?RiT0T8bK
0:RT/P2ASYT0`;g80?klo`3]j_40UiBO08b8U`2;QiH0UI:M0>_Xk`3ln_d0
aL7@092<VP2a[[D0o_co0?ono`3Qg^D0V9BR09NCXP3:am020?ono`1K0;^h
_`2@S9X0`;c:0?omo`30_kd0R8F@0;:`/@3mno`0hn3[0:VV/@3ooOh0inGV
0;6^^@2^Zk@0GEYU0=?AeP3oo_l0T8bJ07MaS@1eLH80o_gh0?kmo`21OH/0
S8>N08UmX@2@QJL0RX:J0?C`oP3em?X0ooko0>?Qk`2:PI`0RH2O085iT@1m
MhD0^KRn0?kmo`2i][d0O7N=07YdSP2j]/@0oO_o0;Zfa029QIH0lNki0?om
o`2c[kh0Q7bA089hT026OI80^;710?kko`3fmO/0Pg^B0:BM[@3nn?l0oo_o
0?olo`30^LT0Q7bC08Z1W02k^LH0ooko0<S2cP28Oih0Rh6T08n7W03fmO/0
m??i0?ono`3Wi>d0ShZQ08Z3Y@23OYD0gM_P0?ono`2e/<@0YIZj0:^Oa@2[
Wl<0ZInj09^B[`2?QJP0QWjF0?ojoP3moO/0T8jI09ZEV`1BCE@0CTER08f5
VP020?ooo`3H0?oko`2[Y;H0Mfj907Q^T@2f[/D0o_Wo0;B^^P1bJHP0n?Sj
0?[goP2BRi/0M6Z207E[QP1iL8d0[ZS20;Jbb@22NY80Jf640?ono`3mo?X0
If2109:<YP3ooo/0ooko0?olo`2]Y[P0NG2?07idV@2g[l@0ooko0;:/^01Z
H8D0ooom0?gjo`1gLh@0NW6>08=iWP2BQK00UHRc0:2A^P2STl00XY:o0::B
`@2STl00X9>n0:FI`@2cYl/0`[OI08Z<V@1TLWd0IhJ;072GW01mYZX0R:nf
08Nb^028]K/0S;Bl08^c^`2<]K/0RkBj08R_]P24Zk80O:>X07:IWP1]SYD0
Ih>40;2o^P3kooh0Zk^k06B6Q`1UQ8H0Z;Nj0?_kn@2`^[T0JH6106Z>SP1V
RXX0KHJ:0=_VjP3nool0XK>g07NATP1[Q8P0MhZ@08RPY01TPGl0dn?S0?om
o`2E[jh0LHf@06J8R@2G[:d0nooo0=7TgP1QQ7h0/<?:0?oon`3enOX0l_go
09FY/01aSI40MHn@0<gMg03jooh0SZ6W06B1Q`3nool0ookk06N3QP2M/[L0
oooo0=_Yk01oU9T0M8N=07j?UP2;XjL0R:Z[07JJVP1aT980SJFY0?coo`3b
m_L0nooo0;[<d01jVIh0LiJL07V>T@3enOX0n_ko08^UYP28/KL0S[>l096b
^@25[Jd0NijP07VAV`2d`/80nooo0:bg^`1_QhL0LHV90;S3a`3kool0dn7Q
072=T`2__/<0nooo0=SRh`22UiX0K8V=06^3Q`29UiX0h^kZ0?kko`2j`l`0
Lh^=0>[bm03hnO/0[kg007R;TP1_QhT0O8nF08ROY`1ZQ8D0d^3P0?koo`2L
ZZd0L9JI076@T`2CYJL0oOco0=KPh@1RQX@0KhN90??dn@3kool0lOOg08>K
W`1]SYD0VK2f0?coo`3oo_d0am?C06N6R@2CXj<0o?oo0<oPf01]Rh<0JXB5
072=T@1QPH00/kk00?con`3hnO/0moco09NX/01bSY80M92A0<oMg@3lo_d0
RjBX07:0P`1`Ph40n__m0?Wmo`1`QX@0LX>:06F4R@3kool0m?co07V7Q`1]
Qh@0NJ2K07jXYP28[k@0Sk2i202C^/40302C^[l0T[Vn09:i`02L`LL0[lkC
0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3o
ool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WY
j@3QhN40gMgM0=_Kf`80f][J00P0S96D08B:V02=UJ`0W:G20:^gd@2d`mX0
]L7K0;Bog@P0]L3L00H0][oL0;>lf@2_^=D0Z[C?0:F_b02Q[<8209nZ`008
0:2Z``2QZl@0XZc50:B^a`2V/<T0Yk7:0:Rbb`2Y/l`30:J`b@80Yk7:00T0
YJo80:>]aP2QZl@0X:[30:6[a02R[<D0Xjg60::/a@2QZl@00P2OZL830:2Z
``80WjW200H0X:[30:B^a`2W/LX0[;OC0:njeP2c_]X=0;G0g0080;G1f`2m
an00b];U0=CJjP3Df>40TI:G0?ooo`3oooej0?ooo`008@3oool0D@3no_h0
n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0fm_I0=[JfP2]Zk00QX><08f9V02O
VZh0/:S00;jed034_=<0_;C;0<Ble02n]/h0]jo70;F]a02ZXkD0Z:6a0?7_
m03oo_l0h^3S0<k<c`3@c]<0noSo096=W02TWk<0k>W`0?[goP3eloP0clgB
0<k<d@3eloP0noSo0>gZl@2VXKD0UI6P0:FR[@3lnOl0ooco0<G2c@2QWJ`0
WYV]0:j[]03knOh0ooko0;>`]`2FTZ00aL7?0?omo`3NgM/0bLKA0>k/k@3l
n_/0b<CB0:n[^@3ooOl0j^S[0;2/^P2f/kh0GeaW0=3>d`3ooOh0V9BR0;Zd
d02f//<0o_kf0?ooo`30_LH0`k_B09J;[@2AQJT0Q7^F0<K2d03oo_l0o_ko
0;ZhaP0208j5XP1S0:JN/`31^lD0gMgO0?knoP3Mfm`0_[[;0:2K/@32_lX0
oogo0;bhb@26PIL0^[K70?gko`3ooOl0fM?M0<:k``3Gd=P0ooco0?_ho`2k
^LH0PgVK0:NP/P3ooOl0oo_o0=[Ch`2KTZd0U8^X08Z1W037aM<0o?_o0<>m
b@2GSZd0VY2e08b4V`35a<X0ooko0?gkoP2o_<L0UHn[0969/02;QYd0hn7T
0?klo`2`Zl40YY^k0:fQa`2]XLD0ZZ2k09jE/P2ERjh0Rh>K0?olo`3oood0
a<?;0<_6c02VXJP0JF1k09>;X03kno/0o_kn0=78i@28Oi`0OWBI07U^UP2a
ZL40oogo0;bea@1hKY<0/[2n0?olo`3mmol0ZJ6^09fEXP2h//00ooco0?Wf
o`2BRJ@0MffB0?gjo`3oood0LV^<09VC[@3mo_T0ooko0=K>h`29P9/0P7FM
07ebW02g[l@0ooko0;Na_`1iKYP0o_ko0?cjo`2k^<40^K;20<:jd@2MT[@0
V8bd0080Xi?005H0XY:o0::B`@2STl00X9>n0:FI`@2cYl/0`[OI08Z<V@1T
LWd0J8N<072GW01mYZX0R:nf08Rc^@28]K/0S;Bl08^c^`2<]K/0S;>j08R_
]P24Zk80OJBY07>HWP2AZZl0[L700=[Pg03oo_/0e=gL0:S5``2=YjH0/[bn
0?ooo@3Igmd0[kno0;35bP2P^Kh0M8b@0:c0`@3/o?`0mogm0<KDe02c`l<0
c=[M0<_Mg`1jU9<0dn7R0?ojo`2D];<0NIRK072FV@2CZjl0n?co0=?ShP1Z
R8P0/;k90?kon`3jool0^LS=07bIX@1iWZ@0LI2C0=?Qi03oool0TJV]06^:
S`3lool0ooci06f<S`1nVYd0f]kO0?Goo`3Vl?40^<330<S@d`3Pko80X[jo
07jRXP1mWj40LHjD0>7UiP3oool0m__n096VZ`1dVIl0MibR07^@T`80nooo
05L0SJNX08Zc^@2?];d0T[>j08N_[`1oXZ@0OYJP0;6na03joOl0h^?W0;K5
`P3IjNH0nOoo0>kio@2G[k40L9VO08FNXP3PiNP0o_oo0>Kal`2gbL/0`]3@
0>7Zi@3boo`0h>?Z08fQZP1aUiX0Z;Zn0?Klo03gool0`lo=0;;1_P3<emT0
cMoS07bATP3Cgmd0oOko0::a]P1cVYl0MiJI09^][`3ooOl0en?S06^DT01e
TI80jN[_0?[ln`3>e]P0P9^R06jIXP1fU9`0j^ob0?ono@2``<00K9>H09JZ
Z@3nool0ingY0;30_@2e`<H0[lC906j<S02b`/40oook0?[oo`2hb/h0OY^S
07fNY@1cSi<0eN3T0?koo`2CZj/0][k10;C0_P3oool0o_oo0;30_`2d`/D0
KXf?0=CTh`3do_l0^Kk10:Rb]034g=`0UKNi08fb^02A][h0202C^/40302C
^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?kn
oP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0
o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0S96D08B:
V02=UJ`0W:G20:^gd@2d`mX0]L7K0;Bog@P0]L3L00H0]KkM0;:kf02[]=40
XZc709ZT_@2DWkD2096L/00609>N]02DWkD0UJ2f09JQ]`2HXkT0VJBj0P2K
Y[`209RS^@0709VT^P2JYK/0VZFk09RS^@2EX;H0Tijd08nJ/002092K/@<0
TYfc00D0TIbb092K/@2AW;80TYfc096L/P02092K/@0809>N]02IY;X0WJRn
0:Rcc`2/]m<0/[gI0;G0g02f`Md20;G0g0030;K1g@2e`=`0]L3L00H0]L3L
00P0]L7K0;g7h03:d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0oooo000Q0?oo
o`0A0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03KfmT0f][J0:f[/026
Ph`0SHVH09nJ[P2`Z<00_[G@0<:jc`32^]400P32^]803`2n]/h0]jo60;>[
`02UW[00^;Jk0>k/k@3ooo/0o_gi0?ooo@3ooOl0XYj_0:>N]@2UXZ/0j>G/
0?_inP020?ooo@0a0?_inP3]j_40[JZc0:VT^`2YY;P0XYj/0?_ho`3floX0
^;C20:^V^P2VXKP0Xj2Y0>o]lP3mnoh0Z:F/09bHYP3=bML0oO[o0?ooo@3k
mol0ooko0=KDe`2NVZP0^kO60?klo`3/j^l0`;c;0;nla`1VHfh0eM?H0?on
o`2MVJL0oOOo0?olo`3oooL0no_i0?omo`3klol0XIJf0965Z@2DRjH0YJ6_
0?kno`3oool0V9JT09F<Z@2@Qj@0a[oA0?oko`020?ooo@0b0?oon`3nn_l0
`;_?0<6nb@3ooOl0`[gA09F?Z@2>RIl0^k[20?Kdn@3ono`0oocl0?omo`3i
m?X0`[k<092=WP2ER[80[ZNi0?ono@3akNh0Yind09Z@/`2QUkT0UXjV0<;0
cP3oo_l0b/C>0::I^02KT;P0V92X0:FTZP3moOl0ooko09nLY`2LUK@0Uhnh
09:<YP3UhnH0o_co0;Rcb@2XWKd0[j?90:nSa`2/X[d0XIRe09Z@/`2@R:00
oogo0?gmn`3lnol20?omo`3F085hT`2@R9d0oooo0>k^kP2CR;00PWRM08Qm
Y`24NJ<0_kO>0?omo`2k]<H0PWNR07ijT`2e/<H0oo_o0?olo`3oo?h0oogo
0?Gcn02/Zk<0P7NB08=iWP3lnOl0ooom07]dU@2OVK<0oook0>c[l@2DRjH0
R7jP09F:]@21MZ00a;g?0?chm`2l]/@0Ng2K0?glo`3oo_l0ookl0?omo03o
oOl0]:_009Z>]02MSKh0Xi?00::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:g
f@2:S9T0I79m06R7S01`Ui`0OZN[08V`]`28/kT0R;Fk08^c^`2:/[X0S;Fk
08fd^`29/;L0QJbc07nTZP1dVIl0]LC;0?Koo`3ooo/0ooWg0?ooo`3_ool0
/L?30;bm`@3mo?P0oooo0?koo`3eo?l0fNK_08BGW@1iTi@0Z<O20?_jmP3i
ool0m?km0?Woo`3Ch^D0O9BD0=OUiP3oo?l0W;jo07fNX`1kX:H0W;>i0?ko
o`3Ii>H0MY2A0;g6e@3inoP0f>3R08bOY@25Yk00M9nU07^NXP3Jind0o_On
09Vb]P1dUIX0nooo0?kmn@21XjD0MiFG09NMW@3BhN@0o_oo0?clo03nool0
mOoo0:>m_025YjP0P:>W07nMY`33alP0oO_n0>W^l@2<YJT0PJZ`07ZOY@25
V9`0nooo0?coo`2@ZZ/0S;Fk092e_P2D]K`0R[:b08:UY`22VZ@0^lSA0?on
o`3ln_d0noom0?Kon`3QinL0Xk6d08NTZ01hZjl0OYbN09^PX`3IemP0o?oo
0?Ooo`3eo_T0o_oj0=O/h`2KY:T0QJ>]07NV[020W:00]/;00>gjl@3iooX0
nOom0?Cmo03Lj^/0PIFC0=WShP3mo_l0ZKRm07RQY@1lWZ00XkFg0?ono`3I
iND0MYnK07NEU@3Mg^<0o?km0;2j_021WjL0NZVc07RJX`38cM40oogn0:Vk
_@1/Uid0V[>`0?koo`3oood0o?cn0?olo`3bo?l0NiNH0;C8aP3omoP0emoQ
08NSYP25[;<0NIjV086JX@3LiN`0noco09R^[03lool0n?oo0?ooo@3no_`0
looo0?Soo`1cTI40SjRT0?7ko080oo_o00@0nooo0;O>e028[K<0TKW1202C
^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?oo
o`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0
S96D08B:V02=UJ`0W:G20:^gd@2d`mX0]L7K0;Bog@P0]L3L00h0]KkM0;6j
e`2X/Lh0WJO209>M]P2;UZ`0R9>W08NBYP28TjD0RIBV08ZEY`2;UZP0SIRZ
08jIZ`80SiZ/0P2=V:h02P2>VJl0SiZ`08nJ/02=V:h0RIBZ08NBZ02OZ[`0
VJBf08nJ[027TZ@208B?X@0>08JAX`27TZ@0R9>U08RCY@27TZ@0QY6S08NB
Y02;UZP0TIb^09JQ/`2U/<`0Z[GA0;6lf02e`=`20;K1g@030;G0g02f`Md0
]L3L00L0]L3L00P0]L7K0;g7h03:d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0
oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03KfmT0
f][J0:f[/026Ph`0SHVG09nK[02`Z;l0_[K>0080a;cD00h0`k_C0<:jdP31
^M40_[K>0;ZbbP2g[lL0[ZJk0;2X_@2o]l`0dLWN0<k6f`2k/lP0/:Rm0;>[
`080[JFj01@0^k?80<o7g03AbMh0`;S=0;F]`P2f[/<0]Jg20;6Y_P2d[<40
clOL0=79gP2i/LH0]:c10;F]`P2`Z;d0b<3E0<k6f`2h/<D0ZZ:g0;F]`P80
`KW>01d0`;S=0;J^``2/Y;/0[ZJm0;VaaP35_]00blGC0<_5d@3;bLh0KFYc
07aeQ`2KTj/0UHbY0:NN_@2cZ<H0/JO20;6VaP2eZ/X0^:g=0::G]`2NTk<0
W96a09fB/P3;`>00`[OE0:NL^P2JSjd0Vi2^0:NL^P020;BYa`0E0;>XaP2d
ZLL0]:W70:RM^`2WW;X0]:W70;2U``2PUK<0WI:`09Z?[@2WW;X0_[?A0<k3
h@34^ML0Zj2n09jC/@2QU[@0WI:d0;2Ua`38_Ml0^ZoA0080YY^m05`0XYNi
0:BI^`2]X/00^k3>0;6Va02UV[P0YY^i09fB/02UV[P0b[oM0<Fjf02ZWkd0
XYNe0:BI]`2RUkD0/ZO50;bac`2^Xl40[:340:nSa`2aYLT0[J750:RM_`2P
UKL0XYNi0;FZc034_=<0`kg;0<g7d@2<QY@0KF=l08f1Y@31]Md0Y9Rn09:3
[02CQ:d0T86Z0962Z`2MS[L0ZI[30:2A^P2>OjP0SGnS08anXP2LS[80^J_?
0<Nig@2gZLd0WHnc08j0Y02@PZH0SGnS0:bN`P2]Wl<0RgfQ09j@]02o/MD0
[Z3409J7/P2HRK@0UHJ_09B5[P2NSkH0Z9Zn0:2B]P2>P:@0[Z6o0:ZL_@2[
WL00/:;50:jPa02TUK`0X96j0::C_P2STl00XY:o0::B`@2STl00X9>n0:FI
`@2cYl/0`[OI08^:V01TLW/0JHJ<076IV`20Yj`0R[6f08Zc^@29][/0R[>i
08^d^P80SKJl07D0R[>i08J_]@21Z[00OZN]08j`/P2C]KL0UKNi09Ni^`2I
^kd0TkFg08b^/02;[Jl0V;W009Nh_`2I^/40Vkc309Ff_@29Z[40PJ:Y082Q
Z024XjP0X;o40;?Be`2Q`<D0Q:>X08:QYP2E];T0XL3508f^]@2;[;<0QZN^
08^//`2K_<<0T[>j08JW[P2L_L@0[m3E09Be^P2<[K80Sk2e08JW[027Z:d0
U[Nl09o0a@26Yjh0Q:F/09bma02M_/D0QjR_08>TZ`26Yjh0Oj2W09be_02a
c=<0//oE09Zg_@2=[;40SZnd08^^/P21YjX0SZnf0:k?eP2Sa</0RJZa08^/
/`28ZK00QjR_09o0a`2I_/H0T;Fm08nd_02D^L40TkS008jc^`28[KD0PZN_
09F`]`2L]kh0XKk409fl`@2B/kP0RZfa08R^/@2;/K@0RJnb08^^/P23Y:T0
PZ6V09Vf_02cd=H0/LcC09jg_P25Z[80RJjf08^`^02:[kL0Q:Va07jSZ`27
[;@0V[o70;7@e@2R`LH0QjJ[08>RY`2I^;d0W[g2092_]02:ZJh0QZFZ09:a
]P2N_L80V;Nl08RW[02:ZJh0X;o40;?Be`2?/;L00P2:Zk801P26Yjh0UkRo
0:W:d@2E][d0P:6X08ZY[P80W;_001d0UKBi09nn``2G][/0RJR]09Zi_P2`
dMH0UKJk08^//@2>[k@0QjR]08Z[/02F]k`0Vkc108NVZ@2H]kX0W;^n09Zi
_02K^[d0WKbo09Zi_029Z:/0Pj2V09>`]P2_c]<0/M;G09Nj_P29[k80T;Ji
096i^`0809>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0
n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?kn
oP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K
0P3Jf]X0202<TI@0QH^G08jF[@2MYl80[;S@0;C3f02f`]`0]L3N202e`=`0
7`2d_]L0[kWB0:>]b02MYl00TYV/0=[NjP3mo_l0oooo0?Wll@3nool0_Kg5
0;k1b03kool0g^KX08NBV026TZ00RX^P0>7Ui03hooL0`/WC08b@[@28SJ<0
_/780?3dl`3mooh0oOko0>_^m@2XZk@0YZVb0?koo`3knod00P3oood03@3j
oOl0RXfN0;Nfa03oood0oogd0?gom`3hool0`<cT0:fid@2_^mD0]L7K0;>o
f@2f`]`00P2g`]h80;G0g0080;G1f`2man00b];U0=CJjP3Df>40TI:G0?oo
o`3oooej0?ooo`008@3oool0403no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3L
g=`0fm_I0=[JfP2]Zk00QX><08f9U`2OVj`0/:Ro0;jfcP34_=@20<>kd`80
`[[B00@0`;S@0;jfcP2k/l/0^k?80P2e[L820;VaaP040;J^``2h/<D0_[K;
0;VaaP80]:c100D0^;350;Zba`2g[l@0^[;70<2hc@020;bdb@090;J^``2n
]//0`;S=0;Zba`2o]l`0_;C90;R`a@2k/lP0^[;70080]jo40P2i/LH06`2f
[/<0^;350;Zba`2j//T0]jo60;J^``2m]/P0bL?A0=C>fP3DdMP0LFii06iV
N`29P9/0SHBS09bB]02NTk<0WI:`0:>H^P2PUKL0Yibn0:FJ_02ZWl40Z9fo
09^@/P2XWKl0ZYno0:>H^0020:JK^`80Y9Vi00@0XYNg0:BI^@2OU;@0Y9Vi
0P2RUkL01@2[X<00ZYno0:FJ^P2YW[h0Yibl0080Y9Vi01L0YY^k0:FJ^P2T
VKT0Yibl0:fR`P2WW;h0YIZl0:fRa02WW;h0YIZl0:fRa02XWKl0Yibn0:RM
_@2[X<00Yibl0:RM_@2_Y<@0Z9fm0:>H^02/XL40Zj300:RM_@020:^P`01L
0:FJ^P2WW;`0[:710:^P`02/X<@0[j?70;6Ub@2_XlL0[Z?50:NL_P2TVK/0
/ZO90;>[``2k]<@0`K_706mXN01PEW40O72F09J9]02>PZX0TX>^09N8/`2I
R[D0UHJa09>4[`2EQ[40UXNb09F6/@2IR[<0TX>/08n0Z@2CQ:d0UhRa09J7
/02GR;40V8Vb09V:/`2DQJh0VX^d09V:/`2APZ/0V8Vb09n@^@2EQZl0W8bi
09f>^@2KS;L0V8Vd09V:/`2LSK@0VX^b09B5[02HRZd0UHNZ09N9[@2MS[D0
WXnf09b=]P2NSkX0XY>n0:>C`02RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32
]mT0RhZH06AbN`1YQX`0LIVK082W[02:/KH0R[>i08Vf^`2;];X0S;Fk08ff
_02<]K/0RkBj08Ra]`25[[@0Pjbb08BWZ`26ZJd0QJR/08BWZ`26ZJd0QJR/
08:UZ@24Yj/208BW[@0308NZ/02<[kD0SK2f0080RZfc00@0S:ne08VZ[`29
ZZl0Rjba0P2:Zk00902?/;D0T;6f08Z[/02>/KL0RZfc08R[/@29[;80Sk:h
08^^]023YZ`0SK2f09>f^P2:[K40S[6e09Ji_@2?/[H0Rjjb08b_/`29[;00
Rjjd08R[/@2B]K/0TkJl08f`]P2>/KL0SK2f08Z]/`2;Z:h0TZne09:a]P2>
[k@0T;6f092c]`2=/kH0S[Bg08V//P80T;>i00P0SK2f092c^@2A];X0SK2f
08b_]@2B]kl0S[>k092e_@80U;W100/0TKJn08nd_02</KT0S:V_08b[/02=
[;40SJjc08ja]@2>];L0SkFh08ng^@0208ne^00;08ja]@2;[;40RZ^`08j]
/P2B[kD0TJjd08nd_02>/k/0SK:j08jc^`2=/[X00P27[;@09P2>/k/0S:fb
08n`]@28ZJh0QjR]08n`]@2@/KH0SZnd09>d^@2?/;D0SZnd08n`]@2>[k@0
RZ^`08^//@2?/;D0T;6f08b_]@2>/KL0U;Nm08^^]02:[K<0T[Fk08^^]02:
[K<0QjR]08f^/`2>[k@0RJZ_08j_]02<[K80QJJ[08j_]02B]KT0RZfa08nb
]P2E^;`0T;>g0P2<[k<04@27ZZh0QjR]08j_]02;[;40RJZ_08Z[/02<[K80
T;6f08VZ[`2?[[<0RjZ_08j_]02?/[H0Qjf`08^c]@2C^kd0TKZl00P0Tk[1
00`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?oo
o`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3oool0
oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP0808bA
U025RiL0SYJ]09fW`P2/^=00]<?H0;K2g02e`=h80;G0g00F0;>meP2b_=L0
Y[3;09ZT_@2<TjH0aLWE0?[ko`3^k^h0g>GZ0=GKi`3;c^40RhjO0=kRj`3k
ool0`<C=0824T02KW:h0mOWh0?Oon`2JX:h0PXJO0;Voc`80o?oo01@0j^gd
0>[]mP3amOl0`<KB08F9U03gn_l0oooo0=cLg03Kg>40gn;a09NL/P2YZkX0
n_Sk0?Sgl`3Nh^D0g^Sb0;k:hP2a_MD0/koI0;K2g080]<3J00<0/[gI0;>n
fP2e`=`01`2e`=`0202e`M/0_LOP0<[Bi@3Df^X0e=SQ096BU`3oool0ooom
NP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_K
f@3Jf]X0[J^`08J3S02=RIL0Wi^/0;6Y`02o]ll01033^m<01P34_=@0`k_C
0<:jdP31^M40`;S?0;jfc@80_KG<00@0`;S?0<>kdP32^]40`;S?0P2n]/d0
102o]lh0_[K=0;ngcP30^<l20<6id00;0<2hc`35_M@0_[K=0;bdb`2n]/d0
`KW@0<NoeP30^<l0`[[A0;fec02n]/d00P33^m805P2n]/d0_;C;0;ngcP2n
]//0`;S=0<6id030^<l0_[K;0<>lcP3?bML0f=;N0=_Hh@1hM8<0JV9i08Mn
W@2HS[40YI^n0::G^@2WW;h0ZYk20::F^P2VV[h20:VM`@050:bPa02ZW/80
ZIg10:VM`@2XW<000P2]XLD01`2ZW/80ZIg10:NK_`2VV[h0Yi^o0:^O``2/
X<@00P2[Wl<01@2ZW/80Zio30;2Tb02/X<@0Zio30080ZIg100H0[:340:nS
a`2_XlL0[:340;6Vb02YW/020:bQ``070:jSa@2cZ<X0[Z?50;2Ua`2]XLD0
Zio30:jRaP020;:VbP040:nSa`2]XLD0Zio30:^O``80/:C800@0[j?70;2T
b02^X/H0[:340P2_XlL03`2`Y<P0/JG90:nSa`2bYlT0[jC60:ZO`@2aY/P0
_;?>0<W1eP3AbmT0LV]m06iSP`2;OZT0T8>_09V<^00409Z:^@0509N7]P2F
Q[D0V8Rg09b<^`2KS;L00P2LSKP01@2IR[D0V8Vd09^<]`2NSkX0Wi2k0080
WXnj00L0VX^f09^<]`2OT;/0WHji09^<]`2OT;/0XI700080X92m01d0Whnl
09f>^@2KS;L0WHji0:6B_@2NSkH0W8fd09^<]@2MS[L0WXnj09j>^`2PT;d0
XY:o0:>C`02RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0S8^I06AbN`1Y
QX`0LIVK082W[02:/KH0RkBj08Vf^`0508be^`0308^d^P2:/kT0R[>i0080
R[6h00L0R:nf08J]]028[kH0RK2g08Za^02=];/0R[6f0080RK2e00<0R[6f
08bc^02=];T00P2>]KX0102>/kT0Rk2f08^`]P2>/kT208nd^P0V092e^`2?
];X0TKRm08fd^@2A^;d0SkJk08bc^02?][/0S[Fj08bc^02@]k`0SkJk096h
_@2B^Kh0SkJk092g_02A^;d0S[Fj092g_02?][/0SKBi08^b]`2A^;d0TkZo
08je^P2@]k`0TkBk08n`]`2<[kD0T[Fk09Fj`02@]k`0S[Fj096h_@2?][/0
R[6f08nf^`2E_<42096h_@0709>j_`2>]KX0TKJn096f_P2D^L40UK[209>h
`00209:g_`0:096f_P2D]K`0T;>i08ja]`2=/[P0TKJl09:i_P2A^[h0T;Vm
09>j_`80T;Nl00/0T[Nm092c^@2<[kD0T;6h09Nh_`2C^<00T[No092e_@2B
]kl0U;W1096f_P0208fb^P0308^`]P2?];X0TKJl0080TKJl00@0SkBj08jc
^@2A][`0T;Fk0P2>/kT04P2@]K/0TKJl09:g_@2B]kd0SkBj092g_02>]KX0
TkZo08je^P2;/[L0SKBi08^b]`2A^;d0TKJl08fb^02>/kT0SK:h08ba]`<0
SkBj00/0S[Fj092g_02C^[l0T[Vn08je^P2?][/0TKRm08je^P2>/kT0SkBj
08ba]`0208jc^@0;08fb^02@]K/0T;Fk092c^@2>/KL0SK:h092e^`2@]k`0
TKZn09:k_`2?^;`0202C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039
emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3o
ool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40
gMgM0=_Kf`80f][J00P0S96D08F;U`2>UZd0WJO20:bhd02d`mP0]/;L0;G0
gPP0]L3L0300/kgF0;6keP2T/<X0VZBm092HZ`2b^<@0n_go0=?Cd`26TJD0
QhjX08^@[@2:SZL0SY6R0>W/m@3jn_l0WifX0;ZmaP3lool0dMSN08F:W@25
RYh0k_Gm0?coo`39bmL0VZ2`09JK[P2NYKP0/;O:08>:VP3[koX0o?oo09RJ
V@27RiL0QhjQ07n7WP2BV:P0n__o0?3_m02OYKD0WjS50:nkd`2^^]80/[kH
0;C0fP2g`md0^<CN0;K1g@2h`ml80;G0g0080;G1f`2man00b];U0=CJjP3D
f>40TI:G0?ooo`3oooej0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0
iNGU0=oOg`3Lg=`0fm_I0=[JfP2]Zk00QX><08j:V02PW:d0/JW00;ngc`04
0<>kd`80a;cD0P35_MD20<>kdP80`KW@01h0`k_B0<Jne@36_]D0`k_B0<:j
d@34_=<0`k_B0<6id032^]40`k_B0<Bld`33^m80`KW@0<Bld`32^]40aKgD
0<Jne@34_=<0a[kE0<6id032^]40a;cC0<Fme034_=<0`KW@0<2hc`32^]40
aKgD0<FmdP34_=<20<:jd@0I0<Fme03;a=H0d/_K0=OAg`3LfN@0NgN806iV
OP2>Q:H0WiFj0:VOa02VV[h0[Z;60:ZNa02[WlD0[J770:nSb@2ZW/@0ZIg3
0:nSb@2]XLL0/:C:0:jRb02/X<H0ZYk40:fQa`020;6Ub`070:jRb02`Y<X0
[j?90:nSb@2`Y<X0[j?90;2TbP020;6Ub`030:nSb@2bY/`0/jO=0080/JG;
00D0/ZK<0;2TbP2]XLL0/:G70:jSa@020;BYb`0:0;6Vb02`YLL0[J;40;6V
b02`Y<X0[j?90;>Wc@2bY/`0[:360:fQa`@0/ZK<0P2]XLL20;>Wc@030:nS
b@2`Y<X0/ZK:0080/JG90140[J750;2Ua`2bYlT0[jC60;BYb`30]mH0b<3G
0=G>h01eKH@0KV>50923[`2DQ[L0Vhjl09n?`02KRk`0VXZk09f=_P020:2@
`@0C09j>_`2MSKh0VHVf09b<^@2MSKX0WXjk0:2@_@2RT[l0X92m09f=^P2P
T;d0XI6n0::B_`2STl00XI6n09j>^`2PT;d0YIG20:6A`0020:2@_`060:>C
`P2TU<<0Xi?00::B_`2TU<40XY>n0P2SU;l00`2STl00Y9C10:BD``020:>C
`P0@0:>C`02RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0S8^I06AbN`1Y
QX`0LYZL082W[02:/KH0RkBj08Vf^`@0S;Fk102=][`0102;/k/0S;Bl08^c
^`2;/k/208bd_00308fe_@2>][h0S[Nk0080SkRl01P0S[Nk08nh_02A^[h0
T;Vm08ff^P2C^[l0TKRm09:i_P2C^[l0T[Vn08nf^`2@]k`0T[Vn092i_@2>
]k/0Tkc009:k_`2>]k/0TKZn09Bm`@2@^Kd0S[Nk09:k_`2C_<02096j_P<0
T[^o00P0TKZn09Bm`@2B^kl0SkRl09>l`02B^kl0S[Nk096j_P80U;Vo00D0
TkRn09:i_P2C^[l0TKZn092i_@03096j_P80T[^o00T0T;Vm08jg^`2@^Kd0
U[o309>h`02E^/80U[_309Bi`@2B]kl00P2C^<000`2A][h0TKJl09:g_@02
09:i_P04096j_P2@^Kd0TKZn08nk_P80T[^o00<0TKZn096h_@2C^[l00P2F
^l40102D^Kl0T[No09>h`02D^L4409>h`00409Bi`@2C^[l0TKRm096h_@80
TkZo00<0U;_009>j_`2A^;d00P2C^[l0202D^l00TkZo096h_@2A^;d0TkZo
09Bk`02D_L40SkRl0P2A^[h04P2C_<00UKk2096j_P2D_L40UKc1092g_02B
^Kh0TkZo096h_@2C^[l0U;_0096h_@2>]k/0Tkc009Bm`@2A^[h0T;Vm096j
_P80T[^o0`2A^;l03@2D^l80UKc309:i`02B^L00Tk[109:g_@2C^[l0U;_0
09>j_`2A^[h0T;Vm08jj_@2@_;l0202C^/40302C^[l0T[Vn09:i`02L`LL0
[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?oo
o`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b
0>WYj@3QhN40gMgM0=_Kf`80f][J00P0S96D08F;U`2>UZd0WJO20:bhd02d
`mP0]/;L0;G0gPP0]L3L02`0];kI0;2leP2U/L/0WJO009FM/P2QYk<0o?oo
0=KGf@1nQ9X0TYR`08R>Z02FW;@0RXnR0:V]^@3hnol0iNK[0>__l03ioOl0
[[C00824W@2V[;`0nOoo0>c`l`2PXKD0XZ[109RO^@2MYl00S9N]08>;WP3P
i_80m__o0:FVZ027SIT0O8FF08>>X024S9L0o?oo0?gno`2HWk80WZS<0:^g
c`2b_]H0]L7K0;C0fP80]l?M00<0];oK0;K1g@2e`=`01`2e`=`0202e`M/0
_LOP0<[Bi@3Df^X0e=SQ096BU`3oool0ooomNP3oool00240oooo00l0o_kn
0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=_Kf@3Jf]X0[J^`08J3S02>RYP0
X9b]0;6Y`02o]ll01@33^m<20<Ble0030<Fme@35_M@0`k_B00@0`[[A00@0
`k_B0<Bld`35_M@0`k_B0`32^]402@31^M00`[[A0<>kdP33^m80`[[A0<2h
c`33^m80a;cC0<6id0020<>kdP050<Fme034_=<0`KW@0<2hc`31^M000P34
_=<20<6id00H0<>kdP34_=@0`[[B0<6id035_M80d<WI0=WCh@3Lf>H0N7B5
06eTO`2@QZP0W9:g0:FK`02WVl40ZYk20:ZNa02_XlT0[:360:jRb02_XlT0
[:360:jRb02ZW/@0[:360P2bY/`00`2_XlT0[J770:jRb0020:nSb@030;2T
bP2^X/P0[j?90080/:C:0P2bY/`20;2TbP80[j?900/0[Z;80:fQa`2]XLL0
/:C:0;>Wc@2`Y<P0[j?70;2Tb02^X/H0[j?70;:VbP020;2Tb0070;6Ub`2`
Y<X0[j?90:nSb@2aYL/0/ZK<0;6Ub`020:jRb0050:nSb@2bY/`0/ZK<0;2T
bP2_XlT00P2`Y<X20;6Ub@0@0;:VbP2]XLD0[Z?50;:Wb@2aY/P0]Z_=0<Bk
fP3;`m/0eLgR07M_QP1]HHD0Sh:`09R:^`2IRk`0VXZk09f=_P80Who000P0
WHfn09b<_@2LS;d0W8bm0:>C`P2PT;l0WXjm09n?_P@0XI7000<0XY;109n?
_P2NS[d00P2OSkh20::B`@0<09f=_02PT;l0X92o0:2@_`2QTL00Xi?20:BD
``2QTL00WXjm0:2@_@2RT[l0Xi?00P2STl804`2TU<<0Xi?20:6A`02STl00
XY:o0::B`@2STl00X9>n0:FI`@2cYl/0`[OI08b;V@1ULg`0JXN=07:JW020
Yj`0R[6f08^d^P29][/00P2<]K/508ff_00508be^`2<]kh0S;Nn08ji`02?
^/400`2>^L003P2=^;l0R[Fk08bg_@2=^;h0S;Nm08ji_`2A_<80T;_108bg
_@2>]k/0T;Vm08nh_02>]k/0SkRl0P2@^Kd00`2?^;`0T;Vm09:k_`03096j
_P0408jg^`2?^;`0TKZn08nh_0<0T[^o0180Tkc0096j_P2?^;`0T[^o08nh
_P2A^/00T[_109Bm``2B^l40TK[009>l`P2B^l40TKRm09>j_`2D^l00TKZn
092i_@2B^kl209>l`00408nh_P2B^l40SkRn08jg_@80UKk400<0T;Vo096j
`02A^;l00P2C^/401`2A^;l0T[W009Fl``2D^l80T[W008ff^P2@^Kd00P2C
_<001@2A^[h0SkRl08jj_@2@_;l0T;Vm0080UKk200T0TKZn08nh_02C^[l0
U;_0096h_@2B^L00U;_209Fl``2C^/400P2@]kh0102B^L00Tk[1096j_P2@
^Kd209:k_`0808nh_02@^Kd0Tkc009Bm`@2E_/80U;g1096j_P2@^Kd209:k
_`0;096j_P2@^Kd0T[_109:k`@2E_/@0T[_1096j`02B^l40T;Vo09:k`@2?
^;`0102A^[h4092i_@80TKZn00H0T[^o09>l`02A^[h0SkRl09:k_`2A^/02
092i_`80SkRn0P2A^/000`2B^l40TkZo09:k_`0208nh_00409:k_`2C_<00
T[^o09>l`0P0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^C
U@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0
o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3K
fm/20=[JfP0808bAU025RiL0SYJ]09fW`P2/^=00]<?H0;K2g02e`=h80;G0
g00`0;G1f`2c_mT0Z[GA09n[a@2?Uj`0S9:P0?coo`3dmOL0_[k:0<73d031
amD0TIZ[08fFY`22S9P0^<780?Woo`3lool0jnob08J<W02@U:d0W::`0?Wo
o@3Nh^D0VIZ_09RR_@2U/L/0VJC008nK]@2;TjP0]ko<0?Wno`3If]`0^/77
0;[4cP2]^LL0NX>:0>;Vi@3lool0Z[730:Zee@2/^=00]l?K0;O3g@2d`=X0
]L7K0;C0fP2b_MT0/kkJ202e`=`0202e`M/0_LOP0<[Bi@3Df^X0e=SQ096B
U`3oool0ooomNP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3O
gml0g=cL0=_Kf@3Jf]X0[J^`08J3S02>RYP0X9b]0;:Z`@30^=000P33^m<0
0`34_=@0`k_C0<>kd`020<>kd`080<Ble033^m<0a;cD0<JneP38`=P0akoG
0<>kd`32^]820<Ble0050<>kd`35_MD0akoG0<Noe`34_=@00P32^]800`33
^m<0a;cD0<>kd`020<6id@090<Ble035_MD0`k_C0<Noe`33^m<0`[[B0<Bl
e037_mL0aKgE0080`k_C01D0`KW@0<Bld`34_=@0`[[B0<6id035_M80dL[J
0=[DhP3PgNP0N7B506aTO02BR:X0WI>h0:RN``2^X/H0[:340:bPaP2aYL/0
[J770:^Oa@2_XlT00P2^X/P03@2bY/`0[:360;>Wc@2bY/`0/JG;0;2TbP2^
X/P0/:C:0:nSb@2`Y<X0/JG;0;:Vc02cYld0102`Y<X02@2bY/`0[j?90:nS
b@2cYld0]JW?0;:Vc02`Y<X0/JG;0:nSa`020;>Wb`070:nSa`2`Y<P0/jO;
0;:VbP2`Y<P0/JG;0;>Wc@020;2TbP80]JW?0P2`Y<X03@2bY/`0/:C:0;BX
cP2dZ<h0[Z;80:nSb@2dZ<h0/ZK<0:nSa`2`Y<P0/jO;0;2Tb02_Y<H00P2a
Y/P05P2fZld0`[WH0<k6gP3Bbmd0Lf^206iRQP2>PJd0UhVj09Z<_@2JR[/0
Who00:2@`@2LS;d0VXZk09b<_@2NS[l0WHfn09j>_@2LS;/0WXjm0:6A`02P
T;l209b<^`0:09n?_P2PT;l0Xi?20:2@_`2NS[d0XY;10:JFa@2TU<<0XI70
0:2@_@80Xi?000H0X92m0:2@_`2STl80Xi?20:6A`02UUL@20:BD``80Xi?2
0P2STl004`2RT[l0Xi?00::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:gf@2<
RiT0IG=l06Z7S@1bVY`0P:N/08Za]P2;];X0R[Nl08^d^P2<]K/0102=][`2
08be^`0408bg_P2;][d0S;Nn08bg_P80RkJm00D0S;Nn08Ze_02@^l40T;_1
08nj`00208bg_@80S[Vo01@0S;Nm08ff_02C_<80U;g3092i_`2?^;h0TK[0
09:k`@2C_<80TKZn09Jo``2A^[h0T[^o09Fn`P2@^Kd0SkRl09Bm`@2F_lD0
U;g309:k`@80TK[000@0T;Vo09:k`@2F_lD0T[_10P2?^;h01P2C_<80T;Vo
096j`02F_lD0T;Vo09Joa@80TK[00P2C_<8209>j`@0609:i`02C_<80Tkc2
09:k`@2A^/00T[_10P2F_lD02@2@^Kl0TKRo09>j`@2A^;l0T;Nn09>j`@2E
_<<0U;_209:i`00209Bm``80Tkc2102B^l400`2C^/40T[W009>j`@0209>l
`P80T[_100<0Tkc209>j`@2B^L000P2C^/4309:i`003092g_P2B^l40T[_1
0080Tkc20P2A^/000`2B^l40TK[0092i_`0309:k`@80U;g300<0T[_109>l
`P2C_<800P2C_<80102@^Kl0SkRn09:k`@2B^l42096j`00?09Fna02B^l40
TK[009:k`@2@^Kl0T[_109Fna02G`<H0Tkc2092i_`2A^/00Tkc2096j`02B
^l40U[o50080T[_100@0U;g3092i_`2@^Kl0U;g30P2B^l40202@^Kl0T[_1
09>l`P2D_L<0UKk409Fl``2C^/40T[W0202C^/40302C^[l0T[Vn09:i`02L
`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm
0?ooo`3oool04@3oool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0
l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0S96D08F;U`2>UZd0WJO20:bh
d02d`mP0]/;L0;G0gPP0]L3L02`0]/;L0;:mf@2Y]m80XJg7092K[`26SY/0
koCj0?koo`3oo_l0nO[n0??jo`2b_<P0QiBU08B@X022S9D0j?;c0?WmoP3C
emX0Q8ZF07]oV02IWjl0mooo0?Kjo@2GV:X0VjNo09BP^02EXK/0Si^c08B<
W`2i_ld0n_go0?_loP3hool0m_oo0=7Mj`28TIP0c];A0?koo`2i`L`0YK79
0:ZfcP2d`=P0]<3J0;>of@80]L7K0P2f`Md80;G0g0080;G1f`2man00b];U
0=CJjP3Df>40TI:G0?ooo`3oooej0?ooo`008@3oool0403no_h0n_[j0?Cd
m03]kNd0iNGU0=oOg`3Lg=`0fm_I0=[JfP2]Zk00QX><08j:V02QWJh0/Z[1
0<2hd033^m<30<Ble0030<>kd`32^]80`k_C00<0a;cD00D0`k_C0<6id@30
^=00`KWA0<>kd`020<Fme@0:0<Ble032^]80`KWA0<6id@32^]80`k_C0<Bl
e032^]80aKgE0<JneP80a;cD00<0a[kF0<Fme@33^m<00P32^]806@34_=@0
aKgE0<Ble030^=00`KWA0<Fme@35_M@0a;cD0<>kd`32^]80aKgE0<_3f03C
c=h0fM;R0>7Ni`1mNHP0KFEl0968Y`2MTkH0Yig00:bPa02ZWl40Yi^o0:^O
``2`Y<P00P2_XlL0402]XLD0ZYk20;2Tb02]XLD0/:C80:ZN`P2[Wl<0/:C8
0:nSa`2`Y<P0[Z;60:^O``2_XlL0/:C80:nSa`2`Y<P20:nSa`070;:VbP2d
Z<`0/JG90:nSa`2aYLT0/ZK:0;6Ub@020;2Tb0030:^O``2bY/X0/jO;0080
/JG900@0[j?70:jRaP2_XlL0/:C80P2aYLT01`2`Y<P0[j?70:jRaP2`Y<P0
/jO;0;BXc02_XlL00P2^X/H00`2]XLD0/:C80;:VbP020:nSa`0?0:jRaP2b
Y/X0/JG90;2Ua`2aY/P0/:G70;FZc031^=L0cLGL0=?<gP1cJh80KfB60964
/02HR[/0W8nm0080WHfl00<0W8bk09^;^P2NS[d00P2QTL002P2NS[d0Whnl
09n?_02PT;d0XI6n0:2@_@2OSk`0XI6n0:FE`P2PT;d20:FE`P80XI6n0P2P
T;d01`2RT[l0XY>l0:BE_P2TUL00XY>n0::B_`2STl000P2UUL@00`2RT/40
XI6n0:6A_P030::B_`0B0:>D_`2TUL00Xi?00::B_`2RT/40Xi?00:2C_P2U
VL40/jO;0<:gf@2<RiT0IG=l06Z7S@1bVY`0PJR]08Za]P2;];X0R[Nl0`2<
]K/508ff_007092i_`2>]kd0SkRn08nh_P2=][`0SkRn096j`00408nh_P80
SKJl01L0S[Nm08nh_P2@^Kl0Tk[109Bk`P2B^L00T;Nn09>j`@2D^l80TKRo
092g_P2?][/0U;_0092g_02A^;d0U;_0096h_@2C^[l0U;_009:i`02A^;l0
Tk[109Bk`P0209>j`@0>09:i`02?][d0UKc309>j`@2@]kh0Tk[109:i`02A
^;l0UKc3092g_P2C_<80S[Fl08nf_@2C^/4209:i`00>09>h`02B]kl0U;_2
09>j`@2E_<<0T[W008fd^`2?][d0U;_209:i`02C^/40UKc309>j`@2A^;l2
09Bk`P07096h_`2B^L00TK[0092i_`2?^;h0T;Vo09:i`00309>j`@0<09Jk
``2A][h0S[Fl09:i`02D^l80T[W008nf_@2?^;h0U;_2092g_P2B^L00U;_2
0P2C^/405`2D^l80T[W0096h_`2@]kh0S[Fl092g_P2D^l80UKc309:i`02A
^;l0T;Nn09Bk`P2E_<<0Tk[109:i`02?][d0S[Fl09:i`02F_L@0U;_2096h
_`2B^L00U;_20080UKc300@0Tk[109:i`02E_<<0TKRo0P2B^L003P2@]kh0
U;_209>j`@2A^;l0T;Nn09:i`02F_L@0U;_209:i`02A^;l0T;Nn09:i_P2@
]k`0UKc10P2C^[l00`2E_<40T;Nl09:i_P0209>j`@0609Bk`P2B^L00S[Fl
08nd_02C^<00UK[2202C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039
emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3o
ool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40
gMgM0=_Kf`80f][J00P0S96D08F;U`2>UZd0WJO20:bhd02d`mP0]/;L0;G0
gPP0]L3L00l0]/7M0:nmf02Y]m80Xjo909RS]`2>UZ<0emcR0?cmo`2k^l<0
[K:h0:Vd^P2:V:D0R9BZ08F=XP2JXJ/00P3lool07`3cmoP0/[W108V>XP28
SJ00fn;X0?coo`2h^/L0S9VZ09BQ]02;V:/0QI2T0827V@2TZ;@0o_oo0>SX
jP2SZ:/0XJVf09NO]020QIP0`L790?koo`36cML0WZVm0:fid@2d`=P0/koI
0;G1f`2f`]`0]L7K0;O2gP2c_]X0202e`=`0202e`M/0_LOP0<[Bi@3Df^X0
e=SQ096BU`3oool0ooomNP3oool00240oooo0140o_kn0?[jnP3dm?@0kNg]
0>GUi@3Ogml0g=cL0=_Kf@3Jf]X0[J^`08N4S@2>RYP0XIf^0;:Z`@30^=00
`[[B0<Ble0020<Fme@050<Ble033^m<0`k_C0<Ble032^]800P34_=@01032
^]80`k_C0<JneP35_MD20<:jdP80aKgE0P33^m<20<Fme@060<>kd`34_=@0
`KWA0<:jdP34_=@0`k_C0P31^M401034_=@0`k_C0<Fme@34_=@20<:jdP80
aKgE02d0`k_C0<2hc`33^m<0a;cD0<>je@33^m<0akoD0=7:g03Id^80fMKO
07eiQ`1_Igh0THRU09nE]`2WWL00[:730:fR`P2bY/X0Zio30:nSa`2^X/H0
[j?70;6Ub@2]XLD0/:C80:jSa@2bYlT0[Z?50:nTaP2aY/P0[J;40:nTaP2`
YLL0/ZO90;BYb`2aY/P0[jC60;:Wb@2aY/P0[Z?50;2Ua`2_Y<H0/JK80;:W
b@2aY/P00P2`YLL20;6Vb080/JG900X0[J750:nSa`2cYl/0/ZK:0;6Ub@2b
Y/X0/jS:0:jSa@2`YLL0/jS:0P2`YLL0102bYlT0/:G70:jSa@2`YLL30;6V
b0050;2Ua`2_Y<H0/:G70;:VbP2^X/H00P2aYLT04@2`YLL0/JK80;6Vb02f
Zld0aKcI0<[2f@3Gd>00MVj306aQP`2BQK00V8^i09V<^P2KRkP0W8bi09f=
^P2OSk`0WXjk0080WHfj0P2OSk`40:2@_@80XI6n00D0Whnl0:>C`02OSk`0
XI6n0:BD`@020:6A_P0;0:>C`02QTKh0XiBk0:6B^`2PTKX0XY>n0:>D_`2R
T[l0X92m09n?_P2TU<400P2STl005@2TU<40Y9G00:6B_@2PTK`0XI:m0:>C
`02RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0S8^I06EcO01ZQhd0LYZL
086X[@2;/[L0RkBj08Zg_00408be^`0@08ff_02>]kd0S[Nm08nh_P2@]k`0
SKBi08nf^`2@]k`0S[Fj092g_02B^Kh0T;Nl08nf_@2A^;l0T[W009>j`@80
T[W000h0Tk[109Bk`P2@]kh0Tk[109:i`02A^;l0Tk[1096h_`2@]kh0U;_2
09:g_@2F^l40TkRn09Bi_`80TkRn00d0V;g309:g_@2E^/80TkS009Bi`@2C
^<00TKJn09Fj`P2G_<@0TKJn09:g_`2F^l<0TkS00080UK[200/0T[No09Fj
`P2D^L40T[W009>j`@2E_<<0U;_2096f_P2D^L40U[_3096f_P0309>h`007
09Bi`@2E^/80U;W109>h`02D^L40TKRo09Bk`P0209>j`@0609Bk`P2C^/40
T[W009Fl``2B^l40Tkc20P2D^l80802C^/40T[No09:g_`2B]kl0TkS009Fj
`P2G_<@0U[_309>j`@2B^L00Tk[109Bk`P2F_L@0T[W009Bk`P2E_<<0TKRo
092g_P2D^l80UKc309Bi`@2H_LD0U[_309>h`02E^/80TkS0096f_P2E^/80
U[_309Nla02D^L40TkS00P2F^l<00`2C^<00UK[209Bi`@0209Bi`@0=09Nl
a02E^/80T;Fm09:g_`2E^/80U;W109:g_`2A][h0U[_309>h`02B]kl0Ukc4
092e_@0209:g_`80U[_300H0TKJn09>h`02F^l<0U;W109Jk`@2A][`409>h
_P0:092e^`2F^l40U;_2096h_`2C^/40U[_309Fj`P2F^l<0VK_409Bf_`P0
Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn
0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn0?ooo`3o
ool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/20=[JfP08
08bAU025RiL0SYJ]09fW`P2/^=00]<?H0;K2g02e`=h80;G0g00`0;?1g02a
_mX0[kgH0:B`bP2GX[P0T9NW0<O<dP3lool0^Ko=08B>V022T9/0R9NZ07n;
Y@29SjL0c<cH0?ono`3Een<0mo_l0>_cm@2KX;<0RXnS0:N^^03lool0mOSo
09^W]@25TZ80R9>U08B?X@2JXK40TIFP0?Sgo@3hm_T0R8^B08:7VP25RZL0
QhRT0;Jca03oo_l0f=cX0:Ja``2]^M40/[kF0;:nf02f`]`0]l?M0;K2g02i
a>00/kkJ202e`=`0202e`M/0_LOP0<[Bi@3Df^X0e=SQ096BU`3oool0ooom
NP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[J
f03Kfm/0ZZV^08J5S@2@S9X0X9b]0;6/`P2m^<l0:034_=@04@34_=<0`k_B
0<>kd`33^m<0a;cC0<S0e@3Ab]X0f]CR0=gJh`1mNHL0KfMn0968Y`2OUKP0
ZIo40:fQa`2]XLD0[J7700L0[Z;80P2^X/H20:nSa`80/:C8:P2aYLT01@2_
XlL0/JG90;2Tb02`Y<P0/JG90080/:C800X0]Z[>0<:ieP3=aM`0eLcM07I]
PP1^HhD0T8>^09Z:^@2LS;/0WHfl0`2NS[d309n?_P030:2@_`2PT;d0X92m
0080X92m302QTKhA0:>C`00?0::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:g
f@2;RYP0IG9k06Z7S@1dVYd0PJR]08ba]`2<]K/0RkJl00@0SKJl102>]kd4
08nf_@P0T;Nn202A^;l409:i`8P0Tk[100`0TkZo09:i_P2B^L00W<770:o>
d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0
oooo0140oooo00`0o_kn0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3Y
jNT0hN7Q0=gMg@3Kfm/20=[JfP0808bAU025RiL0SYJ]09fW`P2/^=00]<?H
0;K2g02e`=h80;G0g00[0;;0fP2d`]d0[[WG0:Vbc`2RZL<0V9n_0;_2b03i
ool0g^;Q0<;6b@2m`<T0b<[G08B6T`2MX:T0m?Sk0?Wmo02VZkl0];_30?Wo
o`3Ni^T0TiVY09>H[P2na=00nOoo0?gno`3BdmP0`<760>3QiP3BdmP0T96F
0?CenP3nool0_lC70<35b@32al/0WjBZ0:JZ/`3kool0hnOc0:fa_@2^^MD0
/KcH0;Bof`030;G0g0030;K1g@2g`]h0]L3L00L0]L3L00P0]L7K0;g7h03:
d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0oooo000Q0?ooo`0?0?knoP3jn_X0
m?Cd0>g]k@3UiND0gmoO0=cLg03Jf]P0fm_K0:ZY[P26QHd0T8bJ0:2L[@2a
[<80_KS?02P0a;cD0100a;cC0<>kdP33^m<0`k_C0<Bld`38`=D0dL[J0=[D
hP3Mf^<0OGV706mWOP2AR:L0WiFh0:VOa02]XLL0[J751P2^X/P20:nSb@04
0:jRaP2_XlL0[j?70:nSa`80/:C8:P2aYLT01@2_XlL0/JG90;2Tb02`Y<P0
/JG90080/:C800T0]Z[>0<:ieP3=aM`0eLcM07I]PP1^HhD0T8>^09^;^P2L
S;/0102NS[d209n?_P80X92o102PT;d40:6A_PP0XY:o4@2STl003`2RT[l0
XY;10:>C`02PTkh0YIW10;>Wb`32]mT0RhZH06EbN`1ZQhd0M9ZM086X[@2<
/KL0S;Fk08^f_00408ff_0@0S[Nm102?][d8092g_PP0TKRo102B^L2809>j
`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3o
ool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo
0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202<
TI@0QH^G08jF[@2MYl80[;S@0;C3f02f`]`0]L3N202e`=`06P2d`]`0]/CO
0;:mf`2[]=<0Xj[609bS]P2j`l`0l_Wo0?_oo`3io_l0nooo0??fo`2TYkP0
^Kg90?_oo`3]l_H0SiF]09bT[`3Nj>X0loco0<O>h@2PY/00W:>c0;W2a`3e
nOl0n?co0P3kool01@3Gfn@0VinX0>?Wl03enOl0m_go0080nOoo00L0_L??
09bR[P3enol0mO_o0:bb`P2_^]H0/[gI00<0]L3L00<0];oK0;G0g02g`]h0
202e`=`0202e`M/0_LOP0<[Bi@3Df^X0e=SQ096BU`3oool0ooomNP3oool0
0240oooo00l0o_kn0?[jnP3dm?@0kNg]0>GUi@3Ogml0g=cL0=[Jf03Kfm/0
ZZV^08J5S@2@S9X0X9b]0;6/`P2m^<l0:034_=@04034_=<0`k_B0<>kd`33
^m<0a;cC0<S0e@3Ab]X0f]CR0=gJh`1mNHL0KfMn0968Y`2OUKP0ZIo40:fQ
a`2]XLD50:jRb0<0[j?90`2_XlL40;2Tb2T0/JG900D0[j?70;6Ub@2`Y<P0
/:C80;6Ub@020;2Tb0090;JZcP32^MH0cLGL0=G<g@1fKH80KfB60923[P2K
RkX0WHfl00<0WXjm0`2OSkh20:2@_`<0X92m1@2QTKh80::B_a40Xi?000l0
XY:o0::B`@2STl00X9>n0:FI`@2cYl/0`[OI08b;V@1VLg`0JXN=07BJW@21
Z:d0S;6g08be^`2;][`00`2=][`508jg_@<0SkJm202@]kh8096h_`D0T[W0
R02C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03n
o_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo
0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J
00P0S96D08F;U`2>UZd0WJO20:bhd02d`mP0]/;L0;G0gPP0]L3L02X0/L3G
0;6of@2b_M/0/kcK0:ffd`2SZ/@0Yjk10;Roc`2d_<L0^/7A0;W0d`2h_]@0
WjFk0:jeb030amL0]ko:0:J`b`2NZK/0Y[>l0;[6e02h`]/0YZo<09nZ`02T
/;`0YJbl0;W0d03:dN40_/GE0;2ga`2GWZh0/[W90;g4e02f_lh0/kc;0;[3
e02^]lP0W:Bg0;g5fP2oam`0/;S=0;6lf02c_]X30;G0g0030;Bof`2e`=`0
]/7M00P0]L3L00P0]L7K0;g7h03:d^D0e=[Z0=CHh@2ATYL0oooo0?oooGX0
oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3UiND0gmoO0=cLg03Jf]P0
fm_K0:ZY[P26QHd0T8bJ0:2L[@2a[<80_KS?02P0a;cD0100a;cC0<>kdP33
^m<0`k_C0<Bld`38`=D0dL[J0=[DhP3LfN80OGV706mWOP2AR:L0WiFh0:ZP
a@2^X/P0[Z;6102^X/P40:nSb@80[j?71@2`Y<PY0;6Ub@050:nSa`2aYLT0
/:C80;2Tb02aYLT00P2`Y<P02@2fZ/h0`[WF0<g5g03Ec=d0MVf206mTQP2A
Q:l0Vh^j09f=_00209j>_@<0Whnn0`2PT;l20:2@_@H0XI6n202RT[lA0:>C
`00?0::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:gf@2<RiT0IW=l06Z7S@1d
VYd0PZV^08ba]`2<]K/0RkJl0080SKJl1P2>]kd208nf_@P0T;Nn202A^;l6
09:i`8P0Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo0140oooo00`0o_kn
0?ooo`3oool0oooo0?knoP3moOd0n?Sh0?;blP3YjNT0hN7Q0=gMg@3Kfm/2
0=[JfP0808bAU025RiL0SYJ]09fW`P2/^=00]<?H0;K2g02e`=h80;G0g00Z
0;G4f`2c_mT0/KcH0;>ng02c_=/0[[OD0:Zac@2W[/P0Yk;60:Rcb@2R[<D0
ZK?>0:bfd@2]]m00Y:o50:bgb`2Y]=@0[KWA0:ReaP2[]ld0[[WG0:fhf02`
_=H0Z[O:0:Rcb@2Y]<X0ZkK<0:Jaa`2_^]00ZkK<0:B_a@2U/<H0Z;?90:Vd
bP2V/LL0[KO@0:jhd@2]]m80Yk7<0;K0f`2b_MT0];oK0`2e`=`00`2d_m/0
]L3L0;G0g0080;G0g0080;G1f`2man00b];U0=CJjP3Df>40TI:G0?ooo`3o
ooej0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0
f][H0=_Kf`2ZZJh0QXF=092<VP2PW:d0/Jc20;fhc`0X0<Ble00@0<Bld`33
^m80`k_C0<>kd`34_=<0b<3E0=7:fP3Je>80g=WR07eiQ`1_Igh0THRW09nE
^02ZX<D0[Z;80:jRaP@0[Z;8102_XlT80;2Tb2P0/JG900D0[j?70;6Ub@2`
Y<P0/:C80;6Ub@020;2Tb0090;JZcP32^MH0cLGL0=G<g@1fKH80KfB60964
[`2LS;/0WXjm00<0Whnn0`2PT;l20:6A`0H0XI6n2P2RT[lA0:>C`00?0::B
_`2RT/40Xi?00:2C_P2UVL40/jO;0<:gf@2<RiT0IW=l06^8SP1dVYd0PZV^
08fb^02<]K/0S;Nm00H0S[Nm0P2?^;h6092g_PP0TKRo202B^L2:09>j`@0<
09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0
o_kn0P3oool00`3moOd0oooo0?ooo`0A0?ooo`0<0?knoP3oool0oooo0?oo
o`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3MgMd0fm_K0P3Jf]X0202<TI@0
QH^G08jF[@2MYl80[;S@0;C3f02f`]`0]L3N202e`=`06P2g`m/0]/;L0;K1
g@2e`=h0/KcJ0;>lf`2e_]d0/kcK0;:nf02]^M<0];oK0;G0gP2]^=H0];oK
0;:nf02c_mT0/;gM0;2nf@2a_mT0/l7K0;2mg@2__=`0/KoL0:nme`2a_ML0
[k_E0P2`_=H01P2a_ML0/;cF0:fid`2b_]P0/;_G0;:mf@80/KcH00@0[;OC
0;>nfP2e`=h0[k[H0P2d_m/30;G0g080];oK2@2e`=`0202e`M/0_LOP0<[B
i@3Df^X0e=SQ096BU`3oool0ooomNP3oool00240oooo00l0o_kn0?[jnP3d
m?@0kNg]0>GUi@3Ogml0g=cL0=[Jf03Kfm/0ZZV^08J5S@2@S9X0X9b]0;6/
`P2m^<l0:034_=@04034_=<0`k_B0<>kd`33^m<0a;cC0<S0e@3Ab]X0f]CR
0=cIhP1mNHL0KfMn0968Y`2PU[T0ZZ350:jRb02_XlL30:jRb0D0[j?9202`
Y<PX0;6Ub@050:nSa`2aYLT0/:C80;2Tb02aYLT00P2`Y<P02@2fZ/h0`[WF
0<c4f`3Ec=d0MVf206mTQP2AQ:l0W8bk09j>_@0209n?_P<0X92o0`2QTL05
0:6A_P/0XY:o4@2STl003`2RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0
S8^I06IcO01[R8h0M9ZM08:Y[P2=/[P0S;Fk08bg_@0508jg_@<0SkRn1@2@
]kh8096h_`P0T[W0R`2C^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039
emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3o
ool0303no_h0oooo0?ooo`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40
gMgM0=_Kf`80f][J00P0S96D08F;U`2>UZd0WJO20:bhd02d`mP0]/;L0;G0
gPP0]L3L0P2d`=X06P2g`md0]/7M0;Bof`2e`=h0];oM0:jie`2d`]d0/;kK
0;;0g@2`_]/0[kgJ0;G3h02a_m`0/KoJ0;O5hP2^_=L0[kgH0;6ofP2b`=d0
]L?P0;;0g@2/^]D0/kkJ0;G0g02f`Md0]l;N0P2b_MT0202f`Md0]L3L0;Bo
g@2_^]P0/kkL0;[5h`2e`=h0/[gI4P2e`=`0202e`M/0_LOP0<[Bi@3Df^X0
e=SQ096BU`3oool0ooomNP3oool00240oooo00l0o_kn0?[jnP3dm?@0kNg]
0>GUi@3Ogml0g=cL0=[Jf03Kfm/0ZZV^08J5S@2@S9X0X9b]0;6/`P2m^<l0
:034_=@04034_=<0`k_B0<>kd`33^m<0a;cC0<S0e@3Ab]X0f]CR0=cIhP1m
NHL0KfMn09:9Z02PU[T0Zj760:nSb@2_XlL20:jRb0H0[j?90P2aYLT60;2T
b2P0/JG900D0[j?70;6Ub@2`Y<P0/:C80;6Ub@020;2Tb0090;JZcP32^MH0
c<CK0=G<g@1fKH80KfB609:5/02MSK`0WXjm0080Whnn0P2PT;l40:6A`0@0
XI6n302RT[lA0:>C`00?0::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:gf@2<
RiT0IW=l06^8SP1eVih0PZV^08fb^02=][`0S;Nm00@0S[Nm102?^;h4092g
_PP0TKRo202B^L2<09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WG
fP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0A0?oo
o`0<0?knoP3oool0oooo0?ooo`3no_h0oOgm0?Shn03bl_80jNWY0>7Qh@3M
gMd0fm_K0P3Jf]X0202<TI@0QH^G08jF[@2MYl80[;S@0;C3f02f`]`0]L3N
202e`=`06@2g`]h0]L3L0;>of@2c_mT0]L7K0;O5g`2gaN00/l7L0:nmfP2e
`mh0/l7L0;2nf02gaMl0//3K0:fkeP2jb>D0/koI0;O2gP2ia>00]/7M0;C0
fP2f`]`0^<?O0;K1g@2g`]h00P2d_m/01@2f`Md0^<?O0;S3g`2h`ml0/KcH
0080]l;N00H0]L3L0;:mf@2f`Md0]<3J0;>of@2ja^0@0;G0g0080;G1f`2m
an00b];U0=CJjP3Df>40TI:G0?ooo`3oooej0?ooo`008@3oool03`3no_h0
n_[j0?Cdm03]kNd0iNGU0=oOg`3Lg=`0f][H0=_Kf`2ZZJh0QXF=092<VP2P
W:d0/Jc20;fhc`0X0<Ble00@0<Bld`33^m80`k_C0<>kd`34_=<0b<3E0=7:
fP3Je>80g=WR07eiQ`1_Igh0TXVX0:2F^@2[XLH0[j?90:nSa`L0[j?900<0
/:C:0;6Ub@2aYLT00P2aYLT40;2Tb2P0/JG900D0[j?70;6Ub@2`Y<P0/:C8
0;6Ub@020;2Tb0080;JZcP31^=D0c<CK0=G<g@1fKH80L6F709:5/02MSK`2
09n?_P<0X92o0`2QTL000`2RT/40XI6n0:6A_P020:6A_P@0XY:o6@2STl00
3`2RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0S8^I06IcO01[R8h0MI^N
08:Y[P2=/[P0SKJl08bg_@0408jg_@@0SkRn102@]kh8096h_`P0T[W0S02C
^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool04@3oool0303no_h0oooo0?oo
o`3oool0o_kn0?gmo@3hn?P0l_;b0>WYj@3QhN40gMgM0=_Kf`80f][J00P0
S96D08F;U`2>UZd0WJO20:bhd02d`mP0]/;L0;G0gPP0]L3L00`0/[gK0;K1
g@2ha=h0]/;J0;;1f02a`=L0//3J0;G3g@2c`M`0]<;M0;C2g02b`=X20;?1
f`0H0;G3gP2a_mX0];kG0;[4g`2d_]T0]l7L0;W3g02b_=D0/kgH0;K0f`2g
`md0/koI0;O3g@2e`M/0]l?M0;6me`2c_mT0]l?M0;K1g@2c_]X0]l;N0;G1
f`2g`md0^<CN0P2d`=P@0;G0g0080;G1f`2man00b];U0=CJjP3Df>40TI:G
0?ooo`3oooej0?ooo`008@3oool03`3no_h0n_[j0?Cdm03]kNd0iNGU0=oO
g`3Lg=`0g=cJ0=cLg02[ZZl0QXF=092<VP2PW:d0/Zg30;fhc`0X0<Ble00@
0<Bld`33^m80`k_C0<>kd`34_=<0b<3E0=7:fP3Je>80g]SR07miQ`1`J7l0
ThZY0::F^P2/X<H0[j?90:nSa`80[Z;60P2_XlL20;2Tb380/JG900D0[j?7
0;6Ub@2`Y<P0/:C80;6Ub@020;2Tb0090;JZcP32^MP0cLGL0=C=g@1fKX<0
L6F509:6[P2KS[X0WI2l00@0X92m102QTKh80::B_aT0Xi?00100XY:o0::B
`@2STl00X9>n0:FI`@2cYl/0`[OI08Z<V@1ULg`0JhR>07FKWP24ZJl0S[>i
08nf_@2=^;h0SkJm202@]kh;096h_`@0T[W0T02C^/40302C^[l0T[Vn09:i
`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0oooo0?knoP80oooo00<0
oOgm0?ooo`3oool0503oool20?knoP0A0?gmo@3inOT0l_;b0>WYj@3Rh^80
g]kN0=cLg03Kfm/0f][J08fBU@25RiL0SYJ]09fV``2[]m40]<;L0;G0g02d
_ml0@02f`=/0202d`]d0_LWQ0<WDiP3Bf^L0d]WO096EUP3noo/0oOkhNP3o
ool00240oooo00l0o_kn0?[jnP3dm?@0k>c/0>CTi03Ogml0g=cL0=_Kf@3L
g=`0ZZV^08J5S@2@S9X0X9b]0;:]``2m^<l0:034_=@04@34_=<0`k_B0<>k
d`33^m<0a;cC0<S0e@3Ab]X0f]CR0=kHhP1oNHL0L6Qo09>:Z@2RU[X0[:36
0:nSb@2_XlL0[Z;600<0[j?70P2`Y<Pb0;6Ub@050:nSa`2aYLT0/:C80;2T
b02aYLT00P2`Y<P02@2fZ/h0`[WH0<g5g03DcMd0MVj3071UQ@2CQjl0Vhjj
09f@_0040:2@_@@0XI6n202RT[lI0:>C`00?0::B_`2RT/40Xi?00:2C_P2U
VL40/jO;0<:gf@2:S9T0IG=l06^8SP1eVih0Q:V_08jc^@2?][d0SKRn00H0
T;Nn202A^;l209:i`0@0TKRo102B^L2@09>j`@0<09>j_`2B^Kh0T[W009c1
a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0
oooo0?ooo`0D0?ooo`80o_kn00L0oOgm0?Win@3bl_80jNWY0>7Qh@3MgMd0
g=cL0080f][J00P0S96D08B:UP2>UZd0WZO40:bhdP2c`]T0]L3L0;K1hD00
]L7K00P0/l7L0;c8hP38dnL0d]WY0=CHh@2AUIH0o_om0?gnn7X0oooo000Q
0?ooo`0?0?knoP3jn_X0m?Cd0>c/k03Ti>@0g]kN0=_Kf`3KfmT0fm_K0:ZY
[P26QHd0Sh^I0:2L[@2b[L<0_KS?02P0a;cD00l0a;cC0<>kdP33^m<0`k_C
0<Bld`38`=D0dL[J0=[DhP3OfN<0OgV7071XO`2CRZT0XYJj0:bPaP2_XlT0
102_XlL40;2Tb340/JG900D0[j?70;6Ub@2`Y<P0/:C80;6Ub@020;2Tb009
0;JZcP32^MP0cLGL0=C=g@1fKX<0L6F509>7[`2LSk/0WY6m00<0X92m1@2Q
TKh80::B_aT0Xi?000l0XY:o0::B`@2STl00X9>n0:FI`@2cYl/0`[OI08Z<
V@1VM7d0JhR>07FKWP24ZJl0S[>i08nf_@2=^;h01@2@]kh8096h_`<0T[W0
0`2A^;l509:i`900Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ
08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo01@0oooo
0P3no_h01`3moOd0n?Sh0?;blP3YjNT0h^;R0=kNgP3Lg=`00P3Kfm/0202=
TYD0Q8ZF08jF[@2OZ<D0[KWC0;?2f@2e`M/0^<?Q@02c`M`0202f`Md0_<SR
0<[Bi`3Cf^X0eMWT096DV@3oool0o_klNP3oool00240oooo00l0o_kn0?[j
nP3dm?@0k>c/0>CTi03Ng]h0fm_K0=[Jf03Kfm/0ZZV^08J5S@2?RiT0X9b]
0;:]``2m^<l0:034_=@03`34_=<0`k_B0<>kd`33^m<0a;cC0<S0e@3Ab]X0
f]CR0=oIh`1oNHL0L6Qo09>:Z@2RU[X0[J770;2TbP030:nSa`D0/:C8<@2a
YLT01@2_XlL0/JG90;2Tb02`Y<P0/JG90080/:C800T0]Z[>0<:if03=aM`0
eLkN07I^P`1aIXH0ThN_09b?^`2NTKd00P2PT;d60:6A_PP0XY:o6@2STl00
3`2RT[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0RhfJ06IdO@1/RHl0MI^N
08BY[`2>/kT0SkJm08fh_P04092g_PP0TKRo102B^L02096h_`H0T[W0T02C
^/40302C^[l0T[Vn09:i`02L`LL0[lkC0;kCf039emX0Ri>E0?Shn03no_h0
oooo0?knoP80oooo00<0oOgm0?ooo`3oool0503oool20?knoP060?gmo@3h
n?P0lo?c0>_[j`3Ti>@0h>3P0`3Ng]h0202>TiL0Q8ZH08fE[02NZ<<0[KWA
0;?2e`2e`M/0]l;N@02c`M`0202g`]h0_/SS0<_CjP3Dfnd0eMWT09:CV03o
ool0oognNP3oool00240oooo00l0o_kn0?[jnP3dm?@0k>c/0>CTi03Ng]h0
g=cL0=_Kf@3Kfm/0ZZV^08J5S@2?RiT0X9b]0;:]``2m^<l0:034_=@03`34
_=<0`k_B0<>kd`33^m<0a;cC0<S0e@3Ab]X0f]CR0=oIh`20NXP0L6Qo09>:
Z@2SUk/0[J770;2TbP090;2Tb300/JG900D0[j?70;6Ub@2`Y<P0/:C80;6U
b@020;2Tb0090;JZcP32^MP0cLGL0=G>gP1fKX<0LFJ609B8/02MT;`0Wi:n
00H0XI6n2P2RT[lI0:>C`00?0::B_`2RT/40Xi?00:2C_P2UVL40/jO;0<:g
f@2;SIX0IWAm06b9S`1fW9l0Q:V_08jc^@2?][d0S[Vo00@0T;Nn202A^;l:
09:i`980Tk[100`0TkZo09:i_P2B^L00W<770:o>d`2ndmP0bMOJ08^CU@3h
n?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3oool0oooo01@0oooo0P3no_h0
1P3moOd0nOWi0?Gem@3^k^h0jNWY0>GUi@<0i>CT00P0SY>G08B:V02;TjX0
W:K10:bhd02c`]L0]<3H0;C0fT00/l7K00P0]/;L0;g7h03;dnP0eM_[0=GG
h`2ATYL0o_ko0?onogX0oooo000Q0?ooo`0?0?knoP3jn_X0m?Cd0>g]k@3U
iND0gmoO0=gMg@3Lg=X0g=cL0:^Z[`26QHd0T8bJ0:2L[@2b[L<0_KS?02P0
a;cD00l0a;cC0<>kdP33^m<0`k_C0<Bld`38`=D0dL[J0=[DhP3OfN<0P7Z8
071XO`2CRZT0XiNk0:fQa`2`Y<X02@2`Y<P`0;6Ub@050:nSa`2aYLT0/:C8
0;2Tb02aYLT00P2`Y<P02@2fZ/h0`[WH0<g5g03Ec]h0MVj3075VQP2DR;00
WI2l09nB_P050:6A_P/0XY:o6@2STl003`2RT[l0XY;10:>C`02PTkh0YIW1
0;>Wb`32]mT0RhfJ06IdO@1/RHl0MYbO08FZ/02?];X0SkJm08ji_`03092g
_PP0TKRo2P2B^L2C09>j`@0<09>j_`2B^Kh0T[W009c1a`2_c]<0_]?H0<WG
fP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool00`3moOd0oooo0?ooo`0D0?oo
o`80o_kn00H0oOgm0?_kn`3hn?P0m?Cd0?3`l03]kNd30>c/k00808fBUP26
S9X0T9R_0:6[aP2`_=80^<OJ0;S4fP2g`m]00;S4g0080;W4fP2nbMd0cMCV
0=KLjP3FfN80T96F0?omo`3oo_mj0?ooo`00803oool0403no_h0oOgm0?[j
nP3emOD0kNg]0>KViP3QhN40g]kN0=gMf`3Ng]h0[:^`08N6SP2@S9X0X9b]
0;:]``2m^<lX0<Ble00@0<Bld`33^m80`k_C0<>kd`34_=<0b<3E0=7:fP3J
e>80gmWS081jR01`J7l0U8^Z0:>G^`2]XLL0/:C:0;2Tb080/JG91P2`Y<P`
0;6Ub@050:nSa`2aYLT0/:C80;2Tb02aYLT00P2`Y<P02@2fZ/h0`KSG0<g5
g03Ec]h0Mfn4075VQP2DR;00WI2l09nB_P040:6A_P`0XY:o6@2STl003`2R
T[l0XY;10:>C`02PTkh0YIW10;>Wb`32]mT0RhfJ06IdO@1/RHl0MYbO08FZ
/02?];X0T;Nn08ji_`02092g_PP0TKRo2P2B^L2D09>j`@0<09>j_`2B^Kh0
T[W009c1a`2_c]<0_]?H0<WGfP2;TiD0n?Sh0?knoP3oool0o_kn0P3oool0
0`3moOd0oooo0?ooo`0D0?ooo`80o_kn00L0oOgm0?clo03kno/0nOWi0?Kf
mP3dm?@0lo?c0080m?Cd00P0SI:H08jDXP2NY[d0[KOB0;[6g032d^80`m3S
0<7=iD00a/kU00P0a<oS0<[Bi@3FgNd0gNC^0=[Mi02BTIH0oogn0?onoGX0
oooo000P0?ooo`0@0?knoP3moOd0no_k0?Gem@3^k^h0inOW0>7Qh@3Ogml0
g]kL0=kNgP2][;40R8N?092<VP2QWJh0/Jc20;fhcbP0a;cD0100a;cC0<>k
dP33^m<0`k_C0<Bld`38`=D0dL[J0=[DhP3OfN<0P7Z8075YP02DRjX0XiNk
0:fQa`2`Y<X0/:C8102aYLT40;2Tb300/JG900D0[j?70;6Ub@2`Y<P0/:C8
0;6Ub@020;2Tb0090;JZcP31^=L0cLGL0=G>gP1gKh@0LFJ609B8/02NTKd0
X9>o00@0XI6n302RT[lI0:>C`00?0::B_`2RT/40Xi?00:2C_P2UVL40/jO;
0<:gf@2;SIX0IWAm06b9S`1fW9l0QJZ`08nd^P2@]kh0S[Vo00L0TKRo202B
^L000`2C^/40T[W009:i`00209:i`9@0Tk[100`0TkZo09:i_P2B^L00W<77
0:o>d`2ndmP0bMOJ08^CU@3hn?P0o_kn0?ooo`3no_h20?ooo`030?gmo@3o
ool0oooo01@0oooo0P3no_h01P3moOd0o_kn0?gmo@3lo?`0n_[j0?Win@80
n?Sh00T0nOWi08jCV@2FW:X0Zk?:0;[4g`34d>H0bm_[0<gJk@3<f>h0@03@
enX0203AgNd0e]o^0=oWm03WjoH0gn;W09FEU`3oo_`0ookkNP3oool00240
oooo00l0o_kn0?_kn`3gmoL0l_;b0>c/k03Xj>P0iNGU0>GVh03Rhmh0/[:d
08J4S`2ASI`0X9^_0;6/`P2l]ld0:033^m<00`32^]80`k_C0<Ble0020<:j
d@0;0<NoeP3AbMh0fM7V0=cGg@1nN8@0LVZ209B:[@2UV/80Z9k30;2WaP2`
Yl80>02`Y<P0102_Y<H0/:G70;6Vb02`YLL20:nTaP0<0;:Wb@2dZL/0_[K=
0<k7f@3FcN00NFn8071TRP2HR;D0Vh^h0:>D_@2RT[l0Xi?00P2TU<40102S
Tl00XY:o0:>C`02TU<4P0:>C`P0@0::B`@2QTL00XY;30:>C`P2QTKh0YIJo
0;BVbP34]]L0ShbG06QaNP1`Qhl0NibS08>X/02;/[T0S[Zm08Vk^PP0T;Vo
202A^/2H09:k`@0909Nla02B^L00Tkc009[2a02_dM80_MGG0<OEf02=U9X0
n?Sh0080oooo0P3moOd00`3oool0o_kn0?knoP0P0?ooo`0808bAY02UZ[d0
_lCG0<[?hP3Ef^d0fn3c0=WNl@3LhOA00=_Qk`080=kNj03Shnd0jNWa0>k_
m03TiNT0U9FG0?koo`3koOaj0?ooo`00803oool0403no_h0oOgm0?clo03i
nOT0mOGe0?7al@3]kNd0jn_[0>OXh`3^k^`0_[g208R6T@2BSYl0XIb`0;:]
``2o^]0X0<S0e`0@0<Jne@37_mH0b<3G0<NoeP37_m@0c<CI0=G=hP3MeNX0
iN3V081jR01bJX80UH^]0:^QaP2bZ</0]Jc;0;N^bCP0^:g?00@0]jc<0;R]
c@2i[/h0^:g=0P2g[<`02`2i[/h0_;7A0<c4f`3?b=X0eLkP07]aRP1dJ8`0
Vhji0:BE`02/WL@0YIS300<0YYW40`2UV<<00`2VVL@0Y9O20:BG`P0N0:BG
`P0@0:FH``2UV<@0YIS40:JIa@2UVL40ZIg10;N/c036^mT0THnJ06egP01a
SY@0NIjT08N^]@2D^Kl0U;_009Fn`100U[_1V02G_<802@2G^L80V;g309_3
a@2Pa/L0[lk@0;oDe`3;fM`0Ri>F0?Ogm`020?ooo`030?gmo@3no_h0oooo
0080o_kn803oool00`2n`//0Yj^d0:^_^0020;Jj``030;c0b@30a<d0_L7:
0400_L;800P0`<380<;2bP33a<T0`/?70<G6b02f^;L0o_oo0?kooGX0oooo
000P0?ooo`0@0?knoP3moOd0oOgm0?_kn`3inOT0moOg0?Gem@3dm?@0m?Cb
0?Gem@2m_<80QhFB09^GZ02`Zkl0_[W?0<g8gRP0d<WK00<0clOL0=38g@3A
b]`00P3@bM/02`3Ec]h0g=GU0>?Lk03TgnH0Q7j<07mgS`2OU[D0/jW<0<6g
f@33^]D0`[[B03P0a;_F00@0`k[E0<BkeP35_=L0a;_F0P33^]D03@35_=L0
akkI0=?;hP3HdN<0h]_[081hS`1mLY@0YY[20;BXcP2i[]00^JgA0;R/d02g
Zll00P2fZ/h20;FYcB40]:S<0100]JW=0;BXcP2eZLl0]JW?0;BXc02h[Ld0
a;[E0=;8h@2CTil0KG^407FFV`1lZ:/0TKZn0:C7c@2T`lP0ZLS=402XalbH
0:W8c@0<0:[9cP2VaLX0Y/S:0;GDeP32g=d0c^3R0=GPhP2;T9@0moOg0?kn
oP3oool0oOgm0P3oool20?knoR00oooo00P0inWX0;o1`02h^[T0_/2o0;Ni
^02h^[T0^[bk0;Bf]D00^K^j00H0]kRl0;Ri_@2k_;h0_Kk00<C6a@3Ti^<2
0?kooGX0oooo000P0?ooo`D0oOgm00/0o?cl0?_kn`3jn_X0n_[j0?[jo034
`l/0UI>P0:jZ^@30_<d0al?D0=SDi@0Z0=WEi00>0=[Fi@3IeN<0f]KT0=gI
i`3Sh>/0j>G`0>cVl024OX`0RH6F0;:Ya033^]L0d<OR0=?;hP3Cbn0h0=;:
h@040=79gP3Bb]l0d/[O0=;:g`80dLWN00`0dl_P0=C<h@3HdnL0iN7`0>[V
m024OHl0QgjI0;BZc037_=`0c<;K0<RofP36_MP20<Fle`<0a[gH00<0aKcG
0<JmfP36_MX07P36_MX04036_MP0aKcI0<Flf@35_=T0aKcG0<W1f@3Cbn00
gMKX09^MZ@1aPXT0PJBX08jj^`2RbLh0]mCJ0;O>e02ndmRX0;cEf@0<0;kF
fP2leMT0^M?D0<;Jg03;gn00f^SY0=gUi`2>TYD0n?Sh0?knoP3oool0o_kn
0P3oool20?knoR00oooo00D0oook0?Wjm@3jnoH0o?gh0?gnn@030?oond00
ooom00P0o_oo0?gooP3mooh0o?km0?Ggm03nood0o?ki0?[lmgX0oooo000P
0?ooo`H0o_kn0P3moOd0203oool0no_m0<O6c02IUj80]K6o0<k:f03EdMl0
g][X:03Qg^L20>7Nj@80hMkW00`0h]oX0>CQj03XiN`0jnS_0?;_n028QI00
T8bK0<2kc`3>bMd0dlkR0=SDh`3Je^@n0=WEh`0<0=[Fi03KenD0inCe0>cZ
m@3Og>D0QhB?09^FZP32^]80clOL0=?<g03DcMl0dlcN0`3Ab]`00`3Bbmd0
dL[L0=39f`0P0=7:g080d/_M0`3Bb]l02`3DcMd0fmGS0>;Lj02QY:/0MhJ;
08j][`2Ub<X0]=?F0<OLh@3;f]l0cmgP00P0c=_N203=g=nH0<cKgP0<0<WK
g@3>h>80cMcO0=7Qh@3Ki^P0jo?e0>;Vj@2ATY@0nOWi0?knoP3oool0o_kn
0P3oool00`3no_h0oooo0?ooo`0O0?ooo`040?gko03oo_l0ooko0?klo@80
ooko00<0o?[k0?ono`3oo_l0?`3oo_l00`3no_h0ooom0?kno0030?ooo@03
0?kno03oood0oooo07T0oooo000P0?ooo`P0o_kn0P3oool01P3JfMh0Y:>[
0:VV[`2j]l00_[_20;nl`bX0`[o600h0`Kk50<6oa032`<D0`l760<G3aP37
aLP0][>j07ejP`2=RYD0YjB_0:VV/@2]Z[D0/Znf0:j[/SP0[:Vb202/ZK00
402/Z[D0YJBZ096AT`1/Jg00THjI0:RT/`2ZYk80[:Z_0:NT[@2XYJh0ZZN`
0:fZ/`2b[kP0][>l0;Vf_`2k^<4P0;Re`080^;Fn00h0^;G00;Rd`P2h]L00
^[O00;fj`@31_l@0WIbR07^5Q`2>Xj@0X;Rj0:Zi_02c_Kl0]ko10;Jo_ZP0
]Ko000X0]/310;Fo`02e_Kl0^/;40;_1`@2m`L80^KZl09JGV@3kno/0oooo
0P3no_h20?ooo`030?knoP3oool0oooo01l0oooo00P0ooko0?gkoP3no?l0
oO_n0?omo`3oo_l0o?[m0?klod00oogo0P3oood01P3no_`0no_i0?ooo@3f
m_H0oooo0?clo7X0oooo000R0?ooo`H0o_kn00P0moOe0?ooo`3oool0emKK
0<6oa02i]k`0]kFh0;Ne]RX0^[Zl0P2i^K/0302i^KT0^[Zj0;Zj^P2j^[X0
a<;70<?1aP3Acm@0d<kC0<k<d@3?cM00d]3A0<g<bSh0d];D0P3AdM<0403B
dmP0bL_:0;fn^@2k^kT0dM3E0=?@e`3@c]40cLc80=KDe`3CdM@0c/c?0<O5
b031_l80^kVl0;Rf^@2g]KPP0;Zh_@030;Vg^02i]kX0^KNl0080^[Nn00/0
^[Rm0;^i_02k^KX0_;Zm0:b`/@2a^k`0]Kfo0;Zk_`2h^;X0^K^h0;:i/P08
0;Jj^`P0]k^lV02f^[/0302c^KT0/kNh0;Ri^`2k_;h0^;Rj0;Jf]P37alL0
h>3P0?knoP3oool0o_kn0?gmo@80oooo00<0oOgm0?ooo`3oool0803oool0
0`3jn_X0oOgm0?ooo`030?ooo`030?gmo@3no_h0o_kn03h0o_kn0`3oool0
0`3moOd0oooo0?kno`1l0?ooo`00:03oool0103ooo/0n_[h0?ooo`3no_l2
0?ono`030?ooo@3ooo/0oooo02T0oooo0`3no_h20?kno0090?gmn`3knO`0
ooko0?ono`3knOX0ooko0?kmn`3lnoL0oook03P0oooo1`3no_h02@3moOd0
o_oo0?koo@3joO@0oooj0?ooo`3jn_`0oook0?oomP040?knoP040?gmo@3n
o_h0oooo0?ooob00o_kn0P3oood40?ooo`0:0?ooo@3no_`0ooko0?ooo`3n
ool0noWl0?olo`3on_/0oooj0?[om`P0o_knX03oool0103lool0o_oo0?oo
o`3no?d20?ono`060?Wgn03oool0oooo0?ooo`3no_h0oOgm0P3oool00`3m
oOd0oooo0?ooo`0O0?ooo`070?_mn03noo/0o_ok0?cnn@3jo?L0oOoj0?cn
n@110?kon`030?ooo`3kno/0oooo00<0oooo00<0no[o0?ono`3oool0N@3o
ool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0
ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o
0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0
oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo
0?oooh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00
o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<
0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0oooo
o`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool0
0?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0oooo
S03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?oo
ool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo
003o0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo0?oo
oh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<0?ooo`00o`3o
oooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3ooon<0?oo
o`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3o
oon<0?ooo`00\
\>"], "Graphics",
  ImageSize->{650, 448},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(\(Mathematica\)\(\ \)\(users\)\(\ \)\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Along with the increasing use of mathematics and computation in a variety \
of fields, utilization of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has increased steadily.  "
}], "Text"],

Cell[CellGroupData[{

Cell["Professional Users by Field", "Subsection"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000Ei000452000`400?l00000o`00003ooooooooo
ooooooooooooooooooooooooogkooooo003o0?ooool0ooooo`3ooooo0?ooool0ooooOP3oool00?l0
ooooo`3ooooo0?ooool0ooooo`3ooomn0?ooo`00o`3ooooo0?ooool0ooooo`3ooooo0?ooogh0oooo
003o0?ooool0ooooo`3ooooo0?ooool0ooooOP3oool00?l0ooooo`3ooooo0?ooool0ooooo`3ooomn
0?ooo`00o`3ooooo0?ooool0ooooo`3ooooo0?ooogh0oooo003o0?ooool0ooooo`3ooooo0?ooool0
ooooOP3oool00?l0ooooo`3ooooo0?ooool0ooooo`3ooomn0?ooo`001`3oool0103kno/0kno_0>OW
i`3Zj^[o0>g]kOl0kNg]o`3]kNgo0>g]kOl0kNg]I@3]kNd00`3jn_X0oooo0?ooo`0;0?ooo`001`3o
ool00`3YjNT0dM7A0=7Ad@3o0=7AdOl0dM7Ao`3AdM7o0=7AdOl0dM7AIP3AdM400`3Ogml0oooo0?oo
o`0;0?ooo`001`3oool00`3YjNT0dM7A0=7Ad@3o0=7AdOl0dM7Ao`3AdM7o0=7AdOl0dM7AIP3AdM40
0`3Lg=`0oooo0?ooo`0;0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3Jf][o0>?Shol0hn?So`3Shn?o
0>?Shol0hn?SHP3Shn<0103Kfm/0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo
0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo
0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo
0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo
0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo
0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo9P3oool01P1UADP000000000001UADP0
bH^@0?oio_l0ooooo`3ooooo0?ooocH0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooobH0oooo00<0IDE80000000000000P0000000`2IPXL0oooo
0?ooo`3o0?ooool0ooooo`3ooold0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0ooooo`3ooolV0?ooo`0307iGFP00000000000080000000<09QXK0?ooo`3o
ool0o`3ooooo0?ooool0oooo=03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOo0?ooool0oooo9P3oool0103TaLP0d[Rk0<^d]P1UATP20000000309MXK03oool0
oooo0?l0ooooo`3ooooo0?oooc<0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooobX0oooo00@0<R<T000000000000on7Zo`3ooooo0?ooool0oooo
=03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0
oooo:P3oool0102`NGh0000000000039Ri3o0?ooool0ooooo`3ooold0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooolZ0?ooo`040?b]]0000000
000007iGF_l0ooooo`3ooooo0?oooc@0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooob/0oooo00@06Q8B000000000000o]3Ho`3ooooo0?ooool0
oooo<`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0oooo:`3oool0101H?Cl000000000002GJ6`80?ooo`040?oXk039Ri00IDE8038S9080000000<0
<R<T07iGFP3ac]404`3oool0203T[[@0IDE8038S90000000<b<T07iGFP39Ri00on7Z103oool00`3T
[[@0IDE8038S900200000003038S901nEeX0hYbR0?l0ooooo`3ooooj0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0000000<0bH^@
0?ooo`3oool02`3oool01@20P8000000000000000000omoS00H0oooo00@0oko60000000000000000
2@3oool0100I4Q8000000000000b8b@70?ooo`030?oQjP0I4Q80000000H0000000<06A8B0?o@f03o
ool0103oool0103o_lH000000000000000070?ooo`030?o@f01UADP0000000L0000000@0onS/0?oo
o`3ohNX0<R<T200000000`2INWh0oooo0?ooo`3o0?ooool0oooom`3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo0P3oool3000000030<V;T03o
ool0oooo00/0oooo00D0P82000000000000000000?oOh`060?ooo`040?noaP0000000000000000P0
oooo00<0om3H0000000000000P0000000`3oj>`0oooo0?ooo`040?ooo`030?noaP000000000000L0
000000<06A4B0?o@f03oool00`3oool0103o_lH000000000000000060?ooo`030>:LXP0000000000
00P000000P3oool00`3o_lH00000000000070000000300d92@3od=P0oooo0?l0ooooo`3oooog0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool2
0?ooo`<0000000<0bH^@0?ooo`3oool02`3oool01@20P8000000000000000000omoS00H0oooo00@0
oko60000000000000000203oool00`1nEeX0000000000002000000030<^d]P3oool0oooo00@0oooo
00@0onS/02`O8020LGD0YIZK0P3TaLP00`3H_;l0VI6B075>D@020000000301TB4P3ac]40oooo0080
oooo00@0oko600000000000000001@3oool0302hVil00000000000000000<b<T08b2Q`2oZjd0i<G8
0<^d]P2<R8T0OUMJ03<S9080oooo00@0onS/0000001/EeX0YIZK0P3TaLP00`3N`L@0VI6B075>D@02
0000000301TB4P3ac]40oooo0?l0ooooo`3oooof0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0000000<0bH^@0?ooo`3oool02`3o
ool01@20P8000000000000000000omoS00H0oooo00@0oko600000000000000001`3oool0103ohNX0
00000000001;=3H200000003081jOP3oool0oooo00@0oooo00<0oo?l0?o`m@3oool01P3oool0101U
ATP000000000001nEeX30?ooo`040?noaP0000000000000000D0oooo00D0<b<T0000000000000000
0?7>d@090?ooo`030?oco03ohNX0oooo00H0oooo00@0bH^@000000000000OUMJo`3ooooo0?ooooL0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
o`80oooo0`0000000`39Ri00oooo0?ooo`0;0?ooo`050820P000000000000000003ogn<01P3oool0
103o_lH000000000000000070?ooo`040<V;T000000000000?b]]080000000<0LDiA0?ooo`3oool0
3@3oool01020NWh000000000000b8b@30?ooo`040?noaP0000000000000000@0oooo00D0oko60000
00000000000009MXK00C0?ooo`040?oco00000000000038S9?l0ooooo`3oooog0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<00000
00<0bH^@0?ooo`3oool02`3oool01@20P8000000000000000000omoS00H0oooo00@0oko600000000
000000001`3oool01`1UADP0000000d92@3oool0<R<T0000001<=3H03`3oool01020P80000000000
000000030?ooo`040?noaP0000000000000000@0oooo00D0UfQ/00000000000000000?oco00D0?oo
o`<00000o`3ooooo0?ooooL0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooo`80oooo0`0000000`39Ri00oooo0?ooo`0;0?ooo`050820P0000000
00000000003ogn<01P3oool0103o_lH000000000000000060?ooo`090?78c`000000000005m1A03o
ool0_H:7000000071@D0onS/00h0oooo00@0FDI80000000000009QXK0`3oool0103o_lH000000000
000000030?ooo`050?o`m@0I4Q8000000000002`NWh0503oool0102bRi0000000000000V6Q_50?oo
o`050=;5b020J6`0IDI803l/;@0P5QL00P0000001@0I4Q80C3Df081aM@3;];H0ooWn00P0oooo00X0
k=kO081aM@1UATP0<b<T00L51@0000003@T903<S901cG5l0f;bo2P3oool02P3IaLP0P6Q/06E6B00c
8b@03@T90000000c8b@0?b`]07=LG`3oj>`20?ooo`050?o_l@20P800P8200820P030`<001@3oool0
0`3;];H0P61S03<S90020000000601TB4P1H?Cl0YIZK0?oXk03oool0YYZK0P20P8000`3oj>`0oooo
0?ooo`020?ooo`040<2`/P20P800P8200820P0d0oooo00`0oo3e0:FJV`20J6`0DSTk03<S900=2@T0
000000d92@0c8b@0IDI8081aM@3UemX90?ooo`0:0?oXk02IQHP0IDI803<S900I4Q80000003<S900o
;2d0IDI80<2]/@<0oooo00D0onoa0820P020P800P8200<30`0070?ooo`030:bGVP1UATP0<b<T0080
000000D03@T903<S901H?Cl0OfU/0>C5b0050?ooo`<0P82000<0omoS0?ooo`3oool0103oool0103o
gn<0P8200820P020P8070?ooo`050?odmP2bXZ@0P6Q/06E6B00V6a/00P000000100c8b@0DSTk081a
M@3oj>`50?ooo`030:bGVP1UATP0<b<T0080000000D03@T903<S901H?Cl0OfU/0>C5b0040?ooo`05
0?o`m@2ITI80LeMJ03<S900I4Q800P000000100I4Q80?b`]075>D@3<_Koo0?oooeD0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooo`80oooo0`00
00000`39Ri00oooo0?ooo`0;0?ooo`050820P000000000000000003ogn<01P3oool0103o_lH00000
0000000000060?ooo`0607iGFP0000000000081aM@3oool0on7Z0P0000000`39Ri00oooo0?ooo`0:
0?ooo`030?oQjP1UADP000000080000000D0/7Un0?ooo`3oool0oooo0?noaP03000000<0oooo00D0
oko600000000000000000?o@f00B0?ooo`030?oQjP1UADP000000080000000<0/7Un0?ooo`3oool0
``3oool00`20H6<000000000000800000003038S903oj>`0oooo00D0oooo00<0oo?l02HJ6`000000
200000000`1;=3H0oo?l0?ooo`060?ooo`030>:LXP000000000000L000000`3oool01@3ogn<00000
000000000000P82000@0oooo00<0UfQ/0000000000001P0000000`0I4A80om3H03<S9002000000D0
oooo00@0P61S00000000000000003@3oool00`3o_lH00000000000080000000301TB4P3od=P0oooo
00H0oooo00<0hYbR0000000000001`0000001@20P800oooo0?ooo`3oool0omoS00<0000000<0P820
0?ooo`3oool00`3oool00`3olo`0Bc@f000000080000000306E5B03oool0oooo00<0oooo0`000000
0`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000L0oooo00<0LDiA0000000000001`00
00040?ooo`030?oco01;=3H0000000P0000000<0IDE80?ooo`3oool00P3oool00`3o_lH000000000
00070000000300d92@3od=P0oooo0?l0ooooD`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo0P3oool3000000030<V;T03oool0oooo00/0oooo
00D0P82000000000000000000?oOh`060?ooo`040?noaP0000000000000000H0oooo0`0000001P2U
VY/0oooo0?ooo`0b8b@0000004/d=PX0oooo00<0oo3e09MXK00000000`0000000`0I4A80on7Z0?oo
o`020?ooo`040?noaP0000000000000000<0oooo00@0hYbR00000000000000004P3oool00`3;YJ/0
0000000000020000000301TA4P3ohNX0oooo0<@0oooo00L0P61S000000000000000003<S901UADP0
Bc@f00D0000000<0VH^@0?ooo`3oool0103oool02@1UADP000000000000000006A4B0;f2Q`39Ri00
/7Un01TA4P030000000306E5B03oool0oooo00@0oooo00<0hYbR0000000000000P0000001P0I4A80
Y75e0<V;T01UADP06A4B000000<0oooo00D0omoS00000000000000000820P0030?ooo`060?oOh`00
000000000000000=2@T0bH^@0P3o_lH01@2TLGD000000000001;=3H09QXK008000001@3oool01020
H6<0000000000000000=0?ooo`030?noaP0000000000008000000P1UADP00`0V6Q/0000000000002
00000003038S903olo`0oooo00@0oooo00<0hYbR0000000000000P0000001`0I4A80OUMJ0<V;T01U
ADP06A4B00000020P8000`3oool01@3ogn<00000000000000000P82000D0oooo00H0OUMJ00000000
00000000038S902`NGh20?noaP040<V;T01;=3H0000006E5B0D0oooo0`0000000`3o_lH0oooo0?oo
o`040?ooo`040?noaP0000000000000000H0oooo00<0hYbR0000000000000P0000001P1<=3H0bH^@
0<V;T01UADP03@T9000000@0oooo00H0OUMJ0000000000000000038S902`NGh20?noaP040<V;T01;
=3H0000006E5B0@0oooo00@0om3H000000000000Bc@f0P39Ri000`2mPXL0<R<T0000000200000003
038S903oool0oooo0?l0ooooDP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOo0?ooool0oooo0P3oool3000000030<V;T03oool0oooo00/0oooo00D0P8200000
0000000000000?oOh`060?ooo`040?noaP0000000000000000D0oooo00D0o]KJ0000000000000000
0=Rl_`020?ooo`0409MXK000000000000?oco0P0oooo00<0oko603l/;@000000100000000`3RW:80
oooo0?ooo`020?ooo`040?noaP0000000000000000<0oooo00@0bH^@0000000000000000403oool0
0`3o_lH0OUMJ00000004000000030>:LXP3oool0oooo0<@0oooo00@0P61S0000002GJ6`0o:fd0`3o
ool00`3ohNX0IDI8000000020000000304`d=P3oool0oooo00<0oooo00H0hYbR0000000000000000
09MXK03olo`30?ooo`030?oco01<=3H000000080000000<0lLkA0?ooo`3oool00P3oool00`3od=P0
000000000002000000030<V;T03olo`0oooo00<0oooo00D0/GUn0?ooo`3oool0oooo0?oOh`030000
00050820P03oool0oooo0?ooo`2oZjd00`0000000`2<LGD0oooo0?ooo`020?ooo`030>:LXP000000
000000<000001@3oool01020H6<0000000000000000=0?ooo`040?noaP00000000000<Z;T0<0oooo
00<0oo3e0<V;T00000000`0000000`2GJ6`0oooo0?ooo`020?ooo`030?oXk0000000000000800000
00<0bH^@0?oco03oool00`3oool00`3l[K@0/Z:T0?ooo`020?ooo`050?oOh`000000000000000020
P800103oool01P3l[K@00000000000000000UfQ/0?oco0D0oooo00<0/X:706E5B03oool0103oool3
000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000001@3oool00`3od=P000000000
0002000000030<V;T03onOh0oooo0080oooo00<0o]KJ06E5B03oool00P3oool01P3l[K@000000000
00000000UfQ/0?oco0D0oooo00<0/X:706E5B03oool0103oool00`000000f:fd0?ooo`040?ooo`05
0>:LXP00000000000000003RW:80o`3ooomC0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0000000<0bH^@0?ooo`3oool02`3oool0
1@20P8000000000000000000omoS00H0oooo00@0oko600000000000000001@3oool01@2/WYl00000
000000000000on_]0080oooo00@0o]3H000000000000_H:71@3oool00`3oko40S7Un03<S90050000
000306aKG`3ac]40oooo00@0oooo00@0oko600000000000000000`3oool01039Ri00000000000000
000>0?ooo`030<J//@0c8b@0000000@0000000<0C3@f0;nX[03oool0aP3oool00`3OaLP0oo3e0?oo
o`050?ooo`030?odmP1nEeX000000080000000H0i;Jm0?ooo`3oool0oooo0?7>d@0=2@T200000003
0;:CV@3oool0oooo00@0oooo00D0fLW<000000000000000007m/K@030?ooo`060?o_l@0c8b@00000
0000000V6Q/0lLkA2P3oool01@3ogn<00000000000000000P82000<0oooo00D0QWeo000000000000
00000?;KgP050?ooo`030>C5b00I4Q800000008000001@3oool01020H6<0000000000000000=0?oo
o`030?oOh`2oZjd0oo3e00H0oooo00<0onS/07iGFP0000000P0000001@3bfmh0oooo0?ooo`3oool0
VH6400<0000000<0Wh640?ooo`3oool02@3oool01@3ogn<00000000000000000P82000<0oooo00D0
on_]01TB4P0000000000061>D@080?ooo`030?oOh`3oool0oooo00<0oooo0`0000000`3o_lH0oooo
0?ooo`040?ooo`040?noaP0000000000000000@0oooo00H0omoS03<S90000000000004`d=P3ac]49
0?ooo`050?o[k@0I4Q8000000000001PCU40203oool00`3ogn<0oooo0?ooo`020?ooo`030?oioP3o
l?D0oooo00H0oooo00@0i;o6000000000000F3doo`3ooomC0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0000000H0IDE80<V;T039
Ri00bH^@0>:LXP3o_lH80?ooo`050820P000000000000000003ogn<01P3oool0103o_lH000000000
000000050?ooo`04081XK0000000000006E5B0@0oooo00<09QXK0000000I4A801@3oool00`2<LGD0
00000000000200000003038S9039Ri00oo?l00L0oooo00@0oko600000000000000000`3oool0103l
[K@0000000000000000=0?ooo`030?o@f00=2@T000000080000000<06A8B0<V;T03olo`0d`3oool0
100b8b@000000000001UADP30?ooo`0407iGFP000000000002HJ6`P0oooo00@0Bc@f000000000000
?b`]0`3oool01@3;];H00000000000000000P7Yn00/0oooo00D0omoS00000000000000000820P003
0?ooo`04081PH`0000000000000000L0oooo00@0bH^@00000000000000001@3oool01020H6<00000
00000000000H0?ooo`0401TB4P00000000000;:RY0<0oooo00D0C3@f00000000000000000?oioP0;
0?ooo`050?oOh`000000000000000020P8000`3oool01@3;];H00000000000000000_j^]00h0oooo
0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00D0UfQ/00000000
000000000?oco00:0?ooo`050<^d]P00000000000000002oZjd05`3oool300000?l0ooooD`3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo0P3o
ool90000000303l/;@3o_lH0oooo00D0oooo00D0P82000000000000000000?oOh`060?ooo`040?no
aP0000000000000000D0oooo00@0F3do000000000000bH^@103oool0101H?Cl000000000003o_lH4
0?ooo`0503l/;@00000000000000001nEeX02P3oool0103o_lH000000000000000030?ooo`050?no
aP00000000000000003o_lH0303oool01P1nEeX000000000000000006A4B0?7>dMD0oooo00@0/7Un
000000000000<R<T0`3oool0100I4A8000000000001UATP80?ooo`040<V;T0000000000000d92@<0
oooo00D0VI6B00000000000000000;n[[@0;0?ooo`050?oOh`000000000000000020P8000`3oool0
1020H6<000000000000000070?ooo`040?noaP0000000000000000D0oooo00@0P61S000000000000
0000603oool0101H?Cl000000000002ITI830?ooo`0401TB4P000000000007iGFP`0oooo00D0omoS
00000000000000000820P0030?ooo`0509VATP00000000000000003ac]403P3oool3000000030?no
aP3oool0oooo00@0oooo00@0oko60000000000000000103oool0100b8b@000000000000o;2d;0?oo
o`0509VATP00000000000000003ac]405P3oool0103od=P0000000000000003o0?oooe<0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooo`80oooo
2`0000000`1UADP0oo?l0?ooo`030?ooo`050820P000000000000000003ogn<01P3oool0103o_lH0
00000000000000050?ooo`0401TB4P00000000000?o@f0@0oooo00@0OUMJ000000000000/7Un103o
ool300000003038S903onOh0oooo00T0oooo00@0oko60000000000000000103oool3000000030>:L
XP3oool0oooo00X0oooo0`0000000`0b8b@0oo?l0?ooo`3E0?ooo`040<V;T0000000000000000080
oooo00D0oo3e0000000000000000081PH`080?ooo`050?noaP00000000000000003ohNX00P3oool0
1@20LGD00000000000000000lLkA00/0oooo00D0omoS00000000000000000820P0030?ooo`05081j
OP00000000000000003ol?D01`3oool3000000D0oooo00@0P61S0000000000000000603oool0101U
ATP0000000000020P8020?ooo`050?oQjP00000000000000003RW:80303oool01@3ogn<000000000
00000000P82000<0oooo00D0P7Yn00000000000000000?oOh`0>0?ooo`<0000000<0oko60?ooo`3o
ool0103oool0103o_lH000000000000000030?ooo`050?o`m@00000000000000001aCU402`3oool0
1@20NWh00000000000000000omoS01H0oooo00@0IDE8000000000000Bc@fo`3ooomC0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0
000000H0IDI80820P020P800P7Yn07iGFP1<=3H30000000300d92@3BaLP0oooo0080oooo00D0P820
00000000000000000>C5b0060?ooo`040?6^]00000000000000000@0oooo00@0i:jd000000000000
F3do1@3oool01@2CRXd000000000000V6Q/0ooSj0080oooo00D0oko600000000000000000?kFfP0;
0?ooo`040?noaP0000000000000000@0oooo00D0OUMJ000000000000F3do0?oioP0:0?ooo`050?no
aP00000000000000003ne]X0e`3oool0102TLGD000000000000=2@T20?ooo`050?SGfP0000000000
00000020N7/0203oool01@3ol?D00000000000000000lJjd0080oooo00D0NEMJ0000000000000000
0?odmP0;0?ooo`050?oOh`000000000000000020P8000`3oool01@2bXj@00000000000000000^:BX
00L0oooo0`0000050?ooo`04081PH`0000000000000001P0oooo00@0DSTk000000000000QXB40P3o
ool01@3a[[@00000000000000000onS/00`0oooo00D0omoS00000000000000000820P0030?ooo`04
07mKG`0000000000000000l0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000
000000<0oooo00D0n=OJ0000000000000000081dMP0;0?ooo`0407mKG`0000000000000001@0oooo
00<0iM;F081aM@0c8b@00P0000000`0=2@T0f:fd0?ooo`3o0?oooe80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooo`80oooo0`0000000`39Ri00
oooo0?ooo`030?ooo`050:F;T000000000000000001aCU400`3oool01@20P8000000000000000000
S8:700H0oooo00@0/7Un000000000000Bc@f103oool0101;=3H000000000003RW:850?ooo`050=Rl
_`00000000000000003ac]400P3oool0103ohNX0000000000000000<0?ooo`040?noaP0000000000
000000@0oooo00D0on7Z00000000000000000<V;T00:0?ooo`040?oQjP000000000000000=L0oooo
00D0oo?l000000000000000006E5B0020?ooo`050>C5b0000000000000000020P8002@3oool30000
00040<V;T03oool0oooo06E6B0<00000303oool01@3ogn<00000000000000000P82000<0oooo00H0
oo3e000000000000000002HJ6`3od=P60?ooo`<000001@3oool01020H6<0000000000000000G0?oo
o`050?oco000000000000000002bXZ@00P3oool01039Ri00000000000000000=0?ooo`050?oOh`00
0000000000000020P8000`3oool0101UATP0000000000000000;0?noaP040?oco03oool0oooo0?oo
o`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000030?ooo`050>C5b0000000
000000000020P8002`3oool0101UATP0000000000000000;0?noaP030?oco03oool0oooo00@0oooo
00<0oko607iGFP000000100000000`3RW:80oooo0?ooo`3o0?oooe80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooo`80oooo0`0000000`39Ri00
oooo0?ooo`030?ooo`050?o`m@0I4A8000000000000V6Q/00`3oool01@20P8000000000000000000
IDI800D0oooo00D0oo?l01TA4P000000000007iGFP030?ooo`050?oQjP00000000000000003olo`0
1@3oool01@3ne]X00000000000000000_j^]00<0oooo00@03@T9000000000000o:fd2`3oool0103o
_lH000000000000000050?ooo`0504`d=P00000000000000003ac]402P3oool0100I4A8000000000
003l[KCF0?ooo`0509MXK000000000000000002`NGh00P3oool01@3TaLP00000000000000000P820
00T0oooo0`0000001039Ri00oooo0?ooo`1UATP3000000`0oooo00D0omoS00000000000000000820
P0040?ooo`030>:LXP00000000000080000000<0UfQ/0?b]]03onOh00`3oool3000000D0oooo00@0
P61S00000000000000005`3oool01@2GJ6`00000000000000000f;bo0080oooo00@0bH^@00000000
000000003@3oool01@3ogn<00000000000000000P82000<0oooo00<0IDI800000000000030000000
103o_lH0oooo0?ooo`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000000000000000
0`3oool01@3TaLP00000000000000000P82000/0oooo00<0IDI8000000000000300000000`3o_lH0
oooo0?ooo`020?ooo`030?o`m@1UADP0000000D0000000<0OUMJ0?ooo`3oool0o`3ooomC0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?oo
o`<0000000<0bH^@0?ooo`3oool0103oool01@39Ri000000000000000000oo?l0080oooo00<0P820
0000000000000P0000001P39Ri00oooo0?ooo`3oool0oo?l09MXK0<0000000D0hYbR0?ooo`3oool0
oooo0>:LXP020000000304/d=P3oool0oooo00@0oooo00D0ooWn000000000000000008b8R@030?oo
o`0504`d=P000000000001TA4P3oj>`0103oool00`3od=P0on7Z0?ooo`030?ooo`040?noaP000000
0000000000D0oooo00D0S7Un000000000000000006E6B0050?ooo`030?o@f039Ri00oooo0080oooo
00D0UfQ/0000000000006A4B0?o@f0040?ooo`030?oXk03ohNX0oooo0<d0oooo00<0bkBf00000000
00000P000000103ohNX0oooo0?ooo`3TaLP3000000030820P03oool0oooo00L0oooo0`0000001039
Ri00oooo0?ooo`1UATP3000000`0oooo00D0omoS00000000000000000820P0050?ooo`030>:LXP00
0000000000X000001@3oool01020H6<0000000000000000F0?ooo`0309MXK0000000000000800000
00@0oo3e0?ooo`3oool0bH^@0`00000=0?ooo`050?oOh`000000000000000020P8000`3oool00`1U
ATP000000000000<000000040?noaP3oool0oooo0?ooo`<0000000<0oko60?ooo`3oool0103oool0
103o_lH000000000000000030?ooo`050>C5b0000000000000000020P8002`3oool00`1UATP00000
0000000<000000030?noaP3oool0oooo0080oooo00<0S6Q/000000000000100000000`2GJ6`0ooWn
0?ooo`3o0?oooe@0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooo`80oooo0`0000000`39Ri00oooo0?ooo`040?ooo`050?oOh`00000000000000
003TYJ/00P3oool02P20P8000000000000000000K4iA0000000=2@T0C3@f05Tm?`0I4Q8300000006
08]OH`3onOh0oooo0?ooo`3onOh0?b`]0P0000000`3HW:80oooo0?ooo`050?ooo`0407iGFP000000
000006a>D@<0oooo00D0aJR/0000000000000000020F5`0306E6B00303<S90000000bH^@00@0oooo
00@0oko600000000000000001@3oool00`3ojnd0OUMJ00d92@020000000700d92@0c8b@0IDI805Tm
?`0V6Q/0000003l[;@030?ooo`030?o`m@16<38000000080000000H0DSTk06E6B01UATP0C3@f00d9
2@39Ri3<0?ooo`030?oOh`2IRi009QXK00<0000000D0K5aO0?ooo`3oool0oooo0?SGfP0300000003
081hN`3oool0oooo00H0oooo00D0oo3e00000000000000000?6^]0020?ooo`0507mKG`0000000000
0000003oko402`3oool01@3ogn<00000000000000000P82000H0oooo00H0onS/0:2>T@1UATP0C3@f
03<S90071@D6000000D0oooo00@0P61S0000000000000000503oool00`3<]KX0C3@f000000020000
000300d92@3;[[@0oooo0080oooo00D0o[Jm00000000000000000?oOh`0<0?ooo`050?oOh`000000
000000000020P8000`3oool0101bDeH000000000000000080820P0<0000000@0oko60?ooo`3oool0
oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000<0oooo00D0om_N0000
000000000000081`LP0;0?ooo`04079CEP0000000000000000P0P8200`0000001P3o_lH0oooo0?oo
o`3oool0_iBI00L51@80000000@03@T908E`LP3TaLP0ooWno`3ooomG0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0000000<0bH^@
0?ooo`3oool01@3oool3000000040<V;T03oool0oooo0820P0<0000000<0omWQ07iGFP0000001@00
00000`1nEeX0oooo0?ooo`020?ooo`040?b]]00000000000000000P0oooo00@0o:fd000000000000
6A8B103oool00`3od=P0<R<T00000006000000030<V;T03oool0oooo0080oooo00@0oko600000000
000000001`3oool00`3ohNX0UfQ/00000007000000@0oooo00<0onS/038S900000001P0000000`39
Ri00oooo0?ooo`380?ooo`030?oioP2`NGh0000000@0000000<06A4B0?oXk03oool00P3oool01@3o
l?D00000000000000000P61S00P0oooo00D0oko600000000000000000?oQjP020?ooo`050820P000
000000000000003ac]402`3oool01@3ogn<00000000000000000P82000l0oooo0`0000050?ooo`04
081PH`000000000000000180oooo00<0oo?l0;1iOP0000000`0000000`0=2@T0om3H0?ooo`040?oo
o`<0000000<0hYbR0?ooo`3oool02P3oool01@3ogn<00000000000000000P82000<0oooo00@0P61S
0000000000000000203oool3000000@0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP00
00000000000000@0oooo0`0000000`1aCU40oooo0?ooo`090?ooo`04081PH`0000000000000000P0
oooo0`0000040?ooo`<0000000<0<R<T0?oco03oool0o`3ooomI0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0000000<0bH^@0?oo
o`3oool01@3oool3000000040<V;T03oool0oooo0820P0<0000000T0omoS0?ooo`3o_lH0UfQ/01TB
4P0b8b@0IDE80<V;T03onOh06P3oool00`3RW:80C3@f000000020000000306E6B039Ri00oo?l0140
oooo00P0i;Jm06E5B00b8b@0000002HJ6`1UADP0bH^@0?o@f0H0oooo00<0hYbR07iGFP0=2@T00P00
00000`1;=3H0Y75e0?oco03:0?ooo`0309UjOP000000000000<0000000<06A4B0?o@f03oool0103o
ool0100I4A8000000000001UATP80?ooo`040<V;T0000000000000d92@<0oooo00D0YIZK00000000
000000000<^d]P0;0?ooo`050?oOh`000000000000000020P8003`3oool3000000D0oooo00@0P61S
00000000000000004@3oool00`3od=P0<R<T000000040000000308aaM@3oool0oooo00@0oooo00@0
9QXK000000000000UfQ/303oool01@3ogn<00000000000000000P82000<0oooo00D0P82000000000
000000000?oXk0060?ooo`040?o@f00000000000000000@0oooo0`0000000`3RW:80oooo0?ooo`04
0?ooo`040?noaP0000000000000000@0oooo00@0Bc@f000000000000C3@f2`3oool01@20P8000000
000000000000onS/00H0oooo00@0om3H00000000000000000`3oool01@3o_lH00000000000000000
o:fd0?l0ooooF`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0oooo0P3oool3000000030<V;T03oool0oooo00@0oooo00D0om3H0000000000000000
0<V;T0020?ooo`050820P000000000000000003ogn<0o`3ooolK0?ooo`030>:LXP000000000000<0
000000<0Bc@f0?oQjP3oool01@3oool0101nEeX000000000000V6Q/80?ooo`0404/d=P0000000000
03l/;@<0oooo00D0f;bo000000000000000008b2Q`0;0?ooo`050?oOh`000000000000000020P800
3`3oool3000000D0oooo00@0P61S0000000000000000403oool00`3ac]4000000000000400000003
04/d=P3ol?D0oooo00D0oooo00D0F3do0000000000006A4B0?oioP0;0?ooo`050?oOh`0000000000
00000020P8000`3oool01@2bXZ@00000000000000000lLkA00H0oooo00@0o:fd000000000000IDE8
103oool3000000030;1iOP3oool0oooo00@0oooo00@0hYbR0000000000000000103oool01@2`NGh0
00000000000=2@T0oo?l00X0oooo00D0/Z:T00000000000000000?7>d@060?ooo`040?b]]0000000
000006E5B0<0oooo00@0oko60000000000000000o`3ooomL0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool20?ooo`<0000000<0bH^@0?ooo`3o
ool0103oool01@1nEeX00000000000000000omoS0080oooo00D0P82000000000000000000?oOh`3o
0?oooaT0oooo00<0i<G805Pm?`0000000`0000000`0c8b@0/Y^O0?ooo`070?ooo`050?7>d@0=2@T0
00000000002bTiT01P3oool01@3IbL`00000000000000000Ofa]00<0oooo00H0ooSj04`d=P000000
000003<S903ac]4:0?ooo`050?oOh`000000000000000020P8001@3oool00`3TaLP0onS/0?ooo`06
0?ooo`040<^DV@0000000000075>D@D0oooo00@0P61S00000000000000003`3oool00`3TaLP0;1lP
000000020000000301XB4P20LGD0i<G800P0oooo00D0YY:F00000000000000000:^:S@0;0?ooo`05
0?oOh`000000000000000020P8000`3oool01@3bgn<00000000000000000WhJ800D0oooo00D0ooWn
06E5B000000000000>Bf_@040?ooo`<0000000<03@T90>BoaP3oool00`3oool01@3oo?l0IDE80000
00000000<b<T00@0oooo00H0oo3e04`d=P000000000006E6B03ac]490?ooo`050?;Oh`0000000000
0000002OQXP01@3oool01@3onOh0IDE8000000000000i;Jm00<0oooo00D0oo3e00d92@0000000000
0?kFfP3o0?oooe/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooo`80oooo0`0000000`39Ri00oooo0?ooo`030?ooo`050=Rl_`00000000000000
001<=3H00`3oool01@20P8000000000000000000omoS0?l0oooo603oool00`3ol?D0000000000003
000000030<V;T03oool0oooo00T0oooo00H0hYbR000000000000000009MXK03olo`30?ooo`030?oc
o01<=3H000000080000000<0lLkA0?ooo`3oool00P3oool00`3ohNX06A4B00000002000000030<V;
T03oool0oooo00<0oooo00D0i:jd0?ooo`3oool0oooo0?oOh`03000000030820P03oool0oooo00<0
oooo00<0IDE801TA4P3T_lH01@3oool01@39Ri000000000000000000oko600D0oooo00@0P61S0000
0000000000003P3oool00`3ohNX0000000000003000000030>C5b03oool0oooo00P0oooo00<0oo3e
01TA4P0000000P0000000`39Ri00oooo0?ooo`030?ooo`030?o@f03TaLP0oooo0080oooo00D0omoS
00000000000000000820P0040?ooo`050<V;T0000000000002HJ6`3olo`0103oool0101nEeX00000
0000001nEeX50?ooo`D0000000D0i<G80?ooo`3oool0oooo0<^^]00300000003075>D@3oool0oooo
00<0oooo00<0on7Z01TA4P0000000P0000000`39Ri00oooo0?ooo`020?ooo`030?oXk039Ri00oooo
0080oooo00D0bH^@0000000000009QXK0?oco0040?ooo`0407iGFP000000000007iGFPD0oooo00D0
UfQ/0000000000006A4B0?o@f0040?ooo`030?oXk03ohNX0oooo0?l0ooooD`3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo0P3oool300000003
0<V;T03oool0oooo0080oooo00<0on7Z03l/;@0000000P0000001@20J6`0oooo0?ooo`3oool0P820
00<0000000<0omoS0?ooo`3oool0o`3ooolF0?ooo`060;n[[@00000000000000000=2@T0om3H3@3o
ool02@1UADP000000000000000006A4B0;f2Q`39Ri00/7Un01TA4P030000000306E5B03oool0oooo
00@0oooo00<0o:fd0000000000000P0000001P0I4A80UfQ/0<V;T02GJ6`0Bc@f03<S90<0oooo00D0
omoS00000000000000000820P0050?ooo`0406E5B0000000000006E5B080bH^@00<0_H:7038S9000
00000P0000000`1UADP0oooo0?ooo`040?ooo`04081PH`0000000000000000h0oooo00H0OUMJ0000
00000000000001TA4P3od=P<0?ooo`030?b]]000000000000080000000L06A4B06E5B039Ri00UfQ/
04/d=P000000/Z:T00<0oooo00D0omoS00000000000000000820P0040?ooo`090?oco01;=3H00000
0000000I4A80bH^@0?noaP3a[[@0<R<T0080000000<03@T90?oQjP3oool0103oool3000000070;1i
OP0000003@T909MXK039Ri00UfQ/01TB4P030000000308b2Q`3oool0oooo00@0oooo00<0o:fd0000
000000000P0000001P0o:bd0bH^@0<V;T02GJ6`09QXK06E5B0<0oooo00T0oo?l04/d=P0000000000
01TA4P39Ri00oko60?6^]00b8b@00P0000000`0=2@T0on7Z0?ooo`040?ooo`030?oQjP0=2@T00000
0080000000H0Y75e0<V;T039Ri00UfQ/01TB4P39Ri3o0?oooe@0oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooo`80oooo0`0000001@1UADP0bH^@
0<V;T02GJ6`0Bc@f00D0000000D0i<G80?ooo`3oool0oooo0820P003000000030?oOh`3oool0oooo
02`0oooo00@0bH^@0000000000000000i@3oool01@20NWh00000000000000000S75e00h0oooo00<0
oo?l02HJ6`000000200000000`1;=3H0oo?l0?ooo`060?ooo`030?b]]00=2@T0000000H0000000D0
3@T90?ooo`3oool0oooo0?oOh`03000000030820P03oool0oooo00<0oooo2P0000000`0V6Q/0oo?l
0?ooo`050?ooo`04081PH`0000000000000000d0oooo00H0oo?l000000000000000001TA4P3od=P>
0?ooo`030?b]]00I4A80000000L0000000D0S8R90?ooo`3oool0oooo0?oOh`03000000030820P03o
ool0oooo00<0oooo00<0om3H01TA4P0000001`0000000`1aCU40oooo0?ooo`040?ooo`<0000000<0
oo?l04/d=P0000001`0000000`3ne]X0oooo0?ooo`050?ooo`0308]OH`000000000000H0000000<0
6A4B0?ooo`3oool00P3oool00`3od=P06A4B0000000700000003075>D@3oool0oooo00D0oooo00<0
OUMJ0000000000001P0000000`39Ri00oooo0?ooo`3o0?oooe80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooo`80oooo2P0000000`0=2@T0OUMJ
0<^d]P040?ooo`050820P000000000000000003ogn<0;P3oool01039Ri00000000000000003U0?oo
o`05079CEP00000000000000003bfmh03`3oool02P3/g]l0P75e06E6B00c8b@01`D50000000=2@T0
<b<T07=LG`3H_;l:0?ooo`090>GBeP20LGD0IDI803<S900=2@T0000002HJ6`0c8b@0LeMJ00<0oooo
00D0onoa0820P020P800P8200<30`0050?ooo`0;0?o`m@2bXZ@0LeaO03l/;@0=2@T0000000L51@0c
8b@0IDI8081aM@3/fml01`3oool01020H6<0000000000000000=0?ooo`050>BUZ`00000000000000
003T][d0403oool02P3ol?D0YY>F06E6B00c8b@06A8B0000000V6Q/0<b<T06E6B030];H30?ooo`05
0?o_l@20P800P8200820P030`<001P3oool02P3onOh0VH6404`d=P0V6Q/0000000L51@0c8b@0IDI8
08b2Q`3oko450?ooo`0>0?oOh`20P800P82008b8R@3oool0ooWn08]dMP0o;2d06A8B0000000V6a/0
IDI808b2Q`3ac]480?ooo`050?ohnP3;];H0P75e06E6B00V6a/00P0000000`0V6Q/0C3Df081XK005
0?ooo`0:0?oioP2IPH@0C3@f02HJ6`0000001`D503<S901UATP0S8:70?o_l@L0oooo00D0ooCf09VA
TP1aCU40?b`]00L51@020000000302HJ6`1B>C/0i;o60?l0ooooE03oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo0P3oool70000000301TA4P1U
ADP0_H:700L0oooo00D0P82000000000000000000?oOh`0^0?ooo`040<V;T0000000000000000>D0
oooo00@0IDI80000000000000000C03oool01020H6<0000000000000000=0?ooo`040<V;T0000000
000000000?l0ooooc03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOo0?ooool0oooo4`3oool01@20P8000000000000000000omoS02h0oooo00@0bH^@00000000
00000000i@3oool0101UATP0000000000000001<0?ooo`04081PH`0000000000000000d0oooo00@0
bH^@0000000000000000o`3oooo<0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0ooooo`3ooolC0?ooo`050820P000000000000000003ogn<0o`3ooolH0?oo
o`05075>D@00000000000000003ogn<0B`3oool01020H6<0000000000000000=0?ooo`050>:LXP00
000000000000003o_lH0o`3oooo;0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0ooooo`3ooooo0?oooc00oooo00D0S7eo000000000000000009n1Q0070?oo
o`030?oenP3oool0oooo0440oooo00@0P61S00000000000000003@3oool01P3oj>`06A8B00000000
0000C3@f0?7>d@H0oooo00<0ooWn0?o`m@3oool0o`3oooo10?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?oooc00oooo00<0i<G800000000
00000P0000000`39Ri00oo?l0?ooo`020?ooo`030?o@f02`NGh0S6Q/02L0oooo00D0i<G800000000
000000000820P00G0?ooo`04081PH`0000000000000000h0oooo00<0bH^@0000000000000P000000
0`39Ri00ooWn0?ooo`020?ooo`030=RUZ`0I4A80oko601@0oooo00D0i<G800000000000000000820
P03o0?ooojT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0oooo<@3oool00`1;=3H00000000000030000000304/d=P1UADP0000000800000
00<0P61S0?ooo`3oool09@3oool01@3TaLP00000000000000000P82001L0oooo00@0P61S00000000
000000003`3oool00`1;=3H00000000000020000000302HJ6`1UADP0IDE800<0000000<0oko60?oo
o`3oool04P3oool01@3TaLP00000000000000000P8200?l0ooooZ@3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooola0?ooo`030?oco01;
=3H0000000P0000000<0P61S0?ooo`3oool09@3oool01@3TaLP00000000000000000P82001L0oooo
00@0P61S00000000000000003`3oool00`3olo`09QXK00000008000000030?noaP3oool0oooo0180
oooo00D0i<G800000000000000000820P03o0?ooojT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo<P3oool02`3onOh0f;bo07=PH`0o
;2d09QXK000000071@D0<b<T04`d=P1UATP0`:R/02L0oooo00D0i<G800000000000000000820P00G
0?ooo`04081PH`000000000000000100oooo00/0k=_O081jOP1UATP0?b`]01<=3P0000003@T903<S
901I?Cl0P75e0?oOh`0D0?ooo`050>C5b0000000000000000020P800o`3ooonY0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?oooh00oooo
00@0P61S0000000000000000o`3ooooM0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?ooool0ooooo`3ooomR0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?ooool0ooooo`3ooomR
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3o
oooo0?ooool0ooooo`3ooomR0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWiol0ooooo`3ooooo0?ooool0ooooo`3ooomR0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?ooool0ooooo`3ooomR0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?oo
ool0ooooo`3ooomR0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWiol0ooooo`3ooooo0?ooool0ooooo`3ooomR0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oooln0?ooo`<0oogo00<0ooco0?ojo`3onOl00P3o
h^H01@3oeM@0omOF0?nj/`3o[jD0oj2B00@0ok:X00<0ojjT0?n@OP3oS7T02@3oSGX0203nQG40jFI9
0>aXC03/J4`0mFmC0?E/CP3oO6D0oi9o1P3oSg/00`3oSGL0ojFF0?ncZP060?nbZ0070?naYP3oblH0
omWG0?oIe`3of=H0omgN0?ojo`020?oio`050?oko`3oo?l0ooco0?olo`3ooOl0o`3ooooo0?ooon40
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ocL0oooo00D0ooWn0?o_m@3ol?D0onc`0?oCdP020?o@c`0=0?o3_P3o/:T0ok:[0?nXWP3oUXL0oiF5
0?n=O@3oSG/0ohMd0?n8M@3gO6L0lWEP0?QiHP040?ajI0030?eiH`3aKE<0lFaB00T0lFaB00P0kFY>
0>9N@03TGd40hE/m0>iVB03]HT<0lVQ;0?Y`E@H0n6mD00<0n6iB0?mhGP3oOFH01P3oO6D01`3oNf@0
ohE^0?n?N@3oSgT0oheh0?nAO@3oVXP00P3oW8X01P3oYID0okV_0?nf[@3o]Zd0okbc0?oBc`80omCA
00H0omOE0?o^lP3olOH0oo3e0?oamP3om?[o0?ooool0oooof03oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo;@3oool00`3oh^D0onca0?oKg@02
0?o2_P060?n[Y03oWiD0nh=b0?f3LP3lOf`0n7]V0P3dMf804@3cMV40jViG0>U^EP3YKUH0iVQ@0>1T
B@3PI4X0gF960=QK?`3HFcd0eUTk0<mC<`3?DS<0ce<c0=9D=@3CECL0iVE:00@0geTi00<0geXj0>5K
?03QG3d02@3QG3d0203RG3d0i5m10>AN?`3WHD@0lFQ;0>eR@`3[Gd00jUhn1P3ZGcl00`3[Gcl0j5dm
0>QL>`060>QL>`030>QM?03[GS`0ke`j0080ke`j00H0lEhl0?IVAP3fIDD0mVE50?QWB03mKE020?e^
D0060?i_DP3oMUX0ogIK0?mfF`3oMU`0ogiV0P3oOfL01P3oOVH0oh1V0?n:L@3oT7X0ojVJ0?nh[080
olW200<0onCV0?odnP3okNl0o`3ooooo0?oooll0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oooaP0oooo01P0ooko0?oko`3oo?l0oo?e0?ofn@3o
inH0omWG0?o<a`3g_K@0nkje0>V]X03YXiL0jZBJ0>VKS`3YUHL0j8Uh0>R0KP3XLeh0j7EQ0=eTC@3I
GdL0e5]20=EMA03EFd820==J@0090=9H?P3AEcd0dEPn0=mTC03HFcd0eUXl0=II>P3EF3X0eUTj00<0
eeTk0`3GFS`00`3GFcd0f5/m0=QK?@040=QK?@030=MJ?03OHdP0k6aB0180i5m100<0hei00>QSA@3a
J4/04P3]HT<00`3]HD80n6e@0?IUA@070?IUA@@0mFA4103eHd<30?AS@P060?MVA`3iI440ofQ60?mY
A`3oJTT0oV]:0P3nK4/05@3nKTh0ofm?0?i^CP3oL540og]N0?n5J@3oTG/0oiAo0?nPS@3o[Ih0oj:A
0?nfY@3o`K@0olFh0?oGd03of]@0on_Y0?oXi@3on_d0oo_o0?omo`3o0?ooool0oooo_@3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo403oool0
4P3on_l0ooKl0?oan03ojo00on7T0?o4`03oclh0ojjX0?nISP3^NVT0j7=Q0<IC?02oBc<0`D`d0<5=
=@32CSH0cE]30<eD>@80cUDj0P3?E3T>0<iE>P030=INA@3QIe00f5/m0140f5/m00<0f5`m0=II>`3[
Je404P3TGd420>9N@0030?5XB`3]HT<0kF930100kF9300<0kF520?AYBP3fIDD04P3fIDD00`3dHd<0
nVE30?mXAP080?mXAP030?mWA@3oK4`0ofM50080ofQ601D0ofM60?mWA@3oJ4H0ofQ60?iWA03oKD`0
ofU60?mWA@3oJ4@0ofU60?mW@`3oPFD0oiEm0?nZVP3o_;00om7<0?oAcP3oj^d0onoa0?obm`3on?h0
0P3oool00`3oo_l0oooo0?ooo`3o0?ooool0oooo/03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`00
1`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo2@3oool04P3omOd0oo_o0?oVk03oe]P0omKG
0?o:b@3o/jh0ojFM0?nAQ@3kQgT0i6mL0<9@=`2oC3@0^4@Z0;a8;`2mBC40_d`d0<5==@@0a54h00<0
`dlg0=5MAP3>ECX04P3>ECX00`39D3D0gVE=0=QL?`0@0=QK?@040=QJ?03PHdP0fee00>]ZD140i5m1
00@0i5ho0>]VBP3UHD<0lFQ;4@3]HT<00`3]HD80m6]=0?I[C@0D0?IUA@030?YU@`3oJ4H0ofQ600L0
ofQ600<0oFI40?mbDP3mIdD01P3oJ4H00`3oJDL0ogAG0?m[B@040?m[B00B0?mYAP3oId80ofE00?mS
?P3oHc`0ofM40?mhF03oQFP0oi1h0?nSTP3o^Zh0ol[20?nk/03ofmT0on3P0?o/k`3omO/0oogoo`3o
oooo0?ooojd0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooo`@0oooo0100oo7h0?obn03ogn<0ol_<0?nb[P3oThP0oj2G0>UkK@3?GdT0eF1;0<A@
=`2jARd0^4DZ0;]8;P2mB2l0_d`d2`34DCP00`35DcX0ef5<0<iF>`0A0<iE>P030<iF>`3=E3X0h6I?
0140f5/m00@0eeXm0=aPA@3IG3l0jFY@4@3TGd40103RGT00if940>EP@P3aJ4/A0>eR@`030>]R@`3d
JD`0mVY=0180mVE500<0m6A40?]/CP3iHd002@3oJ4H00`3mIT@0og5A0?eWA@060?mXAP030?i^C@3o
N5/0of]900X0of]80100ofU60?mW@`3oIT40of<m0?iO>@3lGSL0of4l0?mhF03oPFH0oiEm0?nSS`3o
/J<0olFl0?oIe`3oh^80ooGjo`3ooooo0?ooojT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooi0?ooo`0D0?odmP3ol_@0omkL0?oDd@3nal40m[bg0>n/
YP3YVY40iY650=mkK03@I540dFAA0<YNBP34Ed80_50h0;I;<`2cB2l0^dlh0;e>=033CcLA0<AA>003
0<MD>`3HHT`0cUHk0140cUDj00<0dEPn0<mG?03OITh04@3HFcd0103HG3l0eUTl0=IJ?03[Je4A0>AO
@@040>QRA@3TH440hei00?5XBa00kF9300@0k6930>eRA03^HT<0mFY<4P3fIDD00`3eI4<0mVE50?ma
D`090?mXAP030?eVA03oLE40oFM500H0ofQ600<0oVU80?mfF@3oJdT04@3oJdP20?mZA`0B0?mYA03o
J4<0ofQ20?m`C@3oME@0ogUH0?n0HP3oS740oi9k0?nQS@3o/:80olZn0?o3^@3odLL0on3K0?o[j@3o
o?l0oo?do`3ooooo0?oooih0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooe0?ooo`0>0?oGf@3o^kP0l8=f0>AeI@3EJ5H0eFUE0<UMB035F480_U4j0;E9
<P2bARl0]DXb0;I;<`2jCSL70;]?=`030;U==P2nCCD0a54h0100a54h00@0a50g0<ID?03EH4X0cUHk
4@3>ECX00`3<DcP0cUDj0>1VC`0A0=QK?@040=aN@@3JGD80f5Xl0>][DA00i5m100D0i5m00>UTB03W
HT@0i5ho0?5XB`0@0>eR@`040>]O@03eK4h0l6I80?EYBa40mVE500@0m6930?a/C@3hITH0og=G2@3o
J4H00`3mIT@0og5A0?eWA@050?mXAP030?mWA@3oJdT0of];0180of]800<0ofa90?mXA@3oK4P01`3o
KDT03P3oK4P0ofY60?mX@P3oI3h0ofU40?m`C@3oMeH0ogeN0?n7JP3oP640oiR10?n`W`3od</0onOY
o`3ooooo0?oooiX0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3oooo_0?ooo`0>0?ono`3oinh0oncc0?n_Z`3SNVh0aEi<0;UD@02hDCd0^Ddf0;a@>02iCCD0
]DXb0;Q<=02iCCD=0;]?=`030;a@>02nCCD0a54h0100a54h00@0`Tlf0<aI@@3EHDX0cUHk403>ECX0
103=DcP0eEa30<eD>@3PITlA0=QK?@040=MJ?03FFS`0f5/m0>][DA00i5m100D0i5m00>5L?P3RGT00
i5m10>mVB@0@0>eR@`040>eP@P3]H400jf930?AYBa40mVE500@0mVA40?]]CP3gIdL0og=G2@3oJ4H0
0`3mIdD0ofm?0?eWA@050?mXAP030?eVA03oKTl0oVI20180of]800<0ofi=0?m/BP3oK4P0303oKDT0
3P3oJdP0ofY70?mYA03oJD<0ofU40?m^B`3oME80ogUG0?mkF@3oSW40ok6Q0?o;`P3on_l0oo7ao`3o
oooo0?oooiD0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooZ0?ooo`0>0?olo`3olo/0onoe0?nl^@3o[JL0g79T0;9:=P2bBcL0/D/f0:m9=@2_B3@0[DPb
0;E>>P2eBC8A0;]?=`030;U==P32ESl0_Tde0140a54h00@0a50g0<9?=P3GHT/0cUHk403>ECX0103=
E3T0dUTo0<eD>@3PITlD0=QK?@030>][D@3TGd40i5m100h0i5m100D0iV530>MRA03TGSl0i5m10>mW
B`0@0>eR@`040>eQ@P3]HT80kF930?AYC140mVE500@0mVA40?=R@@3eIDD0og=G2@3oJ4H00`3mIT@0
og5A0?eWA@060?mXAP030?mZB03nIT80of]80140of]800<0ofa:0?m]BP3oJTH04@3oKDT0103oK4P0
ogAA0?m`B`3oKdP20?maC080og9=00H0oh1O0?n^W@3oc<D0om;=0?oen`3onooo0?ooool0ooooT03o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooon80oooo
00h0ooOk0?oZj`3ohn<0olk=0?_7a@3YZ:<0fiF=0=21M@3?Kf00`5U80;A>>P2/AS40[DLb0:i8<`H0
[dPd00<0/4Xd0;I;<`2kCcL0402kCcL00`2jCSL0_50h0;i==@0@0<AA>0050<=@=`3;Ecl0aE<k0=MR
B`3>ES/03`3>ECX01@3?E3T0dUTo0<mF?03>ECX0gVE>0100f5/m00D0eeTl0=aOA03GFS`0f5/m0>MX
C`0@0>AO@@050>AP@@3VHD@0hem10>AO@@3_Id/03`3]HT<01@3/HT<0lVQ:0?5UB03/HD80m6U<0100
mVE500D0mFE50?YZB`3hJ4T0mVE50?mcE`090?mXAP030?eVA03oLE40oFM500@0ofQ600@0ofM50?m/
B`3oJDP0oVI24P3oJdP00`3oK4X0of]80?mZAP0A0?m]B@040?m`C03oNUX0ogQE0?maC0D0og1;0P3o
KdT01`3oKTL0ogYG0?n8J@3oV7l0oiZ20?nfY`3oc<<00P3og=H00`3okN`0ooKg0?ooo`1I0?ooo`04
0>C5b01<=3H0LDiA0>nf_Ol0ooooo`3ooolZ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0oooogP3oool02`3omOd0om_O0?o1`@3o[:P0jXEk0<USD`2lED40
YClX0:8n9P2Y@bh0[DLc00`0[dPd00<0[dTc0;E>>P2fBS<0402kCcL0102iCCD0aeU30;eA>@2nCCD@
0<AA>0050<9@=`37E3/0a58i0=QSC03>ES/03`3>ECX01@3=DcT0e5Y20<mF?@3>ECX0gVI?0100f5/m
00D0f5Tl0=MJ?03HFcd0f5/m0>MXD00@0>AO@@050>EQ@`3TGSl0i5m10>AO@@3_Id/03`3]HT<01@3/
HD80jUhm0>eP@03]HT<0m6U<0140mVE500@0mVI80?ITAP3fIDD0og5E2@3oJ4H00`3mIT@0og5A0?eW
A@040?mXAP050?eUA03oLE00ofY90?eVA03oK4L0403oJdP0103oJTL0og9A0?mZA`3oJTHA0?m]B@04
0?m^B`3oK4T0ofi80?mcC@`0og1;00/0ofi80?mZ@@3oISd0ofPo0?n1H@3oUW`0okBS0?neY03ofmP0
oo[o0?ofo01E0?ooo`040;NVY`00000000000?na^?l0ooooo`3ooolZ0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooofP3oool02`3ooOl0onC[0?o:b@3o
Y9l0iX1f0<m[G@2iFDH0YTLc09Lk902dDCd0[4H`0140[dPd00<0/ddi0;I:<`2kCcL03`2kCcL0102k
CcH0`UI00;a@>02nCCD@0<AA>0040<AB>@32CcH0a54h0<eK@a00cUDj00D0cE@i0<aC>03>ECX0cUDj
0=iVC`0?0=QK?@030=IJ?03LGd@0fUi10080f5/m00<0ifQ@0>AO@@3TGd403@3TGd400`3RGT00jfI:
0>9N@0020>AO@@030>mWB`3]HT<0kF9300d0kF9300D0kV=50?5VB03[HT<0kF930?AYC00@0?IUA@05
0?AS@`3cHD00m6A40?IUA@3oLUH02@3oJ4H00`3mIT@0og5A0?eWA@040?mXAP050?mYAP3oJ4H0ofU7
0?mXAP3oJDD04@3oJdP00`3oKDX0of]80?m/B00A0?m]B@050?m[AP3oJD@0ofi90?mkF@3oLD`03`3o
L4/02@3oKDH0of]20?m[@03oLDT0ohYZ0?nPR03oWH<0okJV0?oLfP1C0?ooo`040:>HV@0000000000
0?o=eOl0ooooo`3ooolZ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0ooooeP3oool03`3om_P0oooo0?o@dP3o[:P0iGmd0<YXF@2mGD`0[U4n09/n:02K@2X0
X4<^0:A6<P2]CCX0_5M40:e8<P0@0:m8=0030:e8<P2^B3<0]TXc0100^dlg00@0^Dde0;Q<=02kCcL0
_Tde3`34DCP01@32CCH0cEQ10<YF@033DCP0`Dde00l0cUDj00<0cE@i0=5I?`3AFD000P3>ECX00`3N
ITl0f5/m0=QK?@0>0=QK?@050=YM@P3IG400f5/m0=QK?@3WJ500403TGd401@3UH480i5m10>AO@@3T
Gd40kfM;00l0kF9300D0kfA60?5XBP3]HD80kF930?AYC00?0?IUA@060?EUA@3jJDX0nVU:0?ATA03f
IDD0og9F2@3oJ4H00`3mIT@0og5B0?eWA@040?mXAP050?mYA`3oJ4H0ofQ60?mXAP3oJDD0403oJdP0
1@3oJDH0ofY60?mZA`3oMeL0ofe:00l0ofe900D0ofa80?m`CP3oJTH0ofm:0?mcC@0@0?m`B`0>0?m_
BP3oNUD0ogUC0?mcC03oLDT0of]20?m]A03oNU@0ohUX0?nHO03oWH<0ok^]0?oUi03olOA>0?ooo`04
08n:R`00000000000?oUk_l0ooooo`3ooolZ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooc`3oool03`3ooOl0onCU0?oUi@3fa;l0fZ^Q0=JCS@3HQW`0
bfUJ0;1A?P2]Cc/0ZT/h0:A6<@2Q@bh0XTD`0:A6<@040:A6<P030:Q:=P2kF4@0[DPb00l0[dPd00@0
[TPc0;UA?P2`BCD0]TXc3`2kCcL01@2iCCH0a5M00<1C?02kCcL0_Tde0100a54h00@0aE<j0<IC>P34
DCP0`Dde3P3>ECX0103?ECX0cU@i0=5H?P3AFCl20<iE>P030=iVC`3HFcd0f5/m00<0f5/m0`3IG3l0
103IG3h0fE`o0=UL?`3IG3l30=QK?@060=UK?P3HFcd0eeTk0=eP@`3OHTL0j6YA0P3[ITX20>YUB0X0
jfI:00@0jfE90>UUB@3XI4L0i5m10P3SGSl00`3^IDP0k6510>aQ@@020>aQ@@030>aP@@3bJ4X0lfU<
00L0lfU<00<0lfQ;0?5VB03cJD/00P3cJD`00`3hKE40mfI60?ET@`020?ET@`050?EUA@3fIDD0mVE5
0?IUA@3fITH01`3gITH01@3gITL0mfQ80?IUA@3fIDD0og9F00<0ofQ600<0ofM60?mXAP3oJ4H02@3o
J4H00`3nIdD0ofi=0?m^C@020?mXAP030?mYA@3oJdP0of]800d0of]800H0ofY70?m`C`3oKD/0ofY7
0?mjF`3oKDX@0?m]B@050?m`C@3oJdL0ofm:0?m`B`3oM4l0403oL4/00`3oLDX0ogA>0?meCP040?md
C@0=0?mcB`3oLDT0ogA=0?mfD@3oOUX0ogiI0?n=K`3oX8L0okFU0?o<_`3ogmL0oo3^0?ogmP170?oo
o`03081iO000000040/;0?l0ooooo`3oool[0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0oooob`3oool01`3omoh0oo3g0?oMhP3eXId0]ee>0:96=02TAS40
0P2TAS800`2SAC00ZDXf0:a=>@0;0:A6<P030:U;=`2jEd@0[DPb00l0[dPd00@0[DLc0;9;=@2_B3@0
]TXc3`2kCcL01@2iCcL0]T/c0;U<=@2kCcL0_Tde00h0a54h00H0`e4h0<YE?`3;F440`U0g0<AA>031
CCD50<iE>P040<mD>@3>E3T0cE@i0<eD>@<0cUDj0P3?E3T0203@F3d0d5Ll0<eE>P3AFCl0d5Lm0<eD
>@3MI4`0f5Xl0P3EF3X01P3CF3X0fee10>EXCP3UJ4h0iFI=0>=WC@80iFQ>00L0iVYA0=UK?@3EF3X0
eEPj0=UL@03MHDD0ee/m0080f5/m00<0ifQ@0>AO@@3TGd40303TGd400`3TGSl0iF530>EQA0030>AO
@@030>mWB`3]HT<0kF9300`0kF9300<0kF520?=YB`3[H4000P3]HT<00`3cJ4/0mVE50?IUA@020?IU
A@060?=Q@@3cHT40lf910?AR@P3mKe<0og9F1@3oL5D00`3mL5<0lF0n0?=Q@0020?=R@@090?m/C@3o
IdD0ofM50?mZB03oJdX0ofY90?m]BP3oJDP0ofM50080ofQ600<0oVM50?mWA@3oIdD00P3oIdD00`3o
J4H0oFI40?eWA@020?mXAP030?m_C`3oJdP0of]800d0of]800H0ofU70?mXA@3oJTL0ofY70?miFP3o
KDX?0?m]B@060?m/B03oKDT0ofe90?m]B03oL4/0og9<403oL4/0103oKdP0ogeI0?mfD@3oLdd70?md
C@040?mcC03oM4d0ogA=0?mcC0<0ogA=00H0og=<0?moF`3o/Z00omkL0?oLf@3onOe30?ooo`03081W
J`000000@bh`0?l0ooooo`3oool[0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0oooob03oool02P3oloX0omkT0?nk^P3ZRH00`fQK09Y3<02A>bP0WTDc0:]=
?02TAS420:A6<P030:A6<@2ZBcL0[4di00/0Y4Hb00<0[Tll0;YGA02]B380402_B3@00`2_BC<0[dPd
0;I:<`0C0;]?=`030;i==@34DCP0a54h00d0a54h00D0aeDl0<MD>`31CcH0`U0g0;m<=0030<iE>P03
0<eD>@3@ES/0deU10080e5]200@0e5]10=1G?03=E3T0cE<h0P3<DcP0203FGD@0ff9;0=YQBP3JHD/0
eei50<aB=P3GGTH0eETk103HFcd30=IJ?0040=QJ?03FFS`0eUXl0=IJ?0<0f5/m00<0eEPj0=IH>P3H
Fcd00P3HFcd00`3WJ500i5m10>AO@@0=0>AO@@030>5K?@3SGT00i5m10080i5m100<0kfM;0>eR@`3]
HT<03@3]HT<00`3_I4D0kF520>eR@`020>eR@`P0mVE51`3fI4@00`3hITL0oFi@0?ATA0020?IUA@08
0?YYB@3mIT@0oVI20?m_C`3oMEL0og=E0?mbE@3nKDd20?eVA0040?mXAP3nId@0ofe<0?m^C@80ofe<
00<0ofY80?mZB@3mIdD00P3oJ4H0103oNEX0ofY70?mYA`3oJTL<0?m[B080ofU800@0of]80?mZA`3o
N5T0ofe:3P3oKDT01@3oK4P0og5@0?maCP3oKDT0ofe80180og1;00<0og5:0?mdC@3oLd`0203oM4d0
0`3oLd`0ogA=0?mdC@040?mdC@090?mcC03oN5<0og590?m/@`3oNE@0ojRC0?oAbP3oj>P0oo;g0400
oooo00<0P5UL0000001VATT0o`3ooooo0?ooob/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3oooo40?ooo`0>0?olo`3onOl0om_P0?nj^03]RX80aFUM08hj
9@2?>bH0UCl[09Y3<02KA340ZeA20:iA?P2SAC020:A6<P030:A6<@2ZBcL0[4di00X0Y4Hb00@0XdD`
0:Q9=@2jEd@0[DPb3P2_B3@01@2]B380_EI20;=<>02_B3@0]TXc00h0^dlg00H0^Thg0<EH@P34Ed40
^Ddf0;]?=`2nCCD:0<AA>00:0<9@=`32CCH0`Tlf0<AA>033DCP0_T/b0<AA>03;FD80cEY30<MD?080
cE@i00<0cE<h0<aB=`3@F3d00P3IH4P01@3JHDT0fV180==J@03=DcL0cE@i0080cUDj00L0cU@i0<iF
>`3AF400c58g0<iD>@3>ECX0h6M@00h0f5/m00<0fE/m0=UM@03HFcd00`3HFcd00`3WJ500i5m10>AO
@@0<0>AO@@030>EQ@`3XHdL0i5m000<0i5m100<0kfM;0>eR@`3]HT<03@3]HT<01@3/HT80kF930>eR
@`3]HT<0k65100l0mVE500<0mVE60?MWB03fI4@00P3fIDD04`3dHT00ofQ60?mXAP3nIdD0oFI40?eU
A03mIT@0oVM50?mXAP3oIdD0oFI40?eWA03oLE80og=E0?maDP3oLE<0ofi<0?m]C03nIT800P3oIdD0
2P3oMeL0og9A0?mcD@3oKT`0ofM50?mZA`3oJdP0ofQ60?mZA`3oJDH50?m[B0070?mZA`3oL4l0og=C
0?m[B03oJTL0ogQH0?m]BP0>0?m]B@080?m/B03oKT/0ofi;0?m]B@3oKDP0og1;0?meDP3oL4X?0?m`
B`030?maBP3oLT/0ogE>00P0ogA=00<0og=<0?mdC@3oM4d01@3oM4d02`3oNE<0ogE>0?meCP3oMDh0
og170?m[@@3oRVX0oj6:0?o3]P3og]`0oo;g03d0oooo00<0Kde@0000002BIFT0o`3ooooo0?ooob/0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooono0?oo
o`0;0?ohnP3og=`0n/K40?70^`3MUY00`VEG0;aPD@2]ED@0V44^09<m:@2F?bd0102J@c00102I@Rl0
Z4lm0:mA?P2SAC020:A6<P030:A6<@2ZBcL0[4di00X0Y4Hb00@0[Dhk0:M9=02jEd@0[DPb3P2_B3@0
1@2^B380[dPd0:m8=02_BC@0]TXc00l0^dlg00l0^Ddf0;a@>02kCcL0^Thg0;i==@34DCP0`e4h0<EA
>03;Ecl0bUHn0<YG?`36DcX0`e4g0<9@=`33DCL00P3=FT<0203>Fd@0aE<j0<AB>03;Ed00a54h0<QE
?@39ESh0a54j0P3>E3T30<iE>P@0cU@i00<0ceDj0<iE>P3>ECX00P3>ECX00`3?ES/0dUU00<eD>@03
0<iE>P030=iVC`3HFcd0f5/m00`0f5/m00<0fUe00=iRA`3GFC`00`3HFcd00`3WJ500i5m10>AO@@0;
0>AO@@030>AO@03UH440if=600@0i5m100<0kVE90>eR@`3]HT<0303]HT<00`3_IDH0l6E60>eR@`02
0>eR@`030>aQ@@3fIDD0mVE500d0mVE500<0n6M80?ASA03fIDD00P3fIDD00`3dHT40ofQ60?mXAP08
0?mXAP030?iWA@3nITD0oVM50080oVM50100ofQ60?iZA`3oJ4H0oVQ60?iWA@3oMeP0ofi=0?m_C@3o
KDX0ofY60?mZA`3oJdT0og=B0?mbD@3oM5@0ofa90P3oJTL02@3oK4T0ofm>0?m`CP3oKDX0ofY70?m[
B03oJTL0ogUJ0?m]BP0>0?m]B@060?m]BP3oKTX0ofe90?m]B@3oKdX0og5;0P3oLD`?0?m`B`040?m`
B@3oLT/0ogUE0?meCPP0ogA=00<0og9;0?mdC@3oM4d00`3oM4d00`3oLd`0ogeI0?miD`040?meCP0;
0?mdC@3oLTX0og9:0?n0G@3oQfL0ohma0?n]V@3oc<40olg50?oRg03on_`0=`3oool00`1C>S`00000
0<b=T`3o0?ooool0oooo:`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?oook/0oooo00T0ooGh0?oUj`3o];@0nIB>0<=VF@2`EdD0Vd@a08Xf802C?RX02P2J
@c00102KA380Y4Xi0:iB?`2SAC020:A6<P030:A6<@2ZBcL0[4di00X0Y4Hb00@0ZT/j0:M9=@2jEd@0
[DPb3@2_B3@01P2^B3<0]dll0;=<>02]Ac<0[TLc0;U==Pd0^dlg00l0^Ddf0;aA>@31Ed00]DXb0<5D
?P38FdH0`U<j0<5@=P32D3H0a54h0<YF?`38ESl0bUDo0<EC>P32D3L00P34DCP01032CcL0`U0g0<9@
=`34DCP20<AB>0<0a54h00<0`Dde0<iE>P3>ECX0303>ECX00`3@Ec`0eUi50<mD>@030<iE>P030=iV
C`3HFcd0f5/m00`0f5/m00<0eELi0=II>`3HFcd00`3HFcd00`3WJ500i5m10>AO@@0;0>AO@@030>EP
@P3WHT@0hU`n00@0i5m100<0j5m00>eR@`3]HT<0303]HT<00`3[Gcl0k6930>eR@`020>eR@`030>aQ
@@3fIDD0mVE500d0mVE500<0nFY;0?ITA03fIDD00P3fIDD00`3dHT40ofQ60?mXAP080?mXAP070?iW
A@3oIdD0ofQ60?mXAP3oJTP0og9A0?eWA@030?mXAP030?mhF@3oJdP0of]800@0of]80`3oJTL20?m[
B0030?mZA`3oK4T0ofm>0080og9@00D0ofU60?m[A`3oMUH0ogUI0?mhF0030?m]B@80ofa8203oKDT0
2P3oK4P0og1>0?mhF03oK4P0ofY70?mhF03oLTh0og5<0?mlF@3oKTT=0?m`B`050?m`BP3oN5@0ogQB
0?mbB`3oMDl0203oM4d00`3oLT/0ogA=0?mdC@030?mdC@030?mcC03oO5L0og=;00X0ogE>00P0og=;
0?m/@`3oL4L0oh1N0?n?L@3oZ9L0olVn0?oThS@0oooo00<0>2HX0000003o/KP0o`3ooooo0?ooob/0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oooni0?oo
o`090?o]m@3oh^P0gH9l0:9?@02TCcd0XDPf098l:@2E?b`0V48_00/0VT<`00D0VT8_0:99>02TBSL0
[U8o0:=5<0020:A6<P030:A6<@2ZBcL0[4di00T0Y4Hb00D0XD<_0:=5<@2VB3@0^UM40:e8<P0=0:m8
=0050:i8=02iE3l0/ddi0:e7<`2^Ac<0302kCcL02P2hC3@0_U4j0<ULB038G4H0^D`e0;Q==@2lD3P0
_U4j0;m?=P34D3L20<AA>0<0`U0g2034DCP00`36DcX0a58h0<AA>0020<AA>0030<5==@3>ECX0cUDj
00`0cUDj00<0cE@i0<iE>P3>ECX00`3>ECX00`3NITl0f5/m0=QK?@0;0=QK?@030=UL?`3RIDX0eUXl
00@0f5/m00<0ifQ@0>AO@@3TGd402`3TGd400`3UHD<0kVU=0>9N@0040>AO@@030>QO@03]HT<0kF93
00/0kF9300<0kVA50?9YB`3]HT<00`3]HT<00`3/HD40mVE50?IUA@0=0?IUA@030?ATA03fIDD0mVE5
0080mVE500<0m6910?mXAP3oJ4H0203oJ4H01`3nIdD0ofM50?mXAP3oJ4H0ofY80?m_CP3oIdD00`3o
J4H00`3oMEH0of]80?m[B00;0?m[B00?0?mZA`3oKD/0og=C0?mXAP3oJdP0ofa:0?miFP3oKdd0ofe9
0?mY@`3oLTl0ogQI0?mfEP3oJdL0ofa800L0ofe90P3oK4P01P3oKDT0ofY70?mjFP3oLTh0og1;0?ma
BPh0og1;00D0og1:0?mlFP3oNU@0og9;0?mjE@080?mdC@030?mbB`3oM4d0ogA=00<0ogA=00@0og=<
0?mlE`3oMe00ogQA303oMDh0203oLT`0og9;0?mhD`3oOEP0ogmK0?n/UP3oko40onWY<@3oool00`0T
6AX000000?o=e@3o0?ooool0oooo:`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?oookH0oooo00D0oo_o0?oDf03cU8h0[5E809E2<P0208ln;P0309M1;`2H
@Rl0VT<`00h0VT<`00<0V48_09]3;`2QA3000`2TAS800`2TAS40ZT/g0:a=>@080:A6<P060:=5<@2`
D3h0YTPd0:I8=02jEd@0[DPb3P2_B3@01@2]B380[DLc0:m8=02^Ac<0^dlf00<0^dlg0P2lD3T00`2l
D3P0^4de0;iA>P020<]MB@060;eA>P2iCCD0^dlg0;a@>02kCcL0^Dde0`2kCcL00`2nCCD0a54h0<AA
>00<0<AA>0030<aI@@32CCH0a54h0080a54h00<0`Dde0<iE>P3>ECX0303>ECX00`3BFT00ce@i0<iE
>P030<iE>P030=iVC`3HFcd0f5/m00/0f5/m00<0fE`o0>1TB03FFS`0103HFcd00`3WJ500i5m10>AO
@@0<0>AO@@030>EQ@`3TGd40i5m100<0i5m100<0j5m00>eR@`3]HT<02`3]HT<00`3^I4D0mFa>0>aR
@`030>eR@`030>aQ@@3fIDD0mVE500`0mVE500<0mfI60?QXB03fIDD00`3fIDD00`3dHT40ofQ60?mX
AP080?mXAP030?iWA@3oIdD0ofQ60080ofQ600<0oFM50?mXAP3oJ4H00P3oJ4H00`3oMUP0of]80?m[
B00<0?m[B0030?mZA`3oIdH0of]80080of]800<0ofU60?m]B@3oKDT00P3oKDT20?m]BP0B0?m]B@3o
JdH0ofe90?mhF03oNET0ofm;0?mZAP3oKDX0ofi;0?m[A`3oKDX0ofe90?mZA`3oNUX0og9>0?m`B`3o
L4X0og5:3@3oL4/01@3oL4X0ogaI0?mjE03oLd`0og9;00L0ogA=00<0ogE?0?mkE`3oLd`0103oM4d0
103oLd`0ogaG0?mhDP3oNE<?0?meCP080?mdC@3oNe<0ogaC0?mlE03oQF00ojZC0?oUi03ooOl^0?oo
o`03010;2`000000onG^0?l0ooooo`3oool[0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0oooo[`3oool0403oo_l0ooWm0?o]l03ogMd0lKbk0<MnM`2oMfl0
/EY=08lm;@2=>b/0SS`/08dl;02=?B`0RSXY09Do;@2K@c0>09Y3<00409]4<@2LAC<0Vd<_0:54<0<0
Y4Hb00<0Y4Ha0:Y;=`2/CCT0202TAS801P2SAC40YTTf0:I8<`2WBC@0^UM40:e8<PT0[dPd0140[TPd
0:m9=02_B3@0[dPd0;A=>@2eCc/0[TPc0:i8<P2dC3P0a5I10;e@>@2iC3@0^dlh0<1C?P31ECl0_U8k
0;Y>=`060;]?=`030;Y>=`30E3d0^Thf00<0^dlg00<0_Tde0<AA>034DCP03034DCP00`34DSP0a54h
0<AA>0020<AA>0030<5==@3>ECX0cUDj00`0cUDj00<0d5Hl0<iE>P3>ECX00`3>ECX00`3NITl0f5/m
0=QK?@0<0=QK?@030=MJ?03HFcd0f5/m00<0f5/m00<0ifQ@0>AO@@3TGd402`3TGd400`3WHTD0hei0
0>AO@@040>AO@@030>QO@03]HT<0kF9300/0kF9300<0kF110>aP@@3]HT<00`3]HT<00`3/HD40mVE5
0?IUA@0=0?IUA@030?QWB03fIDD0mVE50080mVE500<0mFA40?aVA03oJ4H0303oJ4H00`3oKD`0oVQ6
0?mXAP030?mXAP030?mfF03oJdP0of]800/0of]800<0ofa90?maC`3oJdP00`3oJdP00`3oJ4D0ofe9
0?m]B@0;0?m]B@0<0?m^BP3oLe80ogEE0?m_C@3oJdL0ofe90?miF03oN5D0og5;0?mdD03oN5D0og1:
303oL4/01@3oL4X0ogaI0?mjE03oLd`0ogMA00L0ogA=00<0ogI?0?n0G03oLT/01@3oM4d0103oM4h0
ogE>0?mgD03oMU0?0?meCP030?mgC`3oNU40ogYA0080ogYA00P0ogaC0?n=J`3oWh<0oj^D0?oFc@3o
hmh0oo?c0?olobL0oooo00<0oo;g0000000@2`/0o`3ooooo0?ooob`0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooon]0?ooo`080?odo03okO@0njbZ0>F8
P@2fH5@0S3XZ08<b8@2<>b/608dl;0040990<02B@C40U3l/09]3<0h0VT<`00@0VT8`09a5<`2K@bl0
XD@`0`2TAS800`2TAS40ZT/g0:e=>P080:A6<P060:U9=@2TAc<0Y4Hb0:I8=02lF4D0[DPb1@2_B3@0
3P2]B3<0[DLc0:m8=02/AC40^58n0;=<>02/AC40[dTc0;MA?@2cBcL0[DPb0:m8=02^Ac80^Dde3@2k
CcL00`2kCcH0^Ddf0;]?=`030;]?=`030;i==@34DCP0a54h00/0a54h00<0aE<j0<]G?`34DCP00`34
DCP00`31CCD0cUDj0<iE>P0<0<iE>P030<mG?03>ECX0cUDj00<0cUDj00<0gVI?0=QK?@3HFcd02`3H
Fcd00`3NH4D0f5/m0=QK?@040=QK?@030>UYD@3TGd40i5m100X0i5m100<0i6120>QTA`3TGd401@3T
Gd400`3XGd00kF930>eR@`0:0>eR@`030>eSA03dK4h0kF9300@0kF9300<0k6510?IUA@3fIDD03@3f
IDD00`3eIDD0mVE50?IUA@030?IUA@030?YU@`3oJ4H0ofQ600L0ofQ600D0ofa:0?m[B`3oJ4H0ofQ6
0?iVA@050?mXAP030?mfF03oJdP0of]800/0of]800<0ofa90?m_CP3oJTL00`3oJdP00`3oJ4D0ofe9
0?m]B@0<0?m]B@0C0?m[AP3oJT@0ofe90?m]B@3oK4P0ogUI0?mcC@3oL4X0og9>0?mkF03oMU40ofm8
0?mfDP3oMe@0ogE?0?m`B`3oL4X0ofm90?m`BP040?m`B`060?m_BP3oNEL0ogUC0?mcC03oMDh0og9;
1P3oM4d00`3oMDl0ogmK0?mbB`050?mdC@040?mcC03oMDh0ogUE0?miD`l0ogE>00<0ogeI0?mnE`3o
Ne401@3oNe402`3oNE00og960?mgC@3oU7@0ojnK0?o@b03omOX0oo_o0?ooo`3ob=40ooSo0240oooo
00<0olgE00000013;S00o`3ooooo0?ooob`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooon[0?ooo`070?oXk03o[:X0f7Yc0=AhL02D@S40OC0M08Hf9@09
08dl;004098o;`2??bl0U3l]09]3<0h0VT<`00@0U3d[09Q2;`2K@bl0XD@`102TAS800`2YBCD0ZD/f
0:A6<P060:A6<P0F0:A6<@2cDd40ZDXf0:A6<@2UB3@0]54m0:m9<`2_BCD0[DPc0:e7<`2_B3@0[DHb
0;UC?P2fCcX0ZT@_0:a5<02hDSh0/d`h0:e8<P2_B3@0/4Xd0:e8<P80[dPd00<0[TLc0;]?=`2kCcL0
302kCcL00`2lD3L0_4lh0;]?=`030;]?=`030;i==@34DCP0a54h00/0a54h00<0aE8i0<ED?034DCP0
0`34DCP00`31CCD0cUDj0<iE>P0<0<iE>P030==J@@3>ECX0cUDj00<0cUDj00<0gVI?0=QK?@3HFcd0
2`3HFcd00`3HFSd0f5/m0=QK?@040=QK?@030>1SB03TGd40i5m100X0i5m100<0heho0>5K?03TGd40
1@3TGd400`3XGd00kF930>eR@`0;0>eR@`030?1UAP3]HT<0kF9300@0kF9300<0lf=30?IUA@3fIDD0
2P3fIDD00`3fITH0oVmC0?IUA@050?IUA@030?YU@`3oJ4H0ofQ600L0ofQ600<0oVe=0?m/C03oIdD0
0P3oJTL50?mXAP030?mfF03oJdP0of]800/0of]800<0ofU60?mXA@3oJdP00`3oJdP00`3oJ4D0ofe9
0?m]B@0;0?m]B@030?m]BP3oKT/0ofe90080ofe90180ofa80?miF@3oM4h0og1;0?m`B@3oM500ogMC
0?m`B@3oMe<0ogMD0?meC`3oKdT0ogA@0?mjF@3oM500og1;0?m`BP3oKTT20?m`BP060?mjF03oMe<0
og=<0?mdC@3oN580og=<1@3oM4d00`3oMDl0ogmK0?mbB`050?mdC@040?mcC03oMTl0ogE>0?mcC0l0
ogE>00<0ohIR0?mjDP3oNe401`3oNe402@3oNE00ogE;0?m`@`3oQ5l0ojF;0?naV`3o]ZX0D3Li0;F0
P@0Q0?ooo`030?na^0000000ITI90?l0ooooo`3oool/0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooZ03oool0203oi>X0omCI0?NGU@32Jf40WTXl08De
9020<Ql0RcXZ2`2=?2`0102<>b/0RCXY09E0;@2K@c0>09Y3<0040:9:>@2J@c00Vd<_0:54<0@0Y4Hb
00<0XdDa0:A5<@2TAS801`2TAS805@2TAc<0YTLb0:A6<P2TAC40ZT@`0:m8=02ZA2l0^UA00;I@?02]
AS40[dTc0;E?>`2cC3P0[4Da0:m8=02]B3<0[DLc0:m8=02]Ac<0^5<o0:e8<P020:m8=0030:i7<`2k
CcL0^dlg00`0^dlg00<0_U4j0<5D?P2kCcL00`2kCcL00`2nCCD0a54h0<AA>00;0<AA>0030<5<=033
CcL0a54h00<0a54h00<0`Dde0<iE>P3>ECX02`3>ECX00`3=ECX0cUDj0<iE>P040<iE>P030=iVC`3H
Fcd0f5/m00/0f5/m00<0eeXm0=QK?@3HFcd0103HFcd00`3FFC/0i5m10>AO@@0:0>AO@@030>IQA03T
Gd40i5m100D0i5m100<0j5m00>eR@`3]HT<02P3]HT<00`3ZGSd0jelo0>eR@`050>eR@`030?5R@P3f
IDD0mVE500X0mVE500<0mVI60?MWA`3fIDD01@3fIDD00`3jID<0ofQ60?mXAP070?mXAP050?i]C@3o
K4`0ofM50?mYA`3oKTh01@3oJ4H00`3oMeT0of]80?m[B00;0?m[B0030?m]B`3oK4P0of]800<0of]8
00<0ofU60?m/B03oKDT02`3oKDT00`3oKDX0ogMG0?m/B0020?m]B@030?m/B03oNET0ogA>00@0og1;
01<0og5;0?m`BP3oKdX0og1:0?m`B`3oLTh0ogIC0?mbCP3oKdT0ogIC0?mjF03oME40ofm90?mjF03o
Me80og=<0?meCP3oO5P0og=<00D0ogA=00<0ogI?0?n0G03oLT/01@3oM4d01@3oLd`0ogE>0?meCP3o
NUD0ogI?00h0ogE>00<0ohAP0?mgC@3oNe402P3oNe401`3oN4h0og950?mhC03oK4P090/404HP7P3o
hNP0803oool00`3NVIl00000099UJ@3o0?ooool0oooo;03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooj<0oooo00X0oogo0?o[kP3baL80dIbJ0;mjM02C
AcT0Sd<e08Pn<02>?Rl0S3/[3@2=?2`01@2=>b/0UD<c08Pi:@2E@2d0Vd<`00d0VT<`00D0VD8`0:18
=P2J@c00Vd<_0:54<0040:A6<P80XdDa102TAS803@2UAc<0Y4Lc0:A6<@2XBSH0ZT`i0:A6<P2QA300
[4di0:m9=@2^B380[TLc0;9;=P2aBCD00P2_B3@20:m9=0D0[dPd0P2^B3@30:m8=0030:i7<`2kCcL0
^dlg00`0^dlg00<0^Dde0;]?=`2kCcL00`2kCcL00`2nCCD0a54h0<AA>00;0<AA>0030<mLA@34DCP0
a54h00<0a54h00<0`Dde0<iE>P3>ECX02P3>ECX00`3?ECX0dUTo0<iE>P050<iE>P030=iVC`3HFcd0
f5/m00/0f5/m00<0g5m30=QK?@3HFcd0103HFcd00`3FF3X0i5m10>AO@@0:0>AO@@030>EQ@`3TGd40
i5m100D0i5m100<0j5m00>eR@`3]HT<02P3]HT<00`3dJD`0kF930>eR@`050>eR@`030?5R@P3fIDD0
mVE500X0mVE500<0mfI60?ET@`3fIDD01@3fIDD00`3jID<0ofQ60?mXAP070?mXAP050?i]C@3oK4`0
ofM50?iWA@3oJDP01@3oJ4H00`3nJDL0of]80?m[B00;0?m[B0030?m^C03oJdP0of]800@0of]800<0
ofY60?m]B@3oKDT02`3oKDT00`3oL4d0ofe90?m]B@020?m]B@030?mcD@3oLT`0og1;0080og1;00<0
ogA?0?mbC@3oL4/01`3oL4/01P3oLDd0og9=0?maC03oKdT0ogMD0?mmF@80ogA=00<0ogUD0?meCP3o
Ld`00P3oMDh20?mdC@030?mfC`3oP5`0og9;00L0ogA=00<0ogE>0?miDP3oMDl03P3oMDh00`3oPUh0
ogeE0?mjD@0;0?mkD@0;0?miC`3oLDL0ofHl03HD301S7aP0ofIE0?mlK@3oX9P0olK00?oXj@3okNl0
6`3oool00`2VLgP000000<b=T`3o0?ooool0oooo;03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`00
1`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooj00oooo00`0oo_o0?oan03o/[80_FUQ08Ll;P24>R`0
PCPY084g:023>BX0PCPY09E8>`2FACH?08dl;00408hm;02LBS`0WTLf09Y2;`d0VT<`00D0W4Hd09Y3
<02J@c00Vd<_0:54<0030:A6<P0=0:A6<@2SAC00XdDa0:I7<`2WBCD0YTLc0:E7<`2cE480/E4o09i1
;@2VB3@0YdTe0:A6<@020:A6<P030:Y5<@2_B3@0[dPd00/0[dPd00<0/T/g0;9=>02_B3@00P2_B3@0
0`2^Ac<0^dlg0;]?=`0;0;]?=`030;aA>@38FdH0^Thg00@0^dlg00<0_Tde0<AA>034DCP02P34DCP0
0`34DSP0`E0f0<AA>0040<AA>0030<5==@3>ECX0cUDj00/0cUDj00<0e5]20<iE>P3>ECX0103>ECX0
0`3NITl0f5/m0=QK?@0:0=QK?@030=IJ?03GFS`0f5/m00D0f5/m00<0eUPj0>AO@@3TGd402P3TGd40
0`3SGT00i5m10>AO@@050>AO@@030>IN?`3]HT<0kF9300T0kF9300<0k6520>]O?`3]HT<01P3]HT<0
0`3aHT80mVE50?IUA@0:0?IUA@030?Y[CP3fIDD0mVE500D0mVE500<0nVI40?mXAP3oJ4H01`3oJ4H0
103nK4/0of];0?mWA@3oL4l60?mXAP030?eU@P3oJdP0of]800/0of]800<0ofa80?m[B03oJdP0103o
JdP00`3oJTH0ofe90?m]B@0:0?m]B@030?m_B`3oKDT0ofe900<0ofe900<0ofY60?m_BP3oL4/00P3o
L4/00`3oKdX0og1:0?m`B`0;0?m`B`0=0?m_B@3oLT/0ogA=0?mdC@3oMe40ogeI0?mbBP3oNE@0ogmK
0?mcC03oLD/0ogI?0?mbB`080?mdC@80ogE>00<0ogUC0?meCP3oMDh0303oMDh00`3oQ600ogU@0?mh
D00:0?mkD@0?0?mhC`3oJ3l0ofPn0?m`A01471808@P60?mD@`3oIE40of5>0?mSD@3oHe00ofUG0?n`
Z`3ohnP0oogo01P0oooo00<0Kda?0000003o/KP0o`3ooooo0?ooob`0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooonN0?ooo`060?odn`3obL`0nYVG09mB
A01m=B@0PCHX1@23>BX00`21>BX0RSh`09E3=00?08dl;00408/j:P2NBC`0WTLf09Y2;``0VT<`0140
V48_0:QB@02KA340VT<`09]3;`2QA300XdDa0:A6<P2SA340ZDXf0:U9=@2QA2l0ZDPe0;=D@P2ZC3P0
XdDa0:A6<@020:A6<P030:=4<02SAC40Y4Hb0080Y4Hb00<0ZTDa0:m8=02_B3@02P2_B3@00`2_BC<0
/T/g0;9<>0030:m8=0030:i7<`2kCcL0^dlg00`0^dlg00<0`UDo0;Y>=`2kCcL00`2kCcL00`2nCCD0
a54h0<AA>00:0<AA>0030<YF?`34DCP0a54h00@0a54h00<0`Dde0<iE>P3>ECX02P3>ECX00`3=E3T0
c5<h0<iE>P050<iE>P030=iVC`3HFcd0f5/m00T0f5/m00<0f5Xl0=mRA`3IG3h01P3HFcd00`3FF3X0
i5m10>AO@@090>AO@@030>9N@03ZITT0i5m100H0i5m100<0iUm00>eR@`3]HT<02@3]HT<00`3_I4H0
kF=40>eR@`060>eR@`030?5R@P3fIDD0mVE500T0mVE500<0lf=30?=Q@03fIDD01@3fIDD00`3gITH0
og1B0?mWA@080?mXAP040?i]C@3oK4`0ofM50?mcE0H0ofQ600<0oFE20?m[B03oJdP02`3oJdP00`3o
L4l0of]80?m[B0040?m[B0030?mYA03oKDT0ofe900X0ofe900<0og=A0?m]B@3oKDT00`3oKDT00`3o
JTH0ofm:0?m`B`0@0?m`B`0@0?m_B@3oLT/0ogA=0?mdC@3oLd`0og590?mcC03oM4d0og9<0?mdC@3o
LT/0og]G0?mgD03oLTX0ogE>0?mgD@80ogA=00<0og=<0?meCP3oMU400P3oMDh00`3oNUD0ogE>0?me
CP0<0?meCP040?moF`3oNe80oh1J0?miD0P0og]A00T0ogaB0?m`AP3oISd0ofU00?mnDP1D8aL07PP5
0?mD@`3oIE40103oHTl01P3oGd/0ofiL0?nXXP3ob/X0oo?h0?omoaD0oooo00<0@bh`0000003ocMD0
o`3ooooo0?ooob`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooonK0?ooo`070?oioP3oeMX0ok>d0=n6P02BAST0MRhN080g:00708<i:P03080h:@20>2P0
SCd^00d0SC`/00H0SS/[09=2<P2B@340W4Xl09i7=P2J@Rl<09Y3<00?09Q2;`2MA380VT<`09Q2;`2K
@bl0XDDa0:a=>P2WB3@0Xd@_0:i??@2^DCh0Xd@`0:A6<P2SAC40Y4Ha00<0Y4Hb00<0Y4Da0:Y<>02T
AS800`2TAS800`2ZAC40[dPd0:m8=00;0:m8=0030:e8<P2^Ac<0[dPd0080[dPd00<0[TLc0;]?=`2k
CcL02`2kCcL00`2iCCH0^4`d0;]?=`040;]?=`030;i==@34DCP0a54h00T0a54h00<0a50g0=9OB035
DST01@34DCP00`31CCD0cUDj0<iE>P0:0<iE>P030=AL@`3@ES/0cUDj00D0cUDj00<0gVI?0=QK?@3H
Fcd02@3HFcd00`3FFS`0hVA90=UL?P060=QK?@030=IH>P3TGd40i5m100T0i5m100<0i5ho0>IQA03T
Gd401P3TGd400`3VGd00kF930>eR@`090>eR@`030?5WB@3^I4D0kF9300H0kF9300<0lF920?IUA@3f
IDD02@3fIDD00`3gIdP0mfI60?IUA@050?IUA@030?MWA`3oLeL0ofM500P0ofQ600@0oVe=0?m/C03n
IT80ofU71P3oJ4H00`3mID80of]80?m[B00;0?m[B0030?m^C03oJdP0of]800@0of]83@3oKDT00`3o
L4`0ofe90?m]B@030?m]B@030?mZAP3oKdX0og1;0080og1;00<0ofi90?mgE03oL4X02`3oL4/00`3o
KdT0og9;0?mdC@020?mdC@030?meCP3oMTl0og==00<0ogA=00d0og=<0?mbB`3oLd`0ogE>0?mkE`3o
LT/0og=<0?mjE03oN5<0ogeJ0?mbC03oMDh0og=<00h0ogE>00@0og=;0?mlDP3oNe<0ogU@1`3oNe40
2P3oO580ogI>0?mZ?`3oJD00ogA<0?n5F01A8AH07PX80?mFA@3oIE450?mRC`060?mQCP3oG4L0oeY5
0?nHT03o^kL0on7T503oool00`0O5AH000000?oUkP3o0?ooool0oooo;03oool0103YjNT0dM7A0=7A
d@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooiL0oooo00T0oo?d0?[9b`3[_[`0
fIVD0;9PEP2EAcT0N34P07dc9022>2T02023>BX01022>BX0TD@g08Dk;02:>b/=08dl;00608`l;02=
?B`0SS`/09a:?02NAcH0VT8_2@2J@c00102I@Rl0VT<`09]3<@2OAcH209Q1;P050:59=`2F?b`0XTDa
0:U;=`2VB3@00P2TAS800`2RA300XdDa0:A6<P050:A6<P030:=5<@2WBCH0Y4Hb00<0Y4Hb00<0ZTDa
0:m8=02_B3@02P2_B3@00`2aBSH0^E<o0:m9=0030:m8=0030:i7<`2kCcL0^dlg00/0^dlg00<0aEU3
0;]?=`2kCcL0102kCcL00`2nCCD0a54h0<AA>0090<AA>0030<AB>@35DST0a58i00D0a54h00<0`Dde
0<iE>P3>ECX02@3>ECX00`3=DcT0dUTo0<mG>`060<iE>P030=iVC`3HFcd0f5/m00P0f5/m00<0ee/m
0=QM@03HFSd01P3HFcd00`3GFcd0eUPj0>=N@0090>=N@0030>=N?`3VHTD0hei000H0hei000<0hem1
0>IO@03]HT<02P3/HD800`3]HT<0k6520>aQ@P060>aQ@P030?5R@@3eIDD0mVE500T0mVE500<0nVY<
0?MVAP3fIDD01@3fIDD00`3gIdL0og=G0?mWA@080?mXAP040?i]C@3oK4`0og1?0?mYA`H0ofQ600<0
oFE20?m[B03oJdP02P3oJdP00`3oK4T0of]70?m[B0050?m[B0030?miF@3oKDT0ofe90100ofe900<0
ofa80?m_B@3oL4/00P3oL4/00`3oLD/0og5<0?maC00;0?m`B`030?m`BP3oLT/0ogA=0080ogA=00<0
ogI@0?miD`3oM4d0103oM4d20?mcC0<0ogA=00T0og=<0?mgDP3oMe40ogeJ0?mjE@3oMTl0ogQB0?mi
E03oM4d0303oMDh01@3oM4d0ogYA0?mjDP3oOED0ogYA00@0og]A00`0ogaB0?mhD03oKdL0ofTo0?m/
@P3oN4l0ogaB0?n4E`1P9aT020820?Y??`3oIU480?mRC`080?mOBP3oGd`0og5P0?n1L`3oX9P0olk:
0?oVi`3oloH>0?ooo`030?obm`00000020H60<X0oooo00T0ooCf0>C5b03;];H0/Z:T08J4Q@2ITI80
/Z:T0=Rl_`3hi>P0LP3oool02@3oj>`0f;fo0;:RY02<R8T0P8200:JJV`3H_;l0lLkA0?oioP3M0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooU@3oool0
1`3og^@0ojVY0;=UG024@380M2hN07Xa8@22>BX03023>BX01021>2T0PcXZ08<i:P2:>b/=08dl;006
08ln;P2E@c<0S3/[09a:?02NAcH0VT8_1P2J@c0209Q2;`0909U3<02XD3l0W4Dc09Y3<02RBCL0V48_
09Y3<02H@Rl0VT0^00D0Y4Hb0P2SAC450:A6<P030:A6<@2WB3@0YDLc00@0Y4Hb00<0ZTDa0:m8=02_
B3@02P2_B3@00`2]B380[dPd0:m8=0030:m8=0030:i7<`2kCcL0^dlg00X0^dlg00<0^Dde0;U==P2k
CcL01@2kCcL00`2nCCD0a54h0<AA>0080<AA>0030<=A>03AG4H0ae@k00H0a54h00<0`Dde0<iE>P3>
ECX02@3>ECX00`3CFd80d5Hk0<iE>P060<iE>P040=iWD03HFcd0f5/m0=QK?@L0eUXl00<0eELj0>9T
B`3LGT<00P3HFcd01P3FFS`0eETk0=EI>`3EEcT0hVA:0>1RA`H0kf]?00H0k6U=0>m[C`3_Jdl0kf]?
0>iZC`3_JTl70>m[C`040>]VBP3TG3d0kV=40?Q^D`P0mfiB00<0mfe@0?M^DP3gKU800P3gKU80203f
K500mfiB0?M^DP3gKU80mfiA0?QZC03mKU40m6A40P3cHD400`3dHd<0mVE50?IUA@020?IUA@040?AT
A03eIDD0m6910?ITA0@0m6A40P3fIDD00`3gIdL0ogAH0?mWA@080?mXAP040?i]C@3oKTd0ofU70?mY
A`H0ofQ600<0oFI40?mZA`3oJdP02@3oJdP00`3oJTL0ogIG0?m/B@060?m[B0030?miFP3oKDT0ofe9
00T0ofe900<0ofa80?mcD@3oKDT01@3oKDT00`3oKTP0og1;0?m`B`020?m`B`030?mcC`3oLTd0og1;
00/0og1;00D0og5:0?mcC03oM4d0ogA=0?mcC0020?meCP@0ogA=00<0og=<0?mbB`3oM4d0103oM4d0
0`3oMe40ogiI0?mcC0020?meCP050?mhD03oM4d0ogE>0?mlE`3oLd`02P3oMDh00`3oNE00ogaC0?ml
E0050?mkD@050?mjD@3oJd80ofPm0?mY?P3oMTh00P3oNe401@3oPeH0JBXJ0000003jF4X0ofQE00d0
of9?00D0oe]50?mfIP3oOFl0ol6o0?o/lP0<0?ooo`030?o=e@0000008QLH0<T0oooo00<0UfQ/00d9
2@0000001P0000000`0=2@T0/7Un0?oco01^0?ooo`0309MXK00I4A80000000L0000000<06A4B0=Rf
_@3oool0f`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?oooi<0oooo00P0omSN0<aiL`2IDD@0RD<g06h^7`1n>Rd0SD8e084g:0d0PcTZ00@0Q3X[084h:P23
>BX0RS/[3@2=?2`01P2B@C00WTXl08`j:P2LBS`0WTLf09Y2;`D0VT<`00P0UCh/0:E<?02UC3/0V44^
09i6<`2KA340VD8_09M0;P80VT<`00<0VD8_09Y0;P2VAc<0102TAS820:=5<@D0Y4Hb00<0XdDa0:a=
>P2YBcL0102TAS800`2ZAC40[dPd0:m8=0090:m8=0030;19=@2eCCT0[dTc00@0[dPd00<0[TLc0;]?
=`2kCcL02P2kCcL00`2oDcd0^Ddg0;]?=`050;]?=`030;i==@34DCP0a54h00T0a54h00<0bUHn0<AB
>@34DCP01@34DCP00`31CCD0cUDj0<iE>P080<iE>P040<iD>@3IH4P0dETo0<mD>@D0cUDj00L0cE<i
0=UOAP3EF3X0e5Pj0=QK?`3SID/0iVU@0080iFQ>00D0hfE;0>EXCP3UJ4h0iVYA0=UL@0030=EH>P06
0=IJ?03HFS`0f5Xl0=IJ?03JGD80fE`o2`3WHT@00`3TGT40if940>MRA0060>MRA0030>IO@03]HT<0
l6I800T0l6E700<0lFI80?1UA`3`IDL01@3`IDL0103aITP0nfi@0?UXB03fIDD20?ITA0090?AS@`3c
HT40lf910?5P?`3iJ4P0og=G0?m`E03oKe@0oViC00<0og5E00H0og=G0?MWB03bHT40m6=30?m^C`3o
IdD80?mXAP030?mZB03oJ4H0oFE200P0ofQ600<0ofQ50?m[B03oJdP02@3oJdP00`3oJTP0of]80?m[
B0050?m[B0030?miFP3oKDT0ofe90140ofe900<0ofi80?m`B`3oL4/00P3oL4/00`3oLD/0og1:0?m`
B`0;0?m`B`070?maBP3oLd`0ogA=0?mdC@3oLd`0ogYD0?mgDP040?mdC@030?mcC03oLT/0ogA=00@0
ogA=00<0ogMA0?mmFP3oLdd00P3oMDh01`3oNeD0ogE>0?meCP3oMe40og=<0?miDP3oO5P0203oMDh0
103oNE00ogQ@0?mgCP3oNE030?mkD@060?mlDP3oLDT0ofPm0?mY?P3oLTX0ogaB0P3oNe401@3oPeH0
IbXJ0000003iEDH0ofMD00`0of9?00T0ofEB0?mSD03oH4`0oem:0?m`GP3oOW40okJb0?ocnP3oo_l0
2@3oool00`3o/KP0000003<S9@390?ooo`/0000000<06A4B0?o@f03oool0K03oool;0000000300d9
2@3od=P0oooo0=X0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooon@0?ooo`0;0?oXl03ojO00kiFB08i8>`1m>R`0LS<U07De9`1j>B/0TdXo08a2=021=bP0
3023>BX01@22>2T0TTHi08Lm;`21>2T0RS/[00d0SC`/00`0S3/[08`l:`2<>b/0W4Xl09i7=P2J@Rl0
Vd@a09Y3<02E?R`0WTHc0:=;>@2G@Bh209]4<@0509Y3<02J@Rl0VT<`09e5<`2MAC800P2J@c000`2I
@Rl0VT0^0:I7<`040:A6<P80XdDa1P2TAS800`2SAC40Y4Ha0:A6<P030:A6<P030:Y5<@2_B3@0[dPd
00T0[dPd00<0/4Te0;aE@`2]Ac<0102_B3@00`2^Ac80^dlg0;]?=`090;]?=`030;Y>=`38FdH0_50h
00H0^dlg00<0_Tde0<AA>034DCP02034DCP00`33DCP0`U4g0<AA>0060<AA>0060<5==@3>ECX0cUDj
0<iE>P3>ES/0d5Ll0`3@ES/03@3>ES/0cUDj0<iD>@3:D3D0c58f0==K@P3MHd`0fV9;0=eTC@3KHT/0
cEDj0<aB=`3NI4`00`3HFcd70=UL@0030=UL?`3FFC/0f5Xl00L0f5/m00<0eUPj0>AN?`3TGSl0103T
GSl01P3TGd40i5ho0>AN?`3TGSl0iF120>AP@PL0i5ho00<0i5m10>IO@03]HT<02@3]HD800`3[H400
k6110>eQ@P020>eQ@P070>eP@P3]HD80kF520>eQ@P3^HD<0oG5D0?ITA0060?IUA@050?ITA03fIDD0
mfM70?UYB@3iJ4T01@3gIdL20?IUA@0>0?MVAP3oLeD0oVI20?mYA@3oLeD0ogEH0?meEP3oMUP0ofU7
0?iV@P3mIT@0ofM40?m^CP3oJTX30?mYA`D0ofQ600<0ofQ50?m[B03oJDL0203oJdP00`3oJTL0ofQ6
0?m[B0060?m[B0030?miFP3oKDT0ofe900T0ofe900<0of]70?m/B03oKDT01@3oKDT00`3oKTP0og1;
0?m`B`030?m`B`030?mbC@3oL4/0og1;00X0og1;00<0og5:0?mcC03oM4d00P3oM4d20?mcC0@0ogA=
00<0ogA<0?mbB`3oM4d0103oM4d00`3oMe40ogeJ0?mcC@020?meCP030?mkE@3oMDh0ogE>0080ogE>
00L0ogM?0?mfC`3oMTh0oh1M0?miD`3oLd`0ogM?00<0ogE>0P3oNE020?mlE0080?mjD@3oNe40og]A
0?mgC`3oJT00ofPm0?mdBP3oO5830?mkD@050?n0E@2<=R<000000?9<?@3oIE00303oHTl0103oIeD0
of=?0?mSD03oHe020?mRCP040?mZE`3oKE/0ok>^0?oZl0P0oooo00<0gYVO00000019<cD0b@3oool0
200b8b@000000000000b8b@0OUMJ0<V;T02GJ6`0Bc@f100000000`0I4A80onS/0?ooo`1[0?ooo`05
038S90000000000001TB4P1nEeX00P39Ri000`1aCU400000000000020000000301TA4P3od=P0oooo
0=T0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooon<
0?ooo`060?oal`3ofMT0kl720<23O@2HCd@0NcP[1@1h=bT0101g=RP0RT8f08i4=P21=bP<08<i:P05
088i:P25>b`0QC/[08<i:P2:>b/0302=?2`02P2>?Bd0UD<c08hl;02=?2`0VTPh0:A<?02H@Bl0W4Dc
09i6=02H@Bh809Y3<00709Y4<P2JA340VT<`09Y3<02I@Rl0VT0^0:I7<`040:A6<P030:54;`2TAS80
Y4Hb00@0Y4Hb00<0YTPd0:Q9=P2TAS80102TAS800`2ZAC40[dPd0:m8=0090:m8=0030:i8=02^B380
[dPd00@0[dPd00<0]4hj0;]?=`2kCcL04P2kCcL0102nCCD0a54h0<AA>034DCP30<=A>080a54h00d0
`e4h0<AB>@3:Ecl0bELo0<IC>P33DCP0`e4g0<AA>03<FD40cUU20<aI@@30CC@0cU@i0080cE@i00T0
dETo0=EMA03DG4<0eEa30=AL@`3AFCl0c5@i0=1F?03AESd0203>ECX00`3FGD@0f5/m0=QK?@070=QK
?@040=MK?@3MHDD0fee20=QJ?0L0f5/m00<0eUPj0>AO@@3TGd401`3TGd400`3SGSl0j6950>IQ@`08
0>AO@@030>IO@03]HT<0kF9300L0kF9300<0jf520?=XB`3_HdD01`3]HT<00`3^Hd@0oG5D0?ITA009
0?IUA@030?MWB03fIDD0mVE500H0mVE500<0mfI60?mbEP3oIdD0203oJ4H00`3mIT<0oVQ70?m]CP02
0?m^CP040?m]CP3oJTP0oVI40?mWA@80oVM500d0of]70?mbDP3oM5@0ofe;0?mYA@3oJdP0ofa90?m]
B`3oK4X0ofe:0?mZA`3oLe80ofa:00L0of]800<0ogQI0?m]B@3oKDT0203oKDT00`3oK4P0ogAC0?m^
B`060?m]B@030?mhEP3oLD`0og1;00<0og1;00<0ogIB0?maB`3oL4/02@3oL4/00`3oL4X0ogQD0?mf
D0040?mdC@030?mgDP3oM4d0ogA=0080ogA=00<0ogYD0?mmFP3oLT/0103oM4d00`3oMTl0ogQD0?md
CP030?meCP030?mhD@3oMDh0ogE>00H0ogE>00H0ogA=0?miD`3oMDh0ogA=0?mkEP3oNe@20?mkD`07
0?miD@3oNU40og]A0?mbBP3oK440ofY10?mfC@050?mkD@060?n0E@2?>2@000000>m:?03oKU`0of=@
2`3oHTl00`3oJ5L0ofaJ0?mSD0040?mSD0080?mSC`3oHe00ofYH0?n7NP3oUX`0olk<0?oXj03onOd3
0?ooo`030:IcN0000000ITM:0<T0oooo00<0/X:70;n[[@3ol?D01@3oool00`3onOh0ZhZ=00000002
0000000307mYK03oool0oooo06X0oooo00@0/X:709VATP3TaLP0ooSj103oool00`3onOh0i<G8075>
D@020000000301TB4P3T_lH0oooo0=P0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooon:0?ooo`060?o]m03o[jl0/6AJ06/]7@1[:a`0McHX1`1h=bT0101i
=bX0OC/]08Hl;P21>2T<08<i:P0508Ll;@27?2h0PcTZ084h:@2;>b/02@2=?2`208`k:`08090o;`2C
@S80TT0a09=2<P2A?c00W4Tl09i7=@2J@Rl;09Y3<00709]3<@2J@c00VT<`09Y3<02I@Rl0VT0^0:I7
<`030:A6<P030:A5<@2QA2l0Y4Hb00@0Y4Hb00<0Y4Ha0:M8=02ZBSL01@2TAS800`2ZAC40[dPd0:m8
=0090:m8=0030;mGA@2_B3@0[dPd00@0[dPd00<0^E8o0;]?=`2kCcL02@2kCcL00`31E3h0_U4j0;]?
=`050;]?=`0F0;U==@2lC3@0a54h0<AA>033DCL0bUM00<]I@P3=FD80aU<k0<9?=P31CcD0aE<j0<]G
?`3@G4D0cEY30<9@=P33DCL0a54h0<9@=`32CcH0`U0g0<5==@X0cUDj00<0ceLl0=1H?@3?E3T01`3>
ECX00`3<DSH0f5/m0=QK?@080=QK?@030=IH>P3FFS`0f5/m00L0f5/m00<0eEPj0>=O@@3TGd401`3T
Gd400`3TGT40hUdo0>AN?`080>AO@@030>IN?`3]HT<0kF9300L0kF9300<0jf520>]N?@3/HT<01`3]
HT<00`3^Hd@0oG5D0?ITA0080?IUA@030?ATA03iJT`0mVA400L0mVE500<0mfI60?mbEP3oIdD02@3o
J4H00`3oIdD0ofQ60?mXAP070?mXAP030?mXA@3oJDL0ofU60080of]800T0ofY70?m^B`3oMeL0ogAE
0?mcD`3oId80ofE00?mYAP3oKdd00P3oLU001P3oL4h0ofY70?m[B03oJdP0ogUJ0?m/B0T0ofe900<0
ofa80?m^B`3oKTX01@3oKDT00`3oK4P0og]K0?maC0040?m`B`030?m`BP3oLTd0og1;00T0og1;00<0
ofm90?mmF`3oN580103oM4d20?mcC0<0ogA=00<0ogYD0?mmFP3oLT/01@3oM4d01P3oM4`0ogE?0?me
CP3oMDh0ogI?0?mlF@`0ogE>00X0ogI?0?moF03oP5X0ogaD0?miD@3oOED0ofe40?mW?@3oJ3d0ogM>
1P3oNe401P3oOe@0XD8[0000002K<BL0oea90?mRCP/0of9?00<0ofUG0?mSC`3oH4`02@3oHe002@3o
G4H0of]I0?nLU03o_K/0onW_0?ooo`1_C4l00000081IG03C0?ooo`0409MXK0000000000002HJ6gL0
oooo00@0C3@f000000000000Bc@ff@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooohL0oooo00H0ooCi0?o:c@3^Ti00dWih078a8P1`<24907Pg:@0407Pf
:025?c<0MS@U07lg9`d0PcTZ00@0RCd_08Xn<021>2T0P3HW202=?2`0302<>b/0SSd/09I4=02C@S80
T3l_08lo;`26=RD0SC`/08`k:`2KAcX0WTLe09Y2;`X0VT<`00<0V44^0:E<>P2H@Rl00P2J@c000`2I
@Rl0VT0^0:I7<`030:A6<P030:A5<@2QA2l0Y4Hb00@0Y4Hb00<0XdDa0:13;@2SA2l01@2TAS800`2Z
AC40[dPd0:m8=0080:m8=0030:i8=02cC3P0[dPd00D0[dPd00<0^E8o0;]?=`2kCcL02@2kCcL02P2m
DCX0_50h0;U==P2iCCD0^Thf0;]?=`2hC3@0_50i0<EI@`35E3`20<9@=P0;0<9A=`3;FD80d5e50=1L
A@37E3`0`U4g0<AA>032D3L0aU<j0<5?=P32D3L01P34DCP00`31CCD0cUDj0<iE>P080<iE>P80cE@i
203>ECX00`3<DSL0f5/m0=QK?@070=QK?@030=UM@@3LGd@0f5/m00P0f5/m00<0eUTk0>9O@03TGd40
1P3TGd40103SGd40jFA80>UTA`3RGT080>AO@@030>USA@3]HT<0kF9300L0kF9300<0kV=40>iQ@`3]
HT<01`3]HT<00`3^Hd@0oG5D0?ITA0080?IUA@030?ITA03eI4<0mVE500L0mVE500<0mfI60?mbEP3o
IdD0203oJ4H20?mZB@T0ofQ600<0ofI20?m[B03oJdP0103oJdP02`3oJDH0ofQ60?mZA`3oK4X0ofQ7
0?mYAP3oLE00og=C0?mbDP3oLU00ofY70080ofU600L0ogMH0?mdD`3oKT/0of]70?m^BP3oK4P0of]7
00D0ofe900<0of]70?m]B@3oKDT0103oKDT00`3oK4P0og]K0?maC0050?m`B`030?mkF@3oL4/0og1;
00P0og1;00<0ofm90?mmF`3oN580103oM4d00`3oLdd0ogE>0?mdC@020?mdC@030?mhD`3oO5T0og9;
00D0ogA=00<0ogA<0?meC`3oMDh00`3oMDh00`3oM4d0ogE>0?meCP090?meCP090?mfC`3oOeL0ogU@
0?miD03oNe<0ogYB0?mX?@3oHcX0og170080ogU@1@3oNe401P3oOU<0[4`a0000001h9Qh0oem;0?mT
D@/0of9?00<0ofUH0?mUD`3oJ5D02P3oHe00203oHTh0oea60?mG@03oSH40ol[:04<];`000000P6M[
d`3oool0103od=P0000000000000001g0?ooo`04081XK0000000000000000=T0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooon60?ooo`060?oJg`3RTi00
XUM<07Lf:01X:QX0McHX2`1h=bT00`1k>B/0NCHW080h:00=08<i:P04088j:P23>BX0PcTZ080f9`D0
SC`/00T0S3TZ08dj:`2<>b/0V4Df08/i:@2E@S80TT4a08dl;02A@2l00P2=?2`0102<>b/0WTTk09m8
=P2H@Rl:09Y3<00309Y2;`2KAC40VT<`0080VT<`00<0VD8_09Y0;P2VAc<00`2TAS800`2TAC40XD@_
0:A6<P040:A6<P030:I7<`2/Cc/0XdHb00D0Y4Hb00<0ZTDa0:m8=02_B3@0202_B3@00`2_BC@0[DLa
0:m8=0050:m8=0030;UB?`2kCcL0^dlg00H0^dlg0P2iCCD03`2iCCH0]TTc0;I;<`34ET00ae]40<5E
?`2fBc<0^4`d0;a@>@32Ed00a5@k0<9?=P32DCL0a54h0<9@=`020<9?=P060<=A>034DCP0a54h0<9=
=P3=FD<0a50g1`34DCP00`31CCD0cUDj0<iE>P070<iE>P030<eD>@3DG4<0cE@i00P0cUDj00<0c58g
0=QK?@3HFcd01`3HFcd00`3KGD40gF550=QJ?0090=QK?@030>5N?`3TGd40i5m100H0i5m100<0j6=5
0>MRA03TGd40203TGd400`3]J4`0kF520>eR@`060>eR@`030>]Q@P3bJ4/0lFQ:00P0kF9300<0kV=4
0?eaE03fI4@01`3fIDD00`3fI4@0mfM70?MVA@080?IUA@030?MVAP3oLUH0ofM500P0ofQ60P3oJDL8
0?mXAP030?mYA`3oL500of]800L0of]800D0ofY70?mcD`3oKTd0of]80?mZA`020?mXAP0A0?mZA`3o
JdP0ofY70?mZA`3oN5T0og=A0?m]BP3oJdL0ofY40?mfE@3oMUH0ofY60?m/B03oKDT0ofU60?mcD@3o
Kdd01P3oKDT00`3oK4P0ogUI0?maC0050?m`B`030?mbC03oKdT0og1;00P0og1;00<0ofi90?mkF@3o
Me40103oM4d20?mhDP060?mcC03oM4d0ogA=0?mjE03oOUX0og9;1@3oM4d00`3oLd/0ogA>0?meCP02
0?meCP030?mfC`3oMe40ogE>00X0ogE>00/0ogI@0?mmE`3oNe40og]A0?mlDP3oK4<0ofPm0?m[@P3o
NU40og]C0?mnF0020?mkD@090?mjD@3oNe40og]A0?mnD`2YBRl0000008@Y803oH4`0ofQE00/0of9?
00@0ofIC0?mUD`3oKeh0of=?303oHe001@3oH4d0ogEU01`<30000000P6md0=@0oooo00@06A4B0000
00000000oko6MP3oool01@2<R8T00000000000000000omoS0=P0oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooon20?ooo`080?ogn`3acLl0aiRE0;IWG`28
@cH0PSh`07Dd9P1h>2T<07Pg:@0407Th:P1i=bX0N3HX080h:0`0PcTZ00h0PSPY08Pn<022>2T0PcTZ
080f9`2=?2`0Rc/[090o;P2D@c@0SSd]09M4=@2=?2/0SC`/090o;`@0SC`/00L0U48c08dl;02=?2`0
S3/[0:5;?02QB3H0V48_00T0VT<`00<0VD<`09e5<P2J@c400`2J@c000`2I@Rl0VT4^0:I7<`030:A6
<P030:A5<@2QA2l0Y4Hb00@0Y4Hb00<0YDLc0:U;>02TAS80102TAS800`2TAS40[DLc0:m8=0090:m8
=0030;A=>@2`BCD0[dPd00D0[dPd00L0^E8o0;]?=`2jCSH0^Thf0<5E?P31ECl0_E4i0080^Thf00T0
a5M20<AG@@2oDS`0_e8k0;Y>=`2mDCT0_E0j0;e@>@2jCSH00P2kCcL00`2jCSL0_Dde0<AA>0080<AA
>0030<EC>@35DST0a54h00L0a54h00<0`Dde0<iE>P3>ECX01`3>ECX00`3>E3T0dUTo0<mE>P080<iE
>P030<aB=`3HFcd0f5/m00L0f5/m00<0fU`o0=UJ?@3HFcd02@3HFcd00`3QGSl0i5m10>AO@@050>AO
@@030>EP@@3UH480hem100T0i5m100<0kFM;0>eQ@P3]HT<01P3]HT<00`3/HD80k6510>iQ@`080>eR
@`030>iSA03jKe<0mVA400L0mVE500<0mFE50?YZB`3gIdP0203fIDD00`3gITH0og9F0?mWA@080?mX
AP030?mZA`3nId@0ofQ600L0ofQ600<0ofY80?miFP3oJdP0203oJdP00`3oK4X0ofa90?m[B0070?m[
B00?0?mcDP3oKDT0ofe90?m]B@3oK4P0ofm<0?m^B`3oKDT0ofa80?m`C@3oLe80og9@0?m^BP3oK4P0
og1=0080og9A00D0ofe:0?m]B@3oK4P0ogYJ0?maC0060?m`B`030?mgE03oL4/0og1;00L0og1;00@0
ofm90?mlFP3oMU40og==0`3oM4d00`3oMDh0ogA=0?mdC@020?mdC@030?mjE03oOEX0og9;00D0ogA=
00<0ogA<0?meC@3oMDh00P3oMDh00`3oMe00ogUC0?meCP0:0?meCP090?mfD03oOUP0og]A0?mfC@3o
KT@0ofHm0?mbBP3oNU40og]A0080ogaB00/0ogQ?0?mlD`3oNe<0ogaC0?mnEP3oNe80^5Hh0000000a
3P/0oeY90?mTD00;0?mRC`040?mQCP3oHe00ofA@0?mTD@/0of=@00<0ofAB0?m]FP3oG4T00P000000
1@26@c`0ojBL0?o5`03oi^H0oocm0<L0oooo00<0ooWn0>C5b02bXZ@00P20P8001@2oZjd0lLkA0?oo
o`3oool0IDE80080000000<0oko60?ooo`3oool08@3oool00`3ol?D0i<G80;:RY0020820P00408b8
R@2bXZ@0jlW=0?oioPT0oooo00<0oo3e0<^d]P20P8000P20P800102OUIL0f;bo0?kFfP3onOh`0?oo
o`060?;Oh`2bXZ@0P8200820P02PUYL0lLkA0P3oool01@2bXZ@00000000000000000omoS0=P0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomo0?ooo`09
0?ono`3ohNP0ojn`0:MLD@1l>R`0LS8S07Lf:01h=bT0Q3lc00h0N3LY00@0NcT[084m<01h=RP0P3PX
3023>BX02@21>2T0RCd_084h:P24>R/0Oc@T09]7>@29>BP0SC`/08lm;@0808dl;00808`l;02>?B`0
SC`/08dl;02<>b/0XD/l0:58=P2H@Rl909Y3<00309Q2;`2QAcD0WDDc00<0VT<`00<0WDHc0:]@?P2S
AC000`2TAS800`2TAC40XD@_0:A6<P040:A6<P030:U:=P2TAS80Y4Hb00@0Y4Hb00<0Y4D`0;1:=02_
B3@0202_B3@03@2_BC<0[DPc0:m8=02_B3@0/4Te0;1:=P2_BC<0ZTH`0;MA?@30F4D0]DTb0;Q<=02k
CcL00P2lD3P50;]?=`030;]?=P2iCCH0^dlg00L0^dlg00<0_Tde0<AA>034DCP01P34DCP00`32D3L0
cEU20<QE?@080<AA>0030<5==@3>ECX0cUDj00H0cUDj00<0ce@i0=5I?`3AEcd02@3>ECX00`3<DSL0
f5/m0=QK?@060=QK?@030=IJ?03OHTL0eUTk00X0f5/m00<0hEho0>AO@@3TGd401@3TGd400`3VHD<0
jfI90>9L?P090>AO@@030>eWB`3]HD80kF9300D0kF9300@0k6930?=WB@3dJ4/0jf52203]HT<00`3^
Hd@0nVmD0?ITA0070?IUA@030?ITA03dHT40mVE500P0mVE500<0mfI60?maE@3oIdD01`3oJ4H0103m
ID@0ofm?0?aU@@3oIdD70?mXAP030?mZB03oN5T0of]800L0of]800<0ofa:0?m]C03oJTL0203oJdP0
0`3oIdD0ofe90?m]B@070?m]B@80of]70P3oKDT0303oKDX0ofi:0?m^BP3oKDX0ofY60?m^BP3oNe/0
ogUE0?m_B03oL4/0og5<0?mbC@80og1;00<0ofm80?m`B`3oL4/01`3oL4/0103oKdT0ogaJ0?mfD@3o
Ldd40?mdC@070?mlF@3oMU00ogA=0?mdC@3oN580ogUD0?mcC0050?mdC@030?mdC03oMDd0ogE>00<0
ogE>0P3oMTl:0?meCP060?mfD03oOUP0og9:0?mY?P3oJ3d0og582@3oNe40203oNe80ogQ?0<5O@@00
00000`000?mIA`3oJEP0of5>2P3oHTl0103oHDh0of=?0?mVE03oKU`<0?mSD00;0?mZF03kDD000000
0000002K>bl0of=>0?mVD`3oIeD0oi^A0?oDe@3oo?l0WP3oool>000000@0oooo0`0000000`3o_lH0
oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00<0onS/038S900000001@0000000`2b
W:80oooo06E5B002000000030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool3
000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000001`3oool00`3H_;l000000000
0007000000030<V;T03oool0oooo00D0oooo00<0/7Un0000000000001`0000000`3TaLP0oooo0?oo
o`020?ooo`<0000000<0P61S0?ooo`3oool01P3oool0103o_lH000000000000000050?ooo`<00000
00<0oko60?ooo`3oool0103oool01@3ogn<00000000000000000P82000H0oooo00<0om3H01TB4P00
0000100000000`1UADP0oo?l0;:RY003000000030?oOh`3oool0oooo0=H0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomm0?ooo`060?ono`3omO`0nJn_
08U3=`1e<bH0N3HX0`1h=bT00`1g=RP0T4Ll07Pg:@0=07Pg:@0407Ld9`1f=BP0N3HX080h:0X0PcTZ
00L0PcPY08<i:P20>2T0P3TY08Lm;`2=@C<0OCDW00`0SC`/00P0UD<d08lm;@2=?2`0SC`/08`k:`2Q
Bc`0XDPf09Q2;`X0VT<`00<0Ucl]09U2;`2J@c000P2J@c000`2MAC<0[E4o0:=5<0030:A6<P030:A5
<@2QA2l0Y4Hb00<0Y4Hb00<0YDLc0;5D@@2SAC401@2TAS800`2TAC00/4Xd0:m8=0040:m8=00>0:m9
<`2^B3@0[dPd0:m8=02bBSH0]U0k0:m7<P2]AS40]e4m0;eF@`2]Ac40[DLc0:m8=02iDSl:0;]?=`03
0;iA>P2lD3P0^dlg00L0^dlg00<0_Tde0<AA>034DCP01P34DCP00`34D3L0ae@k0<IC>P080<AA>003
0<5==@3>ECX0cUDj00H0cUDj00<0cE@i0==I@@3BFCl02@3>ECX00`3<DSL0f5/m0=QK?@070=QK?@03
0=UL?`3HFcd0f5/m00T0f5/m00<0hEho0>AO@@3TGd401@3TGd400`3SGSl0hUdn0>AO@@090>AO@@03
0>eWB`3]HD80kF9300H0kF9300<0kVA60?1UA`3]HD80203]HT<00`3^Hd@0nVmD0?ITA0060?IUA@03
0?ITA03iJDX0nVY;00X0mVE500<0m6910?mXAP3oJ4H01`3oJ4H00`3oJTP0oVI20?mWA@070?mXAP03
0?mZB03oN5T0of]800L0of]800<0ofi<0?m`C`3oJTL0203oJdP00`3oIdD0ofe90?m]B@070?m]B@03
0?meD`3oLe40ofa800H0ofe900h0ofa80?mjFP3oLD`0og1:0?m_B03oMe@0ogUF0?m_B03oL4X0og==
0?meC`3oL4X0og1;0?m_BPD0og1;00@0ofm90?mmF`3oMU40og==103oM4d01P3oLDX0og9;0?mdC@3o
M4d0og=<0?mbB`L0ogA=00<0ogI>0?meCP3oMDh00P3oMDh00`3oN580ogMB0?meCP0:0?meCP060?md
C03oJCh0ofPm0?m[@P3oOED0og]B2P3oNe401P32Gch0000002081@3oH4l0ofIB0?mSD@80of5>2@3o
HTl00`3oHDd0ofAB0?mWE@0<0?mSD0050?mRCP3HA3L000000000002Z@3@00P3oIE401P3oI500of=?
0?mZF03oWI@0omkR0?oen9`0oooo3P0000040?ooo`<0000000<0oko60?ooo`3oool0103oool0103o
_lH000000000000000060?ooo`0308aaM@000000000000D0000000<09QXK0?oco01UADP00P000000
0`3o_lH0oooo0?ooo`020?ooo`040?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?oo
o`040?ooo`040?noaP0000000000000000H0oooo00<0oo?l02HJ6`000000200000000`1UADP0oooo
0?ooo`030?ooo`030?oioP1;=3H0000000T0000000<0/Z:T0?ooo`3oool00P3oool300000003081P
H`3oool0oooo00H0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0
oooo00D0omoS00000000000000000820P0050?ooo`030?o@f00I4A80000000H0000000<0Bc@f0;:L
XP0000000P0000000`3ogn<0oooo0?ooo`3F0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooO03oool01@3ognH0ojJU0>6:Q@1c<b@0McHX00D0N3LY00<0
N3HX08M2=@1h=bT03@1h=bT0101h=RP0N3LY07Pf:020>2P808<i:P0908<h:@22>BX0Qc`^08@j;021
>BX0R3h`084g:021>2T0OcDV00`0SC`/00P0T3h^08dm;@2=?2`0SC`/08`k:`2QBc`0XDPf09Q2;`T0
VT<`00<0WDDb09i7=@2J@c000`2J@c000`2MAC<0[E4o0:=5<0030:A6<P030:A5<@2QA300Y4Hb00<0
Y4Hb00<0Y4Da0:I7<`2TAS801@2TAS803P2TAC00/4Xd0:m8=02]Ac<0[TTc0:m8=02]Ac<0/ddi0;A=
>02/Ac40[DPb0;aF@P2hDSd0[4Hb0P2_BC<01@2]Ac<0[dPd0:m8=02_B3@0^E8o00T0^dlg00<0^Ddf
0<AH@@2mDCX0202kCcL00`2nCCD0a54h0<AA>0070<AA>0030<AA=`34DCP0a54h00L0a54h00<0`Dde
0<iE>P3>ECX01P3>ECX00`3?E3T0cE8h0<iF>`090<iE>P030<aB=`3HFcd0f5/m00L0f5/m00<0fE`n
0=QK?@3HFcd02@3HFcd00`3QGSl0i5m10>AO@@050>AO@@030>9O@@3TGd40i5m100T0i5m100<0kFM;
0>eQ@P3]HT<01P3]HT<00`3[Gcl0kF100>eR@`080>eR@`030>iSA03jKe@0mVA400H0mVE500@0m6A4
0?U[C03jK4d0mFE52@3fIDD00`3dHT40ofQ60?mXAP080?mXAP030?eVA03oIdD0ofQ600H0ofQ600<0
ofY80?mhF03oJdP01`3oJdP00`3oJdT0ofa:0?mZA`080?m[B0030?mWA@3oKDT0ofe900L0ofe900<0
og5@0?m`CP3oK4P01P3oKDT00`3oK4P0ogQH0?maC0020?m`B`0<0?m`BP3oL4/0og1:0?m_B@3oME40
ogYH0?m/A@3oKdP0ogA?0?mdD03oL4X0og1;0P3oL4X0103oKdX0ogMD0?meD03oLdd40?mdC@060?mc
C03oMDh0ogE>0?mdC@3oLd`0og9;1P3oM4d00`3oNED0og]E0?meCP040?meCP030?mcC03oMDh0ogE>
00P0ogE>00L0ogI?0?m[@P3oIS`0ofY10?miC`3oOEH0ogYB00X0og]A00X0e6=1000000000000oeQ6
0?mTD03oJ5H0oem;0?mWE03oHe00of5>1`3oHTl00`3oHDd0of=@0?mRCP0<0?mSD0050?mTD@2m?S<0
00000000002mAcT0103oIE401P3oI500of5;0?mNB03oZJ40onCY0?ogoYX0oooo3P0000040?ooo`<0
000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000050?ooo`030?oco00I4Q800000
0080000000L0RV1S0<V;T039Ri00Bc@f0000002`NGh0IDE80080000000<0oko60?ooo`3oool00P3o
ool0103o_lH000000000000000050?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH00000
0000000000060?ooo`0607iGFP00000000000000000b8b@0f9bR0P3o_lH01039Ri009QXK0000001U
ADP50?ooo`060;n[[@00000000000000000I4Q80/7Un0P3o_lH01@3TYJ/0Bc@f000000000000/Z:T
00@0oooo0`0000000`20H6<0oooo0?ooo`060?ooo`040?noaP0000000000000000D0oooo0`000000
0`3o_lH0oooo0?ooo`040?ooo`050?oOh`000000000000000020P800103oool00`3olo`0<R<T0000
00020000000404/d=P39Ri00bH^@04/d=P80000000D0RemS00000000000000000?oOh`3H0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooN03oool01`3o
l?<0omkP0>Vk_@31O7H0TT/o07He9`1a<B801`1h=bT00`1n>bd0Q40c07Pg:P0<07Pg:@0507Pg:P28
@SH0N3LY07Tg:022>BT01023>BX01@22>2T0Q3X[08Pm;`22>BT0Qc`^0080QS`]00L0Q3T[08Dk;025
>b`0PcTZ088i:P2=@380SCd]00/0SC`/00P0T3l_08dl;02=?2`0SC`/08`k:`2QBc`0XDPf09Q2;`T0
VT<`00<0WDDc0:18=P2J@c000`2J@c000`2MAC<0[E4o0:=5<0030:A6<P030:M8=02bDT40Y4Hb00<0
Y4Hb00<0Z4Xf0:A5<@2TAS800`2TAS803`2TAS40YdTd0:M8=02^AS80[dPd0;I@?02gDCd0[TPb0:i7
<`2bCCT0/ddh0:i8<`2^BC@0[dPd0:i8<`070:m8=0030;UB?`2kCcL0^dlg00P0^dlg00<0^Thf0;]?
=`2kCcL01`2kCcL00`2nCCD0a54h0<AA>0050<AA>0040<=A>039E3h0c5U20<=A>0P0a54h00<0`Dde
0<iE>P3>ECX01@3>ECX00`3?E3T0d5Pm0=AK@@0:0<iE>P030<aB=`3HFcd0f5/m00H0f5/m00<0fee0
0=YN@@3HFcd02P3HFcd00`3QGSl0i5m10>AO@@040>AO@@030>AO@03WHdD0hUm100X0i5m100<0kFM;
0>eQ@P3]HT<01@3]HT<00`3^I4D0lfU;0>]Q@@090>eR@`030>iSA03jKe@0mVA400P0mVE500<0mVA4
0?IUA@3fIDD0203fIDD00`3dHT40ofQ60?mXAP050?mXAP050?eXAP3oKD`0oV]:0?eVA03oIdD01`3o
J4H00`3oJdP0ogIH0?m[B0070?m[B0030?m^B`3oJTP0of]800P0of]800<0ofM50?m]B@3oKDT01P3o
KDT00`3oKDX0ofa80?m/B0080?m]B@030?m]B03oL4/0og1;00D0og1;0140og1:0?maC03oLD/0og1:
0?mcCP3oM500og1;0?m_BP3oME40ogMD0?m_B@3oKTL0ogI?0?mfD03oM4d0og==0?mcC0020?mdC@05
0?mjE@3oM4d0ogA=0?mcC03oLT/01@3oM4d00`3oLd`0og]H0?mlF0050?meCP030?miE03oMDh0ogE>
00H0ogE>00T0ogM?0?mdC@3oJd@0ofLn0?maA`3oMe00ogaB0?mjD03oNU402P3oNe403@3FID800@00
0000003oFDL0ofEB0?m[F@3oHDh0ofIC0?mRC`3oJEL0of5>0?mTD@3oHe40103oHTl0103oIe@0of=?
0?mWE@3oJ5@;0?mSD0050?mTD02=;bL000000000003FCSl01`3oIE401@3oHD`0og5O0?mjJ@3oZ:40
omGC09P0oooo0`0000000`1nEeX0/Z:T0;:RY0080;:RY0@0oooo0`0000000`3o_lH0oooo0?ooo`04
0?ooo`040?noaP0000000000000000D0oooo00D0LDiA000000000000F3do0>C5b0040?ooo`0309j1
Q00000003@T90080000000<0oko60?ooo`3oool00P3oool0103o_lH000000000000000050?ooo`<0
000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000050?ooo`0609MXK00000000000
03l/;@3;];H0ooWn103oool00`3oko40/Z:T0;:2Q`050?ooo`0504`d=P000000000003l/;@3UemX0
1@3oool00`3ogn<0/Z:T0=W1``040?ooo`<0000000<0P61S0?ooo`3oool01P3oool0103o_lH00000
0000000000050?ooo`<0000000<0oko60?ooo`3oool0103oool01@3ogn<00000000000000000P820
00@0oooo00D0LDiA000000000000;1lP0>C5b0040?ooo`030>C5b01H?Cl01`D500<0000000<0omoS
0?ooo`3oool0eP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooogH0oooo00H0ooOn0?Fj_02ZGeD0UTm206P[6`1e=2D907Pg:@0307Le9`2<A3P0Qd4e00d0
N3LY01L0MC@V07Le9`1g=RT0NSDW08@j:`23>BX0PSTZ084g:@27?2h0T4Dh08<j:`2<?c40PcT[084h
:@22>BX0PcTZ08@j:`26>bd0PSTZ08<i:P21>2T0VTXn08dm;@0:08dl;00308dj:`2C@340SC`/0080
SC`/00@0S3/[0:9<?@2QB3H0V48_202J@c000`2KA340WD@b09Q1;P0409Y3<00309e5<`2]DCl0XdD`
00<0Y4Hb00<0YdTe0;IFA02TAS400`2TAS803@2XC3L0XdDa0:A6<@2SAC40[e4o0:I8=02QA2h0YdTe
0:Q:=P2_Ac80[dPd0:e7<`2]B3<01@2_B3@00`2]B380_5I20;9;=P070:m8=0030;UB?`2kCcL0^dlg
00H0^dlg00@0^Ddf0<9H@@32F440^Thg202kCcL00`2nCCD0a54h0<AA>0050<AA>0030<9@=`31D3H0
a54h00T0a54h00<0`Dde0<iE>P3>ECX01`3>ECX00`3@ES/0cUDj0<iE>P080<iE>P030<aB=`3HFcd0
f5/m00D0f5/m00<0f5Xl0==G>@3GFcd02`3HFcd00`3QGSl0i5m10>AO@@040>AO@@030>AN?`3QG3d0
i5m100X0i5m100<0kFM;0>eQ@P3]HT<01@3]HT<00`3/HD40kF=40>eR@`090>eR@`030>iSA03jL5D0
mVA400H0mVE500<0n6Q:0?e]D03dHd<02P3fIDD00`3dHT40ofQ60?mXAP050?mXAP050?mWA@3mIT@0
ofQ60?iV@P3oIdD01`3oJ4H00`3oJTP0ogIH0?m[B0060?m[B0030?mZA`3oL4l0ofY700T0of]800<0
ofY70?m/B03oKDT01P3oKDT00`3oL4d0ogEC0?m/B0080?m]B@030?mZAP3oL4/0og1;00H0og1;00<0
ogEB0?m`BP3oL4/0103oL4/03@3oL4X0ofm:0?m`B`3oKTL0ogI@0?mgD@3oLT/0ogIA0?mnG03oMDh0
ogA=0?maBP3oMU000P3oM4d20?mbB`D0ogA=00<0ogYG0?mkEP3oMDh0103oMDh00`3oMTh0ogE>0?me
CP050?meCP060?mfC`3oL4X0of@m0?mR>P3oKTD0ogaB0`3oNe400`3oPE/0og]A0?mkD@080?mkD@07
0>IZA@0D1`@000000?mHAP3oHe00of1<0?mPC@020?mRC`090?mQCP3oHTl0ofEB0?mTD@3oJEL0ofQE
0?mPC@3oHTl0og5Q0080of=@00<0of9>0?mSD03oHe002@3oHe001@3oHdl0GAdG000000000000k5E5
00T0ofEA0P3oIe@00`3oJUL0oiB80?o5`P2F0?ooo`<0000000<0bH^@0?ooo`3oool0303oool30000
00030?noaP3oool0oooo00@0oooo00@0oko60000000000000000103oool01@3l[K@0000000000000
0000oo?l00D0oooo00<0ooWn0000000000000P0000000`3o_lH0oooo0?ooo`020?ooo`040?noaP00
00000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0
oooo00D0o:fd00000000000000000?oQjP0=0?ooo`050?b]]000000000000000003ohNX03@3oool3
00000003081PH`3oool0oooo00H0oooo00@0oko600000000000000001@3oool3000000030?noaP3o
ool0oooo00@0oooo00D0omoS00000000000000000820P0030?ooo`050?kFfP000000000000000020
NWh01P3oool00`3olo`0000000000002000000030?oOh`3oool0oooo0=H0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomd0?ooo`060?oho`3oinl0hXZ6
09I=@P1`<240LS8S301h=bT00`1g=BP0NCHY07Pg:@0<07Pg:@0<07hk;P1h=RP0McHY07Xe9`24>R/0
PCPY08]0<P20>2P0Q3X[08Lm;`22>BX0PCPY0`23>BX02021>2T0RCh`0996>@22>2T0PcTZ084h:@2I
BCd0SCd]2P2=?2`00`2<?2/0SC`[08dl;00308dl;00309U5=@2LAC<0VT<`00P0VT<`00<0Vd@b0:M?
?P2H@Bh0102J@c000`2MAC<0[E4o0:=5<0030:A6<P0<0:M9=@2fET@0Y4Ha0:=5<@2TAS80Xd@a0:I8
=02`DCl0Y4Lc0:54<02YBcP0YTLc0P2TAS400`2TA300/4Xd0:m8=0080:m8=0030:m9=02_B3@0[dPd
00H0[dPd00<0^E8o0;]?=`2kCcL04P2kCcL00`2nCCD0a54h0<AA>0050<AA>0030<EC>`3:Ed00`U0g
00T0a54h00<0`Dde0<iE>P3>ECX01@3>ECX00`3=E3T0c54f0<eD>@0:0<iE>P030<aB=`3HFcd0f5/m
00D0f5/m00<0fee00=mSB03GFcd02`3HFcd00`3QGSl0i5m10>AO@@040>AO@@030>MQ@`3VHdD0i5m1
00X0i5m100<0kFM;0>eQ@P3]HT<01@3]HT<00`3_IDD0kF520>eR@`090>eR@`030>eSA03dJdd0mVE5
00H0mVE500<0mVI60?IUA@3fI4@02P3fIDD00`3dHT40ofQ60?mXAP050?mXAP050?mZB03oJdX0ofM5
0?m/B`3oJDL01`3oJ4H00`3oJTP0ogIH0?m[B00C0?m[B0030?m/B03oKDT0ofe90100ofe900<0ofY6
0?m`B`3oL4/01`3oL4/00`3oKdX0og1;0?m`B`060?m`B`0:0?m_B@3oLT/0ogA=0?mdC@3oMTl0ogMB
0?mdC@3oMe40ogeJ0?mlF@80og=<0P3oLT/40?mdC@030?mcC03oNeP0ogaH00D0ogE>00<0ogM@0?mh
D@3oM4h01@3oMDh01@3oMDd0ofHn0?mS>`3oI3`0ogE=00@0og]A00<0ogQ@0?mgCP3oNe40203oNe40
203`KTP080/60000003oF4H0of=?0?mUDP3oJ5H0of5>1@3oHTl01@3oIU<0ofAA0?mQCP3oIeD0og1P
0080of=@00<0ofEC0?mSC`3oHe002@3oHe001@3oJUL0=a4>000000000000oE]900T0ofEA00L0ofIC
0?mWD`3oI4l0oee70?m_G@3oQWL0omKG09@0oooo0`0000000`39Ri00oooo0?ooo`0<0?ooo`<00000
00<0oko60?ooo`3oool0103oool0103o_lH000000000000000040?ooo`040;1iOP000000000007iG
FPL0oooo00D0OUMJ00000000000000000?noaP040?ooo`040?noaP0000000000000000D0oooo0`00
00000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00@0UfQ/000000000000
?b`]3P3oool0102GJ6`000000000001nEeX>0?ooo`<0000000<0P61S0?ooo`3oool01P3oool0103o
_lH000000000000000050?ooo`<0000000<0oko60?ooo`3oool0103oool01@3ogn<0000000000000
0000P82000<0oooo00D0f;bo00000000000000000;n[[@070?ooo`0503l/;@00000000000000003o
gn<0f03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
og<0oooo00H0onkb0=F0O02=ASX0NSPZ07dj;01g=RP;07Pg:@0407Ph:P1e<bH0MC<V07Dd9P`0N3LY
00P0McHX08a5>@1j>2X0MSHX07/f:02@@cD0PcX/08<i:`80PcTZ00<0PcPY08<i:P23>BX01023>BX0
1`24>b`0QS`^08<i:P23>BX0PCPY09U9?@2=?Bd02@2=?2`00`2<>b/0Td8b08ln;@0408dl;00308lm
;02H@Rl0VT<`00T0VT<`00<0W4Dc09Y3<02J@c000`2J@c000`2MAC<0[E4o0:=5<0020:A6<P090:A7
<`2WBCD0]5E30:M9=P2fET@0ZT/j0:54;`2ZBcP0YdPd00H0Y4Hb00<0Y4D`0;1:=02_B3@01`2_B3@2
0:e8<PP0[dPd00<0^E8o0;]?=`2kCcL01P2kCcL00`2iCCD0^4`d0;U==P090;]?=`030;i==@34DCP0
a54h00D0a54h00<0b5Dn0=5NAP32CcH02@34DCP00`31CCD0cUDj0<iE>P050<iE>P030=9I?@3GGdH0
cE@i00X0cUDj00<0c58g0=QK?@3HFcd01@3HFcd00`3IG400gf560=QK?@0:0=QK?@030=UL?`3UHTD0
i5m100D0i5m100<0iF530>MQ@`3TGd402P3TGd400`3[ITT0kF520>eR@`050>eR@`030?=XBP3[HD80
kF9300X0kF9300<0kF100?IUA@3fIDD01@3fIDD00`3cHD00m6A40?IUA@0:0?IUA@030?AR@@3oJ4H0
ofQ600@0ofQ600L0ofM50?m]C03oLE40oFI40?mcE@3oJdX0ofM500H0ofQ600<0ofY80?mfF03oJdP0
1P3oJdP00`3oJTL0ofU60?m[B00:0?m[B0030?m/B03oKDT0ofe900D0ofe900<0of]70?m/B03oKDT0
203oKDT00`3oJTH0og1;0?m`B`060?m`B`030?mcC@3oMU80og1:00P0og1;00l0og5:0?mdC@3oM4d0
ogA=0?mcC03oM4d0ogE>0?mfC`3oLT/0ogA<0?n3H03oN540og170?mdC@3oMDh00P3oM4d00`3oLd`0
og]H0?mlF0050?meCP030?miD`3oNUD0ogE>00@0ogE>00H0ogI?0?m]AP3oHSX0of@l0?maBP3oMdl4
0?mkD@030?mhD03oOED0og]A00P0og]A00P0kfe701h:1P000000oeM60?mSC`3oJ5D0of]J0?mQCPP0
of9?00H0of=@0?mYF03oJUL0of5=0?m[F03oHdl:0?mSD0050?m[FP0K2@L000000000003oGdd02P3o
IE40203oIE00ofIA0?mVD@3oI4h0oem:0?mbH03o_k`0omkQTP3oool3000000030<V;T03oool0oooo
00`0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00@0IDE8
000000000000bH^@1`3oool01@39Ri000000000000000000oko600@0oooo00@0oko6000000000000
00001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000000000000000103oool0100b
8b@000000000001aCU4>0?ooo`04038S9000000000000>:LXPh0oooo0`0000000`20H6<0oooo0?oo
o`060?ooo`040?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`050?oO
h`000000000000000020P8000`3oool01@2bXZ@00000000000000000i<G800L0oooo00D0IDI80000
0000000000000?oOh`3H0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0ooooK`3oool02P3onod0omCD0>Vj_02lO7H0SDLk07Th:P1f=RP0MC<V08@o<`1g=RP;
07Pg:@0407Lf:025@3<0Oc/^07Hd9`/0N3LY00L0NST[07@d9P1o>bl0NCLZ07/h;01h=2D0Q3X/00X0
PcTZ00<0QCX/08Tn;`21>2T00P23>BX00`21>2T0VDTm08dm;@0908dl;00308`k:`2E@S<0Sch^00@0
SC`/00<0Scd[09Q2;`2J@c00202J@c000`2MAC<0V48_09Y3<00209Y3<00?09Y2<02LA340WDHc0:U>
?02YBcL0[Dlk0:A5<@2/CCX0[Dll0;5A?`2TAS80YDLc0:A6<P2RA300YdTe00L0Y4Hb00<0Y4D`0;1:
=02_B3@01P2_B3@00`2]B3<0]Tlk0;A=>0080:m8=0030;UB?`2kCcL0^dlg00H0^dlg00<0_e8k0<5E
?P2iCCH02@2kCcL00`2nCCD0a54h0<AA>0050<AA>080`e0g2P34DCP00`31CCD0cUDj0<iE>P050<iE
>P030<mF>`3@Ecd0ceDj00X0cUDj00<0c58g0=QK?@3HFcd01@3HFcd00`3JG400eeXl0=QK?@0:0=QK
?@030=UL?`3XIDP0i5m100D0i5m100<0iF120>AO@@3TGd402P3TGd400`3[ITX0kF520>eR@`0B0>eR
@`030>eP?`3fIDD0mVE500@0mVE500<0mfI70?]]C`3eI4@02`3fIDD00`3eI4<0oVM50?mXAP060?mX
AP050?mYA`3nIdD0ogAF0?m[BP3oIdD01P3oJ4H00`3oJDL0og1@0?m[B0050?m[B0030?mZA`3oKdd0
ofe<00/0of]800<0of]70?m]B@3oKDT01@3oKDT00`3oLDl0ofa80?m]B@080?m]B@030?m[A`3oL4/0
og1;00H0og1;00<0og5<0?mbC@3oLD/0203oL4/00`3oLDX0ogA=0?mdC@050?mdC@0>0?meCP3oMe40
ogA=0?mgDP3oMU40ogI@0?mkEP3oLd`0og9;0?miD`3oNeL0ogI@0?mfC`3oMU040?meCP030?meC@3o
MDh0ogE>00<0ogE>00L0ofe60?mT?03oJT80og=<0?meCP3oNe@0ogY@00<0og]A00<0og]B0?mlE03o
NU00203oNe40103kLd/0=1@=0000002R<bT20?mRC`030?mQC@3oHTl0of9?00P0of9?00P0og5Q0?mS
D03oI500ofA@0?mXEP3oI580of=@0?mTD@L0of=@00D0ofMF0000000000003PD40?mTD@080?mUD@04
0?mTD03oJ5H0ogET0?mXE@D0ofIA00P0ofUF0?n;OP3o_kX0on[[0?oko`3oool0ooKi0?onoh/0oooo
0`0000000`39Ri00oooo0?ooo`0<0?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH00000
0000000000040?ooo`<0000000<0omWQ0?ooo`3oool01@3oool01@3od=P00000000000000000oko6
00@0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko6
00000000000000000`3oool01@3ok?000000000000000000P71b00d0oooo00D0omWQ000000000000
00000?oOh`0>0?ooo`<0000000<0P61S0?ooo`3oool01P3oool0103o_lH000000000000000050?oo
o`<0000000<0oko60?ooo`3oool0103oool01@3ogn<00000000000000000P82000<0oooo00D0P820
00000000000000000?o/l0070?ooo`05081XK000000000000000003ogn<0f03oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooofh0oooo00@0on3V0>B=R@1`
;b00KRlO0`1h=bT0101g=RP0Pcha08a5>@1g=RP;07Pg:@0407Lf:01b<bD0McHX07He9`L0N3LY00H0
N3HX07Xh:P1n>bd0N3LY07ll;`21?C0207Pg:@0307Lg:@1h=2H0Q3X[00X0PcTZ00<0QSX]0913=`21
>2T00P23>BX00`21>2T0UdXm08dm;@0908dl;00308ln;@2=?2`0SC`/00@0SC`/00<0Scd[09Q2;`2J
@c00202J@c002`2NAc@0V48_09Q2;`2NAS@0WDDb09Lo;@2QBCL0XdXi0:iB?`2Q@bl0XdDa0080Y4Hb
00L0YdTe0;IFA02TAS40Y4Hb0:A5<@2WB3@0Y4Lc00L0Y4Hb00<0Y4D`0;1:=02_B3@01P2_B3@00`2_
BC<0[DLa0:m9<`080:m8=0030;UB?`2kCcL0^dlg00H0^dlg00<0^4`d0;U==@2kCcL02@2kCcL00`2n
CCD0a54h0<AA>0040<AA>0030<IC>P3BGdP0`U0g00X0a54h00<0`Dde0<iE>P3>ECX01@3>ECX00`3D
Fd<0cUDj0<iE>P0:0<iE>P030<aB=`3HFcd0f5/m00@0f5/m00<0fE`o0>9UB`3FFS`02`3HFcd00`3I
G3l0j6E90>AO@@040>9M?P030>AP@P3/J4`0hUdn00@0hUdn00<0hUi00>9M?P3RGCh0103RGCh00`3[
I4T0jelo0>]O@0040>]O@0030>eR@`3`ITL0jem00080jf521P3[Gd00103[H400jf520>eR@`3]H3l6
0?IUA@030?ET@`3cHD00mVE500`0mVE500<0o6I40?mXAP3oJ4H00`3oJ4H01`3oJdT0og9A0?mWA@3n
IdD0ogAF0?m[BP3oIdD01`3oJ4H00`3oId@0of]80?m[B0040?m[B0030?mZA`3oJ4D0ofY700/0of]8
503oKDT00`3oKdX0og1;0?m`B`060?m`B`80ogIB00<0og1:0?m`B`3oL4/01@3oL4/00`3oLdd0ogE>
0?mdC@070?mdC@040?mcC03oNeL0og]H0?mcC0@0ogA=00D0og9:0?mdB`3oNE80ogYE0?mdC@020?mh
DP030?mdC@3oOET0ogQC0080ogE>00@0ogI>0?mW?`3oHCT0ofU10P3oMDh00`3oM4h0ogmI0?mhC`04
0?mkD@030?miD@3oO5<0og]A00L0og]A00P0ogE=03`G3`000000W38W0?mRC`3oHDh0ofQE0?mYE`T0
of9?00/0of]I0?mSD03oHe00ofMD0?mZE`3oHTh0ofAB0?mVD`3oIU@0ofAB0?mSC`040?mSD0040?iP
D0000000000003LB40X0ofEA00<0ofQE0?maG`3oIE001`3oIU401P3oHD`0of]H0?nTV`3obLX0PEUL
0?o3bX/0oooo0`0000000`39Ri00oooo0?ooo`0<0?ooo`<0000000<0oko60?ooo`3oool0103oool0
103o_lH000000000000000030?ooo`040?o@f00000000000000000T0oooo0`0000000`3o_lH0oooo
0?ooo`020?ooo`040?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`04
0?noaP0000000000000000<0oooo00D0o]KJ00000000000000000820P00=0?ooo`040?b]]0000000
0000000000l0oooo0`0000000`20H6<0oooo0?ooo`060?ooo`040?noaP0000000000000000D0oooo
0`0000000`3o_lH0oooo0?ooo`040?ooo`050?oOh`000000000000000020P8000`3oool01020J6`0
00000000000000080?ooo`050820P000000000000000003ogn<0f03oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooof/0oooo00D0ooko0?oJg`3nXJ00]VQP
074a8P0607Pg:@0307Pf:@28@SD0McHX00/0N3LY00@0NcT[07/f:P1h=bT0MSDW1@1h=bT03@1g=RP0
N3LY07ll;P1e=BL0PCd`07/i;01e=BL0S4@h07/i;01h=bT0N3LZ080j;024>BX02P23>BX00`20=bP0
PCPY08<i:P0208<i:P03084h:@2IBSd0SCd]00P0SC`/00<0S3XZ09a7>@2FA3@01@2=?2`00`2??B/0
V48_09Y3<00509Y3<00=09Q2;`2H@Bh0VT<`09U2<02RBCL0Uch]0:18=P2NAS@0V44_09Q2;`2MAC80
/EA10:=5<0030:A6<P070:M9=@2fET@0Y4Ha0:A6<P2SA300/eE20:I8=0070:A6<P030:A5<02`BS@0
[dPd00D0[dPd00@0[TPd0;E?>P2eCcX0[DPd202_B3@00`2iDSl0^dlg0;]?=`050;]?=`030;e@>032
ET00^dlf00X0^dlg00<0_Tde0<AA>034DCP01@34DCP00`38ECh0`U0g0<AA>0090<AA>0030<5==@3>
ECX0cUDj00@0cUDj00<0ceHk0=MNAP3?E3T02`3>ECX00`3<DSL0f5/m0=QK?@030=QK?@030=MJ?03F
FC/0eUTk00D0eUTk00D0eeXl0=QK?@3HFcd0f5/m0=MJ?0020=II>`040=QJ?03UHD@0iF530>aWB`<0
jfI:00<0j6A70>]XB`3/IdX0103[ITX00`3YITT0jfI:0>]VBP040>]VBP030>m[C`3dJdd0m6]=00D0
m6]=00@0mFa>0?A[C@3bJT`0m6U<1`3dJdd00`3bJD/0k6110>]N?@020?AS@`060?ESA03fIDD0mVE5
0?IUA@3gIDH0m6911P3dHd<00`3eI4@0mVI60?IUA@040?IUA@030?aVA03oJ4H0ofQ60080ofQ600P0
ofM60?mZB@3oLE00oFM50?iWA@3oM5H0of]:0?mWA@L0ofQ600<0ofM40?m[B03oJdP0103oJdP00`3o
JdT0ofe;0?m[B00:0?m[B0030?m/BP3oLDl0ofe900D0ofe900<0ofe:0?m]B@3oKDT02P3oKDT00`3o
KdX0og1;0?m`B`060?m`B`80ogA?1`3oL4/00`3oL4X0ogaJ0?meCP070?mdC@050?meCP3oLd`0og]G
0?mkF03oLd`0103oM4d0403oLT/0ogA<0?meCP3oMDh0ogI>0?mkE@3oO5D0ogE=0?mnFP3oMTh0ogA=
0?meCP3oJD40of4i0?mT?03oLT/20?meCP030?mdCP3oOeT0ogQ?00@0og]A00<0ogaB0?n1F`3oNe40
1`3oNe402@3oNE00B1dC0000001a8a`0of9?0?mQCP3oIE80ofIC0?mSC`080?mRC`050?mNBP3oHe00
of=@0?mTD@3oI5800`3oHe001@3oJEH0ofAB0?mTD03oIE80of=?0080of=@00@0jeI7000000000000
FA`F2@3oIE400`3oI500ofQF0?mbG`090?mVD@050?mWD`3oFD80oeI400000033QXX0R`3oool30000
00030<V;T03oool0oooo00`0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000
000000<0oooo00@0oko600000000000000002@3oool3000000030?noaP3oool0oooo0080oooo00@0
oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko6000000000000
00000`3oool01@3TaLP00000000000000000P61S00/0oko600<0ooWn0?ooo`39Ri000`00000;0?no
aP040?oco03oool0oooo0?ooo`<0000000<0P61S0?ooo`3oool01P3oool0103o_lH0000000000000
00050?ooo`<0000000<0oko60?ooo`3oool0103oool01@3ogn<00000000000000000P82000<0oooo
00@0P61S0000000000000000203oool01@20P8000000000000000000omoS0=P0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomZ0?ooo`050?oeo@3a[Zl0
[F5H06LX6@1];Ah01P1h=bT0101e=BL0L30Q08M1=@1g=RP:07Pg:@0507Pf:027@C@0Q3lb07Lf:01e
=BL0101h=bT01P1e=BL0P3/_07dj;01o>bh0MC<V07Lf:080N3LY00H0N3LZ07Pg:@1h=bT0O3T/08e4
>021=bP908<i:P0308@i:P26?2d0PCPY00<0PcTZ00<0PCPY09a;?P2>?Bd0202=?2`00`2>>b/0TSl_
090n;P0508dl;00308lm:`2H@Rl0VT<`00<0VT<`00L0V44^09U2;`2OAS@0YD`k09M1;P2PAcD0XDPf
0080V48_00H0VT8_09Y3<02J@c00WTHc0;5D@@2SAC030:A6<P070:M9=@2fET@0Y4Ha0:A6<P2SAC40
YTPd0:E7<P070:A6<P030:A5<02`BS@0[dPd00D0[dPd00@0[TPd0;E?>P2eCCT0[DLc202_B3@00`2i
DSl0^dlg0;]?=`050;]?=`030;e@>032ET00^Ddf00T0^dlg00<0^Thf0<5@=`34DCP01@34DCP00`34
DSP0`Tlf0<AA>00:0<AA>0030<5==@3>ECX0cUDj00@0cUDj00<0cE@i0<eC>@3>ECX01P3>ECX30<eC
>0050<iD>@3>ECX0c5<h0=II?03FFS`00`3FFC/01@3KGT80gEm40>9TB@3RID/0hVE:00<0hVE;00D0
g5m30=II>`3FFC/0eUTk0=IH>`020=II>`040=QJ?03UHD@0iF530>aWB`<0jfM:00<0k6I:0>QTA`3[
IdX0103[IdX00`3YI4P0jfM:0>]WBP040>]WBP030>mZC`3dK4d0m6]=00@0m6]=00D0lFM90?9XBP3d
Jdd0lVY<0?AZC0060?A[C@040?A/C@3bJD/0k6110>]N?@80m6=300D0m6920?AR@@3dHT40m6910?]/
C@030?e^D@060?e^D03mKU40oFiA0?e^D@3kK4h0lf500`3dHT420?IUA@030?aVA03nJ4H0oFI400<0
oFI400L0oFM50?mVA@3oJ4H0oVM50?mdEP3oJdX0ofM500L0ofQ600<0ofM40?m[B03oJdP0103oJdP0
0`3oKD`0ogEF0?m[B00:0?m[B0030?m/BP3oLU40ofe900@0ofe900<0ofa80?m_C@3oL4h02`3oKDT0
0`3oKdX0og1;0?m`B`060?m`B`030?m_B@3oKDH0og1900H0og1;00<0ofm:0?mnG03oMDh01`3oM4d0
103oN5<0og9;0?mkE@3oNeL50?mdC@030?mbB`3oM4`0ogE>00@0ogE>00D0ogI?0?mjE03oN540ogA=
0?m^B0020?mS>`030?m/A03oMTl0ogE>0080ogE>00<0ogaG0?miD03oNe40103oNe400`3oN4l0ogU@
0?mkD@060?mkD@090?n0E01O9QT0000003/A3@3oHTh0of9?0?mQCP3oGd/0of9>00P0of9?00H0of1<
0?mSD03oHe00of=@0?mPC03oHTh20?mSD080of=?00H0ofAB0?mTD@3oJUP0of=@0?mSC`3KCSh20000
000307/X803oIU80ofEA00P0ofEA00@0ofQF0?m`G@3oK5T0ofE@1P3oIU40203oIe80of1;0?mD?`3o
BcP04@D4090j?@3oeml0onohR@3oool3000000030<V;T03oool0oooo00`0oooo0`0000000`3o_lH0
oooo0?ooo`040?ooo`040?noaP0000000000000000<0oooo00@0oko600000000000000002@3oool3
000000030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool3000000030?noaP3o
ool0oooo00@0oooo00@0oko600000000000000000`3oool00`3TaLP000000000000=000000030?oO
h`3oool0bH^@00h0000000@0oko60?ooo`3oool0oooo0`0000000`20H6<0oooo0?ooo`060?ooo`04
0?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`050?oOh`0000000000
00000020P8000`3oool01020H6<000000000000000080?ooo`050820P000000000000000003ogn<0
f03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooofH0
oooo00L0oogo071?D@1hDE<0_h5o0:EICP1n>Rd0Lc<T00L0N3LY00D0McHX080l;`24?c<0QT4d07Lf
:00:07Pg:@0607Pf:@1g=BP0NCLY07Pg:@1f=BP0N3LY0P1k>B/0101l>R`0NSPZ07Th:P1j>2X407Pg
:@0707dj;01k>B/0N3LY07Pg:@1l>R`0SdDi084g:00908<i:P0308@j:`2;@C<0PSTZ00<0PcTZ00<0
PCPY09a;?P2>?Bd0202=?2`00`2@?bl0Scd]08`k:`0508dl;00=08lm:`2H@Rl0VD4_09m8=P2G@2h0
VT<`0:=;>@2J@S00W4Da09e5<P2J@c00WTHd09U3<00509Y3<00309i6<`2aE440XdD`00<0Y4Hb00H0
YdTe0;IFA02TAS40Y4Ha0:Y<>@2WB3@80:A6<P030:Q7=02`BS@0[dPd00D0[dPd00<0/4Te0;19=02^
B3<02@2_B3@00`2iDSl0^dlg0;]?=`050;]?=`030;eA>@2iCCH0^dlg00T0^dlg00<0^Thf0<AA>034
DCP01@34DCP00`3:Ecl0`e4h0<AA>00:0<AA>0040<5==@3>ECX0cUDj0<iE>P80cE@i00H0cUHk0=EM
A03DFT40e5]30=AK@P3>EC/20<eC>0090<iD>@3AF3h0eei60=IMA@3FGD@0eEa30<iD>@3>DcP0dU@h
00@0ee/m00D0fE`n0=mQA@3JGD40fUe10=YN@@030=YM@@040=UL?`3GFcd0ee/m0=MK?@<0f5/m00<0
fE`o0>QUB@3TGd40103SGT000`3ZIDT0hem10>=N@0040>=N@0030>=O@@3SGT00hei000@0hei000<0
jfI:0>aP@@3/HD80103/HD800`3cJD/0kF930>aQ@P020>aR@`L0k65200@0k6930>eR@`3]H400mFA4
0P3fIDD40?ETA0040?QWB03hJ4P0n6Q80?QWB0<0n6Q800<0n6M80?ETA03eI4@00P3eI4@20?ES@`0?
0?aU@@3oK4/0ofmA0?m_C`3oKe00og1A0?m]C03nIT<0oVM50?iXAP3oMEH0og5A0?i/C@3nKTh0ofY8
0080ofM40`3oJ4H00`3oId@0of]80?m[B0040?m[B0030?mZA`3oJdP0of]800X0of]800<0ofa:0?mb
D@3oKDT01@3oKDT00`3oKDX0ofm<0?m]B@0:0?m]B@030?maB`3oL4/0og1;00L0og1;00<0ogIA0?md
C`3oL4/01@3oL4/00`3oKdX0ogeK0?meCP070?mdC@050?meCP3oM4d0og]G0?mkF03oLd`01@3oM4d0
0`3oM4`0ogE>0?meCP050?meCP070?mhDP3oLTX0ofHn0?mW?`3oLTX0ogaG0?meC`020?mhDP030?me
CP3oOEP0ogU@00D0og]A00<0og]C0?mlE03oNe401P3oNe402@3oPED0H2PJ0000000m4Ph0of9>0?mR
C`3oHDh0ofQF0?mTD@080?mRC`070?mQC@3oHTh0of=@0?mSD03oJEP0ofQE0?mSC`050?mSD0040?mU
DP3oHe00ofAB0<E:?080000000<0[CX`0?mWE03oIE402@3oIE400`3oI500ofQD0?mVD@050?mVD@0;
0?mTC`3oFTD0oe@n0?mD?`3oE4407PT7084L703oGU`0ofIV0?nZ[@3oi>L0Q`3oool3000000030<V;
T03oool0oooo00`0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000<0
oooo00@0olS?00000000000000002@3oool3000000030?noaP3oool0oooo0080oooo00@0oko60000
0000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000000`3o
ool00`3TaLP000000000000=000000030?oOh`3oool0bH^@00h0000000@0oko60?ooo`3oool0oooo
0`0000000`20H6<0oooo0?ooo`060?ooo`040?noaP0000000000000000D0oooo0`0000000`3o_lH0
oooo0?ooo`040?ooo`050?oOh`000000000000000020P8000`3oool01020I6P00000000000000008
0?ooo`050820P000000000000000003ogn<0f03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooofD0oooo00H0ooSo0?no_P0@2@@050L2058O401];Ql:07Pg
:@0407De:01e<bH0PSha07Lf:0X0N3LY00P0O3T[084m<01g=RP0N3LZ07dj;01d<RD0N3LZ07Xh:PP0
N3LY00L0OCX]07/i:`1h=bT0N3LY07`j;02?ACT0PCLX00T0PcTZ00<0PSTY080g:023>BX00`23>BX0
0`21>2T0W4/n08hm;@0808dl;080UD<d00X0S3/[08dl;02=?2`0SC`/08lm;@2>?2`0WTLf09M1;P2G
@2h0Vd@a0P2J@c001P2J@Rl0VT<`09Y3<02J@c00UD0]09U2;`H0VT<`00<0WTHc0;5D@@2SAC000`2T
AS801P2WBSD0/eE20:A6<P2SAC40ZT/j0:M9=@P0Y4Hb00<0/4ll0:e7<`2_B3@01@2_B3@00`2bBcL0
^E<o0:e8<P090:m8=0030;UB?`2kCcL0^dlg00D0^dlg00<0_e<l0;]?=P2kCcL02@2kCcL00`2jCSH0
a54h0<AA>0050<AA>0050<9@=`34DCP0a54h0<AA>034DST00`35DST02P34DCP0`U0g0<1?=@32DCL0
e6190<eH@@3MHd`0e5e40<]B=`3=E3T30<iE>P040=1G?03@F3d0d5Ll0<mE>P<0cUDj00D0cU@j0<mD
>@3?E3T0ce@i0<mE>P020<iE>P030==F>@3HFcd0f5/m0080f5/m00<0eeXl0=II>`3HFcd0303HFcd0
0`3IG3l0j6E80>AO@@030>AO@@030>5M?P3RGT00i5m100`0i5m100<0jfI:0>eQ@P3]HT<00`3]HT<0
0`3]HD80jelo0>eR@`0=0>eR@`030?=R@@3fIDD0mVE500<0mVE500<0nFU:0?IUA@3fIDD0303fIDD0
0`3lIT@0ofM60?mWA@030?mWA@080?m[BP3oJ4H0ofQ60?iWA@3oM5H0ofa<0?mYA`3oJTP30?mXAP0;
0?iV@`3nIT80og5A0?mdEP3oMeH0og5?0?mV@P3oJDH0of]80?m^B`3oLe40303oJdP00`3oK4X0og9A
0?m]B@050?m]B@030?m_C03oKDT0ofe900X0ofe900<0ogEC0?m`B`3oL4/0203oL4/00`3oKdT0og1;
0?m`B`040?m`B`030?m_BP3oOE/0ogE>00L0ogA=00D0ogA?0?mkE`3oNeD0og]H0?mcC0050?mdC@03
0?mdC03oMDh0ogE>00@0ogE>00@0ogI?0?m/@`3oHSX0ofLo103oMDh20?mfC`050?mdC@3oOEL0ogaD
0?mgCP3oNe800`3oNe400`3oN500ogU@0?mkD@060?mkD@050?n0E02?>2@0000001<5103oHDh00P3o
HTl20?mQCPT0of9?00D0of5=0?mSD03oHe00of=?0?mRCP090?mSD0050:i0=000000000000=U7>P3o
I4l02@3oIE401@3oI500ofA?0?mXE03oJEH0ofA@0080ofIA00l0ofE@0?mMB03oE3h0oe<m0?mIA03o
I4l0of=?03`A3P1i7Qh0oeYH0?mBD03oDDl0oeYI0?moP03o`LH0Q@3oool3000000030<V;T03oool0
oooo00`0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo0`00
00000`3olo`0oooo0?ooo`050?ooo`050?oQjP00000000000000003o_lH0103oool0103o_lH00000
0000000000050?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000030?oo
o`050?oOh`000000000000000020P8001`3oool01`20P8000000000000000000omoS0?ooo`3o_lH0
0`0000080?ooo`<0000000@0oko60?ooo`3oool0oooo0`0000000`1nEeX0oooo0?ooo`060?ooo`04
0?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`050?oOh`0000000000
00000020P8000`3oool01@20P8000000000000000000ooWn00L0oooo00D0P75e0000000000000000
0?oOh`3H0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0
ooooH`3oool02@3ooOl0om7@0;ifIP1c?bL04PT402X@2@1W:AP0G2@E06`^800807Pg:@0407Pf:01e
=2L0N3LY07He9`/0N3LY00D0O3T/08<n<@1g=RP0OS/^07He:00;07Pg:@0707Le9`1h=RP0N3LY07Pg
:@1l>R`0SdDi084g:00908<i:P0308/o<@23>BX0PcTZ00<0PcTZ00<0PCPY09a;?P2>?Bd0202=?2`0
2@2;>RT0RcXZ08`k:`2@?Rh0S3XZ0991<@2KB3X0SC/[094n;00909Y3<0030:Y@?`2J@c00VT<`00D0
VT<`00<0WTHc0;5D@@2SAC000`2TAS801P2WBCD0]UI40:A6<@2TAC40XD<_0:=5<@P0Y4Hb00<0/4ll
0:e7<`2_B3@01@2_B3@00`2^B3<0[4Hb0:m8=0090:m8=0030;UB?`2kCcL0^dlg00D0^dlg00<0^4`d
0;]?=`2kCcL02@2kCcL01P2iCCD0a50g0<AA>034DCP0`e4h0<AB>@80ae@k00X0bELo0<9@=`34DCL0
`Dle0<MC>`3EHd`0dUm80=APB@34DcX0`U0f0`34DCP00`31CCD0cUDj0<iE>P040<iE>P030<eD>@3>
ECX0cUDj00`0cUDj00<0deHi0=QK?@3HFcd00P3HFcd00`3LGd80f5/o0=QK?@0<0=QK?@030=UL?`3X
IDP0i5m10080i5m100<0i5m00>aWB`3TH4803@3TGd400`3[ITX0kF520>eR@`030>eR@`030>]Q@P3]
HT<0kF9300d0kF9300<0lf910?IUA@3fIDD00`3fIDD00`3jJT/0mVE50?IUA@0;0?IUA@030?MVAP3o
JTX0ofQ600@0ofQ600L0ofM50?mXAP3oJ4H0oVM50?mdEP3oJdX0ofM500P0ofQ600X0of]70?m[B03o
JdP0ofY70?m/BP3oN5T0ogEF0?mhF@3oJdP0ofU60P3oJTL30?m]B`@0of]800<0ofa90?maD03oKDT0
103oKDT00`3oKT/0ogMG0?m]B@0;0?m]B@030?mfD`3oL4/0og1;00L0og1;00<0og1:0?mfDP3oLTd0
1@3oL4/00`3oKdX0ogeK0?meCP080?mdC@040?maB@3oNeL0og]H0?mcC0D0ogA=00<0ogE=0?meCP3o
MDh00`3oMDh01@3oMTl0of]30?mT?03iFcH0ofm700L0ogE>00T0ogI?0?miD03oMdl0oh1J0?mkD`3o
Ne80ogaC0?miD03oNe<01`3oNe401@3oP5@0U3XU0000000A10<0of5>00<0of9?00<0ofEB0?mRC`3o
HTl01`3oHTl01P3oHTh0of=@0?mSD03oHe00ofID0?mTDPP0of=@00D0VcX_000000000000nU110?m]
F`0:0?mUD@0@0?mTC`3oJED0of]H0?mUD03oIU40ofA?0?mF@@3oE3h0oe<m0?mIA03oIE00ofMC0?mS
C`0o4Ph0MQlM0?mIE`80oe9@0P3oDDl00`3oDTl0ojZ^0?oko`230?ooo`<0000000<0<R<T06E5B01U
ADP01P1UADP00`2`NGh0oooo0?ooo`030?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH0
00000000000000040?ooo`<0000000<0oko60?ooo`3oool01@3oool01@3o_lH00000000000000000
oko600@0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0
oko600000000000000000`3oool01@3ogn<00000000000000000P82000L0oooo00@0P82000000000
000000000P3oool0103o_lH000000000000000080?ooo`<00000103oool30000000306E6B03oool0
oooo00H0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00D0
omoS00000000000000000820P0030?ooo`050820P000000000000000003ogn<01`3oool01@20H6<0
0000000000000000omoS0=P0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooomR0?ooo`0=0?ogo@3c[JH0N44W07E09P1c?bH04PT403<E3`1d<200GRDF05lV
5`1`<B80McHX07Xh:P0507Pg:@0407dj;@28@CH0McHX07Hd9`P0N3LY00P0N3HX07Lf:01h=bT0NCLY
07Xg:@1j=bX0N3LY07Dd9PX0N3LY00<0N3HX07`i;@1h=bT00P1h=bT00`1l>R`0SdDi084g:00908<i
:P0308Pn<023>BX0PcTZ00<0PcTZ00<0PcLY0913=02>?Bd01P2=?2`0302<>b/0SS`/08lm;@2>?Rd0
R3LW09U6=`2;>RX0SC`/08hk:`2;?2/0TSh/09]3<0P0VT<`00<0XDPf09Y3<02J@c001@2J@c000`2N
AS<0/EA10:=5<0030:A6<P050:M9=@2fET@0Y4Ha0:U;=`2WBCD02@2TAS800`2`Cc`0[DLc0:m8=00A
0:m8=0030;UB?`2kCcL0^dlg00D0^dlg00<0^dlh0;]?=`2kCcL0102kCcL05@2iCCH0^Thf0;]?=`2i
CCH0^dlg0;iB>`38ESl0aE<j0<9@=`32CcH0ae@k0=9OB03DGdP0d5a50<5?=@31D3H0a58h0<A@>032
D3L0a50g0<9@=`050<AA>0030<5==@3>ECX0cUDj00<0cUDj00<0ce@i0=AK@@3>ECX03@3>ECX00`3C
EST0f5/m0=QK?@020=QK?@030=]N@@3IG3l0f5/m00`0f5/m00<0fE`o0>QUB03TGd400P3TGd400`3T
Gd00jfM:0>EP@P0=0>AO@@030>aVB`3]HD80kF930080kF9300<0kF520?M]D03^Hd@03P3]HT<00`3c
HT40mVE50?IUA@020?IUA@030?AR@`3eHd<0mVE500`0mVE500<0nFQ90?mcE`3oJ4D00`3oJ4H0203o
KD`0ofQ60?mXAP3oJ4H0oVM50?mdEP3oJdX0ofM5203oJ4H00`3oJdL0of]80?m[B0020?m[B00C0?mY
AP3oKDX0ofY70?m[B03oJTL0ofU60?mWA@3oMeP0ogEF0?mgE`3oK4X0ofU60?mZA`3oK4X0og1>0?mc
DP3oKDT0ofa80?m]B@020?m/B0030?m]B@3oLDh0ofe900/0ofe900<0ogIC0?m`B`3oL4/01`3oL4/0
0`3oL4X0og=?0?m`B`050?m`B`030?m_BP3oOU`0ogE>00P0ogA=00<0ogI?0?mjE`3oMe401@3oM4d0
0`3oLd`0og]E0?mgDP030?meCP050?mfC`3oLT/0of<l0?mR>P3oJ4002@3oMDh30?mkD@060?mjD03o
OED0oh1K0?mhC@3oOeP0ogQ@0P3oNE040?mkD@050?n0E02H?2H00P0000`20P3oHDh00P3oHTl00`3o
HDd0ofYH0?mQCP070?mRC`070?mTD@3oJeT0of=@0?mSD03oHdl0ofiL0?mWE@080?mSD00708df:`00
000000000?mIA`3oJeP0ofA?0?mXE@020?mWE0030?mTD03oIE40ofEA00<0ofEA0140ofA@0?mUD@3o
IU40ofMC0?mUD03oFTD0oe<m0?mD?P3oEd80ofE@0?mVD@3oIE40of=?04hG4P1;4A40odU80?mED`04
0?mBD0040?m@C`3oXZH0ol[@0?ogoh40oooo300000000`1UADP0oooo0?ooo`030?ooo`<0000000<0
hYbR0?ooo`3oool0103oool0103o_lH000000000000000040?ooo`0406E5B000000000000<V;T0L0
oooo00D0bH^@00000000000000000?noaP040?ooo`040?noaP0000000000000000D0oooo0`000000
0`3RW:80oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo0`0000000`20J6`0oooo0?oo
o`050?ooo`04081XK00000000000000000<0oooo0`0000000`3od=P0oooo0?ooo`040?ooo`040?o@
f00000000000000000@0oooo0`0000000`0o;2d0oooo0?ooo`060?ooo`040?noaP00000000000000
00D0oooo0`0000000`3RW:80oooo0?ooo`040?ooo`050?oOh`000000000000000020P8000`3oool0
1@2bXZ@00000000000000000i<G800L0oooo00D0IDI800000000000000000?oOh`3H0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooG`3oool04@3oknl0
l<K30<B6N02WIE40MD0V07U3:@1kA2X0LclV01<:100f6180QCh^07@d9P1V:a`0G2@E068X6@1/;b00
N3LX00@0N3LY00@0N3HY07Xh:`1i>2X0MS@W1P1h=bT01`1g=RP0NcP[07dj;@1l>B`0N3LY084l;`1g
=RP00P1h=bT00`21?C00N3LY07Pg:@0807Pg:@0307Pf:020?2l0N3HX0080N3LY00<0O3X/08m4>021
=bP02@23>BX00`22>2T0PcTZ08<i:P0408<i:P0308Hj:@2=?2`0SC`/0080SC/[00L0TCl_08`l;02?
?bh0Ud@e08lm;@2GA3@0SCd/00D0SC`/00<0Rc`[098n;02K@c001`2J@c000`2JA340V44_09Y3<006
09Y3<00309i6<`2aE440XdD`00<0Y4Hb00D0YdTe0;IFA02SAC40YdXg0:M9=@090:A6<P030;1??02]
Ac<0[dPd00D0[dPd00<0]4hi0:e7<`2_B3@02@2_B3@00`2iDSh0^dlg0;]?=`020;]?=`0C0;Y>=P2j
CSL0^dlg0;iB>`2nDC/0_e<l0;mB?02kCcL0^Dde0;a@>@34Ed80`UE00;M<=02jCSD0^Thg0;iB>`3:
Ecl0aU4j0<=@=`020<AA>0030<=A>033D3P0a58i00`0a54h00<0`Dde0<iE>P3>ECX00`3>ECX00`3=
DSP0ceHk0<iE>P0=0<iE>P060==F>@3HFcd0f5/m0=QK?@3GFcd0fUe03P3HFcd00`3IG3l0j6E80>AO
@@020>AO@@030>AP@@3SGSl0i5m100d0i5m100<0iV530>eR@`3]HT<00P3]HT<00`3]HD80kV930>eS
A00>0>eR@`030?=R@@3fIDD0mVE50080mVE500<0nVY;0?IVAP3fIDD0303fIDD00`3iJ4T0og=F0?mX
A@030?mXAP080?mYAP3oJ4H0ofQ60?mXAP3nIdD0og=E0?m[BP3oIdD80?mXAP060?m[A`3oJdP0of]8
0?m[B03oJdT0og1?2`3oJdP0303oJTL0ofa:0?m`D03oM5<0ofe90?m/B03oJdL0og=@0?mcDP3oL4d0
of]70?m]B@80og1=00H0ofm<0?m]B@3oKDT0ofe90?m/B03oK4T30?m]B@030?mfD`3oL4/0og1;00P0
og1;00<0og1:0?mdCP3oL4/01@3oL4/00`3oLdd0ogA=0?mdC@070?mdC@030?mgD03oMDl0og9:00D0
ogA=00<0og9;0?mnF`3oNUD00P3oMDh01`3oMTl0og9;0?mV?P3oISd0ofm80?mdCP3oMe40203oMDh0
103oNU40og]A0?mkD@3oNe420?mjD@0>0?mkD@3oNe80ogUA0?mlDP3oP5T0ogU@0?mlE03oO580ogU@
0?mnD`38CS<04PL40000003oHDh30?mRC`030?mRD03oHTl0of9?00H0of9?00<0of=A0?maH@3oHdl0
0P3oHe020?mTD@P0of=@00H0P2hU0000000>10<0ofA@0?mUD@3oIU820?mUD@030?mWE03oIe<0ofQF
0080ofIB0P3oIE402P3oIe@0ofUD0?mTD03oGDT0oeI00?mD?`3oFdD0of9>0?mVD@3oIe830?mVD@04
06DO600[2``0nd510?mFE0D0oe9@00H0oda:0?mEE03oLG80ojjb0?oTi`3onOen0?ooo``0000000<0
IDE80?ooo`3oool00`3oool30000000306E5B03oo?l0oooo00@0oooo00@0bH^@0000000000009QXK
103oool01@3FTiT000000000000o;2d0ooWn00D0oooo00<0ooco03l/;@0000000P0000000`3o_lH0
oooo0?ooo`020?ooo`040?noaP0000000000000000D0oooo0`0000000`1UADP0ooWn0?ooo`040?oo
o`040<V;T0000000000001<=3P@0oooo00@0UfQ/000000000000F3do1`3oool0101[BTd000000000
002GJ6`30?ooo`0409MXK000000000000;1jOPH0oooo00@0eY>I000000000000C3@f103oool40000
00030=Rf_@3oool0oooo00D0oooo00@0oko600000000000000001@3oool30000000306E5B03onOh0
oooo00@0oooo00D0i<G8000000000000000009>=S@030?ooo`050>_9c000000000000000002OTiH0
1P3oool00`3onOh081HG00000002000000030?oOh`3oool0oooo0=H0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomM0?ooo`060?omo`3oe=H0]G1N06<a
5@1e@2H0Nd@Z0P1i@bT04`1kA2X0L3hU00X60P0f61<0Q3d]07Pg:@1i=bT0JbhO05lV5`1K8a@0IBTJ
07Lf:01j>2X0N3LY07Tg:@1k>2/0N3LY07Lf:01g=BL00`1h=bT03@1g=RP0NSP[080l;`1g=RP0OCX]
07Lf:01h=RP0N3LY07ll;`1g=RP0N3LY07Lf:025@3@02P1h=bT00`1e<bH0MC@V07Pg:@0207Pg:@03
07`j;02@ACT0PCLX00P0PcTZ00<0PCPY08e2=023>BX01@23>BX02`26>RT0S3/[08lo;P2KBCX0SC`/
0990<02<?B`0SS/[08`k:`2=?2`0S3/[00H0SC`/00<0Rc`[098n;02K@c001P2J@c000`2H@Rl0ZU50
09]4<@0709Y3<00309i6<`2aE440XdD`00<0Y4Hb00D0YdTe0;IFA02TAc<0Y4Lc0:=5<@090:A6<P03
0;1??02]Ac<0[dPd00@0[dPd00<0[dTc0:]6<@2_B3@02P2_B3@03@2jDCd0^Dde0;]?=`2iCCH0_e<l
0<IIA@34Ed40^Dde0;Q==031E3h0a5M10<9E?`2jCSH00P2kCcL00`2iCCD0^Ddf0;]?>0020;]?=`03
0;Y>=P34DCP0a54h00<0a54h00<0`U0g0=APB@35DST03034DCP00`31CCD0cUDj0<iE>P020<iE>P03
0<eD>@3DFd80ceHk00h0cUDj00H0deHi0=QK?@3HFcd0f5/m0=QJ?03NHDD>0=QK?@030=UL?`3XIDP0
i5m10080i5m100<0j6A60>EQ@`3TGd403@3TGd401`3SGT00kF930>eR@`3]HT<0k6930?A[C@3^I4D0
3`3]HT<01P3cHT40mVE50?IUA@3fIDD0m6E50?ITAPh0mVE500<0nFQ90?mcEP3oJ4D00`3oJ4H00`3o
JTT0ofQ60?mXAP020?mXAP030?mZA`3oJ4H0ofQ600L0ofQ600<0ofI50?mXA@3oJdP00P3oJdP00`3o
JdT0og9@0?m[B00<0?m[B0030?m/BP3oLe40ofe90080ofe900D0ofa80?m/B@3oN5P0ofe90?m/B@02
0?mcD@070?maC`3oK4P0ofa80?mcD@3oMeL0og=B0?mZAP020?m]B@030?mdDP3oL4/0og1;00T0og1;
00<0og5<0?m`B`3oL4/0103oL4/00`3oKdP0ogA=0?mdC@0?0?mdC@0<0?maB`3oO5T0ogUD0?meCP3o
MTl0og190?mS>`3oI3`0og=<0?mfC`3oMDh0ogI>1`3oMDh00`3oMTh0ogM?0?mkD@050?mkD@0=0?ml
D`3oOUP0ogY@0?miD03oNU40ogiF0?mkDP3oN500oh=J09@k9@040@400P000?mTD@030?mRC`030?mW
E@3oIU<0of9?00H0of9?00<0of=A0?m^G@3oHdl00P3oHe000`3oHdl0ofiM0?mTDP070?mSD00607/V
7`000000>14=0?mUD@3oJeP0ofQE103oIE40303oI500ofEA0?mVDP3oKU/0of9=0?m/FP3oIE40oe0l
0?mA?03oDSd0oem:0?mXE0D0ofIA00D0ofUD080Z8@060P40d3<b0?mHEP080?mBD0040?m;B@3oHV00
oh230?oPigd0oooo0`0000000`39Ri00oooo0?ooo`0<0?ooo`@0000000<0i<G80?ooo`3oool00P3o
ool01@3olo`06A4B000000000000OUMJ00D0oooo00@0<R<T000000000000/7Un1@3oool00`3H_;l0
000000000002000000030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool40000
00030<V;T03oool0oooo0080oooo00D0ooWn01TA4P000000000003l/;@040?ooo`050?oco0000000
00000000003o_lH01@3oool01@3olo`03@T9000000000000on7Z00<0oooo00D0oo?l000000000000
00000?noaP040?ooo`050?oioP0I4A80000000000020LGD0103oool5000000030>:LXP3oool0oooo
00@0oooo00@0oko600000000000000001@3oool4000000030<V;T03oool0oooo00<0oooo00D0S8:7
00000000000000000;n[[@040?ooo`04038S90000000000005Pm?`H0oooo00<0/7Un000000000000
0P0000000`3ogn<0oooo0?ooo`3F0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0ooooF`3oool01@3on_d0omcM0<^0L@2LGDP0LCdR00D0ND<Y00D0Nd@Z06lm
9@061040>A/C08@m;@0307Pg:@05074a8`1U:1T0GB<E06DX6P1d=2H00P1j>2X0102<ACT0McHX07De
9`1g=RP207Pg:@0507Pf:01n>Bd0NSLZ07/i;01j>2X00`1h=bT01P1h=RP0MSDW07Pg:@1h=bT0McHX
08E0=0T0N3LY00<0McDW084m<01l>B`00`1h=bT00`1l>R`0T4Di084g:00908<i:P0308@j:`23>BX0
PcTZ0080PcTZ00P0PcPY080h:@2<?B`0TT0`08lm;@2C@S80Scd]08`k:`80SC`/00<0S3/[09I4=@2<
>b/01P2=?2`00`2;?2/0TSh/09]3<00609Y3<00309Q1;`2J@Bl0VT<`00L0VT<`00<0WTHc0;5D@@2S
AC000`2TAS801@2WBCD0]UI40:M9=P2^Ccd0XdD`00T0Y4Hb00<0/4ll0:e7<`2_B3@0102_B3@00`2b
BSH0/T`h0:m8=0060:m8=00=0:i8=02_BC<0[dTd0:a5<@2mET40b5Y60;iA>P2fBc<0_50j0<5D?P2o
DS/0aUY40;]?=`030;U==PP0^dlg00<0^Thf0<AA>034DCP00`34DCP00`34DSP0aE<j0<AB>@0<0<AA
>0030<5==@3>ECX0cUDj0080cUDj00<0ce@i0=MMA@3@Ec`03P3>ECX01@3CEST0f5/m0=QK?@3HFcd0
eUXl00l0f5/m00<0fE`o0>QUB03TGd400P3TGd400`3RGT00i5m10>AO@@0=0>AO@@030>=N@03]HT<0
kF930080kF9300<0m6]=0>iTA@3]HT<03P3]HT<01P3cHD00mVE50?IUA@3fIDD0lf910?AR@@h0mVE5
00<0nFQ90?mcEP3oJ4D00P3oJ4H00`3oIdD0ofm?0?mXAP030?mXAP030?iV@P3oIdD0ofQ600H0ofQ6
00<0ofI50?m/B@3oKdd00`3oJdP20?mZA`d0of]800<0of]90?maC`3oKDT01`3oKDT30?m/B00=0?m]
B@3oK4P0og1=0?m`C`3oKdd0of]70?mZAP3oKd/0ogaJ0?mcCP3oKdT0og1;0?m`BP0>0?m`B`030?m_
B03oM4d0ogA=00P0ogA=00<0ogE?0?meCP3oM4d0103oM4d02@3oLT/0ogaI0?miE03oMDh0og190?mU
?@3oHCT0ofi60?mfC`020?meCP030?mhD03oMDh0ogE>00D0ogE>00<0ogI>0?mgC`3oNe401@3oNe40
0`3oO580ogQ@0?mhD0020?mkD@80ogU@00H0og]A0?mnE@3=DC805`P400000036B3X30?mRC`030?mU
DP3oHe40of9?00H0of9?00<0of=A0?m`GP3oHdl00`3oHe000`3oJUL0ofAA0?mSD0060?mSD00506XQ
6`000000FA`F0?mUD@3oIU801`3oIE402@3oI500ofQF0?mTD03oI540oeE10?mD?P3oECh0of1;0?mV
DP060?mVD@050?mXE020;2<01P000=0`;`3oEU@02@3oDU00103oCD`0oe5?0?m]K@3obM1l0?ooo`<0
000000<0bH^@0?ooo`3oool0303oool40000000606E6B03oool0oooo0?ooo`3onOh0UfQ/0`000000
0`3RW:80oooo0?ooo`030?ooo`050<V;T0000000000000000039Ri00103oool00`1UATP000000000
0002000000030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool5000000050>C5
b03oool0oooo0?ooo`3;[[@00`0000000`1aCU40oooo0?ooo`030?ooo`050<V;T0000000000004/d
=P3olo`0103oool0101nEeX000000000001nEeX50?ooo`0506E6B0000000000004/d=P3onOh00`3o
ool01@2oZjd00000000000000000_j^]00@0oooo0`0000001`0=2@T0000000000039Ri00oo3e0?oo
o`3olo`00P3oool0103o_lH000000000000000050?ooo`D0000000H0bH^@0?ooo`3oool0oooo0?oc
o01<=3H3000000030?7>d@3oool0oooo0080oooo00D0bH^@00000000000000000<V;T0040?ooo`03
0<V;T0000000000000<0000000<0omoS0?ooo`3oool0eP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooeX0oooo00D0oo7g0>Fc[@2DEcl0LchT078n8P06
07U3:@0507]4:@1Z>R401`@103TK4`24?Bd00`1h=bT02P1j>2X0McDW06@Y6P1L91D0HBLH06`]7`1i
=RT0OSX]07Pg:@1e=BL207Lf:00307/g:P23?c40NCLY00H0N3LY00H0NcPZ07`i:`1h=bT0N3LY07Lf
:025@3@907Pg:@0307Lf:023?C40OCX]00<0N3LY00<0O3X/0915>@21=bP02023>BX00`20>2P0PSTY
08<i:P0208<i:P0708@j:`2=@C<0PcXZ08Hj:P2>?Bd0SC`/08`k:`0508dl;00309=2<`2<>b/0SC`/
00D0SC`/00<0Rc`[098n;02K@c001P2J@c000`2E@2d0Ud4^09Y3<00709Y3<00309i6<`2aE440XdD`
00<0Y4Hb00@0YdTe0;IFA02SAC40Y4Da2P2TAS800`2`Cc`0[DLc0:m8=0040:m8=0030;1:=P2eCcX0
[dPd00@0[dPd00/0[dTc0:a7<@2lE440^E8n0:a7<@2]AS80_5@o0;iB>`2kCcP0^dlf0;]?=`020;U=
=P030;mC?@2kCcL0^dlg00X0^dlg00<0^Thf0<AA>034DCP00`34DCP00`31CCD0`Tlf0<AA>00<0<AA
>0030<5==@3>ECX0cUDj0080cUDj0P3=E3T?0<iE>P060==F>@3HFcd0f5/m0=IJ?03LGT<0f5/n3P3H
Fcd00`3IG3l0j6E80>AO@@020>AO@@030>AP@P3TGd40i5m100d0i5m100H0hei00>eR@`3]HT<0kF93
0>aR@`3[H40?0>eR@`070>iTA@3fJDX0mVA40?IUA@3dI4@0oFe?0?MWA`0>0?IUA@030?UXB@3oLeH0
ofQ500P0ofQ600<0oFI40?mWA@3oJ4H01P3oJ4H00`3oITD0ofe:0?m`D0030?m[B0030?m]B`3oJdP0
of]800d0of]800<0ofa90?m]B@3oKDT00P3oKDT00`3oJT@0ofa80?m]B@060?m]B@80ofa80P3oKDT0
2@3oK4P0ofe90?mfE03oLD`0ofm80?maC03oOE/0og1;0?m`B@050?m`B`030?meD@3oLD`0og1;00@0
og1;00<0ofm90?mcC03oM4d0203oM4d00`3oLd`0og590?mcC0040?mdC@070?mbB`3oOEX0ogYE0?mc
C03oI3`0of8j0?mV?P040?meCP030?mjEP3oMDh0ogE>00H0ogE>00<0ogM>0?mlDP3oNe40103oNe40
0`3oNU40ogUA0?mkDP050?mkD@070?mlDP3oIT009`h800000039CT00of9?0?mQCP020?mRC`030?mP
C03oHTl0of9?00D0of9?00<0of=A0?m`H03oHdl00`3oHe000`3oHTh0of9?0?mSD0060?mSD00605`M
5`000000NbLO0?mUD@3oIE00of=>1`3oIE401@3oI500oeY60?mA?@3oCc/0oeI10080ofQD1`3oIU40
1@3oJE@0PbdT0080002b<c<0oemN00T0oe9@00H0oe=A0?mHEP3oBDP0oemN0?o8c`3ol_Yj0?ooo`<0
000000<0bH^@0?ooo`3oool0303oool3000000060;1iOP0000006A4B09MXK039Ri00IDI80`000000
0`0=2@T0oo?l0?ooo`050?ooo`0502HJ6`00000000000000002:H6<00P39Ri00101;=3H0000006E5
B01UADP2000000030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool300000007
0;1iOP0000003@T909MXK039Ri00UfQ/01TB4P030000000308b2Q`3oool0oooo00<0oooo00T0oo?l
04/d=P000000000001TA4P39Ri00oko60>:LXP0b8b@00P0000000`0I4A80on7Z0?ooo`040?ooo`05
0:FDV@00000000000000001aCU400P3o_lH01P3RW:806A8B0000000000006A4B0?o`m@@0oooo0`00
00000`1UATP0000000000003000000040?noaP3oool0oooo0?noaP<000001@3oool3000000070;1i
OP000000000005Pm?`39Ri00UfQ/038S90030000000301TA4P3onOh0oooo00@0oooo00D0Bc@f0000
00000000000004/d=P020<V;T00404/d=P000000000006E5B0<0000000<0omoS0?ooo`3oool0eP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooeL0oooo
00H0ooSj0>Rm^@2jTXL0Xf=?07a5;01g@BL807U3:@0507a5:`1mB3801`<103TK4`24?Bd01@1h=bT0
301h=RP0K2hP068X6@1N9AH0IBXL07@d9P1h=BP0NCDX07Xg:P1k>2/0N3LY07Th:PL0N3LY00H0NSP[
07dj;@1h=bT0N3LY07Lf:024@3<:07Pg:@0307He9`1h=bT0N3LY0080N3LY00<0O3X/0915>@21=bP0
1`23>BX02P24>R/0S40b08Pn<023>BX0Pc/[08]0<P22>BX0Q3X[08<i:P26>RT708dl;00308dm;@2?
?Bd0SC`/00H0SC`/00<0Rc`[098n;02K@c001@2J@c000`2I@c00Y4/j09e5<P0809Y3<00309e5<P2[
Cc`0Y4Ha00<0Y4Hb00@0YdTe0;EFA02VB3D0Y4Ha2P2TAS80402`Cc`0[DLc0:m8=02`BCD0/DXf0:m8
=02^B3<0/4Xe0;MA?@2aBCD0[DLa0:i7<`2fD3`0/d`h0:i7<P2_BC@20;19=@80[dPd00<0^e<o0;]?
=`2kCcL00P2kCcL00`2jCSL0`5@m0;]?=`0<0;]?=`030;Y>=P34DCP0a54h0080a54h00<0`Tlg0<iK
A037E3/03@34DCP02031CCD0cUDj0<iE>P3>ECX0cU@i0=AL@P3AF3d0ceDj3P3>ECX01P3CEST0f5/m
0=QK?@3GFS`0gF150=YL?`h0f5/m00L0fE`o0>MTA`3TGd40i5m10>=M?`3WHdH0i5m000h0i5m100H0
hei00>eR@`3]HT<0kF930>mUAP3_I4H?0>eR@`070?1UAP3mLE@0m6A40?IUA@3eI4@0mfM80?MUAP0>
0?IUA@030?QXB@3oLeD0ofQ60080ofQ600<0oVa;0?mXA`3oJ4H00`3oJ4H00`3mIT@0ofM50?mXAP06
0?mXAP030?mVA@3oKDX0og1?00<0of]800<0ofi<0?m[B@3oJdP03P3oJdP40?m]B@030?mgEP3oKTX0
ofe900`0ofe900h0ogAA0?m`B`3oL4/0og1;0?maC03oL4/0og1:0?maB`3oMU80og1:0?m_B@3oLdh0
ogIB0?m`B@80og1;00D0og5=0?maC03oL4/0og1;0?mcC00:0?mdC@030?mgD03oMDh0ogA=00<0ogA=
00P0og9;0?mmFP3oN5<0ofQ00?mT?03oJd@0ogA=0?mfC`/0ogE>00<0ogQA0?n4GP3oNDl01P3oNe40
0`3oO5@0og]B0?mjD@040?mkD@0<0?mlDP3oJT@0:Q0:0000003>BS`0of5>0?mTD@3oIeD0ofAA0?m[
F@3oHe00ofAA1@3oHTl00`3oHe00ofAB0?mSD0040?mSD0030?mXE@3oHe00of=@00D0of=@00<0AAHB
0000002/=b/00P3oIE400`3oKe`0ofIC0?mUD@020?mUD@0<0?mVDP3oIE40oei:0?mE@03oDch0oe<o
0?mNB@3oIE00ofUF0?mVD@3oJ5@0ofMC1@3oIU401@3oJE@0Tc<X0000002Z;2`0oe]J00T0oe9@00T0
oeAB0?mMF`3oDE00oe=A0?mDD`3oIF@0oiNI0?oOhP3ooOl0M`3oool3000000030<V;T03oool0oooo
00/0oooo00H0omoS0000000000003@T90?oioP1VEeX60000000300d92@2hTYH0oooo00H0oooo00<0
aZfa02HJ6`0000001@0000000`1IATP0ooWn079>D@02000000030>BUZ`3oool0oooo0080oooo00@0
oko60000000000000000103oool01`3ogn<000000000000=2@T0ooWn0:FDV@0C3@h01@0000000`0=
2@T0LDiA0?o[k@060?ooo`030?oXk01PDeH0000000H0000000<0AcDf0?7>d@3oool01@3oool00`3o
m?H0S8:703<S90060000000300d92@20H6<0lLkA00@0oooo00L0onoa000000000000000008J4Q02U
U9T0<b<T00<0000000@0oko60?ooo`3oool0oko60`0000040?ooo`070?oOh`000000000000L51@3o
nOh0YIBI02HJ6`050000000300d92@1aCU40o]KJ00H0oooo00<0onS/08aaM@0C3@h01@0000000`0V
6Q/0S75e0;VTZ003000000030?;Be@3oool0oooo0=H0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomE0?ooo`050?ono`3ojNl0d8=f074l7`1h@RP02`1i
@bT01@1k@bP0K3`T0000000o7AD0PcX/00L0N3LY00L0NSPZ06X]7P1M9AH0GR@F06/]801g=2L0NCPZ
00X0N3LY00H0McHX07Pg:@1h=bT0N3LY07Lf:025@3@807Pg:@0407Lf:023?S40RD8f07Pf:0<0N3LY
00<0NSPZ08Ln<023=bT00P23>BX2084h:@0608<i:P27?2d0PCPY08e2=01o=RL0PCPY1@23>BX00`20
=bP0R3/Z08dl;00608dl;003090o;`2E@C<0SC`/00H0SC`/00<0SCd/09E0;P2K@c001P2J@c000`2E
?B`0V48_09Y3<00709Y3<00309]3<02QA2h0Y4Hb00<0Y4Hb00@0YdTe0;AE@`2XBC@0XdDa1`2TAS80
302SAC40Y4Hb0:=5<@2bDCh0/4Te0:a3;`2bBcL0_EI30:m9<`2]AS<0_EI30:e8<`/0[dPd00<0^e<o
0;]?=`2kCcL00P2kCcL00`2iCCH0a5M10;a@>00<0;]?=`030;Y>=P34DCP0a54h0080a54h00<0`U0g
0<9@=P34DSP03@34DCP01`31CCD0cUDj0<iE>P3>ECX0cE@i0<iE>P3>ES/03`3>ECX0103CEST0f5/m
0=QK?@3HFcl@0=QK?@060=UL?`3VHdP0i5m10>AO@@3TGCl0hei03`3TGd401P3SGT00kF930>eR@`3]
HT<0k6930>eSA0l0kF9300@0l6E60?eaE03dI4@0mVE50P3fITH?0?IUA@070?MWB03oLUD0ofM50?mX
AP3mIdD0ofm?0?mYA`040?mXAP030?eVA03oIdD0ofQ600H0ofQ600<0ofI50?m]BP3oL4l0503oJdP3
0?m]B@030?m/B03oJT@0ofe900d0ofe900<0ofi90?m`B`3oL4/02@3oL4/03@3oL4X0ogYH0?m_B@3o
LD`0ogaK0?meC`3oKTL0og1:0?meC`3oM4d0og=<0?mbC03oLd`01@3oM4d00`3oMDh0og590?mbBP04
0?mdC@050?meCP3oLDX0ofDm0?mS>`3oLDX01P3oMDh00`3oMTl0ogeK0?meCP050?meCP030?mhD@3o
Ped0ogU?00L0og]A00<0og]B0?mkD@3oNe40103oNe40103oQeP0@A/B0000002[?c840?mRC`070?mP
C03oGdX0ofaJ0?mQCP3oIU<0of=A0?mQCP020?mRC`030?mPC@3oHe00of=@00<0of=@00<0of5=0?mS
D03oHe001@3oHe000`0/3P/000000=Q5>0020?mUD@0D0?mSCP3oHdl0ofEA0?mUD@3oIU<0of=?0?mH
A03oDSd0oe<n0?mJAP3oHdl0ofE@0?mVD@3oIE00ofIA0?mWDP3oJeP0ofA?0?mWE03oIE420?mVD@06
0?mXD`2^?C0000000:4Y9`3oFeT0oe=A203oDU000`3oEE<0of=S0?mJF`040?mCD@040?mFE@3oX:@0
oncc0?omogD0oooo0`0000000`39Ri00oooo0?ooo`0A0?ooo`070>:LXP1nEeX0<R<T01TB4P1UADP0
bH^@0?oco00:0?ooo`060>:LXP1nEeX03@T90000001;=3H0bH^@603oool01`3ac]40OUMJ038S9000
0000C3@f0<V;T03olo`02P3oool0203o_lH0UfQ/04/d=P0000006A4B06E5B039Ri00ooWn2P3oool0
1`3o_lH0LDiA0000000000006A4B09MXK03olo`03@3oool0103l[K@0LDiA0000003o_lHA0?ooo`06
0;1jOP0b8b@00000038S902GJ6`0oo?l2P3oool01P3ac]40OUMJ01TA4P0000009QXK0<V;T=l0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomD0?ooo`06
0?odn`3o^[@0`WY[074m8@29CCH0N48X2`1i@bT01@1lA2X0JCTR0000001881L0PC//00H0N3LY00T0
McHX07Xh:`20?2l0JbdO05`T5@1K8a@0J2dO07Pg:P1h>2X0201h=bT00`1k>B/0RT<g07Pg:@0207Pg
:@0307Lf:025@3@0N3LY00L0N3LY00<0McLY07/i;01m>Rd0101h=bT02P1i=bP0OCHW08@h:P23>BX0
PCTZ08Ll;P2<@380OcHW08/o<@20=BH208@j;0H0PcTZ00<0OcHW08`k:`2=?2`01P2=?2`00`2>>b/0
SSd]08dl;00608dl;00309=1<P2OB3L0VT8_00D0VT<`00<0WTDc09a5<`2J@c00202J@c000`2K@c00
XD@_0:A6<P030:A6<P030:M9=@2dED<0XD8]00@0Y4Hb00l0XdD`0:=5<@2SAC40ZTXh0:Y<>02SA300
XD@_0;AC@02bBcL0[DPb0:m8=02]B3<0[dPd0:e8<P2bBcL0302_B3@00`2kDcl0^dlg0;]?=`020;]?
=`030;U==@2eBC80^ddf00`0^dlg00<0^Thf0<AA>034DCP00P34DCP00`3:Ed00ae@k0<AA>00=0<AA
>0060<5==@3>ECX0cUDj0<iE>P3>ES/0cEDj403>ECX01@3CEST0f5/m0=IH>`3RI4T0gF9600l0f5/m
00H0fE`o0>ISB03TGd40i5dn0>]UB@3VHD<?0>AO@@030>=N@03]HT<0kF930180kF9300L0l6E60?ea
E03dI4@0mFE50?i_D`3iJ4T0mVA400h0mVE500L0mfM80?mbE@3oIdD0ofQ60?eVA03lID40ofM600@0
ofQ600<0oFM50?mWA03oJ4H01P3oJ4H00`3oITD0ofe:0?m`C`020?m[B0030?mZA`3oL4l0of]800l0
of]80`3oKDT00`3oKTX0ofe90?m]B@0=0?m]B@030?m^B@3oL4/0og1;00X0og1;00@0og5;0?m_BP3o
L4/0ofm90P3oL4/02@3oKdT0og]H0?mdC@3oLT/0ogI@0?miE03oLD/0og9<0?mbB`030?mdC@030?mb
B`3oMU00ogA=0080ogA=00H0ogE>0?maBP3oICd0of<j0?mZ@P3oMTl60?meCP030?mfC`3oNE40ogA=
00D0ogE>00<0ogMA0?n0G03oNE001P3oNe40103oNE00oh5K0?mlE03oNU440?mkD@040?n5E`0o6a80
00000:i1<`D0of9?00T0ofEB0?mQCP3oHTl0ofUG0?mRC`3oI540ofEB0?mQCP3oH4`01@3oHe000`3o
I580of=@0?mSD0050?mSD00301/81`000000nU1100<0ofEA0140ofMD0?mUD@3oIU80oei:0?mE@@3o
DSd0oeA00?mNBP3oIe@0ofA@0?mUD03oIU40ofA@0?m`G@3oIe<0ofA@0?mWE0020?mYEP080?mVD@3o
I500ofQC0;4n<0000000VbDT0?mUI03oEE<80?mBD0040?mCDP3oHf40oeME0?mDD@<0oe=A00D0oe5?
0?m;B@3oPh<0ojne0?oio@1d0?ooo`<0000000<0bH^@0?ooo`3oool0o`3ooon20?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooD`3oool0103ojnl0fXao
07i6;@1[>1/>07U3:@0508iB>@1Z>R@0000004LP5`21>b`01@1h=bT02`1i>2X0NcT[07/h:`1n>bh0
Mc@W06X]7P1O9QL0ER0B06@X6P1h=bT0NSPZ00L0N3LY00<0NSPZ08@n<P1h=bT00P1h=bT00`1g=RP0
QD0d07Pg:@0707Pg:@0307Ld9`1a<280MCHX00D0N3LY00L0OCHW08<h:@26>bd0QC`]08Tm;`2=@C<0
P3PX0080PCPY00<0TdPk08Tn<022>BX01@23>BX00`1o=RL0S3/[08dl;00608dl;00308`l:`2<>b/0
SC`/00H0SC`/00<0U44b0:5:>P2H@Rl01@2J@c000`2OAcD0X4Ld09Q2;`0809Y3<00309]3<02QA2l0
Y4Hb00<0Y4Hb0100YdPd0;MFA@2VB3@0XdDa0:=5<02TAS80YdTd0:iA?P2ZBSL0X48]0:]<>@2[C3/0
Y4Da0:A6<P2`Cc`0[DLc102_B3@00`2`BCD0[DPb0:m8=00;0:m8=0060;]C?`2kCcL0^dlg0;]?=`2j
CSL0_50i3P2kCcL0202jCSH0a54h0<AA>034DCP0a50g0<iJA038E3h0`U0g3@34DCP01`31CCD0cUDj
0<iE>P3>E3T0ef160=AJ@P3=E3T03`3>ECX01P3CEST0f5/m0=QI?03KGD40fEa00=MK?@h0f5/m00H0
fE`o0>ISB03TGd40i5do0>MRA03THD8?0>AO@@060>=N@03]HT<0kF930>]O@03cJD/0kF523`3]HT<0
1P3`IDH0oG5D0?ATA03fIDD0mfM70?IVAPl0mVE500H0mfM80?mbE@3oIdD0oFU60?m]BP3oJDL60?mX
AP030?iV@P3oJ4H0ofQ600H0ofQ600<0of]90?m`C`3oJdP00P3oJdP00`3oKdd0of]80?m[B00>0?m[
B0<0ofe900<0og9@0?m^B`3oKDT03@3oKDT00`3oKTT0og1;0?m`B`0:0?m`B`030?maB`3oM4h0ofm:
00<0og1;00l0og1:0?mjEP3oLd`0og=<0?mfD@3oNUD0og590?mgD@3oNeP0ogE>0?mdC@3oLTX0ogUC
0?mkEP3oLd`00`3oM4d0103oISh0of8i0?mT?03oLDX80?meCP030?mfCP3oNE80ogE>00@0ogE>00<0
ogQA0?n1G@3oNDl01`3oNe400`3oNe80ogM?0?mkD@040?mkD@040?n5E`0i5a0000000:Hn<PD0of9?
00X0ofmN0?mRC`3oHTl0of5>0?mPC@3oIU<0ofAA0?mWE03oI580of1<103oHe000`3oJEH0of=@0?mS
D0050?mSD00300d40`000000oeQ700<0ofEA00@0og9Q0?mVD`3oGd/0oe<n0P3oDSd01@3oGTX0ofIC
0?mUD@3oIE40ofE@0080ofIA00h0ofeK0?mVDP3oIU40ofIA0?mUD03oJEH0ofMD0?mYEP3oJ5<0_d<e
0000001Y6aT0odm>0?mDDPP0oe9@00@0oeEC0?mSH@3oCD`0oe9@1@3oDe400`3oAdD0oe=A0?nZ[P1d
0?ooo`<0000000<0bH^@0?ooo`3oool0o`3ooon20?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooD03oool02@3oo_l0omKC0=:YXP2IFdD0LC`Q07I19`1i
@bT0ND<X07<n8`0;07U3:@0607U2:023BS00J3TS0000001681L0PC//0P1h=bT01@1h=RP0OS`_07Pg
:P1j>2/0NSPZ0080N3LY00T0PCd`07Pg:@1e=2H0KRlR064W6@1R:1T0JbdO07Dd9P1i>2X01@1h=bT0
0`1g=BP0N3DX07Pg:@0307Pg:@03084m<01h=bT0N3LY00H0N3LY00<0OCX]08Do<`1h=RP00`1h=bT0
1P1k>2/0NcT[08@j;026?2d0PSTZ08@j:`80PSTZ0P23>BX00`21>2T0PSPY08<i:P0608<i:P0307lf
9`2<>b/0SC`/00D0SC`/00<0SSd]09Q6=`2=?2`01`2=?2`00`2D@C80XDXj09Q2;`0509Y3<00309U2
<02J@c00VT<`00P0VT<`00<0Vd<`0:54;`2TAS800P2TAS802`2XBCH0[Dhk0;AE@`2UAc<0ZT`h0:m@
?`2UAS<0YDHb0:M9=P2WB3@0Y4Ha00@0Y4Hb00<0/4ll0:e7<`2_B3@00`2_B3@00`2jDcl0[dPd0:m8
=00;0:m8=0070;]C?`2kCcL0^dlg0;]?=`2jCSL0`5@m0;eA>@0=0;]?=`070;Y>=P34DCP0a54h0<AA
>035DST0aE<i0<EA>00>0<AA>0060<5==@3>ECX0cUDj0<iE>P3=E3T0ceDj403>ECX01@3CEST0f5/m
0=YL@03IG3l0eUXl00l0f5/m00D0fE`o0>ISB03TGd00i5m10>9N@00@0>AO@@050>=N@03]HT<0kF93
0>aP@@3^HdD0403]HT<01P3`IDH0oG5D0?ATA03gITH0mVE50?ITA0l0mVE500H0mfM80?mbE@3oIdD0
oVM50?m^CP3oJTP60?mXAP030?iV@P3oJ4H0ofQ600H0ofQ600D0ofe:0?m_C`3oJdP0of]80?m/BP0A
0?m[B0<0ofe900<0ofi:0?m]BP3oKDT03@3oKDT00`3oKTT0og1;0?m`B`0:0?m`B`030?maC03oME80
og1:00<0og1;00<0og1:0?mjEP3oM4d0103oM4d03`3oMDl0ogM@0?mdC@3oMTl0ogaG0?mnF`3oM4d0
ogQB0?miE03oMDl0ofU10?mQ>@3oIcl0og5:0?meC`080?meCP030?mfD03oN580ogE>00@0ogE>00<0
ogM@0?mnF@3oNU001`3oNe400`3oNE00ogiH0?mlDP040?mkD@040?n3EP1`;1`0000009<i;PD0of9?
00<0of=?0?mSD03oHTl0103oHTl02@3oI540of=@0?mQC@3oIE80ofIC0?mTDP3oHdl0ofA@0?mRC`05
0?mSD0040?mMB`0000003@@30?mRCP80ofEA00P0ofIB0?mQC@3oFdH0oe<o0?mE@03oFTH0of5=0?mV
DP<0ofEA00D0ofA@0?mVD@3oIU40ofIA0?mWDP040?mVD@080?mWDP3oIe<0ofMA0<a:>`0000006PH6
0?4j>@3oEUD90?mBD0030?mDDP3oEeD0oeID00L0oe=A00D0oe5A0?m]KP3oWj80omCG0?omo`1`0?oo
o`<0000000<0bH^@0?ooo`3oool0o`3ooon20?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooC`3oool0103ohMl0/VeJ08E;<`1a?24407U3:@0308A;<P2<
DCT0N48X00X0ND<Y00/0O4D[07U2:01<:AH020<205dZ7P1n>R/0N3LY07`j;01h=RP0NcT/07Lf:003
07Pg:@0:07Lf:01h=RP0N3LY07Le9`29@SH0NSPZ064U5`1L91D0GbHG070a8`D0N3LY00<0Rd<h07Pg
:@1h=bT00`1h=bT00`1f=RP0N3LY07Pg:@0607Pg:@0:07De:01g=2L0N3LY07He9`29@SH0OCT/07Pg
:@1i=bX0OSLX08@h:PD0PcTZ00@0PSPY08e2=029?c40PCPY1P23>BX00`1o=RL0S3/[08dl;00508dl
;00308/k:P2<>RX0SC`/00L0SC`/00<0U44b0:5:>P2H@Rl0102J@c000`2H@Bh0XTXh09Q2;`0909Y3
<00;09U2;`2QA300/E900;=D@P2TAC40YTLc0:M9=@2SA340Y4Ha0:A6<P2SAC402@2TAS800`2`Cc`0
[DLc0:m8=0020:m8=0030:e7<@2]B380[dPd00`0[dPd00H0^e<o0;]?=`2kCcL0^dlg0;Y>=P2hBc@>
0;]?=`070;Y>=P34DCP0a54h0<AA>038ECd0beQ10<9@=`0>0<AA>0060<5==@3>ECX0cUDj0=1G?@3C
FD40cE@i403>ECX01@3CEST0ee/m0=ePA@3MHTH0eUXl00l0f5/m00H0fE`o0>ISB03RGT00j6=60>QS
A`3SGd4?0>AO@@050>AN@03[H400kF520?5WB@3]HdD0403]HT<01P3^I4H0nViB0?ITA03hJ4T0n6Q:
0?ITA0l0mVE500D0mfM80?mbE@3oIdD0oFI40?eU@P070?mXAP030?iV@P3oJ4H0ofQ600H0ofQ600H0
ofe:0?m_C`3oJdP0ofQ60?mdE@3oK4X@0?m[B080ofe900<0ofa80?m^C03oKDT03P3oKDT00`3oKTT0
og1;0?m`B`0;0?m`B`030?maB`3oME40og1;0080og1;00<0og1:0?miE@3oM4d0203oM4d02`3oLTX0
ogiJ0?mkE@3oN540ogE?0?mY@@3oHSX0ofa90?mjE@3oM4/0ogA>00X0ogE>00<0ogI?0?meCP3oMDh0
0`3oMDh00`3oMTh0ogaB0?mkD@070?mkD@030?mhD03oNU40og]A00<0og]A00@0oh=F07L_7@000000
TcP]1@3oHTl00`3oI540ofeL0?mRC`050?mRC`090?mTDP3oKE`0of=?0?mTDP3oHe00ofAB0?mXE03o
KE/0of=?00@0of=@00`0mTlo0000000f4@h0ofIC0?mUD@3oI500oeM30?mB?@3oCCX0oeM30?mUD@3o
IU<40?mUD@030?mTD03oJEH0ofA@0080ofIA00<0ofaH0?mVD@3oIU401@3oIU401@3cF4L000000000
003O=380oe]J00P0oe9@00@0oe5?0?m@CP3oEU@0oeEC2@3oDe400`3oFEL0oeQG0?nQY01`0?ooo`<0
000000<0bH^@0?ooo`3oool0o`3ooon20?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWiol0ooooC@3oool01@3ooOl0olk@0:]XEP1e@2H0N44W00D0ND<Y00<0PTT`
095D?01h@RP02P1i@bT01`2<DST0Nd@Z04HT50091080GbTN080j;01n>bh01`1h=bT0301e=BL0N3LY
07Pg:@1g=RP0Q3lb07ll;P1e=2H0IBTJ05hU5P1P9aP0LC0R07Xh:P<0N3LY00<0Pcla07Pg:@1h=bT0
0`1h=bT00`1f=RP0N3LY07Pg:@0507Pg:@0507Pf:01g=BL0McHY07/i:`20?2l0101h=bT00`1n=bP0
Q3PZ08<i:P0408<i:P04088i:P2<@380RCh`084h:@H0PcTZ00<0OcHW08`k:`2=?2`01@2=?2`00`2F
A3D0SC`/08dl;00708dl;00309A1<P2QBSX0V48_00@0VT<`00<0V48_09m6=02J@Rl01@2J@c00202L
A340VT<`09E0;@2UC3/0WDHd0:14;`2VB3@0YTLc0P2TAS800`2VAc<0[4dj0:A6<P0;0:A6<P070;1@
?02]Ac<0[dPd0:m8=02^B3@0^UE00;19=@0=0:m8=0070;]C?`2kCcL0^dlg0;]?=`2oE3`0_e<m0;]?
=P0=0;]?=`040;Y>=P34DCP0a54h0<AA>080aE8i3`34DCP01P31CCD0cUDj0<iE>P3AEcd0deY00<mD
>A00cUDj00@0deHi0=QJ?@3FFC/0f5Xl403HFcd01@3IG3l0iV=80>AO@@3QGCh0hUi00100i5m100D0
i5ho0>YN?P3]HD80lFM:0>iTA@0@0>eR@`050?1UAP3kL5<0mVA40?ES@`3dI4@0403fIDD01P3gIdP0
og9E0?iVA03oLE40ofa<0?mWA@H0ofQ600<0oVI20?mXAP3oJ4H01P3oJ4H01P3oKDX0ofm?0?m[B03o
JdP0ofa:0?m/B@l0of]800D0ofa80?m]B@3oKDT0ofY70?mcDP0?0?m]B@030?m^B@3oL4/0og1;00/0
og1;00<0og9>0?miE`3oL4/00P3oL4/00`3oL4X0ogYE0?mdC@080?mdC@070?mbB`3oNeP0ogI@0?mb
B`3oId00of8j0?mW?`020?meCP040?mbBP3oNeL0ogM@0?mdC@80ogI?1@3oMDh00`3oN5<0ogaH0?me
CP040?meCP030?mfCP3oO580og]A00L0og]A00<0ogQ@0?mkD@3oNe400`3oNe40103oPeH0RCLS0000
002==bd60?mRC`030?mYEP3oHTl0of9?00@0of9?00<0ofIC0?m_GP3oHe000`3oHe001@3oI540ofYG
0?mUD`3oHdl0ofAA0080of=@00X0e4@g0000001H7AP0og1M0?mTD03oFD@0oe<n0?mB?@3oDC`0of=@
1P3oIE400`3oI500ofeK0?mUC`020?mVD@030?mWD`3oIU40ofIA00D0ofIA00D0n5Y90000000:0P80
jCPg0?mED`090?mBD0030?m@CP3oDU00oe9@00T0oe=A00D0oe5?0?mACP3oE580ojFY0?oTk01^0?oo
o`<0000000<0<R<T06E5B01UADP01`1UADP00`3od=P0oooo0?ooo`0X0?ooo`040<V;T00000000000
000004L0oooo00@0bH^@0000000000000000o`3oool10?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooC03oool0103oiNT0ok2Y08]A=`1e@2H707U3:@03
07Q2:02AE3`0N48X00X0ND<Y00L0QD/b07I1:00R4PT01P8105TX7P23?Bh0McHX00H0N3LY00L0McHX
08Y2=`1i>2X0N3LY07Le9`27@C@0Oc`_0080N3LY00P0JRdN05hU5P1N9AH0JbhO07Pg:@1i>2X0McDW
07Dd9PD0N3LY00<0MSHX07Pg:@1h=bT00P1h=bT01`1g=RP0N3LY07Xh:P1k>B/0QT4c07hk;P1e=2H0
101h=bT00`1i=bP0PCPY08<i:P0508<i:P03088i:P1o=bL0PSTY00L0PcTZ00<0OcHW08`k:`2=?2`0
1@2=?2`00`2LBC/0SC`/08dl;00708dl;00309A1<P2QBSX0V48_00@0VT<`00h0V44_09Q1;P2J@Rl0
V48_09Y3<02LAC80Vd@a09Dn;02TC3X0V48`09M0;P2J@c00Vd<`0:54;`@0Y4Hb00<0XdDa0:I8=02T
AS802`2TAS801`2bD3d0[DLc0:m8=02_B3@0[TPd0;UC@02`B3D03@2_B3@0102kDcl0^dlg0;]?=`2k
CcL20;a@>@h0^dlg00H0^Thf0<AA>034DCP0a54h0<EA>034DSP?0<AA>0030<5==@3>ECX0cUDj0080
cE<h4@3>ECX00`3CEST0fU`o0=YM@P080=QK?@L0eUXl00H0f5Xl0=QK?@3IG3l0iV=80>EQ@`3WHT@2
0>AO@@030>AM?`3TGSl0i5ho00/0i5ho00P0i5m10>MRA03]Hd@0l6E70>eR@`3_IDL0kVA60>eP@PP0
kF521P3]HT<01@3`IDH0ng1C0?IS@`3fI4@0m6A400D0mVA42`3fIDD01P3gITH0oFa=0?iWA@3oKTd0
of]:0?mWA@H0ofQ600<0ofe<0?mXAP3oJ4H01P3oJ4H01@3oKDX0ofm>0?m[B03oJTP0ofY70100of]8
00D0og1?0?m/B03oKDT0ofe90?m^BP0?0?m]B@030?m^B@3oL4/0og1;00/0og1;00<0og1:0?m]A`3o
L4/00P3oL4/00`3oL4X0ogYE0?mdC@080?mdC@070?mbB`3oOUX0ogIA0?mV@03oHCT0of8j0?m`B@02
0?mdC@090?mdC03oMDh0ogE>0?mdC@3oNU@0ogYE0?mdC@3oMe40ogM@0080ogE>00<0ogI?0?meCP3o
MDh0103oMDh00`3oMTh0ogYA0?mkD@070?mkD@030?miD03oP5P0og]A00<0og]A00@0oh1E0;A6;@08
0`40RcH/1P3oHTl00`3oH4d0of9?0?mRC`040?mRC`030?mVD`3oKeh0of=@00@0of=@0P3oHDd03@3o
IE<0ofIB0?mVE03oHe00]cX^0000001i:B80ofaJ0?mHA03oDSd0oe<n0?mHA03oHTd01`3oIE400`3o
I500ofeK0?mUC`020?mVD@030?mUD03oIU40ofIA00D0ofIA00P0nE]:008000020000gCHe0?mEDP3o
FUT0oe1>0?mCDPH0oe9@00@0oe5?0?m?CP3oFEL0oe9@203oDe401`3oDDl0of9P0?mBD@3oBDL0og1a
0?o@e@3oo?l0K03oool=000000030?noaP3oool0oooo02P0oooo00@0bH^@0000000000000000A`3o
ool01039Ri00000000000000003o0?ooo`40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooom:0?ooo`050?oTi03BV8l0TUDo074m8P1h@RP0201i@bT00`1o
Abh0T5@k07Q2:00:07U3:@0607Q29`1kA2/0=Qd?00T40P1P:ah0OST[1`1h=bT01`1f=RP0NcT[07Tg
:@1h=bT0McDW08M1=01o?2l00P1h=bT0201i>2X0LC8S068X6@1M9AH0GbHG070a8P27@CD0NSP[1@1h
=bT02`1f=RP0N3HX07Pg:@1j>2X0NSP[08<n<@1i>2X0NCLY07/h:`1l>B`0N3HX00D0N3LY00<0N3DW
08@h:P23>BX01@23>BX00`26>bd0RSla088g:@0708<i:P0307lf:02<>b/0SC`/00@0SC`/00<0SSd/
08hl;02=?2`0202=?2`00`2D@C80XDXj09Q2;`0209Y3<00:09U2<02JA340XTXi09Y3<@2PB3H0XTTh
09Q0;P2MAC<0W4@b09U1;`@0VT<`00<0Vd<`0:54;`2TAS800P2TAS800`2UAc<0Zd`i0:53;P0<0:A6
<P030;9@?@2]Ac<0[dPd0080[dPd00<0[DLb0:m8=02_B3@0302_B3@01P2kDcl0^dlg0;]?=`2jCSL0
_E4j0;Y>=`h0^dlg00H0^Thf0<AA>034DCP0`e4h0<]H@032CcL?0<AA>0050<5==@3>ECX0cUDj0==J
@03>E3T01`3>ECX30<iD>@0;0<mE>P3>ECX0cUDj0<iD>P3>E3T0dUPn0=9I?`3FFCd0gEm30=mRA`3H
FS`00`3GFS`01P3FFC/0eUXl0=IJ?03GFcd0gV960>5TB@80h6=800`0gV570>1SB03QI4T0gV550=MJ
?03GFC`0hf540>AO@@3VHD@0hUdn0>9N?`3SGCh=0>=N@0080>AP@P3YI4H0k6=40?AZC@3eJdh0lFM9
0?1UA`3/HD880>aQ@@030>]Q@@3/H400k61000<0k61000H0kV=40?Q/C`3hJ4P0oFe@0?]/C`3lK4d2
0?a]C`040?a]D03lK4d0mfI60?AS@P80m69200D0mF=30?ETA03eI4@0mFA30?EUA@020?QXB@060?MW
A`3hID@0of]:0?iYA`3oJ4H0oVM50`3oJ4H20?iWA@030?eVA03oMUP0ofY800L0ofQ600D0ofU60?mZ
A`3oJTL0og9A0?m^C@0?0?m[B0060?mYA`3oLe<0ofY70?m]B@3oL4`0ofi:3`3oKDT00`3oM580og1;
0?m`B`0<0?m`B`060?mcCP3oLdl0og1;0?m`B`3oL4X0ogUD2@3oM4d01P3oLd`0ogeJ0?m^A`3kHCT0
ofDm0?m_A`80ogA=00<0og=<0?mnF`3oMU001@3oMDh01`3oN5<0ogQB0?mfD03oO5L0ogI?0?mgD03o
NU<0103oMDh00`3oMTh0ogM?0?mkD@080?mkD@030?mkDP3oNe40og]A0080og]A00D0oh1E0;=6;P09
0`40RS<Z0?mSD0050?mRC`030?mTD@3oIeD0of9?00@0of9?00<0ofIC0?m_GP3oHe00103oHe00403o
IE<0ofaJ0?mSD03oHe00ofMD0?mSD02:;RH0000009T]8`3oDSh0oe8l0?mIA@3oHDh0ofEA0?mWD`3o
J5D60?mUD@030?mTD03oKU/0ofE@0080ofIA00<0ofYG0?mUD@3oIU401@3oIU402`3oGd`04@@20000
003=<S40oe]I0?mCDP3oDU00oeEC0?mDD`3oDE00oe=A00<0oe9@00@0oe9A0?mDD@3oEeH0oe9@2@3o
De40203oDe80oe9A0?mCDP3oDDl0odi=0?n>T03ogMl0ooOlJP3oool=000000030?noaP3oool0oooo
02P0oooo00@0bH^@0000000000000000A`3oool01039Ri00000000000000003o0?ooo`40oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooom80?ooo`040?oK
g`3fWiH0Vea707<o8`/0ND<Y00<0Q4/b08mC>P1h@RP01`1i@bT02@1h@RP0Nd@[08=:<01oAbd0MT4W
02hI2P0B20H0OCX[07Xg:@0607Pg:@0307Lf:@1k>B/0NSLY0080N3LY00<0McDW08M2=P20?2l00`1h
=bT0201i>2X0N3LY06h`8@1Q9aP0GBDE06/^7`1e=BL0NSPZ0`1h=bT01`1e<bH0MCDW08I0<`1h=bT0
NSLZ07hk;@1g=RP00P1h=bT00`1n>bd0N3LY07Pg:@0507Pg:@0307Pe9`24>2X0PcTZ00D0PcTZ00<0
Q3X[08@j;023>BX01P23>BX00`21>2T0T4<e08ln;P0508dl;00309a8>`2??Rh0SC`/00P0SC`/00T0
Td0a09m8=`2G@Bh0VT<`0:59>02G?bd0WTHc09i6=02I@Rl00P2H@Rl809Y3<00309]3<02QA2l0Y4Hb
0080Y4Hb00<0YTLc0:e@?02QA2l0302TAS801P2bD3d0[DLc0:m8=02_B3@0]4hj0;9;=`h0[dPd00H0
^e<o0;]?=`2kCcL0^Dde0<=G@02iCCH>0;]?=`050;Y>=P34DCP0a54h0<9@=`32CSD04034DCP01031
CCD0cE<h0<eB>03=E3T20<eC>00E0<eB>03>ECX0cUDj0<eC>03<DSL0e5]10=YQB@3GGdH0fF180=IM
A03=DcL0cE<h0<]B>03=DcP0eUe40=MOAP3IG440h6980=eOA03IG3l0eETk0080eUTk103HFcd00`3F
FS`0eUTk0=II>`040=II>`060=IJ?03HFcd0fE`o0>ISB03TGd80i5dn4P3TGd400`3ZGcl0kVA60?1U
AP0A0>eR@`060?1UAP3kL5@0m6910?ER@P3dHd<0m6A40`3dHd<00`3dI4@0mVE50?IUA@020?IUA@0<
0?ITA03dHd<0m6=30?AR@@3dI4@0nfa>0?]]C`3jJdd0o6Y:0?mbD`3oLU@0ofQ60P3mIT@0103oIdD0
ofi>0?mbE03oLU<20?mbE0050?mWA@3nIdD0ofQ60?mXAP3oIdD00`3mIT@01@3nIT80ofY70?m[B03o
JdL0ofY700l0of]800H0ofU70?mcD`3oJTL0of]70?mdD`3oKT/?0?m]B@030?meD`3oL4X0og1;00`0
og1;00<0og5<0?m`BP3oL4/00P3oL4/00`3oLDX0ogA=0?mdC@060?mdC@060?meCP3oM4d0ofe70?mQ
>P3oJD40og]G0`3oM4d00`3oLT/0ogmL0?mfD00:0?meCP080?mdC@3oNE<0ogE>0?mcC03oO5P0ogMA
0?meCP3oMdd90?mkD@030?moE`3oNe40og]A0080og]A00D0ogeC0>5J>@0A1P<0IR0I0?mUD@060?mR
C`030?mPC@3oHTl0of9?00<0of9?00<0of=A0?mZF03oHe001@3oHe002`3oI500of=?0?mSD03oHe00
ofAB05HK5@000000]S<V0?m=>P3oHDd0ofIB0080ofEA0P3oIU<60?mUD@030?mTD03oJeT0of=?0080
ofIA00<0ofMB0?mUD03oIU401@3oIU401P3oGd`0;0/800000038<C00oeAB0?m?C@80oe9@00T0oe5?
0?mBD@3oEE<0oeMD0?mBD03oDDl0oeMF0?mRH@3oDDl02`3oDe40203oDe80oe9A0?mBD@3oDU40odm=
0?m;B@3oQ8L0omGLX@3oool01039Ri0000000000000000170?ooo`040<V;T0000000000000000?l0
oooo0@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
odL0oooo00D0omoQ0:ASC`1a?B40Kc/Q07e6;00;07U3:@0307Y3:P2AE3`0N48X00H0ND<Y00T0Nd@Z
07i7;01lAB/0O4D[07U3:@1f@BP0;1H:01D91`26?Rh01`1h=bT00`1g=BL0RT<g07hk;@0207Pg:@03
07Lf:021?C00OCX]00D0N3LY00h0NSPZ07De9`1R9aP0G28D068X6@1a<280NCPZ07Lf:01g=BL0N3LY
07Pf:@20?2l0NSPZ07Lf:0@0N3LY00<0Q3hb07Lf:01h=bT01@1h=bT00`1h=BL0Q3PZ08<i:P0508<i
:P0307lf9P21>2T0PcTZ00H0PcTZ00<0PCLX09U:?P2@?bl01@2=?2`00`2E@c@0SCd]08dl;00608dl
;00;08`k:`2<>BX0Td0a0:E<>`2H@Bl0V48_09i7=02H@2h0Vd@a09]3<@2I@c002P2J@c000`2K@c00
XD@_0:A6<P020:A6<P030:53;`2SA300XD<_00`0Y4Hb00H0/U0m0:e7<`2_B3@0[dPd0;19=@2`BS@>
0:m8=0050;]C?`2kCcL0^dlg0;U==P2jCSH03`2kCcL01@2jCSH0a54h0<A?=`35DcX0aE8j00/0a54h
01L0`Tlg0<9?=P34D3L0a54h0<9@=`35DcT0fV1:0=UPB03GGdH0fV590=]RB`3GGdL0cE@i0<aC>03;
DSP0cE<h0=5H?P3FFd<0e5]20=AK@`3CFd00cE<h0<eD>@020<iE>P80cE@i00<0ee]10=ePA@3FF3X0
4@3HFcd0103IG3l0j6E90>aXC03RGChB0>AO@@80jUhn00<0jf100>eR@`3]HT<03`3]HT<0103`IDH0
nVmB0?UXB@3hJ4T?0?IUA@040?ATA03dHT<0lf=30?AQ@080ofQ60180ofI50?mXAP3oJ4H0ofU60?m[
B`3oKTh0ofi=0?m]C@3oLeD0ofQ60?iWA@3nIT80oFI40?m_C`3oM5H0og=E0?mdEP3oLE820?mXA@03
0?mYAP3oJdP0ofY70080ofY73@3oJdP00`3oLU40ofa80?m]B@0A0?m]B@030?meD`3oL4X0og1;00`0
og1;00<0og1:0?mcC`3oL4X00P3oL4/00`3oLT/0ogA=0?mdC@070?mdC@050?m/A03oHST0of@l0?mc
C03oN5@00`3oM4d00`3oLd`0ogeJ0?mgD00;0?meCP040?meC`3oM4h0ogA=0?mjE080ogI?00<0ogiI
0?mlD`3oNE00203oNe402@3oN500og]A0?mkD@3oNe40ogiC0?UT?`0E1`@0HalH0?mUD@060?mRC`03
0?mVD`3oHDh0of9?00<0of9?00<0of5>0?mQC@3oHe001@3oHe00303oHdl0ofA@0?mSD03oHe00oeY7
038=2P000000hd@d0?mTD@3oJEH0ofMD0?mXE@80ofA@00<0of=>0?mUD@3oIE401P3oIE430?mVD@03
0?mUD03oIU40ofIA00D0ofIA00H0of9>04hE40000000`S4_0?mED`3oEeH40?mBD0090?mCD@3oDe80
oeAB0?mAC`3oEeD0of1O0?mED`3oFEH0oe9@00L0oe=A00<0oeAB0?mQH03oF5L0103oDU40103oDDl0
odY80?m[K03obm;o0?oooo00oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooom60?ooo`040?oCe@2dL5d0LShS07I19`80OdL^2P1i@bT0101e?bD0ND<Y095D
?01h@RP507U3:@0:07a5;01kABX0NdDZ07U3:@1g@BH0ND<Y07I1:00/5PX050P708@m;@L0N3LY00<0
McHX08@o<P1m>R`00`1h=bT00`1g=RP0N3LY07Pg:@0507Pg:@0;07Xh:P1e=BP0HBLH05`T5@1O9QL0
L34S08<n<@20?2h0LS<U07Pg:@1g=RP01P1h=bT00`1g=RP0N3LY07Pg:@0507Pg:@0307Pe9`24>2X0
PcTZ00@0PcTZ00<0PCPY08]0<P21=bP01`23>BX00`21=bP0UdTm090o;`0408dl;00308`l;02<>RX0
SC`/00H0SC`/00`0RcXZ09Q5=P2F@c@0Td4a0:A;>`2H@Bl0VT<`09U3<02H@Rl0XDPf0:E<?02I@Rl:
09Y3<00309]3<02QA2l0Y4Hb0080Y4Hb00<0[E0l0:A5<@2QA2l0302TAS801@2bD3d0[DLc0:m8=02_
BSD0[4Da00l0[dPd00D0^e<o0;]?=`2kCcH0_54j0;e@>00?0;]?=`050;Y>=P34DCP0a50g0<QE?P38
ECd01034DCP04034D3L0a4lg0<A?=`34DCP0`Tlf0<5==@38E3/0dem90=EPB`3:Ed00_d/c0<9@=`32
CcH0deTo0=AL@`3FGD<20==J@0030=5I?`3>ECX0cE@i00<0cUDj0`3=E3T60<iE>P030=1F>`3PIDd0
fUe10180f5/m00<0fE`o0>ITB@3WHT@04P3TGd40103TGd00jf520?9WBP3[HD8A0>eR@`040?1UAP3k
L5<0mfI60?QVAQ40mVE500@0m6A40?IR@@3nIT<0ofM5103oJ4H30?mWA@040?aVA03oMEL0ofY80?mX
AP80ofM500h0ofY90?m[B`3oK4/0of];0?m[B@3oJ4D0og5?0?m_C@3oIT80ogEE0?mfE`3oN5P0ofe;
0?mYAP80of]800<0ofU70?m[B03oJdP01@3oJdP0103oJDL0og=B0?m[A`3oKTXA0?m]B@030?mdDP3o
L4X0og1;00`0og1;00<0og1:0?meD@3oL4X00P3oL4/00`3oLT/0ogA=0?mdC@060?mdC@070?m^A`3o
HSX0of4h0?m]A@3oM4d0og=<0?mbBP020?mdC@030?mbB`3oOE/0ogI@00X0ogE>00<0ogA=0?mkE`3o
MDh00`3oMDh01P3oOEH0oh5M0?mhC`3oOEH0ogaC0?mhD0D0og]A00<0ogYA0?mjDP3oNe400P3oNe40
1@3oOU<0lf8n01@7101U7aT0ofEA00H0of9?00<0ofYH0?mQCP3oHTl00`3oHTl00`3oHDh0of5=0?mS
D0040?mSD0090?mSC`3oJEH0ofaJ0?mRCP3oET<0oe0l01P71@000000oeM60080ofEA00H0ofIB0?mU
D@3oJUP0ofQE0?mZE`3oI5060?mUD@070?mTD03oIU40ofIA0?mVD@3oIe<0ofiL0?mUD0050?mVD@07
0?mRCP1>5A0000000<La<03oEE<0of5O0?mCD@050?mBD0070?mCD@3oEU@0oeMF0?mNG@3oEUD0oeQF
0?mBD0070?mCD@030?mDDP3oHf80oeEC00H0oe9A00@0od]:0?mSH`3oeml0ooGno`3oooo^0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo@`3oool01@3o
m_P0gk>_0;UmKP27CCD0Md4W0080ND<Y00<0Q4Xb0818;`1i@bT0201i@bT01P1h@RP0S54h07a5;02@
Dc/0N48X07U3:@80NT@Z00<0O4D/07]5:P1jA2X00P1i@bT01`1g@RP0PdXa07U3:@1f@BP08a8801@8
1`24?Bd01P1h=bT00`1h>2X0McHX07Pe:00407Pg:@0307De9`1g=RP0N3LY00H0N3LY00P0NSP[07He
9`1d<bH0HbPJ05hU5P1Z;Ah0MCDV07Dc9PP0N3LY00<0O3X]07Pg:@1h=bT01@1h=bT00`1j=bX0Q3TZ
08<i:P0508<i:P0308Hl;@22>BX0PcTZ00H0PcTZ00<0PCLX09M9?@2@?bl0102=?2`02P2C@C40TCl_
08hm;@2??Bd0SSd]09M4=@2>?B`0Scd]09=2<P2=?2`208hm;@0309A2<P2RBSX0V48_0080VT<`00<0
VT8`09U2;`2K@c402`2J@c000`2H@Bl0Y4Hb0:A6<P020:A6<P030:Y<>@2TAS80XD@_00`0Y4Hb00H0
/U0m0:e7<`2_B3@0[DPc0;I>>P2^B3@>0:m8=0050;]C?`2kCcL0^Thg0;mC?02mDSX0302kCcL04`2m
D3P0_E0i0;a@>02iCCD0`dlf0<AA>03;F3l0c5U20<QF?@33CcL0`U4g0<A@>03=FT80c5U10<aI@P36
Dc/0`e4g0<AB>034DST00P36DcX01`35DST0a54h0<AA>031CCD0ceDj0<iE>P3?ES/00`3?ECX>0<iE
>P030<mF>`3QIdl0fE`o0180f5/m00<0fE`o0>QUBP3SGT004P3TGd40103UHD<0m6a?0?1TAP3/HD8A
0>eR@`030>mUAP3lL5@0mfE50180mVE500@0mFA40?ER@@3oKTd0oFI51`3oJ4H00`3nIdD0ogEG0?mZ
B0070?mXAP060?mXA@3oJDL0ofe:0?m/BP3oJTL0ofe:0P3oK4T02P3oJdT0of]80?mXA@3oKdh0og9B
0?mbD@3oK4T0ofY70?mYAP3oKT`20?mbD@060?m`D03oLE00ofY50?mcD@3oLU00ofi:3`3oKDT00`3o
M5<0og1:0?m`B`0=0?m`B`050?maC03oLT`0og1;0?m`B`3oLD/01`3oM4d0103oKDH0of8j0?mT?03o
K4D20?mdC@070?meCP3oNU@0ogA=0?mdC@3oLT/0ogmM0?mfD00@0?meCP0>0?mmF03oPE`0ogU?0?ml
DP3oNe80ogY@0?mnE`3oNe40ogmH0?mlDP3oNE00og]B0?moF03oNE020?mkD@050?mkDP3oMTh07`d8
03lD403oJ5@03@3oHTl00`3oHDd0of=@0?mSD0040?mSD0070?mTD@3oHDh0oeA00?mA?@3oE400eDXj
0<I8>P020?mRCP<0ofEA0P3oIU800`3oIU<0ofA@0?mWD`020?mVDP<0ofEA00L0ofE@0?mVD@3oIU40
ofIA0?mVDP3oJED0ofE@00D0ofIA00L0ofEA07XV7@000000HaTG0?m?CP3oDU00oe5?00L0oe9@00@0
oeMD0?mKF@3oE580oe5?203oDe400`3oE580of9Q0?mCD@070?mBD@050?mBD03oEeH0ogAd0?n^/P3o
m_T0o`3oooo/0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
iol0oooo@P3oool00`3ok?80^G=Q07E09P0407U3:@0307I09P1b?R80N48X00T0ND<Y00T0ND8X07]3
:@1i@bT0LchT07U3:@1kA2X0ODH/07]4:P1h@RP0101i@bT01`1h@RP0ODH]07U3:@1e@2L050X401H:
1`24?Bd01P1h=bT0101h=RP0RT<g080l;`1g=RP307Pg:@0307De9`1g=RP0N3LY00<0N3LY00D0McHX
07Pg:P1k>B/0OSX]07Pf:00207Pg:@0506T/7@1N9AH0G2@E06PZ6`1f=RP01`1h=bT00`1n>Rd0N3LY
07Pg:@0407Pg:@0307Lf:028@CD0PCLX00D0PcTZ00<0QS//08Hk;@23>BX01`23>BX03@21=bP0UdTm
090o;`2=?2`0S3/[08dj:`2=?2`0T3h^08`l:`2HASP0VdLi08`k:`2>>b/01P2=?2`00`2D@C80XTXj
09Q2;`0209Y3<00309i6<`2WCC`0V48_00/0VT<`00<0V44^0:I7<`2TAS800P2TAS800`2SAC40Y4Da
0:54;`0<0:A6<P050;9@?@2]Ac<0[dPd0:e7<`2^B3803`2_B3@0102kDcl0^dlg0;]?=`2kCcH30;]?
=`0B0;]?=P2iCCH0^dlg0;]?=`2iCCH0_U8k0;mC?@2lD3T0^Ddf0;U>=P36FT@0bEa80<EH@P2gC3@0
`U0g0<QE?03?FdD0`dlf4034DCP01032DCL0c5Di0=MMA@3?ECXA0<iE>P030<iF>`3QIe00fem20180
f5/m00<0f5/o0>YXCP3RGT00303TGd400`3RH440hEdn0>9M?P030>9M?P040>9N@03^J4X0jelo0>YO
@0D0jV1100<0jem00>]R@`3]HT<02@3]HT<0103^I4H0oG9G0?a[C03eI4@B0?IUA@030?MTA03mIT<0
ofQ600L0ofQ600<0oFM50?meE`3oJTP0203oJ4H00`3oJTL0ofi<0?m[B00=0?m[B0090?mZB03oJTL0
ofY70?mXAP3oLe<0ofM10?m]B@3oMU@0ogIE0080of]700H0ofe90?m`CP3oKdd0ofe:0?m/B03oK4T3
0?m/B0@0ofe900<0ogAC0?m`BP3oL4/03@3oL4/01@3oLdh0ogEA0?m`BP3oL4/0og5;00D0ogA=00L0
ogE>0?maB@3oHSX0ofDm0?m`B@3oMDh0og=<0080ogA=00H0ogA<0?mdC@3oM4d0og9;0?mkF@3oMU0;
0?meCP030?mhE03oMe80ogE>0080ogE>00<0ogYE0?moF@3oNE001@3oNe401`3oN500og]A0?mgCP3o
OeP0ogM>0?mkD@3oNe<00P3oNE00103oOe@08`h903`C3`3oJ5@60?mRC`030?mUDP3oJeT0of5>00@0
of9?00<0of5>0?mRC`3oHe000P3oHe001`3oI540oee:0?mD@@3oCCX0oe0l0?mKB03oI5800`3oHe00
0`3oHTh0ofA@0?mUD@060?mUD@030?mWD`3oJ5D0ofQE0080ofEA00<0ofA@0?mUD03oIU400P3oIU40
0`3oIe@0ofUF0?mVD@050?mVD@0608l[8P000000DA8B0?m>C@3oDU00oe]J1`3oDU001P3oDTl0odm=
0?mBD03oFeX0oeAB0?mDD`H0oe=A00@0oeAB0?mNG03oFeT0oe5@1`3oDU401@3oDE00oeYH0?mED`3o
Ph@0oo7j0?l0ooooj`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOo0?oood00oooo00@0oo3f0?o7a@2mMF@0LchS1@1i@bT00`1k@bT0LchT07Q2:00907U3:@80
N44W00D0ND<Y07I19`1lAR/0OTH/07Y3:P0607U3:@0707I09P1g@BL0ND<Y07E09`0D2P@05PX708@m
;@0707Pg:@0307hj;P1k>B`0McHX00<0N3LY00/0MCDW07Lf:01h=bT0N3LY07Lf:01i=bT0OSX]07Lf
:020?2l0QClc07Pf:00307Pg:@0606L[701L91D0FB8D06P[7@1h=bT0NSPZ101h=bT00`1d<RD0MSDW
07Pg:@0507Pg:@0307Lf:027@CD0PCLX00@0PcTZ00<0PCPY08Tm;`2:?S002023>BX02@21=bP0VDXn
08ln;P2=?B`0UD8b08dm;@2<>RX0UT@c08`j:P0208`k:`P0SC`/00<0U44b0:9:>P2H@Rl00P2J@c00
0`2MAC80XDTg09Q2;`0;09Y3<00809Q1;P2VAc<0Y4Hb0:A6<P2ZC3P0YTPd0:A6<@2QA2l<0:A6<P05
0;9@?@2]Ac<0[dTc0;E=>@2aBSH03`2_B3@0602kDcl0^4`e0;mB>`35FD80^Thf0;]?=P2iCCD0_e<m
0<9E?`2lD3P0^4`d0;I;<`33ET00b5Y60<5D?P2hC3@0^dlg0;U==P2iCCD0^Ddf0;Y>=P34DCP0a58h
0<MD?180a54h00<0beDj0=MNAP3>ECX04@3>ECX00`3@ES/0gF570=MI>`080=QK?@030=IJ?@3EFC/0
eETk0080eETk00L0dUPk0=9G>P3BEcX0dULj0=1I?03@FCh0fem200<0feXm00<0fe/m0=QH>`3HF3/0
1`3HF3/00`3NGT40iVE80>ISA`030>ISA`040>MTB03bJT`0kfQ:0?1YBPH0kfQ:00<0if530=mK?@3Q
G3h0203QG3h00`3TGd80lFY<0>YN?@020>eR@`050>iR@`3`HT80l6920?1R@P3aHd<00`3cHd<00`3d
IDD0mVE50?IUA@060?IUA@030?MVA@3nJ4H0ofQ600L0ofQ600<0oFM50?meE`3oJTP0203oJ4H00`3o
JdT0og9A0?mXAP0@0?m[B0040?mYA`3oLe80ofa80?m]BP80ofa800d0ofe90?m[A`3oKDT0ogIF0?me
E03oKTX0ofY60?m]BP3oLe40og5@0?maCP3oK4P0ofe90080ofa800<0og1<0?m`B`3oL4/03@3oL4/0
1@3oL4X0ofi70?m`BP3oL4/0og5:00@0ogA=00P0ogE>0?m_B03oI3`0of<k0?maBP3oMDh0ogA=0?mc
C080ogA=00D0ogM@0?mgD@3oM4d0ogA=0?mcC00<0?meCP030?mgD03oMTh0ogE>0080ogE>00<0og]F
0?n0F`3oNDl0203oNe402P3oNE00ogUA0?n1G03oOEH0ogU@0?mlD`3oOU<08`h902l>2`3oJ5@60?mR
C`030?mSD03oIE80of5>00D0of9?00X0ofAA0?mSD03oHe00ofAB0?mNB`3oD3`0oe4l0?m@>`3oFTL0
ofAB103oHe000`3oHdl0of9>0?mUD@030?mUD@0:0?mXE@3oKe`0ofA@0?mUD@3oI500ofaI0?mUD@3o
Ie@0ofIC0?mWD`80ofIA00@0ofEA0?mYEP3oKed0ofE@103oIU401`3oJ5@0^3P]0000000K1PH0od]9
0?mCD@3oGE/01`3oDU00203oDDl0oe1>0?mCD@3oFUX0oeAB0?mGE@3oE580oe9@1@3oDe400`3oCdd0
oeME0?mBD@070?mBD@070?mAD03oFUP0oeID0?m@C@3oSHh0onC/0?omo`3o0?ooonT0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooolo0?ooo`040?o]l@3D
R7/0PTT`06hj7@D0ND<Y00@0N48X08iC>P1oAbd0Md4W201i@bT01`1i@RP0Q4Xb07a5:`1kA2/0MT4W
07i6;01h@RP01P1i@bT0201i@RP0OTH/07]4:`1i@bT0MD0W01D:100F2PL0Q3d]1P1h=bT00`1g=RP0
LS4S07Lf:00307Pg:@0<07Pe:01e<bH0N3LY07Lf:01g=bT0OS/^07/h:P23?S40MC@V07Lf:01k>2/0
N3PY0P1h=bT0201i>2X0N3DX06h_801K91H0G2@E06X]7P1e<bH0NcX[0`1h=bT00`1n>Rh0NCPZ07Pg
:@0507Pg:@0307Lf:027@CD0PCLX00D0PcTZ00<0PcXZ08<i:`23>BX01P23>BX02P22>BX0PCLX0994
=`2IASP0SS`/09Q4=@2??bl0RcTX09Q5=P2>>b/:08dl;00709A1<P2RBSX0V48_09Y3<02J@S00UCl/
09E0;@0<09Y3<00809Q1;P2VAc<0Y4Hb0:A6<P2VB3@0YTLc0:A6<@2QA2l<0:A6<P050;9@?@2]Ac<0
[DLc0;I@?02aBcL0302_B3@0202]B380[DHb0:m8=02iD3`0`E@n0<IJA036FTD0_54j0P2hC3@02031
ECl0aEY30;a@>@2hC3@0^dlg0;Y>=P2iCCD0^dlf1@2kCcL0102jCSH0a54h0<EC>P32CcHB0<AA>003
0<MB=P3=E3X0cUDj00h0cUDj00L0ceLk0<aC>03<DcP0bE<h0=INA@3AEcX0cePk00<0cEHk00X0cEHj
0<YE>@3:ECT0bU@i0<iG?03LHDL0h6=90=mRB03RHdP0kfU;0P3bJT`01P3aJDd0o6M60?mZA`3oKd`0
ofe80?m]B@80ofa800<0og=<0?mdC03oM4`01P3oM4`00`3oNU<0ohAN0?n5GP040?n5GP030?n8H03o
RV@0ohUQ00D0oh]R00<0ohUQ0?mmEP3oMTl02@3oNE401P3oN540ogUD0?mfD@3oMU40ogE@0?mdD@<0
ogAE00D0ofm@0?Y/CP3kKDl0nfa?0>iSA0030>QM?P070>YP@@3]H480jf120>]P@P3^HD80lfA50?aW
A@020?aU@P030?eWA@3oJ4H0ofQ600<0ofQ600<0oFM50?meE`3oJTP0203oJ4H00`3oJTH0ofa:0?m/
B00A0?m[B0040?m]BP3oLE00ogEC0?m/B0@0ofe90P3oK4P20?m]B@0;0?m^B`3oME@0ogED0?mcD03o
JdH0ofe90?mdDP3oM5<0ofi:0?m`BP3oL4/00P3oL4X<0?m`B`040?meC`3oLTd0og1:0?mcCP<0ogA=
00H0ogE>0?m`B@3oHc/0of4i0?m[@`3oMDh20?mdC@050?mcB`3oM4d0ogA=0?mcC@3oMDh00P3oM4d0
0`3oM4/0ogE>0?meCP0;0?meCP070?mhD03oMDh0ogE>0?meCP3oNeH0oh1K0?miC`090?mkD@090?ml
DP3oNe<0ogU?0?mkDP3oOED0ogaA03lH400F1`H0ofUD00L0of9?00<0of1<0?mQCP3oHTl00`3oHTl0
2P3oIe@0ofQE0?mSD03oI580oei:0?mC?`3oD3`0oe4m0?mKB03oHdl50?mSD0030?mTDP3oIE80ofEA
00<0ofEA00<0ofIB0?mXE@3oIE400P3oIE420?mTD080ofQE00<0ofYG0?mUC`3oIU400P3oIU400`3o
Ie<0ofA@0?mVD@030?mVD@080?mYE03?@CD0000001P4103oBdX0oe9@0?mAD03oD4h60?mBD00:0?mA
C`3oD4h0oe=A0?mAC`3oD4h0oe9@0?mED`3oEeD0oeAB0?mBD0<0oe=A00<0odm>0?mAC`3oDDl01`3o
DU40203oDDl0oemM0?mDDP3oDe40od]70?mYIP3o^;`0ooGio`3ooooX0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo?@3oool01@3olO<0fkF_0:IVDP1f
@2H0MT4V00L0ND<Y00<0PDT`08Y?=`1i@bT0201i@bT01@1i@RP0QD`c08A;<@1i@bT0MD0V00P0ND<Y
00P0ND8X0858<01mAB`0ND<Y07E09`091@806@/808@m;@H0N3LY00<0O3X]080k;`1g=RP00`1h=bT0
1@1f=BL0MC<V07Xh:`22?C00N3LY0080NCPZ00<0N3LY07Lf:@1l>R`01P1h=bT02`1g=RP0Qd8f06/^
801M9AH0H2HG06P/7@1f=RL0NCPZ07Lf:023?S80NCPZ00H0N3LY00<0McHX08M1=@21=bP01023>BX0
0`25>R/0RSla08<i:P0408<i:P08088i:P27?2h0Q3X/08Ll;P23>BX0TdDh09=1<P2>?Bd208dl;003
08`k:`2>?Bd0SC`/00X0SC`/00L0Td4a0:18=`2I@c00VT<`09]4<@2SBSP0V48_00`0VT<`00P0V44^
0:I7<`2TAS80Y4Ha0:E7=02TAS80Y4Da0:54<0`0Y4Hb00@0/U0m0:e8<`2aBSD0/4Td1@2_B3@20:i8
=00B0:m8=02aBSH0]Dlk0;E?>P2]Ac80[dTd0;QB?P2hDch0[dPd0;YB?@2nDCX0`5@m0;a@>@2lD3P0
^Thg0;]?=`2jCSL0^Thf2`2kCcL00`2iCSH0aE4h0<UF?P0C0<AA>0040<iH?P3=E3T0cE@i0<aD>@80
be@j01<0be@i0<UC>03;DcT0deTo0=UM@`3RH4D0hf560>=P@`3RHD40hF510>1S@`3OHD40jg1@0>ib
DP3eMe@0oGeI0?emF03oO580og]@0080ogaA00H0ogmB0?n4EP3oQ5H0ohAF0?n6F03oRE`20?n:G003
0?n;G03oS5d0oheN0080oheN00P0ohaK0?n<FP3oSUd0oi1P0?n@G@3oTEl0oi1N0?nBH0P0oi=Q00<0
oi=P0?nBG`3oTUl00`3oTUl01P3oTf40oj1c0?nFI@3oUVD0oiQW0?nGI@D0oiIU2P3oUfH00`3oVVP0
oj5e0?nNK`020?nMK`090?nLKP3oVfl0oi]_0?nLK`3oVfl0oiM]0?nHK@3oV6h0oiEZ0080oi9X00<0
oi=X0?n@I@3oRf000P3oSF404`3oRf40ohYT0?n<J`3oQfH0ohUX0?j0GP3iO5L0ngMC0?]eD@3lMU80
o7EB0?a`C`3oN5X0oW1?0?eXA@3kIT<0o6M50?aXA@3mJ4D00P3mIdD00`3nIdD0ofY80?m[B00B0?m[
B0030?mZAP3oK4T0ofe:00X0ofe90P3oK4P00`3oKDT0ofe:0?m]B@020?m`C@0:0?m]B@3oL4X0og1;
0?mfDP3oME40ofm90?m`BP3oLdl0ogA@0?m_BPL0og1;00@0ogE@0?maC@3oL4/0ogQE0P3oM4d01@3o
MDh0ofm80?mS>`3oHSX0ofU100<0ogA=00T0og=<0?mhDP3oM4d0ogA=0?mcC03oMe40og=<0?mdC@3o
M4/03@3oMDh01`3oNE<0ogI?0?meCP3oMDh0ogMB0?mlE@3oNU002@3oNe400`3oNU40ogYB0?mnEP02
0?mjD@080?moE01N9QL07`X80?m]F@3oIE80of1=0?mUD`3oHTh30?mRC`030?mXE@3oIeD0of9?0080
of9?00`0of5>0?mXE@3oJEH0oee:0?mF@`3oDSh0oe<o0?mKB03oHTl0ofA@0?mXEP3oHdl30?mSD003
0?mSC`3oK5X0ofiK00D0ofEA00<0ofIB0?mVD`3oIE40103oIE40203oJUH0of]H0?mWE03oJ5D0ofQD
0?mUD03oJ5@0ofYG103oIU40203oJE@0fd@g00@10@050@40o4Y80?mBD03oDe40oe]I203oDU002@3o
DU40oe=A0?mLFP3oE5<0oe=A0?mDDP3oEU@0oeEC0?mDDP030?mCD@030?mCDP3oFUT0oe5@00H0oe9A
00X0oe5@0?mNG@3oIF<0oeIC0?mEDP3oCdd0oeQF0?n?T03ohN@0ookoh`3oool01P1UADP000000000
000c8b@0IDI80<bn`o`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3oooll0?ooo`040?n[Y@2<DCT0JCLJ07M2:0P0ND<Y00<0MClU07Q2:027C3@0201i@bT0
1@1jA2X0O4D/07<n901h@RP0Md4W00T0ND<Y00P0N44W07Do9@1i@bT0ND<Y07E09`0000007`h:084k
;0H0N3LY00<0NcP[07/i;01h=bT00P1h=bT01@1j>2X0NcT/07Dd9P1k>B/0McHX00@0N3LY00<0McDW
08U3=`1m>Rd01@1h=bT02P1e=BL0STLk07`j;01a<R@0HBLH05`T5@1Q9aP0MCDW07@d9P1e=BL707Pg
:@0307Lf:027@CD0PCLX00@0PcTZ00<0Q3X/08m1<`22>BX00P23>BX02@20>2P0SD4c080h:026>b`0
Q3X[084h:@21=bP0VTXm090o;`0208dl;00308`k:`2E@c<0T3h^00/0SC`/00H0SS`/09M1;P2J@c00
VT<`09U2<02H@Rl=09Y3<00709Q1;P2VAc<0Y4Hb0:=5<@2ZBcT0Y4Hb0:53;P0=0:A6<P050;9@?@2/
AC40]e4m0;UC?`2^B3<00P2_B3@02P2]B380/d`h0<1HAP2iDch0[4La0;19=02cC3P0/T`h0:e7<`2_
B3@20:e7<`050:m8=02jDch0_U8j0<EI@`2iCCH0402kCcL00`2jCSH0ae8i0<9@=`0:0<AA>0L0`U4h
0180`Tlf0<=?=@3TGd80jfU?0?YaE03oM5P0og5=0?mbB`3oN4l0ogiC0?moE03oPEP0ohEJ0?n7F`3o
R5/0ohQJ0?n9F@3oR5T20?n<F`0:0?n:FP3oRET0ohQJ0?nEJ@3oSUd0oi1P0?n;FP3oS5/0oheL0?n=
F`h0ohaK00@0ohmL0?n>G@3oT5d0oi9T403oTEl01`3oTV40oiea0?nDH`3oUF@0oiMW0?nFI03oU6<0
3P3oUF@01P3oVFL0oj9f0?nMK@3oWVh0oiia0?nOL0`0oii^0`3oWg001`3oWVh0oi]_0?nUP@3oYX80
ojAn0?nTP@3oYX800P3oY7h02P3oXgd0oj9o0?nPO03oWgX0oj5l0?nJMP3oV7<0oi5/0?n;IP3oRVH2
0?n7J0040?mmGP3oN5L0ofI20?mYAPD0ofY73@3oJdP00`3oL4h0ofa80?m]B@0@0?m]B@040?m/B03o
L4/0og1;0?m`BP80og1;00T0og5;0?mdCP3oM4h0og190?m^A`3oMU<0ogYG0?m_B@3oL4X00P3oL4/0
2P3oL4X0ogEB0?mbCP3oN5@0ogA=0?meCP3oLDX0of@l0?mR>P3oKdP40?mdC@030?mbB`3oO5L0og=<
0080ogA=00D0ogI@0?mdC@3oM4d0og=<0?mdC@0=0?meCP050?mfC`3oMDh0ogE>0?mcC@3oMTh02`3o
Ne40203oNe80ogaD0?mkD@3oNe40ogeC08Dc800J20H0ofYE0P3oHTl0203oIE40of9?0?m/F`3oH4`0
of9?0?mQCP3oH4`0of5>0P3oHTl0203oHDh0ofQE0?mMBP3oD3`0oe4m0?mC?P3oHDh0ofAB0P3oHe00
0`3oIU@0of=@0?mSD0020?mSD0030?mSC`3oJeP0of]I00D0ofEA0P3oJEL00`3oI500ofEA0?mUD@02
0?mUD@090?mZEP3oK5X0ofE@0?mVD@3oIe<0ofQE0?m[F@3oJUL0ofEA00<0ofIA00D0ofUD0>m9>`0:
0@4000000?M9A`020?mBD0030?mGE@3oDU00oe9@00@0oe9@00D0oe5?0?mHE`3oEeH0oe=A0?mGE@04
0?mCD@060?mBD03oE5<0oeUF0?mDDP3oDe40oeAB203oDU402`3oDE00oeeL0?mHE@3oE580oeEB0?mC
D@3oGE/0oeIC0?mKF@3oUiP0ooOo0>80oooo00<0OUMJ0000000000000P0000000`0V6Q/0oooo0?oo
o`3j0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo
>`3oool0103W^;@0PTT`07]4:@1e?bD807U3:@0407U2:02>DSX0OTH/08M<<`L0ND<Y00H0Nd@Z07a4
:P21B2l0OTH]07U2:01g@BL807U3:@0307Q2:022BC00Q4Xb0080ND<Y00@0MD0W0000000N3PX0PC//
1P1h=bT0201f=BL0N3HX07Pg:@1j>2X0OSX]07@d9P1g=RP0MC<V1`1h=bT00`1e=BL0N3LY07Pg:@04
07Pg:@0:07De9`2>Ac/0NcT[07Pg:@1e=BL0Ib/L05dU5P1O9QL0NST/07Xh:`L0N3LY00<0N3HX08I0
<`21=bP01023>BX01`20>2T0PCPY088h:@26>bd0Sd8d08<j:`24>R/01023>BX00`21=bP0VTXm090o
;`0208dl;00308`j:P2IASH0TCl_00/0SC`/00H0SS`/09M1;P2J@c00VT<`09Q2;`2J@Rl=09Y3<007
09Q1;P2VAc<0Y4Hb0:=5<@2SA340Y4Hb0:53;P0=0:A6<P0;0;9@?@2_B3@0/4Te0:m8=02eCcX0_EM5
0;I@?02/Ac40/4Te0;1:=P2`BCD00P2_B3@00`2_BC<0[dPd0:m8=0040:m8=0030;]C?`2hC3D0^Dde
0140^dlg00H0^Thf0=5MAP32D3L0`U0g0<9@>031D3P20<5@=`050<=B>@35DST0ae<j0<MB>@39DcT0
0P3<DSL03P3UHdT0m6]@0?meE`3oLDh0ogA<0?mnDP3oPeD0ohEF0?n<H@3oQUT0ohMJ0?n7F@3oR5T0
ohUJ0P3oReX00`3oQeT0ohYI0?n8F@080?n8F@060?n8FP3oU6T0ohaK0?n<FP3oSel0ohiO403oS5/0
1P3oSe`0oi5O0?nAG`3oTEl0oi1O0?n@H0h0oi5O00<0oi9Q0?nML@3oU6<00P3oUF@00`3oTf80oiUW
0?nEI00=0?nEI0060?nII`3oXWH0oie]0?nNKP3oWFd0oimc3`3oWVh0103oWFd0oia_0?nUP03oYX42
0?nSO@D0ojAn0P3oY8000`3oZhL0ojF10?nSO`030?nTOP80oj=n00X0oj5l0?nVR@3o[IH0ojV?0?nO
P`3oV7`0oiAi0?n3I`3oOf80ofe;0P3oKT/20?m/BP030?mZB03oJTL0ofU600@0ofY700<0ofa90?mf
EP3oJdL04@3oKDT00`3oK4P0og1;0?m`B`070?m`B`0@0?m_BP3oLD`0og9=0?m`B`3oKdP0ogA@0?ml
FP3oLD/0ogE@0?mbC@3oMe<0ogE>0?maBP3oI3d0of4i0?m_A`D0ogA=00<0og9;0?mlE`3oLd`00P3o
M4d20?mcC0<0ogA=3@3oMDh01@3oOU/0ogI?0?meCP3oLdd0ogI>00`0og]A00L0ogQ?0?mkD@3oNe40
ogiC09dm9P0I20H0ofYE00@0of9?00H0of=A0?mQCP3oJUL0of5>0?mWE03oIU<20?mRC`060?mPC@3o
ET80odlk0?m@?03oEd<0of5=103oHe000`3oHTh0of=?0?mSD0020?mSD0030?mSC`3oK5X0ofiK00D0
ofEA00<0ofA?0?mSCP3oI500103oIE400`3oJUH0ofaJ0?mUD0040?mVD@030?mXE@3oIe<0ofIA0080
ofIA00D0ofUD0>m9>`0?108000000?E8A`020?mBD0030?m@CP3oDU00oe9@00@0oe9@00H0oe5?0?mJ
F@3oEeH0oe=A0?mBD03oDDl50?mCD@060?mDDP3oEeD0oeME0?mIE`3oDDl0oe5@1`3oDU402`3oDU00
oe=@0?mDD@3oEE80oe=A0?mLFP3oF5H0oe=?0?mFE03oKVd0onCX0>40oooo00<0bH^@0:AaM@2GJ6`0
0`0000000`3RW:80oooo0?ooo`3i0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0oooo>@3oool01P3on_l0ol6o08Y@>@1i@RX0QT/d07Q19`T0ND<Y00<0Re0g
07a5;024BS801@1i@bT0201iA2T0OTH]07E09P1i@RP0RTlf08A:<P1h@RP0Md4W201i@bT02@1h@RP0
Q4Xb08M<=01i@RP0ND<Y07E09`0000007Ph:084k;00607Pg:@0807/i:`1j>2X0MC@V08Q1=P1h=RT0
N3LY07Pe:01g=BP607Pg:@0307Lf:01g=2L0N3LY00D0N3LY00<0MCDW08i6>P1k>B/00`1h=bT0101X
:a`0GRDF05TQ501X:Q`707Pg:@0;07Lf:028@CD0PCLX08<i:P21>2T0PcTZ08Hk;@26>b`0PcX[08Xo
<P21>2T01`23>BX00`21=bP0VTXm090o;`0208dl;00308hk:`2;?2X0SC/[00/0SC`/00H0SS`/09M1
;P2J@c00VT<`0:9:>02J@Rl=09Y3<00709Q1;P2VAc<0Y4Hb0:M:=P2UAc<0Y4Hb0:53;P060:A6<P0;
0:A6<@2SAC40Y4Hb0:E7<P2WBSH0YdPd0:=5<@2`Cc/0_EI20;19=@2/A2l0402_B3@00`2kDch0^D`e
0;]?=`0=0;]?=`0C0;Y>=`2hCCH0]T`f0;E<=P2dBS@0aE@l0<EC>`3;ESh0ceDk0=5E>P3HF3X0fEPj
0?9XC@3oLU@0og]K0?miD`3oN4h0oh=E0?n7E`020?n5E`@0ohMG00@0ohIG0?n=H@3oR5T0ohUL0P3o
QUP?0?n8F@060?n8FP3oUFX0ohaK0?n<F`3oS5X0ohiO403oS5/0203oSe`0oi5O0?nAG`3oTEl0oi1N
0?nDI@3oT5d0oi5P303oTEl00`3oTV40oiea0?nDH`030?nEI0030?nFI03oVVT0oiIU00`0oiET00<0
oiUW0?nRMP3oWFd00`3oWVh00`3oWg80oii^0?nNKP0<0?nNKP070?nMK@3oW6l0ojF00?nTOP3oY7d0
ojF00?nTO`060?nTOP030?nSO@3oY7h0ojAn00D0ojAn00D0oj=m0?n[SP3o/i`0ok:L0?n`VP040?n`
V@070?n`V03oYHX0oj>70?nHOP3oU7T0ohU]0?mjF`020?mbD0070?m_C@3oKdh0ofi<0?m[B03oK4P0
ofY30?mYA0020?m[A`l0ofe900<0ofm90?m`B`3oL4/03P3oL4/02P3oKTP0ofm90?mmF`3oME00ofLn
0?mP>03oJ440og9<0?mdC@3oLd`30?mdC@030?mbB`3oNeL0og=<0080ogA=00<0ogM@0?mkE`3oLd`0
0P3oM4d=0?meCP050?mfC`3oMDh0ogE>0?mcC@3oMTh02`3oNe40203oNE00ogaD0?mkD`3oNe40ogiC
09Xj9@0I20H0ofYE1`3oHTl02P3oH4`0ofMD0?mXEP3oHe00oei:0?mB?P3oD3/0oe4l0?mLB@3oI585
0?mSD0030?mVD`3oIU@0of=@0080of=@00<0of=?0?m]F`3oKU`01P3oIE420?mWE0@0ofEA00<0ofIC
0?mWE03oI500103oIU400`3oJ5D0ofUF0?mWE0020?mWD`050?mXD`3oE4<0>Pl<0000003eAdH00P3o
DU000`3oDe40oeAB0?mBD0040?mBD0030?mAC`3oFEH0oeMF0080oe=A00<0oe]J0?mCD@3oDe401@3o
De401@3oE5<0oeIE0?mIE`3oFEL0oe5@00H0oe9A00L0oe5?0?mCD@3oFEL0oeEB0?mCD@3oGE/0oeYG
0080oeEB00<0oe=@0?n2P@3om_h0h`3oool01039Ri0000000000001;=3Kk0?ooo`040>WYj@3AdM40
dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo=`3oool0203omOH0h;Rc0;E`
GP1kA2X0N48X07U3:01j@bP0ND<Z2@1i@bT02@1h@bP0NT@Z08iC?01i@bT0ND8X07]4:P1h@RP0NdD[
07]4:P0207U3:@0507U3:01i@RP0NT@Z07U3:@1kAB/02@1i@bT0201h@RL0ND<Y07U3:@1j@bT0Fc0L
0000000[50h0P3//101h=bT02`1k>2X0NSPZ07dj;@1j>2/0NcT[07Pf:01h=bT0McHX088m<02:@SH0
McLY00@0N3LY00<0McHX08<n<@22?S401P1h=bT00`1f=BL0SDHj07/i:`0307Pg:@0807Lg:@1a<R<0
IRXK05hU5P1T:AX0LS<T07Tg:@1i>2X307Pg:@0607Hf:028@CD0PcTZ084h:@2<@380PcT[0P2:?c40
0`22>BX0PcTZ08<i:P0708<i:P03084g:02KBch0T3l_0080SC`/00<0Td8a09=1<P2=?2`02`2=?2`0
1@2>?2`0Ud4^09Y3<02J@c00VT<a00h0VT<`01P0V44^0:I7<`2SAC00Zd`i0:I8=02TAS80XD<^0:A6
<@2TAS80YTLc0:Q;=`2WBCD0Y4Ha0:a=>P2]Cc/0YdLd0:E6<P2[CCT0Z4/g0:A6<@2aD3d0/DXe0;E?
>`2]Ac<@0:m8=0030;]C?`32ET00^Thf00<0^dlg01D0^Thg0;U==P2gCCH0]Tdf0;A<=@2iCcP0`5<l
0<IC>`39ECX0cU@i0=YOA@3RJDd0iFU80>MXA@3_LDX0ogYA0?n1G03oPeX0oh5F0?n1E03oQUL00P3o
QeP30?n6E`030?n6F03oQEL0ohEG00H0ohEG00P0ohIH0?nAI`3oQeT0ohQJ0?n9F@3oRe`0ohYJ0?n9
FPd0ohQI00<0ohQJ0?n<G@3oS5/00`3oS5/0103oSEd0oheL0?n=G03oSEd<0?n<F`030?n>G03oTEl0
oi5O00<0oi5O00@0oi1N0?nAH@3oTF00oi5P2P3oTEl00`3oTV40oiea0?nDH`050?nEI0030?nGIP3o
VFP0oiIT00X0oiET00<0oiIW0?nRMP3oWVh0103oWVh0103oWVl0oima0?nOK`3oWFh:0?nNKP030?nP
L@3oYGd0ojAo00<0ojAn00<0ojJ10?nVP03oY7h0103oY7h00`3oY7l0ojF00?nTOP050?nTOP060?nT
O@3o[I40ok6I0?nbVP3o/i`0ok6J103o/9T20?n`VP80ok6J0P3o/I/05@3o/Y/0ojfE0?nXT03oZI40
ojB=0?nQRP3oZIP0oj6=0?nGPP3oTWX0ohU^0?mjFP3oN5P0ogAC0?maCP3oKd`0of]70?mZA03oJTD0
of]60?m[A`050?m]B@030?m_B@3oL4/0og1;00l0og1;00l0ogIC0?e_B`3oICd0of8j0?mV?P3oLdh0
og9;0?mfD03oNUH0ogI?0?mdC@3oMU00og==0?mjEP3oLd`00P3oM4d01@3oM4h0ogE?0?mdC@3oM4d0
ogM@00h0ogE>00D0ogYD0?meCP3oMDh0ogE>0?mjD00:0?mkD@090?mjD@3oNe80ogYA0?mkD@3oOE<0
bE0c00l5103XC3d0ofIC00L0of9?00P0of9>0?mPC03oF4D0odlk0?m@>`3oDd00oem<0?mUD`H0of=@
00<0ofEB0?mUD@3oHdl00`3oHe000`3oIU80ofMC0?mUD@040?mUD@030?mTD03oJeP0ofQE00@0ofEA
00<0ofA@0?mUD03oIU400`3oIU403`3oIE00ofYG0?mXE03oIU40ofQE0?mWD`3oJeP0oeI403/@3@00
0000gD4o0?mCD@3oDU00oeEC0?mFE0050?mBD0030?mAC`3oFeP0oeMF0080oe=A00<0oeYI0?mCD@3o
De401@3oDe401P3oEE<0oeUH0?mIE`3oEE<0oe=A0?mCDPD0oe9A00L0oe9@0?mCD03oFUL0oeEB0?mD
DP3oEe@0oeMC00@0oeEB00<0ofYY0?nWZ`3ohnH0hP3oool0101aCU4000000000003T][gj0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo=P3oool00`3o
nol0cH=e06<c5@0307U3:@0307I19P1e@2D0ND<Y00P0ND<Y00P0OdH]07i6:`1i@bT0SU<l07Y4:P1n
AR`0Nd<Y07a4:P@0ND<Y00D0NT@[07i6;01i@bT0ND<Y08I<=00807U3:@0@07m7;P24BS80N48X07U3
:@1k@bT0DR/H0000000a5Q00OSX[07Pg:@1g=RP0O3T/07Dc9P1n>bd0NcT[07@d9P@0N3LY00@0McHX
08<n<@2<A3P0McHX101h=bT00`1g=RP0MC<V07Pe:00607Pg:@0307De9`2>Ac/0NcT[00<0N3LY01<0
McHX08U3=`20?2l0Kc0R060V5`1L91D0IBXK078c9@1i=bX0McHX07De9`24?c80QClb08Tm;`20>2P0
PCHX08<i:P21>2T0P3PX00X0PcTZ00<0PCLX09I6>@2@?Rh00P2=?2`00`2B?bl0TT4`08dk;00;08dl
;00508hl;02G@Bh0VT<`09Y2;`2OAcH03P2J@c00102H@Bh0YTLc0:M8=02SA3020:=5<0090:M:=@2^
Ccd0Y4Da0:M7=02^D3h0[4dj0:A6<@2SAC40XdD`00D0Y4Hb00<0[dhk0:e7<@2]B3804@2_B3@04P2g
Cc/0]T/c0;I;=@2cBS@0/DXe0:a7<@2kDSd0bEY40=mPA@3aHd80oFE20?maCP3oOET0ogmE0?moD`3o
R5P0ohMG0?n6EP80ohIG00D0ohAG0?n:GP3oQEH0ohQJ0?n8F@0@0?n5E`030?n6F03oTFT0ohIH00<0
ohQI00@0oh]K0?n:G03oRU/0ohIH303oR5T00`3oR5L0ohaK0?n<F`050?n<F`030?n>GP3oSE`0ohaK
00X0ohaK00<0oheK0?nAG`3oTEl01@3oTEl0103oTEh0oi=S0?nBH@3oT5d80?nAG`030?nBH@3oWG40
oiAS00H0oiET00<0oiQV0?nIJ03oUfD02@3oUF@00`3oUVL0oj=g0?nMK@060?nNKP030?nNL@3oVV`0
oii^00T0oii^00<0oj1b0?nXP@3oY7h0103oY7h00`3oYX80ojAn0?nSO@040?nTOP030?nVPP3oXgd0
ojAn00@0ojAn00<0ojF10?n`U`3o/9T00P3o/9T00`3o/I/0ok:I0?n`V@0=0?n`V@0F0?nfY03oc<@0
olc40?o;a03ocLL0olk80?o@c03oblD0okjd0?ncYP3o[Ih0oj6?0?nDO03oR6h0oh1S0?mjFP3oJT@0
ofDn0?mW@03oJD80ofU50?m^Aa40og1;00h0ofm:0?=M>@3oHSX0ofU10?mdC@3oMDh0ogA=0?mbC03o
LT/0og=<0?meCP3oNeL0ogMA0?mgDP80og]G00H0ogE>0?mcC03oMe80ogQB0?mbB`3oO5L>0?meCP05
0?miDP3oMDh0ogE>0?meCP3oNU002`3oNe40203oNE00ogiF0?miD03oO580gUXi00d30`3MA3L0ofMC
1@3oHTl0303oHe00of9?0?mJA`3oCCX0odlk0?mC@03oG4T0of=@0?mRC`3oJ5D0of5=0?mZF080of=?
0`3oHe000`3oIU@0ofA@0?mSD0020?mSD0030?mRCP3oHdl0ofEA00D0ofEA0P3oI4l50?mUD@030?mS
C`3oIE00ofIA00<0ofIA00<0ofE@0?mVD@3oIU400P3oIU401P3oIe80oea905XI4P000000Qb@T0?mC
DP80oe9@00<0oe5?0?mBD03oDU00103oDU001@3oDDl0oe9@0?mCD@3oDe40oe5?00L0oe=A00L0oeAC
0?mHF03oDE00odm=0?mDDP3oEE<0oe5@00D0oe9A00H0oe=@0?mCC`3oEE80oeEB0?mCD@3oEE430?mE
DP050?mED`3oEU@0odQ70?mQH@3ocM80h@3oool0103l[K@000000000001nEe[j0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo=@3oool0103oinh0dHEh
07]3:@1kA2X207U3:@0307Y4:P25C3<0LSdS00T0ND<Y00L0Pd/b0857;`1i@bT0RDlg07e6;01nAR`0
MT4W00D0ND<Y00D0PDT_08]@=`1h@BL0ND<Y08E<<`0807U3:@0@0858;P27C3@0MT4W07U3:@1k@bT0
EB`I0000000a5Q00Oc/[07Dc9P20>bl0NcT[07Ld9`1g=RP0NcP[07`i;0@0N3LY00@0McHX08<n<@2<
A3P0McHX101h=bT00`1j>2/0NcT[07Lf:00607Pg:@0307De9`2>Ac/0NcT[00H0N3LY00/0NSPZ070`
8P1L91D0G2@E064W601h=RP0P3/^07Dc9P20?2l0QT0d080f9`0308<i:P030915>023>BX0PcTZ00X0
PcTZ00H0QcX[08dl;02=?2`0S3/[08Pg9`2;>RX<08dl;00508hl;02G@Bh0VT<`09Y3<02QB3L03P2J
@c00302G@Bd0Xd@`0:U9=P2aE440ZT/h0:53;`2VBC@0[Dlk0:E7<`2TAS80XdD`0:=5<@P0Y4Hb00<0
ZTPd0;YD@02]Ac<03@2_B3@04`2^BC@0ZTHb0:U5<@2VAC80[D/g0<9G@@3AGTP0iV=:0?QUA03oK4P0
ogMA0?mlEP3oP5L0oh=E0?n9F@3oQeL0ohIF0?n6E`3oQEL01@3oPeH0203oQ5L0ohmV0?n5E`3oQEL0
ohIH0?n9FP3oRE/0ohIG3P3oQEL00`3oRE/0ohQI0?n8F@030?n8F@040?n9FP3oR5X0oh]N0?n8F0/0
ohQI00<0ohQG0?n<F`3oS5/01@3oS5/0103oS5X0oheM0?n>GP3oRUT90?n<F`030?n=F`3oTEl0oi5O
00H0oi5O00<0oi5Q0?n@G@3oTV40203oTEl00`3oTV40oiea0?nDH`070?nEI0030?nFI@3oUfD0oiQW
00P0oiET00<0oiIW0?nSM`3oWFd01`3oWVh00`3oWFd0oia]0?nNKP080?nNKP030?nPLP3oYh40ojAn
00D0ojAn0P3oYGh40?nTOP030?nTO`3oYh80ojAn00<0ojAn00<0oj=m0?nVPP3o/9P00`3o/9T00`3o
/9X0ok6J0?n`V00<0?n`V@050?n`V03o^jT0ol[20?o9`@3ob/800`3obL404`3ob/80olc50?o<aP3o
cLL0olo90?o<aP3o`kT0okfb0?nfZ`3oZi/0oif:0?nDO`3oRVl0oh1Q0?m^A`3oJ3d0ofY10?m/A03o
KdT03@3oL4/01@3oIT00k5Te0?mZ@@3oLd`0ogE>00H0ogA=00<0og=<0?mcB`3oN5800P3oNU@20?md
C@040?mkF03oNU@0og9;0?mkEPh0ogE>00D0ogA=0?meCP3oMDh0ogA<0?mgCP0<0?mkD@070?mkDP3o
Ne40ogaB0>ML>`080P80`3/_0?mXE0060?mRC`0=0?mE@P3oD3`0oe0k0?mD@@3oGd`0of=@0?mRC`3o
HTh0of=@0?mRCP3oJEL0ofIC0?mWE@020?mSC`030?mSD03oKeh0ofID00<0of=@00<0of=?0?mRCP3o
IE401@3oIE400`3oIU80ofiK0?mVD`040?mUD@030?mSC`3oIE00ofIA00<0ofIA00<0ofE@0?m[F@3o
IE000P3oIU401P3oJ5<0oei:06/N5P000000/38b0?mDDP80oe5?00<0oeUF0?mAC`3oDU00103oDU00
0`3oDDl0oe9@0?mCD@020?mCD@030?mGEP3oDe40oe=A00@0oe=A00P0oeAB0?mCDP3oDE00oeMF0?mF
E03oDe40oeME0?mCD@<0oe9A00<0oe5@0?mNG03oFEL00`3oEE802P3oE540oeEB0?mEDP3oEE80oeEA
0?mGE03oGE`0ode;0?maL@3okoWQ0?ooo`<0000000<0oo?l0?ooo`3oool0m`3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooc@0oooo00@0okfj0:QWDP1/
>Qd0Md8X0`1i@bT0101jA2X0U5Lo08Q==@1h@BL807U3:@0507Y3:P1i@bT0MT4V07i6:`1jA2X01`1i
@bT01@1j@bT0Nd<Y07U2:01i@bT0QD`c00P0ND<Y0P1h@RP207U3:@0707]3:@108a<0000002dD3P24
?Bl0NSHY07Xh:`0207Pg:@0307Lf:020>bh0OcX^00@0N3LY00@0McHX08<n<@2<A3P0McHX101h=bT0
0`23?S40Qd4d07Le9`0607Pg:@0307De9`2>Ac/0NcT[00@0N3LY00d0N3HX07Pg:@1h=bT0NCLY06h`
8@1Q9aP0F24C06DY6P1h=bX0N3LY07De9`2:@SH0PCLX00<0PcTZ00<0T4@g08<i:P23>BX02P23>BX0
1P25>BP0SSd/08dl;02B?bl0Td8c08`j:``0SC`/00D0SS`/09M1;P2K@c00Ud0^09U2<00;09Y3<00;
09Q2;`2J@c00V40^0:E;>P2WBCD0Y4Db0:Y=>P2WBCD0Y4Hb0:54;P2SAC40302TAS800`2WAC80]Tlj
0:m9<`090:m8=00B0:i8=02/Ac<0ZTHb0:U7<`2/B3@0bEY50=iTC@3fI4@0og=?0?n1F`3oO5@0oh5H
0?n3EP3oQUP0ohMG0?n6EP3oQEL0ohAG2P3oPeH00`3oQ5L0oi1V0?n5EP020?n5E`040?n6F03oQeP0
oheP0?n5EPd0ohEG00<0ohAD0?n8F@3oR5T0103oR5T0103oRET0ohYJ0?n8F@3oRE/;0?n8F@030?n<
FP3oS5/0ohaK00D0ohaK00@0oheL0?n;FP3oSf00oheL203oS5/00`3oSE/0oi5O0?nAG`070?nAG`03
0?n@G@3oTEl0oi9Q00L0oi5O00<0oi9Q0?nML@3oU6<0203oUF@00`3oU6<0oiUW0?nFH`070?nEI003
0?nFI`3oXgL0oie]00P0oii^00<0oii`0?nNKP3oWVh01`3oWVh00`3oWg80ojR40?nTOP060?nTOP03
0?nSO@3oYX80oj=m0080ojAn00<0ojEo0?nVPP3oY7h00`3oY7h00`3oXgd0ojJ30?naVP040?n`V@03
0?naVP3o/9T0ok2H00/0ok2I00<0ok2H0?nlZ`3ob/800P3obL400`3ob/40olW10?o9`@050?o9`@0B
0?o:`P3oc<@0olc50?o=aP3oc/P0ol_40?o9`03o`[P0oknd0?o=c03o`;`0ojRM0?nEO`3oN5D0of]3
0?m/A03oKdP0ofm:1`3oL4/01P3oLD`0ofI00?aN=`3gH3`0og=<0?meCPT0ogA=00<0ogE=0?mcC03o
Ld`00P3oM4d01P3oMe40ogE@0?maB`3oOET0og]F0?mdC@`0ogE>00<0ogQ@0?mjE03oLdd00P3oOEH0
0`3oNU40og]A0?mkD@090?mkD@80ogQ?00D0og]A0?mbB`060P40TbhT0?mZE@040?mRC`070?mSD03o
Ed@0odlk0?m?>`3oDSh0oei:0?mSD0020?mRC`040?mRCP3oHe00of=@0?mSC`80ofAB00<0of=?0?mZ
E`3oHe001P3oHe000`3oHdl0ofEA0?mUD@040?mUD@030?mTD03oKEX0ofIC00@0ofEA00<0of9>0?mU
D03oIU400`3oIU400`3oI500of]H0?mTD0030?mVD@090?mWDP2<:b80000009h[:`3oDE00oeYG0?m@
CP3oFUP0oe5?00L0oe9@0`3oDe400`3oFEP0oe=A0?mCD@050?mCD@060?mAC`3oDE00oeYK0?mHE`3o
DU40oeAC0P3oEE<20?mBD@030?mAD03oHV40oeaJ00<0oeEB00/0oeAA0?mEDP3oEE80oeEB0?mDDP3o
FEL0oeeN0?mDDP3oCdd0og9a0?oDg03P0?ooo`0403<S9000000000000?b]]?T0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooolb0?ooo`040?oSh`39TXL0
OdP_07E09PD0ND<Y00@0ND8X07a4:P2@ECd0N44W201i@bT0101i@RT0OTH]07U3:@26C3<807U3:@05
07]4:`1h@RP0ND<Y07U3:@25C3<01`1i@bT00`1jA2X0P4P^07Q2:00207U3:@0607Y4:P0I3@H00000
04PP601j>2X0NCPZ101h=bT00`1g=2L0N3LY07Pg:@0307Pg:@0407Lf:022?C00Rd<g07Lf:0@0N3LY
00<0NSPZ07`i;01h=bT01P1h=bT00`1e=BL0STHj07/i:`0307Pg:@0>07hk;@1n>bh0N3HY07hk;@1l
>B/0NcT[07De9P1_<B<0HBLH05lV5`1X;1d0LS8T07dh:@24>BX208<i:P0308@j:`23>BX0PcTZ00/0
PcTZ00H0QCTY08hm;02=?2`0TCl_09A1<P2=>b/<08dl;00508hl:`2I@c00VD<`0:59>02KA3401@2J
@c0209]4<@0;09U3<02QBSP0WDHc09U1;`2RBSP0Vd@b09U2;`2WCC/0YTPc0:I8=@2TAC400P2TAS80
0`2Q@bh0Y4Hb0:A6<P0;0:A6<P0I0:Y8<`2^B3<0[TPd0:e8=02_BCD0/DXf0;5:=@2bBS@0^Thi0<eI
@`3GGD80ee/n0=]UA@3/L4l0nWIB0?mdC03oNe80ogmD0?n0E@3oOe@0oh9F0?n5EP3oQEL0ohEI0?n6
F00@0?n3EP030?n3E@3oQUL0ohEG0080ohEG00H0ohIG0?n7F03oQeT0ohMG0?n9G03oQUL:0?n5E`03
0?n5EP3oQeL0ohQI00L0ohQI00<0ohQJ0?n;GP3oR5T02@3oR5T:0?n<F`80oheL00<0ohiN0?n<F`3o
S5/01@3oS5/00`3oSE/0oi5O0?nAG`0:0?nAG`030?n@H03oTV80oi1N00@0oi5O00<0oi9Q0?nML@3o
U6<02@3oUF@0103oUVD0oiAS0?nGIP3oUfH50?nEI0030?nFI`3oXgL0oie]00P0oii^00D0oim_0?nP
L@3oWW00oii`0?nOK`050?nNKP030?nOLP3oYh40ojAn00L0ojAn00<0ojJ00?nVPP3oYGl00P3oY7h0
0`3oYX40ojF10?nTOP030?nTOP030?nUP@3o[iL0ok2I00@0ok2I00<0ok6J0?n`VP3o/9X02P3o/9T0
0`3o/9P0okj_0?o:`P020?o9`@030?o:`P3ob/40olW100X0olW10`3ob/805P3oc/P0on_f0?oYl`3o
i^h0on?[0?oPi`3ofn00om3A0?o2_@3o/jL0ojRH0?nPS03oT7P0oh9T0?mhE@3oLe00og5<0?aS?03j
G3D0oV0i0?m/AP3oLd`:0?mdC@030?mcC03oM4d0ogA=0080ogA=00`0og=<0?mhD`3oMTl0og]F0?mf
C`3oM4d0ogI?0?miE03oLd`0ogUC0?mjE03oMDh20?mfC`D0ogE>00D0ogI?0?mdC@3oOe/0oh9K0?mj
D@0;0?mkD@070?mkD`3oOE@0ogYA0?mjD@060P40SB`S0?mZE@020?mRC`080?mPC@3oFdP0oe=00?m@
?03oE440oea90?mPC@3oJEL30?mRC`030?mVD`3oHe00of=@00@0of=@00P0ofAA0?mUD`3oI540ofIB
0?mWE03oHe00ofAA0?mSD080ofEB1`3oIE400`3oIe<0ofEA0?mUD@020?mUD@030?m^G03oJUL0ofA@
00@0ofIA0P3oIe830?mVD@090?m_F@2V=2X00000090W9P3oDe80oe9A0?mBD03oDe40oe9A00H0oe9@
00D0oe5@0?mCD@3oDe40oe=A0?mBD@070?mCD@030?mBD03oDU40oe=A00@0oe9A00/0oe=B0?mED`3o
De80oe5@0?mPH03oEE<0oeEA0?mEDP3oEE40oe]H0?mDDP030?mEDP80oe=A0P3oEE<0103oDU00oeeK
0?n1P`3ohnII0?ooo`0<0?oOh`2PSY40LDiA04`d=P0c8b@01`D50000000=2@T0<b<T05Tm?`20J6`0
omoS103oool30820P0030?oOh`3oool0oooo00@0oooo00@0omoS0820P020P800P8201`3oool0103/
g]l0P75e06E6B00c8b@20000000500d92@0c8b@0JdY=081jOP3TaLP01@3oool30820P0030?oOh`3o
ool0oooo00<0oooo00@0omoS0820P020P800P8201`3oool01030/;80P8200820P020P8040?ooo`05
0?o_l@20P800P8200820P030`<000`3oool01@3<`L@0P6Q/06E6B00c8b@03@T90080000000@06A8B
05Pm?`2ITI80onS/1P3oool0103onOh0YIZK06E6B00J4Q820000000302HJ6`2/Qh`0oooo0080oooo
0`20P8000`3ogn<0oooo0?ooo`0:0?ooo`0403TW:@000000000006E6B1@0oooo00/0fLG8081XK01U
ATP0<b<T00d92@0000009QXK03l/;@1cG5l0bkBf0?oioP020?ooo`060?oXk02<R8T0P8200820P02<
R8T0onS/4@3oool01P3oko40_j^]081aM@1aCU40@2`]00d92@80000000D081HG04`d=P1UATP0P6Q/
0?o_l@030?ooo`050<30`020P800P8200820P03oko401P3oool0103ogn<0P8200820P020P8070?oo
o`030=Rl_`20LGD0C3Df00<0000000D081HG05Pm?`1nEeX0P7Yn0?;Ri0040?ooo`<0P82000<0`;2b
0?ooo`3oool0103oool0103ogn<0P8200820P020P8060?ooo`040?oOh`20P800P8200820P0D0oooo
00@0omoS0820P020P800P8201`3oool01@3oj>`0/Z:T081XK01<=CH06A8B0080000000@0>BPY06E6
B020LGD0onS/0`3oool00`3;];H0ITY=01TB4P020000000502`O801aCU40YIZK0?oXk03Uf]/00`20
P8001@3om?H0oooo0?ooo`3oool0onoa00<0P82000<0`<300?ooo`3oool0?P3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooc00oooo00@0ooko0?n`ZP28
C3D0MD0V201i@bT00`1lAB`0Se@l07Q19`0707U3:@0507]4:`25C3<0N48X07U3:@24BS801`1i@bT0
0`1h@RP0QT`c07Q19`0207U3:@0308E<<`1i@bT0ND<Y00D0ND<Y00T0Nd@[08Y?=P1f@BL0ND<Z07a5
:`1oAR`0=A`=0000001?8aX01@1h=bT00`1m>Rd0R44f07Pg:@0407Pg:@0407Lf:023?S40S4@h07Lf
:0<0N3LY00<0NSPZ07hk;P1h=bT0201h=bT0201d<RD0N3LY07Lf:01h=bT0NcP[07`i:`1h=bX0MCDW
1@1h=bT02P1f=BL0I2TJ05hU5P1L91D0LBlO08@h:P24>R/0PcTZ08Xo<@26>b`<08<i:P0408Di:@2>
?B`0SS`/08/l:`h0SC`/00d0SS`[09]4<@2J@Rl0VT<a09U3<02J@c00V48_09]4<@2LAC80U3d[0:M=
?@2XCch0Ud4^00D0VT<`00D0VT8_0:I<>@2YBSH0Zd`k0:=4<0020:A6<P030:53;P2TAS80Y4Hb00P0
Y4Hb00`0X4@`09i5<@2M@S00ZT/g0;Q@>@2lCcL0`Tde0=aNA@3oLeH0og=>0?meC@3oP5D40?n0E0L0
ogmD00P0oh1D0?n3E@3oPeH0oh=F0?n2E@3oRel0ohAF0?n5E`h0oh=F00<0ohAF0?n5E`3oQEL01P3o
QEL00`3oR5X0ohMH0?n5E`090?n5E`030?n9F@3oR5T0ohQI00P0ohQI00<0ohIG0?n=H@3oR5T01P3o
R5T00`3oRe/0ohmP0?n<F`0;0?n<F`030?n>G`3oSE`0ohiN00@0ohaK00<0oi=U0?n@G@3oTEl02`3o
TEl00`3oT5d0ohiM0?nBH@030?nAG`030?nBH@3oWG40oiAS00d0oiET00<0oiQW0?nGI@3oUF@00P3o
UF@00`3oUVD0oia/0?nNKP0;0?nNKP030?nMK@3oX740oii^00@0oii^00<0oim`0?nQNP3oY7l02@3o
Y7h0103oYH00ojEn0?nUO`3oY7h20?nUOP80ojAn00<0oj=m0?nUP@3o/IX01`3o/9T00`3o/IX0ok:K
0?n`V@090?n`V@030?o3]P3obL40olW100<0olW100<0ol[20?o9`03obL402`3obL40103odll0onO`
0?oVkP3oinl50?oVkP<0onO_00h0onO`0?oWl@3oj?80on3T0?n/YP3oOVl0ogYP0?n1H`3oNUX0ogI?
0?m`A`3oKd@0og580?mcC0H0ogA=00<0og=<0?mdC@3oM4d0103oM4d00`3oM4/0ogYG0?meCP060?me
CP050?mfCP3oOU`0ogUC0?mcB`3oMe400`3oMDh01@3oNeH0og=<0?mnFP3oP5X0ogYA00/0og]A00X0
ogU@0?mhC`3oNe40ogU@0147101^8a`0of]F0?mSD03oGDX0oe4m0P3oD3`01@3oFTL0of=@0?mRC`3o
HTl0of1=0080of9?00<0of5>0?m[F@3oHTh01`3oHe00203oHdl0ofUF0?mTDP3oIe@0ofQE0?mQC@3o
KU`0ofMD1P3oIE400`3oI500ofaI0?mUD@020?mUD@040?mTD03oL5h0of]H0?mTD0@0ofIA00<0ofYF
0?mYEP3oI5000P3oIU401@3oKUT0]CL/008000208R80oe=B0080oe9@00D0oeID0?mIE`3oDU40oe=B
0?mCD@020?mBD0030?mAC`3oFEP0oe9@0080oe=A00<0oeUH0?mBD03oDe401@3oDe401@3oDDl0oe9A
0?mAD03oFe/0oeAC00@0oe9A00T0oeYH0?mCD@3oGUd0oeIC0?mOG@3oDe40oeA@0?mNG03oDe400P3o
EE80103oE580oeUE0?mPH03oFUP40?mED`030?mWI`3ohNX0oooo05D0oooo00<0oo?l0;1iOP000000
2P0000000`3o_lH0oooo0?ooo`020?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH00000
0000000000060?ooo`030?oco00V6Q/0000000P0000000<0IDE80?ooo`3oool00`3oool300000003
0?noaP3oool0oooo00<0oooo00@0oko600000000000000001`3oool01020H6<00000000000000004
0?ooo`050?oOh`000000000000000020P8000`3oool00`20H6<00000000000070000000301TA4P3o
d=P0oooo00@0oooo00<0bH^@000000000000100000001020H6<0oooo0?ooo`3oool3000000030?no
aP3oool0oooo00T0oooo00<0om3H0000000000000P0000000`3oj>`0oooo0?ooo`0@0?ooo`030>:L
XP000000000000P0000000@06A4B0?o@f03onOh0<R<T0`0000000`3l[K@0oooo0?ooo`0?0?ooo`03
0?oco01H?Cl0000000X0000000D0omoS0?ooo`3oool0oooo0820P003000000030?oOh`3oool0oooo
00@0oooo00@0oko600000000000000001@3oool00`3onOh0Bc@f00000009000000030;:RY03oool0
oooo0080oooo0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0
oko600000000000000001@3oool0103o_lH000000000000000060?ooo`030?7>d@000000000000P0
00000`3oool00`2GJ6`00000000000060000000301TA4P2bRi00000000800000103oool01@3ogn<0
0000000000000000P8200400oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3oool_0?ooo`040?ojo@3YUh`0JCHJ07@o8`P0ND<Y00@0QTdd07i5;@2?Dc/0N44W
1@1i@bT01@1nAR`0O4D[07Q3:01nARd0N48X0080MT0V1`1i@bT00`1i@RP0ODD/07Q2:00207U3:@03
08E<=01i@bT0ND<Y00D0ND<Y00T0N48X07Do9@1kABX0O4D/07a6:`1k@bT0=A`>0000001?8aX01@1h
=bT00`1k>B`0Q3lb07Pg:@0407Pg:@0407Lf:023?S40S4@h07Lf:0<0N3LY00<0NcT[08Q3>01e=BL0
201h=bT01`1e<RD0NSPZ07/i;01h=bT0Pcha07dj;@1h=RP0201h=bT01`1X;1d0GbHG06@V5`1g<B40
PcTZ08@j:`22>BX03@23>BX01@25>BT0SSd/090n;P2IASP0S3/[00d0SC`/00T0SS`[09Q2;`2J@c00
Ud0^09e5<`2KA340U3l/09a5<`2RBSP00`2H@Rl609Y3<00409Y2;`2VC3X0X48/0:53;`<0Y4Hb00<0
XD<^0:A6<P2TAS80102TAS803`2QA300WT@`09]3<02NAS<0/E0l0;a@=`34CcH0iEm10?mfE`3oMTl0
ogeB0?n4EP3oP5@0ogmD0?n0E@0<0?moE0030?moE@3oR5l0oh=E0080oh=F00@0oh=E0?n1E@3oREh0
oh=F0P3oPeD:0?n3EP030?n5E`3oSF40ohEF00P0ohEG00@0ohMH0?n5F03oQUH0ohIF1P3oQEL00`3o
QeT0oi=Y0?n8F@0:0?n8F@040?n7F03oRU/0ohYK0?n7F0@0ohQI00<0ohaM0?n@HP3oS5/02`3oS5/0
0`3oReX0oheN0?n?H0040?n<F`030?nCI@3oT5d0oi5O00`0oi5O00<0ohiM0?n@H@3oTEl00P3oTEl0
0`3oTV40oiea0?nDH`0=0?nEI0030?nFI03oVVT0oiET0080oiET00<0oiAT0?nIJP3oWVh0303oWVh0
0`3oWg00oie]0?nLK@030?nNKP030?nOL03oXGX0ojAo00X0ojAn00X0ojF10?nUO`3oXgd0ojJ30?nV
PP3oXgd0ojAn0?nSO@3oYX<0ok6J1`3o/9T00`3o/IT0ok:K0?naV`080?n`V@030?naVP3oa;T0olW1
00D0olW100<0ol[20?o9`@3obL402P3obL401@3oeM80onO_0?oVkP3oi^h0onO_00T0onK^00l0onO_
0?oQj@3oen00on3[0?o`o03oi^h0olW70?nn[`3oYXl0oiAi0?n2G`3oKdD0ofa10?m]A03oLDX00`3o
M4d00`3oLd`0ogA=0?mdC@030?mdC@030?mcC03oNeD0og]G00X0ogE>00X0ogA=0?mlE`3oMDh0ogA<
0?mgDP3oNE80og=<0?mlF03oOUP0ogYA2`3oNe40303oNU40ogmI0?mlD`3oNU009@l9060O603oKEP0
oem<0?mA?P3oCc/0oe4m0?mGA0@0of9?00H0ofEC0?mRC`3oHTl0of5>0?m[F@3oHTh80?mSD080of5=
00L0of=@0?mRCP3oHe00ofmM0?mXE@3oIE40ofA@00D0ofEA00P0ofE@0?mUD@3oIE40ofEA0?mUD03o
Ked0ofYG0?mTD0@0ofIA0P3oIe<30?mVD@050?m]F03B@3801@40080R8@3oE5800P3oDU002P3oE580
oeIE0?mAC`3oDU40oeEC0?mCDP3oDU00oe1>0?mLF`3oDU020?mCD@030?mHE`3oDU00oe=A00D0oe=A
00D0oeAB0?mBD@3oDE00oeaJ0?mDDP040?mBD@090?mAD03oDDl0oe5>0?mFE03oGe`0oeEB0?mCD@3o
GU/0oe=A0080oeEB00@0oeAB0?mIE`3oJ6L0oeaK103oEE<0103oCdd0og1`0?o2b03ooOmC0?ooo`03
0?oioP1;=3H0000000D0000000<0C3@f06E5B01;=3H00`0000000`3o_lH0oooo0?ooo`020?ooo`<0
000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000060?ooo`0607iGFP0000000000
0000000b8b@0f9bR0P3o_lH01039Ri009QXK0000001UADP50?ooo`<0000000<0oko60?ooo`3oool0
0`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0omoS0000
0000000000000820P0030?ooo`04081XK0000000000004/d=P80bH^@00<0/7Un038S900000000P00
00000`0b8b@0oooo0?ooo`030?ooo`05038S9000000000000000002GJ6`00P39Ri00102UNWh0oooo
0?ooo`3oool3000000030?noaP3oool0oooo00T0oooo00<0/7Un0000000000000P0000000`3TaLP0
oooo0?ooo`0?0?ooo`030>:LXP000000000000<0000000@0LDiA0<V;T02GJ6`0<R<T0`0000000`0I
4A80YH:7000000020000000305Pm?`3oool0oooo00l0oooo00<0oo?l04/d=P00000010000000100b
8b@0IDE806E5B00V6Q/3000000050?oOh`3oool0oooo0?ooo`20P8000`0000000`3ogn<0oooo0?oo
o`040?ooo`040?noaP0000000000000000D0oooo00H0_j^]000000000000000001TB4P2`NGh20?no
aP050>BUZ`1;=3H000000000002bXZ@0103oool300000003081PH`3oool0oooo00@0oooo00@0oko6
00000000000000001P3oool0103o_lH000000000000000050?ooo`040?noaP0000000000000000H0
oooo00H0LDiA000000000000000000d92@1nEeX20<V;T00303l[;@00000000000080oooo00T0oko6
000000000000000001TA4P39Ri00oko60?6^]01UADP00P000000101;=3H000000000000000040?oo
o`050?oOh`000000000000000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0
103YjNT0dM7A0=7Ad@3WinOo0?ooobh0oooo00D0on;Q0;Z2M01e?b@0P4L^07U2:00807U3:@0407a5
:`1mAR`0Se@k07Q2:080ND<Y00P0ND8X07e5:`1lABX0O4@[07U2:01j@bT0ND8X07U3:@80MClU1`1i
@bT00`1j@bX0ND<Y07U3:@0207U3:@030818;P1i@bT0ND<Y00@0ND<Y00@0NT@Z07i6;@1kA2X0O4D[
0P1i@bT0101kA2X0<1T=0000001?8a/607Pg:@0307De9`1h=bT0N3LY00@0N3LY00<0PCh`08M1=@1g
=bT00`1h=bT00`1g=RP0N3LY07Pg:@0407Pg:@0;07Ph:@1i>2X0O3X/07Lf:01j>2X0NCPZ07`i;01h
=bT0McHX07ll;P1h=RP0201h=bT01`1i>2X0MCDV06d/7@1W9aL0JbTI07D`8025>bd03023>BX01@20
>2T0R3XZ08hm;02=>b/0Scl^00/0SC`/00X0SCd/0950<02A@300SS`[0:M>?02SBSP0VD8`09a5<`2L
A340VD8_2`2J@c000`2J@Rl0Yddl0:Y:=`040:A6<P0@09m2;@2QAC40WTDa0:96<`2^CST0]4hh0<5@
=`3FHDP0gVI80>AVA@3dLT`0ogYE0?mjD@3oOE<0ohEK0?n1E080oh9G00<0oh5F0?moE03oOe@03@3o
Oe@00`3oP5D0oh]Q0?n3EP050?n3EP030?n4E`3oQEL0ohII0080ohAG203oPeH00`3oQEP0ohiT0?n6
EP080?n5E`060?n6E`3oQeT0ohIF0?n9G03oR5P0ohIG103oQEL00`3oQeT0oi9W0?n8F@0;0?n8F@80
ohQJ00<0ohYJ0?n<G@3oREX00P3oR5T00`3oRe`0oi1Q0?n<F`0=0?n<F`070?n;FP3oSUh0oh]J0?n>
GP3oS5/0oi=U0?n@G@0>0?nAG`070?nAH03oSeh0oi9R0?nAH03oTV00oiea0?nDH`0>0?nEI0060?nF
IP3oUF@0oiET0?nGIP3oU6@0oiUZ3P3oWVh20?nLK@050?nNL03oWVh0oii^0?nMKP3oY7l0303oY7h0
203oYGl0ojJ20?nSOP3oYX80ojAo0?nTOP3oY800ojnA2@3o/9T0103o/IT0ok:J0?nbV`3o/YX60?n`
V@030?naV`3oa[`0olW100H0olW100<0ol[10?o9`@3obL402@3obL40103ofMT0onO_0?oVkP3oi^h3
0?oWk`D0onK^00H0onO_0?oTk03og><0omGK0?oJh@3oi^h20?oWk`0@0?oan03oool0oooo0?ooo`3o
knd0omgE0?oBa`3oaKT0ojNB0?nAM03oQVH0ogeI0?m`B03oKdH0og590?mcB`<0ogA=00<0ogI?0?md
CP3oMDh03@3oMDh01`3oN580ogM@0?miE03oOU`0ogmI0?mjD@3oO5@02`3oNe402`3oNU80ogU@0?mj
D@0W3`T0FQXD0?mOB@3oDCd0oe4n0?mJA`3oH4d0of=@00@0of9?00H0ofEC0?mRC`3oHTl0of5>0?m[
F03oHdl90?mSD00;0?mZF03oHe00of=@0?mSC`3oKE/0ofUF0?mTD03oJ5H0ofIC0?mWD`3oIE000P3o
IE40203oJ5D0ofIB0?mUD@3oIE40ofE@0?m`G@3oJUL0ofEA1@3oIU402@3oJED0ofMC0?mVD@3oIU40
ofeH0=]3=@0?10<0P24Q0?mED`040?mBD0080?mDD@3oDU00oe=A0?mEDP3oEE<0oe9@0?mJFP3oDU0:
0?mCD@050?mLFP3oDDl0oe9A0?mCD@3oDe801P3oDU401`3oDDl0oeIB0?mIE@3oE500oeAA0?mLFP3o
E5800P3oEE80103oE580oeaI0?mOGP3oDe040?mED`050?mFE03oDDl0oeUG0?miN`3oh><0DP3oool0
201VEeX00000000000000000AS0b0;:RY03ne]X0ooWn103oool00`3Ub/d0S8:70?o@f0040?ooo`<0
000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000050?ooo`0609MXK00000000000
03l/;@3;];H0ooWn103oool00`3oko40/Z:T0;:2Q`050?ooo`<0000000<0oko60?ooo`3oool00`3o
ool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0omoS00000000
000000000820P0030?ooo`030<2e^P3H_;l0oo3e00D0oooo00D0ZhZ=00000000000000000=Rm_`03
0?ooo`050?oXk000000000000000001bFel01`3oool3000000030?noaP3oool0oooo00P0oooo00@0
oo3e02HJ6`0000009QXK0P0000000`2ISY40oooo0?ooo`0>0?ooo`070<^UZ`0=2@T000000000000o
;2d0YIBI0?oOh`040?ooo`050;nX[00V6Q/00000000000071@D00P0000000`0=2@T0d/G80?ooo`0?
0?ooo`080:FDV@0V6Q/000000000000=2@T0OUMJ0;:RY03oj>`40?ooo`040?oOh`3;];H0S8:70?oX
k0<0oooo00D0P82000000000000000000?oOh`060?ooo`040?noaP0000000000000000D0oooo00D0
C3@f000000000000?b`]0>GGfP050?ooo`030?oOh`2bXZ@0fL7300@0oooo0`0000000`20H6<0oooo
0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0oko600000000000000001@3oool0103o
_lH000000000000000050?ooo`060;:;T000000000000000001aCU40l]oS103oool01@3ne]X0/Z:T
0?ooo`3oool0C3@f0080000000<0>BLY0?oXk03oool00`3oool00`3ac]40IDI800000003000000@0
oooo00D0omoS00000000000000000820P0100?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0oooo;@3oool00`3oZjH0U5Po07Do900207]4:PT0ND<Y00P0MD0V
07i6;02?E3`0N44W07U3:@1nARd0MT4W07a5;080ND<Y00@0N44W08E;<`1oAbh0ND<Y0P1e?bD607U3
:@0307Q2:021B2l0Pd/a00<0ND<Y00<0MT4W07U3:@1i@bT00P1i@bT01@1kA2X0OdL^07]4:P21B300
N48X00<0ND<Y00@0Nd@Z01`>1P000000DB@K101h=bT00`1k>B/0S4Di07Lf:00607Pg:@0307Ld9`1e
<bH0N3LY00<0N3LY00<0Oc/^07Pg:@1h=bT00P1h=bT01`1g=RP0N3LY07dh;01l>B/0OCX]07Xh:`1d
<RD00`1h=bT00`1e=BL0MCDV07Pg:@0:07Pg:@0607/g:01g<B80JRPI06DU5@1^;1`0P3PY2`23>BX0
101n=bP0Rc`[08dl;02D@C4808dl;080S3/[00<0SC`/09I4=@2<>RX00P2C@C400`2=?2/0Ud0/09@o
;00?09Y3<00B09Y2;`2VC3X0Y4Ha0:=5<@2PA300WD@`09Lo;@2cCCP0cU]40?1Q@@3oKdd0ogQD0?mj
DP3oOe@0ogmC0?mmD`3oOe@0ogiC0`3oOE<0203oOU<0ogmD0?moE03oOe@0oh9F0?n1EP3oPeP0ogmC
3@3oOe@00`3oOE00ohAF0?n3EP060?n3EP050?n1E03oQeT0ohEI0?n4E`3oPeD0203oPeH<0?n5E`05
0?n6EP3oR5T0ohMH0?n9F`3oQUH00P3oQEL00`3oQUP0ohmS0?n8F@0?0?n8F@050?n9F`3oS5h0ohQI
0?n:F`3oTF80403oS5/01@3oReT0oheN0?n;FP3oTfH0ohmL00T0oi1M00<0oi5O0?nBH03oTV00103o
TV001@3oTEl0oi5Q0?nBHP3oVfl0oiET00d0oiIU00L0oiET0?nDH`3oU6<0oiAS0?nHI@3oUf<0oie[
00D0oii^0`3oWg080?nNKP050?nOL03oX740oie]0?nKK03oY8003P3oY7h01P3oYh<0oj=m0?nVP@3o
Y7h0ojJ10?nbU``0ok2I00<0okBL0?n`V03o/9T0103o/9T00`3o/I/0olRo0?o9`@070?o9`@030?o9
`03obL40olW100P0olW100<0omkP0?oVkP3oi^h0103oi^h00`3oinl0onK^0?oVkP020?oVkP050?oT
k03oeM`0om;I0?oFg@3oiNh00`3oi^h00`3ol_L0oooo0?ooo`070?ooo`0;0?oko`3ok>d0omG?0?ne
Y03oWhH0oh5N0?m/@P3oKD@0ofm70?mbBP3oN5803`3oMDh02`3oMTl0ogE>0?mmF@3oOeX0ogYA0?mm
E@3oN4l0ogaD0?mlE@3oN500ogU@00L0og]A00P0ogeG0?mlD`0o60l0BQ@?0?mE?`3oDSh0oem<0?mS
D0L0of9?00D0ofEB0?mRC`3oHDh0of]I0?mRCP090?mSD080of=?00L0of=@0?mRCP3oKUd0ofUE0?mU
D@3oI500ofEA0080ofMD00@0ofUG0?mUD@3oJ5D0ofIC0`3oIE400`3oIE80ofIA0?mVD@040?mVD@03
0?mUD@3oKe`0ofID0080ofIA00D0ofYF0?m??`0_3@X0P24Q0?mED`030?mBD0030?mLF`3oFEL0oe5?
0080oe9@00T0oe5?0?mBD03oFeT0oe=A0?mBD03oDe40oeAC0?mNGP3oDU001@3oDe401@3oG5X0oe5@
0?mBD@3oDE00oeYI00L0oe9A00D0oe=@0?mIE03oH5d0oeMD0?mCC`030?mEDP050?mDDP3oGU/0of1O
0?mJF03oEeD01P3oEE<00`3oE540ofMW0?oXl01@0?ooo`060<V;T000000000000000000I4A80onS/
3P3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000000000000000103oool01@3l[K@0
0000000000000000on7Z00h0oooo0`0000000`3o_lH0oooo0?ooo`030?ooo`040?noaP0000000000
000000L0oooo00@0P61S0000000000000000103oool01@3ogn<00000000000000000P82000/0oooo
00D0ooWn000000000000000009VATP030?ooo`050?oOh`000000000000000020P8001`3oool30000
00030?noaP3oool0oooo00P0oooo00@0bH^@000000000000o:fd0P0000000`1aCU40oooo0?ooo`0>
0?ooo`0501TA4P000000000000d92@3olo`01`3oool00`3olo`0Bc@f00000003000000030?b]]03o
ool0oooo00h0oooo00H0i<G8000000000000000000d92@3od=P>0?ooo`050820P000000000000000
003ogn<01P3oool0103o_lH000000000000000040?ooo`050?b]]000000000000000003ohNX03@3o
ool300000003081PH`3oool0oooo00@0oooo00@0oko600000000000000001P3oool0103o_lH00000
0000000000050?ooo`040?noaP0000000000000000@0oooo00D0oko6000000000000000009MXK009
0?ooo`050?o`m@000000000000000020LGD01`3oool0100I4Q8000000000000000040?ooo`050?oO
h`000000000000000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOo0?ooob/0oooo00P0ooWl0>nLT028CCD0LShS07U3:@1e@2@0MClU07U3:PL0ND<Y
00L0N48X089:<@1lAB`0Se@l07Q2:01i@RP0OTH/0080N48X0P1i@bT01P1h@RP0PTT`07e5;01i@bT0
M3lS07I09P`0ND<Y00D0Md4W07U3:@1i@bT0ND<Y07e6;00207]4:P0307U3:@1g@BL0ND<Y00<0ND<Y
00@0Nd@Z01d?1`000000DB@K101h=bT00`1j>2X0P3/^07Pg:@0607Pg:@0307Ld9`1e<bH0N3LY00<0
N3LY00`0Q3lb07Lf:01h=bT0N3LY07Pf:021?C00NcT[07Pf:@1i=bX0N3HX07Pg:@1e<bH207Pg:@03
07Lf:01n>bh0OS/]00X0N3LY00P0McDX07dg:023>2X0OCDW06h/701W9aL0KB/K07de9PX0PcTZ00D0
OSLX08/l:`2=?2`0UT@e08`k:`0508dl;00708hk:`2=?B`0VdLi0910<02;>RX0TCl_08dl;00208`k
:`0408dk:P2QB3H0W4Dc09Q2;`l0VT<`00X0WTLd09]0;02YBSH0bEe70>aSA03oKdX0ogE?0?mlE03o
OE<0ogmD0P3oOE<00`3oOU@0ogeC0?mmD`050?mmD`030?mmDP3oOE40ogmD00<0ogmD00<0oh5F0?mn
D`3oPUL0303oOe@00`3oOe<0oh1C0?n3EP080?n3EP040?n4E`3oPED0ohQN0?n1E@H0oh=F00<0oh=D
0?n5E@3oQEL02`3oQEL0203oQUL0ohMH0?n7F@3oR5X0ohMH0?n5E`3oQUL0ohIF4@3oR5T0203oRUX0
oheO0?n;F`3oTF80ohaK0?n<FP3oReX0ohaK0`3oReX40?n<F`0:0?n;FP3oReT0oh]I0?n;F@3oS5d0
oiIZ0?nFJ@3oUVX0oi9V0?nFJ`L0oiM[00<0oiQ]0?nCIP3oReX0203oReP00`3oS5X0oi5R0?n9F00<
0?n9F@030?n=G03oV6`0oiU/0080oiU/00D0oiQ/0?nEIP3oUVT0oiU_0?nML`020?nNM0050?nLL03o
UfP0oiMX0?nGI`3oVf/00`3oWg040?nNKP050?nLK@3oWg40oimb0?nVO@3oY8003P3oY7h01P3oYH00
ojB00?nUP03oY7h0ojB00?n^U@`0ok2I0P3o/9X00`3o/9P0ok2I0?n`V@020?n`V@030?ndW`3ob/80
olW100P0olW100<0olW00?o9`@3obL401`3obL400`3ohN@0onK^0?oVkP050?oVkP090?oWk`3oi^h0
onK^0?oWk`3ogND0om?J0?oFg@3ohn/0onO_00<0onK^00<0ooCh0?ooo`3oool02`3oool0203onOl0
onoa0?oKe`3o]ZH0oif30?n3H@3oL4P0og=<3`3oMDh0303oLd`0ogA=0?mjD@3oNe40ogU@0?mkD@3o
NU80ogYA0?mjDP3oP5/0ogUA0?mjD@D0og]A00L0ogiH0?maA`136Q00Ba@?0?mNB03oGd`0of=@00P0
of9?00D0ofiM0?mRC`3oHDh0of]I0?mRCP090?mSD0060?mSC`3oI540of=@0?mSD03oIU@0ofIC103o
IE401@3oIU<0ofMC0?mXEP3oIU<0of=>00<0ofEA00<0of=?0?mUD03oIU401@3oIU420?mUD080ofIA
00D0ofYF0?a=?P0Z2`T0P28Q0?mED`030?mBD0030?mAD03oDU00oe9@00@0oe9@00H0oe9A0?mBD03o
FEH0oe=A0?mDDP3oFEH50?mCD@060?mBD03oFeX0oe5?0?mBD@3oDE00oeUG1`3oDU401P3oEU<0oeID
0?mPGP3oDe40oeAB0?mCD@<0oeEB00@0oeIC0?mDDP3oGEh0oeQG1P3oEE<0103oE580oeID0?mfM`3o
fn9>0?ooo`060?oco00I4A8000000000000I4A80om3H3`3oool3000000030?noaP3oool0oooo00@0
oooo00@0oko60000000000000000103oool0102GJ6`000000000000o;2d?0?ooo`<0000000<0oko6
0?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo
00D0omoS00000000000000000820P00<0?ooo`<0000000D0P8200?ooo`3oool0oooo0?oOh`030000
00030820P03oool0oooo00D0oooo0`0000000`3o_lH0oooo0?ooo`080?ooo`0706E5B00000003@T9
0?ooo`0b8b@0000004`d=P0?0?ooo`050?oOh`00000000000000001UATP02@3oool01@1;=3H00000
000000000000bH^@0140oooo00D0S8:7000000000000000008aaM@0?0?ooo`050820P00000000000
0000003ogn<01P3oool0103o_lH000000000000000040?ooo`0409MXK0000000000007iGFPh0oooo
0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0oko600000000
000000001@3oool0103o_lH000000000000000040?ooo`0509MXK000000000000000003olo`02@3o
ool01@3ogn<00000000000000000P82000L0oooo00@0IDI80000000000000000103oool01@3ogn<0
0000000000000000P8200400oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3oool[0?ooo`080>Rc[P1f@2H0MT0U07U3:@1h@RP0OdL^08Q==P1f@BL707U3:@06
07Q2:025Bc80O4D[08Q==@1lAB/0Nd@Z1P1i@bT01@1f@2H0ND<Y07U3:@25Bc80ND<Z00L0ND<Y00<0
MT0V07Q2:01i@bT00P1i@bT01@1g@BL0ND<Y07U4:@1nAb`0Nd@[00<0ND<Y00<0NdDZ07U3:@1i@bT0
0P1i@bT0101kA2X07@l70000001A91/407Pg:@0307Dd9P1g=BL0N3LY00H0N3LY00<0Mc@W07Dc9P1h
=bT00`1h=bT01@1g=BP0N3LY07Pg:@1h=RT0Oc`^00H0N3LY00@0M38U07Pg:@1h=bT0McHX0P1n>bh:
07Pg:@0907Le:01n=bP0PcTZ08<h:@27?S00Kb`M06LV5P1Z:1P0MS0Q00T0PcTZ00@0OSLX08/l:`2=
?2`0S3/[102=?2`0202<>RX0T3l_09a9>`2>?2`0T3h^08dm;@2=?2`0SS`/0`2=?2`0102=>bX0Yddl
09m7=@2H@Rl909Y3<00>09Q2;`2H@bl0VD<`09]3<02K@Bl0YTXf0>9QAP3oKd/0ogQ@0?mlE03oOE<0
ogiD0?n0E@3oQ5/<0?mmD`030?mnE@3oQel0ogmC00D0ogmD00<0ogmE0?n5F`3oOE802P3oOe@00`3o
PEL0oheS0?n1E00;0?n3EP030?n4EP3oQUX0oh=F00@0oh=F00<0oh=E0?n5E@3oQEL03P3oQEL01@3o
QUP0ohUK0?n5E`3oQUH0ohEE00/0ohQI0P3oR5X0303oRUX0ohQJ0?n:FP3oR5T0ohUI0?n7F03oQUD0
oh]J0?nBIP3oUf/0oiIZ0?nFJ@<0oiIZ00D0oi=W0?n9EP3oRUP0ohYH0?n:F@030?n;FP060?n:FP3o
SEh0oheN0?n;G03oTF@0ohaL203oSEh00`3oRe`0oh]J0?n:F@070?n:F@030?n;F`3oU6L0ohUH00`0
ohYI00<0ohYJ0?n<G@3oRe`00`3oRe`0103oRUT0ohYK0?n;G03oS5d20?n<GP050?n;G03oS5/0ohaK
0?n<F`3oRUX00`3oReX0303oUVT0oiU_0?nIK`3oVFl0oiab0?nML`3oVfl0oiea0?nMM03oX7L0ojAn
0?nSO@P0ojAn00<0ojB00?nTO`3oY7h00P3oY7h0103oYGl0ojAn0?nTP03o[I<=0?n`V@80ok6J00D0
ok2H0?n`V@3o/9T0ok2I0?nnZ`0;0?o9`@030?o9`03ob/80olW100H0olW100<0on?X0?oVkP3oi^h0
1@3oi^h01`3oinl0onK^0?oWk`3ohn/0omGL0?oFg@3ohn/01@3oi^h00`3omo`0oooo0?ooo`0?0?oo
o`070?omo`3omod0om_G0?n]V@3oRfX0ogM@0?mfC`020?mdC@X0ogE>00<0ogUD0?mhD`3oMDd01P3o
Ne403P3oNe80ogQ?0?moF03oNe<0ogQ@0?mkD@3oO580ogA<0?m[@P3oJ3h0@QT?054H503oJeH0of=@
2@3oHTl0103oIU<0of9?0?mRC`3oHDh:0?mSD0060?mTDP3oJEH0of=@0?mSD03oHTh0ofA@1P3oIE40
103oIU<0ofEA0?mZF03oHdh20?mUD@030?mSC`3oIE00ofIA00D0ofIA00T0ofA@0?mXE@3oIU40ofIA
0?mZE@3oF4D0Aa<>04dC4P3oDDl00`3oDU000`3oDDl0oe1>0?mBC`040?mBD0070?m@CP3oDe40oeAB
0?mAC`3oEUD0oe5?0?mBD0040?mCD@030?mBD03oG5X0oe5?0080oe9A00<0oe9@0?mBD@3oDU40103o
DU401`3oDE00oeeJ0?mCD@3oEU40oe=A0?mED`3oDe400`3oEE80103oEU40oe5?0?mHEP3oEU@60?mE
D`050?mDDP3oF5H0oe5>0?m^K@3oald0C@3oool01@2`NGh00000000000000000bH^@0100oooo0`00
00000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00@0<R<T000000000000
LDiA3`3oool3000000030?noaP3oool0oooo00<0oooo00@0oko600000000000000001`3oool01020
H6<000000000000000040?ooo`050?oOh`000000000000000020P8002`3oool01@3oj>`000000000
00000000P82000<0oooo00D0omoS00000000000000000820P0070?ooo`<0000000<0oko60?ooo`3o
ool01`3oool0203olo`000000000001<=3H0oooo09MXK00000003@T93`3oool01@3ac]4000000000
00000000P6Q/00P0oooo00<0bH^@0000000000000P0000000`3l[K@0oooo0?ooo`0?0?ooo`0505Pm
?`00000000000000003TaLP03`3oool01@20P8000000000000000000omoS00H0oooo00@0oko60000
000000000000103oool0100b8b@000000000003RW:8>0?ooo`<0000000<0P61S0?ooo`3oool0103o
ool0103o_lH000000000000000060?ooo`040?noaP0000000000000000D0oooo00@0oko600000000
00000000103oool0100b8b@000000000001nEeX:0?ooo`050?oOh`000000000000000020P8001`3o
ool01020H6<000000000000000040?ooo`050?oOh`000000000000000020P800@03oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooobP0oooo00@0oogo0?oO
gP37Sh<0QD`c0`1i@bT0101kA2X0U5Lo08U>=P1f@BL707U3:@0507Q2:01kA2X0OTH/07I19`1jA2T0
1P1i@bT01P1oAbh0PDT`07U3:@1i@bT0Qd`d07U3:PH0ND<Y00<0Nd@[08E=<`1i@bT00P1i@bT01@1k
A2/0NT<Y07U2:01oAbh0N48X00<0ND<Y00<0ND<Z0859;`1i@bT00`1i@bT0101kA2X070h70000001A
91/407Pg:@0308A0=01h=bT0N3LY00H0N3LY00X0Mc@W07Dc9P1h=bT0N3LY07Xh:P1i>2X0OCT/07Pg
:@1m>Rd0N3HY1P1h=bT00`1e<bH0McHX07Pg:@0207Pg:@0307Lf:01h=bT0N3LY00T0N3LY00d0McDX
07hg:023>BX0PSPY08Xo<@23>BX0Mc4R06d[6`1Y9aP0L2dM07hf9`23>R/0Q3X[00D0PcTZ00/0OcLX
08/l;02@?Rl0TD0`09I3=02C@300RCTX09=1<P2=?2`0SSd/08hm;@0808dl;00308hm;02I@Rl0VD<`
00@0VT<`01D0VD8_09M2;`2G@S00WD@b0:54<@2^C3H0beM00=1J?@3QJ4T0ng9>0?meCP3oNU80og]C
0?n0EP3oP5D0ogeC0?mnE@3oOU<0ogeD0?mmD`3oOUD02`3oOE<00`3oOU@0oh5H0?moD`070?moE003
0?n2E`3oP5@0oh5G0080ogmE1P3oOe@00`3oP5H0ohQM0?n3E@0<0?n3EP080?n4E`3oQEP0oh=G0?n5
F03oQ5L0oh=E0?n6FP3oSV@80?n5E`070?n6E`3oQEL0ohEG0?n5E`3oQUL0ohIH0?n9FP030?n8F@08
0?n4E@3oR5T0ohaM0?n@I03oSV40ohmR0?n@H`3oRUX20?n9F@80ohYI00P0oh]J0?n>H@3oSf80ohmQ
0?n@HP3oSf00oh]J0?n:F@80oh]J00<0ohYI0?n;F`3oRe/01P3oRe/;0?n;FP030?n@H`3oRUT0oh]J
02D0oh]J00<0oh]K0?nBI03oReX03@3oReX50?n;F`030?n:FP3oSf40oh]J0080oh]J01L0ohYI0?n>
H03oTVD0oi9U0?nEJ@3oU6P0oi=V0?nCI@3oUFP0oiEY0?nGK03oWWL0oiad0?nNM`3oXGX0oj=m0?nR
O03oZ8X0ojb@0?n/U03o[YH0ojnG0?naV@020?n`V@030?naV`3o/Y/0ok2J00@0ok2J0P3o/9T0103o
/IX0ok2I0?n`V@3o_k4<0?o9`@030?o:`@3ob/80olW100@0olW100<0ol_40?oVk@3oi^h01P3oi^h0
1P3oi^l0onK^0?oMi03oeM`0omSO0?oTk0D0onK^00<0onG]0?omo`3oool05@3oool02`3on?/0omgF
0?o5]@3o^Z/0ojJ@0?n;JP3oOEP0ogQB0?mcC03oLTX0ogA=00<0ogE>00@0ogM@0?meCP3oMTh0ogaB
1`3oNe40303oNe80ogYA0?mjD@3oOED0og170?mT>`3oIcd0ofHn04/M4P0C1PD0bT0d0?mYE@X0of9?
00<0ofME0?mRC`3oHDh02`3oHe001@3oI500of=@0?mSD03oHTh0ofA@00P0ofEA00L0ofUE0?mUD@3o
JED0ofIB0?mYEP3oI4l0ofEA00D0ofIA00T0ofEA0?m^F`3oIU80ofIA0?mYE03oGT/0EQXE04<@403o
D4h00`3oDU000`3oDDl0oeYJ0?mFE0050?mBD0<0oe=A00<0oeAB0?mFE03oEeD00P3oE5840?mCD@<0
oe9A00<0oeIE0?mCDP3oDU40103oDU403P3oDE00oeaJ0?mDDP3oEe@0oeYG0?mHE03oEU<0oeEC0?mI
E@3oEE80oeIB0?mCD@3oE580oeID1P3oEE<01P3oE580oeaJ0?mED`3oDe40oeiM0?nZ[D/0oooo00D0
o]KJ00d92@000000000007iGFP0A0?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH00000
0000000000030?ooo`050?o/l0000000000000000020L7803`3oool3000000030?noaP3oool0oooo
00<0oooo00@0oko600000000000000001`3oool01020H6<000000000000000040?ooo`050?oOh`00
0000000000000020P8002P3oool00`3ol?D0Lf=T00000002000000050;n[[@3oool0oooo0?ooo`3o
gn<00`0000000`20P800oooo0?ooo`050?ooo`<0000000<0oko60?ooo`3oool01`3oool01P2`NWh0
00000000001iH6<0oooo0?6oaP80000000<0i:jd0?ooo`3oool0303oool01@3TaLP0000000000000
0000P82000L0oooo00<0c;Fj0000000000000`0000000`0I4Q80lLkA0?ooo`0>0?ooo`050?kFfP07
1@D000000000001nEeX0403oool01@20P8000000000000000000omoS00H0oooo00@0oko600000000
000000000`3oool01@3ofN400000000000000000omoS00h0oooo0`0000000`20H6<0oooo0?ooo`04
0?ooo`040?noaP0000000000000000H0oooo00@0oko600000000000000001@3oool0103o_lH00000
0000000000030?ooo`050?o@f000000000000000003a][d02P3oool01@3oo?l06A8B000000000000
LU]O00L0oooo00@0P8200000000000000000103oool01@3ogn<00000000000000000P8200400oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooolW0?ooo`05
0?okoP3aWI@0ND<Y07<n901i@bX00`1i@bT0101jA2T0S50h08Y?=P1f@BL607U3:@0507U2:01h@RP0
NT<Z07U2:01e@2H01P1i@bT00`1h@RP0PDP^08A:<P0207U3:@0308A:<P1i@bX0ND<Y00D0ND<Y00L0
Nd@Z0858;`1i@RP0Nd@Z07]3:@24BS80Md4V00H0ND<Y00<0MD0V07M19`1i@bT00`1i@bT0101kA2X0
2`H20000001F:1d307Pg:@0307Ph:@1m>Rd0N3LY00L0N3LY00L0MC@V07Le9`1j>2/0N3LY080k;P1m
>B`0O3X/00T0N3LY00L0MC<V07Lf:01h=bT0McHX07hj;P2;@cP0N3HX00X0N3LY00H0McDX07hg:023
>BX0PcTZ084h:@22>BX208<i:P0707La8P1X9aP0IbHF07<^7`1n=bP0Q3X[08<i:P02084h:@0508Hl
;@29?Bl0SCh^09]8>P2>?Bd00P2<>b/=08dl;00?09=2<@2TBcX0V48_09Y3<02E@Bh0SSd/08hn;@2O
BCL0]T`e0=UM@`3mKU00ofm:0?mmD`3oO580ogeC00@0og]B00H0ogeD0?n3F`3oOE80ogeC0?mlDP3o
OeH30?mmE0`0ogeC00<0ogiC0?n0E03oOe@0203oOe@01@3oOe<0oh=H0?n3E`3oP5H0oh1E00@0ogmD
00<0ogmC0?mmD@3oPeD03`3oPeH06P3oQEL0ohMJ0?n5E`3oQEP0ohaP0?n6EP3oQED0ohAF0?n4E@3o
QEL0ohIF0?n5E@3oREX0ohaP0?n;G`3oREX0ohMG0?n6EP3oSUh0oi=Y0?nCIP3oTF<0ohUH0?n:F@3o
SUl0ohiP103oRUT?0?n;FP030?n>H03oRET0oh]J02H0oh]J00<0ohUH0?n;FP3oReX0403oReX00`3o
Re/0oiIZ0?n:F@0C0?n;FP030?n:F@3oReX0oh]J00`0oh]J01`0ohUH0?n8F03oREP0ohUH0?n:F@3o
ReX0ohMF0?n8E@3oREP0oi9V0?nDJ`3oW7H0oi]e0?nMN@3oXX40ojN90?n/T03o[iD0ok6G0?n_U`3o
/9X0okBP0?nbW@3o/Yh0okBO0?n`V`3o`kP0ol[2303obL400`3obL00olW10?o9`@020?o9`@030?o9
`03oe=40onK^00L0onK^00D0onO^0?oIh@3od=D0om?J0?oTj`060?oVkP030?oYl03oool0oooo01/0
oooo00`0onoa0?o?b03o[i`0oiEg0?miE03oKD<0ofa10?maB@3oMDh0ogUD0?miDP3oNU070?mkD@0=
0?mlDP3oNe40og=:0?mX?`3oJ3d0of]10?mcB`3oMdd0FR<E00T20@2h>c40ofeI0?mQCP080?mRC`04
0?mSD@3oJEL0of9?0?mQCP/0of=@00D0ofUG0?mSC`3oHe00of=@0?mSC`0<0?mUD@060?mTC`3oIU<0
ofUF0?mXE@3oIU40ofA@0`3oIU402@3oI4l0ofE@0?mVD@3oIe<0ofYE07<T7@0P1`L0od];0?mCD@03
0?mBD0030?m@CP3oCdd0oe9@00D0oe9@0`3oDe400`3oE5<0oeID0?mEE0020?mDDP80oe=A00H0oe5@
0?mBD@3oDU40oe9A0?mDD`3oE5850?mBD@0?0?mAD03oGE/0oe=A0?mJEP3oGE/0oeYG0?mKF03oDe40
oeEB0?mGE@3oEU@0oe=A0?mBD03oGE`0oeAB00D0oeEC00<0oeAB0?mRHP3oEE<00P3oEE<00`3oDU00
oiRL0?ogo`190?ooo`0509MXK000000000000000003ohNX04@3oool3000000030?noaP3oool0oooo
00@0oooo00@0oko600000000000000000`3oool01@3ne]X00000000000000000P82000l0oooo0`00
00000`3o_lH0oooo0?ooo`030?ooo`040?noaP0000000000000000L0oooo00@0P61S000000000000
0000103oool01@3ogn<00000000000000000P82000P0oooo00<0on7Z09MXK00000000`0000000`0I
4A80oo3e0?ooo`020?ooo`050?oOh`000000000000000020P8001`3oool3000000030?noaP3oool0
oooo00L0oooo0`0000001P2UVY/0oooo0?ooo`0b8b@0000004/d=Ph0oooo00D0o]KJ000000000000
0000081jOP070?ooo`0503l/;@00000000000000000c8b@00P0000000`1;=3H0oooo0?ooo`0=0?oo
o`0509MXK000000000000000003ohNX0403oool01@20P8000000000000000000omoS00H0oooo00@0
oko600000000000000000`3oool0103l[K@0000000000000000?0?ooo`<0000000<0P61S0?ooo`3o
ool0103oool0103o_lH000000000000000060?ooo`040?noaP0000000000000000D0oooo00@0oko6
00000000000000000`3oool0103RW:80000000000000000<0?ooo`0509MXK0000000000000d92@3o
lo`01P3oool01020P80000000000000000040?ooo`050?oOh`000000000000000020P800@03oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooobL0oooo00<0
k;Nb06/h701f@BL01@1i@bT0101f@2H0PDL_08U?=`1h@BL507U3:@0607Q2:01lA2X0R4de07Y3:@1i
@RP0MD0V1`1i@bT01@1h@BL0N48W07U3:@1i@bT0R4de00L0ND<Y00<0MClU07I09P1lAB/00P1nARd0
0`1i@bT0Md4X07U3:@0507U3:@0307a5:`1i@bX0ND<Y00<0ND<Y00@0Nd@Z00P50P000000FBPN0`1h
=bT00`1f=BH0MC@V07Pg:@0607Pg:@0807Dd9P1g<bH0P3`_07`i;01k>2/0Mc@W07@b9@1f=BL907Pg
:@0607Dc9P1g=RP0N3LY07Pg:@1j>2X0OSX]2`1h=bT01P1g=BP0OCHX084g:02?@S@0S40b088i:P80
PcTZ00h0Q3X[07La8P1W9QL0IbDE06dZ6P1o=RL0PcX[08a0<P23>R`0QS`^09I9?02@?c00QSHU08/k
:`l0SC`/00d0SS`/09M3<02??B`0RC/Z0:a=>P3:DcL0hUm10?e^D03oMTl0ogmD0?mmDP3oOE<0ogaB
00L0og]B00<0og]A0?mmDP3oOE<00P3oOE<01@3oO580ogiE0?n0E`3oOeH0og]A00X0ogeC00<0oh1H
0?n6GP3oOe<02`3oOe@0103oQ5P0oh9G0?n3EP3oOe<30?moE0030?n0E@3oQ5H0oh=F00h0oh=F0140
oh5E0?n3E@3oQEP0ohEG0?n1D`3oQeP0oheS0?n>H@3oSV80ohUI0?n6E`3oQeH0oheO0?nBIP3oTfH0
oheN0?n9F0020?n;FP030?n8F03oRUT0ohYI0080oh]J00<0ohaL0?n=G@3oReX04@3oReX00`3oRUT0
oi9U0?n8F00B0?n;FP030?n:F@3oReX0oh]J0180oh]J00<0ohUH0?n;FP3oReX0403oReX00`3oRe/0
oi1R0?n:F@0B0?n;FP030?nBIP3oReX0oh]J0140oh]J00<0ohUH0?n;FP3oRUT00P3oReX02@3oREP0
ohQG0?n7EP3oQeH0ohQF0?n6D`3oReX0oi5U0?nGKP020?nHL@0<0?nLM`3oWg/0oj>20?nZS03o[iD0
ojV=0?o2]`3oc/P0olg70?o<aP3ocLH0olc42@3obL401P3obL00ol[20?o:`P3obL40olW00?oIf0P0
onK^00D0omkV0?oBf@3oe=`0on3W0?oWk`050?oVkP030?oUk@3okoH0oooo01l0oooo00T0ooGf0?oA
bP3o_Jh0ojN@0?n4H`3oIcd0ofm50?mbB@3oNTl01`3oNe40403oNE00og150?mW?@3oJ3d0of]10?mj
D03oO580og]B07La8P0?0`80aT0e0?m]FP3oI500ofIC0?mRC`3oHDh60?mRC`040?mNBP3oH4`0of=?
0?mSC`X0of=@00D0ofQF0?mSD03oHe00of=@0?mRC`080?mUD@0;0?mWE03oLEl0ofA@0?mUD@3oI500
og5N0?mXE@3oJEH0ofIA0?mZE`3oHdl00`3oIU40203oKE/0ofIA0?mVD@3oLE/0QBXR01d61P3oC4/0
oe=A103oDU000`3oEE<0oe9@0?mBD0020?mBD0030?mED`3oEeD0oe=A0080oe=A00T0oe9@0?m?CP3o
DDl0oeAB0?mBD03oEU@0oe=A0?mBD03oDE000P3oDU400`3oDE00oe1>0?mBD@040?mBD@050?mAD03o
FEH0oeEB0?mEDP3oE5000P3oFEL0103oDe40oeEB0?mED`3oFED20?mHEP030?mGE@3oEE<0oeEC00@0
oeEC00<0oeAB0?mPG`3oEE<00`3oEE<00`3oAD<0ohf>0?o/l`180?ooo`04038S90000000000002HJ
6a80oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000<0oooo00D0i<G8
0000000000000000081PH`0;0?noaP040?oioP3oool0oooo0?ooo`<0000000<0oko60?ooo`3oool0
0`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0omoS0000
0000000000000820P0070?ooo`030;n;T0000000000000@0000000<0hYbR0?ooo`3oool00P3oool0
1@3ogn<00000000000000000P82000L0oooo0`0000000`3o_lH0oooo0?ooo`060?ooo`050?kFfP00
000000000000003H_;l00P3oool0102GJ6`000000000003olo`=0?ooo`050?oOh`00000000000000
001nEeX01P3oool01P3RW:800000000000000000<R<T0:FDV@<0000000<0onS/0?ooo`3oool0303o
ool0100b8b@000000000001;=3HA0?ooo`050820P000000000000000003ogn<01P3oool0103o_lH0
00000000000000030?ooo`040<V;T00000000000000000/0oko600@0oo?l0?ooo`3oool0oooo0`00
00000`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0oko6000000000000
00001@3oool0103o_lH000000000000000030?ooo`040<V;T00000000000000000`0oooo00H0on7Z
000000000000000004/d=P3od=P50?ooo`040820P00000000000000000@0oooo00D0omoS00000000
000000000820P0100?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWiol0oooo9P3oool00`3oaL<0T5@m07U3:@0607U3:@0407Y3:P25BS<0Re0h07I19`D0ND<Y0P1l
AB/0102:CcH0O4@Z07I09P1h@RP707U3:@0607Q19`1h@RP0ND<Y07Q2:02?E3`0Nd@Z1@1i@bT0201k
A2X0OdL^07]4:P1nAR`0Nd@Z07Q2:01i@bT0MT4V1@1i@bT00`1i@RP0SU<j07Y4:P0407U3:@0407]4
:P081@80000005PX7P<0N3LY00<0O3T/07Xh:P1h=bT01@1h=bT01@1i=bT0P3/_07Le9`1n>bh0NCLY
0080N3LY00<0OSX]07Pg:@1h=bT0201h=bT01P1e<bH0McHX07Pg:@1g=RP0LS8S07De9``0N3LY00@0
PCPZ08<h:@2:?c40RCd_1023>BX03@24>R/0M2lP06PV5P1W9QH0Jb/L080g:@2<@380QS/]084h:02F
Ac/0TT0a09E3<`2>?Bd03@2=?2`02`2;>RX0QSTZ08Hj:@2fDch0d5Hk0>]Q@@3oLU00og]A0?n1E@3o
Oe<0ogeC00/0og]B00<0ogaC0?mlE03oOE801@3oOE<00`3oNe40oh5J0?moE@090?mmD`030?moEP3o
Q5/0oh1D00/0ogmD00T0ogiC0?n1EP3oP5H0ohAH0?n1E@3oOe@0ogmC0?n4F@3oREl02P3oPeH20?n1
E00B0?n1E@3oQ5H0oh=D0?n9G03oSF<0ohaO0?n7E`3oR5P0ohYJ0?nBI@3oTF<0oi5T0?n;F`3oReX0
ohaK0?n;FP3oRET0ohQH2@3oReX00`3oRUT0ohUG0?n;FP0B0?n;FP030?n@H`3oRUT0oh]J0140oh]J
00<0ohYI0?n;FP3oReX04P3oReX00`3oREP0oh]J0?n;FP0A0?n;FP030?n8E@3oReX0oh]J0140oh]J
00<0oi9U0?n;FP3oReX04@3oReX00`3oS5h0oh]J0?n<F`080?n;FP030?n:F@3oREP0ohIF0080ohMF
00`0ohME0?n4D@3oRUT0oi5T0?nBJ03oV6l0oiai0?nRQ03o/IT0okFR0?njZ@3o`kP20?o>b0040?o<
aP3oc<D0olc40?o:`P@0olW100D0olW00?o:`P3obL40olRo0?oNh0070?oVkP040?oTk@3oe]d0omCK
0?oNi@80onO_1@3oi^h00`3oi>`0ooCm0?ooo`0S0?ooo`070?oTh`3oaKP0ojZC0?n?K`3oLdL0ogA9
0?mhCP040?mkD@0C0?mmD`3oL4H0ofPm0?mW?@3oJ3l0ogE=0?mlDP3oNe40og]B080m;0020000YC<X
0?mZE@3oIE40ofIC0?mPC03oJeT0of=@0?mQCP040?mRC`040?mSD@3oJ5D0of9?0?mSC`X0of=@00D0
of=?0?mRCP3oHe00of=@0?mUDP080?mUD@090?mVD`3oJ5H0ofEA0?mUD@3oI4l0og=R0?mYEP3oIU40
ofMC0080ofQE00@0ofIB0?mVD@3oIU40ofmM0P3oIU401@3oL5X0ORLP01@41@3oCD/0oe=A00<0oe9@
00<0oe5?0?mPG`3oE5800`3oDU000`3oF5H0oe]J0?mBD0030?mCD@80oeME00H0oe=A0?mAC`3oEU@0
oeAB0?mCD@3oDDl30?mBD@030?mGE@3oDU40oe9A00@0oe9A00L0oe5?0?mEDP3oEE80oe=A0?mKF03o
G5X0oe=A0080oeEB00@0oe=@0?mJF03oGEh0oe=A3@3oEE<00`3oBDL0og]m0?o`m0170?ooo`<00000
00<0F3do0?ooo`3oool0403oool3000000030?noaP3oool0oooo00@0oooo00@0oko6000000000000
00000`3oool00`3TaLP000000000000=000000040?oOh`3oool0oooo0?ooo`<0000000<0oko60?oo
o`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0
omoS00000000000000000820P0050?ooo`030?oQjP1UADP0000000@0000000<06A4B0>:LXP3oool0
103oool01@3ogn<00000000000000000P82000L0oooo0`0000000`3o_lH0oooo0?ooo`060?ooo`05
0<^d]P00000000000000003ne]X00P3oool0103l[K@000000000003RW:8>0?ooo`0401TA4P000000
000003l/;@D0oooo00<0on7Z01TA4P0000000P0000000`3o_lH0i<G800000002000000030=Rl_`3o
ool0oooo00`0oooo0`0000000`2`NGh0oooo0?ooo`0?0?ooo`050820P000000000000000003ogn<0
1P3oool0103o_lH000000000000000030?ooo`030<V;T0000000000000`0000000@0oko60?ooo`3o
ool0oooo0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0oko6
00000000000000001@3oool0103o_lH000000000000000030?ooo`040<V;T00000000000000000d0
oooo00<0hYbR0000000000000P0000000`2GJ6`0o]3H0?ooo`020?ooo`040820P000000000000000
00@0oooo00D0omoS00000000000000000820P0100?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo903oool0103og=T0ahf008iB>`1g@RL707U3:@0408A<
<`22BC00R4he07M2:0<0ND<Y00L0N48X07e6;01j@bT0N48X07M19`1i@bT0MClV00L0ND<Y00L0P4L^
08Y@>01g@RP0ND<Y07Q2:02>Dc/0Nd@Z00@0ND<Y00D0Nd@Z07]4:`23BS00Md4W07Y4:P0207U3:@03
07Q2:024Bc80ND<Y00@0ND<Y00<0N48X07e5:`1i@bT0101i@bT0101kA2X020D20000001H:1h307Pg
:@0307dj;01i>2X0N3LY00<0N3LY00D0OSX]07Le:01m>Rd0N3LZ07Dc9P0407Pg:@0308I1=01h=bT0
N3LY00P0N3LY00H0NSLY07Tg:P1h=bT0NcT[08M1=@1g=bT;07Pg:@0507/j;029@3<0Q3X[08@j:`21
>BX00P23>BX03P22>BX0PcX[08Hk;@27?Bh0Qch_07Pb8P1Z:AT0JbPI07@_7`1m=RL0PSTZ09I7>`2A
@300U44a2P2=?2`0302<>b/0SSd/0:U:=P31DCP0d5i40>9UAP3jL4X0ogaF0?mjD@3oOUD0ogeD0?ml
D`h0og]B00<0ogeD0?n0E`3oOU<0103oOE<01@3oOE@0ogiD0?mnE03oO580ogmF0080ogiE1`3oOE<0
0`3oOE80ogmE0?moE00=0?moE0060?n0E@3oOe<0oh9G0?n2E`3oPUP0ohML0`3oPeH04P3oQ5H0ohII
0?n:GP3oRel0ohMJ0?n6EP3oQUL0ohiR0?n?HP3oSEl0ohUH0?n:F@3oS5`0ohaM0?n<G03oReX0oh]K
0?n=G180oh]J00<0ohYI0?n?H@3oRUT09`3oReX00`3oRUT0oh]J0?n;FP0@0?n;FP80ohYI4P3oReX2
0?n:FBL0oh]J00@0ohiO0?n;FP3oReX0oh]K3`3oReX0503oRUT0ohaL0?n;FP3oRUP0ohUG0?n:FP3o
S5d0oheO0?n?H`3oTVH0oiI_0?nNNP3oXh@0ojN;0?n^U@3o/id0ok^Y0?o0/P3o`[D0olBj0P3ob/80
103ocLD0onCZ0?oWl03oinl40?oVkP070?oPj03of=l0omKM0?oRj@3oi^h0onO_0?oVkP020?oWk`@0
onK^00<0oogo0?ooo`3oool09@3oool03P3on?T0on[V0?o>`P3o^JL0ojB;0?n>K03oMdd0og980?m/
@P3oJCh0ofe30?maB@3oNE00ogaB0P3oNe401@3oNe80Qc`W0080002I<BL0ofaG00<0of9?00/0ofEB
0?mSD03oJEH0of5=0?mVD`3oI540of9?0?mTD@3oIeD0of=@0?mVD`0:0?mSD0060?mUDP3oK5T0of=?
0?mRCP3oK5/0ofA@2@3oIE401@3oIe@0ofEA0?mTD03oLF00ofUF00<0ofIA0P3oIe<02P3oJ5D0ofQD
0?mWD`3oIU80ofIA0?m^F@2_=b/00P410?m;B@3oDe440?mBD0030?mCD@3oDU00oe9@0080oe9@00<0
oeMF0?mIF03oDU000`3oDe400`3oEUD0oeMF0?mCD@030?mCD@030?mFE03oEeH0oeEC0080oe9A00<0
oeaK0?mBD@3oDU40103oDU401P3oDe00oeEB0?mCD@3oG5P0oeYG0?mFD`<0oeEB00@0oe=A0?mMFP3o
GU`0oeQF1`3oEE<00`3oE580oeMF0?mED`040?mED`030?m@CP3oO7d0omSJ04D0oooo00D0omoS0000
00000000000007UGFP0B0?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH0000000000000
00030?ooo`030>C5b0000000000000d0000000@0omoS0?ooo`3oool0oooo0`0000000`3o_lH0oooo
0?ooo`030?ooo`040?noaP0000000000000000L0oooo00@0P61S0000000000000000103oool01@3o
gn<00000000000000000P82000<0oooo00<0ooCf08aXK00=2@T00`000000100I4Q80IDI80:JGVP3o
nOh60?ooo`050?oOh`000000000000000020P8001`3oool3000000030?noaP3oool0oooo00H0oooo
00@0QWUk000000000000<b<T0`3oool0103onOh04`d>0000001H?Cl>0?ooo`060<^DV@0000000000
0000002ILGD0ooWn0P3oool02@3TaLP09QXK0000000000009QXK0>C5b03oool0ooCf00d92@020000
000309>5R03oool0oooo00/0oooo00D0oko600000000000000000?6^]00A0?ooo`050820P0000000
00000000003ogn<01P3oool0103o_lH000000000000000030?ooo`030<V;T0000000000000`00000
00@0oko60?ooo`3oool0oooo0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP00000000000000
00H0oooo00@0oko600000000000000001@3oool0103o_lH000000000000000030?ooo`040>>LXP00
00000000000000h0oooo00<0lLkA061:C@0000002P0000040?ooo`050?oOh`000000000000000020
P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ob<0oooo00D0omcK0858;`1^>Qh0Q4X`07Y4:P0707U3:@80N48X00`0N44W07U3:@1i@bT0ND<Y07i6
;@1f@2H0ND<Z07Q2:024BS80OdL]07U3:@1e@2H707U3:@80N44W00D0ND<Z07U3:@1i@RP0Re0g07]4
:P0307U3:@0407]5:P1lAB`0MT4W07Q19`@0ND<Y00<0N48X08I<<`1i@bT00`1i@bT00`1h@RP0Q4Xb
07]4:P0407U3:@0507Y4:P1T=R001@810080001N:Ql00`1h=bT01P1g=2L0N3LY07Pg:@1h=bT0NcP[
07/i:`<0N3LY00<0N3HY07/i:`1h=bT00P1h=bT00`1e=BL0McDW07Pg:@0807Pg:@0607De9`2<ACT0
PCd`07Pg:@1h=BP0MCDW301h=bT02P1k>R`0RClb08a0<P2?@S@0PcPY07lf:02AASX0QS//084h:@24
>R/308<i:P0807lf9`1Z:1T0IbHG06LV5P1i<R80UTLk09E3=02>?B`508dl;00908/k:`2<?2`0Scd]
09M2;`3?GDL0mVE50?m_BP3oMe00ogUA0080ogQ@00L0ogUA0?mlE03oNe80og]C0?mkDP3oPE`0ogU?
00h0og]B00<0ogY@0?mmDP3oOE<0103oOE<20?moEP<0ogeC00<0ogaB0?mnE@3oOeD0103oOE<00`3o
OE80oh=K0?n6G@0?0?moE0070?moE@3oP5D0oh1D0?n3E03oRel0oi5W0?n?H`020?n9F0040?n:F`3o
Re`0oh]L0?n:F``0oh]J00<0ohaM0?n;FP3oReX04@3oReX00`3oRUT0oh]J0?n;FP0A0?n;FP030?n:
F@3oREP0oh]J0180oh]J00<0ohUH0?n;FP3oReX0403oReX00`3oRUT0oh]J0?n;FP0A0?n;FP030?n@
H@3oReX0oh]J0140oh]J00<0oi1P0?n:F`3oReX04@3oReX00`3oS5d0ohYK0?n;FP020?n;FP030?n<
F`3oReX0ohYI00d0oh]J00<0oh]L0?n;FP3oReX01P3oReX0103oRET0ohYI0?n9F03oREP20?n8E`0A
0?n;F`3oS5h0ohiP0?n=H@3oTfT0oj:30?nXS@3o`kX0om_M0?oTjP3oiN/0onK]0?oWl03ogNH0omGM
0?oEg03oh^T01@3oi^h01@3oinl0onK^0?oVkP3oiNd0ongd02d0oooo00T0oo[n0?oQi03o[j<0oh1U
0?meCP3oNe40ogU?0?mhCP3oNU000P3oNe401@3oNe80UT8[0000001n9b00of]G00L0of9?00P0of=A
0?mRC`3oJEH0ofQE0?mPC@3oIeD0of]I0?mSC`X0of=@00D0of9>0?mSD03oHTl0of]I0?mTD0080?mU
D@060?mXE@3oKed0ofEA0?mTC`3oLV40ofUF1P3oIU420?mWD`070?mZF03oIE00ofeH0;Li;0010040
odY90?mCD@040?mBD0030?mAC`3oEeH0oe9@0080oe9@00<0oeMF0?mIF03oDU00103oDe400`3oDDl0
oeAA0?mCD@020?mCD@070?mFE03oHEl0oe9A0?mED`3oDe80oe9@0?mAC`050?mBD@060?mCD03oEE80
oeEB0?mEDP3oE540oe=A0`3oEE801P3oDe40oe]H0?mLF@3oEeD0oeAC0?mHEPD0oeEC00<0oeAB0?mS
HP3oEE<01@3oEE<00`3oE580ofY[0?o1aP140?ooo`050>C5b0000000000000000020LGD04P3oool3
000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000000`3oool01@3ogn<000000000
00000000P82000L0oooo00D0P82000000000000000000?oOh`030?ooo`<0000000<0oko60?ooo`3o
ool00`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0omoS
00000000000000000820P0030?ooo`060;n[[@00000000000000000=2@T0hYbR2P3oool01@3ogn<0
0000000000000000P82000L0oooo0`0000000`3l[K@0oooo0?ooo`060?ooo`0405Pm?`0000000000
0<V;T0@0oooo00@0F3do000000000000oko63P3oool01`2GJ6`00000000000000000Bc@f0?oco03o
gn<00`0000000`0=2@T0om3H0?ooo`020?ooo`0406E5B0000000000007iGFPd0oooo00D0bH^@0000
0000000000000?oQjP0A0?ooo`050820P000000000000000003ogn<01P3oool0103o_lH000000000
000000030?ooo`040?noaP0000000000000000P0oooo0`000000103o_lH0oooo0?ooo`3oool30000
0003081PH`3oool0oooo00@0oooo00@0oko600000000000000001P3oool0103o_lH0000000000000
00050?ooo`040?noaP0000000000000000<0oooo00D0oko600000000000000000?noaP0?0?ooo`04
0?oQjP39Ri00UfQ/03l[;@L00000103oool01@3ogn<00000000000000000P8200400oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooolR0?ooo`050?oio`2f
LEl0MClU07i7;01f@BL0201i@bT00`1g@BL0N48X07I09P0207U3:@0:07m7;P1h@RT0ND<Y07U3:@1f
@BL0RTlf0858;P1j@bT0TE@l07Q2:0H0ND<Y00<0N44W07Q2:01i@bT00P1i@bT01025Bc<0ND<Y07U3
:@1h@BL207i6;@0307U3:@1oB2d0ND<Y00@0ND<Y00<0N48X08I<<`1i@bT00`1i@bT00`1h@RP0SU8i
07a5:`0407U3:@0507]4:P1K<1/00`4100H20@1W;R800P1h=bT01P1g=RP0PSda07Xh:P1g=RP0OS/^
07Tg:P@0N3LY00L0OS/^08e6>P1e=BL0N3LY07Pf:024@3<0NSPZ00T0N3LY00H0MCDW08a5>@21?C00
N3LY07Ld9`1g=RP<07Pg:@0607Xi:`2:@3<0PcT[084h:P2@A3P0PST[2023>BX0401n=RP0L2`M06PV
5P1Y9aL0Qcla09m<?`2@?Rh0SC`/08`k:`29>b/0QcX[098o;`2M@Bh0]U8m0>=UBP3oL4X70?mhD003
0?mgC`3oN4l0og]B0080og]B00H0og]A0?mjDP3oOeL0ogaD0?mkDP3oNe490?mkDP030?mkD@3oOeT0
oh1H00D0ogeC00<0ogmF0?mnE03oOE<0103oOE<0203oOeD0ogeD0?mmD`3oOE@0ogeC0?mmDP3oP5L0
oh=I1`3oOe@03P3oOU<0ogmD0?mnE03oOe@0oh1F0?n3F03oOe@0ogmB0?n:G`3oTVL0ohUF0?n9F03o
Sf00oheM4P3oReX00`3oRET0ohiO0?n:F@0V0?n;FP030?n=GP3oTfH0ohQH0180oh]J00<0ohUH0?n;
FP3oReX0403oReX00`3oRUT0oh]J0?n;FP0A0?n;FP030?n@HP3oReX0oh]J0140oh]J00<0oheN0?n:
F`3oReX04@3oReX00`3oS5d0ohYK0?n;FP030?n;FP030?n<G03oRUT0oh]J00/0oh]J00<0ohaM0?n;
G03oReX03P3oReX50?n:F@0?0?n9F03oReX0ohaL0?nLN03oZHh0okFX0?o9a@3obLX0olW<0?oGg03o
j?40oncg0?oYm03oj?<0onO`0080onK^00@0onO_0?oVkP3oi>`0oo7j;@3oool0403om_h0oo?l0?ob
n`3on?l0ong]0?neXP3oUWH0ohEO0?mjD@3oM4T0ogQ=0?mjD@2KA2`0000007hW803oJeL:0?mRC`04
0?mQCP3oHTl0of]I0?mYF0/0of=@0P3oHdl00`3oHTl0ofaK0?mTD0080?mUD@060?mTD03oHdh0ofEA
0?mTD03oKEX0ofMD1`3oIU40203oIe<0ofUE0?mYEP3oKET0f44b00X30P3oBDT0oe=A103oDU000`3o
DDl0oeQG0?mBD0020?mBD0030?mCD@3oDe80oe=A00<0oe=A00<0oe5?0?mLG03oEUD00`3oDe401`3o
EU@0oeeL0?mAC`3oDU00oeEC0?mDDP3oG5X01@3oDU401`3oEE@0oeEB0?mEDP3oEE80oeIB0?mDD03o
De400`3oEE801P3oE500oeAA0?mED`3oDe40oeEC0?mJF0D0oeEC00<0oe9@0?mED`3oEE<0103oEE<0
103oEeD0oeaL0?mVI@3o`/M30?ooo`050>C5b0000000000000000020P8004P3oool3000000030?no
aP3oool0oooo00@0oooo00@0oko600000000000000000`3oool01@3ogn<00000000000000000P820
00L0oooo00@0P8200000000000000000103oool3000000030?noaP3oool0oooo00<0oooo00@0oko6
00000000000000001`3oool01020H6<000000000000000040?ooo`050?oOh`000000000000000020
P8000`3oool01@20P8000000000000000000VH^@00/0oooo00D0omoS00000000000000000820P007
0?ooo`<0000000<0bH^@0?ooo`3oool01P3oool0100I4Q8000000000003od=P40?ooo`0407iGFP00
000000000;1iOPh0oooo00<0oo?l038S900000000P0000000`1;=3H0VG5e000000020000000306E6
B03oool0oooo0080oooo00@0/7Un000000000000IDI83@3oool01039Ri00000000000000000B0?oo
o`050820P000000000000000003ogn<01P3oool0103o_lH000000000000000030?ooo`040?noaP00
00000000000000P0oooo0`0000040?ooo`<0000000<0P61S0?ooo`3oool0103oool0103o_lH00000
0000000000060?ooo`040?noaP0000000000000000D0oooo00@0oko60000000000000000103oool3
000000030>:LXP3oool0oooo01@0oooo00@0P8200000000000000000103oool01@3ogn<000000000
00000000P8200400oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooolQ0?ooo`060?ogoP3`W980LSdR07Q19`2>Dc/0Nd@[1`1i@bT01`1i@bX0NT@Z07Q19`1f
@2D0Nd@Z07e6:`1k@bX0101i@bT01@1i@bP0ND<Y07Y4:P2AE3`0N48X00D0ND<Y00<0Nd@Z08M<=01h
@RP00`1i@bT01@28CC@0ND<Z07]4:P1oAbd0N44W0080ND<Y00<0Se<k07U3:@1i@bT00`1i@bT00`1h
@RP0QD`c07U3:@0307U3:@0307Q2:@1oAbh0Nd<Y00@0ND<Y00/0Nd@Z05/`6`030@401P8106L^8P1h
=bT0N3HX07De9`22?C00Pcda07@d9P0607Pg:@0707hk;P2=ASX0MCDW07Pg:@1g=RP0RT8g07Xh:`09
07Pg:@0607De9`2<ACT0PCd`07Tg:@2;@cP0N3HX2P1h=bT01`1h=RP0NcT/07dj;@2=@SD0Qcd^07le
9P21>2X02`23>BX03P1f<200JBPH064U5P22>2P0Rc`[08Dj:`2@?c00X4@b0:m:<`3THTL0og=<0?mj
D@3oN500ogUA1`3oN5000`3oMe00og]D0?mlE0050?mkDP040?mnEP3oNU80ogaC0?mkD`P0og]B00<0
og]A0?moE`3oOeL01@3oOE<00`3oNU40ogiD0?mmE0050?mmD`0:0?mkD@3oOeH0ogiE0?mnE03oO580
ogaA0?mmD@3oP5@0ogmD0?mnE0<0ogiC00P0oh1D0?n4F03oQUX0oh5D0?n3E@3oSF40oi5U0?n9F080
oh]J00D0ohYI0?n;FP3oReX0ohYK0?n<F`0W0?n;FP030?n>GP3oTF@0ohYI0140oh]J00<0oheN0?nC
IP3oRUT04@3oReX00`3oS5/0ohmP0?n;FP0A0?n;FP030?n:F@3oReX0oh]J0140oh]J00<0oi1R0?n;
FP3oReX04@3oReX00`3oREP0oh]J0?n;FP0H0?n;FP030?n<G03oReX0oh]J00X0oh]J00<0oh]K0?n:
F`3oReX04P3oReX0103oSEh0ohYK0?n;FP3oReX20?n9F00@0?n9EP3oNdL0ogE90?n5H03oZI40okje
0?oBd@3ofM/0omgO0?oWl03ol?`0ongk0?o/m`3ojO<0onG/0?ohob/0oooo00D0oogo0?oco03olOX0
ooCm0?ono`040?ooo`090?o/k@3o^JP0ohm^0?n5G`3oMdd0[DP[0000001c9Ah0ofeH00/0of9?00P0
of=@0?mVD`3oKUd0ofUF0?mRCP3oIU80of=@0?mSC`H0of=@00D0ofYG0?m]F`3oHDd0ofeK0?mTD009
0?mUD@050?mTD03oIE40ofEA0?mSCP3oIE00203oIU401P3oIE00ofIA0?m[EP3;?Bl020810?m<B`H0
oe9@00@0oe1>0?mBD03oDU00oe9@0P3oDDl40?mCD@030?mBD03oEeH0oeIC00<0oe=A00P0oeME0?mQ
G`3oDDl0oe9A0?mBD03oF5H0oeeM0?mAC`@0oe9A00L0oe]J0?mEDP3oEE80oe=A0?mLFP3oDdl0oe=A
00<0oeEB00L0oeA@0?mDD@3oEE<0oeMD0?mED`3oEU@0oeIE00<0oeEC00<0oe]J0?mDDP3oDe401@3o
EE<01@3oEU@0oeaK0?m@C@3oIFD0on;T0480oooo00D0i<G800000000000000000820P00B0?ooo`<0
000000<0hYbR0?ooo`3oool0103oool0103o_lH000000000000000040?ooo`<0000000<0P6Q/0?oo
o`3oool01@3oool01020J6`000000000000000040?ooo`<0000000<0oko60?ooo`3oool00`3oool0
103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0omoS000000000000
00000820P0030?ooo`05081PH`00000000000000003ne]X02`3oool01@3ogn<00000000000000000
P82000L0oooo0`0000000`1nEeX0oooo0?ooo`050?ooo`040?o@f0000000000001TA4PD0oooo00@0
P7Yn000000000000Bc@f3`3oool00`3od=P03@T900000006000000030;n[[@3oool0oooo0080oooo
00@0bH^@000000000000?b`]3@3oool01039Ri00000000000000000B0?ooo`050820P00000000000
0000003ac]401P3oool0103o_lH000000000000000040?ooo`<0000000<0om3H0?ooo`3oool0103o
ool0103od=P000000000000000040?ooo`<0000000<0P61S0?ooo`3oool0103oool0103o_lH00000
0000000000060?ooo`040?noaP0000000000000000D0oooo00@0oko60000000000000000103oool0
101;=3H000000000002GJ6`F0?ooo`040820P00000000000000000@0oooo00D0omoS000000000000
00000820P0100?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
iol0oooo7`3oool0203onO/0i;B`0:ATCP1c?R<0ND<Y07U2:@1lAB/0Md0W1`1i@bT01P1kA2/0PdXb
07Do9@1h@RP0OTH]07Y4:P@0ND<Y00H0Nd<Z07Y3:@1i@bP0NT@Z091D?01h@RP507U3:@0307]4:P25
CC<0N48X0080ND<Y00@0O4@[0899<01lAB/0Nd@Z0`1i@bT00`1h@bT0NT@Z07U3:@0407U3:@0307Q2
:026C3<0ND<Y00<0ND<Y00<0NT<Z07Q2:01i@bT0101i@bT0201kA2X0F2lK00<10@050P40IblS07Xh
:`1m>Rd0N3HY2@1h=bT01P1n>bh0SDHj07De9`1h=bT0NCLY07Pf:0X0N3LY00D0MCDW08a5>@21?C00
McHX07/h:P0707Pg:@0:07Pf:01j>2/0NcT[07dj;@1i=bT0NcT[07ll;`2:@3<0Rd4b084h:@/0PcTZ
00`0PCPY07df:@1n=bP0Pc<Q08he802U?RD0fU`l0?A`C@3oMU00ogM?0?mjD@3oNE4;0?mhD0030?mk
E03oNe80og]A00D0og]B00H0ogYA0?mmE03oNe<0ogeE0?mjDP3oOE@60?mkDP030?mkD@3oO580ogiD
00D0ogeC00<0oh1F0?mmE03oOE<01P3oOE<04@3oO580ogeC0?mlDP3oOeH0oh5G0?n3F03oPU@0ohIH
0?n<H@3oRed0ohIF0?n8F@3oS5d0oheN0?n:F@3oS5/0ohYJ00P0oh]J00<0ohaL0?n;F`3oReX04@3o
ReX00`3oS5`0oh]K0?n:F@0A0?n;FP030?n;F`3oReX0oh]J0140oh]J00<0oh]K0?n<G03oReX04@3o
ReX00`3oSEd0oiAY0?n8F00A0?n;FP030?n9F03oReX0oh]J02D0oh]J00<0ohmQ0?n;FP3oReX0403o
ReX00`3oRUT0ohaN0?n;FP060?n;FP030?n<F`3oRe/0oh]J00T0oh]J00<0ohaL0?n:F@3oReX04@3o
ReX00`3oS5`0ohYK0?n;FP020?n;FP0C0?n<F`3oR5L0oge<0?miB03oQ5<0oh]I0?n9E`3oQeD0ohYI
0?nBI@3oU6X0oiai0?nSQ03o/IT0okJS0?o5_03oe=<0onSR0?oel`0X0?ooo`050?omo`3omOd0onkh
0?o`n@3onOh0203oool02P3oo_l0ong[0?oMe@2UN6h0000005TO6`3oLF00of1;0?mOB`3oHTh90?mR
C`0:0?mZE`3oJeT0of=?0?mRC`3oIE80ofID0?mZE`3oHTh0ofEB0?mSC`<0of=@0P3oI5400`3oHdl0
ofIB0?mUD@080?mUD@060?mTD03oJ5H0ofUF0?mUD@3oHdl0ofE@203oIU402@3oJeP0ofIA0?m[EP3i
CSd05PH50<Xa;`3oEeD0oe9@0?mCD@030?mBD0030?mGE@3oDU00oe9@0080oe9@00<0oe5?0?mCD@3o
De400`3oDe400`3oDU00oe=A0?mCD@020?mCD@030?mDDP3oEU<0oe9A00<0oe9A00<0oe5?0?mBD03o
EE@00`3oDU40203oFeT0oeEB0?mEDP3oE580oeMB0?mOG@3oFED0oeAB0`3oEE80303oE540oeEC0?mP
GP3oEU@0oeEC0?mFE03oEeD0oeQF0?mFE03oG5X0oeME0?mOGPD0oeEC00H0oeID0?mNGP3oEE<0oe9?
0?mgM`3oh>910?ooo`050>C5b0000000000000000020P8004P3oool30000000306E5B03onOh0oooo
00@0oooo00@0bH^@0000000000004`d>103oool0102GJ6`000000000001H?Cl70?ooo`0406]:C@00
0000000009MXK0@0oooo0`0000000`2TLGD0oooo0?ooo`030?ooo`050>BUZ`00000000000000003T
YJ/01P3oool0101bDeH000000000000V6Q/40?ooo`050?oOh`000000000000000020P8000`3oool0
1020J6`0000000000000000<0?ooo`050?oOh`000000000000000020P8001`3oool4000000030>cK
gP3oool0oooo00@0oooo00@0RV1S000000000000_H:71@3oool01@2oZjd00000000000000000n=oS
00l0oooo00<0d/;703l/;@000000100000000`1H?Cl0ooco0?ooo`030?ooo`040?jf_@0000000000
01XB4Pd0oooo00@0bH^@00000000000000004P3oool01@20P8000000000000000000/YnS00H0oooo
00@0bH^@0000000000009QXK103oool0102GJ6`000000000002`NWh60?ooo`040=JCV@0000000000
04`d=P@0oooo0`0000000`1B>C/0oooo0?ooo`040?ooo`050>BUZ`00000000000000003TYJ/01@3o
ool0103TYJ/000000000000C3@h50?ooo`040?noaP0000000000000000@0oooo00D0f:fd00000000
00003@T90>BoaP0E0?ooo`04081`LP000000000002HJ6`@0oooo00D0omoS00000000000000000820
P0100?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo
7`3oool0203PZJ80KSXN07U3:@1i@bT0ND<Z07Do9@1b?B<0ND8X201i@bT00`1lAB/0LclU07U3:@05
07U3:@0707Q2:02;D3L0R4`e07Q29`1jA2X0Se@k07Q2:00507U3:@80MT4W0P1i@bT00`1jA2X0NdDZ
07U4:@0507U3:@0307a5:`1i@bT0ND<Y00@0ND<Y00<0N48X08I<<`1i@bT00P1i@bT0101h@RP0TEDl
0858;`1h@RP407U3:@0907a5:P0Y5``0000000H30@1X<2@0NcT[07Dd9P29@cL0NcT[00P0N3LY00H0
OS/]08a5>@1g=BL0N3HX08Y4>01m>Rd:07Pg:@0407De9`2<ACT0PCd`07`i:`D0N3LY0P1g=RP01@1m
>Rd0N3DX07Xh:`1n>Rd0MSHX0080N3LY00@0NcT/08Hm;`20=RL0PcPZ2@23>BX0301k=BP0MC@W09E3
=031DcX0lVM80?mcCP3oLTP0ofa10?mS>`3oJT80ogA=0?miD@d0ogQ@00<0ogM?0?mlE@3oNe<0203o
Ne801P3oNU40og]C0?mmE@3oOUH0ogYB0?miD0<0og]B00<0og]A0?n3G@3oOUD01@3oOE<00`3oOE80
oh=K0?mnE0030?mmD`090?mlDP3oNe80ogU?0?n6GP3oQE/0oh1C0?n8F@3oREX0oheM0080oh]J00<0
ohYI0?n;FP3oReX03P3oReX00`3oSEd0oh]L0?n;FP0A0?n;FP040?n:F@3oT680ohaN0?n:FA40oh]J
00<0ohmR0?n?H03oRUT04@3oReX00`3oR5L0ohUH0?n;FP0@0?n;FP030?n<G03oU6L0ohYI0140oh]J
00<0ohiO0?n:F@3oReX04@3oReX00`3oRUP0oh]J0?n;FP0A0?n;FP030?n=G@3oReX0oh]J00l0oh]J
00<0ohYI0?n=GP3oRUX0203oReX00`3oReh0oheN0?n:F@060?n;FP030?n:F@3oSUl0ohYJ0180oh]J
00<0ohYI0?n<F`3oRUT00`3oReX0103oQE@0ogU80?mfA@3oPe890?n;FP0:0?n7EP3oR5D0ohEB0?n5
D03oREP0oiQ`0?nbUP3of/l0om[B0?o`kb<0oooo00@0oo_o0?obn`3olOX0ooOo3@3oool02@20Kg@0
0@410:efN`3om?/0oknn0?n3M@3oI540oeQ20?mOC0070?mRC`030?mWE@3oHe00of=@00<0of=@00H0
of9>0?mTDP3oIU<0ofID0?mYE`3oHdl20?mSD080ofYG00<0of9>0?mUD@3oIE40203oIE401@3oI500
of9>0?mUD@3oIE40of9>00P0ofIA00d0ofMB0?mUD03oJUD0oe]701h91`2]:RT0oe5?0?mCD@3oEE<0
oeID0?m@CP3oDU00oeAB00@0oe9@00<0ode=0?mBD03oDe400`3oDe400`3oDU00oe]J0?mBD0020?mC
D@030?mBD@3oD4l0oe9A00<0oe9A00L0oeEC0?mHEP3oDU40oeME0?mED`3oDE00oe]J00@0oeEB00<0
of5P0?mHE@3oEE800P3oEE801@3oEU40oeaH0?mGE@3oDU00oe=A0080oeEC00@0oeAB0?mGE@3oEeD0
oeeK0P3oEU@60?mED`060?mFE03oHf80oe=A0?mBD03oI6<0okc0@03oool01@3ogn<0000000000000
0000P7Yn0180oooo100000000`39Ri00oooo0?ooo`020?ooo`050?oioP0I4A8000000000000o;2d0
103oool01@3olo`00000000000000000oko600D0oooo00D0oo?l00d92@00000000000?oQjP040?oo
o`@0000000<0onS/0?ooo`3oool00P3oool01P1UADP000000000000000006A4B0?oco0D0oooo00@0
<b<T000000000000OUMJ103oool01@3ogn<00000000000000000P82000<0oooo00D0S8R900000000
000000000?kFfP0;0?ooo`050?oOh`000000000000000020P8001`3oool400000003075>D@3oool0
oooo00<0oooo00D0on7Z00000000000000000?oco0050?ooo`050?kFfP00000000000000002oZjd0
4@3oool00`1nEeX0000000000003000000030:F2Q`3oool0oooo01<0oooo00D0oko6000000000000
00000?oco00A0?ooo`050820P000000000000000001UATP01@3oool01@3olo`06A4B000000000000
OUMJ00@0oooo00D0oo?l00000000000000000?noaP040?ooo`050?oioP0I4A80000000000020LGD0
103oool4000000030?o@f03oool0oooo00<0oooo00H0IDE8000000000000000001TA4P3onOh40?oo
o`0406E5B0000000000003l/;@D0oooo00@0oko600000000000000001@3oool01@2GJ6`000000000
00000000hYbR00/0oooo00<0bH^@0?oXk03oool01P3oool0101<=3H000000000002GJ6`40?ooo`05
0?oOh`000000000000000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?oooah0oooo00<0olk=08mC?01h@RP00`1i@bT00`27C3@0O4@[07I19`07
07U3:@0307<n901mAB/0MD0V00L0ND<Y00H0OTL/07i6;01i@bT0NT@Z095D?01h@RP507U3:@0707m7
;@1i@RP0MT4W07i6;01lAB/0MD0U07@o8`0507U3:@0308=;<@1lAB/0ND<Y00@0ND<Y00<0N48X08M=
=01i@bT00`1i@bT00`1kA2X0ND<Z07U3:@0407U3:@0507a4:@0V50T0000000d5101f=RP00P1h=bT0
0`20?2l0NSPZ07Pg:@0707Pg:@0607hk;P2=ACT0MCDW07Pg:@20?2l0NSLZ2P1h=bT0101g=BL0RD<g
080l;`22?S4407Pg:@0507Le9`20?2l0Pcha07/h:`1h>2X00P1g=RP307Pg:@0307/i:`2?A3L0PCPZ
00L0PcTZ00l0PCPY07dg:@1e<bD0]Tlk0?AT@`3oKD/0ogE>0?mgC`3oMDd0og]H0?mfCP3oIch0ofLl
0?mV?@3oKdL03@3oN5000`3oMdl0ogiI0?moE@0:0?mkDP050?mkD@3oO5@0ogQ?0?n1G03oNE00103o
Ne800`3oO5<0ogeC0?mmD`040?mmD`0>0?mlE03oO540ogaC0?mkD03oOED0ohUP0?n3E@3oQ5H0ohaO
0?n;G@3oRET0ohaK0?n;FP3oS5dD0?n;FP030?n<F`3oReX0oh]J0100oh]J00<0ohYJ0?n:F`3oReX0
4P3oReX00`3oSF40oheP0?n;FP0A0?n;FP80ohiO00<0ohYI0?n;FP3oReX03P3oReX00`3oSEd0oiAW
0?n8F00A0?n;FP030?n@H`3oRUT0oh]J0140oh]J00<0ohaM0?n;FP3oReX0403oReX20?n9F140oh]J
00<0ohYI0?n=H@3oRe`02@3oReX00`3oSEh0ohaN0?n;FP050?n;FP030?n9F@3oS5/0ohaL0180oh]J
00<0ohYK0?n;F`3oReX00P3oReX0103oR5L0ogU80?mfA@3oO4`<0?n;FP0<0?n:F@3oS5X0ohaK0?n:
F`3oQE80oi5T0?nBI@3oVg<0oj^<0?o:]`3og=@0oo;c7P3oool0103om_l0oo;k0?oanP3onol>0?oo
o`0305Dk?@0e9BH0omgV0080oooo00H0oo;h0?oQi@3o_[`0ogEU0?mJAP3oH4`50?mRC`030?mPC@3o
HDd0ofAB00D0of=@00T0of=?0?mUD`3oIU@0of9>0?mWE@3oHTh0ofQF0?mYE`3oHTh02P3oIE401@3o
I500ofUG0?mTD03oIE40of9>00T0ofIA00d0ofMC0?mYE03oH4`090X806<F5P3oDDl0oe9@0?mCD@3o
DU00oeMF0?mBD@3oDDl0odm=00<0oe9@00<0oeQF0?mDD`3oDe40103oDe400`3oEU@0oe=A0?mCD@02
0?mCD@030?m@C`3oDE00oe9A0080oe9A00L0oeED0?mNG@3oDU40oeEC0?mAC`3oEU@0oeME00<0oeEB
00@0oeYF0?mWI@3oFED0oe=A0P3oEE801@3oE500of5O0?mIE`3oEE<0oeAC00@0oeEC00D0oeID0?mG
E@3oEE<0oe9@0?mCD@050?mED`070?mEDP3oFUP0oeIC0?mFD`3oDDh0ofAR0?ni_00o0?ooo`050?oO
h`000000000000000020H6<04P3oool5000000050>C5b03oool0oooo0?ooo`3;[[@00`0000000`1a
CU40oooo0?ooo`030?ooo`050<V;T0000000000004/d=P3olo`0103oool0101nEeX000000000001n
EeX50?ooo`@0000000D0YH^@0?ooo`3oool0oooo0?7>d@050000000304/d=P3olo`0oooo0080oooo
00D0bH^@00000000000000000>:LXP040?ooo`050?oOh`000000000000000020P8000`3oool01@3;
];H00000000000000000S75e00D0oooo00@0om3H0?oQjP3oool0on7Z0P39Ri001@2`NWh000000000
00000000IDI800<0bH^@00@0i;Jm0?ooo`3oool0oooo0`000000200I4A8000000<V;T03ohNX0oooo
0?oioP3oool0hYbR0P0000000`1;=3H0oooo0?ooo`040?ooo`050?oioP00000000000000002<R8T0
403oool00`3o_lH00000000000040000000300d92@3l[K@0oooo01<0oooo00D0oko6000000000000
00000?noaP0A0?ooo`030820P000000000000080000000H0bH^@0?ooo`3oool0oooo0?oco02GJ6`3
000000030>:LXP3oool0oooo00<0oooo00D0IDI8000000000000Bc@f0?oioP030?ooo`050;n[[@00
000000000000002oZjd0103oool40000000304/d=P3ohNX0oooo0080oooo00<0hYbR000000000000
0`0000001@2UU9T0oooo0?ooo`3oool0i<G800<0000000<0LDiA0?ooo`3oool00`3oool0103o_lH0
00000000000000050?ooo`030?oQjP0=2@T000000080000000<0i<G80?ooo`3oool00P3oool00`3o
d=P0bH^@0?ooo`030?ooo`0306E5B01aCU40oo?l00D0oooo00D0bH^@00000000000000000?noaP04
0?ooo`050?oOh`000000000000000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?oooad0oooo00<0okfj0:]YE@1e@2H00`1i@bT0101h@RP0Re0h
08A;<P1i@bP607U3:@0507E09P1nAR/0NT<Y07Do9@1i@bX01P1i@bT01P1f@2H0N48X07U3:@1jA2X0
TE@l07Q2:0D0ND<Y00L0Q4/b07]4:`1oAbh0MT0V07Y4:P1f@2H0MClU00D0ND<Y00<0O4H[07U3:@1i
@bT02@1i@bT00`1h@RP0MD0V07U3:@0407U3:@0907I19`21B2h0>al@0000000?1`D0O3T[07Pg:@1g
=BL0MC@V00T0N3LY00D0OS/^08e6>P1e=BL0N3HX07Le9P0;07Pg:@0407De9`2<A3P0PCd`07Hf:080
N3LY00D0McDW084m;`1j=bT0N3LY07/i:`0707Pg:@0307/i:`2DBC`0PCLX00@0PcTZ0P21>2X02021
>2T0XT/k0==K@03jHd40og9=0?mfC`3oMdl0ogE=0P3oM4d01`3oMU40ogQ@0?mdC03oJ3h0of@k0?mU
?03oLd/03@3oN5000`3oMdl0ogU@0?mkDP0;0?mkDP080?mjD@3oOeD0ogYA0?mnEP3oNe40og]B0?mk
D@3oOE@50?mmD`070?mlDP3oO500ohUO0?n4E@3oQUH0ohYJ0?n;G@070?n;FP030?n<G@3oRU/0oh]J
0180oh]J00<0ohiO0?n:F`3oReX04@3oReX00`3oRUT0ohaK0?n;FP0A0?n;FP030?n9F@3oR5P0oh]J
0140oh]J00<0ohmR0?n@H`3oRUT0403oReX00`3oSEd0oiAX0?n8F00A0?n;FP030?n@H`3oRUT0oh]J
0100oh]J00<0ohYI0?n@HP3oReX0403oReX00`3oRUT0ohmR0?n;F`0B0?n;FP030?n:F@3oReX0oh]J
00T0oh]J00<0oh]N0?n<G03oReX0103oReX00`3oRe`0ohiO0?n;FP0A0?n;FP030?n:F@3oRe/0ohaL
00<0oh]J00D0oh1?0?mcA@3oNdX0ohQG0?n<F`0:0?n;FP060?n:F@3oSEd0ohYK0?n;FP3oRe`0oh]J
0P3oR5L02@3oR5D0ohID0?n=GP3oTF@0oiE[0?nYQ`3obKH0omgE0?ojo`0H0?ooo`050?omo`3om?d0
oo7j0?obn`3on_h03`3oool00`0D3Pl0JdU<0?ooo`050?ooo`050?oam`3o`;l0ohf20?mWE@3oHDd0
0P3oHDh0103oHTl0of=@0?mTDP3oHdl90?mSD0050?mTD@3oIE<0ofaJ0?mRCP3oHdl02P3oIE401@3o
I500ofaI0?mTD03oIE40of=>00P0ofIA00L0ofMD0?m^G03oIDl0ofeH02h?30184100oe5?0080oe9@
00/0oe5?0?mCDP3oDDl0oeAC0?mKF@3oDDl0oe9@0?mAC`3oH5l0oeUF0?mBD0040?mCD@030?mBD03o
De40oe=A0080oe=A00<0oe1?0?mAC`3oDU400P3oDU401`3oDE00oe9@0?mBD@3oDU40oe5@0?mDDP3o
De400`3oEE800`3oEeD0of1N0?mED`030?mEDP050?mCD@3oGed0oeQF0?mED`3oHF001@3oEE<0103o
EE80oeYH0?mEE03oFUP50?mED`030?mDDP3oDDl0oeIC0080oeIC00<0oe9?0?mRH03of]d0;P3oool0
0`3ojnl0oJje0?ooo`0>0?ooo`<0000000<0LDiA0?ooo`3oool0403oool30000000706E5B0000000
3@T909MXK039Ri00UfQ/01TB4P030000000308b2Q`3oool0oooo00<0oooo00T0oo?l04/d=P000000
000001TA4P39Ri00oko60>:LXP0b8b@00P0000000`0I4A80on7Z0?ooo`040?ooo`<0000000<0/7Un
0000001nEeX00P39Ri001@0V6Q/00000000000000000IDE80080000000@06A4B0:AaM@2`NGh0<R<T
0`0000000`0I4A80oo?l0?ooo`030?ooo`050?oOh`000000000000000020P8000`3oool00`3ol?D0
6A4B000000020000000907iGFP39Ri00bH^@0;1jOP0b8b@000000<V;T03oool0oko600X0000000@0
P61S0?ooo`3oool0oooo0`0000000`39Ri0000000000000200000003081PH`3oool0OUMJ00800000
00<0/7Un0?ooo`3oool01@3oool0101;=3H0000000000020H6<@0?ooo`06038S90000000000000d9
2@39Ri006A4B0`0000000`3RW:80oooo0?ooo`0B0?ooo`<0000000<0hYbR0?ooo`3oool03`3oool0
2P20P8000000000000000000<b<T0000000I4A80UfQ/0;1jOP0b8b@30000000301TA4P3olo`0oooo
00@0oooo00D0YIBI0000000000000000075>D@020?noaP060>:LXP0I4Q8000000000000I4A80oo3e
103oool30000000605Pm?`000000000007iGFP39Ri00Bc@f0`000000200I4A80/7Un0000000=2@T0
OUMJ0<V;T02`NGh06A8B0`0000000`2<PXL0oooo0?ooo`030?ooo`040?noaP0000000000000000H0
oooo00H0OUMJ000000000000000000d92@1UADP20<V;T003075>D@000000IDE800@0oooo00@0IDE8
000000000000IDE80P39Ri000`2`NGh0<R<T000000020000000306E5B03oool0oooo00<0oooo00D0
omoS00000000000000000820P0100?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0oooo6`3oool0103ok>/0_7e]07a5:`1h@RP507U3:@0307U2:@2?Dc`0OdL^
00@0ND<Y00L0Nd@[07]4:P1h@RL0RTlf07e5;02=DSX0MT4W00D0ND<Y00H0O4D[0858;`1h@RP0ND<Y
07Y4:P1nARd407U3:@0507Y4:P1i@bT0O4D[07U3:@1i@bX00P1i@bT00`1mARd0Md0V07U3:@0407U3
:@0307]4:P1i@bT0ND<Y00D0ND<Y01@0Md8X07U3:@1i@bT0ND<Y07i7;@20Abh0ND8X07U3:@1jA2X0
O4D[07Y4:P1lAB/0O4@Z03hR4P0000003`L507/i:P1h=RP0PSda07hk;@T0N3LY00<0OS/^08e6>P1e
=BL00P1m>Rd;07Pg:@0707De9`2;ACT0PSha07dj;@1f=BL0NcT[07dj;@0;07Pg:@0;07/h:`27?Bl0
OcLY080h:P25>R/0T3l^0;1<>036ECX0e6550?A/B@3oM4h00P3oM4d00`3oMDd0ogA=0?mdC@030?md
C@0=0?mcC03oNE<0ogQ@0?mfCP3oLDT0ofY10?mW?P3oKD@0ogQA0?mfCP3oNU80ogQ@0?miD@070?mh
D0030?mgC`3oOEL0og]C00l0og]B00T0ogaC0?mmE@3oO5@0oh9I0?n6G@3oQe`0oh=E0?n:G03oSEh0
0P3oRUT20?n<G0X0oh]J00<0oh]K0?n=G`3oReX04P3oReX00`3oRUT0ohaM0?n;FP0B0?n;FP030?n>
G`3oS5/0oh]J0100oh]J00<0ohUI0?n@H`3oSEh04@3oReX20?n>Ga40oh]J00<0oheL0?nBI@3oRET0
4@3oReX00`3oT6<0ohYI0?n;FP0@0?n;FP030?n:F@3oSf40oh]J0100oh]J00<0ohYI0?n>H03oS5`0
403oReX00`3oRUT0oheO0?n=G`0<0?n;FP030?n<G@3oRe`0oh]J0080oh]J00<0ohaK0?n=G@3oRe`0
4P3oReX02P3oS5/0oheM0?n;FP3oReX0ohUH0?n1D03oNDP0oh9A0?n:F@3oS5/60?n;FP070?n<F`3o
Re/0oheN0?n:F@3oS5`0ohiO0?n;F`090?n;FP<0ohYI00/0oh]K0?n=G@3oS5d0oiYa0?nZR@3o]IX0
ol>]0?oD``3oin00ooKe0?oko00?0?ooo`050?ojoP3okoP0ooCm0?ogo@3oo?l03`3oool00`38SI<0
3`X:0>>j`@090?ooo`090?ojo@3oeM80ok6[0?nGS@3oOg40ofUF0?mQC@3oH4/0of9?00/0of=@00H0
ofQF0?mXE@3oIU80ofQF0?mUD@3oIU890?mUD@030?mTD03oLf80ofMC00L0ofIA00L0ofMB0?mVDP3o
IU40ofiI03PB3P0`2`/0oe5?00D0oe9@00P0oe=A0?mFE03oDU00oeED0?mAD03oGUh0oeQF0?mBD0@0
oe=A00<0oeME0?mFE03oDe400P3oDe400`3oFUP0oe]I0?mAD0030?mBD@030?mDDP3oEE@0oe9A00<0
oe9A00H0oeME0?mED`3oEE40oeIC0?mDD03oE5830?mEDP050?mDD@3oGU/0oeMF0?mED`3oF5L01@3o
EE<20?mDDP030?mIF03oF5L0oeEC00D0oeEC00<0oeUF0?mIE`3oEU<00P3oEU<0103oEE80ogEd0?oE
e`3oo_lV0?ooo`090?o[k`3Xb<X0XiVI081[L01YB4/0>RPZ00L51@0>2@X0ooWm00h0oooo00@0LDiA
000000000000<b<T4P3oool3000000030?noaP2UU9T081HG00D0000000<03@T9075>D@3ojnd01P3o
ool00`3oj>`0H5=F000000060000000304Le=P3ac]40oooo00@0oooo00H0omoS0000000000003@T9
0?oioP1VEeX600000004075>D@3ojnd0/YbR03l/;@D0000000<01`D5075>D@3ne]X01@3oool01@3o
gn<00000000000000000P82000@0oooo00<0o]KJ081XK00I4Q801`0000000`39Ri00oooo0?noaP0:
00000004081PH`3oool0oooo0?oOh`80000000<03@T90?ooo`1/G5l00`0000000`20H6<0o]3H0000
0002000000030?oOh`3oool0oooo00D0oooo00@0eY>I000000000000>BLY3`3oool0302oZjd00000
000000000000Wh640?ooo`3oj>`0YIBI01<=3P0000003@T90;:;T1<0oooo00@0LDiA000000000000
IDI84@3oool01P20P8000000000000000000dZZ`03l/;@H0000000<0?b`]0?kFfP3oool01@3oool0
0`3om?H0S8:703<S90060000000300d92@20H6<0lLkA00@0oooo00L0onoa000000000000000008J1
Q02UU9T09QXK00D0000000D0>BLY0?kFfP3oool0/YbR020F5`050000000300d92@1aCU40on_]00D0
oooo00@0oko600000000000000001P3oool00`3ojnd0S7Un04`d=P070000000300d92@3oool0oooo
0080oooo00<0P75e01XB4P0000001P0000000`0/7b00YIBI0?oioP050?ooo`050?oOh`0000000000
00000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?oooa/0oooo00<0]WIU07<n901i@bT01P1i@bT00`1f@BL0SU<j07m7;P0307U3:@0807Q19`1m
AR`0ND<Y07I19`1e?bD0ODD/08iB>P1f@BL507U3:@0307e6;024BS80N48X0080ND<Y00P0MClV07U3
:@1i@bT0ND8X07a4:P1oAbh0OTH]07]4:P@0ND<Y00<0QD/c07]4:P1i@bT00`1i@bT00`1h@BL0QD`c
07U3:@0607U3:@0307M2:01i@bT0ND<Y0080ND<Y00@0N48X07]4:`1i@bT0OTH/0`1i@bT0201lA2X0
?24@0000000?1`D0NcTZ07Lf:01m>R`0NcT[2@1h=bT00`1n>bd0RT@h07De9`0207Xh:`T0N3LY00<0
N3HX07Tf:@1h=bX00P24?c800`1n>Rd0N3LY07Pg:@0;07Pg:@0807De:01b=BP0Qch`09]2<02cBcL0
iF=70?mdC@3oMdl=0?mdC@060?maB@3oN500ogQ@0?mhD03oNU80ofi50P3oIC`01`3oK4<0ogM?0?mi
D@3oOUP0ogQ@0?miD@3oMdl01@3oN5000`3oN4h0ogYA0?mkDP090?mkDP0;0?mjD@3oNE40og]A0?mo
E`3oOeD0ohAF0?n>I03oT680oh]J0?n:F@3oRET0203oReX00`3oRUT0oh]J0?n;FP070?n;FP030?n9
F03oS5/0oh]J0180oh]J00<0ohYI0?n;G03oReX04P3oReX00`3oSf80oh]K0?n;FP0A0?n;FP030?n:
F@3oReX0oh]J00l0oh]J00<0ohYI0?n8E`3oRUT04@3oReX00`3oR5L0oh]J0?n;FP0@0?n;FP030?n@
HP3oRUT0oh]J0140oh]J00<0ohYH0?n;FP3oReX0403oReX00`3oRUT0oh]J0?n;FP0?0?n;FP030?n;
F`3oReX0ohYI00d0oh]J00L0ohaN0?n=GP3oReX0oh]J0?n<F`3oT640ohYI0140oh]J00T0ohYI0?n?
H03oRET0ohaK0?n8E`3oNTT0ogE60?n0C`3oS5/0103oReX01P3oRET0ohYI0?n<G@3oQUH0ohmP0?n@
H@80oh]J00<0oh]L0?n=GP3oReX04P3oReX02@3oRET0ohMF0?n4DP3oQU80oiQ_0?o3[P3oi^80oo7b
0?ono`090?ooo`040?ojo`3ol_/0oo7j0?odo140oooo00<0ooGn02hP8@0g9RL03`3oool01P3ohnD0
oifE0?mnL@3oJUL0oea70?mSC`T0of=@00<0ofA@0?mYE`3oJ5D00P3oI500103oIe<0ofMD0?mUD@3o
I5040?mUD@050?mZEP3oKEX0of=?0?mbH@3oIe<01`3oIU401`3oIE40of]H0?m/F@3oK5L0BaLB01P5
1P3oD4h01P3oDU001`3oDDl0oe5@0?mAC`3oEE<0oeiM0?mHEP3oD4l0103oDe400`3oE540oe=A0?mC
D@020?mCD@030?mIF03oFeX0oe5@0080oe9A00<0oe5@0?mFE03oEeD0103oDU401`3oE500oe=A0?mF
D`3oEeD0of=Q0?mHD`3oDe400`3oEE800`3oDdl0oeEB0?mED`070?mED`040?mBD03oEE<0oe5?0?mD
D`@0oeEC00<0oeUG0?mWI`3oGE`0103oEU<0103oEE80oeME0?n[[`3oo_lR0?ooo`030?oFg`2RL7@0
6a8C00H0000000<040/;07QCEP3oj?803P3oool01@3l[K@00000000000000000o:fd0140oooo0`00
00002@3o_lH0oooo0?oOh`2GJ6`0<R<T0000001<=3H0bH^@0?oco00:0?ooo`080?noaP2GJ6`0Bc@f
0000000I4A80IDE80<V;T03onOh<0?ooo`060>:LXP1nEeX06A4B02HJ6`2`NGh0on7Z103oool01P3o
_lH0F3do0000000b8b@0IDE80>BoaQ<0oooo00P0/7Yn01TA4P000000000002HJ6`1nEeX0bH^@0?oc
o0@0oooo00D0omoS00000000000000000820P00<0?ooo`040?b]]02GJ6`0Bc@f081PHal0oooo00D0
LDiA00000000000000000?o`m@030?ooo`0508b2Q`00000000000000003ne]X04P3oool01@3l[K@0
0000000000000000o:fd0100oooo00d0P82000000000000000000?oOh`3oool0oko609MXK00I4Q80
<R<T06E5B039Ri00ooWn00X0oooo00L0oko6075>D@000000000001TA4P2GJ6`0oo?l00d0oooo00H0
hYbR04`d=P000000Bc@f0;1iOP3ol?D30?ooo`070?oOh`1nEeX0<R<T0000001<=3H0bH^@0?oco00D
0?ooo`030?oQjP2GJ6`0<R<T0080000000<0F3do0<V;T03od=P01@3oool02@3ol?D0bH^@07iGFP0I
4A80000001TA4P1UADP0bH^@0?o`m@070?ooo`050?oOh`000000000000000020P800@03oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooaX0oooo00<0ok:]
07]4:@1h@RT01P1i@bT0101nARd0OdL^08]A>01oAbd207U3:@0307Q3:01h@BL0ND@Y00<0ND<Y00<0
ODD/08aA>@1f@BL01P1i@bT0301h@RP0ND<Y07U3:@1i@bT0MClV07U3:@1h@RP0NT@Z07a5;01kA2X0
ND8X08I==0@0ND<Y00<0QD/c07]4:`1i@bT0101i@bT00`1mAR`0ND<Y07U3:@0407U3:@80N48X101i
@bT00`1i@bX0OTH/07]4:`0407U3:@0807a5:P0/5`d0000001881@1k>BX0MC<V078a8`1g=RP907Pg
:@0507Xh:P1j=b/0N3LY07Le9`1g=RP01`1h=bT0201g=RP0N3LY07dj;01l>2/0OCT]08I1=01m>Rd0
MC<U2`1h=bT02@1e=RP0K34U07dj;@2K@Bl0gF560?m_C03oMdh0ogI>0?meCP0>0?mdC@030?meCP3o
NU<0ogQ@00<0ogQ@00@0ofe40?mV?@3oI3/0ofi50P3oN5001@3oMDd0ogYD0?mjDP3oNU80ogM?00@0
ogQ@00<0ogeF0?mkDP3oNe801@3oNe802@3oNU40ogUA0?miD03oQ5X0oh1E0?n1E03oSF40oheM0?n<
F`020?n:F@030?n;F`3oSEh0oh]J00L0oh]J00<0oh]K0?n<F`3oRUT02@3oReX00`3oSV40oh]K0?n;
FP0B0?n;FP030?nAH`3oReX0oh]J0140oh]J00<0ohaN0?n;FP3oReX0403oReX00`3oRUT0oh]J0?n;
FP0T0?n;FP030?n9F03oReX0oh]J0100oh]J00<0oi1R0?n:F@3oReX0403oReX00`3oREP0ohYI0?n;
FP0?0?n;FP030?n:F@3oSf80oheP0140oh]J00<0ohiO0?n=H@3oRUT03@3oReX01P3oRET0ohaN0?n;
G03oRUX0oheN0?n9F140oh]J00<0oh]K0?n<G03oR5P00P3oReX0103oNdX0ogM60?miB03oREP40?n;
FP050?n:F@3oReh0oh]L0?n>G`3oReX00P3oRUT0103oReX0ohUH0?n<F`3oRUTC0?n;FP0;0?n=GP3o
S5`0oh]J0?n;FP3oQUH0oh=@0?n4DP3oWGH0okBH0?oEb03ol>l01P3oool01@3onOh0oo7j0?oanP3o
lOX0ooSl0140oooo00<0iIjT00L51@23FUh04@3oool01P3omol0olO50?n;O`3oG4L0oeY40?mPC0L0
of=@00<0of=?0?mYE`3oJ5D00P3oIE40103oIU80ofQF0?mVDP3oJ5D40?mUD@050?mVD`3oIe@0ofA?
0?maG`3oIU80203oIU401P3oJUL0of]I0?m/E`1F6QD03`<40?m@CPH0oe9@00L0oeAB0?mMG03oDDl0
oe5?0?mFE03oDE00oeED00D0oe=A00L0oe9@0?mCD@3oDe40oe=A0?mMG03oGUd0oe5?00@0oe9A00`0
oe9@0?mBD@3oDU40oe9A0?mCDP3oG5X0oeEB0?mCD@3oF5@0oe]H0?mFD`3oDe430?mEDP050?mDD03o
EE80oeEC0?mFE03oHV401@3oEE<01P3oGE`0oeEC0?mFE03oEE<0oeQF0?mFE080oeEC00<0oeUG0?mQ
H@3oEU@0103oEU<0103oEE<0oeID0?mXI`3o`LDO0?ooo`030>Rc^P1cD5<06a8C00H0000000@07aDF
07QCEP3ETiT0onkb4@3oool0100b8b@000000000001UADPA0?ooo`<0000000<0oko60?ooo`3oool0
D`3oool01@3ogn<00000000000000000P82002l0oooo00@0?b`]000000000000UfQ/103oool01@3T
aLP00000000000000000_j^]01<0oooo00@06A8B000000000000IDE8403oool01@20P80000000000
00000000omoS06L0oooo00D0omoS00000000000000000820P0100?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo6@3oool0103o[jT0Nd<Y07m7;P1h@RP6
07U3:@0?0859<025Bc<0S54i07m7;P1i@bT0OdL]07Q2:01h@BL0ND<Y07Q2:02;DCP0Nd@[07a5:`2;
DCP0N44W00D0ND<Y00X0MT0U07U2:@1i@bT0ND<Y07Q2:01f@BL0ND<Y07i6;01nARd0MT4W0P1i@bT0
0`1oAbh0ND<Y07U3:@0207U3:@0308A:<P1kA2X0ND<Y00<0ND<Y00<0MT4W07M19`1i@bT01@1i@bT0
1`1f@2H0ND<Y07U3:@1h@RP0Nd@Z07m8;@1kA2/01P1i@bT01`1lABX09A<:0000000E2PH0NcPZ07di
;01m>Rd02P1h=bT01@1g=RP0M38U07Le:021?300McHY00H0N3LY00T0MSDW08@o<P1e=BL0OCX]07Xh
:P1g=RP0N3LZ07di;@1i>2X02@1h=bT02`1e=RP0K38U08Dn;`2kCcH0hf140?m^C03oNE<0ogE=0?mf
D@3oNE<0ogA<00h0ogA=00<0ogE>0?mhD@3oN5000`3oN5003@3oNE40og590?mY@03oIC`0ofe40?mg
C`3oNU80ogQ@0?mkE03oNe80ogM?0?mjDP3oMTh00P3oN5000`3oNe<0og]B0?mkDP020?mkDP0:0?mi
D03oNE40og]A0?n5F`3oQEP0oh5C0?n>H03oS5/0ohYJ0?n9F@D0oh]J0P3oSEh80?n;FP030?n8FP3o
RUT0ohYK00P0oh]J00<0ohYI0?n>G`3oReX04P3oReX00`3oREP0oheM0?n;FP0A0?n;FP030?n9F03o
S5`0oh]J0100oh]J00<0ohYI0?nBIP3oS5`0403oReX00`3oR5P0oi5T0?n>H@0A0?n;FP030?n9F03o
ReX0oh]J0100oh]J00<0oi1S0?n:F@3oReX0403oReX00`3oRUT0oh]J0?n;FP0?0?n;FP030?n:F@3o
T6<0ohiP0180oh]J00<0oh]L0?n;FP3oReX03P3oReX00`3oSEh0ohaL0?n=GP0B0?n;FP0:0?n:F@3o
Sf00ohUI0?n<F`3oPU40ogM60?mjB@3oQE@0ohaK0?n;FP80ohYI00D0ohaM0?n:F@3oSUl0ohiO0?n:
F@040?n;FP030?n?H03oREP0oh]J0180oh]J00<0ohaK0?n=GP3oReX0103oReX0203oRUT0ohED0?n3
C`3oQ580oieg0?nbU@3oa[80on;J0`3oool00`3olo/0on[d0?ofo`0C0?ooo`03071=D@000000TXb<
01<0oooo00H0oo;d0?no_@3oVY40ofYG0?mI@`3oHdl50?mSD0030?mSC`3oL5l0ofMD00<0ofEA00D0
ofA@0?mVD`3oJ5H0ofMC0?mVD`020?mUD@050?mTD03oHD`0of=?0?mcH`3oIe<02@3oIU401@3oHdl0
ofYE070Q6P010@80oe1>00H0oe9@00T0oeAB0?mHE`3oDU00oe9@0?m?C@3oD4h0oeIE0?mFE03oDU00
0`3oDe401`3oG5/0oe=B0?mCD@3oDe40oeUH0?mLFP3oDDl00`3oDU400`3oDE00oeAB0?mAD0020?mB
D@070?mCDP3oI680oe=A0?mEDP3oEU80oe=?0?mFE0050?mEDP040?mCD@3oEE<0oeID0?mOG`D0oeEC
00H0ofMU0?mDDP3oFUP0oeUH0?mGE@3oFEL20?mED`040?mJF03oHEl0oe5>0?mFDP@0oeIC00@0oeYH
0?mFDP3oHV00onS[6P3oool0103ojnl0dI2E07=@D`0K4Q<60000000301lE5P1hDeH0j[Ro01D0oooo
00D0bH^@00000000000000000>:LXP0@0?ooo`<0000000<0oko60?ooo`3oool0D`3oool01@3ogn<0
0000000000000000P82002l0oooo00@03@T9000000000000om3H103oool01@3ol?D0000000000000
0000VI6B01<0oooo00D0IDI800000000000000000?7>d@0?0?ooo`050820P000000000000000003o
gn<0I`3oool01@3ogn<00000000000000000P8200400oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooolG0?ooo`050?oZj@2oNfX0N48Y07M19`1nAbd01`1i
@bT01P1i@RP0N48X08I<<`1mAB/0O4D[07Y3:@@0ND<Y00D0Q4/a07Y4:P1mAB`0SU8j07I19`0407U3
:@0307Q2:025Bc<0N48X0080ND<Y00D0N48X07a4:P1oAbd0NT<Y07Y4:P0207U3:@0307U3:01i@bT0
ND<Y00<0ND<Y00<0R4de07a5:`1i@bT00P1i@bT00`1g@RP0PdXa07]5:`0607U3:@0707I09P1jA2X0
Nd@Z07e6;01i@bT0OdL]07U2:00607U3:@0707a5:P0V4`X0000001D:1P1k>BX0Oc/^07ll;P0:07Pg
:@0407Lf:01e<bH0N3PY07dj;@@0N3LY00D0NcP[07dj;01h=RT0O3T/07`j;00407Pg:@0307@d9@21
?300NSP[00D0N3LY0180McHY07Hf:029?Rl0ZTPc0<EF?P3OHD80nFe:0?maC03oM4h0og==0?meD03o
M4`0ogE?0?mfC`3oMe40og=<0?mfC`3oMe0<0?mdC@030?mgD@3oN500ogQ@00<0ogQ@00L0ogUA0?mg
C`3oKTH0ofHm0?mW?P3oKD@0ogI>0080ogQ@00l0ogU@0?mhD03oNe@0ogUA0?mhD@3oNU40ogaC0?n2
F@3oPUP0oh9E0?n<H03oRU/0ohUH0?n;G03oS5/0303oReX00`3oS5`0oh]J0?n;FP080?n;FP030?n=
G@3oRe/0oh]J00H0oh]J00<0oh]L0?n<G03oReX04@3oReX00`3oRe/0ohaL0?n;FP0B0?n;FP030?n<
G03oReX0oh]J0100oh]J00<0oh]K0?n;FP3oReX03`3oReX00`3oRUT0oi5T0?n>H@0A0?n;FP80ohYI
4@3oReX00`3oT6<0ohYI0?n;FP0?0?n;FP030?n:F@3oTfL0ohaL0100oh]J00<0ohaK0?n;FP3oReX0
403oReX00`3oRe/0oheO0?n:F@0A0?n;FP030?n<G@3oS5`0ohYJ0140oh]J00d0ohaK0?n;FP3oReX0
oh=C0?mhA`3oOD`0ohQG0?n;FP3oS5`0oh]J0?n>H03oRe`0oh]K0080oh]J00<0ohYJ0?n;FP3oReX0
0P3oReX00`3oS5/0ohaL0?n;FP0B0?n;FP030?n;F`3oRUT0oh]J00P0oh]J00`0ohYJ0?n8E`3oQUD0
ohIE0?n<GP3oSV@0ohaV0?nCM@3o_Z/0omc?0?o[i03om?<A0?ooo`040>noaP0L51@000000=_:cAH0
oooo00H0ong_0?o@cP3oWiH0ohQk0?m]F`3oHTh30?mSD0030?mYE`3oJ5D0ofEA00D0ofEA00T0ofIB
0?mUD@3oIe@0ofIB0?mWD`3oK5T0ofQE0?mYE@3oIe80203oIU401`3oIE00ofYH0?m_F`1m9Ah00P42
0>i4@`3oDe401`3oDU00303oE580oe9@0?mAC`3oDDl0oe=A0?mED`3oEe@0oeID0?mDD`3oDe40oeUG
0?mCDP80oe=A0P3oDU040?mBD@030?mAD03oFUP0oe5@0080oe9A00<0oe=B0?mRH@3oDe400P3oEE80
203oE540oeaI0?mHE@3oEe@0oeAB0?mEDP3oEE40oeQE0P3oEE<00`3oE580oeEC0?mED`030?mED`04
0?mSHP3oEE<0oeQF0?mHEP80oeEC00H0oeUG0?mFE03oEeD0oeYH0?mIE`3oEeD30?mFD`060?mED`3o
FeP0oeaI0?m@C@3oOgl0oo;g4`3oool01`3ojnl0j<S:0:>IV@20Jg00JDQ;03XX:P071@D00`000000
1P0V6a/0JdY=081^L`2?RX/0dkVl0?o^lQP0oooo00L0ooWn07iGFP000000000000d92@2<LGD0ooCf
00h0oooo0`0000000`3o_lH0oooo0?ooo`1C0?ooo`050?oOh`000000000000000020P800;`3oool0
10071@D000000000003onOh40?ooo`050?olo`000000000000000026Q8@04`3oool01P2oZ:`00000
000000000000CCdo0?oXk0h0oooo00D0P82000000000000000000?oOh`1W0?ooo`050?oOh`000000
000000000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOo0?oooaL0oooo00H0_gUY07<n901i@bT0N44W08E<<`1f@BL607U3:@0407I19`1i@bX0MT4W
07Do9@D0ND<Y00H0MT4W07I09P1i@bT0Nd@[08A:<P1h@RP507U3:@0607a5:`1i@bT0ND<Y07Q2:01k
A2/0ND<Z101i@bT00`1h@RP0Re4h07Y4:P0407U3:@0308iB>P1lAB`0ND<Y0080ND<Y00<0N48X0899
<01kA2/01P1i@bT01P1e@2H0Nd@Z07U3:@1i@bT0N44W07Q2:0L0ND<Y00L0O4DZ02HC2P0000005@X6
07/g:@1e<bH0McHX00X0N3LY00<0McHX07Dd9P1j=bX00`1h=bT01@1h=RP0OcX]07Pg:@1j>2/0McHX
00D0N3LY00<0NSPZ07@c9@1b<bD00P1h=bT307Lf:@0607/g:@2XCCd0gU/m0?m^B`3oLd`0ogA=0P3o
LD`01@3oMU40og5<0?maC03oLT`0og=<00@0ogA=0P3oMDh00`3oN580ogM@0?mbB`090?mdC@030?me
C@3oN500ogQ@00D0ogQ@00H0ogUA0?mdB`3oJD00ofDl0?mX?`3oMDd30?mhD0090?mgC`3oMdh0ohIM
0?n;GP3oREP0oh]L0?n<F`3oReX0ohUI0100oh]J00<0ohYK0?n<G03oReX02@3oReX00`3oS5l0oh]J
0?n;FP060?n;FP030?n?H03oRUT0oh]J0140oh]J00<0oh]K0?n:F@3oReX04@3oReX00`3oSf00ohYI
0?n;FP0@0?n;FP030?n:F@3oSV00oh]J0100oh]J0P3oRUTA0?n;FP030?n:F@3oREP0oh]J0100oh]J
00<0oi1S0?n:F@3oReX03`3oReX00`3oR5P0oiEY0?n;G00@0?n;FP030?n=H@3oSf80ohYI02@0oh]J
00@0ohaK0?n<G03oSUl0ohYI403oReX02@3oS5d0ohYI0?mnCP3oMdH0ogi=0?n<F`3oU6L0ohYI0?n;
F`0:0?n;FP030?n9F@3oSEh0oh]J0180oh]J00<0ohaM0?n<G03oReX0303oReX0303oREP0ogY:0?mg
AP3oMdH0oga;0?n5E03oREP0oi9U0?nCI`3o/9<0on7K0?ono`h0oooo00<0KD]>0000000Y7Ah06`3o
ool01`3om_d0okfj0?m]F`3oHTl0of9>0?mUDP3oIU<02P3oIE420?mVDP030?mYE`3oHTd0ofIA00T0
ofIA00H0ofQE0?mZE`2B<2D000000;/^;03oDe450?mBD0060?mAC`3oEe@0oeaL0?mAC`3oDU00odm>
0`3oDe401@3oE580oe9@0?mGE@3oDU00oe1>00<0oe=A00<0oe1?0?mAD03oDU400`3oDU401`3oDU00
oe9A0?mBD@3oDU40oe=B0?mNG@3oDe400P3oEE80303oDe40oemL0?mFD`3oEU<0oeID0?mIE@3oE500
oemM0?mDDP3oEE<0oeQF0?mKF@@0oeEC00@0oeeL0?mED`3oEE<0oe=A0`3oEE<01@3oFEL0oe5@0?m@
CP3oGed0oe]H00@0oeIC00H0oeEA0?mMF`3oGE`0oe=A0?m^KP3oj?8?0?ooo`030?oFg`2RL7@06a8C
00H0000000@040/;07QCEP3ETiT0omcU803oool01@0o;2d00000000000000000RemS00P0oooo0P3o
hNX40?ooo`<0000000<0oko60?ooo`3oool0D`3oool01@3onOh0hYbR07iGFP000000P82002l0oooo
00@0?b`]000000000000hYbR103oool01@3ac]400000000000000000/Z:T01@0oooo00H0OUMJ0000
00000000000001TA4P3l[K@80?ooo`030?oQjP3ol?D0oooo0080oooo00D0P8200000000000000000
0?oOh`1W0?ooo`050?oOh`000000000000000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooaH0oooo00L0ojVS07Q2:01i@bT0ND<Y07U3:P2<
DCT0MT4W00D0ND<Y00D0N48W08M<=@1nARd0N48W07Q19`0507U3:@0507i6;01iA2T0ND<Y07U3:@1f
@2H01@1i@bT01P1i@RP0Md4W07U3:P1nAR`0O4@Z07a5:`D0ND<Y00<0N48X08iB>P1jA2X0101i@bT0
0`2<DCT0O4D/07U3:@0207U3:@0307Q19`1f@2H0ND<Y00@0ND<Y00P0O4D/07m7;P24BS80NT@Z07U3
:@1h@RP0PDP_07i6;@L0ND<Y00L0ODDZ01/>200000006P`807lj;024?c80McHX00X0N3LY00L0McDW
07@c9@23?S40Oc`^07Xg:P26@3<0McDW00T0N3LY00`0MC@V07di;01k>B`0MSHX07De:01k>B/0PCPZ
0;]C?P3oJDH0og9=0?maC03oLT`30?maC0070?mcCP3oLD`0og5<0?maC03oLTh0ogQC0?mdC0050?md
C@040?meCP3oLd/0ogQA0?mjE@P0ogA=00<0ogE>0?miD@3oN5001`3oN500303oMdl0ofi40?mV?03o
Ich0og180?mhD03oPeT0ohiQ0?n:F@3oReX0ohYK0?n>Ga@0oh]J0P3oRUT:0?n;FP030?n:F@3oSEd0
oh]J00H0oh]J0P3oRUTB0?n;FP030?n;F`3oSUl0oh]J0140oh]J00<0ohaK0?n:F@3oReX0403oReX0
0`3oRUT0ohiQ0?n;FP0A0?n;FP030?n6EP3oReX0oh]J00l0oh]J00<0ohYI0?n9F03oReX0403oReX0
0`3oT680ohYI0?n;FP0@0?n;FP030?n<G03oReX0oh]J00l0oh]J0P3oSf000`3oRUT0oh]J0?n;FP0>
0?n;FP030?n<GP3oRET0oh]J0100oh]J00H0ohYI0?n>G`3oRUT0ohaL0?n>G`3oRUX>0?n;FP080?n>
G`3oReX0ogi>0?mdA@3oMdH0oh]L0?n9F03oRU/<0?n;FP030?n;G03oReX0oh]J0200oh]J0100ohUH
0?mjB@3oN4L0ogY90?n3DP3oS5/0oh]J0?n<F`3oRUP0ohUH0?n:F@3oRU/0oi9U0?n/S`3ogmP0ooco
2P3oool0103oiNT0;R0Q0000002WLgPM0?ooo`070?omo`3obl/0ohQl0?m/F@3oHD`0of=>0?mTD00:
0?mUD@040?mTD03oHD`0ofQD0?mWD`T0ofIA00D0ofQB09<a9P000000]R`[0?mCD@060?mBD0050?mC
D@3oDe80oe9@0?mBD03oDDl01@3oDe40103oDU00oeUH0?mLG03oE5820?mCD@030?m@C`3oDE00oe9A
00@0oe9A00D0oe9@0?mBD@3oDU40oe9A0?mAC`040?mEDP0;0?mKF@3oEU<0oeEB0?mCD@3oEeD0oeUE
0?mMFP3oE580oeEC0?mHEP3oFUP0103oEE<01@3oDU00oeEC0?mDDP3oFUP0oeAB00<0oeEC00@0oeED
0?mBD03oDe40oeEB103oEU<01`3oE500oe]I0?mLFP3oEE<0oe=@0?mgN03oo?l02`3oool00`3X/kX0
Le1C01/B4`060000000401lE5P1hDeH0eI>I0?o^lR<0oooo00<0YIBI0000000000000P0000000`1U
ADP0hYbR0?oco0040?ooo`030<Z;T0000000oko600@0oooo0`0000000`3o_lH0oooo0?ooo`0k0?oo
o`050>C5b0000000000000000020P8005`3oool00`3ne]X0oooo0?ooo`0]0?ooo`0506E6B0000000
000001TA4P3ogn<00`3oool01@2<LGD00000000000000000i<G801@0oooo00<0oo?l04/d=P000000
0`0000000`1UADP0lLS?0?ooo`030?ooo`040?b]]02GJ6`000000?oOh`<0oooo00D0P82000000000
000000000?oOh`0m0?ooo`040<V;T00000000000000002H0oooo00D0omoS00000000000000000820
P0100?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo
5@3oool00`3oZJ00MT4W07M29`0207U3:@0307a5;02@E3/0MT4W00D0ND<Y00D0N48X08A;<@1kA2X0
MClU07Q2:00407U3:@0307U2:02>DcX0OTH]0080ND<Y00<0MT0V07U3:@1i@bT00`1i@bT01P1kABX0
O4D[0899<01kA2/0N44W08E<<`D0ND<Y00<0N48X07Do9@1i@bT0101i@bT00`24BS80Nd@Z07U3:@02
07U3:@0?07U2:01i@bT0ND<Y07U3:@1h@RP0ND<Y07]4:`1oAbh0MClU08mD>`1lA2/0ND<Y07Q2:022
BC00OdL]00L0ND<Y00L0ODDZ01@;1P0000009Pl;07hj;023?S40McDW00T0N3LY00H0N3HX07@d9P1k
>R/0OCX]080l;`1g=RP;07Pg:@0707@b9@1k>Rd0MCHZ080j:`2H@bl0dEm70?aWAP020?mbC0H0og5<
00L0ogA?0?mbC@3oLD`0og5<0?mbC@3oME00og9;00T0ogA=00@0ogM@0?mdCP3oM4d0ogI@103oM4d0
0`3oMDh0ogaH0?mgC`060?mhD080ogI>00H0ogYB0?mbB03oK400ofe20?mkCP3oRET40?n;FP030?n:
F`3oSf00ohYK01<0oh]J00<0oheN0?n;FP3oReX02@3oReX00`3oSEd0oh]J0?n9F@050?n;FP030?n;
G03oSf40ohYI0140oh]J00<0oh]K0?n<F`3oReX04P3oReX00`3oS5/0oh]J0?n;FP0@0?n;FP030?n9
F03oReX0oh]J0280oh]J00<0ohiO0?n>H@3oRUT0403oReX00`3oS5/0oh]J0?n;FP0@0?n;FP030?n9
F03oReX0oh]J00l0oh]J00<0ohQG0?n9F03oReX0403oReX00`3oSEd0ohYI0?n;FP0@0?n;FP040?n<
F`3oReX0oh]J0?n:F@80ohaL3P3oReX01@3oS5/0ohEE0?mgAP3oLD<0oh1@00h0oh]J00<0ohYK0?n<
F`3oReX04@3oReX00`3oRET0oh]J0?n:F@0;0?n;FP0:0?n<F`3oQ5<0ogU80?meAP3oNTX0ohMF0?n<
F`3oReX0ohUI0?n:F0@0oh]J00L0ohYI0?n9F03oR5H0oieg0?nlX`3og=@0ooKh00L0oooo00@0h<;5
000000000000onWc803oool01@3ocll0oh5c0?m`G@3oHD/0of9=00P0ofEA00P0ofA@0?m`GP3oJ5D0
ofEA0?mZE`3oIe@0ofMC0?mVDPD0ofIA00H0ofA@0?m/F@2K?c80000006<G5P3oDe860?mBD0060?mA
C`3oD4h0oe9@0?mAC`3oGEd0oeAC1P3oDe40103oF5D0oeUF0?mDDP3oDU020?mDDP@0oe9A00<0oeME
0?mLFP3oDE000P3oDU401P3oDDl0oeEB0?mEDP3oEE80oe=A0?mOG@@0oeEB00H0oeEC0?mLFP3oEE<0
oeEC0?mDDP3oEE840?mED`050?mBD03oE580oeAB0?mMG03oE5800`3oEE<0103oEU@0oeEC0?mAC`3o
E5850?mFD`060?mCD@3oE580oeEC0?mED`3oDe40okg11`3oool0103ojnl0dI2E07=@D`0K4Q<60000
000301lE5P1hDeH0j[Ro02L0oooo00<0ooWn06E5B00000001@0000000`1H?Cl0IDE804/d=P030000
00030?noaP3oool0oooo0080oooo0`0000000`3o_lH0oooo0?ooo`0k0?ooo`050>C5b00000000000
00000020P800A`3oool01@2ITI800000000000000000?b`]0080bH^@00H0UfQ/0000000000000000
038S903onOhE0?ooo`030?oco01UADP0000000@0000000@0Bc@f06E5B01UADP09QXK0`0000001@3o
gn<0oooo0?ooo`3oool0P82000<0000000<0omoS0?ooo`3oool0>`3oool01039Ri00000000000000
000V0?ooo`050?oOh`000000000000000020P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`00
1`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooa<0oooo00@0onWW0;UbH@1d?bD0N48X0`1i@bT00`1i
@RT0RTlg07I19`0507U3:@0407U3:P1i@bT0Md4W07M2:0H0ND<Y00D0OTD/07Y4:P1i@bT0N48X07M1
9`0507U3:@0307m6;P1nAR`0O4D[0080ND<Y00<0QD`b07U3:@1i@bT00P1i@bT00`1i@RP0PTT_07]4
:P0507U3:@0708E;<`1kA2/0ND<Y07U3:@1g@RP0QT`c08=9<@0207U3:@0707e5;01mAR`0Nd@Z07U3
:@1h@BL0Se<k07a4:`0207U3:@0307U2:01i@bT0ND<Y00H0ND<Y00H0ODDZ01@;1P0000009Pl;07Tg
:@1f=RP907Pg:@0607/i:`1k>B`0MSDW07`i;01j>2/0McHX2@1h=bT02P1g=RT0Lc@W07di:`2??B/0
/ddh0<eJ?P3_JTP0og=<0?mbC03oLTd70?maC0030?mbC@3oLdh0og5<00<0og5<00<0og=?0?mfD03o
M4d02@3oM4d02`3oLd`0ogE>0?mhDP3oMDl0ogA>0?mdC03oMe00ogA=0?mfCP3oNU<0ogQ@0080ogM?
00h0ogYB0?mmE@3oOE<0ohQM0?n5E`3oR5T0ohaM0?n5E03oOD`0ogQ70?mlB`3oQEH0oh]J0?n<F`80
oh]J00<0ohYJ0?n>GP3oS5/07`3oReX00`3oRed0ohaM0?n;FP050?n;FP030?n<G03oS5d0oh]J0140
oh]J00<0ohYK0?n<G03oReX0403oReX00`3oRe/0oheM0?n;FP0A0?n;FP030?n=G@3oReX0oh]J00l0
oh]J00<0ohQH0?nCI`3oS5d0403oReX00`3oSf80oi=V0?n8F00@0?n;FP030?n:F@3oReX0oh]J00l0
oh]J0P3oRUX@0?n;FP030?n=G@3oT680ohUI0140oh]J00<0ohaL0?n;FP3oReX03`3oReX00`3oRUX0
ohaL0?n;F`030?n;FP030?n<G@3oSEd0oh]J00H0oh]J00X0ohYJ0?n;FP3oReX0ohaL0?n<GP3oSf00
ohEE0?miBP3oO4/0ohIE3`3oReX00`3oRe`0ohaL0?n;FP0A0?n;FP030?n<G@3oSEh0ohYJ00X0oh]J
00H0ohUH0?mnCP3oMdH0og]:0?n1D03oREP30?n;FP030?n<G03oRe/0oh]J00H0oh]J00l0ohYI0?n8
E`3oQeD0oi=W0?nTP03o]IP0olNc0?oPeP3ol^l0oo_m0?ooo`2URhl000000:5_L`3on?d08P3oool0
1`3ojNT0olo;0?nQV@3oMFD0ofMC0?mOBP3oI5001@3oIE401P3oIU80ofE@0?mVD@3oIU40ofMB0?mX
E0<0ofMC103oIU401@3oJEH0XD4e0000001L5QH0oeAB00L0oe9@00D0oeIE0?mFE03oDTl0oemO0?mE
E0060?mCD@060?mBD03oEE<0oeEC0?mDDP3oFeX0oeYI103oDU400`3oDe80oe=A0?mAD0030?mBD@06
0?mCD03oEE80oeEB0?mDDP3oEU80oemL0`3oEE801P3oE580oeIC0?mIEP3oEeD0oeEC0?mGE@D0oeEC
00@0oe9@0?mED`3oEU@0oeAB103oEE<0103oF5L0oeYI0?mJE`3oEE830?mFD`030?mFDP3oFEP0oeUG
00<0oeEC00T0of]Z0>V//P2oYZ/0_jZ]0::GV020Jg00JDQ;03XX:P071@D00`0000001P0V6a/0JdY=
081^L`2?RX/0dkVl0?o^lR`0oooo00<0i<G8081aM@0V6Q/02@0000000`3ob<l0oooo0?ooo`020?oo
o`<0000000<0oko60?ooo`3oool0>`3oool01@3TaLP00000000000000000P82004L0oooo00<0ooCf
08aaM@0I4Q801P0000000`0I4Q80P6Q/0?oXk00H0?ooo`030;:KW`1<=3H0000000T0000000D0onCW
0?ooo`3oool0oooo0820P003000000030?oOh`3oool0oooo03/0oooo00@0bH^@0000000000000000
9P3oool01@3ogn<00000000000000000P8200400oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooolC0?ooo`030;]lK01f@2H0ND<Y00@0ND<Y00<0LchT08=:
<P1f@BL00`1i@bT01P1f@BL0ND<Y07]4:P1kA2X0MT0V07Q2:0D0ND<Y00D0ND<X07U2:01i@bT0ND<Y
07M19`0407U3:@0407i6;01kA2T0Nd@Z07M1:0<0ND<Y00<0Q4/b07U3:@1i@bT00P1i@bT00`1h@BL0
S58i07i6;00407U3:@0307Q2:028CCD0Nd@[0080ND<Y00H0ND8X07@n8`1c?R@0O4D/07]4:@1i@RP3
07U3:@0707Q19`2?Dc/0O4@[07Q2:01oAbh0RTlf07Q2:00707U3:@0607i6:`0D2`H0000002H@2P26
@C@0MCDW1P1h=bT02@1f=BL0PCd`07Xh:`1k>B`0NCLY07@c9@21?300RT8g07Pf:00707Pg:@0807Hf
:01_<bH0NcX]0:Y<=`3YHT@0og5<0?mgD`3oM4l;0?maC0030?mdD03oLdh0og5<00<0og5<00<0og1:
0?mcC@3oMDl03@3oM4d03@3oLd`0ogA>0?miE03oMDl0ogQB0?mfC`3oMDd0oh=K0?n4E@3oRUd0ohiQ
0?n;FP3oRUT0103oReX01`3oS5/0ohMF0?miB@3oMdH0oge=0?n6E@3oS5/00P3oReX00`3oR5X0oheM
0?n:F@0B0?n;FP030?n<F`3oSf00ohYK0180oh]J00<0oh]L0?n8FP3oReX0403oReX00`3oRUT0oh]L
0?n<GP0A0?n;FP030?n;G03oSf00ohYI0100oh]J00<0ohaL0?n;FP3oReX0403oReX00`3oRe`0oh]K
0?n;FP0?0?n;FP030?n>H@3oTFD0ohYI0100oh]J00<0ohYI0?n;FP3oReX03P3oReX00`3oRUT0oi5U
0?n<G`0@0?n;FP030?n;F`3oS5`0oh]J0100oh]J00<0ohYI0?n<F`3oReX03`3oReX00`3oRUT0ohiQ
0?n;G0050?n;FP030?n<G03oSUl0oh]J00@0oh]J00X0ohYI0?n>G`3oSf00ohYI0?n=GP3oSE`0ohAC
0?mgAP3oNDX0ohYI3P3oReX00`3oRe/0ohaN0?n<G00B0?n;FP80ohUH00<0ohYI0?n;FP3oReX01P3o
ReX0203oS5/0ohYI0?n0D03oNDP0ogM60?n1D@3oReX0ohaK0`3oReX00`3oSUl0ohYJ0?n;FP0<0?n;
FP090?n8F03oQE@0oh5=0?nCJ03oZXL0okVT03PS8`000000omoN02H0oooo00H0oogo0?oCe03oZjD0
ofQD0?mOB@3oI5040?mUD@030?m_G03oKEX0ofIA0080ofIA00D0ofEA0?mUD03oJUL0ofE@0?mXE@02
0?mVD@050?mTD02kBC/0000002X:303oE5802@3oDU000`3oDDl0of5Q0?mEE0060?mCD@060?mDDP3o
I6<0oe=A0?m?CP3oFEP0oe]H1@3oDU401P3oEE@0oeEC0?mAD03oDU40oe=B0?mIE@<0oeEB00<0oe=@
0?mED`3oEE800`3oEE801P3oE540oeAB0?mIE`3oEU@0oeeL0?mDD@<0oeEC00<0oeED0?mNG@3oE580
0P3oEU@02@3oE580oeEC0?mED`3oE580oeaK0?mPGP3oEE<0oeME0?mFE0020?mFD`080?mDDP3oGU`0
ofIV0?mHEP3oEE<0od=008/O7P060@4600000004010;2`1hDeH0eI>I0?oLiC@0oooo00@0ooWn0>:L
XP2GJ6`0IDE80P000000100I4A80IDE80;f2Q`3ohNX50?ooo`<0000000<0oko60?ooo`3oool0>`3o
ool01@3TaLP00000000000000000P82004X0oooo00H0hYbR04`d=P000000000001TA4P2`NWhM0?oo
o`030?oco03RW:80OUMJ00<0000000@0?b/]09MXK03RW:80on7Z103oool01@20P800000000000000
0000omoS03d0oooo00@0bH^@00000000000000009P3oool01@3ogn<00000000000000000P8200400
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooolB0?oo
o`030?^UWP25C3<0ND<Y00@0ND<Y00<0Nd@Z0899;`1i@bP00`1i@bT01`1kA2X0O4D[07U3:@1oAbh0
P4T_07<n901f@BL01@1i@bT01@1oAbh0OTH]07Q2:01i@bT0Md4W00<0ND<Y00@0ODD[07]4:P1i@bT0
N4<X101i@bT00`25C3<0ND<Y07U3:@0407U3:@0307]3:@1i@bT0ND<Y0080ND<Y00<0MT4W08aB>P1n
AR`00P1i@bT00`1h@BL0PDP_07a5:`0607U3:@0607Q19`2<DST0O4D[07U3:@1oAbh0Qd`d2@1i@bT0
1@0A20D0000002TA2`20?2h0McHX00H0N3LY00P0OcX]07dj;01j>2/0McHX07Pf:@1e<bH0N3LZ07Xf
:@L0N3LY00T0MCHX07lj;032DCL0kF=40?m]B`3oLT`0og5<0?m^BP3oKDP02`3oLD`00`3oLTd0og5<
0?maC0030?maC0030?maB`3oMU80ogMB00l0ogA=00T0og9;0?mdCP3oPe/0ohEF0?n6EP3oSEl0ohaK
0?n;FP3oRUT01`3oReX01P3oS5/0ohEE0?mhA`3oMTD0ogY90?n7EP80oh]J00<0ohYI0?n<GP3oRU/0
4P3oReX00`3oRUT0ohYK0?n9F00=0?n;FP030?n:F@3oReX0oh]J0080oh]J00<0ohYI0?n@H@3oS5`0
4@3oReX00`3oS5`0ohYI0?n;FP0@0?n;FP030?n8FP3oReX0ohYI0100oh]J00<0ohYI0?n6EP3oReX0
403oReX00`3oREP0ohYI0?n;FP0?0?n;FP030?n?HP3oTfH0ohQH0100oh]J00<0ohYI0?n;FP3oReX0
3P3oReX00`3oR5P0oiAX0?n?H00@0?n;FP030?n:F03oREP0oh]J0100oh]J00<0ohiO0?n;FP3oReX0
3`3oReX00`3oS5/0ohaL0?n;FP050?n;FP040?n:F@3oRU/0ohiO0?n;FP80ohYI00X0oh]J0?n=G@3o
Re`0oheN0?n:F@3oS5`0oh=D0?mgAP3oMTD0ohAD3`3oReX00`3oRUT0oh]J0?n;FP0B0?n;FP030?n<
G03oRUT0oh]J00P0oh]J00L0ohYI0?mlC03oMdH0ogM60?n2D@3oS5/0ohYK0080oh]J00@0ohUK0?n>
H@3oRe/0ohYJ403oReX01`3oREL0oh5@09H`5P000000MB0G0?nVW`3ohN@0:03oool0103oe]P0ohYm
0?mOB@3oH4X30?mUD@030?mZF03oKEX0ofIA00@0ofIA00X0ofA@0?mVD@3oIe@0ofUF0?mXE@3oI4h0
_4m20000000a2``0oeAB1`3oDU001@3oDDl0oe9A0?mAC`3oGUd0oeID00L0oe=A00P0oeAB0?mCD@3o
DDl0oeiN0?mMF`3oEE<0oe9@0?mAD080oe9A00L0oeaL0?mHE`3oDE00oe9A0?mGE@3oHf00oe=@00<0
oeEB00<0oe1>0?mDD@3oEE800P3oEE801P3oDe40oeEC0?mDDP3oEE@0oeUG0?mDDP<0oeEC00H0oeME
0?mUH`3oE580oeUH0?mLF`3oE5820?mED`060?mDDP3oG5/0of1O0?mDD@3oEU<0oeID0P3oEU<01@3o
EU80of1N0?mCD`2A92805PD500H0000000@07aDF07QCEP3ETiT0onkbAP3oool3000000030?noaP3o
ool0oooo0;/0oooo00D0P82000000000000000000?oOh`1W0?ooo`050?oOh`000000000000000020
P800@03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
oa40oooo00<0olW808mE>`1f@BL01@1i@bT00`1kA2X0SU<j07I19P0307U3:@80Nd@Z00H0N48X0899
<022BC00R4de0857;`1h@RP407U3:@05089:<@21B2l0N48X07U3:@1g@BL00P1i@bT01@1f@BL0OdL^
07U2:01lAB/0RE0g00@0ND<Y00<0QD`c07U3:@1i@bT00P1i@bT207I09PD0ND<Y00L0MT4W08mD?01n
AR`0ND<Y07Y4:P28CCD0PDP_00L0ND<Y00H0N44W08mC>`1lA2/0ND<Y07Q2:01h@BL807U3:@05070n
900;1@<00000048N5@1h=RP0101h=bT01@1g=RP0OCX/07dj;01j>2/0McHX00<0N3LY00<0M38U07Dd
9P1g=RP01@1h=bT0301d=BL0McHY0:E;>@3`I4D0ofi:0?m`B`3oKTX0og1=0?m]B@3oJdP0ogMD0?mb
C@P0og5<00<0ogE?0?mfDP3oLD/01`3oLD`00`3oLD/0ogA=0?mdC@0;0?mdC@080?mcC03oMDd0ohAK
0?n8F`3oRU/0ohaK0?n>GP3oRU/;0?n;FP060?n;F`3oQUD0og]:0?mgAP3oNdX0ohQG0P3oReX00`3o
RUX0ohiO0?n:F`0B0?n;FP030?n:F@3oRe`0oh]J00/0oh]J00<0ohYJ0?n<F`3oReX01@3oReX00`3o
RUT0oh]J0?n;FP0?0?n;FP030?n:F@3oSf00ohaL0140oh]J00<0oh]L0?n>G`3oReX03`3oReX00`3o
Re/0oi5T0?n:F@0A0?n;FP030?n:F@3oReX0oh]J00h0oh]J00<0ohmR0?nCIP3oR5P0403oReX00`3o
RUT0oh]J0?n;FP0>0?n;FP030?n:F@3oT680oheN0100oh]J00<0ohiO0?n:F@3oReX0403oReX00`3o
Sf80oh]J0?n;FP0?0?n;FP030?n>H@3oRe`0oh]J00H0oh]J00L0ohUI0?n:F`3oS5`0oi5S0?n?H@3o
R5L0oh]K00<0oh]J00D0ohMF0?mhB@3oLdD0ogi>0?n:F@0?0?n;FP030?n=GP3oREP0oh]J0140oh]J
00<0oheN0?n8FP3oReX02@3oReX0103oOTd0ogM60?mhA`3oPE450?n;FP030?n<F`3oReX0oh]J0100
oh]J00X0ohaK0?n9F@2kBBl020<103hB3P3oHdh0og1K0?mjJ03oXIH0onGY9`3oool0203om_d0on7T
0?nSV`3oJ5<0ofA@0?mUD@3oI4l0ofYF203oIU401`3oIU<0of=?0?mZE`3@Ccl00P0002892P3oE580
1`3oDU00103oDDl0oeQG0?mAC`3oDDl80?mCD@0<0?mAC`3oDE00oe=A0?mGE@3oE5<0oe=B0?mAC`3o
FEL0oe=A0?mBD@3oEeD0oeEC0P3oDU400`3oEU@0of5N0?mCD@030?mEDP030?mCC`3oFEH0oeEB0080
oeEB00<0oeAA0?mED`3oEE<00P3oEE<02P3oE5<0oeAB0?mED`3oEE<0oeME0?mRH@3oE580oeUG0?mK
F@3oE5820?mED`0:0?mDDP3oG5/0of1O0?mEDP3oDe40oeAB0?mGE@3O?3X0JATI01H51@L0000000<0
50H00>6^/P3oool0o`3ooonl0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWiol0oooo3`3oool01@3onod0f:JN08I<=025Bc80ND<Z00D0ND<Y00H0NT@Z07m6;@1g
@BL0ND<Y07a5;01lABX307U3:@0507M19`1h@RP0SE8j08A9<P1h@RP0101i@bT0201h@BP0ND8X07U3
:@1i@bT0PTXa07Y3:@1mAB/0N48W0P1i@bT00`1kA2X0PTTa07U3:@0307U3:@0807e7;@1i@bT0ND<Y
07U3:@1h@bT0R4de07m7;P1i@RP407U3:@0707Q2:01i@bT0Md8W07a5:`1jA2T0NT<Z07]4:`0707U3
:@0607Q19`2?Dc/0O4@[07]4:P21BC00ND8X201i@bT0301`?B@02`D30000001:8QT0Oc/^07Th:P1h
=RP0OCX]07Tg:P1j>2X0N3LY07Th:P@0N3LY00d0NSPZ08m7?025?c80McHX07Hf:@1i=bX0OSPY08/n
;`2hD3T0iFA60?]XA@3oKTX0ofm;0080ofi:00<0ofm;0?m`C@3oKTX00P3oKTX00`3oLTh0og5<0?ma
C0050?maC0030?mbC@3oLdh0og5<00P0og5<00<0ogA?0?mdCP3oM4d01P3oM4d02@3oMTl0ogI>0?mm
E03oPET0ohAG0?n=G`3oReX0oh]K0?n<F`040?n;FP030?n;F`3oReX0oh]J00/0oh]J00D0ohAD0?mk
B`3oNDP0ogm>0?n6E@020?n;FP030?n=G@3oReX0oh]J0140oh]J00<0oh]K0?n;G03oReX02`3oReX0
103oRUT0oh]K0?n<G03oRe/30?n;FP030?n=G@3oReX0oh]J0140oh]J00<0ohaM0?n;FP3oReX03`3o
ReX00`3oRe/0oh]L0?n;FP0?0?n;FP030?n;F`3oSUl0ohYI0100oh]J00<0ohYI0?n@HP3oReX03`3o
ReX00`3oSV00oi5S0?n9F@0@0?n;FP030?n:F@3oReX0oh]J00l0oh]J00<0ohUH0?n:F@3oReX03P3o
ReX00`3oRUX0ohmP0?n;FP0@0?n;FP030?n<G@3oRUX0oh]J00l0oh]J0P3oS5`70?n;FP060?n>H03o
S5`0ohYI0?n=G@3oRed0oh]K103oReX01P3oQeL0ogU:0?miB@3oPU40oh]J0?n;F`h0oh]J00<0oh]K
0?n<G03oReX06`3oReX01P3oR5L0oh9A0?mjB@3oNTT0oh9A0?n8E`H0oh]J00<0ohYI0?n;FP3oReX0
3`3oReX04@3oRe/0kWU?05lV60040P40@1@@0=mJB03oKUX0ofaH0?m[EP3oK5L0og5K0?meHP3oRg`0
ok>Z0?oGe03oko00oo_o02@0oooo00L0oo3a0?o1^P3oXi/0oh9c0?m^F`3oI4h0ofE@00P0ofIA00H0
ofIB0=M??P040@007PL70?mBD03oDe470?mBD0040?mDDP3oDU00oe1>0?mBD0L0oe=A00D0oeAC0?mG
EP3oDe40oe5?0?mAD0020?mBD@0:0?mCDP3oE580oeED0?mBD03oEU@0oeAB0?mBD@3oEeD0of9P0?mC
D0<0oeEB00<0ofER0?mHEP3oEE800P3oEE803P3oFEH0oeME0?mED`3oEE<0oeQF0?mMG@3oDU00oeED
0?mFE03oEeD0of1O0?mDDP3oEE<0oe=A0`3oEE<01`3oCT`0gd910;@g=P26;2X0GaTH03D=3@0<0`<0
0`0000002@0>0`<0Ba@C080T902>;Rd0cd0o0<8b;`00000070X20?nfS`3o0?oookd0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool?0?ooo`040=ff/@1/
>Ad0ND<Y08Q==@H0ND<Y00H0LchT07Q19`1h@RP0OdL^07a5:`1h@RP307U3:@0507]4:P1h@RP0Re0h
0899<01h@RP00`1i@bT00`1h@RT0ND<Z07U3:@0207U3:@030899<01i@bP0ND<Y00<0ND<Y00<0MT0V
07Q2:01i@bT00`1i@bT00`1g@BL0ND<Y07U3:@0207U3:@0307U3:01i@bT0ND<Y00<0ND<Y00L0N48X
0899<021B2h0N44W07U3:@1j@bT0Nd<Z00P0ND<Y00H0N44W095D?01kA2/0O4D/08U==P1f@BL807U3
:@08070n900;1@<0000004DP5`1l>R`0NcL[07hk;P1g=BL807Pg:@0707Xh:`2:@cT0K2hP074e:027
?2`0`UM10?ISA0020?m_BPH0ofi:00<0ofm;0?m]B@3oKTX00P3oKTX80?maC0030?mbC03oLD/0og5<
00P0og5<00/0og5;0?mgD@3oM4d0ogA=0?mcC@3oLT/0ogI?0?mjDP3oNE00oh]O0?n7E`0:0?n;FP03
0?n:F@3oS5`0oh]J00d0oh]J00T0ohUH0?mlC03oN4L0og=50?n1D@3oR5X0ohaK0?n>G`3oRe/04P3o
ReX00`3oS5/0oh]K0?n;FP0=0?n;FP060?n;G@3oRET0oh]J0?n;FP3oS5`0ohYK4`3oReX00`3oRe/0
oh]J0?n;FP0>0?n;FP030?n:F@3oS5l0oh]L0100oh]J00<0ohYK0?n?H03oReX03`3oReX00`3oRUT0
ohmQ0?n;FP0?0?n;FP030?n:F@3oREP0oh]J0100oh]J00<0ohYI0?n;FP3oReX03P3oReX00`3oRUT0
oh]J0?n;FP0@0?n;FP030?n:F@3oReX0oh]J00h0oh]J00<0ohQH0?n?H03oRU/0403oReX02P3oRUX0
ohUH0?n;FP3oReX0ohYJ0?n;G03oRET0ohYK0?n<G`3oRUT30?n;FP0:0?n<G03oSUl0ohYI0?n;FP3o
S5/0ohIE0?mhB03oMdP0ohUH0?n<F`l0oh]J00<0oh]K0?n?H03oReX04@3oReX00`3oRe/0ohiO0?n;
FP060?n;FP060?n<F`3oQE@0ogM60?mgAP3oNDP0ohQG1@3oReX00`3oRUT0oh]K0?n=G@0@0?n;FP08
0?n9FP3oS5`0oh]J05XS5`000000MBDM0?mZEP3oKUT70?m/F0070?m]F03oJE<0ofM@0?moKP3o`;`0
onc`0?ono`0U0?ooo`050?o5a@3oNV`0ofUF0?mMB03oIDl01`3oIU401`3dEdL03@<300T20P3><S80
oeID0?mCDP3oDDl01@3oDU020?mCD@030?mBD03oCdh0oe=A00X0oe=A00<0oe1?0?mBD@3oDU400P3o
DU40203oDU00oeAB0?mMG@3oEE<0oe9@0?mDDP3oF5H0oe=A0`3oEE800`3oHf00oeAB0?mEDP020?mE
DP060?mKF@3oF5H0oeEC0?mED`3oEU@0oeQF0P3oE5800`3oF5H0oeAB0?mAC`020?mED`040?mGEP3o
AdH0_2l^044A40L0000000d0@@h>0;/]:`3oADD0oe=@0?mNG03oE580oeEC0?mHEP3M>3D00`010000
003oS4X0om>f0?l0oooo_03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooo`h0oooo00D0ooKl0:QWD`1f@BP0N44W08U?=`0607U3:@0507i6;@1h@RP0NT<Z
07a5:`1h@RP00P1i@bT01`1i@RP0OdL^095E?01g@BL0Re0g0898<01h@RP00`1i@bT01`1f@BL0RTlg
07Q2:01h@RP0OTH/08I<<`1h@RP0101i@bT00`22BC00ND<Y07U3:@0307U3:@0707M19`1i@bT0ND<Y
07U3:@1h@RP0MClU07Q2:00407U3:@0807a4:P25C3<0ND8X07Q2:01i@bT0OdH^08mC>`1f@2H707U3
:@0507Q19`2<DCP0O4@[07Do9@1c?R@02@1i@bT01P1T>2401@810000000h5a00NcT[07Lf:0X0N3LY
00L0MSHY07hl<029?Rl0YdPb0>]VA`3oLT/0ofm;00L0ofi:00<0ofe90?mbD03oKTX00`3oKTX00`3o
L4`0og5<0?maC0050?maC0030?mcCP3oLD`0og5<00P0og5<00X0og1;0?mfDP3oLD/0og5;0?mfCP3o
OE@0ohII0?n>HP3oS5/0ohYI303oReX00`3oRe`0oh]J0?n:F@0<0?n;FP030?n:FP3oRUT0oh1@0080
ogQ700@0oh5A0?n8E`3oRUX0ohaM4P3oReX00`3oRe/0ohmP0?n:F`0=0?n;FP030?n=G@3oRU/0ohYI
0080oh]J00<0ohiO0?n:F@3oReX0403oReX00`3oSEd0oh]J0?n;FP0A0?n;FP030?n:F@3oReX0oh]J
00h0oh]J00<0oheN0?nBIP3oRUT0403oReX00`3oRUP0oh]J0?n;FP0>0?n;FP030?n:F@3oREP0oh]J
0100oh]J00<0ohYI0?n;FP3oReX03@3oReX00`3oRUT0ohmR0?n=H00@0?n;FP030?n;G03oSUl0oh]J
00l0oh]J00<0ohYK0?n9F03oReX03`3oReX02@3oRET0oheO0?n:F@3oRUT0oheN0?n;G03oSf00oh]L
0?n:F@050?n;FP090?n:F@3oReT0ohYK0?n<F`3oQUD0ogU80?mgAP3oPU40ohaK00l0oh]J00<0ohYI
0?n<G03oRUT04@3oReX00`3oRe/0ohiO0?n;FP060?n;FP070?n<F`3oQE@0ogU90?mhA`3oODd0ohMF
0?n<F`040?n;FP030?n9F@3oS5`0ohiO0100oh]J00P0ohYJ0?n@G@3oS5/0/DD]0000001F6aD0of=>
0?m`F`/0ofaH00H0of]D0?mUC@3oNVP0ojVP0?o?c`3ol_@S0?ooo`060?o]nP3oh>l0ok2^0?n:O@3o
IU80of5;1P3oIU40103oFdT04@H400`20`3L=C@20?mED`030?mCDP3oDU40oe9@00<0oe9@00@0oeMF
0?mIE`3oDDl0oda<203oDe40103oDe80oe=A0?mCD@3oD4h70?mBD@040?m@CP3oE5<0oe5?0?m@CP@0
oeEB00<0ofIT0?mLF@3oDe400P3oEE800`3oG5T0oeQF0?mED`020?mED`090?mAC`3oE540oeEC0?mG
E@3oDU00oeAA0?m5A02C92@060L700H0000000T03P<306LF5@2h:RP0od900?mFD`3oEE<0oeME0?mC
D@3oEeH00P3oEE<01`3oF5H0mC/j00X10`000000ohe=0?nLE@3oh=00o`3ooonk0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo3P3oool01P3dX9H0M3lT
07U3:@1e@2D0SU8i07Y4:PD0ND<Y00@0TULn07Q19`1kA2/0N48X101i@bT01P1lAB`0R4de07M19`2<
DCT0Q4Tb07Q2:0<0ND<Y00L0ND8X0819;P1f@2H0O4D[07m7;@25C3<0N48X00@0ND<Y00<0TULn07U3
:@1i@bT00`1i@bT01P1g@BL0ND<Y07U3:@1i@bT0O4D[07i6;@<0ND<Y00T0ND<Z07m7;@1nAR`0PTXa
07a5:`1h@RP0ND<Y07Y4:P1nARd0201i@bT01@1h@RT0Nd@Z07U3:@1i@bX0ND8X00T0ND<Y00@0ES0L
000000050P40IC0V2P1h=bT01`1g=bT0LS@W08Dl;@31DCT0lFI90?m_B@3oLD/02@3oKTX00`3oLTl0
ofa70?m^BP030?m^BP030?m_B`3oL4T0og5<00@0og5<00<0og1:0?mcCP3oLD`02@3oLD`0203oLD/0
og5:0?n0F@3oOU@0ohAF0?n?H@3oS5X0ohYI3`3oReX00`3oS5/0ohYI0?n:F@0=0?n;FP080?n<F`3o
QE@0ogU80?mfA@3oNdX0ohMF0?n;FP3oRUTB0?n;FP030?n:F@3oRe`0ohYI00d0oh]J00H0ohaO0?n;
F`3oRUT0oh]J0?n<F`3oSf0A0?n;FP030?n:F@3oRe/0oh]J0100oh]J00<0ohYI0?n=GP3oRUT0403o
ReX00`3oRU/0ohYI0?n;FP0?0?n;FP030?n9F03oReX0oh]J00h0oh]J00<0ohYI0?n9F03oReX0403o
ReX00`3oRUT0oh]J0?n;FP0=0?n;FP040?n:F@3oTfH0ohmR0?n:F@l0oh]J00<0oh]L0?n>H03oReX0
3`3oReX00`3oTVH0oh]N0?n;FP0?0?n;FP070?n8FP3oS5`0oheQ0?n<F`3oS5h0oheM0?n:F@080?n;
FP80ohYI00D0oh]J0?miB03oMTD0ogI70?n9F00@0?n;FP030?n=GP3oS5/0oh]J0140oh]J00<0oh]I
0?n9F03oReX0103oReX0203oS5/0ohYI0?n1D@3oN4L0ogM60?n1D@3oReX0ohaK1@3oReX00`3oRe`0
ohiO0?n;FP0@0?n;FP070?n=G03oS5/0[T@/0080000]3P/0of1<0?mbF`0>0?m/F0060?mYD`3oHd/0
of=;0?nAPP3oal@0onKZ803oool02P3onol0on;a0?oSl@3ol?`0onKd0?n/Z03oMfH0oea60?mPBP3o
IE430?mVD@0:0?mPC00E1PD01P810:`Y:03oE580oe1>0?mGE@3oDE00oeAB0?mAC`80oe9@00@0oe=A
0?mDDP3oDDl0oeYG1`3oDe401@3oDU00oeYH0?mBD03oDe40oeAB00H0oe9A00H0oe9@0?m=C03oEU@0
oe=B0?mAC`3oDe430?mEDP030?mLF03oG5X0oe=A0080oeEB00<0oeeJ0?mHEP3oEE<00P3oEE<01P3o
FUL0oeQF0?mED`3N>cX0IaTI01P61PH0000000P06@D506@E502e:BL0odM50?mJE`3oF5H0oeMD0?mF
D`<0oeAB00/0oe=@0?mED`3oEE<0oeQF0?lo?P0O1`H000000>n2A@3oVe80ojMY0?oZh@3o0?oookX0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool<0?oo
o`030?oRhP37R7/0Nd@[0080N48X00<0S54h09=G?`1i@bT01@1i@bT00`21B2l0PTT`08=9<00507U3
:@0507M19`1i@RP0N4<Y08Y?=`22B300101i@bT01`1g@RP0NT@Y07a4:P1lAB/0ND<Y08M==01h@BL0
0`1i@bT00`1h@RP0NT<Z07U3:@0407U3:@0>07M2:01i@bT0ND<Y07U3:@1nAbd0P4P_07Q2:01i@bT0
O4@[07a5:`1kA2X0ND8X07m7;P1mAR`207U3:@0307Q2:01g@BL0ND<Z00P0ND<Y00@0MT0V07Y3:P2:
CcL0ND8X1P1i@bT01`1jA2X0O4D[07]4:`1T=b40108000H20P25?c802@1h=bT01P2>?bh0ZTTd0=5I
?P3aIdH0ofm:0?maC@X0ofi:0P3oL4`60?m^BP030?mdD03oL4/0og5<0080og5<0P3oM4h80?maC007
0?mcC@3oNeD0ogU?0?n4F@3oREX0ohaM0?n=G00D0?n;FP030?n;F`3oSEh0oh]J00d0oh]J00P0ohaK
0?n7EP3oO4`0ogQ70?miB03oPE40oh]K0?n<G180oh]J00<0ohaK0?n=GP3oRe/0303oReX00`3oREX0
ohaM0?n<G0020?n;FP030?n<F`3oS5d0oh]J0100oh]J00<0oheM0?n:F`3oReX0403oReX00`3oS5d0
ohYJ0?n;FP0?0?n;FP030?n<G03oSUl0oh]J00l0oh]J00<0oheN0?n;F`3oReX03`3oReX00`3oREP0
ohYI0?n;FP0?0?n;FP030?n>G@3oReX0oh]J00d0oh]J00<0ohYJ0?n>H@3oSUl0403oReX00`3oRUP0
oh]J0?n;FP0?0?n;FP80ohYJ3P3oReX01`3oSUl0oh]J0?n9F@3oS5/0ohaM0?n;F`3oRUT02P3oReX0
1`3oS5/0ohUI0?mnC@3oN4L0ogm?0?n:F@3oS5/0403oReX00`3oS5/0oh]J0?n;FP0?0?n;FP030?n:
FP3oSEd0ohYJ00D0oh]J00P0ohaK0?n5E03oNTX0ogM60?mlB`3oQUD0ohYJ0?n<F`D0oh]J00@0ohaK
0?n;F`3oReX0ohYJ3`3oReX01`3oS5/0jWY?05XS5P020@40<A0<0=MD@`3oKeX03`3oK5P02P3oKEP0
ofeG0?m`F`3oJeD0ofYC0?mfH@3oPW00ojfT0?o?b@3oiN<L0?ooo`0:0?oWm@3oh_40on?a0?oRl@3o
ho80onOe0?oKh`3ob<d0ojZV0?n1LP80ofA?00H0ofEA0?mWD`0N2@L0000007dN7P3oEE<30?mBD009
0?mDD@3oEU@0oe9@0?mDD`3oDDl0oeEC0?mCD03oHV40oeAB00L0oe=A00D0oeIE0?mCD@3oDDl0of5O
0?mED`060?mBD@060?mOGP3oE580oeAB0?mFD`3oDe00oeIC0P3oEE800`3oDdh0oeEB0?mED@020?mE
DP080?mFD`3oCT`0gT=10;<g=`26:2P0Ga/K03@?3`0<0`<30000000<00d30`153`h0P1`K08`U902a
;Rd0jd0o0?m@CP3oDE00oeaK0?mJE`3oH5h0oeME0`3oEU<03P3oE580oeiL0?mIEP3oEU@0oeEC0?mG
E@3oBDP0CQ8A0000003DLS`0oiiE0?nKD@3oYfP0onkUo`3oooni0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo2`3oool0203ol?80UeU2070l8P1i@bX0
ND<Y07Q2:028CcH0S54h1@1i@bT0101kA2X0N48X07i5;@24BS4407U3:@0607]4:P21B2l0ND8X07U3
:@1h@BL0N48X0`1i@bT00`1h@RP0O4D/07a5;00307U3:@0308M==01h@BL0ND<Y0080ND<Y00<0NdDZ
07U3:@1i@bT0101i@bT02@1g@RP0ND<Y07U3:@1i@bT0Md4W07I19`1nARd0MT4W07Y4:P0307U3:@06
07m7;P1nAR`0ND<Y07U2:024Bc40N44W2@1i@bT00`1f@2H0N48X07Q19`0607U3:@0807a5;01kABX0
Nd@Z07U3:@1T=b001@<000@10@1g=RP507Pg:@0;07Lf:@1d=2L0PCX/0=AI?`3oJTP0ofa80?m]B@3o
KTX0ofY70?m^B`3oLDh0203oKTX20?m`C0P0ofi:00H0og=?0?maC03oLD`0og1:0?meD03oLTd60?ma
C0050?meC@3oQE/0ohYK0?n=GP3oS5/0103oReX00`3oS5`0oh]J0?n;FP0B0?n;FP030?n<G03oSEh0
ohUI00d0oh]J00P0ohaK0?n;FP3oR5L0oge=0?mfA`3oNdX0ohQH0?n;Fa80oh]J00<0oh]K0?n;FP3o
ReX03P3oReX01@3oS5/0oh]J0?n;F`3oSEd0ohaK0140oh]J00<0ohiQ0?n;FP3oReX03`3oReX20?n>
G`030?n9F@3oReX0oh]J00d0oh]J00<0ohaL0?n<GP3oReX03`3oReX00`3oT680ohYK0?n;FP0?0?n;
FP80ohUH403oReX00`3oTF<0oh]J0?n;FP0>0?n;FP030?n8E`3oREP0oh]J00h0oh]J00<0ohYK0?nA
I03oRUX03`3oReX00`3oSEl0ohmP0?n:F@0;0?n;FP060?n9F03oSUl0oheN0?n=GP3oRe`0oi1Q3@3o
ReX01P3oS5/0ohUH0?mlB`3oN4L0oh=B0?n=G100oh]J00<0ohYI0?n?H03oReX04@3oReX00`3oRe/0
ohaK0?n;FP030?n;FP080?n<F`3oREP0ogi>0?mhA`3oNTT0ohIE0?n:F@3oS5/60?n;FP030?n:F@3o
S5/0oh]J0100oh]J00L0ohaK0?n8F01G8QD0000006DN603oHDd0og1J00l0ofaH00<0ofeH0?m^F03o
KET01@3oK5P01@3oJE<0ofUA0?mcG`3oOfh0ol2m01T0oooo00D0onkk0?oQl03oh_40on;a0?oSl@03
0?oRl@0;0?oSl@3oi_@0on7]0?o7b@3oUXd0of]I0?mVD00h40`0000005DD503oEE<0103oDU00203o
DDl0oe=A0?mBD@3oEE<0oeUI0?mED`3oHV00oeAB203oDe40103oEE<0oe5?0?mNG@3oE5<60?mBD@07
0?mBD03oDU40oe5@0?mHEP3oGe`0oeME0?mCD@020?mEDP050?mFDP3oGe`0odA30;/_;@103`l01`00
00003`0o3Pd0/RLU0?lg=@3o>cX0odQ70?m@CP3oG5`0oeME0?mFE03oEE<0oeEB0?mNG@3oFUP0oe=A
0?mDDP030?mFD`030?mED@3oHV00oeaJ00<0oeEC00P0oe]I09XW9@000000^V<c0?nNE@3oW5@0oiY@
0?ngPol0oooo^@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooo`/0oooo00<0cZFM07E09P1i@bT00`1i@bT00`1h@BL0MT0V07U3:@0307U3:@0507]4:`25
Bc<0ND<Y07a5;022BS00101i@bT01P1kA2/0S58j07Q2:01i@bT0MT0V07Q2:080ND<Y00@0N48X07M1
9@24Bc80OdH]0`1i@bT00`1g@BP0ND<Y07U3:@0207U3:@0308aB>@1kA2X0ND<Y00@0ND<Y00L0Nd@[
07U3:@1i@bT0ND<Y07Y4:@1lAB/0Nd@Z00D0ND<Y00H0OdL^07i6;01i@bT0ND<Y08=9<01h@RP907U3
:@0307I09P1jA2X0ND8X00@0ND<Y00<0N48X07i6;@1lAB/00`1i@bT00`1O=Al00P0000@20P0407Pg
:@0607Lf:01i=bX0S3d^0<EF?`3iID<0ofa90P3oJdP01@3oJTL0ofm<0?m[B03oKDX0og1=00P0ofi:
00<0og1=0?m_B`3oKTX01`3oKTX01@3oLDd0og5<0?maC03oME00og=>0080og5<00P0og1;0?maC03o
LTd0og]B0?n<H03oRET0oh]K0?n<F`H0oh]J00<0ohYI0?n<F`3oReX04`3oReX00`3oSEh0ohaN0?n9
F@0?0?n;FP050?n:F@3oOTd0ogM60?miB03oQUD04P3oReX00`3oRET0oheN0?n9F@0>0?n;FP050?n<
F`3oRUP0oh]J0?n;F`3oS5`04P3oReX00`3oS5`0oh]J0?n;FP0>0?n;FP80ohYI4@3oReX00`3oREP0
oh]J0?n;FP0>0?n;FP030?n=G03oReX0oh]J00l0oh]J0P3oRUT@0?n;FP030?nAHP3oReX0oh]J00d0
oh]J00<0ohYI0?n9F03oReX03`3oReX00`3oRe/0oi9U0?n;FP0?0?n;FP030?n:F@3oReX0oh]J00P0
oh]J00T0ohYK0?n<F`3oSV40oh]K0?n;FP3oRe/0oh]J0?n:F@3oREP0303oReX0203oRe/0ohUH0?mm
C@3oMdH0ogm?0?n;F`3oREP0ohaL3`3oReX20?n:FA80oh]J00<0ohUH0?n:F@3oReX00`3oReX01@3o
QE@0ogY90?mfA`3oNdX0ohQG00X0oh]J00<0ohaK0?n;FP3oReX03P3oReX20?n:FP060=UF=`020@40
IAhH0?mQC@3oLU/0ofeH3`3oK5P00`3oKUT0of]E0?m/F0070?m/F0070?m[E@3oJU<0ofmJ0?mkJ@3o
[JH0onGZ0?ono`0E0?ooo`030?oWm@3ohO00on;a00L0on;a00T0onCc0?oUm03ohNh0oloF0?n<P@1L
71D0000004H@403oEE<0203oDU00103oEE<0oe5>0?mQH03oE5870?mCD@050?mED`3oGE`0odm>0?mP
G`3oEE<01P3oDU420?mBD0090?mAD03oF5L0of1N0?mDD@3oEeD0oeIC0?mEDP3oEU<0oeAC00H00000
00P03P<306HF5@2_9B@0ocHf0?m2@03oA480od];0?mFE@80oeEC00T0oemN0?mHEP3oEE<0oeEC0?mE
DP3oGE`0oeYG0?mFD`3oDe400`3oEU<02`3oEE40of5O0?mIE`3oEeD0oeEA0?mED`3oGU/0YR/Y0000
002ZFS00oieE0080oiaD00<0oiiH0?oQd@3oool0o`3ooong0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo2P3oool00`3ol_P0UeU407U3:@0307U3:@03
07I09P1h@BL0MClU00@0ND<Y00D0ODD/08iB>P1kA2X0OTH/08A:<@0407U3:@0<07a5:`2<DCT0N48X
07U3:@1f@2H0N48X07U3:@1jA2X0Nd<Y07Do9`1kA2T0ND@Y0`1i@bT00`1g@BL0ND<Y07U3:@0207U3
:@0308E;<`1kA2X0ND<Y00<0ND<Y00<0N48X08I==01i@bT00P1i@bT00`1oAbh0N44W07U3:@0507U3
:@050818;`1nARd0ND<Y07U3:@1f@2H02P1i@bT0201e?bD0PdXa07U3:@1i@bT0N48X07U3:P1nAb`0
OTH/1@1i@bT00`1J<Ah0000000T50`0207Pg:@0507@d9`1g=bX0OSTZ0;E?>`3oJ4H00P3oK4P30?m[
B0040?mZA`3oJdP0of]80?m/B080ofm;1`3oKTX00`3oKd/0ofi:0?m^BP080?m^BP030?mbCP3oLdh0
og==0080og1;00@0og==0?meCP3oNU80ohQN2`3oReX00`3oRUT0oheO0?n;FP0C0?n;FP030?n:F@3o
Re`0ohiO0100oh]J00D0ohUH0?mkBP3oMTL0og]90?n7EP0S0?n;FP040?n9F03oS5`0oh]J0?n=GA80
oh]J00<0oheN0?n;FP3oReX03P3oReX00`3oRUX0ohmR0?n:F`0@0?n;FP030?n=G`3oS5d0oh]J00h0
oh]J00<0ohYI0?n9F03oReX03P3oReX00`3oRUT0oi5T0?nAI00@0?n;FP030?nAHP3oReX0oh]J01l0
oh]J00<0ohUH0?n8E`3oReX03`3oReX00`3oSEd0oh]J0?n;FP060?n;FP040?n=GP3oRUT0ohmR0?n;
G0@0oh]J00<0ohYK0?n?H03oReX0303oReX01@3oRUT0oge=0?mgAP3oN4L0ohUI0080oh]J00<0ohYI
0?n<F`3oReX03@3oReX00`3oSf00ohaL0?n;FP0@0?n;FP030?n;G03oS5h0oh]J0080oh]J00H0ohaK
0?n5E03oN4L0ogM60?mhA`3oQeH90?n;FP030?n<G03oSUl0ohYJ00l0oh]J00L0ohaK0?n;FP3LECL0
0P0003<@3@3oHdh0og5K0140ofaH00<0ofeG0?m/F03oK5P02@3oK5P01`3oKEP0ofeG0?m/E@3oK5D0
oijB0?oTj@3onOl04P3oool00`3ol_l0on7`0?oRl@020?oRl@030?oQl03oh_40on;a00D0on;a0P3o
ho401@3ohO00AR0N0000000Z1`H0odi<00T0oe9@00<0oe9?0?mGE03oDe401`3oDe401@3oE580oeUH
0?m?CP3oHEh0oeAC00L0oe9A00/0oeMF0?mAD03oF5H0oemL0?mDDP3oDe40oeUG0?mFD`3oEeD0oe9?
00@10@020000000?01`71P1Y61L0/bPW0?lm>`3o@Sl0od4o0?m3@@3oCD/0oeAB0?mJE`3oHf80oeAB
0?mED`3oDU00oeME00<0oeEC00D0oe=A0?mEDP3oE580ofES0?mFE0030?mFD`0:0?mCD@3oEE80oe=A
0?mGE03oEE<0oeiK0:XZ:@000000TdlY0?nPEP80oiaD00<0oi]A0?nZKP3olnh0o`3ooong0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo2@3oool00`3o
e=@0Xf5=07M29`0407U3:@0308=:<01kA2X0MT4W0080ND<Y00L0O4D/07i6;@1j@bT0PTX`07Y3:P1m
AB/0P4P^00@0ND<Y00/0Md4W07I09P1i@bT0N4<Y07I09P1i@RP0ND<Y07e6;01i@RP0NT<Y07U2:004
07U3:@0307M2:01i@bT0ND<Y0080ND<Y00<0Md4X07U3:@1i@bT00`1i@bT01P1h@RP0QTdd07Y3:@1o
Abd0ND<Y07]4:PL0ND<Y00D0OdL^07i6;@1i@bT0Nd@[07i7;@0907U3:@0807I09P1h@RP0NT<Z07]4
:`1jA2X0OdL^07a5:`1iA2T607U3:@0905/b7`0000002P@307Hf:@2<?bh0^U0j0=EL?`3^ITH0ofa8
00D0of]800<0ofa90?m]B`3oK4T00P3oJdP00`3oK4X0ofm<0?m^BP050?m^BP030?m`C03oKd/0ofi:
00P0ofi:00P0ofm;0?m`C03oME00ogI@0?mjD@3oPeT0ohII0?n=G@l0oh]J00<0ohaM0?n=G@3oRUX0
4`3oReX00`3oS5`0oh]K0?n;FP0>0?n;FP070?n<F`3oREX0ohIE0?mkB`3oMTH0oge=0?n4E00@0?n;
FP030?n;F`3oSEh0ohaL00l0oh]J00@0ohYI0?n;F`3oSEh0oh]K4@3oReX00`3oRe/0ohaK0?n;FP0?
0?n;FP030?n<G03oS5/0oh]J00l0oh]J00<0oheM0?n;G03oReX03`3oReX00`3oSEd0oh]J0?n;FP0=
0?n;FP030?n:F@3oTF@0oi5T0100oh]J00<0oi1R0?n;FP3oReX03@3oReX00`3oSUl0oi5U0?n9F@0?
0?n;FP030?n?H@3oReX0oh]J00l0oh]J00/0ohaL0?n;FP3oReX0oh]J0?n;F`3oS5d0ohUH0?n>G`3o
Re/0ohiO0?n:F@060?n;FP030?n=GP3oRe`0ohYJ00`0oh]J00D0oh1@0?mgAP3oOD`0ohMH0?n<G004
0?n;FP030?n<F`3oReX0oh]J00T0oh]J0P3oRe/B0?n;FP0<0?n<F`3oS5`0ohYJ0?n<F`3oReX0ohQG
0?n0C`3oNDP0oga;0?n3DP3oRUT0ohaK1`3oReX0103oRe/0oheN0?n<G03oRUX?0?n;FP070?n<F`3d
OU80KbXL0040000f4@d0fUQ60?m`FP0?0?m/F0030?m^F@3oL5/0ofiH0100ofaH00L0ofaF0?mZE03o
Of`0oiB70?nl]P3oj>L0ooSl00d0oooo00<0oogo0?oUm03ohO001@3oh_400`3oho40on;a0?oRl@05
0?oRl@080=ng`P0;1PP020@40;9UK`3oQ8`0oeaM0?mAC`3oCT`50?mBD0060?mAC`3oGed0oe9@0?mE
D`3oDU00oeIE0P3oE5840?mCD@030?mBD@3oEE80oe9@00P0oe9A01<0oeMF0?mAD03oF5L0oemN0?mE
D@3oEE80oeIC0?mFE03oFUP0oe5>0:@]:`2e;B`0kS/h0?m0?@3o@d40odE30?m:B@3oCdd0oeAB00<0
oeEC00<0oeQF0?mLF`3oEE<00P3oEE<02@3oEUD0oeME0?mFE03oEE<0oeAB0?mEDP3oEE<0oeYH0?mF
E0030?mFD`0:0?mEDP3oEE<0oeiM0?mFE03oEeD0oeeJ0;l`;P020040QdLU0?nQEP<0oiaD00<0oiY?
0?nZJ`3ojmh0o`3ooonf0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0oooo203oool00`3of]`0QDXc06Tf6P0407U3:@0707Q2:02AE3/0O4@[07Q2:01i@bT0
OdL^07a5:`0207Q2:00407E09P1i@bT0N48X07M19`@0ND<Y00`0OTH/07U3:@1i@bT0N48X07U3:01h
@BL0N48X07U3:@1h@RP0PTT`08Y?=P1h@RP307U3:@0607M2:01i@bT0ND<Y07U3:@22BC00O4D[1@1i
@bT01P1f@2H0PDP_07a5:`1i@RP0Nd@Z07U3:PL0ND<Y00D0OdL^07i6;01h@RT0Nd@Z07m7;P0907U3
:@0607I09P1f@BL0ND8X0858;`1f@2H0N48X1`1i@bT01`1kA2X0DbdJ0000000<10<0beHl0?YYB03o
KDP01`3oJdP00`3oJDD0ofm<0?m^BP030?m[B0030?m[A`3oKd`0ofe900<0ofi:00<0ofa90?m`C03o
L4`02@3oKTX01@3oJdL0og1<0?moE`3oQU/0ohiN01<0oh]J00<0ohYI0?n<F`3oS5l0503oReX00`3o
RUT0ohUH0?n;FP0@0?n;FP060?n:FP3oOTh0ogI60?mdA@3oP4l0ohaK3`3oReX00`3oRUT0oh]L0?n:
F@0?0?n;FP050?n:F@3oS5/0ohiO0?n<F`3oRET0403oReX00`3oS5`0ohYI0?n;FP0?0?n;FP030?n@
H`3oReX0oh]J00h0oh]J00<0ohYI0?n<G03oRUT03`3oReX00`3oU6X0oh]J0?n;FP0=0?n;FP030?n:
F@3oTF<0oi1S0100oh]J00<0oi1R0?n;FP3oReX03@3oReX00`3oSEd0ohiQ0?n9F@0?0?n;FP030?n>
G`3oReX0oh]J00d0oh]J00<0ohYI0?n?H03oSEh00P3oRUT01@3oS5l0ohaL0?nAH`3oReX0ohYI00P0
oh]J00<0ohYI0?n=GP3oReX0303oReX01P3oOdl0ogQ70?n1D@3oRUT0oheN0?n<F`<0oh]J00@0ohYJ
0?n:F@3oS5/0oh]K2@3oReX00`3oS5/0oheN0?n;FP0A0?n;FP050?n9F03oReX0oh]J0?n:F@3oOTh0
0P3oMdH00`3oPE00ohaK0?n;FP090?n;FP030?n<F`3oRUT0oh]J00l0oh]J00L0oheL0?n?G@1[:AX0
000003lC3P3oIU00og1J00l0ofaH00<0ofmI0?maG03oKEP04@3oK5P0103oKEP0og1K0?maG03oKEP2
0?mVC`030?n>O`3o/JX0ong^00/0oooo00<0ooKl0?oPl03oh_40103oh_400`3oho40on;a0?oRl@05
0?oRl@0;0?o]n`2;GfH00000088oAP3ob=X0okoB0?nfb@3oTih0ofib0?m=B`3oDDl0103oDU000`3o
DDh0od];0?mBD0020?mCD@030?mED`3oEeD0oe9@00<0oe=A00@0oeaL0?mNG@3oCdh0oe5@1`3oDU40
3`3oD4h0oe9A0?mDDP3oEE80oeIC0?mDD@3oCdd0od]80?m4@@3o?c/0ocdk0?m1?P3oB4D0oeUE0?mC
D@020?mFE080oeEC00D0oeID0?mED`3oEE<0oeAB0?mBD0020?mED`0:0?mDDP3oHV40oeID0?mIE`3o
EU@0oeAB0?mDD@3oEU<0oeAB0?mAC`@0oeIC00T0oe=A0?mPGP3oEe@0oeEC0?mPG@3@=C<000000811
903oXEH00`3oW5@0103oVe80oiU?0?nOF`3on?Co0?oookD0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool70?ooo`040?odm`2bKUd0LCdQ07Q19`D0ND<Y
00<0Q4Xb07Q1:01h@RP00P1lAB/01@1h@RP0ND<Y07]4:P1i@bX0ND<Y0080N48X101i@bT01P2>DcX0
ND<Y07U3:@1i@bT0NT@X07Q2:080ND<Y00@0ND8X0858;P25Bc<0N48X0`1i@bT01P1g@RP0ND<Y07U3
:@1i@bT0PTX`07a5;0D0ND<Y00H0Nd<Y08A;<P1i@bT0N48X0899<020Abh707U3:@0507i6;@1lAB`0
ND<Y07Q19`1h@bP0201i@bT01@1h@RP0N44W07U4:@23BS40N48X00T0ND<Y00H0MClW04XY6P000000
30@30?aU@P3oKDT80?m[B0030?m`C@3oK4T0of]700@0of]800<0ofe:0?m`C@3oKTX00P3oKTX00`3o
K4T0ofe90?m_B`070?m^BP050?m]B@3oLD`0oh5H0?n4E`3oSEh00P3oS5`D0?n;FP030?n:F@3oRU/0
ohaL01D0oh]J00<0ohQH0?n;FP3oReX03P3oReX0203oS5/0ohYI0?n4D`3oMdL0ogQ70?n0D03oRUT0
ohaK3P3oReX00`3oRU/0ohiO0?n;FP0@0?n;FP030?n@H@3oSUl0oh]J0100oh]J00<0ohYK0?n:F@3o
ReX03`3oReX00`3oRe/0ohUH0?n;FP0>0?n;FP030?n:F@3oTF@0ohYI00l0oh]J00<0oi5T0?n;FP3o
ReX03@3oReX00`3oRUT0oi5T0?nAI00@0?n;FP030?nAHP3oReX0oh]J00d0oh]J00<0ohYI0?n9F03o
ReX03P3oReX00`3oR5L0ohUF0?n;FP0?0?n;FP070?n8FP3oSEd0ohmP0?n:F@3oReh0oh]L0?n:F@0:
0?n;FP030?n=GP3oReX0oh]J00/0oh]J00L0ogm?0?mgAP3oNd/0oh]J0?n>G`3oReX0ohYI00D0oh]J
00<0ohYI0?n<F`3oReX0203oReX00`3oS5/0ohYI0?n;FP0@0?n;FP050?n=GP3oReX0ohaK0?n<F`3o
Odh00P3oMdH00`3oOTh0oh]J0?n;FP090?n;FP030?n8F03oS5`0oh]J00l0oh]J00L0oheL0?n?G@3:
CC801P8103T@303oFDH0og5K00l0ofaH00<0ofeG0?m`F`3oK5P04P3oK5P00`3oKUP0og5L0?m/F002
0?m/F0060?m]E`3oITh0of9:0?n:N`3oal@0ooKm2@3oool00`3okOP0on;a0?oRl@0;0?oRl@0>0?oS
l@3oko`0@2HX00@20P3oX[@0ok_>0?nlc`3o_]80ol;E0?ncaP3oPXX0odm<0?m=C03oDDl30?mBD00:
0?mHE@3oDE00oe=A0?mCD@3oDU00oeEC0?mIEP3oDE00oe9@0?mCD@80oeAB00<0oe=A0?mAD03oDU40
1P3oDU403`3oEU@0oe=B0?mBD@3oD4h0odm<0?m5@`3oA440od0m0?lm>`3oAD<0odU70?mCC`3oE580
ofAR0?mGE@030?mED`030?mDDP3oGel0oeME0080oeEC00@0oe=A0?mED`3oEE<0oeEC0P3oEU@01`3o
EE<0oeED0?mEE03oFEL0oeAB0?mFD`3oGed00`3oEU<02`3oE580oeQF0?mED`3oE580oeEC0?mIE`3o
AD@0=0/;07De7P3oWED0oieD0080oiaD00@0oiaC0?nQF`3oVDl0omc1o`3ooone0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo1`3oool0103`aL80K3XM
0858;`1lAB`507U3:@0507E09@1h@bP0N48X07e6;@1i@RP00P1i@bT01@21BBl0OTH/07U3:@1h@BL0
N48X00@0ND<Y00D0Re0g07U3:@1i@RP0OTH/07U2:00407U3:@80N48X101i@bT00`1g@RP0ND<Y07U3
:@0507U3:@0907U2:01nAR`0O4D[07Q2:027CC@0ND<Y07U2:01oAbh0OTH]00L0ND<Y00@0ODH]07i6
;01i@bT0Nd@Y201i@bT01@1j@bT0OTH]07a7:`1iA2T0ODH]00P0ND<Y00P0MT0X07E1:P2KES<0bfdi
014910020000HBPJ0?m^BPP0of]800<0ofe90?m/B@3oJdP01@3oJdP01`3oK4P0ofi:0?m^BP3oKTX0
og9>0?mbC`3oKDT01@3oKTX01@3oKDT0ofe80?mmEP3oQUT0oheN00<0oh]J00<0ohiO0?n8FP3oReX0
4`3oReX00`3oRUT0oheN0?n:F@0C0?n;FP030?n:F`3oReX0ohUH0180oh]J00D0ohMG0?miB@3oMTL0
oga<0?n7EP0?0?n;FP030?n;F`3oS5`0oh]J0100oh]J00<0oh]K0?n:F@3oReX03`3oReX00`3oS5`0
ohmP0?n:F@0?0?n;FP030?n:F@3oT680oh]J0200oh]J00<0ohYI0?n;FP3oReX03@3oReX00`3oRUT0
oi5T0?nAI00@0?n;FP030?nAHP3oReX0oh]J00d0oh]J0P3oRUT?0?n;FP030?n<GP3oRU/0oh]J00h0
oh]J00@0ohYI0?n=GP3oReX0oh]L3P3oReX00`3oRe/0oh]J0?n;FP0:0?n;FP070?n1D@3oN4L0ogQ7
0?n5E@3oRET0ohYI0?n;F`060?n;FP80ohYI00<0ohaK0?n;FP3oReX01@3oReX00`3oSEh0oh]K0?n;
FP0@0?n;FP0:0?n<F`3oRe/0oh]J0?n7EP3oO4`0ogQ70?miB03oQE@0ohYI0?n<F`T0oh]J00<0ohYI
0?n;FP3oS5/03`3oReX01`3oRe/0ohaK0<M<<@0>10<07`T70?mKB03oLU`03`3oK5P00`3oKEL0ofmJ
0?m_FP0B0?m/F0030?m_FP3oL5/0ofaH00H0ofaH00D0ofI?0?mbG@3oQGD0ojBJ0?oal`070?ooo`03
0?oWm@3oh_40on;a00D0on;a00<0on?a0?oRl@3oh_400`3oh_401@3ol?`0ojJb00h82@2DB500okkB
0080okc?0P3o^lh02P3o_]80okW<0?nKZ03oM7T0oe=A0?m@CP3oDU00oe5?0?mQG`3oDU040?mCD@08
0?mDD`3oDU00oeQF0?mCD@3oDU00odm>0?mBD03oDE070?mBD@0?0?mLF`3oCD`0odM60?m5@P3o@d00
od<n0?m1?P3oAT<0ode;0?mCD03oDdl0oeIB0?mHE@3oIF80oeID00<0oeEC00<0oeAB0?mMG03oEeD0
0P3oEE<20?mDDP80oeEC00T0oe=A0?mDDP3oEE<0oeEC0?mDDP3oFUP0oeAB0?mFD`3oI6800`3oEU<0
2`3oEE40oeiL0?mCD@3oDU00oeEC0?mHE@3oBdT0JQLF04/R4`3oV580oieD0080oiaD00@0oiaC0?nP
G03oWEH0okAno`3ooone0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0oooo1P3oool01@3oj^/0VEm:07M19`21B2l0ODD[00@0ND<Y00D0Nd@Z07Y3:P28CCD0
P4L_07Y4:P0307U3:@0407m7;P1lAB/0ND<Y07E09P@0ND<Y00L0N48X07M2:01i@bX0ODH]0859;`26
C3@0N44W0080ND<Y00<0Nd@Z07m6;@1h@RP00`1i@bT00`1jA2X0OTH]07U3:@0207U3:@0907]4:P1i
@bT0ND<Y07Y4:P1lAB/0Nd@Z07Y4:P1h@RP0Q4/b0080ND<Y00<0Md4W07U3:@1i@bT01P1i@bT01020
B2l0PDL_07U3:@29CcH507U3:@0807Y4:P1i@bT0ODD[07a5:`1f@BL0SE8j0898<01h@RP407U3:@0<
07Q2:@1i@bT0Nd@Y09YD<P3=LCh0kX930?n<AP3oTD/0Sd`T00H30@0;1@<0d5Xk1`3oJdP00`3oKDX0
ofa:0?m[B0060?m[B0050?m`C03oKd/0ofi:0?m_B`3oKd`0103oKTX01`3oKd/0og==0?mlE03oQeX0
ohYK0?n:FP3oS5/01@3oReX00`3oSEh0ohaK0?n;FP0C0?n;FP030?n<F`3oS5d0oheM01@0oh]J00<0
oh]K0?n<F`3oReX0403oReX01`3oS5/0ohUI0?moC`3oNDP0ogQ70?n1D@3oRUT03P3oReX00`3oRe`0
oh]J0?n;FP0@0?n;FP030?n<G03oReX0oh]J00l0oh]J0P3oS5`@0?n;FP030?n<G03oReX0oh]J00h0
oh]J00<0oh]K0?n;G03oReX03P3oReX00`3oRUT0ohUH0?n;FP0>0?n;FP80oheN403oReX00`3oTF<0
oh]J0?n;FP0=0?n;FP030?n=G@3oReX0oh]J00h0oh]J00<0oi1R0?n<F`3oReX0203oReX0203oRe/0
oh]J0?n;FP3oSf00ohaL0?n<G@3oReX0ohmO403oReX00`3oS5`0oh]J0?n;FP080?n;FP080?n<F`3o
PU40ogQ70?mkBP3oQE@0oh]J0?n<G03oSEd90?n;FP030?n<F`3oRUT0oh]J00D0oh]J00<0oheM0?n;
FP3oReX03`3oReX0103oRe`0ohYJ0?n9F03oP4l20?mhA`030?n0C`3oRUT0oh]J00X0oh]J00<0ohaL
0?n>G`3oRU/03`3oReX01`3oS5/0lGaA06DW6P060P408@X70=1??`3oLEX03`3oK5P00`3oKEL0ofiI
0?m]F@0A0?m/F0030?m]F@3oKeX0ofiH00T0ofaH00P0ofaG0?mZE@3oJeH0ogIR0?nGRP3o^;80om;=
0?ogn080oooo00<0ooSo0?oRl@3oh_401P3oh_400`3oho80on?a0?oRl@020?oRl@080?oYm`3odMd0
JSm301h?403o[;l0okg@0?nkcP3o_<l30?nkcP090?nlc`3o_M00ok_=0?na``3oS9D0of=T0?mED`3o
DU00oeMF00L0oe=A00L0oeEC0?mCDP3oG5X0oeME0?mIE`3oDU40oe=A0080oe9A01<0odi<0?m;B@3o
ATH0odA20?m1?`3o@D00odE30?m;B@3oD4d0oeAA0?mEDP3oE540oeAB0?mLFP3oGU/0oeIB0?mFD`3o
E5<0oeAB00@0oeEC00<0oeEB0?mED`3oEE<00P3oEU@30?mED`050?mKF@3oEE<0oeEC0?mDDP3oGE/0
0P3oEU<03`3oEU@0oeIC0?mFD`3oEU<0oeEB0?mNG03oEE<0of1O0?mED`3oEe@0oeIC06XJ6@0I2`H0
oiE?0?nNE@020?nLE0050?nLD`3oXU`0oiiG0?nMEP3odK<0o`3ooond0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo1@3oool01P3okoD0[f]J07I09P1i
@RP0OTH]07]4:`@0ND<Y00@0P4T_08Q?=P2?DcX0O4D[101i@bT0101f@BL0ND<Y07U3:@1e@2H407U3
:@0707a6:`1i@RP0OTH]07U3:@20B2l0Qd`d07Q19`0207U3:@0307m7;P2<DCP0N44W00<0ND<Y00T0
Nd@[08E;<P1i@bT0ND<Y07Q19`26C3<0Nd@Z07E09@1kA2T0101i@bT0101g@RP0ND<Y07i6;@2:CcH8
07U3:@0407m7;P21Abl0MT4W07Do9@<0ND<Y00@0ND8X07Y4:P22BC00MT0V0P1i@bT0101f@BL0S54h
09AH?`1kA2X307U3:@0507I1:@1nABX0W5Ld0=Qe?`3oSTH00P3oS4H01`3oRdD0ohm;0?n@A`1G;QD0
000007dd8P3oL4/01@3oJdP00`3oJdL0ofm<0?m[A`070?m[B0030?m/B03oL4`0ofi:0080ofi:00H0
ofe90?m/B03oLDd0ogaC0?n<H@3oRUT=0?n;FP030?n:F`3oReX0oh]J0180oh]J00<0oh]L0?n>G`3o
ReX04`3oReX00`3oSEh0oh]J0?n;FP0A0?n;FP080?n<F`3oRUX0oga=0?mhA`3oNDP0ohED0?n;FP3o
S5/<0?n;FP030?n;G03oRUT0oh]J0100oh]J00<0ohiO0?n:F@3oRU/03P3oReX20?n<Fa00oh]J00<0
ohaL0?n?G`3oReX03P3oReX00`3oSEh0ohmP0?n:F@0>0?n;FP030?n:F`3oUVX0ohYI00h0oh]J0P3o
REP@0?n;FP030?n?H03oReX0oh]J00`0oh]J00<0ohYI0?nAI03oR5P03P3oReX20?n:F@P0oh]J00D0
ohYK0?n=GP3oSEh0ohiO0?n7E`020?n;FP030?n:F`3oSf00oh]J00l0oh]J00<0oheN0?n;FP3oReX0
203oReX02@3oS5/0oh=B0?mhA`3oO4`0ohUH0?n;FP3oS5/0oheN0?n9F@0:0?n;FP030?n<F`3oRUT0
ohUI0080oh]J00<0ohYI0?n>H03oReX0403oReX01`3oSf00oh]L0?n7EP3oNTT0ogQ70?mkBP3oQE@0
303oReX00`3oS5`0oh]L0?n:F@0?0?n;FP070?n<F`3oSE`0KR`M000000154Ph0oee90?m`FP0?0?m/
F0030?m]E`3oKeX0ofaH0140ofaH00<0ofeH0?maG03oKEL03`3oK5P01`3oK5L0of]E0?mmJ@3oa<40
onca0?oQkP3oioD0203oh_402@3ohO00on;a0?oRl@3oho80onWf0:YVK0000000PTmH0?o1e0020?nk
cP030?nlc`3o^lh0ok_>00D0ok_>00H0okc?0?nodP3oYKD0ogAi0?mJF03oDU080?mCD@0?0?mAC`3o
DU00oe]J0?m@C`3oCdd0odU70?m2@03o?Sd0ocln0?m1?`3oATD0oeID0?mBD03oEeH0oeME00<0oeEB
00T0oeA@0?mEDP3oE500oe=?0?mEDP3oDdl0oeEC0?mCD@3oEU@00P3oEE<01P3oE580oeaJ0?mED`3o
E580oe]I0?mJF@<0oeEC00L0oeQF0?mED`3oEE<0oe=A0?mMF`3oDU00oeEC0080oeID0P3oEU<0103o
EE40oeaJ0?mED`3oG5X20?mED`040?mNF`208B00:a@:0?nECP<0oiaD00H0oiaC0?nSH03oWED0oiaC
0?nMEP3od;7o0?oook<0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3oool40?ooo`070?oko`3QTXD0Kc/O07U3:@1b?R80RDlg0858;`0407U3:@0407]5:`1h
@RP0S58i07a5:`@0ND<Y00@0NT<Y07U3:@1i@bT0PTX`101i@bT01`22BC00O4H[07U3:@1i@bT0P4L^
08A:<P1h@RP00P1i@bT00`1lAB/0PDP_07Q2:00307U3:@0807]4:`25Bc80ND<Y07U3:@1h@BT0OdP]
0899<01h@RP507U3:@0407M2:01h@RP0OTH]08Q==@P0ND<Y00<0MT4W07]4:`1i@bT0101i@bT00`1l
AB/0ODH/07U2:00307U3:@0307I19`2<DCT0RTlf0080ND<Y00@0MT0X078o:02@D300egDo0P3oSTL3
0?n<AP070?n>B03oS4H0ohe70=5_=@081040;a<=0?mdC@050?m[B0030?m^BP3oJdP0of]800P0of]8
00L0og1<0?m/B03oLDh0ofa80?mdC`3oMTl0ohMK0100oh]J00<0ohiO0?n<G03oRET04`3oReX00`3o
S5`0ohaM0?n;FP0B0?n;FP030?n;G03oSUl0oh]J0180oh]J00H0oh]L0?n;FP3oOTd0ogM60?mhA`3o
P50=0?n;FP030?n:F@3oRU/0ohYI0100oh]J00@0ohYJ0?n<G03oS5`0oh]K3@3oReX00`3oRET0ohaN
0?n:F`0@0?n;FP030?n:F03oReX0oh]J00d0oh]J00<0ohYI0?n9EP3oRUT03P3oReX00`3oRU/0oiEX
0?n:F@0>0?n;FP80ohUH403oReX00`3oRUP0oh]J0?n;FP0<0?n;FP030?n:F@3oT6<0ohYI00h0oh]J
00<0oheN0?n:F`3oReX00`3oReX20?n9F@050?n;G03oReX0ohiO0?nBI03oREP0103oReX00`3oRe`0
oi1S0?n:F@0>0?n;FP030?n9F03oSEh0oh]K00P0oh]J00D0ohaK0?n5E03oNDP0ogU90?n9F0020?n;
FP030?n<F`3oRUT0oh]J00/0oh]J00<0ohaK0?n:F@3oReX00P3oReX00`3oREP0oh]J0?n;FP0>0?n;
FP080?n<F`3oREP0oh=B0?miB03oN4L0ogm?0?n:F@3oRU/=0?n;FP030?n:F@3oReX0oh]J00h0oh]J
00L0ohmN0?1N?@090`80Aa<?0?mMBP3oM5d0ofeH00d0ofaH00<0ofaG0?m^F@3oKUP04P3oK5P20?m^
FA<0ofaH00L0ofaF0?mVC`3oMV80ojBL0?oCfP3oj_L0onKd00H0on;a00T0on?a0?oRl@3oh_40onSf
0?nb_P0Y61X000000<IkR@3o_]80303o^lh01P3o_M00ol7D0?mjQ@3oEED0ode;0?mBD0@0oe=A0P3o
E5803`3oDe40odm=0?m<B`3oA480od0n0?lm?03o@3l0od910?m9A`3oCD`0oe=B0?mMG@3oD4l0oeaJ
0?mIE`030?mEDP030?mGD`3oEE80oeEB0080oeEB0P3oDe400`3oEE<0oeQF0?mED`020?mDDP050?mJ
F@3oEE<0oeAB0?mKF@3oFUP00`3oEE<02@3oDU00oeEC0?mED`3oEE<0oe=A0?mFD`3oDe40oeME0?mL
FP030?mFD`030?mCD@3oEE<0oe9@0080oeEC00D0oeiK08`R8P0R3`P0oi]I0?nNF0020?nLE0070?nJ
DP3oXf40oj9O0?nME@3oVDl0ojAS0?o`j@3o0?oook80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool40?ooo`070?n`ZP1e?bD0ND<Y07U3:@1kA2/0TEDm
0857;`0307U3:@0507Q2:01i@RP0N44W095D?01lAB`00`1i@bT01@1f@BL0QT`b07Q2:01kA2X0TUDn
00<0ND<Y00<0Nd@Z07i6;01i@bT00P1i@bT00`20B2l0Qd`d07Q19`0207U3:@0307Do9@1e@2H0ND<Y
00<0ND<Y00H0Nd@Z08=;<@1i@bT0ND<Y07Q1:@1g@RH707U3:@0407M2:01i@bT0ND<Y07U2:0L0ND<Y
00T0N48X07a4:`1f@BL0SU<j07]4:P1h@RP0O4D[07m7;@1oAR`01@1i@bT02@1f@BL0R4de07]3:@1h
@RP0L3hW07a5;02VFcD0jh540?n@B0040?n<AP030?n;A@3oSTX0ohe80080oha600@0EbhD00l6103<
DcH0og5<0`3oJdP00`3oJTL0ofa90?m^B`090?m[B0060?mZA`3oK4X0ogA?0?mjDP3oRUd0ohiO4P3o
ReX00`3oSf00ohQJ0?n;FP0B0?n;FP030?n9F@3oS5h0oh]J01<0oh]J00<0ohaL0?n<G`3oRU/0403o
ReX02P3oRUT0ohaN0?n<G`3oRET0oga;0?mgAP3oMDH0oh5@0?n;FP3oS5/:0?n;FP030?n<G03oSf00
ohaK0100oh]J00@0oheN0?n;F`3oRUT0ohaK803oReX00`3oSEh0oh]J0?n;FP0>0?n;FP030?n=GP3o
RU/0ohUI00d0oh]J00<0ohYK0?n>G`3oReX03P3oReX00`3oRUT0ohUH0?n;FP0?0?n;FP030?n:F@3o
ReX0oh]J00`0oh]J00<0ohYI0?n=G@3oRUT03P3oReX00`3oSV00oh]N0?n;FP020?n;FP070?n8F03o
SUl0ohiO0?n<G@3oS5`0oh]J0?n:F@050?n;FP030?n9F03oR5L0oh]J00d0oh]J00<0ohUI0?n>G`3o
Re/02@3oReX01@3oQE@0ogU80?mfA@3oPe80ohaK0080oh]J00<0oh]L0?n;FP3oReX02`3oReX01P3o
Re/0ohaK0?n:F@3oRe`0oheN0?n:Fa00oh]J00H0ohUH0?mmC@3oN4L0ogI50?n0C`3oS5/=0?n;FP03
0?n:F@3oRe/0oh]J00l0oh]J00L0oi5N0>YL?00A1P<09@/80?mNB`3oMUl0ofeH00d0ofaH00@0ofaG
0?maG03oKUT0ofaG4@3oK5P00`3oKeX0ofiI0?m^FP0B0?m/F00:0?m/E`3oKUP0ofiI0?m[E03oIDd0
oh=c0?nm^P3og>L0ongk0?oUl`@0on;a00P0on7`0?oRl@3oh_40onCb0;I]M00000002P@40?n^_`<0
ok_>00<0okc?0?nmd03o^/h0203o^lh01`3o]//0oibc0?n0S`3oHVP0oe=A0?mAC`3oDe400P3oE580
4@3oDe40odm=0?m9A`3oA480oc/j0?lo>`3o@Cl0odA20?m<BP3oDe40oeEC0?mCDP3oDU40oe=A0?mA
C`3oFUP0oeUG00<0oeEB0140oeeJ0?mCD@3oDe40oeeK0?mFE03oEE80oe5?0?mED`3oEE@0oeME0?mF
E03oEE<0oeAB0?mED`3oE580oeYH0?mJF@030?mED`050?mHEP3oEE<0oeEC0?mED`3oE5800P3oEU<0
0`3oE580oeUF0?mDDP020?mFD`0?0?mEDP3oEE<0oeAB0?mDDP3oEE<0oeiK098U900B20@0oi]K0?nO
F03oWED0oiaD0?nME03oWEH0ojEU0080oieE00<0oiE90?ndO`3ooOh0o`3ooona0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo0`3oool0203]cL/0OdP_
07Q2:01i@bT0N48X08U>=P2HFT80OdH^0P1i@bT01P1j@bT0O4D/07Y4:@1h@RP0Qdhe07]4:`<0ND<Y
00X0Md8X08=:<@1i@bT0Nd@Z091D>`1i@bT0NT<Y07i6;@1kA2X0N44W0`1i@bT01`21BBl0R4de07Q1
9`1i@bT0NT@Z08A;<P1h@RT0101i@bT01P1kA2/0Q4/b07]3:@1lAB/0QD/b07]4:PH0ND<Y0P1h@RP0
0`1jA2X0OTH/07Q2:00707U3:@0907I19`27CCD0MT0V0859<01lAB/0ODD[07U3:@1kA2X0ND8X00D0
ND<Y00P0N48X08=;<`1nAbh0WULb0=Ed?P3]QD@0ohi60?n>A`D0oha600X0ohm;0?n>BP3oS4H0oha6
0?n?A`3SNS`04`X504`O503/IT@0ofi:0P3oJdP00`3oKDT0ofm;0?m[B0060?m[B080ofa800H0og=>
0?miC`3oQ5X0oh]M0?n;FP3oRUXD0?n;FP030?n>GP3oS5/0oh]J0180oh]J00<0oh]K0?n<F`3oReX0
503oReX00`3oRe/0ohaK0?n;FP0?0?n;FP80ohYJ00T0oh]J0?n:FP3oQeH0ogm>0?mhA`3oOD`0ohAD
0?n:F@3oS5/02@3oReX00`3oRUX0oh]J0?n;FP0@0?n;FP050?n=GP3oS5`0oh]J0?n=G@3oRe/03@3o
ReX00`3oSEd0oh]K0?n;FP0>0?n;FP030?n<G03oRe/0oh]J00h0oh]J00<0oi1Q0?n=G@3oRUX03P3o
ReX00`3oRUP0ohUH0?n;FP0>0?n;FP030?n9F03oReX0oh]J00h0oh]J00<0ohYI0?n;FP3oReX03@3o
ReX00`3oRET0oh]J0?n;FP0=0?n;FP060?n9F@3oRUX0oheN0?n;FP3oSUl0ohUI0P3oS5`80?n;FP03
0?n;F`3oT680oh]J00h0oh]J00<0ohaL0?n=G@3oRe/01`3oReX01@3oRUX0ohIE0?mhA`3oN4L0oh5@
00<0oh]J00<0ohYK0?n<F`3oReX03@3oReX0103oRUX0ohaK0?n:F@3oRUT>0?n;FP070?n;F`3oRUT0
ohAE0?mkC03oN4L0ogi=0?n5E@0>0?n;FP030?n<G03oS5/0oh]K00l0oh]J00H0nHAF07``7`091080
6@L50=9C@P3oLE/>0?m/F0040?m]F@3oLE`0ofmJ0?m]F100ofaH00@0ofiI0?m`F`3oKUX0ofeH4@3o
K5P0103oKET0ofiI0?m_FP3oKUT30?m/F0080?mZE@3oKUP0ogYX0?n>PP3o^[T0omcV0?oYm`3oi?<2
0?oRl@070?oSl@3oh_40m<C@01<;30000000cFIa0?nod@040?nkcP030?nld03o_<l0ok_>00D0ok_>
01@0okc?0?nic@3oX;P0oifd0?nL/`3oVk80ohfP0?m^MP3oCdd0odU70?m7AP3o@d40od0n0?m1?`3o
@D00odM50?m?CP3oD4l0oe=A0?mFE0@0oe9A00@0oeAB0?mFE03oFeX0oeUG0`3oEE801`3oGE/0oe=A
0?mDDP3oFEL0oeEC0?mEDP3oGU`00P3oEE<0103oEU@0oeEC0?mGE@3oF5H20?mED`030?mIF03oFEL0
oeEC0080oeEC00H0oe]I0?mED`3oEE<0oeEC0?mEDP3oE5820?mFD`040?mED`3oFUL0oeID0?mED`80
oeAB00h0oeME0?mKF@3oEE<0oeaI0;</;0010@40oha<0?nMD`3oWEH0oieE0?nLE03oW580oj1I0?nM
E@80oiaD00<0oiU>0?oI_@3oool0o`3ooon`0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0oooo0P3oool00`3omO`0Xf9>07Q2:00307U3:@0;07a5:`2AECd0
PDL_07U3:@1kA2X0PDP^07I1:026C3@0N48X07<n901i@RP0101i@bT02@1g@2H0ND<Y07]4:P2AE3`0
ND<Y07m7;P1i@bT0N48X0817;P0307U3:@0707a5:`1lAB`0ND<Y07U3:@1kA2X0Re0g07Q2:00407U3
:@0607]4:P28CCD0ND<Y07Q2:027C3@0ODD/1P1i@bT01@1f@2H0ND<Y07i6;02?E3/0N48X00L0ND<Y
00H0N44W08E;<P1b?B<0ND<X07]4:P1i@RP707U3:@0607Q2:@1kA2/0ZEhg0>Im@P3oSDL0ohm61`3o
S4H00`3oRdD0ohY40?n=A`030?n<AP050?n@B01R=1X0000008Pg903oL4/00P3oK4T00`3oKd`0of]8
0?m[B0050?m[B0030?mYAP3oLdd0ohAH0080ohaK00@0oh]J0?n<F`3oRUT0ohUH5@3oReX00`3oRUT0
ohaK0?n;FP0C0?n;FP030?n;F`3oS5/0ohYI0180oh]J00<0ohYI0?n;F`3oReX04@3oReX01@3oS5/0
ohYI0?n;FP3oS5/0ohED0080ogM600<0ogU80?n8E`3oReX02P3oReX00`3oSEl0oh]J0?n;FP0>0?n;
FP050?n;F`3oS5`0ohYI0?n;FP3oSf003@3oReX00`3oRUT0ohaN0?n;FP0>0?n;FP030?n<G03oSV40
ohYI00h0oh]J00<0ohYI0?n6EP3oRUT03P3oReX00`3oRU/0oi1R0?n;FP0>0?n;FP030?n9F03oReX0
oh]J00h0oh]J00<0ohYI0?n;FP3oReX03@3oReX00`3oS5/0oh]J0?n;FP0<0?n;FP050?n9F03oSEl0
oh]J0?n;G03oRe/0303oReX00`3oS5/0ohQH0?n;FP0>0?n;FP030?n<G03oRe`0oh]J00H0oh]J00H0
ohQJ0?n7EP3oMdP0og]:0?n8E`3oS5/20?n;FP030?n:F@3oSEh0oh]J00l0oh]J0P3oS5/00`3oRUT0
oh]J0?n;FP0<0?n;FP050?n6E@3oO4/0ogQ70?miB@3oR5L00P3oS5/=0?n;FP030?n>G`3oRU/0oh]J
00h0oh]J00L0ohaK0?nAH01j;al0000002<;203oETD0ofmJ00h0ofaH00<0ofeG0?m`F`3oKEL04@3o
K5P00`3oKEL0ofiI0?m^F@0B0?m/F0030?m^F@3oLE`0ofaG00P0ofaH00H0of]E0?m[D`3oNfX0oiN;
0?o;cP3oi_D20?oRl@060?oXmP2@KgL0000007hm@`3o]LP0okg@1@3o^lh00`3o^/h0ok_>0?nkcP04
0?nkcP0>0?nmd03oY;/0oiZa0?nJ/@3oV;00oiB[0?n?Y@3oRj80ogb@0?mIH03o?cd0odI40?m?C@3o
DDl20?mCD@<0oe9A00T0oe=A0?mHEP3oEE<0oe5@0?mBD@3oE5<0oeiL0?mDDP3oEe@00`3oEE801`3o
GU/0oe=A0?mEDP3oDe40oe=@0?mEDP3oI640103oEE<0103oE580oeYI0?mHEP3oEE<20?mDDP@0oeEC
00D0oe=A0?mED`3oEE<0oeME0?mFE0020?mFD`0D0?mKFP3oEE40oeYG0?mGE@3oFeP0oeID0?mED`3o
EU@0oeEC0?mJE`3i?C`040@40?U`>`3oX5X0oiaD0?nPF@3oVe<0oiaD0?nKD@3oVe<30?nLE0030?n[
K@3oool0oooo0?l0oooo[`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooo`80oooo00<0okJb07Q29`1i@bT00`1i@bT02`1c?R@0S50h0858;`1i@bT0OdL]
07U3:@1h@BL0R4de07Q2:01e@2H0ND8X00<0ND<Y00H0MT4W07U2:01i@bT0Nd<[08mC>`1nAR`207U3
:@0307Q2:024C3<0ND<Y0080ND<Y00<0N48X07Q19`1i@bT00P1i@bT00`1f@BL0ND<Y07U3:@0307U3
:@0507Q19`1mAB`0ND<Y07U3:@1h@BL01`1i@bT0101f@2H0ND<Y07Q2:01h@BL907U3:@0307e5;028
CCD0O4D[00L0ND<Y0P1h@RT01@29C2l0eg@n0?N3@@3oS4D0ohi600P0oha600<0ohm:0?n@C@3oRdD0
0`3oS4H0203oSdL0YeT[0000000H2@D0eULi0?m^BP3oK4P0ofm;1@3oJdP01@3oK4P0ogI>0?n9G`3o
QeH0ohaK00@0oh]J0P3oRUT00`3oS5/0oh]J0?n;FP0C0?n;FP030?n9F03oS5h0oh]J02P0oh]J00<0
ohaL0?n9F03oReX04@3oReX02@3oSUl0ohYI0?n;FP3oReX0ohED0?mjB@3oLdD0og];0?n:F@0:0?n;
FP80ohYI3`3oReX01P3oRET0oheN0?n>H@3oReX0oh]K0?n>G`d0oh]J00<0ohYI0?n;FP3oReX03P3o
ReX20?n:F@h0oh]J00<0ohYI0?nBIP3oRe`03P3oReX00`3oSEh0oiAW0?n;FP0=0?n;FP030?n:F@3o
SUl0ohaL00h0oh]J0P3oRUT=0?n;FP030?n9F@3oSUl0ohiP00`0oh]J00D0oh]K0?n@H`3oRU/0oi1Q
0?n9F@0>0?n;FP030?n?H03oReX0oh]J00d0oh]J00<0oh]K0?n<F`3oReX01P3oReX01P3oS5/0ohMF
0?mkBP3oN4L0ohED0?n<F`<0oh]J00<0ohmR0?n:F`3oReX03P3oReX01@3oRUT0ohaL0?n;FP3oS5`0
ohYI00`0oh]J00D0ohIF0?miB03oMDD0ogU80?n5EP0?0?n;FP030?n<G03oRU/0oh]J00h0oh]J00L0
ohYJ0?n>G@3NF3T01`8202<:1`3oEdD0ofmJ00h0ofaH00<0ofaG0?m_FP3oKeX04@3oK5P20?m^F@03
0?m/E`3oK5P0ofaH0140ofaH00<0og1K0?m]F03oK5P02@3oK5P0303oKEP0ofYC0?m[E@3oLE`0ojRP
0?oOk03oi?<0on?a06<k?`0910D0l7J20?o9fPH0ok_>0P3o_<l40?nkcP0=0?nlc`3o]<X0oifd0?nI
/@3oTjX0ohFK0?n9W`3oQih0ohRO0?n=Y03oSjD0ohVM0?mLG`020?mCD@030?mBD03oF5H0oe9A00<0
oe9A00P0oeAB0?mAC`3oF5H0oe=B0?mAD03oDU00oe5@0?mDD@<0oeEB00L0oeUF0?mCD@3oEE80oe=A
0?mLF@3oDe40ofER00D0oeEC00<0oeEB0?mED`3oFEL00P3oE5840?mED`080?mFE@3oEE<0oeEC0?mI
F@3oFUP0oeAB0?mFD`3oGE/20?mDDP0<0?mJE`3oGE`0oeME0?mED`3oEE80oeEC0?mIE`3o@T8050D5
0?1[>03oXf80oiaC0P3oWED00`3oW5@0oieF0?nME@030?nLE0030?nIC03ohLl0oooo0?l0oooo[`3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooo`40oooo
00<0ooGk0;1/F01d?b@00`1i@bT0301h@RP0MT4W07Do9P1h@RP0NT@Y07I19`1i@bT0N48X0858;`1h
@RP0MD0V07U2:080ND<Y00L0N48X08A:<P1mAB`0ND<Y07]3:@28CCD0NT@Z0080ND<Y00<0N48X07i6
;@1i@bT00P1i@bT0101h@RP0N44W07U3:@1i@bT207Q2:0<0ND<Y00L0Nd@Z07a5:`1lAB/0Md8X07U3
:@1h@RP0N44W00L0ND<Y00@0MT0U07U3:@1f@2H0N44W1`1i@bT01@1h@RP0OTH/089:<@2<DCT0O4@/
00H0ND<Y00P0MT4X07Q2:@2:Bb`0iWa30?n?D@3oSD`0ohi>0?n=A`P0oha60P3oRdD50?n<AP060=in
?`040@40000008`i9P3oKDT0og1=0P3oJdP01`3oK4P0ofY70?m/B@3oKd/0ohAJ0?n:F@3oS5/01`3o
ReX00`3oRUT0ohiO0?n;F`0E0?n;FP030?n:F@3oSUl0oh]K01<0oh]J00<0ohaK0?n9F03oReX04P3o
ReX00`3oS5/0ohUH0?n;FP0A0?n;FP0:0?n>G`3oReX0oh]J0?n<F`3oR5L0oge=0?mgA`3oNTT0ohIE
0?n<F`P0oh]J00<0ohaL0?n:F`3oReX03`3oReX00`3oRUT0ohUH0?n;FP020?n;FP030?n>G`3oReX0
oh]J00X0oh]J00<0oheN0?n:F@3oReX03P3oReX00`3oSUl0ohmP0?n:F@0=0?n;FP030?n9F@3oSf00
ohYK00h0oh]J00<0oheN0?nEI`3oRUT03@3oReX00`3oR5P0oi=V0?n=GP0>0?n;FP030?n8E`3oReX0
oh]J00`0oh]J00<0ohUI0?n>G`3oT6402@3oReX0103oRU/0ohYI0?n?H@3oREP20?n;FP030?n:F@3o
ReX0oh]J00d0oh]J00<0ohUH0?n;FP3oReX03@3oReX00`3oRe/0ohaN0?n;FP060?n;FP040?n9F03o
O4`0ogM60?moCPD0oh]J00<0ohUH0?n;FP3oReX03P3oReX01@3oSEh0ohaL0?n;FP3oReX0ohaL00X0
oh]J00L0ohaK0?n8E`3oNTX0ogE50?mkBP3oQUD0ohaK00h0oh]J00<0ohUI0?n<G@3oReX03P3oReX0
1`3oS5/0oheM0=aG>@090P4050D40?mFA@3oKeX03P3oK5P00`3oKEL0ofiI0?mbG@0A0?m/F0030?m_
FP3oLE`0ofeG0180ofaH00<0ofiI0?m`F`3oKET03P3oK5P02@3oJeD0ofeG0?n5M03o^[H0ol7;00X6
1`1i?4@0okoB0?nmd0060?nkcP030?nmd03o_<l0ok_>0080ok_>00/0okc?0?nkcP3oXKP0ohnV0?n:
X03oQid0ohBJ0?n9X03oRj40oiB/0?nJ/@020?nK/`060?nAY@3oHfL0oe9A0?mAC`3oEE@0oe5@1P3o
DU401@3oEeD0oeAB0?mBD03oDDl0oeAA00<0oeEB00L0oeAA0?mEDP3oEE80oeA@0?mMFP3oDe40ofAQ
00H0oeEC00@0oe=A0?mFE03oFUP0oe=A0`3oEE<03P3oEU@0of9Q0?mDDP3oEE<0oeYI0?mIE`3oE580
oeIC0?mIE`3oE580oeIC0?mDDP3oGE`0oeME0`3oEE<01`3oF5@0oeIC02H92@2WBBH0ojAR0?nLD`3o
W5@00P3oVe800`3oYF<0oj9O0?nLE0020?nLE0030?nJC`3o/G/0oogo0?l0oooo[`3oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooo`040?o]kP2iLf80NT<Y
07]5:`<0ND<Y00@0OTH]08A;<P1d?bD0Md8X0`1i@bT207Q2:00307I09P1g@RP0ND<Y0080ND<Y00H0
N48X08A:<P1lAB`0N48X07Y3:@1e@2H307U3:@0307U2:01h@RP0ND<Y0080ND<Y0P1h@RP207U3:@06
08=;<@1i@bT0ND<Y07U3:@1kA2X0OTH]0P1i@bT0101g@RP0N48X08E;<`24BS8707U3:@030899<01k
A2/0R4he00H0ND<Y00H0O4D[07i6;@1lAB/0MT4W0899<01f@2H407U3:@0;07Q2:@1e@BP0S4d_0;aU
=P3NNT40o8M50?j:B03oRTT0oXU70?b8A@3oSDP01`3oS4H00`3oSDL0ohm:0?n<AP050?n<AP0<0?j?
B029BB@01P<100T30P3IGCl0ofe:0?m[A`3oK4T0ogA>0?n0EP3oQEP0ohaM303oReX00`3oRe/0oh]J
0?n;F`0E0?n;FP030?n<G@3oRUT0oh]J0140oh]J00@0oh]K0?n<F`3oRe/0oh]L4@3oReX00`3oRe/0
ohaL0?n=G@0F0?n;FP070?n<F`3oQ5<0ogY90?mhA`3oO4`0ohMF0?n<F`070?n;FP030?n<G03oRUT0
oh]J00l0oh]J00<0ohaL0?n=G@3oReX00P3oReX00`3oS5/0ohYI0?n;FP0:0?n;FP030?n?H03oRUT0
oh]J00d0oh]J00<0oh]K0?n;G03oRUX03P3oReX00`3oRUT0ohaM0?n;FP0>0?n;FP030?n8E`3oReX0
oh]J00`0oh]J00<0ohQH0?nCIP3oSEh03P3oReX00`3oR5L0oh]J0?n;FP0<0?n;FP030?n:FP3oS5`0
oheM00D0oh]J00D0oheM0?n;FP3oSUl0ohYI0?n<G@040?n;FP030?n>G`3oS5`0oh]J00h0oh]J00<0
ohiO0?n;FP3oReX03@3oReX00`3oSEh0ohYI0?n;FP040?n;FP060?n<F`3oQeH0ogU90?mgAP3oOdh0
ohYI0`3oReX00`3oRe/0oheM0?n<F`0>0?n;FP030?n;F`3oS5`0oheL00@0oh]J00<0ohaK0?n;FP3o
ReX01P3oReX01@3oQE@0oge<0?mhA`3oO4/0ohIE0140oh]J00<0ohYI0?n;FP3oReX03P3oReX01`3g
P5@0Kb`L00<1000G1`D0bT`m0?m_FP3oKEP03@3oK5P00`3oKET0ofiI0?m^F@0@0?m/F0040?m]F@3o
KeX0ofmK0?m]F140ofaH00@0ofeI0?m_F`3oL5/0ofaG3`3oK5P20?m^F@080>5C@P24:R008@P60248
203YKGP0okk>0?nlc`3o_M040?nkcP0>0?nlc`3o^ll0okc?0?njc@3o]/X0ok;50?n_``3oX[H0ohRO
0?n:X03oS:80oi:Y0?nG[`3oVk850?nJ/@050?nK/P3oVK40oi2S0?mlR@3oGV001`3oDU401@3oDe40
oeEC0?mGE@3oFEP0oe=A00<0oeEB00L0oeAA0?mED@3oEE80oeEB0?mDD@3oEE80oeE@00H0oeEC00D0
oeiM0?mED`3oEU@0oeME0?mEE0020?mED`080?mFE03oEeL0oeEB0?mED`3oFUT0oeYH0?mDDP3oEU<2
0?mED`80oeIC00/0oeQF0?mJE`3oEU@0oeeK0?mDDP3oEE<0oeeJ02h<3027?1l0oiaB0?nLD`020?nL
E0030?nNE@3oY640oj1J00<0oiaD00@0oiiG0?nKD@3o_Hh0ooclo`3ooon^0?ooo`040>WYj@3AdM40
dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWioh0oooo00D0oo_n0<YoL@1R<Q@0RTlf
07a5:`0307U3:@050818;`25Bc<0MT4V07i6;@1i@bX00P1i@bT0101nABd0O4D/07<n901h@BL407U3
:@0507E09P1g@RL0NdDZ07U3:@1e?bH00P1i@bT00`1h@BL0Qdde07a5:`0307U3:@0907M19`1i@bT0
ND<Y07U3:@20Abh0N48X07]4:P1i@bX0ND<X0080ND<Y00<0MT4W07Q2:01i@bT00P1kA2X607U3:@05
07I19`2?E3`0O4D/07m6;@1i@RP00P1i@bT0101i@RP0ND<Y07a4:P1lA2X207U3:@0407Q2:029CcH0
OTH]07Q2:080ND<Y00D0LT0W07m8;@2WG3D0kh930?n:A`020?f8AP050?f9B03oRd`0nhM50?f8AP3n
RTP01`3oS4H00`3oSdX0oh]50?n<AP050?n<AP090?n=A`3oRdD0G34G0000001k<R80ogE>0?mjDP3o
PeH0ohmN0100oh]J00@0ohYI0?n>G`3oS5h0ohYI5@3oReX00`3oReT0oh]J0?n;FP0A0?n;FP80ohYI
00<0ohaK0?n;FP3oReX0403oReX00`3oRE/0oheM0?n;FP0A0?n;FP0<0?n;F`3oRET0oh]J0?n;FP3o
S5/0ohYI0?n0D03oNDP0ogQ70?n3DP3oReX0ohaK1P3oReX00`3oS5/0oheN0?n;FP0?0?n;FP080?n=
G@3oRU/0oh]J0?n;FP3oRe/0oh]J0?n;F@3oRU/90?n;FP030?n7E`3oSUl0oh]J00d0oh]J00<0ohYI
0?n@HP3oSf003P3oReX00`3oRET0oiEW0?n;F`0?0?n;FP030?n;F`3oReX0oh]J00/0oh]J00<0ohYI
0?nAI@3oS5d03P3oReX00`3oR5L0oh]J0?n;FP0=0?n;FP080?n9F03oRUT0oh]J0?n:F@3oREP0ohiO
0?n:F@3oTF<80?n;FP030?n>H03oSEd0oh]J00d0oh]J00<0ohYI0?n:F03oReX03@3oReX00`3oRU/0
ohUI0?n;FP040?n;FP060?n<F`3oReX0ogY90?mhA`3oPe80ohYK103oReX00`3oS5`0oh]L0?n;FP0>
0?n;FP030?n:F@3oSf00ohYI00@0oh]J00@0oh]K0?n>H03oS5/0ohYI0P3oReX01`3oR5X0ohaK0?mo
C`3oMTD0ogI60?moD03oRe/04@3oReX00`3oSEh0oh]J0?n;FP0=0?n;FP070?n9FP3oTf00R3DR0000
000`3P/0oeU70?maF`0>0?m/F0030?m]F@3oKeX0ofaH0140ofaH0P3oKUTA0?m/F0030?m/E`3oKeX0
ofmJ0140ofaH00<0og5K0?mcG02b=b/00P0000003P0l3@`0kT=20?mGE03oGUh0ogj50?n``@3o`M@0
okc?0?nkcP3o_<l0okW<0?ndb03o/LD0oj^o0P3oY[T0203oZkh0oiV_0?nE[03oV[40oi^c0?nK/P3o
Vk<0oibd203oV[401@3oVk<0oiJ[0?mXL`3oEeH0odm=00L0oe9A00<0oeEB0?mGE@3oEE<00P3oEE80
203oE540oeA?0?mEDP3oEE80oeYH0?mGE03oE500oeAB1@3oEE<01P3oFEL0oeEC0?mDDP3oGeh0oeAB
0?mIE`<0oeEC00<0oeID0?mED`3oEE<00`3oEU<0203oEeD0of1O0?mCD@3oEU<0oeAA0?mCD@3oFUL0
oeAB0P3oEE<01@3oGEX0=0h=05/X503oWEH0oj1J0080oiaD00<0oi]C0?nNF03oVe<00`3oW5@0103o
WeP0oimI0?nJCP3oaYoo0?ooojh0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWoP3oool01@3ofML0LchT07Q1:022BS00O4@Z00<0ND<Y00@0Nd<Z07]4:P1lABX0
Nd@Z0P1i@bT01P1h@RP0Qd`d0859;`24BS80O4D/07Q2:080ND<Y00H0MD0V078m8`1jA2T0ND<Y07U2
:01e@2H207U3:@0307I19`2?E3`0ODD/00<0ND<Y00P0Md4W07U3:@1i@bT0ND<Y07E09P1i@bT0PDP_
07]4:P<0ND<Y00D0MClU07U3:@1h@BL0MClT07Q2:00607U3:@0407I19`2?Dc/0NT<Z07Do9P80ND<Y
00@0N48X07m7;@1lABX0NdDZ0`1i@bT02P1h@RP0R4lf07a5;01h@RP0ND<Y07A1:02UGCP0f7Dn0?n:
B03nRTL30?f8AP060?j:B03kQd@0oHQ60?f8AP3nRTT0ohY31P3oS4H00`3oS4L0oh]50?n<AP060?n<
AP080?nICP2SFBX01P<103PG3P3oO580oiES0?n;FP3oRUXB0?n;FP030?n=G`3oS5/0oh]J01<0oh]J
00@0ohUI0?n:F@3oSUl0oh]K4P3oReX00`3oRET0oh]J0?n;F`0A0?n;FP030?n9F@3oS5d0ohYK0140
oh]J00<0ohaM0?n<GP3oRUT0103oReX01P3oQE@0ogQ70?mgAP3oOTh0ohQG0?n<F`H0oh]J00<0oheN
0?n;F`3oReX03P3oReX00`3oS5`0oh]J0?n;FP020?n;FP80ohYI00<0ohaK0?n;FP3oReX01`3oReX0
0`3oRU/0oh]L0?n8F00>0?n;FP80ohYI7P3oReX00`3oRUT0ohaN0?n=GP0=0?n;FP030?n8F03oTfH0
oheN00h0oh]J00<0ohQG0?n;FP3oReX0303oReX02@3oRUT0ohIE0?n:F@3oRe`0ohiQ0?n:F@3oSUh0
oh]J0?n:F@070?n;FP030?n:F@3oREP0oh]J00d0oh]J00<0ohYI0?nBI@3oRe/03`3oReX00`3oSEd0
oh]J0?n;FP040?n;FP050?mmC@3oN4L0oh=B0?n<F`3oRU/00`3oReX00`3oRUT0oheM0?n:F@0?0?n;
FP030?n<F`3oRUT0oh]J00D0oh]J00`0ohQJ0?n>G`3oS5/0oh]J0?n<F`3oREP0ogm?0?mfAP3oNDP0
ohAC0?n<G03oRU/@0?n;FP030?n?H03oRU`0ohYI00d0oh]J00L0ohYJ0?nDH@3mHd004PH4038>2`3o
FTL0ogEN00h0ofaH00<0ofiH0?m]F03oKEP0403oK5P0103oKeX0og1K0?m]E`3oKEP@0?m/F0040?m]
E`3oKET0og9M0?m]F0l0ofaH01H0ofeH0?mcG03oIe40[S@X00l40`000000SB8P0?m7AP3oFeX0oeIE
0?mCDP3oCd`0ofe`0?nR/03o`=<0okoB0?nbaP3o[;l0ojRk0?nW^P3oY;L0ojg20P3o//H00`3oWkH0
oi^c0?nJ/@030?nJ/@030?nI/@3oV[40oiZa00H0oiZa00H0oi^c0?n>Z03oQ9l0ogN90?mOIP3oDe05
0?mBD@0>0?mAD03oDU00oeiL0?mFD`3oEU40oe=A0?mFD`3oFeT0oeIA0?mEDP3oFEL0oeID0?mEDP3o
DDl50?mED`80oe9@00P0oeAB0?mNG03oDe40oeIE0?mHEP3oEE<0oeUG0?mOGP<0oeAB0P3oEU<0103o
F5D0oeiM0?mCD@3oEU<20?mDDP090?mFDP3oEE<0oe=A0?mED`3oG5T0?Pl?02hC2@3oWEP0ojET00<0
oiaD00<0oi]B0?nMEP3oW5@00P3oW5@01@3oWeL0oimH0?nLD`3oWeT0oo[h0?l0oooo[@3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOn0?ooo`050<RRV01`?280
MT0V08M<=01lAB/00`1i@bT00`1i@RP0MD0T07Q29`0307U3:@0>07Q2:022BC00ODD/08mE?01oAbh0
N48X07U3:@1h@RP0PDP_08I;=01jA2X0ND<Y07Do9@1i@RP207U3:@0307Q2:@1lA2/0NT@Z00<0ND<Y
00P0MT0V07U3:@1i@bT0ND<Y07U2:01nARd0O4D[07Q2:0<0ND<Y00D0MClU07U3:@1nAR`0OdL^07Q2
:@0607U3:@0307I19`2?Dc/0OdH]0080ND<Y00D0N48X07e5;01i@bT0Nd@Z07Q2:00307U3:@0907Q2
:021B300N48X07Q1:@1e@2P0/f8h0?R7A`3oS4H0ohY700@0oHQ600<0ohe<0?f8A@3mR4H00P3mR4H0
0`3oST/0oha60?n<AP030?n<AP030?n<A`3oST/0oha600L0oha600L0ohi70?N5@@108Q000@0005<P
503oHcl0oi=Q01@0oh]J00<0ohaL0?n;G03oRUT04`3oReX00`3oRUT0ohYK0?n=G@0C0?n;FP030?n:
F@3oS5/0oh]J0180oh]J00<0ohmP0?n;FP3oReX0403oReX00`3oS5`0oh]J0?n;FP030?n;FP060?n<
F`3oPe80ogM60?mgAP3oNdX0ohUH1`3oReX00`3oRe/0oh]J0?n;FP0>0?n;FP030?n@H@3oRe`0oh]J
00<0oh]J00<0ohUH0?n<G@3oReX0203oReX00`3oRUT0oheN0?n;FP0=0?n;FP030?n8F03oTV@0ohaL
00h0oh]J00<0ohYI0?n<G03oReX0303oReX00`3oRUT0ohmP0?n>H00=0?n;FP030?n8F03oTfH0oheN
01d0oh]J00H0oh]K0?n?HP3oSEh0oh]J0?n;GP3oRe/90?n;FP030?n9F@3oRe`0oh]L00l0oh]J00<0
ohaK0?n;FP3oReX0303oReX00`3oRU/0ohiO0?n;FP040?n;FP040?n:F@3oOTh0ogM60?mlC080ohaK
103oReX00`3oS5/0ohaM0?n;FP0>0?n;FP030?n=G@3oS5`0oh]J00P0oh]J00T0ohiO0?n;F`3oQUD0
og]:0?mgAP3oNTX0ohMF0?n9F03oRUT0403oReX00`3oSEh0ohYK0?n9F@0=0?n;FP070?n:FP3oUF80
nV=002H>200I1`H0oe]80?mdG@0>0?m/F0030?m`F`3oKeX0ofeG0100ofaH00<0ofiI0?maG03oK5P0
4P3oK5P00`3oKeX0og1K0?m]F@0@0?m/F0080?m`FP3oDCl0D1HA0000000J1PD0l3Th0?mFE03oFUT3
0?mGE@0=0?mEE@3oDe40oeQH0?mXK@3oQi40ojbo0?nV^@3oYkX0ojg00?nbaP3o^Ld0okkB0?nba`05
0?nJ/@030?nI/@3oWK@0oije00L0oiZa00L0oi^c0?n5X03oP9`0ohJQ0?moV@3oIF`0odm<00@0oe9A
00T0oe5@0?mHE`3oH5h0oe=A0?mCD03oFeL0oeME0?mRH@3oE500103oEE800`3oEU<0oeEC0?mED`03
0?mED`0=0?mFE03oFEL0oeAA0?mNG@3oDe40oeEC0?mFE@3oEE<0oeQF0?mLG03oE580oeEC0?mED@03
0?mFD`050?mDDP3oEU<0oeIC0?mFD`3oDe400P3oEE<01`3oEeD0oeEC0?mKF@1<4a<02`D20?nOF03o
XUl00`3oW5@00`3oVU40oimH0?nLE0020?nLE0050?nNF03oWeP0oi]B0?nLDP3og/H0o`3ooon]0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiod0oooo00H0onCT
08]@>@1h@RP0ODD/095D?01mAB`407U3:@030818;P1mABd0ND<Y00<0ND<Y00T0N44W07U2:02=DST0
OdL^07U2:01i@bT0NT<Y0899<021B2l00P1i@bT01P1e?bD0ND<Y07U3:@1i@bT0NT@Y07Q2:0<0ND<Y
00L0N48W08M<=@1f@BL0ND<Y07i6;@22BBl0NT@Z00D0ND<Y00D0OTH]07U3:@21B300QT`c07Q2:006
07U3:@0507M19`2=DSX0PdXa07U3:@1nAR`00P1jA2X607U3:@0707Q2:@1nAR`0UE4_0;eW>P3UNd00
o8U60?j:AP050?f8AP030?j9A`3nRTL0oHQ600<0oHQ600<0oXY80?n=BP3oS4H00`3oS4H00`3oSTT0
oha60?n<AP040?n<AP0=0?n=A`3oTDT0oj=C0?nfG03o^e/0ok1E09eP;P0B2@@03@D305XS5`3FJ4@0
oheL0?n<F`0B0?n;FP040?n=G@3oRe/0ohaL0?n;Fa<0oh]J0P3oS5`00`3oRUT0oh]J0?n;FP0@0?n;
FP030?n:F@3oReX0ohaK0180oh]J00<0ohaM0?n;G03oReX03`3oReX00`3oS5/0ohaL0?n;FP040?n;
FP080?n<F`3oR5L0oh5@0?miB03oNdX0oh=C0?n9F03oS5/40?n;FP030?n<G03oRU/0oh]J00l0oh]J
00<0oheN0?n;F`3oReX00`3oReX00`3oS5`0oh]M0?n;FP070?n;FP030?n;F`3oS5`0oh]K00h0oh]J
00<0ohYI0?n=G03oReX03P3oReX00`3oSUl0oh]J0?n;FP0<0?n;FP80oh]K3P3oReX00`3oS5d0ohaK
0?n;FP0<0?n;FP030?n:F@3oUVT0ohaK00P0oh]J00<0oh]K0?n;FP3oReX00P3oSEd00`3oSV40oi9V
0?n;F`0<0?n;FP030?n:F@3oSF00ohmR00h0oh]J00<0ohmQ0?n<G03oReX03@3oReX00`3oRUT0oheM
0?n;FP030?n;FP050?n9F03oO4`0ogQ70?mlB`3oR5P01@3oReX00`3oRe/0oheM0?n;F`0?0?n;FP03
0?n<G03oReX0oh]J00L0oh]J00T0ohaK0?n9F@3oOe00ogQ70?miB03oP4l0ohUI0?n>GP3oS5/0403o
ReX20?n<F`h0oh]J00L0ohaK0?j4E`2==b<04PH400T30P3<C3d0ofmJ00h0ofaH00<0ofmJ0?m_F@3o
KEP0403oK5P20?m^F@030?m]F@3oK5P0ofaH00l0ofaH00<0ofeH0?m`F`3oK5P03`3oK5P0403oKET0
ofeH0?mTC`24<2H03@@301@4101`6QT0gTE40?mIF03oF5H0oeME0?mFE03oDDl0odi<0?m;B@3oAT@2
0?m3@@090?m8A`3oHV@0oi2M0?n]_@3o^L`0okkA0?nlc`3o]LT0oife00L0oiZa00<0oiVa0?nJ/@3o
V[40103oV[402`3oVk<0ohbV0?n4W`3oRjD0ohBO0?n5W`3oPid0ogJ90?mWL@3oFE/0oe=B0080oe9A
00d0oe=A0?mKF@3oE580oeEB0?mFD`3oEe@0of1N0?mCD@3oEE80oeAB0?mLF03oEe@0of=Q00D0oeEC
00@0oeME0?mOGP3oEE80oeUG0`3oEE<01`3oEE@0oeID0?mDDP3oE580oeEC0?mFD`3oEE<00P3oEU<0
3P3oEeD0oeQE0?mED`3oEU<0oeQG0?mED`3oEeD0oeaI0?mEDP3oFEL0K1/K00`50@3oPdD0oiiD103o
W5@02@3oWEH0oiaE0?nLE03oW5@0oiiF0?nRG`3oWUL0oiaC0?nfPP3o0?ooojd0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo03oool01`3ol_P0V5Y507U3:@1h
@BL0Qd`d09EI@01lA2/00P1i@bT01@1i@bX0R4hf08U==P25BS<0N48X0080ND<Y00X0ND8X07Q2:01h
@RT0SU<j07m7;P1h@RP0ND<Y0899<01f@2H0MT4W0P1i@bT01P1h@BL0ND<Y07U3:@1f@BL0Re0h08A:
<P<0ND<Y00H0N48W08Q==P1f@BL0PDP_07]4:P1f@BL607U3:@04095E?@1i@bT0MT0V07I19`L0ND<Y
00@0MT4W08mC>`1lAB/0OTH/1`1i@bT0101h@RP0MT4Y0858;03<KSP20?j9APP0oHQ600<0oXU70?j:
B@3mR4H0103mR4H01P3nRDH0ohe80?n<AP3oS4H0oh]50?n@CP<0oha600D0oh]50?n=B03oU4T0ojmM
0?njF@040?nkF`090?nnF`3oZe<0MShL00h60`080`40^dT_0?n3E@3oSUd0ohaK0180oh]J00<0ohUH
0?n=GP3oReX0503oReX00`3oS5/0ohQG0?n;FP0C0?n;FP030?n<G@3oReX0oh]J0100oh]J00<0ohUH
0?n<F`3oReX03`3oReX00`3oRET0ohmP0?n;F`060?n;FP060?n:F@3oODd0ogE60?miB03oPe80ohaK
103oReX00`3oS5/0oh]J0?n;FP0>0?n;FP030?n:F@3oS5h0oh]J00@0oh]J00<0ohYI0?n>G`3oReX0
1`3oReX00`3oRe`0ohaL0?n;FP0=0?n;FP030?n:F@3oS5h0oh]J00h0oh]J00<0ohYI0?n;FP3oReX0
3@3oReX00`3oREP0oh]J0?n;FP0<0?n;FP030?n9F03oReX0oh]J00`0oh]J00<0ohYI0?nFJP3oS5/0
1`3oReX0103oRe/0oi5S0?n?H@3oR5L20?n;FP030?n:F`3oSf00ohYJ00d0oh]J00<0ohUH0?n:F@3o
ReX03@3oReX00`3oR5L0ohYI0?n;FP0<0?n;FP030?n:F@3oSf80oh]J00@0oh]J00<0oga<0?mhA`3o
Odl01P3oReX00`3oRUT0ohaL0?n:G00?0?n;FP030?n>G`3oReX0oh]J00H0oh]J00X0ohaK0?n;FP3o
Pe80ogU80?mhA`3oO4l0ohQI0?n;FP3oS5/0ohYI3`3oReX00`3oRUT0ohYH0?n9F00>0?n;FP070?n<
F`3oT5h0RC@R0000000F1PD0oTln0?m]F@0>0?m/F080ofmJ403oK5P00`3oKUT0og1K0?m/E@0A0?m/
F0030?m^F@3oKeX0og1K0100ofaH0180ofmJ0?mZE02o>Bd03P<200L20@1f6AT0odU90?mJF@3oEeH0
oeEC0?mBD03oBdT0odE30?m3@@3oA480odE30?m:B03oE5830?mGE@070?mEE03oDU40ofia0?nV]@3o
]//0oj>j0?nI/@060?nJ/@030?nI/@3oW[D0oibc00@0oiZa00H0oifd0?n?Z03oPId0ohBO0?n0W03o
PId40?n4W`060?n1V`3oI6`0oe=A0?mAC`3oDU40oeIC0`3oEE80203oEe@0ofAR0?mGE03oDe40oeAB
0?mOG@3oEU@0ofAQ1P3oEE<00`3oDU00oeAB0?mDDP040?mED`0G0?mDDP3oEeD0oe]H0?mED`3oHV80
oeQF0?mFD`3oEE<0oeaK0?mNG@3oE580oeEC0?mUH`3oEe@0oeEC0?mBD03oF5H0oe]H08`S8P080`00
og4k0?nOF03oWEH00`3oW5@02P3oWeP0oiaD0?nOFP3oW5@0oi]C0?nQGP3oWUP0oiaD0?nNE`3oflCo
0?oooj`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo03o
ool01P3]VY00ND8X07U3:@1f@BL0QT`e089:<080ND<Y0140N44W07Do9@22BC40RDdf08A:<P1h@RP0
ND<Y07Q2:022BC00S58i07I19`2?E3/0OdL^07Q19`1kA2X0MT4W07Do9@0307U3:@0608aA>01i@bT0
ND<Y07Q19`25Bc<0PDP_0`1i@bT01P1h@RL0QD/c07i7;01lAB`0MClU07Q2:0H0ND<Y00<0TEDm07U3
:@1i@bT0201i@bT00`1i@RP0RE0g07e5;00707U3:@0607Q2:@1iA2T0VEDa0=Yg@03lR4H0oHQ5403m
R4H02`3nRDP0oh]:0?n<AP3oS4H0oha70?n;A@3oS4H0oh]50?n:A03oSdX0oj9C0080okaK1P3o^e/0
203o_E`0ol1M0>=h>P0G30D0000006@W603oJdH0ohiM4`3oReX00`3oS5`0ohaJ0?n:F@0D0?n;FP03
0?n:F@3oS5`0ohUI0180oh]J00<0oheM0?n;FP3oRET04@3oReX20?n:FA00oh]J00<0ohYI0?n<G@3o
ReX01P3oReX01P3oREP0og]:0?mgAP3oMTD0oh=B0?n<F`80oh]J00@0ohYJ0?n=GP3oSEh0ohUI3`3o
ReX00`3oS5h0oh]K0?n;FP040?n;FP030?n;F`3oSf00ohYJ00H0oh]J00<0ohUI0?n<G03oReX03P3o
ReX00`3oRUT0oh]J0?n;FP0=0?n;FP030?n?H03oReX0oh]J00d0oh]J00<0ohiO0?n9F@3oReX0303o
ReX00`3oREP0oh]J0?n;FP0<0?n;FP030?n:F@3oUVX0ohaK00<0oh]J00H0ohYI0?n;G03oRU/0ohUH
0?n?H03oRUT50?n;FP030?n8E`3oReX0oh]J00/0oh]J00<0ohaL0?n>G`3oReX0303oReX00`3oRUX0
ohaO0?n=GP0>0?n;FP0:0?n<G03oREP0oh]J0?n;FP3oR5X0ohaK0?n3DP3oN4L0oge=0?n:F@H0oh]J
00<0oh]K0?n>G`3oRET03P3oReX00`3oRe/0oheN0?n;F`070?n;FP090?n:F@3oOTh0ogM60?mgAP3o
P4l0oh]J0?n<G`3oRe/0oh]L0140oh]J00<0ohaK0?n;FP3oReX0303oReX0203oS5/0oi1N0?5O?@0>
1@<08@X70?m@?`3oKeX0ofeI303oK5P00`3oKEL0ofeI0?maG00A0?m/F0030?mbG@3oK5P0ofaH0100
ofaH00<0ofiH0?mbG@3oKUT0403oK5P00`3oLE/0of=>05`K4`020000000=08XO7`3oF5H0oeUG0?mE
D`3oD4h0odA30?m3@@3o@T00odE30?m8AP3oC4X0oe=A0?mHEP060?mGE@060?mED`3oGEd0ohNB0?nC
Z03oWK@0oi^c1P3oV[400`3oVk<0oiZa0?nJ/@020?nJ/@040?nK/`3oUk00ohRR0?n3WPP0ohBO00H0
oh:L0?mXL@3oEEH0oe1>0?mHE@3oDe420?mEDP080?mED`3oFED0oe=?0?mFD`3oEeD0oe9>0?mEDP3o
IF880?mED`030?mDDP3oEE<0oeEC0080oeEC00l0oeAB0?mKF03oH5l0oeID0?mQH@3oF5H0oeIC0?mE
D`3oF5H0oeYH0?mDDP3oEU<0of=Q0?mGE03oEE<00P3oE5801P3oFEL0UC4a00800031DRT0oj=L0?nP
F`80oiaD00H0oiaC0?nQG03oW5<0oiaD0?nMEP3oW5<20?nLE@040?nLE03oVU40oja`0?ockol0oooo
Z`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOk0?ooo`03
0?oBe@1oB2h0MT0V00<0ND<Y01D0MClU07U2:@1i@bT0O4D/07U4:@1kA2X0RTlf08A9<P1h@RP0ND<Y
07Q2:022BC00SU8i07I19`2;DCP0O4D/07Q29`1jA2X0O4@[07i5;@1h@RT00P1i@bT01P2AECh0ND<Y
07U3:@1i@bT0N48X07U2:0<0ND<Y00H0N48X0818;`1h@bP0N48X07i6;@1j@bX607U3:@0408mD?01l
AB`0Re0g07I19`H0ND<Y00@0O4D[07i6;01lAB/0QD`b1P1i@bT01`1f@BP0P4P/0;iZ>`3bPd@0oh]>
0?R7B@3mRDL0203mR4H00`3nRDL0ohe=0?f8AP070?f8AP090?n<A`3oRT@0oi5=0?n=B03nRdD0ohi:
0?nIC`3o[5P0okeL00T0ok]K00P0okeL0?o5H@2iKC@00`000000000H1`@0i6U40?nAGa<0oh]J00<0
ohaK0?n:F03oS5`04`3oReX0103oRUT0oheN0?n;FP3oRUTB0?n;FP030?n>G`3oR5X0ohUI0100oh]J
00<0ohaK0?n:F@3oReX0403oReX00`3oRe/0ohQH0?n;FP050?n;FP0<0?n<F`3oREP0ogi>0?mhA`3o
MTL0ohED0?n;FP3oS5/0oh]J0?n:F@3oS5/0oh]K3`3oReX00`3oRUT0ohaL0?n;FP050?n;FP030?n:
F`3oSEd0oh]J00H0oh]J00<0ohaL0?n;FP3oReX03@3oReX00`3oSEh0ohYK0?n;FP0=0?n;FP030?n>
G`3oRUT0oh]J00`0oh]J00<0ohYI0?nAI@3oR5P03@3oReX20?n:F@d0oh]J00<0ohYI0?nFJP3oS5/0
0P3oRUT01@3oRU/0ohaL0?n>G`3oS5`0ohYI00H0oh]J00<0ohQG0?n:F@3oReX0303oReX00`3oSf40
oi=V0?n:F@0<0?n;FP040?n:F@3oSf40ohiO0?n:F@`0oh]J00@0ohYI0?n?HP3oRU/0oh]J0P3oS5/0
103oQ5<0ogU80?mjB@3oRUT60?n;FP030?n:FP3oRe/0ohaK00l0oh]J00<0ohiO0?n:F`3oReX01@3o
ReX01P3oS5/0oh]J0?n0C`3oLT@0ogQ70?mnCP80oh]J00<0ohYI0?n>H@3oSEh0403oReX00`3oSUl0
ohYK0?n;FP0<0?n;FP080?n<F`3oTF00kehl01X91@0B1P@0oe0o0?maF`3oKET<0?m/F0030?m]F03o
KEL0og1K0140ofaH00<0ofmI0?m/F03oK5P04@3oK5P00`3oKe/0ofmJ0?m/F00>0?m/F0040?m]F03o
M5d0ofYD06HO6080000000D0LA/K0?mAD03oDU00oda:0?m7A@020?m3@@030?m6A03oBDL0oe1>0080
oeQF00<0oeMF0?mGE@3oEeD01P3oEeD01P3oF5H0oe5?0?mUJ@3oPi80oibc0?nK/`/0oiZa00L0ohjW
0?n1W@3oQ9l0ohBO0?n5W`3oSZL0oh>N00@0ohBO00H0ohFO0?n6X@3oNHd0of9W0?mDD@3oDe420?mE
DP080?mDDP3oDdl0oeEB0?mCD@3oF5@0oeEC0?mCD@3oFEL60?mED`040?mIE`3oHF00oe=A0?mCD@@0
oeEC00D0oeED0?mFE03oEeD0of1O0?mGE@020?mFD`0?0?mDDP3oEE00oeAB0?mED`3oIfD0oeMD0?mE
D`3oFeT0oeeK0?mCD@2]>CP00P0009e48P3oXe/0oj1I0080oiaD00@0oiaC0?nQG03oXeh0oiaD0P3o
WED01P3oV4h0oiaB0?nLE03oW5@0oiY?0?oLaOl0ooooZ`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOj0?ooo`030?o]k@2LGDL0M3lT0080ND<Y00/0N44W07I0
9@1g@2H0ND<Y07a5:`1kA2/0ND8X07I09P2<DCT0QDXc07Q2:00207U3:@0:07Y3:@1kA2X0NT<Z07Q2
9`1jA2T0NT@Z07U3:@22BC00RTlg07M2:080ND<Y00H0T5Dl07U3:@1i@bT0NT@Z07U3:@1h@RT207U3
:@0707a5;01j@bX0Qdde07I19`1h@RP0SE<i07]4:P0607U3:@04091E?01kA2/0PDP_07Q2:0H0ND<Y
00@0O4DZ07]4:P1d?R@0OTH]101i@bT02P1c@2L0PDH[0:ML=P3MMcl0n8I40?J3@`3ePd<0mXE60?J5
@`3lR4L60?f8AP030?f9A`3nRTT0oXU600L0oHQ600T0oHQ70?n<B03oST`0oh]60?nDC03oYE<0okEH
0?nmGP3o_5/0303o^e/01`3o`5h0k9e=09YM;0128a0070/7094k9P3TLd/00P3oS5/B0?n;FP030?n=
G@3oS5`0oh]J01<0oh]J00<0ohaM0?n=G@3oRUT04P3oReX20?n<G@030?n;F`3oReX0oh]J00d0oh]J
00<0oh]K0?n<F`3oRe/0403oReX0103oS5/0oheO0?n<G03oRUX50?n;FP070?n<F`3oReX0ohQG0?mn
C@3oMdH0og];0?n2D@030?n;FP030?n=GP3oS5/0oh]J00h0oh]J00<0ohaM0?n:F@3oReX01@3oReX0
0`3oS5/0oh]K0?n;F`050?n;FP030?n=G@3oRe`0oh]J00d0oh]J00<0ohaK0?n<G03oReX03P3oReX0
0`3oS5`0oh]J0?n;FP0<0?n;FP030?n=GP3oReX0oh]J00d0oh]J00<0ohYI0?n;FP3oReX02`3oReX0
1`3oRUT0oiAW0?n<G03oSf00ohaM0?n;FP3oS5`0203oReX00`3oRe/0oi1Q0?n:FP0=0?n;FP030?n9
F@3oRe/0oh]J00`0oh]J00<0ohaL0?n<G@3oRUT03@3oReX02@3oS5d0oh]K0?n;FP3oReX0ohUI0?mn
C@3oMdH0ogU80?n8E`070?n;FP030?n=G@3oRed0oh]J00d0oh]J00<0oh]K0?n=G@3oRUX01@3oReX0
3`3oS5/0ohUI0?n3DP3oO4/0ogU90?n0C`3oR5L0oh]J0?n<F`3oRUT0oheM0?n;FP3oSEh0ohYK0?n:
FP0<0?n;FP030?n:F`3oSUh0oh]K00d0oh]J00P0ohYJ0?n5E`21<b0030D301861039B3T0og5K0?m^
F@`0ofaH00<0ofeI0?m]E`3oKET03`3oK5P00`3oKET0ofiJ0?m]E`0A0?m/F0040?m]F03oKe/0ofmJ
0?m^F@h0ofaH0180ofeH0?m^F@3KED@0TblU03HA3@0P1`L0VRDS0>@m?03oBTP0odM50?m4@P3oAT@0
odU70?m>C03oE580oeEC0?mGE@3oF5H70?mGE@0=0?mGEP3oEeD0oeUG0?mIE`3oEeH0oeME0?mED`3o
EE@0ofM/0?n5U@3oUJT0oibc0?nK/P030?nJ/@060?nL/`3oV[40oiZa0?nJ/@3oUZl0oh>N0`3oQ9l0
0`3oQIl0oh>O0?n2WP060?n4W`090?n5X03oQIh0og:30?mLG@3oEe40oeEA0?mEDP3oDe40oeIB0080
oeEB00<0oeMD0?mLFP3oD4h01P3oEE<0103oEU@0oeQG0?mGEP3oFEP40?mED`0F0?mDDP3oEU<0oeID
0?mIE`3oEU<0oeEB0?mFD`3oEE<0oe]H0?mJF03oEU<0oeMD0?mFE03oEE<0oeaJ0?mLF`3oE580ZcPe
0000000l6Ph0oj=H0?nLD`<0oiaD00`0oj5M0?nSH@3oW5@0oieD0?nNE@3oXel0oj1I0?nME03oW5@0
oiaB0?n[K`3ok^Go0?ooojX0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWnP3oool00`3J[JH0JcHJ07U3:@0207U3:@0B07m7;P1nAR`0MT0V07]4:P1i@RP0N48X
07i6;@1oAbh0Q4Xb0857;`1i@RP0ND<Y07Q2:01f@2D0ND<Y07a4:`1i@bT0N44W0`1i@bT01`1h@RP0
ND<Y07U3:@1i@bT0Se@l07U3:@1i@RP00P27C3@01P1h@BL0ND<Y0858;`1kA2X0N48X07]4:P80N48Y
00<0N44W07U3:@1i@bT01@1i@bT00`2AECh0Md4W07Q2:00407U3:@0707I19`1oAbd0Nd@Z07U3:@1i
@bX0M3lS07Q29`0307U3:@0<07Y3:P2eHSL0iWa10?^7A@3gQDD0m8=30?Z8BP3kRD`0m8=30?b:C`3e
QDD0nhM41P3mR4H00`3oSTd0oHQ60?f8AP070?f8AP050?b8A@3oXUL0ojmG0?njG03o_E/04@3o^e/0
1`3oaF40ok=H07Po7P00000020<106dZ6`3oPUD0:03oReX0103oRET0ohYK0?n<G03oRUTA0?n;FP03
0?n:F@3oReX0oheM0140oh]J00<0ohQJ0?n=G@3oRUT0403oReX00`3oRU/0ohaK0?n;FP070?n;FP09
0?n:FP3oPE40ogU80?mgAP3oO4`0ohYI0?n8FP3oRUT0ohaL00l0oh]J00<0ohaK0?n@H@3oRUT01P3o
ReX0103oRU/0ohUI0?n<F`3oRe/40?n;FP030?n<G`3oRe`0oh]J00d0oh]J00<0ohmP0?n;FP3oReX0
303oReX00`3oRe`0oi9W0?n:F@0=0?n;FP80ohYI3P3oReX00`3oREP0oh]J0?n;FP090?n;FP060?n:
F@3oTVD0oh]J0?nBIP3oS5`0ohYI2`3oReX00`3oRU/0oiAY0?n9F@0<0?n;FP030?n;F`3oT640ohYI
00h0oh]J00<0oh]K0?n;FP3oReX0303oReX0203oS5/0oh]J0?n;FP3oReX0oh1?0?mfA@3oO4`0ohQG
603oReX00`3oS5d0oh]J0?n;FP040?n;FP070?n<F`3oQUD0ogQ70?mgAP3oN4L0ohIE0?n<F`030?n;
FP070?n?H03oS5`0oh]J0?n;FP3oS5h0oh]L0?n9F@0:0?n;FP030?n:F`3oS5/0ohYJ00h0oh]J00H0
oi5O09Y2:P0000008`/80?mB@@3oLE/=0?m/F0030?m]F@3oKUT0ofeH0100ofaH00<0og9M0?m/F03o
K5P0403oK5P0103oKET0ofaE0?m_FP3oK5L?0?m/F00<0?mdG@2_>2`000000000000W20T0k3Th0?m7
AP3o@d40odA20?m=B`3oDe40oeID0P3oF5H;0?mGE@030?mIE`3oF5H0oeED00D0oeME00D0oeID0?mD
DP3oFU/0ogF00?nF[0030?nJ/@80oi^c00<0oiZa0?nK/`3oSZL01@3oQ9l00`3oQIl0ohVS0?n4W`07
0?n4W`070?n1W03oNYH0ofIi0?mHE`3oEE80oe=A0?mDD0030?mEDP040?mGDP3oDe00oeME0?mDDPD0
oeEC00@0oe=A0?mHE`3oG5/0oeAB0`3oEE<0103oE580oeaL0?mHE`3oDU020?mFE00A0?mEDP3oE580
oeaK0?mLF`3oEE<0oe=A0?mDDP3oEE<0oeAB0?mCD03oE580/CPg0000000e5``0oj=F0?nOF@3oW5<0
0P3oW5@0303oVe<0oiYA0?nLD`3oW5@0oieE0?nTHP3oYfP0oiaE0?nLE03oWEH0oiI;0?nfP_l0oooo
ZP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOj0?ooo`03
0;n0L01e?bD0ND<Y0080ND<Y00X0QD/c0899<01e?bD0OdL^07U3:@1h@RP0PDL_089:<@1h@BL0N48X
0P1i@bT01@1lAB/0QD/c07I19`1nARd0N44W00<0ND<Y00<0MClU07Q2:01i@bT00P1i@bT0202AECd0
ND<Y07U3:@24BS80PTT`07Q2:01lA2/0Nd@Z0P1i@bT0101f@2H0Nd@Z07I09P1f@BL707U3:@0308E;
=021B2l0N48X00<0ND<Y00<0Q4Xb07Q19`1kA2X00P1i@bT02@1i@RP0OTL/07Y4:P1i@bT0N48Y07I1
:02hICL0n8E50?Z6A0020?F4A0070?F5@`3hQdX0nhQ;0?F4A03eQD@0m8A20?j;CP050?f8AP030?n:
B03mR4D0oHQ600H0oHQ600H0nhQ60?^7A03oYeD0okaQ0?nmG@3o_5/C0?nkF`030?nnG@3o/5D0L3/I
0080000000<0LRhM0?n7F03oSE`04P3oReX00`3oRUT0ohmP0?n;FP0X0?n;FP030?n<G@3oRUT0oh]J
0100oh]J00<0oheM0?n<G03oReX0403oReX00`3oRUP0ohYI0?n;FP060?n;FP0:0?n:FP3oReX0ohMF
0?mkBP3oMTH0oga;0?n8E`3oS5/0oheN0?n;F`h0oh]J00<0oh]K0?n;FP3oREP01`3oReX00`3oRET0
ohUH0?n;FP040?n;FP030?n;F`3oReX0oh]J00d0oh]J00<0ohYI0?n8E`3oReX03@3oReX00`3oRUT0
oh]J0?n;FP0<0?n;FP030?n:F@3oREP0oh]J00`0oh]J00<0ohYI0?n=G`3oReX0203oReX01`3oREP0
ohaL0?n?H03oRe`0ohYI0?nFJP3oS5/0303oReX00`3oRU/0oiIZ0?n9F@0<0?n;FP030?n;G03oTVH0
ohYI00d0oh]J00<0oh]K0?n:F@3oReX0303oReX02@3oRUT0ohiO0?n;FP3oReX0ohMF0?mfA`3oO4`0
ohQG0?n:F`080?n;FP030?n=GP3oReX0oh]J00`0oh]J00<0ohUI0?n<G@3oRET01@3oReX01@3oR5L0
ogY:0?mgAP3oNdX0ohMF00@0oh]J00<0ohaL0?n;G03oReX00P3oReX00`3oRUT0ohaN0?n;G0090?n;
FP030?n:F@3oREP0ohYI00h0oh]J00L0ohmM0?m_B00L2`L08`/80?mC@P3oLEX0ofeI00`0ofaH0P3o
KeX00`3oKEL0ofaH0?m/F00>0?m/F0030?m`F`3oK5P0ofaH0100ofaH00<0ofeG0?m`FP3oK5L03P3o
K5P03P3oKEP0ofmI0?m_F@2i=b/03@@30000001Z5aD0oc`k0?m4@`3oB4H0oe1>0?mED`3oEeD0oeQF
3@3oEeD00`3oG5X0oeME0?mGE@080?mGE@0;0?mDD`3oF5H0ofY`0?nF[@3oVk<0oiZa0?nL/`3oVk<0
oiZa0?nH/03oQZ001@3oQ9l00`3oQIl0ohbU0?n4W`060?n4W`080?n5W`3oMiD0ogFC0?meT`3oKhL0
oeUK0?mEDP3oEU<30?mEDP050?mCD@3oDdl0oeID0?mHEP3oDe400`3oEE<01@3oE580oeYH0?mNG@3o
GE`0oeAB00<0oeEC00D0oeAB0?mJF03oEeD0oeAB0?mCD@030?mFD`050?mFDP3oEU<0oeIC0?mFD`3o
DU000P3oEE<0203oEU@0oeMD0;hm>`000000;1<;0?nVG03oXEd0oiaC0P3oW5@30?nKDP80oiaD00P0
oimK0?nTH@3oW5D0oiaD0?nLD`3oVDl0oiM<0?oajOl0ooooZ@3oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOi0?ooo`030?ogo@2EEd40O4D/0080ND<Y00@0ND8X
08Q<=@26Bc@0Md4U0P1i@bT01@1h@RP0PDP^0899<01f@2H0N44W0080ND<Y00D0OTH]08iB>@1kA2/0
NT<Y07Q2:00207U3:@0307U4:@1nAR`0ND<Y00<0ND<Y00L0TEDm07U3:@1i@bT0MT4W07U2:01h@RP0
NTDZ00<0ND<Y00@0Md4W07U3:@22BC00O4D[1`1i@bT00`1e?bD0QD`c07Q19`0207U3:@0307a5:`1k
A2/0ND<Y00<0ND<Y00P0MClU08Q==@1kA2/0N48X08A8:`2oJC`0mHA30?N4A0<0mHA400P0mH=30?B4
@P3dQ4<0mHA40?F5@`3iR4`0mhA20?b7A@@0oHQ600<0oi1C0?f8AP3mR4H0103mR4H0103kR4H0oXU6
0?nCC03o[EL20?nlF`030?nnGP3o_5`0okaL01<0ok]K00T0okiM0?nfF03GLSD070l60040001f;1/0
og]A0?n<F`3oRe/04P3oReX00`3oS5h0oh]J0?n;FP0C0?n;FP030?n>H@3oReX0oh]J0140oh]J00<0
ohaO0?n;FP3oReX0403oReX00`3oSUl0ohYK0?n;FP0?0?n;FP030?n:F`3oReX0oh]J00T0oh]J00L0
ohUH0?mlB`3oMdH0ogU80?n5E03oReX0oheN00l0oh]J00<0ohYK0?n;G03oReX0203oReX00`3oS5`0
oh]K0?n;FP020?n;FP030?n:F@3oT680ohYK00d0oh]J00<0ohYK0?nBIP3oRET03@3oReX00`3oREP0
ohYI0?n;FP0<0?n;FP030?n=GP3oTF<0ohYI00`0oh]J00<0ohQH0?nBI03oRUT01@3oReX02P3oRe/0
ohYJ0?nAH`3oS5/0ohYI0?n;F`3oReX0ohYI0?nFJP3oS5/=0?n;FP030?n9F03oReX0oh]J00`0oh]J
00<0ohUH0?n;FP3oReX02`3oReX00`3oRUT0oi1R0?n:F@0@0?n;FP050?n6E@3oNDP0ogU80?n7EP3o
S5/0203oReX00`3oREP0oh]J0?n;FP0=0?n;FP030?n:F`3oSEd0oh]J00@0oh]J00D0ohAC0?miB03o
MdH0ogm?0?n9F0050?n;FP030?n<G03oReX0oh]J00<0oh]J00<0ohYI0?n>G`3oRe/0203oReX00`3o
RUT0ohaK0?n;FP0<0?n;FP080?n<F`3oTEl0ofi703TG3`0B1P@0oeA30?m_F@3oKEP<0?m/F0030?m^
F@3oLE`0ofeG0100ofaH00<0og1K0?m_FP3oK5P0403oK5P00`3oK5D0og1K0?m]F@0?0?m/F00:0?m_
F@3oF4D0IQhG0000000A10@0_RPW0?m3@P3oBDL0oe=A0?mFE0l0oeME00<0oe]I0?mIF03oEeD0303o
EeD0203oEU@0oeiP0?n4TP3oUjh0oi^c0?nI/@3oV[40oiR`1P3oQ9l00`3oPih0oh6M0?n4W`050?n4
W`040?n5W`3oOYX0ogBB0?mcT@80ogFC00@0ofj20?mMF`3oGed0oeE@0P3oEE801P3oEU<0oemM0?mE
D`3oEeD0oeIE0?mFE080oeEC00D0oeAB0?mJF03oGUd0oeeL0?mDDP040?mED`0F0?mCD@3oE580oeEC
0?mBC`3oEU<0oeEC0?mGE@3oE580oe=A0?mED`3oEU<0oe=A0?mED`3oDe40of5O0?mMG03:?cd00000
02@@203oTTl0oj=M0?nLD`80oiaD00d0oi]C0?nMEP3oXE/0oiaC0?nLE03oWED0oiaC0?nME03oW5@0
oiaC0?nMD`3oVDd0omc40?l0ooooZ@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOh0?ooo`040?ognP3;PG80NT<Y07e6;0<0ND<Y00<0ND<Z08=9<@1oARd00`1i
@bT0101g@BL0ND8X07I09P1i@RP307U3:@0307e6;@1h@RP0ND8X00<0ND<Y00<0O4D[08aA>01g@BL0
0`1i@bT01`1j@bX0ND<Y07Y4:P1mAB/0NT@Y07Y4:P1iA2T00`1i@bT0101g@BL0N48X08M==01nAR`7
07U3:@0507Do9@1j@bT0ND8X07e5:`1oAbh01@1i@bT01`1jA2X0M3lV07Y4:`2CDC00c70m0>j1@@3h
QDD01@3eQ4@00`3fQDH0nHQ;0?F3@`020?F4A0030?J5A@3hQDH0o8Q800<0oHQ600<0oXU70?f8A@3m
R4H00P3mR4H01`3kQdH0o8M50?b;B@3oWe80ok=H0?nlG03o_5/0103o^e/00`3o_5`0okaO0?nkF`0B
0?nkF`0;0?nlF`3o_Ud0ojeC08QD:@0F2`D04PH4074/703OKdP0oheL0?n=F`3oRUX04@3oReX00`3o
SEh0oh]K0?n;FP0B0?n;FP030?n=GP3oSEd0oh]J0100oh]J00<0oh]K0?n:G@3oSEd04@3oReX00`3o
S5`0oh]J0?n;F`0>0?n;FP030?n:FP3oS5d0oh]K00X0oh]J00P0ohYI0?n2D@3oNT/0ogM60?moCP3o
R5L0oheN0?n;F`l0oh]J00<0ohaL0?n;FP3oReX01`3oReX00`3oSEd0oheN0?n;F`020?n;FP030?n9
F@3oSUl0oh]J00d0oh]J00<0ohYI0?n=GP3oReX0303oReX00`3oSUl0ohmQ0?n:F@0<0?n;FP030?n=
G@3oT640ohYI00`0oh]J00P0ohQH0?nBI03oRUT0oh]J0?n;G03oRe/0oheO0?n;F`80ohaL1@3oReX0
0`3oRUT0oiAX0?n;F`0<0?n;FP030?n:F03oREP0oh]J00`0oh]J00<0oheM0?n;FP3oReX0303oReX0
0`3oS5`0ohYK0?n;FP0=0?n;FP070?n<G03oRe/0oh9A0?mgB03oNTT0ohED0?n<F`070?n;FP80ohYJ
00<0oheN0?n;F`3oReX0303oReX20?n;F`80oh]J00L0ohaK0?n;FP3oQE@0og];0?mdAP3oNdX0ohIE
00H0oh]J00<0ohaM0?n<G03oReX01P3oReX00`3oS5d0ohaL0?n;FP050?n;FP030?n;G03oS5`0oh]J
00`0oh]J00L0ohaK0?n6E`2K@2T07@/700d40`2mA3H0ofiI00`0ofaH00@0ofeH0?m^F@3oL5/0ofeH
3P3oK5P0103oKET0og1K0?m]F@3oK5L@0?m/F0040?m^F@3oKeX0ofeF0?m]F0T0ofaH0P3oKET02`3o
K5P0of]F0?mYD`3oIU00oeY608`^8`0<0`806@D506LG5`3I@Cl0oeAB0100oeME00<0oeED0?mJF@3o
EeH04@3oEeD01P3oEU@0oeaL0?mhP`3oUZX0oiJ^0?n6X0L0ohBO00<0ohJP0?n6X@3oQ9l00`3oQ9l0
503oQIl0oh6L0?mfT`3oMI<0og^H0?mgU03oMI<0ogJC0?meT03oJGT0oeeQ0?mGD`3oEU80oeIC0?mN
F`3oFeX0oeEC0?mDDP3oEeD0oeQF0`3oEE<00`3oE580oeMD0?mED`040?mED`0<0?mDDP3oFUT0oeAB
0?mNG03oEU@0oeIC0?mDDP3oEE<0oeaK0?mGE@3oEU@0of=Q0P3oEE<0203oFEP0oeQF0?98A`0:0000
6``60?mm@P3oWU<0oiaC0P3oW5@03@3oWUL0oieG0?nTH@3oW5<0oiaD0?nJDP3oWED0oiaB0?nLE03o
W5<0oj1J0?nOFP3o]7l0o`3ooonY0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWioP0oooo00@0nZBL06<c5@20Abh0O4D/0P1i@bT01@1h@RP0MClT08iB>@25Bc<0
ND<X0080ND<Y00<0Nd<Y07Q2:@1f@BL00`1i@bT02P1f@2H0ND<Y07U3:@21B2l0PTP`07Q2:01i@bT0
NT@Z07]4:`1h@RP307U3:@0507Do9@1i@bT0OdL^08A9<P1h@BL0101i@bT307Q2:00307Do901h@RP0
ND<Y00D0ND<Y00D0MT4W07I09P1mAB`0Nd@Z07]3:`0607U3:@04078o9`1g@2@0[5he0?>2A0P0mHA4
00<0m8520?B3@@3eQ4@00`3eQ4@00`3gQTD0n8I50?f:B@020?f8AP090?j:A`3mRDL0oHQ60?f8AP3h
QTD0ohi<0?nNC`3o]Uh0okeL00P0ok]K00@0ok]J0?nlG03o_600okaL4`3o^e/0203o`el0oiE806Hf
6@0000005@L40=aG>03oReX0oi5O4@3oReX00`3oS5`0ohmP0?n;F`0D0?n;FP030?n<F`3oReX0oh]J
0100oh]J00<0ohYK0?n<G@3oReX0403oReX00`3oRUT0ohaK0?n;FP0?0?n;FP80ohYI2P3oReX0203o
S5/0ohYI0?n3DP3oMTL0ogQ70?n0D03oRUX0ohaK3@3oReX00`3oRUT0ohaN0?n:FP090?n;FP030?n;
F`3oS5l0oh]K0080oh]J0P3oRe/=0?n;FP030?n:F`3oT680ohYI00`0oh]J00<0ohYI0?n9EP3oREP0
303oReX00`3oRUT0ohQG0?n;FP0<0?n;FP070?n9F03oTF<0ohmQ0?n9F03oSV00ohYL0?n:F@090?n;
FP030?n6E@3oReX0oh]J00/0oh]J00<0ohiO0?n;F`3oReX0303oReX00`3oTF80ohYI0?n;FP0;0?n;
FP030?n:F@3oRe`0ohaM00`0oh]J00P0ohYI0?n>G`3oSf00oh1?0?mgAP3oN4L0ohIE0?n<F`T0oh]J
00<0ohaO0?n:F`3oReX0303oReX0303oREP0ohaK0?n:F@3oReX0oh]L0?n9F03oP500ogM70?mjB@3o
PE40oh]J0?n<F`D0oh]J0P3oS5`00`3oRUX0oh]J0?n;FP060?n;FP030?n<GP3oSEh0oh]J00<0oh]J
00<0oheN0?n=G@3oReX0303oReX01`3oS5/0oi5O09]0:@0000006PP60>14=@3oKeX0303oK5P00`3o
KEL0ofmJ0?m`F`0?0?m/F0040?m]E`3oKeT0ofiI0?m/E`l0ofaH00<0ofaG0?m]E`3oKUT02P3oK5P0
3P3oKET0ofiI0?mZD`3oIE00of=<0?mNA`3oFD80]c@W01/81P000000KaPH0?m8A`3oGEX0oeQF403o
EeD00`3oFUT0oeQF0?mEE00D0?mGE@050?mED`3oEE@0ofA]0?mnU@3oQZ001P3oQ9l00`3oQIl0ohFP
0?n4W`030?n4W`060?n1W@3oLi40ogFC0?meT`3oNiP0ogJC0P3oMI<0103oLi40ogJC0?mfT`3oIG82
0?mFD@030?mDDP3oF5L0oeEC0080oeEC00H0oeED0?mBD03oEeD0oeAB0?mIE`3oE5050?mED`050?mD
DP3oFUP0oe=A0?mSHP3oEU@00P3oEU<01@3oE580oeID0?mGE03oEU@0ofAR0080oeEC00P0oeIB0?mA
C`3oE5805@8200h50@3EGS00oj9I0?nQF`80oiaC00<0oj5L0?nLD`3oVU000P3oW5@02@3oVe<0oi]A
0?nPFP3oW5@0oiaC0?nPFP3oWUX0oiYB0?o_j03o0?ooojP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWm`3oool01@3ok?<0SU8j078n8`1nARd0O4D/0080ND<Y
00@0ND8X07@o9027CC@0QT/d0P1i@bT0101lAB/0R4de07M2:01e@2H207U3:@0:07]4:`21B2l0ND<Y
07U3:@22BS40Q4Tb07Q2:01i@bT0Md4W07I19`@0ND<Y00D0MClU07U2:01oAbh0OdH^07U2:00407U3
:@0407U2:01j@bT0N48W07Q29`L0ND<Y00@0LclU07i6;021B2l0N48X1P1i@bT01@1f@RT0T4l/0<a`
?`3hQdX0n8E400L0mHA400<0mXE50?b<CP3dPd@01@3eQ4@01@3hQdP0nhU70?f9A@3mR4D0oXY80080
oHQ600D0mhI40?jBB`3o/UT0okmN0?nmFP0:0?nkF`030?nkFP3o_Uh0okaL01@0ok]K00P0olEQ0?na
E@2iHRl02`D200D10022<Ql0ogI>0?nAGa40oh]J00@0oh]K0?n=G03oSEd0ohYI4P3oReX20?n<Fa80
oh]J00<0oh]L0?n:F@3oRUT0403oReX00`3oS5`0ohYI0?n;FP0>0?n;FP030?n:F@3oReX0ohYI00/0
oh]J00H0ohaK0?n2D@3oMdH0ogM60?mkBP3oR5P>0?n;FP030?n9F03oS5`0oh]J00T0oh]J00<0ohYK
0?n<G03oRUT00P3oReX00`3oS5`0oh]J0?n;FP0<0?n;FP030?n9F03oRe/0oh]J00`0oh]J0P3oS5h=
0?n;FP030?n8E`3oRUT0oh]J00T0oh]J00L0ohYI0?n9F03oSUl0oi1R0?n?HP3oREP0ohYI00/0oh]J
00<0ohQG0?n;FP3oReX02`3oReX00`3oU6X0oh]J0?n;FP0<0?n;FP030?n;F`3oReX0oh]J00`0oh]J
00<0ohUH0?n9F@3oReX0303oReX01@3oS5h0ohQH0?mhA`3oN4L0ohAC00T0oh]J00<0ohYJ0?n>G`3o
Re/03P3oReX02P3oSf00ohUH0?n;FP3oS5/0ohIE0?mlC03oMdH0ogY:0?n7EP3oS5/70?n;FP030?n<
G03oRUT0oh]J00T0oh]J00L0oheN0?n<GP3oRUX0oh]J0?n<F`3oSEh0ohYJ00d0oh]J00L0ohmM0?m[
A@0J2PH06PL50>15=`3oLE/0ofiI00/0ofaH00<0ofeH0?m^F03oL5/0403oK5P00`3oKeX0ofeI0?m/
F00?0?m/F0040?m]F03oLE`0ofeG0?m]F0P0ofaH00T0ofeI0?m^F@3oJe@0ofA>0?mNA`3oF480oeY3
0?mG@@1e8AT00P0000000`1c6aX0oe=B0?mLF`0A0?mGE@030?mHEP3oFeT0oeED01<0oeME00P0oeID
0?mIF03oF5H0oeME0?mCD@3oH6<0ogR<0?n7X@D0ohBO00<0oh>N0?n1W@3oQ9l00P3oQ9l00`3oQIl0
ogbH0?mdTP020?meT`<0ogBB00T0ogRE0?meT`3oMI<0ogFC0?meT@3oIG@0oeUG0?mHD`3oFEP01@3o
EE<01@3oF5H0oeQE0?mMF`3oDDl0oeAB00D0oeEC0P3oE5802@3oHf80oeID0?mFD`3oEU<0oeID0?mB
D03oE580oeID0?mWI@020?mED`0>0?mDDP3oFeT0oeME01H30`0;1000aeP^0?nRF`3oXf40oiiF0?nM
E@3oXE`0oiaD0?nKDP3oVE420?nLE0080?nLDP3oYF@0oieE0?nLD`3oX5X0oimJ0?nJD@3o_8go0?oo
ojP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWm`3oool0
7@3^Vi80J3DI07U3:P1nARd0OdL]07Q2:01i@bT0OdL^08M<=028CCH0QT/d07U3:01i@bT0OTH/095D
>`1jA2X0OTH]07Q2:@1h@RP0OdL]08U@=`1h@RP0ND<Y0899;`22B300N48X07U3:@1lA2/0N48Y00<0
ND<Y00D0MT4W07I09P1oAbd0N48X07Do9@0407U3:@0607Q2:01oAbh0OdH^08Q<=@21Abl0N48X1@1i
@bT0101i@RP0NdDZ07]3:@1nAR`607U3:@0607Do9`2GE340iGa00?R7BP3bQDH0mHA61`3eQ4@00`3f
Q4D0nhU<0?F4A0040?F4A00;0?N5A@3eQ4D0nHM:0?n<B`3mR4D0oh];0?R7A@3hQDD0oiU>0?nfFP3o
_U/03@3o^e/0103o^eX0okaK0?nmGP3o_EhC0?nkF`030?o0G@3oa5l0]68_0080000000<0>AL?0>Ua
B@3oS5`04@3oReX00`3oRUT0oheN0?n;FP0C0?n;FP030?n<FP3oSUl0oh]J0140oh]J00<0ohaK0?n:
F@3oRUT03`3oReX00`3oRe`0oh]J0?n:F@0?0?n;FP030?n;F`3oS5h0oh]J00`0oh]J00H0oh1@0?mh
A`3oMTH0oga=0?n;FP3oRU/J0?n;FP80ohYI00<0oh]J0?n<F`3oReX03@3oReX00`3oReh0oheN0?n;
FP0;0?n;FP030?n:F@3oSf80oi5T00d0oh]J00<0ohiO0?n<G03oRUT01`3oReX01`3oRUT0oh]J0?nB
I@3oREP0ohaL0?nAI03oREP03@3oReX00`3oR5L0oh]J0?n;FP0;0?n;FP030?nDJ@3oRe/0oh]J01X0
oh]J00<0oh]L0?nBI@3oReX02`3oReX01P3oRUX0ohmP0?n>G`3oNdX0ogM60?n3DP/0oh]J00<0ohYK
0?n;F`3oReX03@3oReX02@3oSEh0oh]J0?n8FP3oQUH0ogU80?mgAP3oN4L0ohEE0?n<F`070?n;FP03
0?n<G`3oReX0oh]J00/0oh]J00D0ohaL0?n;FP3oS5`0oh]K0?n:F@0=0?n;FP070?n=G03oJ4<0;A4:
00d40`3TASP0og5K0?m_FP0<0?m/F0030?m]E`3oKUT0ofaH00l0ofaH00<0og1K0?m]F03oKET03`3o
K5P00`3oKEP0og1K0?m`F`080?m/F00:0?m]F@3oKEP0ofM@0?mPB`3oGdP0oeY40?mI@P3oH4T0of5;
07HR6P80000000<0LaTH0?m?C`3oFUP0403oEeD0103oEE<0oeUH0?mGEP3oEE@B0?mGE@050?mFE@3o
EeH0oeYH0?mEE03oEeH00P3oEeD00`3oEU<0oeiO0?mjSP020?n5W`<0ohBO00<0oh>N0?n7X@3oPih0
0P3oQ9l00`3oPYh0ogBB0?meT`020?meT`040?mdTP3oLXl0ogRE0?mfU0<0ogFC00D0ogJC0?meT`3o
KX<0oeeT0?mFE0060?mED`040?mHEP3oEU@0oe9@0?mCD@D0oeEC00@0oeAB0?mCD@3oIFD0oeID103o
EU<00`3oE580oeYG0?mHEP020?mED`0I0?mCD@3oH640oeQF02@71`020000V48S0?nQF03oWUP0oieE
0?nMEP3oXUh0oiaC0?nMEP3oWeT0oiaD0?nLD`3oXV00oimJ0?nMEP3oVe80oj9M0?nPF`3oVe<0oiYB
0?o_j03o0?ooojL0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWmP3oool0303ef]L0M3lT07Q2:01g@RP0Re0h07m6;P1h@RP0NT@Z07i6;@28CCD0OdL_07m7;P80
ND<Y00P0Nd@Z0817;P20B2h0R4de07Q2:01nAR`0Nd@Z08Q>=@80ND<Y00H0PDT`08=9<@1h@RP0ND<Y
08E<<`1h@RP307U3:@0407Q29`1mAR`0NT<Z07e5:`D0ND<Y00D0N48X0899<022BC00Q4`b07m7;@05
07U3:@0407U2:01nARd0NT<Y07I19`D0ND<Y00P0NT<X09AC<P2lIcX0iga00?:4A03_PD80kWm10?:3
APL0mHA400<0mhI70?F3@`3eQ4@01@3eQ4@02@3gQDH0m8930?R6A@3mRTT0oI=;0?nWE03o]U/0ok]K
0?nmG00@0?nkF`040?nlG03o^e`0okaO0?nmGA80ok]K00X0okaL0?nmG03SUTP0Qd`T02HD2P0S3PT0
UdT`0?QfC@3oReX0ohaK3`3oReX0103oRe/0ohaK0?n;G03oSEhB0?n;FP030?n;F`3oSEh0ohaK0100
oh]J00<0oh]K0?n<F`3oRe/0403oReX00`3oRUX0oheM0?n;G00?0?n;FP030?n;F`3oSE`0oh]J00`0
oh]J00H0ohUH0?n2D@3oNDT0ogY:0?n1D@3oR5L<0?n;FP80oh]K2`3oReX01@3oS5/0ohaL0?n;F`3o
S5`0ohaK00h0oh]J00<0oh]L0?n;FP3oReX0303oReX00`3oS5/0oh]K0?n;FP0:0?n;FP040?n:F@3o
TVH0ohiQ0?n:F@@0oh]J00H0ohaK0?n<G03oREP0ohmQ0?n<F`3oS5`A0?n;FP030?n8E`3oReX0oh]J
00/0oh]J00<0oheN0?n;FP3oReX0303oReX00`3oSf00oh]J0?n;FP0;0?n;FP030?n;F`3oReX0oh]J
00`0oh]J00@0oh5B0?mjBP3oMdH0oh9A2`3oReX00`3oRe`0oh]K0?n;FP0<0?n;FP0:0?n:FP3oSEd0
oh]J0?n8E`3oPE00ogU80?mkBP3oPe80ohUH0?n;F`L0oh]J00<0ohaM0?n;F`3oReX03P3oReX00`3o
S5/0oh]K0?n;FP0<0?n;FP070?n8F@2QA2/05@P500d40`2l@SD0og5K0?m^F@0;0?m/F0030?m]F@3o
KUT0ofiJ00l0ofaH00@0ofiI0?m`F`3oK5P0ofeH3P3oK5P0103oKEP0ofmJ0?m]F03oKET60?m/F00A
0?m[E`3oJ580ofE?0?mRB`3oGDH0oe]60?mMA`3oH4X0ofE@0>YF@`2=;bD0=10<01h81`2>9bP0jTE4
0?mEE03oFEL03`3oEeD0103oF5H0oeYI0?mFE@3oF5HC0?mGE@80oeUG0P3oF5H00`3oEUD0oeME0?mG
E@030?mGE@040?mEE@3oGf<0ofik0?n0U`<0ohBO00D0ohNQ0?n4W`3oQ9l0ohBO0?mmV@040?meT`03
0?mdTP3oNID0ogJC00H0ogFC00D0ogJC0?meT03oIGD0oeMH0?mDDP050?mED`030?mFE03oGE`0oeUG
00D0oeEC00<0oeYI0?mIE`3oE580103oEU<01@3oEE80oeeK0?mED`3oEE80oeID0080oeEC00L0oeUG
0?mFE00l3Ph00000078c6`3oXUP0oi]B0080oiaD0P3oW5<03P3oXE/0oj9Q0?nLD`3oW5<0ojAS0?nM
E@3oW5@0oieE0?nOE`3oXUl0oieF0?nKD`3o/7L0oogno`3ooonV0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWioH0oooo00T0_8j207U3:@1i@bT0MT4W08I<<`1f
@BL0ND<Y07]4:@1i@bT00P1f@BL0201h@BL0ND<Y07U3:@1c?R@0N48X0817;P2;D3L0N44W0P1h@RP0
201e@2H0ND<Y07U3:@21BC00Q4Tb07Q2:01i@bT0NdDZ0`1i@bT01P1mAR`0ND8X07U2:01h@RP0QD`c
07I19`@0ND<Y00D0N48X0858;`21B2l0MT0V07Q2:00407U3:@0507]4:P1h@RL0N48X095D?02;D3L0
0`1i@bT02`1f@BP0PdX]0<]]>03^Od80kh120>eo@P3eQdd0lhI;0>an@@3]Od80lH5100H0mHA400<0
mhI90?F5@`3eQ4@01P3eQ4@01@3eQ4H0oHM40?nRDP3o^e`0okaK01H0ok]K00<0okaL0?nlGP3o^eX0
4P3o^e/02@3o_E`0ol1L0?ndE`1O<aL0000000D10025<b40ohEH0?n;F`0B0?n;FP030?n<G03oReX0
oh]J0180oh]J00<0ohYI0?n;FP3oReX08@3oReX00`3oRET0ohaO0?n;F`0?0?n;FP030?n<G@3oRUT0
oh]J00d0oh]J00D0ohIG0?mfAP3oMTH0ogQ70?n5E@0<0?n;FP030?n<G03oReX0oh]J00/0oh]J00@0
ohUH0?n;F`3oSEh0ohUI3@3oReX00`3oSUl0ohQH0?n;FP0;0?n;FP030?n:F@3oT6<0oheN00`0oh]J
0P3oREP01P3oReX0oh]K0?n;FP3oRe/0oi1S0?n<G0L0oh]J00<0ohYI0?n;FP3oReX02`3oReX00`3o
RUT0ohQG0?n;FP0<0?n;FP030?n9F03oReX0oh]J00/0oh]J00<0ohUH0?n:F@3oReX02`3oReX00`3o
RU/0oi=V0?n:F@0<0?n;FP040?n5E03oN4L0ogM60?n1D@/0oh]J00<0ohUI0?n<F`3oReX03@3oReX0
0`3oSEh0oh]K0?moC`020?mhA`030?n0C`3oS5/0oh]J00P0oh]J00<0ohYI0?n<G03oReX03@3oReX0
103oRUT0ohaM0?n;FP3oRU/<0?n;FP060?n?G@2TBc40000001X71@3_BS/0ofiI303oK5P00`3oKeX0
ofiI0?m[E@0?0?m/F0030?m/E@3oKET0ofaH00l0ofaH0P3oKEL02@3oKUT0ofaH0?m/F03oK5P0ofeI
0?m]F03oJUD0ofQA0?mQC0020?mKA@070?mJA@3oG4H0of9=0?mZE@3oKeT0ofiI0;Y2=00200000004
01D4103O?Sh0oeUG0?mFEA00oeME00<0oeUG0?mGEP3oEeD04P3oEeD0103oF5H0oeEC0?mNG@3oF5H<
0?mGE@060?mLG@3oMh`0oh>L0?n5W`3oQ9l0oh>N0P3oQ9l00`3oMY@0ogFC0?meT`020?meT`030?mg
U03oNYH0ogJC00L0ogFC00D0og>A0?m]R`3oKHL0oeiW0?mFD`040?mED`030?mIE`3oI6@0oeaL00D0
oeEC0P3oEU@00`3oDe40oeAB0?mFD`030?mFD`040?mEDP3oEU<0oeAB0?mGE@@0oeEC01L0GQLG0000
001:8Q80oj9G0?nPG03oWUT0oiaC0?nMEP3oVe<0oiaC0?nKDP3oW5@0oiaC0?nSHP3oWEH0oimH0?nM
D`3oVe40oj5M0?nMF03oVe@0oiaD0?oG_P3o0?ooojH0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWmP3oool0302FFD80ND<Y07U3:@1f@BL0PTTa07I19`1kA2X0
OTD[07M19`1h@BL0MT4W07Q19`80ND<Y00@0Nd<Z07U3:@1lA2/0PDP_0P1i@bT02@1h@RP0ND<Y07U3
:@1i@bT0ODH/07i6;@1h@RP0ND<Y07I19`0307U3:@0607a5;02;D3L0Nd@Z07Q2:01oAbh0N48X101i
@bT0101h@RP0PTT`085:<01i@RP307U3:@0707Q2:01nAR`0OTH/07U3:@1h@RP0TE@l08mD>`0207U3
:@0407E0:01j@RH0bFlm0?60@P<0kWm200H0kh=50?64A@3^Od40kWm20?:5AP3eQ4D50?F4A0030?B4
@P3eQ4@0mHA400D0mHA400H0mH=50?nKE03o]U`0okeK0?nmG`3o^e`G0?nkF`030?njF@3o_640okeN
01<0ok]K00<0okaK0?nYD@1B:a@00P000000102J?BH0ohYJ0?n?G@3oRUX@0?n;FP030?n<F`3oRUT0
ohYK0180oh]J00<0ohaL0?n>GP3oReX0403oReX00`3oS5/0ohYI0?n:F`0?0?n;FP030?n9F@3oSEh0
oh]J00h0oh]J00@0oh]K0?n>G`3oReX0ohUI303oReX0203oS5/0ohQG0?mmC@3oN4L0ogU80?n7EP3o
ReX0ohaK2P3oReX00`3oSf00ohYI0?n;FP0;0?n;FP030?n=G@3oReX0oh]J00h0oh]J00<0oh]K0?n;
FP3oReX02P3oReX00`3oRUT0ohaN0?n:F`0;0?n;FP070?n:FP3oREP0ohUH0?n:F`3oS5d0ohmP0?n:
F@090?n;FP030?n:F@3oReX0oh]J00/0oh]J00<0ohUH0?n:F@3oReX02`3oReX00`3oRUT0oh]J0?n;
FP0<0?n;FP030?n:F@3oReX0oh]J00/0oh]J0P3oR5L<0?n;FP040?n:F@3oNTX0ogQ70?n1D@`0oh]J
00<0oh]K0?n:F`3oReX0303oReX01`3oS5`0oheL0?n0C`3oMdH0ogQ70?mnCP3oRUT02P3oReX00`3o
SV40oh]J0?n;FP0=0?n;FP050?n;GP3oSEd0ohQH0?n;FP3oRe/02@3oReX01`3oS5/0oi1N0?mfCP0U
3`X07@P60?99>`3oL5X0303oK5P00`3oKUT0og5L0?m]E`0>0?m/F0030?m]F@3oKeX0of]E0100ofaH
00@0ofiJ0?m]F@3oJeD0ofaH0P3oKET0103oJUD0ofUD0?mVC`3oFdH20?mI@`0=0?mLAP3oH4X0ofI?
0?mZE@3oKET0og=L0?mYE03J@S@04@D300D0001Q51@0od910?mHE`0?0?mGE@040?mHEP3oF5L0oe]I
0?mCDQ@0oeME00<0oeYH0?mIF03oEE@03@3oEeD0203oEUD0oeAC0?m/M`3oO9<0ohRR0?n9X`3oPId0
ogND103oMI<0103oMY@0ogND0?mbS`3oLi450?meT`080?mdTP3oMI<0off;0?maSP3oKH/0ofb:0?mT
LP3oEeH30?mED`050?mFE03oHf80oe]H0?mGE@3oEU@0103oEE<00`3oDe40oeEC0?mBC`040?mFD`0H
0?mDDP3oEU<0oeIC0?mED`3oF5H0oeEC0?mDDP3oFeT0MAhM0000000m6`h0oi]B0?nRG`3oXE/0oiaC
0?nLE03oWED0oiaC0?nLDP3oWE@0oiaD0?nME@3oW5D0oj5K0P3oWeP01@3oWE<0oi]D0?nKE03oVU00
okR50?l0ooooYP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOe0?ooo`080?oVjP25C3<0ND<Y07U3:@1i@bX0MClT07]4:P21B2h207U3:@0<07Q2:01f@2H0ND8X
07U3:@1kA2X0TUDm07Q2:01oAbh0PTT_07Q2:01i@bT0P4P_0`1i@bT00`1g@BL0N48X07U3:@0407U3
:@0607m7;P1j@bT0TUDm07a5:`1i@bT0MT0V1@1i@bT04`1h@RP0Q4Xb08Q>=P24BS80N48X07U3:@1k
A2X0O4@Z07m7;@1h@RP0ND<Y07Q2:02AE3`0OdL^07Q2:@1e@2P0RTd^0<E[=`3bPT800`3^Od800`3^
P480k7ho0>io@@020>io@P030>n1@P3dQTL0mH=300@0mHA400<0n8M80?F4A03eQ4@00`3eQ4@00`3b
PD<0lH530?nLC`020?nnGP050?nkG03o^eX0okaQ0?njFP3o_5h05`3o^e/0103o_5`0okeN0?nkF`3o
^eXA0?nkF`090?nnG@3o[e@0W5<X01P<1@030@00XSlX0?mlD@3oT5h0oh]K0100oh]J00<0ohYK0?n>
G`3oRU/04@3oReX20?n:F@030?n;G03oRe/0oh]J00l0oh]J0P3oS5`00`3oRe/0oh]J0?n;FP0=0?n;
FP030?n;G03oSEh0ohYI00h0oh]J00<0ohYK0?n?H03oRE/03P3oReX01`3oRU/0ohAD0?miB03oNDP0
oh=B0?n;FP3oS5/02@3oReX00`3oRUP0oheM0?n;FP0<0?n;FP030?n?HP3oSV40ohUH00`0oh]J00<0
oheN0?n?HP3oRUT0303oReX20?n:F@X0oh]J00D0ohYI0?n<G@3oReX0ohaL0?n<G`0<0?n;FP030?n9
F03oReX0oh]J00/0oh]J00<0ohUH0?n:F@3oReX02`3oReX00`3oSEl0ohYK0?n;FP0<0?n;FP030?nD
J03oRe/0oh]J00/0oh]J00<0ohaL0?n;FP3oReX02P3oReX01@3oRUT0ogm?0?mgAP3oP500ohaK00/0
oh]J00<0ohYK0?n=G03oRUT03@3oReX01@3oS5h0ohEE0?mgAP3oNTT0oh5A00X0oh]J00<0oh]K0?n>
G`3oReX03P3oReX01`3oRU/0oheN0?n;FP3oReX0ohUH0?n;FP3oRe/0203oReX01`3oT5h0ogI=04`N
4`0<0`80lTTk0?m`FP3oKUP02`3oK5P00`3oKEL0og1K0?m]E`0?0?m/F0030?mbG@3oKUT0ofeG00l0
ofaH00<0ofeG0?m`F`3oK5L00P3oKET02@3oK5H0ofMA0?mOB03oFD<0oeQ20?mJA@3oGDL0of5;0?mX
DP020?m]F@090?m/F03oL5/0oea907/U7@0000005P@40;/[:P3oEE<0oeUI0100oeME00<0oeUH0?mH
EP3oEeD04P3oEeD0103oEE@0oeME0?mHEP3oFUPA0?mGE@060?mFD`3oG5h0og^@0?n9X`3oOiX0ogJC
103oMI<00`3oM980ogFC0?meT`070?meT`090?m]R`3oK8X0ogFB0?m/RP3oKH/0ofn=0?mRK`3oEE<0
oeAB0080oeEC00@0oeAB0?mED`3oEE<0oeME103oEE<00`3oF5H0oeEC0?mDDP040?mFD`0?0?mHEP3o
EU@0oeID0?mKF03oE580oeID0?mED@3oGU`0a38`0000000d5P/0oiM@0?nOF@3oW5H0oiaC0080oiaD
00l0oiaC0?nME@3oW5D0oiaD0?nHD03oW5@0oj1J0?nLD`3oW5@0oi]B0?nKD`3oVe@0oiUA0?nTHP3o
mo@0o`3ooonU0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
io@0oooo00<0ooCg0<9iJP20B2l00P1i@bT0201h@RP0Md4W07a5:`1i@bT0ND8Y08I<=01d?bD0MT0V
0P1i@bT0201kA2X0RDhf07a5:`20B2l0PTT`07U2:01i@bT0PdXa0`1i@bT207Q2:00;07U3:@1jA2X0
PdXa07Y3:01kABX0Nd@Z07U3:@2>DcX0O4@[07Y4:P1mAB`01P1i@bT01`1jA2X0ODH/07m7;P1h@RP0
O4D[07]5:`1jA2X00`1i@bT01`1i@RP0RDhf07M1:02BD2l0cg0n0>Yo@P3cPd<0103^Od800`3_PTH0
m8M:0>eo@P020>io@P030>j0@`3_PT@0lhE500<0mHA400<0m8930?N6A`3eQ4@00P3eQ4@01P3cPd@0
mh]90?nMC`3o[UL0okaM0?nkF`<0okaL0P3o^e/00`3o_5h0okeM0?nmG@0F0?nkF`030?nlG@3o^eX0
okeP0080okaL403o^e/02@3o_U`0ol=O0?^UC`1oCRD00`8002D?2@1n<R00iGM=0?n>G00@0?n;FP04
0?n;F`3oSE`0ohYI0?n:FQ80oh]J00<0ohiN0?n9F@3oReX04@3oReX00`3oRe/0oh]J0?n;FP0=0?n;
FP030?n<G03oSUl0ohaK00h0oh]J00<0ohYJ0?n=G@3oRe/03P3oReX01`3oRU/0ohED0?mlB`3oMdH0
ogY:0?n5E@3oS5/0203oReX00`3oRe/0ohaL0?n;F`0=0?n;FP80ohaK3@3oReX20?n=GP`0oh]J00<0
ohYI0?n>H03oRUT01P3oReX0203oS5`0ohaK0?n=G@3oSf40oh]K0?n:F@3oTVH0oheN303oReX20?n:
F@`0oh]J00<0ohUH0?n:F@3oReX02`3oReX00`3oT680oh]L0?n;FP0;0?n;FP030?n:F@3oS5/0oh]K
00`0oh]J00<0ohiO0?n;FP3oReX02@3oReX01P3oR5L0og];0?mfAP3oOdl0ohYJ0?n<F`X0oh]J00<0
oh]K0?n<G03oS5`02`3oReX0203oS5/0ohUH0?mnCP3oN4P0ogQ70?n0C`3oRUT0ohaK2P3oReX00`3o
S5d0oh]K0?n;FP0=0?n;FP030?n<G@3oRUT0oh]J00@0oh]J00<0ohaL0?n;FP3oReX01@3oReX01`3o
RET0XDL_02@>2@030@00YC`_0?m`FP3oKUT02P3oK5P0103oKEP0ofmI0?m`F`3oKUT>0?m/F0040?m/
E`3oL5/0ofiI0?m]F0d0ofaH00l0ofeH0?m_FP3oKe/0ofeG0?m[E@3oIU40ofA=0?mPBP3oG4H0oe]5
0?mMA`3oGTT0ofE?0?m[E@3oJeL00`3oKET02@3oL5/0ofUD09@e:P0D1@@02`82060G5P3L@T40oeYH
0?mHEP0>0?mGE@040?mHEP3oFEP0oeED0?mHEQ40oeME00H0oeIE0?mGE@3oEeH0oe]I0?mGE@3oF5HC
0?mGE@060?mDD`3oFeX0ofE^0?m_PP3oM900ogJC0P3oMI<01@3oMY@0ogJC0?meT`3oMI<0ognK00@0
ogFC00H0ogJC0?mbS`3oKX/0off;0?maSP3oK8/20?m]R`070?m^R`3oIGX0of1V0?mFE@3oEE<0oeYI
0?mGE@020?mED`070?mEE03oFEL0oeID0?mED`3oH5l0oeQF0?mRH@040?mFD`0=0?mKF@3oEe@0oeME
0?mLFP3oEU<0oeIB0?mGE@3oEU@0jd4o0000000O3@L0nh];0?nLD`020?nLE00A0?nME@3oYF<0oieE
0?nRG`3oWUP0oiaD0?nKD`3oVe40oiaC0?nLE03oWED0oj1J0?nME`3oVe@0oiaE0?nPG@3og/X0o`3o
oonU0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWio@0oooo
01@0ok>^07]4:P1oAbh0ND<Y07Q2:01oAbh0Md4W07]4:P1i@bT0N48X08M==01oAbd0PTT`07Q2:01i
@bT0N48X078m8@1nAR`0Md4W07E09P80ND<Y00D0Md8W07U3:@1i@bT0ND<Y07Q19`0207U3:@0307]4
:P1mAR`0Nd@Z00<0ND<Y00@0TE@l07]4:`1nAR`0Q4/a1P1i@bT01@1h@RP0MD0U07I09@1lAB`0OTH]
00D0ND<Y00D0MT4X08A;<02ZGSH0jWm20>n0@P060>io@P030>n0@P3^Od80kWm200@0kWm200D0kX52
0?F4A@3eQ4@0mHA40?J6B@030?F4A0040>an@P3oVTh0okYL0?noG0D0ok]K00<0okaL0?nmGP3o^e/0
0P3o^e/00`3o_5`0okaQ0?nkF`0G0?nkF`030?nlG03o_Eh0ok]J0180ok]K00P0ol=N0?N3?`138a00
000002H?2P3hHCh0oiAQ0?n<Fa00oh]J00<0ohYI0?n?H03oRUT04@3oReX00`3oRe/0ohaK0?n9F00B
0?n;FP030?n;F`3oReX0oh]J00d0oh]J00<0ohYI0?n;FP3oS5/03`3oReX00`3oSEh0ohYI0?n;FP0=
0?n;FP080?n=GP3oRUT0ohAC0?mjB@3oN4L0ogm?0?n9F03oS5/70?n;FP030?n8FP3oS5`0oh]J00`0
oh]J00@0ohUH0?n>G`3oSf00ohYI2`3oReX00`3oRe`0oh]J0?n;FP0<0?n;FP030?n:F@3oReX0oh]J
0080oh]J00D0ohUH0?n;G03oSf80oheM0?n:F`020?n:F@040?n;FP3oRET0ohmQ0?n:F``0oh]J00<0
oheM0?n:F`3oReX02`3oReX00`3oREP0ohYI0?n;FP0;0?n;FP030?n;F`3oRU/0oh]J00X0oh]J00<0
ohUI0?n=GP3oRe/0303oReX00`3oSUl0oh]J0?n;FP090?n;FP040?n8E`3oN4L0ogM60?n3E@d0oh]J
00<0ohMG0?n=G@3oReX02P3oReX01`3oS5/0ohMF0?mkB`3oM4D0ogQ:0?n6E@3oS5/02P3oReX00`3o
RET0ohaN0?n:F`0>0?n;FP030?n<FP3oRU/0oh]J00D0oh]J00<0oh]K0?n;FP3oREP0103oReX01P3o
Re/0WDH^000000080P40_cT]0?m`F`/0ofaH00<0ofaG0?m_FP3oLE`03`3oK5P00`3oKUT0ofaE0?m]
F@0?0?m/F00;0?m]F03oKUP0ofI?0?mOBP3oG4H0oeQ20?mG@@3oGDH0ofE>0?mYE03oKEL00P3oKET3
0?m/F080ofiI00L0cSh`03@?30000000IaDE0?m1?`3oFUP0oeQF00h0oeME00<0oeED0?mJF03oEU@0
4`3oEeD01@3oEE@0oe]J0?mGE@3oF5H0oeED01<0oeME0P3oEE@01P3oG5X0oeMF0?mDD`3oEeD0oeQK
0?mbRP<0ogJC0`3oMI<00`3oM980ogFC0?meT`020?meT`040?meTP3oK8X0off;0?m]R`80ofb:103o
KH/01@3oKX/0ofZ20?mIFP3oEeD0oeAB00@0oeEC00D0oeUG0?mED`3oE580oeAB0?mSHP040?mFD`04
0?mDDP3oDe40oeME0?mMF`80oeEC00/0oeMD0?mFD`3oDe00000001880`3^PdL0oiaC0?nSG`3oWeT0
oieE0?nUH`020?nLD`<0oiaD00H0oj1K0?nNEP3oVe<0oi]B0?nQG03oXUh20?nKE0030?nQG@3obZP0
oooo0?l0ooooY03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOd0?ooo`080;YcHP1/>1`0O4D[07U3:@1f@BL0R4`e08A;<@1h@RP207U3:@0:07U2:028C3D0Re0g
07I19`1i@bT0MClU0899<01iA2T0N48X07I19`80ND<Y00D0MT4W07U3:@1i@bT0ND<Y07M19`0207U3
:@0307E09P1i@RP0ND<Y00<0ND<Y00@0TE@l07a5:`1i@bX0O4D[1P1i@bT0101f@2H0O4D/07a5:`1l
AB/507U3:@0507Q2:@24BBl0`FXj0>Un@@3`PD801`3^Od800`3]Od00kWm10>io@P040>io@P0;0>j1
@P3dQDH0mHA40?F3@`3lRe00mHA50?B3A03dPD<0oia?0?nkG03o_5/0203o^e/01`3o_F00ok]J0?nk
F`3o^e/0okaL0?nkFP3o_5h05P3o^e/0103o^eX0okaM0?nmH03o_5`A0?nkF`090?nmG03o`eh0ojUC
0:EG:@030P005`P509Pk9P3oP5@0ohaK0100oh]J00<0ohYK0?n=GP3oREP04P3oReX00`3oS5/0ohaN
0?n;FP0@0?n;FP030?n<F`3oReX0oh]J00l0oh]J00<0ohUH0?n;FP3oReX03@3oReX00`3oSEh0ohYK
0?n;FP0=0?n;FP080?n<G03oS5h0oh]J0?n8E`3oNTT0ogM60?mkBP3oQUD80?n;FP030?n<F`3oRUT0
oh]J00d0oh]J00<0ohaK0?n:F@3oReX02P3oReX00`3oRUT0oh]J0?n;F`0<0?n;FP080?n;G03oS5`0
oh]J0?n;FP3oSUl0oheN0?n;FP3oRe`60?n;FP030?n9F03oRUT0oh]J00/0oh]J00<0ohmQ0?n=GP3o
ReX02`3oReX00`3oS5/0oh]J0?n;FP0;0?n;FP030?n:F03oReX0oh]J00X0oh]J00<0ohYI0?nDI`3o
Re`0303oReX00`3oSEd0oh]J0?n;FP090?n;FP040?mnC@3oMTD0oge=0?n9F0d0oh]J00<0oi1R0?n:
F@3oReX02P3oReX01P3oQ5<0ogY90?mfA@3oOdl0ohUH0?n<F`/0oh]J00<0ohYK0?n<F`3oReX03@3o
ReX00`3oRUT0ohaM0?n;FP070?n;FP030?n;F`3oReX0ohUH0080oh]J00L0oh]K0?mcB`0L2`L030<2
0<8k;`3oLU`0ofiI00/0ofaH00<0ofiH0?m_FP3oK5P03P3oK5P00`3oLE`0ofeG0?m/F00?0?m/F00;
0?m/E`3oHd`0oea70?mLA@3oFD<0oe]40?mRB`3oIe40of]D0?m/F03oKET01P3oK5P0203oIU80KR4J
00/30P000000K1TH0?mBD03oFEP0oeMF3`3oEeD00`3oF5H0oeUG0?mEE00B0?mGE@050?mHEP3oFEP0
oeQF0?mGE@3oEUD04`3oEeD01@3oEE@0oeiM0?mFE03oF5L0oeIE0080oeME00@0oeEC0?mMH03oKHP0
og>A103oMI<00`3oM980ogBA0?meT`020?meT`030?m_S@3oKH/0off;0080off;00<0ofb:0?m]R`3o
KH/00`3oKH/00`3oKX/0ofIi0?mED`060?mED`040?mEE03oE580oe=A0?mTH`D0oeIC0P3oEU@03P3o
FEP0oeEC0?mED`3oEE<0oeQF0?mBC`0<0@800P000=Yl@`3oVU80ojAR0?nPFP3oWED0ojIU0P3oW5<0
2@3oWUH0oiaD0?nLE03oYF@0oj5L0?nLD`3oVe80oj=O0?nPG0020?nKE0030?nSH03o/g`0oooo0?l0
ooooY03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOc0?oo
o`090?oBdP22BC00LC`Q07M19`1i@bT0N48X07m7;P27CSD0N48X0080ND<Y00X0MD0U08Q<=@2:CcH0
MT4W07U3:@1lABX0Nd@Z07U3:@1h@BL0N48X0P1i@bT0201kABX0ND<Y07U3:@1i@bT0Md4W07U3:P1f
@BL0N44W1@1i@bT01024BS80Nd@Z07Q19`1h@RP507U3:@0407Q2:01e?bD0OdH/07Q2:@D0ND<Y00D0
N44Y08A9;03?L3d0iGTn0>n3B@070>io@P030>io@@3dQT`0k7i000H0kWm200T0lH=50?B3@`3dPd<0
m8A20?F3A03oT4/0ok5L0?nlF@3o_5`02@3o^e/00`3o_5`0okeP0?nkF`040?nkF`030?noH`3o^eX0
ok]K01H0ok]K00<0okeP0?njFP3o^e/0403o^e/0103o_5/0ol1M0?nkF`2NEBT200000003044K4@3o
O500oh]K0140oh]J00<0ohUH0?n<F`3oReX04P3oReX00`3oS5/0oh]J0?n;FP0>0?n;FP030?n9F03o
S5/0oh]J0100oh]J00<0ohYI0?n;FP3oReX03@3oReX00`3oSUl0oh]K0?n;FP0=0?n;FP080?n<F`3o
ReX0oh]J0?n5EP3oNDP0ogM60?miB03oQUD70?n;FP030?n<G03oSUl0ohYI00d0oh]J00<0oh]L0?n<
F`3oRUT02P3oReX00`3oRUT0ohmP0?n;G00<0?n;FP060?n>H03oRe`0ohaL0?n?HP3oRUX0oh]K203o
ReX00`3oRUT0ohQG0?n;FP0;0?n;FP030?n?H@3oSEh0oh]J00X0oh]J00<0ohQH0?nEJ03oReh0303o
ReX00`3oREP0oh]J0?n;FP0:0?n;FP030?n9F@3oSV40ohYK00`0oh]J00<0ohUH0?n;FP3oReX01`3o
ReX01P3oS5/0ohAC0?mgAP3oO4/0ohaM0?n:F``0oh]J00<0ohYI0?n;FP3oReX02P3oReX0103oOdl0
ogQ70?mgAP3oOTd=0?n;FP030?n:F@3oRe/0ohaL00d0oh]J00<0ohUI0?n>G`3oRe/02@3oReX02P3o
RU/0oh]J0?n;FP3oSe`0og9:03DD30080`80aC`_0?mbG03oKeT;0?m/F0030?m]E`3oKEP0ofaH00h0
ofaH00<0ofmJ0?m^F@3oK5P03@3oK5P02P3oK5H0ofI?0?mNB03oFT@0oe]40?mJA@3oG4H0of9;0?mZ
E03oKEL70?m/F0040?m]F03oKUT0ofaH07/T7080000000<0HADD0?m>C@3oF5L03`3oEeD00`3oEU@0
oeiM0?mEE00C0?mGE@030?mHEP3oFEP0oeME01D0oeME00<0oeEC0?mKF@3oF5H0103oEeD01P3oF5H0
oeED0?mMF`3oEeT0ofam0?mdT@@0ogFC00D0ogVF0?meT`3oMI<0ogND0?m^S0030?m]R`030?m_S03o
LXl0ofb:00D0off;00<0ofj<0?mXNP3oG6001@3oEE<0103oE580oeEC0?mSH@3oFEL50?mFD`030?mR
H03oEU<0oeEB00<0oeEC00H0oeaJ0?mIEP0[2@P000000=Ei@@3oW5@20?nLD`030?nLE03oVe80oiaD
0080oiaD00d0oieF0?nKD`3oY680oj9N0?nLD`3oW5@0oimH0?nKDP3oVe@0oiaE0?nRG`3oYFH0ooC`
0?l0ooooY03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOb
0?ooo`050?oemP2hLf80MT0U08aA>01h@RP00P1i@bT02`1g@BH0Qd`d07Q2:01i@bT0ND<Z07U4:P26
C3@0RDhf07M19`1kABX0S54h0080ND<Y00D0Md4W07U3:@1i@bT0N48X08E<<P0207U3:@0607M2:024
BS40Md8W07Y4:P2>DST0NT@Z101i@bT00`1e@2H0ND<Y0899<00507U3:@0407Y4:P1i@bP0MClT07e6
;0@0ND<Y00P0Md8Y07e5;02HDc00eG8m0>Qk@P3VO440iGY00>f0@`L0kWm200<0l8=50>eo@@3^Od80
1@3^Od801`3_P4<0kX120?b;CP3jS4T0ojQE0?nkG03o_5/0303o^e/0103o_5`0okaK0?nlG03o_5`3
0?nkF`030?nmG@3o_5d0okaL01H0ok]K00@0ok]J0?nmGP3o_5`0okaL403o^e/02P3o_5/0okUJ0;j0
?@1oA20070l7030C302XDC@0og]@0?n>G03oS5/?0?n;FP030?n<G@3oS5`0ohYJ0140oh]J00<0ohaL
0?n=G@3oReX0403oReX00`3oSEd0ohaL0?n:FP0=0?n;FP<0ohaK3P3oReX00`3oRUT0oheM0?n;F`0=
0?n;FP0<0?n<F`3oSEh0ohaK0?n<F`3oREP0oh=B0?mlB`3oNDT0oh5@0?n8E`3oReX0ohaK103oReX2
0?n<G0030?n:FP3oReX0oh]J00X0oh]J00D0ohaL0?n;F`3oS5/0oh]K0?n<F`0:0?n;FP030?n=G@3o
Re/0oh]J00H0oh]J00H0ohaK0?n9F@3oS5d0oi1P0?n:FP3oRUT=0?n;FP030?nBI@3oRe/0oh]J00X0
oh]J00<0ohmQ0?n<G@3oReX02P3oReX00`3oR5P0oiEY0?n;GP0;0?n;FP030?n:F@3oSUl0ohYJ00/0
oh]J00<0oheM0?n;FP3oReX02`3oReX00`3oRET0ohiN0?n;FP070?n;FP060?n9F03oOdh0ogQ70?mo
CP3oRe/0ohaK3@3oReX00`3oS5`0oh]J0?n;FP060?n;FP070?n;F`3oReX0ohMF0?mlB`3oNDP0oge<
0?n6E`0=0?n;FP030?n:FP3oSUl0ohaM00`0oh]J00@0oh]K0?n<G03oSEd0oh]K2`3oReX0203oRe/0
ohUI0:eC=@0O30P020<20:Tm<@3oKeX0ofeH2P3oK5P00`3oKET0ofiI0?m]E`0>0?m/F0030?m]F@3o
KeT0ofiJ00P0ofaH0P3oKET01P3oK5P0ofYF0?mVD@3oHTd0of190?mLA@80oee700<0of5;0?mVD03o
JU@02@3oK5P02P3oKET0ofmI0?ELB02F=b/0@Q@@01L51@2<8B00fD=20?mGE@3oF5H<0?mGE@050?mF
E@3oF5H0oeQG0?mJF03oEU@04P3oEeD0103oF5H0oe]J0?mFE03oFeTB0?mGE@070?mFE@3oEeD0oeQG
0?mIE`3oEUD0oeQF0?mFE@020?mHEP040?mGE@3oFUP0oeME0?mMG0<0oeME00@0oeQF0?mJG@3oK7h0
ogJB0P3oMY<0103oNIH0ogJC0?mfT`3oL8d40?m]R`030?m`SP3oMI<0ofb:00D0off;00D0ofj;0?m_
S03oLH/0of9c0?mGF0050?mED`030?mHEP3oE580oeIC00@0oeIC00<0oe]I0?mED`3oE5800`3oEE<0
1@3oEU@0oe=@07@I6@000000^6hl00<0oiaD00P0oieE0?nKDP3oW5@0oi]C0?nRGP3oWEH0oieD0?nT
H`<0oiaD00<0oiaC0?nLE03oWEH00P3oW5@0103oW5<0omBn0?C?dP3on?go0?oooj80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWlP3oool0103of=H0JCLJ08iC
>`2;D3L207U3:@0<07a6:`1i@bT0Qdde07Q2:01i@bT0O4@/08=:<@24BS80Qd`d07U3:01oAbd0O4D/
0P1i@bT01@1g@BL0ND<Y07U3:@1i@bT0Nd@[0080ND<Y00H0N48X0859;`1i@bT0N48X08M<=01jA2X4
07U3:@0307I09P1kA2X0TUHm00@0ND<Y00<0O4@[07]4:P1h@BL00P1h@RP307U3:@0:07I1:02@Cc00
bVhm0>am@P3UNT00lHMA0>UlA03VNT00j7e40>in@0H0kWm200<0kh530>io@P3^Od801@3^Od801@3Y
OT00ohe<0?nXE@3o_EX0okaK0100ok]K00<0okeM0?nmH@3o^eX0103o^e/00`3o_5`0ok]J0?nmGP0F
0?nkF`040?nlG03o_V00ok]J0?nlFa00ok]K00P0okaK0?o6H@3o[5@0B2HA000000080`40_T/a0?n9
FQ00oh]J00<0ohaK0?n<G03oRe`0403oReX0103oRUX0oh]L0?n>GP3oRUT@0?n;FP030?n=G@3oRE/0
ohYI00d0oh]J00@0ohUI0?n<GP3oReh0ohYJ3P3oReX00`3oS5l0ohaK0?n;FP0<0?n;FP030?n9F@3o
S5/0ohYJ00<0oh]J00@0ogm>0?mgAP3oMdH0ogm?1@3oReX20?n:F@d0oh]J00H0ohaK0?n:F`3oReX0
oh]J0?n;F`3oS5`80?n;FP030?n:F@3oSUl0oh]J00@0oh]J00D0ohYI0?n=GP3oRU/0oheO0?n;FP02
0?n:F@030?n;FP3oTVD0ohaL00/0oh]J00<0ohYI0?nBIP3oRe/02`3oReX00`3oSf40oheN0?n;FP0:
0?n;FP030?n8F03oUFT0oh]N00/0oh]J00<0ohYI0?n@H`3oReX02`3oReX00`3oU6L0ohiO0?n9F@0:
0?n;FP030?n9F@3oSEh0oh]J00L0oh]J00L0ohUH0?mhA`3oMdH0ogY90?n9F03oRe/0ohYK00d0oh]J
00<0oh]L0?n;FP3oReX01@3oReX0203oS5/0ohMF0?mlC03oM4D0ogY90?n4E03oSUh0ohYI3@3oReX0
0`3oSEh0ohYI0?n;FP0=0?n;FP80ohYI303oReX01P3oTf40W4H^0000000A0`80cSla0?m`F`/0ofaH
00<0ofiI0?m_FP3oJeD03P3oK5P00`3oL5/0ofiI0?m]E`070?m/F00;0?m]F@3oK5P0ofQC0?mUC`3o
HDX0oeU30?mH@@3oFTD0of1:0?mTCP3oJUD00P3oKET:0?m/F0030?m`FP3oM5d0aD<e0080000000<0
8@H60=Hn?@3oFeT03P3oEeD01@3oEUD0oeQF0?mKF@3oF5H0oeIE01<0oeME00<0oeQF0?mEE03oEeD0
4`3oEeD01@3oFeT0oeME0?mHE`3oEE@0oeME0080oeQG0P3oG5X00`3oEE<0oeIE0?mGE@070?mGE@07
0?mPJP3oL8P0ogND0?mcT03oMI<0og>A0?m/RP0<0?m]R`070?m^R`3oJXP0og6>0?m]R`3oI7P0oeQE
0?mCD@030?mED`040?mCD@3oD4l0oeID0?mDDP<0oeIC00<0oeAB0?mCD@3oE5801@3oEE<0401V5aH0
000009e?:`3oXUL0oiaC0?nUI03oWEH0oiaC0?nJD@3oWED0oieF0?nLD`3oWEH0oi]@0?nME@3oWE@2
0?nME@080?nLE03oWET0oiM@0?nEC@3oSDP0IBL<0000003oa<_o0?oooj80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWlP3oool04P3J/:/0JCLK08aC>P24BS00
ND<Y07a5:`1i@bP0Kc/Q08U?=`1h@RP0ND<Y07a4;024Bc80ND<Z07]5:P1nAR`0NT<Y07Do9@80ND<Y
00H0PTT`07Q2:01i@bT0N44W07M19`1i@bT207Q2:00408A:<P1h@RP0ND8X078m8`@0ND<Y0P1h@RP0
0`1kA2X0PTT`07U3:@0207U3:@0607U2:020Abh0N44W07i5;@2>DcX0O4D[0P1i@bT0101h@RP0S4d^
0=Ye@03^Od820>Ik@@060>f1B`3WO4<0iW]10>Ej@@3^PD@0kWm1103^Od800`3`PDH0lXE80>io@P05
0>io@P070>Ik@03gS4P0okEJ0?o0H03o_5`0okeO0?nkFP0?0?nkF`030?nkFP3o_5d0okeQ00D0ok]K
00@0ok]J0?nmH@3o^UX0okaN5@3o^e/00`3o^UT0okaL0?nmG`0B0?nkF`030?o4G`3aW4`0>Ql>0080
000000@0]4L^0?nDHP3oSE`0ohUJ3P3oReX00`3oRUT0oheN0?n<G00A0?n;FP<0ohaK403oReX00`3o
SUl0ohYK0?n:FP0=0?n;FP030?n9F@3oSEh0oheM00l0oh]J00<0oheM0?n;FP3oReX02`3oReX00`3o
RET0ohYK0?n<F`030?n;FP050?n:F@3oOTh0ogM60?mdA@3oP4l0103oReX00`3oRET0oh]L0?n:F`0=
0?n;FP070?n=GP3oRU/0oh]J0?n:F@3oSUl0oh]L0?n9F@070?n;FP090?n:F@3oS5d0oh]J0?n:F@3o
R5P0oheN0?n:F@3oSEh0ohaL00D0oh]J00<0ohmP0?n:F`3oReX02P3oReX00`3oRET0ohYK0?n;F`0;
0?n;FP030?n@HP3oSEh0oh]J00X0oh]J00<0ohQH0?nEJ@3oReh02`3oReX00`3oR5P0oi1R0?n9F@0;
0?n;FP030?n;G03oS5/0oh]J00X0oh]J00<0ohUI0?n@H`3oRe`01P3oReX0203oS5/0oh1?0?mgAP3o
NTT0ohQG0?n=GP3oRe/0ohYI2`3oReX00`3oRUT0ohaK0?n;FP060?n;FP080?n<F`3oQUH0ogY90?me
A03oMdP0ohAD0?n>G`3oS5`=0?n;FP030?n<G03oRe`0oh]J00d0oh]J0P3oRUT<0?n;FP070?n@GP3o
OU<0:Q4;00000033?S<0og=L0?m]F@0;0?m/F0030?m`F`3oKEL0ofaH00d0ofaH0P3oKeX00`3oKEL0
ofaH0?m/F0030?m/F00=0?m]F@3oKUX0ofaG0?mYDP3oHT`0oee60?mH@P3oEd40oee60?mVD03oIe40
ofUD0?m^F@0<0?m/F0080?maF`3oKEP0dCla01/81P000000IQLF0?lm?03oFUT>0?mGE@040?mEE03o
FEL0oeQF0?mGEQ40oeME00@0oeIE0?mGE@3oFEL0oeQF503oEeD01P3oEeH0oeID0?mLFP3oEE<0oeIE
0?mKFP80oeQF00<0oeYH0?mEE03oEE@02@3oEeD01`3oEUD0oe=A0?mKGP3oK7d0ogRE0?m`SP3oK8X0
1P3oKH/20?m/RPD0off;00P0ofn<0?m[RP3oJHP0ofV80?mZR03oHW40oeID0?mED@<0oeEC00@0oe]I
0?mGD`3oE580oeAB0P3oEU<0103oEU@0oeeL0?mKF@3oE5830?mED`0L0?mQH02V:2L000000:1B:`3o
XUL0oiaC0?nSG`3oWED0oiaD0?nNF03oW5@0oiaC0?nME@3oWeT0oiaE0?nKDP3oV580oiE<0?nCB`3o
RdH0oha30?n7?`3oQSh0oglk040L30000000g9RN0?olool0ooooX@3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOb0?ooo`090;IoK`1f@2H0Se<k07m7;P1i@bT0
NdDZ0858;`21Abl0P4P^0080ND<Y01D0Nd@Z07m7;P1e?bD0NT<W07]4:P1f@BL0ND8X07U3:@1h@RP0
RDhf07I19`1i@bT0N44W07U3:@1i@RP0ND<Y07a4;028CSH0N48X07Do9@1h@BL0101i@bT207Q2:00@
07Q19`1c?R@0ND<Y07U3:@1h@RP0OTH/07]4:`1i@RP0OTH/09QJA@21BC00ND<Y07I19`1oAbd0bVdl
0>]m@@80iW]100L0iG]10>=i?P3VNT00iW]10>Ik@P3ZOdD0kh=400@0kWm200<0kh130?23AP3^Od80
103^Od802P3VNd00oh]60?ndFP3o_E/0ok]K0?nkFP3o_Eh0okeM0?nlG@3o^eX>0?nkF`030?nkFP3o
_5h0ok]K00D0ok]K0P3o^eX00`3o_El0okeM0?nkFP0E0?nkF`030?nlG@3o_F00ok]L0140ok]K00T0
ol=O0?nRC`29BB<0000000l50`2_A2d0ohIG0?nAH03oRUX03`3oReX00`3oS5`0oh]L0?n:F@0@0?n;
FP030?n<G03oS5/0oh]J0100oh]J00<0ohiO0?n:F`3oReX03P3oReX00`3oSEh0oh]J0?n;FP0=0?n;
FP80ohYI3@3oReX00`3oRET0ohaL0?n:F@020?n;FP080?n<F`3oReX0oh5A0?miB03oMdH0oh1@0?n9
FP3oS5/20?n;FP030?n:F@3oS5/0oh]J00`0oh]J00<0oh]K0?n9F03oReX00P3oReX00`3oSUl0ohUK
0?n;FP070?n;FP070?n=G@3oRUT0oheQ0?n;G03oS5d0oh]K0?n:F@060?n;FP80ohQG303oReX00`3o
R5L0oh]J0?n;FP0:0?n;FP030?n<G03oRe/0oh]J00X0oh]J00<0ohYI0?nEJ03oSEh0603oReX00`3o
RUT0ohUF0?n:F@0;0?n;FP030?n9F03oQeL0oh]J00D0oh]J00P0ohaK0?n6E@3oNDP0og]:0?n7EP3o
S5/0ohaL0?n;G0`0oh]J00<0oh]L0?n<G03oRe/01@3oReX0203oSE`0ohQG0?mjBP3oMDH0og]:0?n6
E@3oS5/0oheN3P3oReX00`3oSEl0oh]J0?n;FP0=0?n;FP030?n<G@3oReX0oh]J00X0oh]J00P0ohmM
0?mnD`1E8QH000000:Xe:P3oLed0og5M0?m]F0T0ofaH00<0ofeG0?m`F`3oKUX03P3oK5P00`3oKEL0
ofiJ0?m/E`040?m/F080ofeI00`0of]F0?mUCP3oH4X0oea70?mH@P3oFD<0oem80?mSC03oJU@0og9M
0?m]F@3oKEP<0?m/F0090?m`FP3oGd/0PbLO000000050@40^2/Z0?mCD@3oG5X0oeQF00h0oeME00<0
oe]I0?mHEP3oEE@04@3oEeD01@3oEE@0oeUG0?mFE03oF5H0oeED0180oeME00/0oeED0?mHEP3oFEL0
oeID0?mED`3oFeX0oeUG0?mJF@3oF5L0oeID0?mFE@0=0?mGE@040?mED`3oF5L0ofMg0?maSPh0off;
00T0ofb:0?mZR03oJ8L0ofV80?mZR03oK8X0ofAg0?mDEP3oEE800P3oEE<00`3oIF@0oeME0?mFE002
0?mDDP80oeIC00<0of=Q0?mOG@3oDe400`3oEE<01P3oHV40h3Tf0000002KC2T0ojAK0?nKD`80oieE
01@0oimJ0?nWI@3oWE<0oiQ@0?nEC@3oTTT0oi9:0?n?A@3oQ400oh]00?n:?`3oO3T0ohHn0?n:@P3o
SDH0ohi706la6@000000ME5D0?obmol0ooooX@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOa0?ooo`0:0?oYj`28CCH0ND8X08E<<`2?E3/0O4D[07U2:025Bc<0
Re0h07I09P80ND<Y01D0Md4W07U3:01i@bT0Nd@Z07Y4:P20B2l0Nd@[07U3:@1h@RP0Qddd07M19`1h
@RP0SE8i07]4:`1nARd0O4D/07Q2:027C3@0MT4W08Q>=@1lAB/0101i@bT00`1kA2/0NT@Z0818;`02
07U3:@0307Y4:P1mARd0O4D[0080ND<Y00L0OdH]08aA>@1g@BP0QTXZ0;1P=`3GLcl0ig]100<0iW]1
00<0iWa20>Ik@P3VNd400P3VNd400`3UNd00j7e20>j1@`020>io@P030>j0@`3_PT@0kWm200<0kWm2
00D0l8930?FEC@3oZ5@0ok]L0?nmG0040?nkF`80okaL00<0okeM0?nlG@3o^e/03P3o^e/00`3o_5/0
okaL0?nlGP050?nkF`@0okaL00<0okaM0?nkF`3o^e/04P3o^e/0103o_5`0ok]J0?nlG@3o_5`@0?nk
F`090?o1GP3o^E/0nJ1>06Ln7@000000;a8<08dk9P3_O500oh]K00h0oh]J0P3oRe/00`3oSEl0ohaL
0?n;FP0@0?n;FP030?n<G@3oSEd0oh]J00l0oh]J00<0oheN0?n:FP3oReX03@3oReX00`3oS5/0oheM
0?n<F`0>0?n;FP030?n<G03oRe/0ohYJ00`0oh]J00<0ohaL0?n;F`3oReX00P3oReX0203oS5/0oh]J
0?n:F@3oP4l0ogU80?mjB@3oP4l0ohUI0`3oReX00`3oRe`0oh]J0?n;FP0;0?n;FP030?n>GP3oReX0
oh]J0080oh]J00<0oheM0?n<G03oReX00`3oReX01`3oS5`0oheN0?n;FP3oSel0oh]J0?n;G03oS5/0
2P3oReX00`3oT6@0oh]J0?n;FP0:0?n;FP030?n:FP3oSEd0oh]J00X0oh]J0P3oRUT;0?n;FP030?n8
F03oUFT0oh]N00/0oh]J0P3oRUT;0?n;FP030?n=G`3oSf40ohYI00/0oh]J00<0ohiP0?n=GP3oReX0
0`3oReX02P3oS5/0ohYI0?n1D03oNDP0oga;0?n:F@3oS5/0ohYI0?n<G@3oRUT;0?n;FP030?n<G03o
S5d0oh]J00D0oh]J00D0ohIE0?mnC@3oNDP0og]:0?n5E0020?n;FP030?n<G@3oRUX0oh]J00/0oh]J
00<0ohYI0?n=G@3oS5/03@3oReX20?n=G@030?n;F`3oReX0oh]J00T0oh]J00H0ohQI0:Q?=00Z4@/0
000009Lg;@3oL5/20?m^F@030?m`F`3oKEP0ofaH00D0ofaH00@0ofeH0?m^F@3oL5/0ofiJ3@3oK5P0
103oKe/0ofiI0?m/EP3oKET20?m/F00>0?m]F@3oJUD0ofIA0?mRC@3oH4X0oea60?mLA@3oGDP0of5;
0?mWD@3oJeH0ofeH0?m`F`3oKeX<0?m/F0080?m]F03oKeX0ofUD09/g;00N2@L01@4205/F5@3E?ch2
0?mHE`d0oeME0P3oFEL20?mHEQ40oeME00<0oeQG0?mGEP3oFeT0503oEeD20?mHEP080?mJF03oGE/0
oeUG0?mKFP3oEeD0oeQF0?mGEP3oEUD?0?mGE@080?mHE`3oEeH0oeUG0?mIE`3oH6P0ofMk0?m/RP3o
KX/40?m]R`030?meT`3oM980ofb:0080off;00<0ofj<0?m`S@3oJhT00P3oJXP02`3oJ8L0ofZ80?mZ
R03oJhT0ofR30?mMI03oEU<0oeEC0?mGEP3oG5X0oeIC0080oeID00D0oeEC0?mFD`3oEE80oeiL0?mD
DP030?mED`0L0?mFE03oBDP0000008Dl7`3oXEH0oiI?0?nCBP3oTDT0ohe50?n6@`3oSD<0ohQ10?n7
@03oST@0ohi50?nABP3oSTH0oiE<0?nFC@3oVeH0oiYA0?nKD`3oX5`0oj=N09Y48`000000@Bd_0?o^
lol0ooooX@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOa
0?ooo`0:0?o2_@1d?b@0ND<Y07Q19`2?DcX0O4D[07Q2:01nARd0PDP_07M09P80ND<Y00l0MT0V07Q2
9`1e@2@0Nd@Z07U3:@25Bc80O4D[07U3:@1h@RP0R4de07I19`1h@RP0Qd`d07a5:`1h@BL00P1i@bT0
101g@BL0N48X08iC>P1lAB`407U3:@0608=:<@1nARd0SU8i07U3:@1h@RP0O4D[101i@bT01@1kA2/0
PTT`09AB<@3PMch0jGa100D0iW]100<0jGm70>UnA@3VNT000`3VNd403@3TNT40iga30>io@`3^Od80
kh=40?R:D03]Od80kWm20>]o@@3^Od80ojQD0?nlG03o_5/02P3o^e/00`3o_E`0okeP0?nkFP0=0?nk
F`030?nkFP3o_5`0okeP00P0ok]K00<0okeO0?nkFP3o_5/05@3o^e/00`3o_5`0okeP0?nkFP0@0?nk
F`070?nlF`3o^e/0h7Hi028@1`000000<Q@<0?m_B@020?n<F`l0oh]J00<0ohYK0?n:F@3oReX0403o
ReX00`3oRU/0ohiO0?n;FP0?0?n;FP030?n<G`3oReX0oh]J00h0oh]J00<0ohYI0?n<G03oReX0303o
ReX00`3oRUT0ohaN0?n=GP0=0?n;FP030?n<GP3oRe/0oh]J00D0oh]J00P0ohIE0?mjB@3oN4L0ogY:
0?n8E`3oS5/0oh]J0?n=G@h0oh]J00<0oi9V0?n;FP3oReX00P3oReX02P3oSEd0oh]J0?n:F`3oRUT0
oi5S0?n9F03oRU/0oh]J0?n<G03oRUT<0?n;FP030?n8E`3oRET0oh]J00X0oh]J00<0ohUI0?n?HP3o
ReX02P3oReX20?n:F@/0oh]J00<0ohQH0?nEJ@3oReh02P3oReX00`3oRUT0ohmP0?n<G00;0?n;FP80
ohYI2`3oReX00`3oRUT0ohUH0?n;FP050?n;FP040?mlC03oMdH0ogQ70?n9F080oh]J00<0oh]K0?n<
F`3oReX02`3oReX20?n:F@D0oh]J00D0oh5@0?mgAP3oN4L0oge=0?n:F@020?n;FP80ohYI303oReX0
0`3oRUT0ohaO0?n=GP0<0?n;FP030?n:FP3oSV40oh]J00`0oh]J00H0oh]K0:M><`0000000`410:df
:`3oL5X30?m/F0030?m^F@3oLE`0ofeG00D0ofaH00<0ofeG0?m]F@3oK5P03@3oK5P02@3oL5X0ofmJ
0?m/F03oKET0ofaH0?mYE03oI4l0oem90?mKAP020?mJA@030?mLA`3oIDl0of]G0080ofaH00@0ofeI
0?m/F03oLUd0ofeH303oK5P02@3oKUT0ofaG0>M4=@0_30T00000054A4@3o@T00oeME0?mHEP0>0?mG
E@030?mKF@3oEeD0oeME0180oeME00<0oeYH0?mGE@3oEeD0503oEeD01@3oF5H0oeYI0?mKF@3oEU@0
oeQF01@0oeME00<0oeaJ0?mGE@3oEeD00P3oEeD0103oEU@0oeAB0?mLH`3oK8P40?m]R`030?meT`3o
M980ofb:0080off;00<0ofb:0?mZR03oJXP00P3oJXP00`3oJhX0ofZ80?mZR0020?mZR0050?mYQP3o
GfP0oeID0?mED`3oFEH00`3oEU<0103oEU@0oeIC0?mFE03oGU`20?mCD@0B0?m?C@3oC4X0odM50?li
=`000000Hb/D0?nBA@3oSD80ohU10?n5@03oSDH0ohe:0?nGC@3oV500oiYB0?nLE03oWED0oj5K0P3o
W5802P3oW5<0oj5K0?nLDP3oVe<0oiaE0?nYHP2oERh00000024F4`3oj^ko0?oooj40oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWl03oool0403onOl0eHUl07M1
9`1h@RP0Q4Xb09AF?P1lAB`0ND<Y07Q2:01e?bD0ND8W07U3:@1i@bX0TE@l07m7;@1c?R@207U3:@09
07e5;01kA2X0ND<Y07Q2:029CSH0MT4W07U3:@1e?bD0Nd@Z00<0ND<Y00@0Md4W07]4:P1e?bD0N48X
101i@bT01@22BS40OTH]07m7;P1i@bT0NT@Y00D0ND<Y00<0ND8Z095C=`3DLSh01`3VNd400`3ZOdH0
jGi50>Ij@0040>Ik@@0:0>Mk@`3]P480kWm20>j1@P3`Q4L0kGm10>Ym@P3lR4@0ojYH0?nlG0h0ok]K
0P3o_Ed00`3o^e`0ok]K0?nkF`0;0?nkF`030?nmG@3o_5`0ok]K00L0ok]K00@0okYI0?noI03o^eX0
okaL503o^e/30?nlG100ok]K00T0okaK0?o3GP3oYe40M3dK00D30@0?1@80eU<f0?n3E@3oSU`03`3o
ReX00`3oRUX0oh]N0?n;FP0@0?n;FP030?n;F`3oS5/0oh]J00l0oh]J00<0ohiO0?n;FP3oReX03@3o
ReX00`3oRUT0oh]J0?n<F`0=0?n;FP030?n:F@3oReX0oh]J00d0oh]J00<0ohmP0?n:F`3oReX01@3o
ReX0203oREP0oge=0?mgAP3oNTT0ohED0?n;FP3oRUX0ohUH3@3oReX02@3oREP0oh]K0?n;FP3oReX0
ohYI0?n;G03oS5`0ohmQ0?n9EP050?n;FP030?n?H03oReX0oh]J00X0oh]J0P3oRUT<0?n;FP030?n>
G`3oReX0oh]J00X0oh]J00<0ohQG0?n;FP3oReX02@3oReX00`3oR5P0oiEY0?n;GP0:0?n;FP030?n8
F03oTfL0ohaM00/0oh]J00<0ohYI0?n;FP3oReX02P3oReX00`3oT680ohmR0?n:F@030?n;FP050?n8
FP3oPe80ogM60?miB03oQUD00`3oReX00`3oRU/0ohaL0?n;FP0:0?n;FP030?n;F`3oSf00ohYI0080
oh]J00L0ohaK0?n:F@3oPE00ogQ70?miB03oPE40ohYI0080oh]J00<0ohYK0?n=GP3oS5/02`3oReX0
0`3oRUX0oheN0?n;G00=0?n;FP030?n<F`3oRUT0oh]J00/0oh]J00L0ohiM0?mlD@0V3`X01P810;0g
:`3oLE/0ofiI00@0ofaH00<0ofmJ0?m`F`3oKEP00`3oK5P00`3oKET0ofiI0?m/F00=0?m/F0060?m[
E@3oLE`0ofaG0?m[E`3oJE@0of=<0P3oFD<01@3oFTD0oea70?mSC03oJ580of]G00<0ofaH00<0ofaG
0?m_FP3oKeX03@3oK5P00`3oKeX0ofUD090/8P0200000004068F5P3oEE@0oeQF0?mFE@l0oeME00<0
oeUG0?mFE@3oEeD03`3oEeD0103oF5H0oeME0?mIE`3oF5LD0?mGE@030?mEE03oFEL0oeaJ01D0oeME
00@0oeQG0?mIE`3oFeX0oeED1P3oEeD00`3oE5<0of5[0?m/R@030?m]R`80of^:0P3oKH/00`3oKhd0
og2>0?mYR0020?mZR0030?mYR03oMY<0of^900@0ofZ800`0ofV80?mPJ@3oEeH0oeeK0?mGE03oEU<0
oeEB0?mDDP3oDTh0oe9=0?m:B03o@d430?m1?`0:0?m5@@3o>CL02P8205DU4P3oW4d0oiA<0?nGC`3o
VeD0oiaC0?nLDP80oiaD0100oi]A0?nLE03oWED0oj5L0?nRG@3oWUH0oiaD0?nLD`3oXEd0oiaE0?nK
E03oYEd0gf<c000000040P80onO[o`3ooonQ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWio00oooo00P0oo7f0899<01mAB/0MT4W08E;<`2>DSX0N48X07U2:080
MT0V00T0ND8X07U3:@1i@RX0SU@k07Y3:@1kA2/0N48Y07U3:@1g@BL00P1i@bT01P1h@RP0PTTa07U2
:01g@BD0MD0T07Y4:P<0ND<Y00<0Md4W07Do9@1h@BL01@1i@bT01@22BC00O4D[07I09P1iA2T0N48X
00@0ND<Y00@0LclV08m=;03?Kch0jWe21`3VNd400`3UNSl0i7To0>Ik@@040>Ik@@090>Ij@03[OdD0
kWm20>ao@03/OSl0jgm20?nEC@3o]U`0okiM0100ok]K00<0okaL0?nmGP3o_5`03@3o^e/00`3o_Ed0
okaL0?nkF`070?nkF`040?nkFP3o^UX0okaO0?nlG1@0ok]K00<0ok]J0?nmH03o_5`04@3o^e/00`3o
`5d0ol9M07i37`020000000407L]703oP5@0ohiM0?n9FPh0oh]J00<0ohiO0?n;F`3oRUT0403oReX0
0`3oSEd0oh]K0?n;FP0?0?n;FP030?n<G`3oRUX0oh]J00d0oh]J00<0ohaL0?n;FP3oReX03@3oReX0
0`3oREP0oh]J0?n;FP0<0?n;FP030?n:F@3oReX0oh]J00L0oh]J00H0ogi=0?mgAP3oN4L0oh1@0?n;
FP3oS5h=0?n;FP090?n:F`3oSEd0ohYK0?n;GP3oREP0oi1Q0?n:F@3oReX0ohYI00@0oh]J00<0oh]K
0?nCI03oRUT02`3oReX00`3oRe/0oiEX0?n;FP0;0?n;FP030?n:F03oReX0oh]J00X0oh]J00<0ohQG
0?n;FP3oReX02@3oReX00`3oR5P0oiIZ0?n;GP0:0?n;FP030?n8F03oU6L0ohaM00X0oh]J00<0ohYI
0?n>H@3oRET02`3oReX00`3oR5P0oh]J0?n;FP030?n;FP040?n8E`3oNDT0ogQ70?n6E0<0oh]J00<0
oh]K0?n;FP3oRUX02`3oReX02`3oRe/0ohUH0?n;FP3oReX0ohaK0?n7EP3oODd0ogI50?miB03oQeH0
ohaK00@0oh]J00<0ohaL0?n;FP3oReX02P3oReX20?n<F`030?n:F@3oReX0oh]J00/0oh]J00<0ohUH
0?n;FP3oReX02P3oReX01P3oT5h0ogYA04PM4`020@40/SL/0?mbG0L0ofaH00L0ofiJ0?maG03oKEP0
ofaH0?m]F@3oKeX0ofeI00`0ofaH0P3oKUP02`3oK5L0ofYE0?mTC`3oH4T0oeY30?mI@`3oGDH0oee8
0?mSC03oJeD0ofeI00@0ofaH00<0ofeG0?m^F@3oL5/03@3oK5P00`3oLE/0ofeG09P^9@0200000003
04P?3`3oBTT0oeQF00d0oeME00@0oeED0?mHEP3oGE/0oeEC4@3oEeD20?mHEP030?mMF`3oEE<0oeME
00l0oeME00<0oeIE0?mGE@3oF5L00P3oF5H00`3oEE<0oeED0?mGE@0C0?mGE@040?mEE03oEeH0of5P
0?mCDPX0oeME00@0oei[0?m/Q`3oKX/0off;0P3oK8X20?m]R`030?m_S@3oJHP0ofZ80080ofZ800<0
ofV80?meT`3oJhT0103oJhX06@3oJXP0ofV80?mQL`3oE580odm=0?m;B03oAdD0odE10?m1?`3o@3h0
od8n0?m3@@3oA480odE30?m7A@3oCDT0odM803@<2`1=8a<0ojaN0?nME@3oW5@0oieE0?nLD`3oVe80
0P3oW5@0403oWEH0oiaD0?nME@3oXUd0oiiF0?nRG03oW5<0oiaB0?nSHP3oW5D0oi]C0?nRF03ZJ3H0
20<000<20@3oloOo0?oooj40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWl03oool02P3OVHh0K3TL07]4:`1d?bD0QD/b07U2:@1i@bT0ODD/0899<01i@RP207U3
:@0707Q2:022BC00OdL^08eB>P1f@BL0ND<Y07]4:P0307U3:@0407I19P1jA2X0PTX`07e5:`<0ND<Y
00@0ND8X07M2:027CC@0OTH]1@1i@bT01022BC00PTX`07U3:01i@RP407U3:@050898:`2gI3L0fWLn
0>1h?`3UNd801P3VNd400`3UNd40iga20>Ek@@060>Ik@@070>Ml@P3^P4D0lhM=0?>;B@3oZ5@0okeM
0?nlF`0B0?nkF`050?nlF`3o_Ed0okaL0?nmG@3o_5d02`3o^e/00`3o^eX0okaN0?nlGP080?nkF`05
0?nlG03o_5d0okeM0?nmG@3o_5/04`3o^e/20?nlG0030?nmG@3o_5d0ok]K00h0ok]K00X0okaL0?ni
FP2jNS/0ISHJ01@:100l5`l0^UXj0?n4E`3oT5h0oh]K3@3oReX00`3oS5/0ohUH0?n<G00@0?n;FP03
0?n:F@3oS5d0oheM00l0oh]J00<0ohaM0?n;FP3oReX03@3oReX00`3oS5/0oh]K0?n;FP0=0?n;FP80
oheM3@3oReX00`3oRUX0ohaM0?n;FP070?n;FP070?n4E03oO4`0ogM60?mlC03oQUH0ohaK0?n=G@09
0?n;FP070?n<F`3oSEd0oh]J0?n<G@3oRUX0ohaM0?n<F`030?n;FP030?n:F`3oS5`0ohaK00<0oh]J
00<0ohYI0?n=GP3oReX02P3oReX00`3oRe/0ohaL0?n:FP0;0?n;FP030?n;F`3oReX0oh]J00/0oh]J
00<0oh]K0?n;FP3oReX02@3oReX00`3oSE`0ohYJ0?n;FP0:0?n;FP030?n<G03oRe/0oh]J00X0oh]J
00<0ohaM0?n;FP3oReX02@3oReX00`3oS5`0ohiP0?n:F@030?n;FP050?n4E03oNTT0og]:0?n8E`3o
S5/00P3oReX00`3oRUX0oheN0?n<G00<0?n;FP0:0?n=G@3oReX0ohaK0?n:F@3oP540ogI70?mhB03o
Odh0ohQH0?n<F`<0oh]J00<0oh]L0?n=GP3oRUT02`3oReX00`3oRe/0oheM0?n;FP0=0?n;FP030?n=
G@3oRe`0oh]J00T0oh]J00P0ohYJ0?n:F`2QBc8090l:0000002M>Bh0og1J0?m]F0P0ofaH00D0ofmI
0?m`F`3oK5P0ofiH0?m/E`090?m/F080ofeI00`0ofaH0?mZE@3oIe80of=<0?mOB03oFdH0oea60?mN
B03oHT`0ofQB0?mZEP3oKEP20?m]F@<0ofaH00D0ofeI0?m^FP3oKeX0ofmK0?m]F@0:0?m/F00:0?m]
F03oKeX0lUi;0:0h;01:5a8060D508dQ803C@3l0oeEC0?mHEP`0oeME00D0oeQF0?mEE03oFeX0oeMF
0?mFE@0?0?mGE@060?mFE03oF5H0oeQF0?mHE`3oEU@0oeIE3P3oEeD01P3oF5H0oeUH0?mFE03oFeX0
oeQF0?mKF`80oeMF4`3oEeD20?mHEP040?mJF03oEU@0oeQG0?mFE@/0oeME00T0oeID0?mJG03oHfh0
of^60?m]R`3oLHl0og2=0?m^R`3oJXT00`3oJhT0<`3oJXP0ofR70?maS@3oIhD0of>10?mRP03oH7h0
oeej0?mKN03oFGL0oeQf0?m@H`3oAD<0odI20?m7A@3oBTL0oda:0?m?C03oCdd0oe1>0?mCD@3oE580
oeID0?mGE@3oCT`0J1XI03XJ3P3oVe80oiiF0?nLE03oWUL0oimI0?nLD`3oW580oiaD0?nTHP3oX5X0
oiaC0?nME@3oWUL0oj1I0?nLE03oW5<0oimK0?nMEP3oVe@0oieC0?mg?P0Z4PP000000?o[i03o0?oo
oj40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWk`3oool0
0`3ok_<0MClU070l8P0207Q2:00?07U3:@1e?bD0ND<Y0898<02:D3H0QD/c0817;P1i@bT0O4D[07E0
901mAB`0Re0h07I19`1h@BL0Qddd00<0ND<Y00@0N48X07i6;02;DCP0OdL^0`1i@bT0101h@BL0Md4W
08Y?=P1oAbd407U3:@0407Q2:01mAR`0SU4i07]4:P<0ND<Y00L0MT4X07a4;034JcT0hWXo0=ae>`3N
Mcd0hGU000H0iW]100<0i7To0>j2B`3TNT001P3VNd401@3TND00lH540?nWE@3o_5`0okaK01L0ok]K
00@0okaL0?nmG@3o_5d0okeN2P3o^e/00`3o^eX0okaM0?nkFP090?nkF`050?nkFP3o_Uh0okaM0?nk
F`3o^eX0503o^e/00`3o_5d0okaL0?nkFP0?0?nkF`080?nnG@3oa5l0oiA703XN3P000000=A@<0<a=
<P3oSE`?0?n;FP80ohaL00<0ohYI0?n;FP3oReX03@3oReX00`3oRUT0oh]L0?n<G00?0?n;FP030?n;
F`3oRUT0ohYI00d0oh]J00<0oheN0?n>G`3oReX03@3oReX00`3oRU/0ohaK0?n;FP0<0?n;FP80ohYI
1`3oReX20?n<F`050?n6E@3oNDP0ogM60?mnCP3oRUT01P3oReX02@3oRUT0oh]J0?n?H03oRUT0ohiO
0?n;FP3oRUX0oheN0?n:F@050?n;FP030?n:F@3oS5/0oh]J00<0oh]J00<0ohYK0?n9F03oReX02P3o
ReX00`3oRU/0ohaM0?n;FP0:0?n;FP030?n@H@3oReX0oh]J00X0oh]J00<0oiAY0?n:F`3oReX02P3o
ReX00`3oREP0ohYI0?n;FP090?n;FP030?n:F@3oREP0oh]J01L0oh]J00<0ohUH0?n;FP3oReX00P3o
ReX01@3oOTh0ogI50?mhA`3oR5L0ohaK00@0oh]J00<0ohmP0?n;FP3oReX02P3oReX02@3oSEh0oh]L
0?n;FP3oQ5<0og]:0?mgAP3oOdl0ohQG0?n<F`050?n;FP030?n;G03oRUT0oh]J00X0oh]J00<0oh]K
0?n=GP3oRUX0303oReX0103oRU/0ohaO0?n:F`3oRUX90?n;FP030?n9FP3oTEl0/UHh0080000000<0
`3``0?m`FP3oK5P02@3oK5P00`3oK5L0og1K0?maG0090?m/F080ofeI00T0ofUB0?mSC@3oHDX0oeY3
0?mH@P3oFTD0of190?mVD@3oK5H00`3oKET60?m/F0040?m]E`3oL5/0ofaH0?m]E``0ofaH00<0ogAN
0<=7=`0;0P400P000000103F?3X0oe]J0?mGEP3oEUD<0?mGE@040?mIE`3oF5L0oeME0?mEE100oeME
0`3oF5H>0?mGE@80oeED00L0oeME0?mLFP3oF5H0oeQF0?mMF`3oF5H0oeED01D0oeME00@0oe]I0?mH
EP3oF5H0oeED403oEeD03@3oEU@0oe]P0?m]R@3oNYH0ogBB0?m/R`3oIhD0ofF30?mRO`3oGg`0oeai
0?mKN03oF7H0103oEW<0203oFgP0oeml0?mSP03oH7d0ofB30?mQM`3oEEH0oeUC0P3oEe@00`3oEU<0
oeaJ0?mGE@050?mED`0;0;<c<@0Y4PT0oh]:0?nRE`3oW5@0oj5M0?nLD`3oXE/0oj1J0?nLE03oWED0
0P3oW5@03@3oVe<0oiaC0?nMDP3oX5T0oimJ0?nLD`3oVe<0oi]D0?nPF@3oRTP0DR@A0000003H/J40
o`3ooonQ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinl0
oooo0140ok2]07E09024BS80Md4W07a5:`1i@RP0MT0V07U3:@22B300Re0h08M<=01oAbh0OTH]07Q1
9`1i@bT0ODH/08]A>00207I19`0708M==01i@RP0ND<Y07Q2:01i@RP0ND<Y07U2:00307U3:@0307U2
:01lAB/0O4D[00D0ND<Y00@0N48X07a5;01kAB/0ND8X0`1i@bT02P1e@2L0OTD]0;IT>@3QNCl0gWPn
0=Yd>P3NN3h0h7Tn0>=i@03VNT040>Ik@@030>Aj@03[P4P0iWY000H0iW]100D0kh=50?n]D`3o_EX0
okiN0?nmGP0I0?nkF`80okaL00<0okeN0?nkFP3o^e/02@3o^e/00`3o_5d0okaL0?nkF`090?nkF`04
0?nlG03o^UT0okmS0?nkFQ<0ok]K00@0ok]J0?nlG03o_5`0okYI3`3o^e/0203o_5/0olAO0>N@AP0B
2@<0000000T20@2eD3@0ohiM403oReX00`3oREP0ohaK0?n;FP0?0?n;FP030?n;F`3oREP0oh]J00h0
oh]J00<0ohaK0?n;FP3oReX03@3oReX00`3oRU/0ohiO0?n;FP0<0?n;FP030?n:F@3oSEh0ohUH00`0
oh]J00<0oh]K0?n?H03oRUT0203oReX01P3oS5/0ohAD0?mgAP3oMdH0ogU80?n7E`<0oh]J00X0ohYI
0?n?H03oT680ohUF0?n<G@3oRUT0ohUI0?n;FP3oS5/0ohmP1`3oReX00`3oRUT0ohiO0?n:F`020?n;
FP030?n:F`3oSUl0oh]J00X0oh]J00<0ohYK0?n>G`3oReX02P3oReX00`3oTF<0oh]J0?n;FP0:0?n;
FP030?nFJP3oRU/0oh]J00X0oh]J00<0ohUH0?n:F@3oReX02@3oReX00`3oR5L0ohUH0?n;FP090?n;
FP030?n:F@3oSf00oheN00X0oh]J00<0ohUI0?n@H@3oRUT00P3oReX01@3oQ5@0ogQ70?mhA`3oP500
oh]K00<0oh]J00<0oh]K0?n?H03oReX0303oReX0203oSUl0ohYJ0?moC`3oN4L0ogM60?moCP3oRUT0
ohaK1@3oReX00`3oSEd0ohYK0?n;FP0;0?n;FP030?n:F@3oS5`0oh]J00/0oh]J00@0oh]K0?n<G`3o
ReX0ohUI2P3oReX01`3oSE`0oh=F03PF3P000000`cda0?m_FP3oKUT02@3oK5P01@3oKEL0ofmJ0?m^
F@3oKUT0og5L00H0ofaH00/0ofeI0?m/F03oIe80of5;0?mLA`3oF480oeU20?mLAP3oIDh0ofQC0?m/
EP020?m]F@T0ofaH00<0ofmJ0?m`F`3oK5P02`3oK5P0203oKUT0og9K0?=9>P0P2@L00000040=3@3o
?Sd0oeMF3@3oEeD00`3oEU@0oeQG0?mJF00A0?mGE@040?mEE03oFEL0oeUG0?mHEPh0oeME00P0oeED
0?mSH@3oF5H0oeED0?mHEP3oFeT0oeUG0?mHEQD0oeME00@0oeUH0?mIE`3oF5H0oeIE4P3oEeD02@3o
F5H0oeMD0?mFF`3oGW@0oeml0?mMNP3oFWL0oeUf0?mHM@030?mGM00>0?mIM`3oGGX0oemm0?mSP03o
IhH0ofR60?mXQ`3oIhH0ofV80?mXQ`3oJXP0of=l0?mGFP3oEe<20?mFD`040?mPG@3oGE`0oeEC0?mG
E@80oeEC01/0oe]H0?m<C00M30H0ogm40?nSF@3oW5@0oieG0?nLE03oWeT0oimK0?nLE03oVe80oiYA
0?nLE03oW5<0oiaD0?nLDP3oVe40oj5K0?nNF03oVU00oi]C0?nRGP3oTdX0IblG00000036Z900o`3o
oonQ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinl0oooo
00P0/6aI07]4:P27C3<0ND<Y07i6;01h@BL0N48X07U3:@80Nd@[00X0QD/c07i6;@1nAR`0Qd`d07U3
:P1nARd0S54i07I19`1i@bT0ODD[0`1i@bT00`1g@BL0N48X07I09@0307U3:@0407Q2:026Bc@0OdP^
07Do9@<0ND<Y00D0N48X07a5;01oAbd0Md4W07E09P0207U3:@0;07M2:024BBd0`fXl0>5i?`3ON3h0
h7U00>Z3C@3MMcd0gWPn0>=j@P3VNd801@3VNd400`3UNT40iW]10>Ik@@030>Ik@@090>Aj@@3SNCl0
ojQF0?nmG03o^e/0okaL0?nlGP3o_V<0okYI01T0ok]K00@0okaL0?nnGP3o_5`0ok]J2P3o^e/00`3o
_F00ok]J0?nkF`090?nkF`030?nlG03o_Ed0okaL01@0ok]K00<0ok]J0?nmH03o_5d0403o^e/0203o
`5d0oia<06Pg6@0000004`L40=UF=`3oREX0ohaK3P3oReX00`3oRUT0ohaN0?n;F`0@0?n;FP030?n=
GP3oS5/0oh]J00h0oh]J00<0ohaL0?n:F@3oReX03P3oReX00`3oSEd0oh]J0?n;FP0;0?n;FP030?n:
F`3oSEh0oh]J00`0oh]J0P3oRe`90?n;FP0=0?n:F`3oQE@0ogU80?mgAP3oOD`0ohUH0?n:F`3oR5L0
ohmQ0?n:F`3oS5`0ohYI0?n:FP050?n;FP030?n<F`3oReX0oh]J00H0oh]J00D0ohmP0?n;F`3oReX0
ohYK0?n>G`0<0?n;FP030?n:F@3oReX0oh]J00T0oh]J00<0ohYI0?n;FP3oReX02P3oReX00`3oUVX0
ohYK0?n;FP0:0?n;FP030?n9F03oRUT0oh]J00P0oh]J00<0ohQH0?n@H`3oSf802P3oReX00`3oRUT0
ohmP0?n>GP0;0?n;FP070?n=G@3oReX0oh]J0?n<F`3oO4/0ogQ70?n0D0050?n;FP030?n;F`3oSUl0
oh]J00/0oh]J00L0ohaL0?n;FP3oPE00ogQ70?mgAP3oODd0ohYI00L0oh]J00<0ohaL0?n;FP3oReX0
2`3oReX00`3oSUl0oh]J0?n;FP0;0?n;FP030?n<F`3oReX0oh]J00X0oh]J00L0oh]K0?n3E@1]:a`0
0@000<Hm<03oLU/0ofiI00T0ofaH00<0ofeG0?m_FP3oL5/00P3oK5P00`3oKUT0og5L0?m/F0030?m/
F00;0?mZE@3oHd`0oei80?mKAP3oFd@0oeU20?mOB03oIDh0of]F0?m/F03oKET02P3oK5P00`3oKEL0
og5L0?m]F00<0?m/F0090?m`FP3oHTh0S2TP00l50`010000[2LV0?m=C@3oF5L0oeQF00`0oeME00@0
oeQF0?mKF@3oFEL0oeQF403oEeD00`3oF5H0oe]I0?mHEP0>0?mGE@090?mCDP3oGEd0oeUG0?mHE`3o
EeD0oeED0?mJF03oEU@0oeQF01@0oeME00<0oeEC0?mJF@3oEeD04P3oEeD02@3oEE<0oe1>0?m=B`3o
BTP0odI40?m4@P3oA4<0oe5S0?mHMP020?mHM@0;0?mJM`3oGW`0of:00?mVQ03oIXD0ofR70?mYR03o
JXP0of^:0?m[R@3oKX/00P3oJ8L01@3oIhH0ofR70?mYR03oIH00oeQI0080oeIC00<0oeQE0?mOGP3o
EE<00`3oEE<03P3oFUP0odY90188103oMCh0ojEJ0?nLE03oW5<0oi]B0?nNF@3oYF<0oieE0?nLE03o
WED0oiaD0P3oW5<02`3oXUd0oj5L0?nQG03oWEH0ojAR0?nKD`3oY5l0ojMN08Lm8@000000X8Ye0?l0
ooooX@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinO^0?oo
o`0K0?oThP1lAB/0ODH/08=:<@1kA2X0QT`c07U3:01h@RP0ND<Y07I09P1e@2H0RDhf0899<01j@bT0
Se@k07]4:P1lAB/0PTXa07Q2:01g@BL0N48X07U3:@1jA2X0O4D[07Q2:@20Abh0ODH[00<0ND<Y00@0
N48X08I;=024Bc<0OdH]0P1i@bT0401jA2X0ODH]07]4:`1i@bT0ODH/07a5:`1i@bT0Md8Y09YD;`3F
MCl0hGXo0=mh?P3NN3h0h7U00>^5C`3MMcd20=ih?P030>5i@03UNd40iW]10080iW]100<0ig]20>Il
@P3VNd400P3VNd401@3UNd40lH540?JFC03o/5P0okaL00D0ok]K00D0okaN0?nlG@3o_Eh0ok]K0?nl
G00G0?nkF`050?nlG03o_5h0okeM0?nkF`3o_5`01`3o^e/00`3o_5`0okeN0?nlG00;0?nkF`040?nm
G03o_Eh0ok]K0?nlG1<0ok]K00@0okaM0?nmGP3o^eX0okaL3@3o^e/02P3o_5`0okiL0?niFP3JTTL0
GC<H00<0000n60l0TdH^0?YoD`3oSU`>0?n;FP040?n<G@3oS5/0oh]K0?n:FPd0oh]J00@0ohYJ0?n:
F@3oS5/0ohaL3P3oReX00`3oS5/0oh]J0?n;F`0=0?n;FP030?n<G03oS5h0oh]J00`0oh]J00<0oh]K
0?n<G@3oRe/03@3oReX00`3oRe`0oh]J0?n;FP070?n;FP080?n;F`3oRET0ohAD0?mkB`3oNDT0ogm?
0?n6E@3oRe/80?n;FP030?n;F`3oS5/0oh]K00P0oh]J00D0oheM0?n;FP3oRUX0oh]L0?n<G00:0?n;
FP030?n:FP3oSEh0oh]J00/0oh]J00<0ohYI0?n;FP3oReX02@3oReX00`3oUFT0ohYK0?n;FP0:0?n;
FP030?n9F03oRUT0oh]J00P0oh]J00<0ohUI0?nAI03oSf802`3oReX00`3oRUT0oh]J0?n;FP090?n;
FP070?n;F`3oSEd0oh]J0?n6E@3oO4/0ogY90?n5E@060?n;FP030?n<G03oReX0oh]J00X0oh]J00H0
ohYK0?n5E@3oO4/0ogQ80?n0C`3oQeH80?n;FP030?n=G@3oS5/0oh]J00X0oh]J00<0ohaK0?n<G@3o
ReX02`3oReX00`3oRUX0oh]J0?n<F`0:0?n;FP080?n:FP3oRU/0]5Hh03HF3P020@40YCda0?m_FP3o
KET90?m/F0040?m]F03oL5/0ofmJ0?m/F080ofeI00d0ofaH0?m/E`3oK5H0ofE@0?mQB`3oGTP0oea6
0?mKAP3oH4X0of9<0?mZE03oK5L0ofeH00`0ofaH00<0ofeI0?m^F@3oKe/02`3oK5P02P3oKET0ofmJ
0?mYE02R>2`060L500X20P1A4Q80cclm0?mGE@3oEeH<0?mGE@040?mFE@3oFEL0oeYH0?mFE@l0oeME
00D0oeQF0?mFE03oFUP0oeUG0?mFE@090?mGE@060?mGEP3oF5H0oeED0?mMG03oEeH0oeaK0P3oEUD0
103oF5H0oe]J0?mFE03oFUPD0?mGE@040?mHEP3oFUP0oeQF0?mHEPD0oeME103oF5H04@3oEeD0oeID
0?mFE03oE580oe9@0?m@CP3oCT`0od]90?m9A`3oB4H0odI40?m4@`3oAT@0odE40?m8AP3oBTP0od]:
0080odm=00<0oeYV0?mWQP3oJHL01@3oJXP00`3oJHP0ofZ80?mZR0020?mZR0<0ofR702P0ofN60?mX
Q`3oJ8L0ofV80?mSNP3oEeX0oeID0?mGE03oGEX0oeAB0?mFE03oEU<0oeEC0?mHEP3o@d4010810>QX
>03oYe/0oiaD0?nME@3oWeT0oj1J0?nSH03oWED0oiaC0?nSH@3oWEH0oj1L0?nLDP3oX5/0oj5L0?nN
EP3oW5D0ojAS0?nKE03oXUd0ojaP0;MB:`050P40SF]1o`3ooonQ0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinh0oooo00l0ekF/07I1:01lAB/0PTT`07Q29`21
B2h0Qd`d07]4:P1i@bT0Nd@Z07Q2:025Bc@0OTL]07U3:@1lAB`00P1i@bT02`1f@2H0ND<Y07a5:`1j
A2X0Nd@Z07i6;01oAbh0PTT`08aA>025BS<0N48X0080ND<Y00@0N48X08A:<P27C3D0PTT`0P1h@RP0
2@1nARd0ND8X07U3:@1i@bT0ODD/07]4:`1i@bX0WUHa0=af?@040=ih?P030>1i?`3WP4T0gGLm0080
gWPn00L0ggPm0>=j@`3UNd40iW]10>Ej?`3]PD`0jGi60080iW]100@0hGPo0?>:B03o^Ed0okeL2P3o
^e/0103o_Ed0okeN0?nkF`3o_5`H0?nkF`040?nkFP3o_V40ok]J0?nlG0P0ok]K00<0okaL0?nkFP3o
^e/02P3o^e/0103o_5T0okiR0?nlG@3o^eXC0?nkF`030?nkFP3o_F40ok]K0100ok]K00P0okeL0;=P
;00U4`P00000048J403oNe00oi5P0?n=G0d0oh]J00<0ohYI0?n>G`3oRU/03`3oReX00`3oRUT0oheN
0?n9F@0>0?n;FP030?n<G03oSEh0oh]K00`0oh]J00<0ohYJ0?n9F03oS5`03P3oReX00`3oS5/0ohYI
0?n;FP0:0?n;FP030?n:F@3oS5h0ohYJ00@0oh]J00`0ohUI0?n:F@3oRe`0ohYK0?n>H@3oSUl0ohYI
0?n9F@3oO4d0ogI70?meA@3oPU880?n;FP040?n:F@3oSf00ohaL0?n:F@P0oh]J00<0ohaO0?n8FP3o
S5`0303oReX00`3oS5h0oh]J0?n;FP090?n;FP030?n;F`3oT6<0ohUI00X0oh]J00<0oiI[0?n:F`3o
ReX02@3oReX00`3oREP0ohYI0?n;FP090?n;FP040?n:F@3oRe`0ohYK0?n:FPP0oh]J00@0ohYI0?n>
H@3oTfT0ohYI2P3oReX00`3oR5L0ohaK0?n0D0020?mgAP030?n4D`3oReX0oh]J00D0oh]J00<0oh]K
0?n;FP3oReX0203oReX01`3oS5/0ohAF0?mgA`3oMdH0ogU80?n4E03oS5/01`3oReX00`3oRUT0oh]J
0?n:F@0;0?n;FP030?n9F@3oS5/0oh]J00/0oh]J00<0ohYI0?n:F`3oS5/02P3oReX00`3oRUX0oi5P
0;9D=`02000000030:0b:03oL5X0ofaH00T0ofaH00T0ofeG0?m^F@3oK5P0ofeI0?m^FP3oJeL0ofMB
0?mRC@3oGdP00P3oFD801`3oGDL0of1:0?mWD@3oK5P0ofeI0?m]E`3oKET0303oK5P00`3oK5L0ofiI
0?mbG@0<0?m/F0090?m_FP3oKUP0oe0o04LC3`000000APl>0?0i>03oFEP0oeMF00/0oeME00D0oeIE
0?mHE`3oFEL0oeME0?mFE@0?0?mGE@050?mHEP3oEeD0oeUG0?mHE`3oEUD01`3oEeD01P3oEUD0oeME
0?mIF03oFEP0oeQG0?mLFP80oeED00H0oeME0?mEE03oFUP0oeME0?mJF03oEE@B0?mGE@060?mFE@3o
F5H0oeQG0?mDD`3oFEL0oeED0P3oEeD40?mHEP080?mGE@3oEE<0oe=A0?mBD03oCdd0odY80?m6A03o
@d820?m2@0090?m3@@3oA480odM50?m8AP3oB4T0od]90?mDDP3oFEL0oeYH0080oeQF0`3oEeD00`3o
EU@0oeeP0?mWOP050?mZR0060?m_S@3oJXP0ofZ80?mZR03oK8X0ofN60P3oJ8L00`3oIhH0ofR70?mX
Q`020?mXQ`060?mUP@3oH6/0oeUE0?mLF@3oE580oeEC0`3oEeD01`3oB4L02`@40<MJ<03oZed0oiaD
0?nME@3oY6800P3oVe402P3oWUH0oiiH0?nKD`3oW5<0oj5L0?nLD`3oW580oi]A0?nKD`3oWED20?nK
E0050?nLD`3oXE/0ohi7048L2`20GBl0o`3ooonQ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWinh0oooo00l0`Xf107I19`1nAR`0QD/c07i6;@21Abl0UEM107i6
;01kA2/0SU8i07E09P1h@RL0NT<Y07U2:01c?R@00P1i@bT02`1f@2H0N44W08iB>P1lAB/0OTH/07I0
9P21B2l0PTT`0898<01nARd0N48X0080ND<Y00L0N48X08I;=@23BS40O4D[07I19`1lAB/0O4@[00<0
ND<Y00D0MD0V07]3:`2/GcP0fWDl0>1i?`050=ih?P030=Yd>P3NN3h0gWPn0080gWPn00/0gWLm0>Aj
@03VNd40i7U10>YoA@3WOD@0iW]10=ig?P3dPdD0ok5I0?nlF`0<0?nkF`050?nkFP3o_5`0okeN0?nl
G03o^eX05`3o^e/01@3o^UT0okaM0?nmG@3o_5d0ok]J00D0ok]K00@0ok]J0?nlF`3o_F00ok]J2`3o
^e/01@3o^eX0okeN0?nlG@3o_Ed0ok]J0180ok]K00@0ok]J0?nlG03o_Ed0ok]J3P3o^e/01`3o_5`0
olQR0?n=@P1J<1H00000048I403XG3/00P3oSE`>0?n;FP030?n<GP3oS5/0oh]J00h0oh]J0P3oS5`0
0`3oRUT0oh]J0?n;FP0<0?n;FP030?n:F@3oS5/0ohaK00`0oh]J0P3oRUT00`3oS5/0oh]K0?n;FP0;
0?n;FP030?n=GP3oReX0ohYI00/0oh]J00/0ohQH0?n;FP3oReX0oh]J0?n:F@3oRUX0ohiO0?n:F@3o
SEh0oheM0?n:F@020?n;FP080?n;F`3oRET0oge>0?mhA`3oMdL0ohAC0?n:F@3oS5/60?n;FP030?n9
F03oSUl0oh]K00T0oh]J00@0ohiO0?n9F03oS5d0ohYI2P3oReX00`3oRUP0ohUH0?n;FP090?n;FP03
0?n;F`3oUVX0ohYI00X0oh]J00<0ohmR0?n:F`3oReX02@3oReX00`3oREP0ohYI0?n;FP0:0?n;FP03
0?n8E`3oRUT0oh]J00P0oh]J00<0ohUI0?n;G03oSUl02P3oReX01P3oRU/0ohmP0?n7EP3oN4L0ogI5
0?mmC@L0oh]J00<0ohYI0?n=G@3oReX0203oReX01`3oS5/0ohQG0?mjBP3oM4D0oga<0?n5E03oS5/0
203oReX00`3oSEh0ohmP0?n:F`0:0?n;FP030?n:F@3oRU`0oheM00/0oh]J00@0ohYJ0?n<G03oSf00
ohYK2@3oReX0203oRUX0oi9O0?n1E@0b50d0000009lc:03oKUT0ofeI2@3oK5P0203oKET0ofaE0?m^
FP3oKET0ofYE0?mWDP3oHD/0oeU30P3oF480203oGdT0ofA>0?m[EP3oKUT0ofeI0?maG03oKUP0of]E
3@3oK5P00`3oK5D0ofiI0?m_FP0;0?m/F0080?m^F@3oK5H0XS4V00D100000000Ea@D0?m:BP3oGE`=
0?mGE@040?mHEP3oFEL0oeMF0?mEE100oeME0P3oF5H00`3oEE<0oeME0?mGE@050?mGE@80oeED00@0
oe]I0?mCDP3oG5X0oeaJ0P3oEE@20?mGE@050?mFE@3oFEL0oeUG0?mIE`3oEU@04P3oEeD01@3oEE@0
oeYH0?mHEP3oFEP0oeME00<0oeQF01L0oeUG0?mFE03oDe40oe5?0?m@CP3oC4X0odQ60?m5@`3o@T00
od0o0?lo?`3o@d40odE30?m8AP3oBdT0ode;0?m?C@3oDe40oeME0?mKFP3oEUD0oeaJ0?mEE0080?mG
E@030?mJF`3oHWD0of^900<0ofZ800@0og2>0?mZR03oJXP0ofV8103oJ8L00`3oIhH0ofR70?mXQ`03
0?mXQ`040?mWQP3oGF00oeAB0?mDDP80oeEC01H0oeQF0?mJF03oBTT06@T90;=@:`3oXeP0oieD0?nL
E03oWeT0oiaC0?nKDP3oWE@0oieF0?nID@3oVU00oj5N0?nLD`3oW5@0oi]A0?nLD`3oWUT0oiY@0P3o
Ve80103oW580oj5A098o7@20FbWo0?oooj40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWkP3oool06`2eL5h0MT4W07]4:P2:CcH0ND<Z0899<02DEcl0OTH/07]4
:`2>DST0Nd@Z07]4:01g@BP0MClU07Q19`1i@bT0Md4W07Q2:01f@BL0SU8j07m6;@1lAB/0N48X07m7
;P22BC00LchT07I09P0307U3:@0607Q2:025BS<0ODD/07I19`1nAR`0OTH]101i@bT01022BBl0/V8i
0>5i?`3PNCh50=ih?P030=if?@3LMC/0gWPn00@0gWPn00T0hWY10>Ik@@3VNd40i7Y00>Ik@03KMCd0
ohe<0?n[EP3o_Ed03`3o^e/0103o_E`0okaK0?nlG@3o_5dH0?nkF`040?nlG03o^e/0okaQ0?nkG0D0
ok]K00<0ok]J0?nmH03o_F003@3o^e/00`3o_Eh0okeM0?nlG00C0?nkF`030?nkFP3o_5`0okaL00l0
ok]K00P0okaK0?o5H@3o/ED0Hc@H0000000;0P40QSDR0?n5E`l0oh]J00<0oheM0?n<GP3oRUT03@3o
ReX0103oRUX0ohaK0?n:F03oS5/>0?n;FP030?n:F@3oS5/0oh]J00`0oh]J00<0ohUI0?n<F`3oReX0
303oReX00`3oReh0ohmP0?n;FP0<0?n;FP080?n>GP3oR5X0oh]J0?n>H03oS5`0ohiO0?n;F`3oRUT5
0?n;FP080?n:F@3oSEh0ohEE0?miB03oN4L0ogi>0?n9F03oS5/50?n;FP030?n9F@3oSf00oh]J00/0
oh]J00<0ohmP0?n;FP3oReX02@3oReX00`3oS5`0ohiO0?n:F@090?n;FP030?n;F`3oTF<0oh]J00X0
oh]J00<0ohIE0?n;FP3oReX02@3oReX00`3oREP0ohYI0?n;FP090?n;FP030?n:F@3oR5L0oh]J00X0
oh]J00<0ohQG0?n9F03oReX02@3oReX01`3oRU/0oi9U0?mnC@3oMTD0ogi>0?n:F@3oS5/01P3oReX0
0`3oS5`0ohYI0?n;FP080?n;FP060?n4D`3oNTT0ogE50?moD03oR5L0ohaK203oReX00`3oRUT0ohaK
0?n;F`0;0?n;FP030?n<F`3oSUl0oh]J00/0oh]J00<0ohYK0?n>G`3oReX02@3oReX0203oRUX0oi5O
0?mnD`1Q9aT000000:<c:@3oKET0ofiI2@3oK5P04P3oKeX0ofeI0?m_F@3oJE<0of5<0?mNB@3oFTD0
oeQ20?mKA@3oHDX0of=>0?m[EP3oKeT0ofmJ0?maG03oKeX0og1K0?m]E`d0ofaH00<0ofmJ0?m]E`3o
KEL02`3oK5P00`3oLE/0og5J09d_9@020000000304h@403kBTP0oeUH00`0oeME00@0oeED0?mFE03o
FUP0oeID3`3oEeD00`3oEE@0oeID0?mIF0080?mGE@060?mEE03oEeD0of1O0?mEE03oFeT0oeEC0P3o
EE@40?mGE@80oeUH00<0oeEC0?mGE@3oEeD0403oEeD0103oEE@0oeQF0?mIE`3oFUT20?mHEP0J0?mI
E`3oEE<0oe9@0?m?C@3oC4/0odU70?m7A@3oA480od900?m0?`3o?cl0odA20?m7A@3oBTP0ode;0?m@
CP3oDU00oeEC0?mHEP3oFEL0oeIE0?mJF03oF5H0oeUG0?mHEP3oEU@90?mGE@040?mGE03oEUD0ofEm
0?m[RP80ofZ800D0og2>0?mZR03oK8X0ofZ80?mWQP030?mXQ`030?m]R`3oIhH0ofR700@0ofR700<0
of=h0?mCC`3oDU000`3oEE<02P3oFUP0oe9@02l<302<?B00oiYB0?nME@3oW5@0oiYA0?nKDP3oW5<2
0?nLE0030?nPF@3oX5X0oiiG0080oiaD00@0oimH0?nME@3oVDl0oimJ0P3oVe<01@3oVe00ohQ509A0
7P20H2H0ooc/0?l0ooooX03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinO^0?ooo`0J0:ETC`1i@RP0PTT`08mC>`1j@bX0LShS08eB>@1nARd0Nd@Z08=:<@1nAR`0
MT4W07U3:026CC@0O4@[07U3:@1g@BL0ND<Y07Q2:@1i@bT0O4D/07U3:@1h@RP0PDL_08=:<@1jA2X5
07U3:@0407M29`1oAbh0ODH/07a5:`<0ND<Y00D0Md8X07]4:@2mJ3h0hGTo0=mh?P060=ih?P030=ef
?@3NN3h0gWPn00@0gWPn00P0ggPo0>9i?`3UNd40iGY10>^3A03oZUH0okYL0?nlG180ok]K00H0okaL
0?nkF`3o_Ed0okaK0?nmGP3o_5XF0?nkF`050?nlG@3o^eX0okaN0?nmG`3o_5X0103o^e/20?nlG@03
0?nkFP3o^e/0ok]K00`0ok]K00<0okaL0?nmGP3o^e/04P3o^e/0103o_5`0okeM0?nkFP3o_5d>0?nk
F`090?o0G@3o]EL0[g0f05H^5@040P40DAlD0<MU@`3oQUL0oheL00d0oh]J00<0ohaM0?n=G03oRUT0
403oReX00`3oSEd0ohYJ0?n;FP0=0?n;FP030?n<F`3oRe/0oh]J00`0oh]J00<0ohaK0?n:F@3oReX0
2P3oReX20?n:FP`0oh]J00H0ohiO0?n;FP3oS5h0ohYI0?n;G03oRe/90?n;FP070?n;F`3oSEd0ohMG
0?mmC03oN4L0ogU80?n2D@060?n;FP030?n:F@3oS5`0oh]J00X0oh]J00<0ohaK0?n<G03oReX02@3o
ReX00`3oS5`0ohiO0?n;FP0:0?n;FP030?n8E`3oRUT0oh]J00T0oh]J00<0ohQG0?n;FP3oReX02@3o
ReX00`3oREP0ohYI0?n;FP090?n;FP030?n=G`3oSV00ohUI00T0oh]J00<0ohaM0?nAH`3oReX02P3o
ReX01P3oR5P0oge<0?miB03oPe80oh]J0?n<F`L0oh]J00<0oheN0?n;F`3oReX01P3oReX01`3oQUD0
og]:0?mgA`3oNT/0ohAC0?n;FP3oS5/02@3oReX00`3oS5d0oh]K0?n;FP0:0?n;FP030?n;F`3oSEd0
ohYJ00/0oh]J0P3oRe/00`3oReX0ohYJ0?n;FP080?n;FP070?n9FP2^DCH0<A@=0000002E=R`0ofiI
0?m]F@080?m/F00<0?m]F03oJE@0ofE>0?mPB`3oGTP0oe]60?mLAP3oGdT0of9<0?mWDP3oJeH0ofaG
0P3oKET01@3oK5P0ofaF0?m^F03oL5/0ofeH00`0ofaH00<0ofeI0?m/EP3oKeX02`3oK5P02@3oKUT0
oem=0:0l;`155A004P@407dN7@3C@3l0oe9A0?mHE`0;0?mGE@80oeQF00<0oeUH0?mGE@3oEeH03P3o
EeD01@3oEU@0oeQF0?mKF@3oEeD0oeQF00D0oeME00P0oeQG0?mKFP3oEE<0oe]I0?mEE03oFEL0oeME
0?mFE@<0oeME0P3oEeH20?mIE`030?mHEP3oEeD0oeME00l0oeME00X0oeQF0?mFE03oEU@0oeID0?mA
C`3oD4h0ode;0?m;B@3oB4H0odM50`3oAD<01`3oAT@0odU70?m;B@3oCD/0odm=0?mBD03oEE<00P3o
EU@02@3oEUD0oeQF0?mHEP3oF5H0oeMF0?mIE`3oEU@0oeeL0?mGEP0?0?mGE@050?mIFP3oIGH0ofV5
0?mZR03oKX`00P3oJXT50?mXQ`030?m`S`3oIhH0ofR700D0ofR700@0of=f0?mJGP3oEE<0oeIC0P3o
EE<06`3oF5H0IATH04HO403oQDL0oj5G0?nLE03oWEL0oj9M0?nLE03oW5D0oiaD0?nME@3oXE`0oiaC
0?nLE03oW5<0oj=O0?nOE`3oXel0oiiG0?nQG@3oW5D0ojIO0?n6AP0o6``0>R0>0?oIV01@0?ooo`03
0?o`m@3TaLP0VI6B0080P82000@0S8R90<F_/P3ne]X0ooWn1P3oool0103oj>`0i<G80;n[[@2OUIL2
0820P00309VATP3;];H0oo3e00`0oooo00<0onS/0>C5b02VVY/00P20P8000`2bXZ@0d[Rk0?o`m@0@
0?ooo`030?o`m@3TaLP0VI6B0080P82000@0S8R90<F_/P3ne]X0ooWn7@3oool0203bemX0/Z:T09VA
TP20P800VI6B0;n[[@3TaLP0oo3e1P3oool00`3ol?D0i<G809VATP020820P00408b8R@35[k80o]KJ
0?oioPD0oooo00@0ooCf0>C5b02bXZ@0VI6B0P20P8000`2ITI80_j^]0?SWj0380?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWind0oooo00X0onO]09=F@01lA2`0
TUHn07m8;@1h@RP0LShR08iB>P1nARd0ND<Y0`1f@BL0201i@bT0SU8i07a5:`1i@bT0Md4W07]4:P1e
@2D0LchT0P1i@bT01@1h@RP0PDL_08Q>=@27C3@0N44W00@0ND<Y00<0MT0V07e6;01i@bT00`1i@bT0
1P1f@2P0Q4T]0;eW>@3QO4L0gGM10=ig?`H0gWPn00<0jX=?0=ih?P3NN3h01P3NN3h0103UOTX0ohmB
0?ndF03o_5/H0?nkF`030?nkFP3o_F00okaL01P0ok]K00<0ok]J0?nmG@3o_6401@3o^e/00`3o_5/0
okaL0?nkF`0=0?nkF`030?nlG03o^UT0okmT01@0ok]K00<0okeM0?nlG03o^e/03P3o^e/0203o`5d0
okaK0?n=A00R4PT0000003<C303hHCh0oheL3P3oReX00`3oREP0ohaM0?n;FP0>0?n;FP030?n;F`3o
SUl0ohYI00d0oh]J00<0ohYI0?n<F`3oRe/03@3oReX00`3oSUl0oh]J0?n;FP0E0?n;FP030?nBIP3o
RUT0oh]K0080oh]J00<0ohmP0?n;FP3oReX02`3oReX20?n<F`050?n8E`3oODd0ogQ70?mkBP3oR5L0
1@3oReX00`3oS5`0oh]K0?n;FP0:0?n;FP030?n8E`3oS5/0oh]J00T0oh]J00<0ohUH0?n:F@3oReX0
2P3oReX00`3oS5`0oh]J0?n;FP080?n;FP030?n:F@3oR5L0oh]J00T0oh]J00<0ohUH0?n:F@3oReX0
2@3oReX00`3oSf80oi5U0?n:F@0:0?n;FP030?n=GP3oReX0oh]J00L0oh]J00D0ohaK0?n3DP3oNDP0
ogM60?n3DP080?n;FP030?n:F@3oT680ohaL00H0oh]J00L0ohYI0?n1D@3oN4L0ogU80?n0D03oR5L0
oh]K00/0oh]J00<0ohYI0?n;FP3oReX02@3oReX00`3oS5`0ohiP0?n;FP0;0?n;FP030?n:F@3oReX0
ohaL00X0oh]J00H0ohmL0:a@=00000000P000;4h;03oKUT80?m/F0040?mWD03oHT/0oe]50?mKA@80
oeY500D0oei80?mWDP3oJeL0ofaH0?m]F@050?m/F0050?m]F@3oKUP0ofeG0?m]F03oLE`02P3oK5P0
0`3oKEP0og9M0?m/F00;0?m/F0090?m_F@3oKUT0d4/j00l50`0000001P410<Xg=`3oF5P0oeMF00`0
oeME00<0oeEC0?mKFP3oEeD03`3oEeD0103oEE@0oeQG0?mIF03oF5H50?mGE@050?mEE03oEeD0oe]J
0?mHEP3oF5L01`3oEeD00`3oEE@0oeQG0?mHE`0A0?mGE@050?mFE03oEE<0odi=0?m:B@3o@D000P3o
AD<40?m4@P050?m5@`3oB4H0ode;0?mAC`3oEE<00P3oEU@00`3oEeD0oeQF0?mHEP080?mGE@030?mH
E`3oFUP0oeQF01<0oeME00H0oeMD0?mLG`3oI7X0ofV80?m^R`3oIhH50?mXQ`030?m`SP3oIhH0ofR7
00@0ofR700D0of^90?mYR03oJ8L0of5/0?mGE0020?mED`0:0?mJF01e7A`000000?=/>P3oYUX0oiaD
0?nOF@3oXf40oimK0?nNF@80oiaD00l0oiaC0?nOE`3oW580oiaE0?nLD`3oWE@0ojES0?nMEP3oWeX0
oiiH0?nYJ@3oUe40Cb8A020C203ocG80:P3oool<000000040;:RY03oool0oooo0?noaP<000001@3o
ool01@3ogn<00000000000000000P82000P0oooo00<0/7Un0000000000001`0000000`39Ri00oooo
0?ooo`020?ooo`030:F;T0000000000000L0000000<0UfQ/0?oco03oool01`3oool00`3oj>`0IDE8
00000007000000050?o@f03oool0oooo0?ooo`3o_lH00`0000070?ooo`030;1iOP000000000000L0
000000<0bH^@0?ooo`3oool00P3oool01@20P8000000000000000000omoS00H0oooo00@0oko60000
0000000000001`3oool00`3od=P0IDE800000007000000030?oXk03oool0oooo0080oooo00<0/7Un
0000000000001`0000001P39Ri00oooo0?ooo`3oool0on7Z01TB4PL0000000<06A8B0?o@f03oool0
aP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinO]0?ooo`0E
0?nn^@2=DSX0O4D[08]@=`1f@2H0O4D/07U2:02<DCP0OTH]07M19`1lAR/0MT4W07I09P1i@bT0QD/c
07a5:`1h@RP0PdT`07I19`1nAR`0O4D[00<0ND<Y00@0Nd@Z07m8;P25Bc<0N44W0`1i@bT0101h@RP0
LchT07e6;@1h@RP207U3:@0707Q2:@24BBd0`6Xk0=Yd?03PNdP0eG8j0=]e?@060=ih?P030>Z3C`3N
N3h0gWPn00D0gWPn00D0fWDm0?n@B03o^5T0okeL0?nkFP0J0?nkF`040?nlGP3o_Eh0okaL0?nlG1L0
ok]K00<0okYI0?nmG`3o^e/00`3o^e/00`3o^eX0okeM0?nlGP0@0?nkF`030?nlG@3o^eX0ok]K0180
ok]K00@0okaM0?nmH03o^UT0okaL3@3o^e/02@3o_5`0okeL0=B4@00A2@<0000000<0003;G3/0ohiM
0?n;F`0=0?n;FP030?n=G@3oReX0oh]J00d0oh]J00@0ohYJ0?n>G`3oSUl0ohYI3@3oReX00`3oRUT0
ohiO0?n;F`0=0?n;FP030?n>G`3oReX0oh]J00/0oh]J00T0oheM0?n:F`3oReX0oh]J0?n;F`3oRU/0
ohUH0?n>H@3oSEd01@3oReX00`3oRUT0ohaN0?n;FP0;0?n;FP080?n<F`3oReX0ohQJ0?n:F@3oOD`0
ogM60?miB03oPe840?n;FP030?n<F`3oReX0oh]J00X0oh]J00@0oheN0?n;FP3oSV40oh]K203oReX0
0`3oSf80oi1S0?n:F@080?n;FP040?n:FP3oSUl0oiAX0?n8F0X0oh]J00<0ohQG0?n;FP3oReX01`3o
ReX0103oRUT0oi=W0?n>H@3oRUT90?n;FP030?n?HP3oTF@0ohQH00T0oh]J00<0ohYI0?n9F03oReX0
203oReX01@3oREP0ogQ80?mgAP3oNTT0ohYI00T0oh]J00<0ohYI0?n;FP3oReX0103oReX01`3oR5L0
oga<0?mhA`3oNTX0ohIE0?n=G`3oSf002`3oReX00`3oSEh0ohaL0?n;FP0:0?n;FP030?n<G@3oREP0
oh]J00/0oh]J00<0oh]K0?n<G03oReX02@3oReX01`3oSE`0ogeC02dB30060P40/CP/0?m/F03oKET0
0`3oK5P02`3oKET0of]G0?mZE@3oIU40oem90?mJ@`3oF480oeU20?mMA`3oIDh0of]D00T0ofaH00<0
ofiJ0?m_FP3oKEL00P3oK5P00`3oKEP0og9M0?m^F@080?m/F0030?m^F03oKeX0ofaH00T0ofaH00X0
ofeH0?m_FP3oK5L0oe0o02091`000000=`d<0?Tk>P3oFEP0oeIE303oEeD00`3oG5X0oeQF0?mFE@0?
0?mGE@030?mHEP3oFUP0oeUH00@0oeME0P3oF5H00`3oGEh0oeQF0?mED`080?mGE@80oeQF00<0oeYH
0?mIF03oEeD0203oEeD20?mHEP80oeME0P3oEE<01@3oDDl0odi<0?m8AP3oAD<0odA20080od=10P3o
AD<01@3oAT@0odM50?m;B@3oCdd0oe=A0100oeME00<0oeQF0?mOG`3oDe805`3oEeD00`3oFEL0ofN0
0?mXQ`060?mXQ`030?m^S03oIhH0ofR700H0ofR700<0ofV80?mVPP3oF5/00P3oEE<02P3oFeP0MAdL
0080003lKc/0ojAJ0?nLE03oW5<0oi]A0?nPG03oWeT20?nLE00?0?nKDP3oWED0oiaB0?nLE@3oW580
oiaC0?nVI03oW5D0oi]C0?nOFP3oYVL0ojiR06T_600E30@0olac02X0oooo30000000102bXZ@0oooo
0?ooo`3o_lH3000000D0oooo00D0omoS00000000000000000820P0070?ooo`030:FDV@0000000000
00P0000000<0IDE80?ooo`3oool00P3oool00`20H6<000000000000800000003038S903oj>`0oooo
00H0oooo00<0LDiA0000000000001`0000040?ooo`040?noaP0000000000000000H0oooo00<0YIBI
000000000000200000000`1UADP0oooo0?ooo`020?ooo`050820P000000000000000003ogn<01P3o
ool0103o_lH000000000000000060?ooo`030>:LXP000000000000P00000103oool00`2UU9T00000
000000080000000506E5B03oool0oooo0?ooo`3o_lH02@0000000`0I4A80om3H0?ooo`350?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWind0oooo00l0kYZA08U>
=P1kA2/0QD/c07Do9@1nARd0OdL^07U3:01i@bT0NT<Y07Q1:@1lAB`0OTL]07U3:@1c?bD00P1i@RP0
1@27CCD0N48W08iB>P25Bc<0ND<X0080ND<Y00<0N48X07I09P1e@2H0101i@bT00`1k@bT0MD0V07M0
9P0307U3:@0807e4:P30JS/0fgHm0=Eb>`3PNdP0eG<l0=]h@@3NN3l50=ih?P030>^4D03NN3h0gWPn
00@0gWPn00L0gGLm0?nFC03o_600ok]I0?nnH@3o^e/0okaM01X0ok]K00D0ok]J0?nmH@3o_F00okaL
0?nkFP0F0?nkF`040?nkFP3o_V<0ok]J0?nmG@80ok]K00<0ok]J0?nmH03o_5`03`3o^e/40?nlG180
ok]K00@0okYI0?nnGP3o_5h0ok]J3P3o^e/0203o_U`0mX4o03XO3`00000090h90?eS@03oS5/0ohiM
3@3oReX00`3oS5/0ohQG0?n;FP0>0?n;FP030?n<F`3oReX0oh]J00d0oh]J00<0ohYI0?n=GP3oReX0
3@3oReX00`3oSf00oh]K0?n;FP0;0?n;FP050?n=GP3oRU/0ohaL0?n<G03oSf002@3oReX00`3oS5/0
oh]K0?n;FP0:0?n;FP0;0?n;F`3oRUT0oh]J0?n;FP3oQeP0og]:0?mdAP3oMdH0ohAC0?n;FP3oR5X0
0P3oReX00`3oSV40oh]J0?n;FP090?n;FP040?n?H03oRU/0ohYI0?n<G@L0oh]J00@0ohYJ0?n=GP3o
Re`0ohYI2@3oReX00`3oReh0oi9U0?n:F@0:0?n;FP030?n9EP3oReX0oh]J00L0oh]J00@0ohYI0?nC
I`3oSV40ohYI2@3oReX00`3oREP0ohQG0?n;FP090?n;FP030?n?H03oReX0oh]J00L0oh]J00D0ohaK
0?n0C`3oL480ogQ80?n3DP090?n;FP030?n?H03oSEh0ohUI00<0oh]J00L0ohaK0?n8E`3oNDP0ogI5
0?miB03oQE@0oh]J0080ohYI2`3oReX00`3oS5/0oh]J0?n;FP0:0?n;FP030?n<G03oReX0oh]J00X0
oh]J00<0ohaL0?n>G`3oRET02@3oReX01@3oSE`0ohAF080c8@030@40/cT]0080ofiI00d0ofaH0?m]
F@3oKET0of]G0?mXD`3oHD`0oee70?mI@`3oFT@0oea70?mNB03oIDh0of]G00X0ofaH00<0ofaG0?m`
F`3oKEL01@3oK5P00`3oLUd0ofeI0?m/F0050?m/F0030?m_FP3oKEL0ofaH00X0ofaH00P0og5K0?mR
CP2T<2D01@4000T20P2D8R<0oe1>0?mJF0`0oeME00<0oeQF0?mKF@3oF5H0403oEeD02P3oF5L0oeYI
0?mDD`3oEeD0oeED0?mHEP3oF5L0oeME0?mMG@3oF5H:0?mGE@040?mHEP3oFEL0oeUH0?mEE0D0oeME
0`3oF5H0503oEeD0oeID0?mDDP3oDe40ode>0?m<BP3oAT@0od=20?m3@@3o@T00odA20?m5@`3o@d80
odM50?m:B03oCD/0oe5?0?mED`3oF5H0oeMF3P3oEeD01@3oEE@0oeQG0?mGE@3oFEP0oeID01P0oeME
00@0oeUH0?mFE03oF5l0ofR61P3oJ8L00`3oL8h0ofN60?mXQ`040?mXQ`0<0?mYR03oJ8L0ofR70?mY
R03oH7@0oeMC0?mED`3oFeP0MahM01@80P3oNSl0oj9F0P3oW5@00`3oVe40oj5K0?nOFP030?nLE003
0?nMEP3oXEd0oiaC0080oiaD00X0oj9L0?nLE@3oVe80oiiG0?nTHP3oZeh0NCDL00d70`3ob6H0ookk
:@3oool<000000040;:RY03oool0oooo0?noaP<000001@3oool01@3ogn<00000000000000000P820
00L0oooo00D0?b`]0000000000000000075>D@030?noaP0408YPH`000000000006E5B0@0oooo00L0
P61S000000000000000003<S901UADP0Bc@f00D0000000<0VH^@0?ooo`3oool0103oool00`3RW:80
0000000000020000000604`d=P39Ri00bH^@06E5B00=2@T00000103oool0103o_lH0000000000000
00060?ooo`0503l/;@00000000000000001aCU400`3o_lH0102:H6<000000000001UADP40?ooo`05
0820P000000000000000003ogn<01P3oool0103o_lH000000000000000050?ooo`030?7>d@000000
00000080000000D06A4B07iGFP39Ri00UfQ/01TA4P02000000@0oooo00D0?b`]0000000000000000
075>D@030?noaP0408YPH`000000000006E5B0<0oooo00@0om3H000000000000Bc@f0P39Ri000`2`
NGh0<R<T0000000200000003038S903oool0oooo0<@0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWk03oool0403oloH0`7UX07]5:`1i@bL0MD0U07Q1:01mAB`0
P4P_07Do9@1g@BL0Qddd07I19P26Bc<0Re0g07M1:01g@RL207U3:@0408=9<@1j@bT0PDP`0818;`<0
ND<Y00<0Md8X07Q19`1i@bT00P1i@bT04@1kA2X0OTH]07U3:@1i@RT0O4D[07U3:@1g@RP0ODDZ0;UV
>@3JMSd0eg@m0=Ic?03LN480eW@m0=Md?@3IMSl0gWLn00@0gWPn00T0ggPo0=ih?P3NN3h0gWPn0=mh
?P3KMSd0hGU00?ZPD@3o_Ed00`3o^e/01P3o_5h0okeM0?nkFP3o_Eh0okaM0?nlG1T0ok]K0P3o_Ed0
0`3o_Uh0ok]K0?nlG00F0?nkF`080?nmGP3o_Ed0okaK0?nmG@3o^e/0okaL0?nlG@3o_5`?0?nkF`04
0?nlG03o_E/0okeN0?nlG180ok]K00@0okaK0?nnH03o^e/0okaL3@3o^e/02P3o`5h0okQJ0<R8@P1G
;aH00@0005@Q5P2VBc40oXAG0?n<F`3oRUX;0?n;FP030?n:F@3oS5`0ohaL00l0oh]J0P3oSEd=0?n;
FP040?n<G03oS5d0ohaL0?n:FP`0oh]J00<0oheM0?n:FP3oReX0203oReX01@3oSEh0ohaK0?n?H@3o
R5L0oh]L00/0oh]J00<0oh]K0?n<G@3oReX02`3oReX03P3oS5`0ohUI0?n;FP3oS5/0ohUI0?n5E@3o
OTd0ogQ80?moCP3oQUH0oh]J0?n<F`3oRe/0oheM2`3oReX0103oSEh0oh]K0?n<G03oS5h80?n;FP03
0?n<G@3oSEd0oh]J00T0oh]J00<0oh]K0?n;FP3oReX02@3oReX00`3oTF80oh]J0?n;FP070?n;FP04
0?n:F@3oTfL0ohiQ0?n:F@T0oh]J00<0ohQG0?n;FP3oReX0203oReX00`3oRe/0oi1Q0?n;FP060?n;
FP070?n<F`3oRUT0oh9A0?miB@3oP500ohUH0?n<F`080?n;FP80oh]K0`3oReX02P3oS5/0ohQG0?n1
D03oNDP0og]:0?n2D@3oREP0oh]K0?n=GP3oSEd:0?n;FP030?n;F`3oSUh0oh]J00X0oh]J00<0oh]K
0?n=G`3oRe/02`3oReX00`3oS5d0ohaL0?n;FP080?n;FP0C0?n:FP3oS5`0a5hn04HL4`000000W3X_
0?maF`3oKET0of]G0?mXD`3oHdh0of1:0?mMA`3oFdD0oea70?mOB@3oHdd0ofUC0?m/E`020?m]F@T0
ofaH00@0ofeI0?m_FP3oKET0ofeI1P3oK5P00`3oKUP0ofmJ0?m/F0030?m/F0040?m/E`3oL5/0ofiI
0?m]F0P0ofaH00X0ofeH0?m`F`3oK5H0[clb02P;2@050040AQ0@0<Tj>@3oFEP0oeMF2P3oEeD0103o
EU@0oeQG0?mIF03oFEL@0?mGE@030?mIF03oEU@0oeQG00<0oeQF00D0oeaJ0?mHEP3oFEP0oeME0?mF
E@090?mGE@030?mHEP3oFEP0oeMF00<0oeQF00/0oeME0?mFE03oE580oe=A0?m@CP3oCT`0od]90?m9
A`3oATD0odI40?m4@P020?m5@`090?m8AP3oB4L0ode;0?m>C03oDe40oe9@0?mDDP3oEU@0oeME00<0
oeQF3@3oEeD20?mFE@050?mHEP3oF5L0oeYH0?mHEP3oF5L05@3oEeD01P3oEUD0oeQF0?mHEP3oFUP0
oeIE0?mJF@80oeME00@0oe]Q0?mSN@3oJHL0ofV80`3oJ8L00`3oL8h0ofN60?mXQ`020?mXQ`80ofV8
103oJ8L03@3oJ8H0of5a0?mFEP3oFeL0PB0O00H30@3eKS/0ojML0?nMEP3oW5@0oimI0?nRH03oWEH0
0P3oW5@0403oWED0oj5M0?nQG@3oWE@0oiaC0?nRG@3oVe40oi]C0?nLE@3oWeT0oimJ0?nYG`2`CbH0
1`@10?o7H03ol<XY0?ooo`<0000000<0OUMJ0;:RY02bXZ@01P2bXZ@0103/g]l0oooo0?ooo`3o_lH3
000000D0oooo00D0omoS00000000000000000820P0060?ooo`0609MXK0000000000003l/;@3;];H0
ooco103oool00`3ogn<0/Z:T0;:2Q`040?ooo`0409mfNP20LGD0bkBf0?kFfP<0oooo00<0oo3e0;:G
VP0=2@T00P0000000`0V6Q/0oo3e0?ooo`030?ooo`070;:;T000000000000000001aCU40i<G80?ol
o`030?ooo`030?o[k@2bXZ@0oooo00<0oooo00@0oko600000000000000001@3oool01P2GJ6`00000
0000000o;2d0bkBf0?olo`@0oooo00<0omoS0;:RY02bPXL0103oool01@20P8000000000000000000
omoS00H0oooo00@0oko600000000000000001@3oool01P1IATP00000000000000000ZhZ=0?oioP@0
oooo00<0o]KJ0;:RY03oool00P3oool01P2GJ6`000000000000o;2d0bkBf0?olo`@0oooo00<0omoS
0;:RY02bPXL00`3oool00`3onOh0[9NJ0?o`m@050?ooo`050?7>d@0c8b@000000000002`NWh0a@3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinO/0?ooo`0F0?nm
^P2GFD@0M3lT089:;`1c?R@0ND<Y07e6;01lAB/0MD0V0899;`24Bc80MT4W08A:<P2:CcH0OdL^07i7
;01h@RP0ND<Y08E;<P1h@BL0MClU07Q19`80ND<Y00@0ND8X07Do9@23BS40N44W0P1i@bT02@1mARd0
N48X07I29`25Bc<0PDT`07E09`25BBh0`fXl0=Ue?@030=Md?@060=Ic>`3GM3d0eg@m0=Me?P3LN440
gWLm0P3NN3h00`3NMcd0gGLm0=ih?P020=ih?P040=9b>`3kRTL0ojUF0?nmF`P0ok]K00D0okeN0?nk
FP3o_F40okaL0?nkFP0H0?nkF`050?nlF@3o_600okeN0?nmH@3o^eX05@3o^e/0203o^eX0okaM0?nk
F`3o_F00okeK0?nkFP3o^e`0okeN4@3o^e/00`3o_5h0okYJ0?nlH@0A0?nkF`80ok]J00<0okaM0?nm
GP3o^e/03@3o^e/00`3o_E`0ok]L09I@9@020000000406<V6@3oPED0oi9Q0?n9FP`0oh]J00<0oh]K
0?n:F@3oReX03@3oReX00`3oRUT0ohaL0?n<GP0>0?n;FP030?n;GP3oS5h0ohYJ00`0oh]J00<0oheK
0?n<F`3oReX00`3oReX02P3oRUT0ohaL0?n>H@3oRUT0ohiQ0?n;FP3oRUT0ohYK0?n;G03oRe/;0?n;
FP030?n<F`3oRe`0ohUI00X0oh]J00<0ohaK0?n?H03oRUT00`3oReX02@3oS5/0oh=B0?meAP3oMTD0
oga<0?n9F03oReX0oh]K0?n9F00:0?n;FP060?n<G03oREP0oh]J0?n:F`3oSUl0ohaK1@3oReX00`3o
RUT0oi1S0?n<H00:0?n;FP030?n9F03oREH0oh]J00T0oh]J00<0oiIZ0?n;FP3oReX01`3oReX0103o
RUT0oi=W0?n>H@3oRUT80?n;FP030?n;G03oSV40ohYI00T0oh]J00<0ohYH0?n9F03oReX01P3oReX0
1@3oR5L0ogY90?mfA@3oP500oh]L00l0oh]J00T0ogm?0?mhA`3oMD@0ogi=0?n;FP3oS5/0oh]J0?n<
F`3oRU/02`3oReX00`3oS5`0ohYI0?n;FP090?n;FP030?n:F@3oSEh0ohUH00/0oh]J00<0ohaL0?n;
F`3oReX0203oReX00`3oREX0ohmM0<=N?@020000000>0<0m<P3oKUP0ofI?0?mQB`3oGDP0oeU30?mH
@P3oG4H0of9<0?mWD@3oK5P0ofiH0?m_F@3oKET;0?m/F0030?m^F@3oK5P0ofeG00T0ofaH00H0ofeH
0?m]F@3oKET0ofeG0?m_FP3oKEL:0?m/F0090?m]F@3oMEh0ldTj054G4P000000@`h?0>hh=P3oEeD0
oeUG00/0oeME00@0oeQG0?mEE03oFEP0oeED3P3oEeD0203oEE@0oeME0?mGEP3oEU@0oe]I0?mMF`3o
F5L0oeUH0P3oEE@:0?mGE@0=0?mEE03oF5H0oeYH0?mJF@3oE5<0oeAB0?mAC`3oC4X0odY80?m8AP3o
AT@0od900?lo?`020?m2@0070?m6A03oB4H0od]90?m?C@3oDU00oeAB0?mED`020?mJF0030?mFE@3o
FEL0oeIE01<0oeME00H0oeID0?mLFP3oF5H0oeQF0?mGEP3oEE@E0?mGE@060?mEE03oFUP0oeQF0?mH
E`3oFEP0oeED103oEeD0103oEU@0oeEC0?mNJ03oJHH30?mXQ`060?m`S`3oIhH0ofR70?mXQ`3oJHP0
ofN61P3oJ8L0303oJHP0ofJ00?mJG0298b4000000?=]>`3oYUX0oiiF0?nLE03oWeT0oimK0?nKD`<0
oiaD00l0oimI0?nUH`3oWEH0oi]C0?nOFP3oW5<0oiY@0?nNF03oXEd0oi]C0?nVG@3NISP02@@10?o4
D@3of9T0:@3oool3000000030<V;T03oool0oooo00T0oooo00@0oko600000000000000001@3oool0
1@3ogn<00000000000000000P82000D0oooo00D0o:fd00000000000000000?oQjP0F0?ooo`050>:L
XP000000000000000039Ri000`3oool01@3o_lH00000000000000000UfQ/00`0oooo00@0oko60000
000000000000103oool01@3l[K@00000000000000000on7Z00d0oooo00D0P8200000000000000000
0?oOh`060?ooo`040?noaP0000000000000000@0oooo00D0oko6000000000000000009MXK00:0?oo
o`050?b]]000000000000000003ohNX05@3oool01020NWh000000000000b8bC50?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWin`0oooo00@0okbi07]4:P1e@2D0
MT4V0P1i@bT03`1nARd0OTH/07Do9@1k@bT0ND<Y07Q2:025Bc<0Re0g0899<01oAbh0N48X07Q19`2:
D3L0MClT07E09P0307U3:@0>07U2:01c?R@0R4hf07I19`1i@bT0O4H[07Y3:@1h@RP0OdL^08]?=`1g
@BP0QDX]0<=Z?03KMSd40=Md?@090=Ic?03GM3d0eg@m0=Md?@3IMT00h7U10=mh?@3NN3h0g7Hl00<0
gWPn00D0fgHm0?n;BP3o/eX0okmL0?nlF`080?nkF`050?nkFP3o_5T0okeN0?nlG@3o_V800P3o^eXG
0?nkF`050?nkFP3o_5/0okeM0?nlG@3o_Eh05P3o^e/01`3o^eX0okeM0?nlGP3o^e/0okaI0?nlGP3o
_5`04@3o^e/0103o^eX0okeM0?nmG@3o^eXB0?nkF`030?nmG@3o_F00ok]J00d0ok]K00T0ol1M0?nh
F@3fQ3l0>1h>0000001C81@0ofA10?nBH@3oS5/0303oReX00`3oRUT0ohiO0?n;FP0=0?n;FP030?n:
F@3oSEh0oh]L00d0oh]J00<0ohYI0?n=GP3oS5`0303oReX0103oRUT0oh]J0?n:F`3oReX20?n:F@05
0?nBI@3oReX0oheN0?n;FP3oRUT0103oReX00`3oSUl0ohYI0?n;FP090?n;FP030?n:FP3oS5/0oh]J
00X0oh]J00<0ohYK0?n=GP3oReX01@3oReX01`3oPE40ogU80?mfA@3oODd0ohMI0?n;F`3oT6402P3o
ReX01P3oRUT0ohmP0?n;FP3oReX0oh]K0?n>G`L0oh]J00<0ohYI0?n;FP3oReX01`3oReX00`3oRUT0
ohiO0?nAH`0:0?n;FP030?nFJP3oReX0oh]J00L0oh]J00@0ohYI0?nCIP3oSf00ohYI203oReX00`3o
S5d0oi=W0?n:F@090?n;FP030?n=GP3oReX0oh]J00H0oh]J00@0og]:0?mfA@3oNDP0ohIE2P3oReX0
1P3oRET0ohiO0?n:F@3oReX0ohaK0?n2D@80ogM600<0oge=0?n:F@3oS5/00`3oReX00`3oRUT0oh]J
0?n;FP080?n;FP030?n=G@3oReX0oh]J00X0oh]J00<0ohiO0?n:F`3oReX02P3oReX00`3oRUT0ohUH
0?n;FP090?n;FP080?n>G@3oQEL0@QXA0000002o>bl0ofM@0?mPBP3oFTD20?mH@P080?mNB03oIE00
ofQC0?m]E`3oKET0ofmJ0?m]E`3oKEP;0?m/F0030?m]E`3oL5/0ofaH00/0ofaH0P3oKEL00`3oKUP0
ofiI0?m/F00:0?m/F0080?m/EP2L;bD06`L50000001@4Q80odY:0?mKF@3oF5L;0?mGE@040?mHEP3o
F5L0oeME0?mEE0d0oeME00D0oeIE0?mHEP3oG5X0oeAB0?mMG0020?mHEP030?mIF03oEE@0oeME00T0
oeME00/0oeEE0?mGEP3oEeD0oeQF0?mCD@3oD4h0odU70?m8AP3oAdD0odE30?m0@0020?m2@0080?m3
@@3oAdD0od]90?m=B`3oDDl0oeAB0?mED`3oEU@20?mHEP050?mFE@3oFEL0oeUG0?mHEP3oEE@0503o
EeD0103oDe80oeaJ0?mHE`3oF5HF0?mGE@030?mEE03oFEP0oeeK0080oeQF2@3oEeD00`3oEe@0of=e
0?mXQ`020?mXQ`060?mYR03oJ8L0ofR70?mWQP3oK8X0ofV8203oJ8L02P3oJ8<0TbPX0000002hDb/0
oieD0?nLD`3oVU80oiaD0?nKD`3oW5<30?nLE00?0?nLDP3oW5@0oieD0?nLE03oW580oiaD0?nOF@3o
WEH0oiiI0?nKD@3oYUh0mW0m00d60P3oWch0olaa02T0oooo0`0000000`39Ri00oooo0?ooo`090?oo
o`040?noaP0000000000000000D0oooo00D0omoS00000000000000000820P0050?ooo`0409MXK000
0000000007iGFQP0oooo00@0<R<T000000000000IDE80`3oool01@2GJ6`00000000000000000oo?l
00`0oooo00@0oko60000000000000000103oool0102GJ6`000000000001nEeX>0?ooo`050820P000
000000000000003ogn<01P3oool0103o_lH000000000000000040?ooo`0509MXK000000000000000
003olo`02P3oool0102GJ6`000000000001nEeXF0?ooo`040820P0000000000000000<D0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWk03oool05P3PT8<0ISDI
07Y3:01lAR/0S58i07Q2:01oARd0OdL^0858;P1k@bT0Md0V07Q2:025Bc<0Re0g0899<01oAbh0ND<X
0858;`20B2l0OdL]0858;`1h@RP207U3:@0407Q2:01e?bD0ODL/07U3:@80MT0V00L0ND<Y07Q2:021
B2l0R4`e07]3:@34Jc`0fgHm00D0eg@m00X0eW<l0=Md?@3GM3d0eg@m0=Id?@3KMSl0h7To0=ih?P3S
Nd<0gWPo0P3NN3h00`3/Pd@0okUM0?nmG00=0?nkF`050?nlG03o_5d0okaI0?o0IP3o^eX06@3o^e/0
103o^e`0ok]K0?nmG`3o^UTF0?nkF`060?nlG03o^eX0ol1V0?nkF03o^e`0ok]J4P3o^e/00`3o_5`0
okiN0?nlG00B0?nkF`030?nmG@3o_F00okeM00d0ok]K00L0okiM0?o0G@3oZ580BbLC0000000G20D0
[4D/00l0oh]J00<0ohiQ0?n;FP3oReX03@3oReX00`3oS5/0ohUH0?n;FP0<0?n;FP030?n9F@3oS5d0
ohYI00`0oh]J0P3oREP01@3oS5d0ohaK0?n:F@3oSEh0ohYJ00L0oh]J00<0ohaK0?n;F`3oReX02P3o
ReX20?n<F`030?n:F@3oReX0oh]J00P0oh]J00<0ohYK0?n=GP3oReX00`3oReX02@3oRe/0ohaK0?n6
E@3oNdX0ogQ70?mlC03oQeH0ohaK0?n:F@0:0?n;FP070?n=GP3oReX0oh]J0?n;FP3oR5X0oh]K0?n9
F@060?n;FP030?n;F`3oReX0oh]J00H0oh]J00@0ohYI0?n>H@3oTfH0ohYI2@3oReX00`3oTVL0oh]J
0?n;FP070?n;FP040?n:F@3oTfL0ohiQ0?n:F@P0oh]J00<0ohaM0?nCI`3oR5P02@3oReX00`3oTF<0
oh]J0?n;FP050?n;FP060?n3D`3oMdH0ogU80?n4D`3oT680ohYI2@3oReX02P3oRUT0ohYJ0?n;FP3o
RUX0oh1@0?mhA`3oNDP0oh5A0?n;FP3oS5/30?n;FP030?n<G03oReX0oh]J00T0oh]J00<0ohYI0?n;
FP3oReX02@3oReX00`3oSEd0oh]L0?n;FP0:0?n;FP030?n:F@3oS5/0oh]J00T0oh]J00D0oheL0?n3
EP22<b40000008LW7P020?mLAP050?mI@`3oFTD0of5:0?mVD@3oJUH00P3oKET0103oK5P0ofeI0?m^
F03oKEL;0?m/F0030?m]E`3oKUP0ofiI00`0ofaH00<0og1K0?m/E@3oKUT02P3oK5P00`3oKEP0og9L
0:4d:0020000000402X9203iAdH0oeUH0?mFE@X0oeME00<0oeID0?mJF03oFeT0403oEeD01`3oFUT0
oeEC0?mOG`3oFUP0oeQG0?mGE@3oEE@02P3oEeD01P3oEU@0oeAB0?mAC`3oBdT0odM50?m6A@80odE3
0`3o@d40203oA480od]80?m=B`3oD4h0oeAB0?mED`3oEU@0oeME0P3oF5H01`3oEeH0oeME0?mGE@3o
EE<0oeiM0?mFE03oEeH04`3oEeD01P3oEUD0oeME0?mIF03oEeD0oeQF0?mEE1H0oeME00@0oeMF0?mM
G@3oEE<0oeQG2`3oEeD00`3oEU@0oeYL0?mWP@020?mXQ`040?mVQ@3oJ8L0ofR70?mYR0X0ofR700P0
of^:0:Xf@@000000XDLS0?nIDP3oWE@0oiaD0?nLD`80oi]B0`3oW5@0103oW5<0oiUA0?nLE03oWUP2
0?nLD`090?nUH`3oVe@0oi]C0?nMEP3oYf80ohE701H:102kK2h0om5h02T0oooo0`0000000`39Ri00
oooo0?ooo`090?ooo`040?noaP0000000000000000D0oooo00D0omoS00000000000000000820P005
0?ooo`04038S9000000000000>:LXQP0oooo00@0/7Un000000000000<R<T0`3oool0100b8b@00000
0000000o;2d=0?ooo`040?noaP0000000000000000@0oooo00@0<R<T000000000000hYbR3P3oool0
1@20P8000000000000000000omoS00H0oooo00@0oko60000000000000000103oool0100b8b@00000
0000001nEeX;0?ooo`04038S9000000000000>:LXQH0oooo00@0P6Q/0000000000000000a@3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinO[0?ooo`0?0?oDe@2Y
Ie80KCTN07e6;02DEcl0Se@k07I19`29CcH0PdXa07I19`1i@bT0NdD[07U3:@1j@bT0ND@Y0080N48X
00H0ODD[07U3:@1f@2H0QT/d08Q>=@1g@BL207U3:@0607i6;@2?DcX0MT4W07Y3:01jA2T0NT<Y0P1i
@bT0101lA2`0RDhb0;]V>@3IMCd50=Md?@030=Eb>`3GM3d0eg@m00<0eg@m00T0eg@n0=]f@03NN3l0
iGi70=ih?`3QNT00l8a80?ndF03o_5`04@3o^e/0103o_5`0okaM0?nlF`3o_F020?nlG1P0ok]K00<0
okaN0?nlF`3o_E`00P3o_5`E0?nkF`050?nlG03o_5h0okeN0?nlG@3o_5`04P3o^e/0103o_Eh0ok]K
0?nlG@3o_5`A0?nkF`030?nlGP3o_5d0ok]K00`0ok]K00T0okaK0?nmG03j[5@0U60^03dP3P070`80
FRDH0=iZA@3oQUP00P3oS5/:0?n;FP030?n;F`3oS5`0oheM00h0oh]J00<0ohYI0?n<G03oS5`0303o
ReX00`3oRe/0oheN0?n;F`070?n;FP80oh]K00@0ohaM0?n<G03oS5`0oheN303oReX00`3oS5/0ohaL
0?n:FP0;0?n;FP80ohaL2`3oReX00`3oS5d0ohaK0?n;FP050?n;FP070?n:F@3oPU40ogU80?mhA`3o
P4l0ohUI0?n:FP0:0?n;FP070?n=G@3oReX0oh]J0?n;FP3oS5/0oh]L0?n<F`030?n;FP030?n9F@3o
T680oh]L00P0oh]J00<0ohYJ0?n<G03oS5d02P3oReX00`3oUV/0oh]J0?n;FP070?n;FP040?n:F@3o
TfL0ohiQ0?n:F@P0oh]J00<0oh]K0?n<G03oReX02@3oReX00`3oRUT0oh]J0?n;FP020?n;FP080?n;
F`3oReX0oh9A0?miB@3oODd0ohUH0?n;FP3oRe/:0?n;FP070?n=G@3oRUX0oh5@0?miBP3oNDP0oh1?
0?n9F0050?n;FP030?n<G03oS5/0oh]J00T0oh]J00<0ohaL0?n;F`3oReX02@3oReX00`3oRUX0ohaL
0?n;FP0:0?n;FP040?n;F`3oS5h0ohaL0?n:FP@0oh]J00h0ohaK0?n;F`3oReX0ohYI0?n6E@2kESL0
?QT@00400024:R00oei70?mRB`3oHdh0ofQC0?m[E`D0ofaH00<0ofiI0?m`F`3oK5L02P3oK5P20?m]
F@030?m^F03oKUT0ofaH00/0ofaH00D0ofiH0?m^FP3oK5P0ofaG0?m^F@070?m/F0090?m^F@3oHTh0
Yclb05LJ500@10@0NQ`K0;lj>@3oDE40oeQF00X0oeME00@0oeQF0?mGEP3oFEL0oeID3@3oEeD20?mH
EP070?mFE@3oEeD0oeUH0?mGE@3oF5H0oeIE0?mHEP030?mGE@0:0?mFE03oEE<0oe=A0?mBD03oCdd0
oda;0?m;B@3oBDL0odM50?m3@P80odA30P3oAT@0103oBDL0ode;0?m@CP3oDU020?mDDPT0oeME0P3o
F5H0103oFEL0oeQG0?mGE@3oF5HB0?mGE@030?mHEP3oEU@0oeeL0080oeQF5@3oEeD01@3oF5H0oeME
0?mMF`3oEU@0oeYH0080oeQF3`3oEeD01`3oFU`0of=e0?mWP`3oIhH0ofR70?mYQ`3oJXT01P3oJ8L0
3P3oJHP0ofZ90?mXQ`3oIhH0ofn=08d^>`000000R3/L0?nFC`3oWED0oiaD0?nMEP3oX5/0oj5M0`3o
W5@0403oXE`0oi]B0?nLD`3oW5@0oj5J0?nMEP3oYV@0oi]D0?nKD`3oX5`0oj9M0?nDC@0L3@L0Q4/N
0?o9IP3oe/dX0?ooo`<0000000<0bH^@0?ooo`3oool02@3oool0103o_lH000000000000000050?oo
o`050?oOh`000000000000000020P800103oool01@3ofN400000000000000000omoS01P0oooo00@0
bH^@00000000000000000P3oool01@3oj>`00000000000000000NE]O00d0oooo00@0oko600000000
000000000`3oool01@3ofN400000000000000000omoS00h0oooo00D0P82000000000000000000?oO
h`060?ooo`040?noaP0000000000000000<0oooo00D0om3H00000000000000000?6f_@0:0?ooo`05
0?oIh@00000000000000003ogn<0503oool00`3ol?D0/Z:T01XB4P020000000307iGFP3oool0oooo
0<<0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj`3oool0
5P3o^;<0S58i07a6:`20B2l0TEDm08aA>@1f@2H0Re0h08mC>`1nAR`0ND<Y08E<<`1i@bT0N44W07I1
9`1g@2H0PDP_07]4:P1i@bT0Md4W07E09P1e?bD307U3:@0507i6;02DEch0PTT`07a5;01h@RP00P1i
@bT0101f@BP0R4/^0<I/?@3KMSh60=Md?@030=Eb>`3GM3d0eg@m00@0eg@m00H0eg<l0=Yf@03ONTD0
m8A60?nSD`3o_U/F0?nkF`80ok]J00@0okiP0?nkFP3o_Eh0ok]J603o^e/0103o_5`0okeN0?nkFP3o
_EdE0?nkF`030?nlF@3o_F40okeN01@0ok]K00@0ok]J0?noH`3o^e/0okaL4@3o^e/00`3o_Ed0okaL
0?nmGP0=0?nkF`090?noG03o`E`0j7Xk01/>1`000000GRDG0?mZAP3oSed0ohUJ00/0oh]J00<0ohYK
0?n=GP3oReX03@3oReX00`3oRUT0oheN0?n;G00=0?n;FP080?n>G`3oS5`0oh]J0?n;FP3oRET0ohYI
0?n;G@3oRUT20?n>H@070?n9F@3oReX0oh]J0?n;FP3oSEh0ohaL0?n:F@0;0?n;FP030?n>G`3oReh0
oh]J00X0oh]J00<0oh]L0?n<F`3oReX02@3oReX00`3oRUT0ohiN0?n9F@060?n;FP070?n:FP3oR5L0
oge=0?mhA`3oMdP0ohEE0?n<F`090?n;FP030?n:F03oReX0oh]J00<0oh]J00<0ohUH0?n<F`3oRe/0
0P3oReX00`3oRUT0oh]J0?n;FP080?n;FP030?n:F@3oREP0oh]J00T0oh]J00<0oi9U0?n;FP3oReX0
1`3oReX0103oRUT0oi=W0?n>H@3oRUT80?n;FP030?n;F@3oRUT0oh]J00P0oh]J00<0ohYI0?n?H@3o
ReX00P3oReX02@3oS5/0oh]J0?moC`3oN4L0oga<0?n<F`3oRUT0oi5S0?n<G@090?n;FP060?n<F`3o
RET0og]:0?mgAP3oNTT0ohAC1P3oReX00`3oS5`0ohUH0?n;FP090?n;FP030?n:F`3oREP0oh]J00T0
oh]J00<0ohQJ0?n<G`3oRU/02P3oReX00`3oRU/0ohiO0?n:F@040?n;FP80ohaK00X0ohUH0?n4E@3o
Odl0oge:0;Q<;@0000000P0008l[8P3oJU<0ofeI1`3oK5P0103oKEP0ofmJ0?maG03oKEP;0?m/F003
0?m`F`3oKEL0ofaH00/0ofaH00<0og1K0?m_FP3oKEP00`3oK5P00`3oKEP0ofeI0?m^F@030?m/F008
0?m]F@3oLe`0f4dl00P1000000004`<30<4e=@3oFEP=0?mGE@030?mKFP3oEeD0oeME00T0oeME0P3o
EE@01P3oF5L0oeQF0?mHEP3oG5X0oeUH0?mFE@80oeQF00P0oeME0?mFE03oEE<0oe=A0?m?C@3oC4X0
od]90?m5@`<0od9000P0odA20?m5@`3oAdD0odY80?m;BP3oD4h0oe=A0?mFE0<0oeQF3@3oEeD0103o
F5H0oeYH0?mIE`3oEE@B0?mGE@060?mEE03oF5H0oeQF0?mKF@3oEeD0oeED503oEeD01P3oEUD0oeUG
0?mHEP3oFUP0oeQG0?mEE1@0oeME00@0oeID0?mKGP3oIX80ofR70P3oIhH03`3oJ8L0ofN60?m]R`3o
JhT0ofJ50?mTP`3oKX/0og6?0?mWQP3oJXP0odeT00P20P0g6@l0og]70?nNE0020?nLE0040?nLD`3o
WE@0oj5O0?nLD`80oiaD00P0oiiH0?nMEP3oWeT0oiaC0?nNEP3oW5D0oj1K0?nKD`80oj5M00H0oj=S
0?nVE`0W4PT0G3HE0?o7G`3o`IhX0?ooo`<0000000<0bH^@0?ooo`3oool02@3oool0103o_lH00000
0000000000050?ooo`050?oOh`000000000000000020P800103oool0103l[K@0000000000000000I
0?ooo`0407iGFP000000000001TA4P80oooo00D0lLkA00000000000000000820P00=0?ooo`040?no
aP0000000000000000<0oooo00@0o:fd00000000000000003`3oool01@20P8000000000000000000
omoS00H0oooo00@0oko600000000000000000`3oool0103RW:80000000000000000;0?ooo`040?b]
]00000000000000001<0oooo00<0oo3e09MXK00000000`0000000`0I4A80on7Z0?ooo`340?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWin/0oooo0140ojfX08M<
=02>DSX0Pd/a095E?@2AE3d0MD0V08Q==@2<DST0PDL_07Q2:025C3<0ND<Y07I09P1h@RP0OdL]07Q2
:00207U3:@0307M19`1e@2H0N48X00<0ND<Y00@0O4D[09AG?P23BS40N48X0P1i@bT01@1i@RT0PTP]
0<9[@03UOdd0eg@n00H0eg@m00<0eG8l0=Md?@3GM3d01@3GM3d0103ELS`0hg/o0?nbF@3o_U/J0?nk
F`050?nkFP3o_F40ok]K0?nlG@3o^eX05`3o^e/01@3o^eX0okaK0?nmH03o_5`0ok]J01@0ok]K0P3o
^eX00`3o^e/0okeM0?njF@0B0?nkF`030?nkFP3o_Ed0okeM0180ok]K00@0ok]L0?nmH@3o_5`0ok]J
3@3o^e/01`3ocFD0_70g0080000000007P`70>=YA03oUV<03@3oReX00`3oS5/0ohaM0?n9F@0<0?n;
FP030?n:F@3oSEh0ohYI00d0oh]J00L0ohiO0?n:FP3oReX0oheN0?n=G@3oSEl0oh]J0080ohYI1@3o
ReX00`3oSUl0ohaL0?n;FP0:0?n;FP030?n:F@3oSUl0oh]K00X0oh]J00<0ohUI0?n>G`3oReX02`3o
ReX00`3oRe/0oh]J0?n;FP050?n;FP080?n8FP3oReX0oh5A0?miB03oMTL0oh1@0?n:F@3oS5/70?n;
FP030?n=GP3oReX0oh]J00@0oh]J00<0ohYI0?n<G03oRET00P3oReX00`3oSEl0oh]J0?n;FP080?n;
FP030?n:F`3oRe/0oh]J00P0oh]J00<0ohQE0?n;FP3oReX01`3oReX0103oRUT0oi=X0?n>H@3oRUTD
0?n;FP030?n>H03oReX0oh]J0080oh]J00L0ogm?0?mdAP3oN4L0ohIF0?n;FP3oRUT0ohUH00P0oh]J
00P0oh]K0?n;FP3oPe80ogQ70?mgA`3oOTh0ohQG0?n<F`D0oh]J00<0ohUH0?n?H03oRU/02P3oReX0
0`3oSUl0oh]L0?n;FP080?n;FP030?n8FP3oReh0oh]L00/0oh]J00<0oh]L0?n<G03oReX00P3oReX0
3@3oRe/0oh]J0?n7EP3oQE@0oga<0?meA@3oN4L0ofm303LE3@000000V30V0?m[E`3oKeX01`3oK5P0
103oKEP0ofmJ0?m`F`3oKEL:0?m/F0030?m]E`3oKEP0ofmJ00/0ofaH00@0ofeH0?m/F03oLE`0ofeG
1@3oK5P0303oKEL0ofiI0?m^F@3oK5P0ofmJ0?mcG03oDT40<0h:0000000g3@`0iSDd0?mJF0/0oeME
00@0oeMF0?mIE`3oF5H0oeED2@3oEeD0403oEE@0oeAC0?mJF@3oF5H0oe]J0?mMF`3oEE@0oeYH0?mG
E@3oEE<0oeAB0?mAC`3oCD/0od]90?m8AP3o@d420?m2@00:0?lo?`3oA480odM50?m8AP3oBTP0ode;
0?mHE03oE580oeaJ0?mFE@80oeQF3@3oEeD01@3oEUD0oeME0?mHE`3oF5H0oeYH01<0oeME00<0oeED
0?mGE@3oFUP00P3oFELE0?mGE@030?mEE03oEeD0oeUG0080oe]I00<0oeEC0?mGE@3oEeD05@3oEeD0
0`3oEU@0oem[0?mXQ`020?m_S@060?mWQP3oIXD0og:?0?m_S03oIH@0ofR70P3oIhH0203oJXP0of9o
050E700=1P<0oh1<0?n`LP3oXe`0oiaC0P3oW5@00`3oV500oimG0?nLD`020?nLE00@0?nKDP3oXE/0
oj=Q0?nLDP3oW5<0oiaE0?nJD03oVe<0oj5N0?nMEP3oY6<0ojMM03/J3@0a80/0olUL0?o2UbP0oooo
0`0000000`39Ri00oooo0?ooo`090?ooo`040?noaP0000000000000000D0oooo00D0omoS00000000
000000000820P0040?ooo`040<V;T00000000000000000/0oko600<0omWQ0?ooo`3oool02P3oool0
1@3olo`00000000000000000IDE80080oooo00D0i<G800000000000000000820P00=0?ooo`040?no
aP0000000000000000<0oooo00@0bH^@00000000000000002`3o_lH01@3ofN40oooo0?ooo`3oool0
P82000<0000000<0omoS0?ooo`3oool0103oool0103o_lH000000000000000030?ooo`040<V;T000
00000000000000/0oooo00@0bH^@00000000000000002`3o_lH00`3ofN40oooo0?ooo`040?ooo`03
0?noaP0o;2d0000000@0000000<0hYbR0?ooo`3oool0a03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinO[0?ooo`0@0?o8aP1h@BL0R4de07Q2:01nAR`0Qd`d07Q2
:01k@bT0RDlg0858;`1h@RP0PDP_07Q2:01f@2H0N48X0858<0<0ND<Y00<0N48X07]4:P1i@bT00`1i
@bT00`1lAB`0SU8j07Y4:P0307U3:@0607a5:`2fHcP0f7A10=UhB03BLS`0eg<l103GM3d00`3ELc`0
g7U40=Qf?`060=Md?@050<a^>P3oX540ol1Q0?nlG03o^eX06P3o^e/01P3o^eX0okaL0?nlGP3o_V00
okaL0?nkFQL0ok]K00D0okYI0?nmG@3o_5d0okeN0?nkFP0D0?nkF`<0okaL00<0okeN0?nkFP3o^e/0
4P3o^e/00`3o_Ed0ok]K0?nkFP0@0?nkF`030?nkFP3o_Eh0okeN00d0ok]K00X0okYK0?o0G@3AKSD0
>Ql>0000000f50d0ofa70?nAG`3oSE`0ohYJ2P3oReX00`3oRUT0ohiN0?n;FP0=0?n;FP030?n;F`3o
S5/0ohUH00/0oh]J0P3oRUT01@3oSUh0ohQG0?n>G`3oSEh0ohUI00T0oh]J0P3oSEh00`3oRUX0oh]J
0?n;FP080?n;FP030?n9F03oRe/0oh]J00/0oh]J00<0ohUH0?n;FP3oReX0203oReX00`3oSEd0oh]L
0?n;FP080?n;FP060?n<F`3oP500ogE50?mfA@3oODd0ohYI1`3oReX00`3oS5d0ohUH0?n;FP050?n;
FP050?n=G@3oRe`0ohUI0?n:F@3oT6802@3oReX00`3oRUT0oi1R0?n>G`090?n;FP030?n8E`3oReX0
oh]J00L0oh]J00<0ohYJ0?n?HP3oSUl02@3oReX00`3oT680ohQH0?n;FP080?n;FP0;0?n:F@3oReX0
oh]J0?n;FP3oS5/0ohED0?mgAP3oLdD0ogm?0?n<F`3oRUT00P3oSEh90?n;FP040?moD03oMDD0ogE5
0?mlC080ohaK1P3oReX00`3oSEh0ohUH0?n;FP090?n;FP030?n=G03oS5/0oh]J00X0oh]J00<0ohaL
0?n9F03oReX02@3oReX00`3oREP0ohYI0?n:F@030?n<F`0=0?n5E03oOTh0ogY90?mfA@3oMDD0ogi>
0?mfBP1[:AT0000009`b:03oK5P0og5K0?m]F0070?m/F0030?m_FP3oLE`0ofaH00X0ofaH00<0ofeI
0?m/E@3oKUT0303oK5P00`3oKEP0ofiI0?m/E`080?m/F00:0?m_FP3oL5/0ofIA0;Li;00K1`D00000
088M7@3oAdL0oe]J0?mHEPT0oeME00D0oeED0?mHE`3oF5H0oeQG0?mEE0080?mGE@0L0?mEE03oEeH0
oemN0?mDD`3oG5/0oeYH0?mFE03oEE@0oe1>0?m>C03oBTP0odU70?m6A03o@T40od500?m1?`3o@T00
odI40?m9A`3oBTP0ode;0?mAC`3oEE<0oeID0?mFE@3oFeT0oeeK0?mEE140oeME00@0oeQF0?mFE03o
FEL0oeQF4P3oEeD20?mEE0040?mJF03oEU@0oe]I0?mEDa@0oeME00H0oeED0?mIF03oG5X0oeID0?mJ
F03oEE@G0?mGE@070?mEE03oEeD0oeUG0?mLF`3oIg`0ofn=0?maSP020?mXQ`030?mWQP3oJ8L0ofR7
00<0ofR700P0off;09TZ=P000000JRlK0?naK`3o/6d0ojiZ0?nOF0<0oiaD0P3oWEH20?nLE0030?nL
D`3oWEH0oj9P0080oiaC00/0oieF0?nKD@3oVe80oimI0?nJD03oWUP0oj]T048N400U5PP0olUJ0?o9
U00X0?ooo`<0000000<0bH^@0?ooo`3oool02@3oool0103o_lH000000000000000050?ooo`050?oO
h`000000000000000020P800103oool00`39Ri0000000000000<00000003081PH`3oool0oooo00X0
oooo00D0UfQ/00000000000000000;1iOP020?ooo`050>C5b0000000000000000020P8003@3oool0
103o_lH000000000000000030?ooo`030<V;T0000000000000`0000000D0P61S0?ooo`3oool0oooo
0820P003000000030?oOh`3oool0oooo00@0oooo00@0oko600000000000000000`3oool01039Ri00
000000000000000;0?ooo`030<V;T0000000000000`0000000<0P61S0?ooo`3oool00P3oool00`3o
hNX0IDE8000000040000000300d92@3RW:80oooo0<H0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWjP3oool04@3oo_l0ljJN06Xh6`23BC40NT@Z07Do9@1f@BH0
N48X07M19`2:CcP0PTP_07M19`1h@RP0Nd@Z07Y4:P1kA2X0PTT`0080ND<Y00@0NT@Z07m7;@2:D3P0
Md4W0`1i@bT00`1lA2/0PDL_07Q3:@0207U3:@0807I19`2WFc<0dg0j0=Ie@P3KNT/0dG0k0=Qe@03H
MCh30=Md?@030=Eb>`3ROD/0fWM200@0eg@m00<0dg8l0>Io@P3oXe@00P3o_5d01@3o^eX0okaL0?nm
G@3o_5h0ok]L01X0ok]K00H0okaM0?nkF`3o_El0okaL0?nmGP3o^eXF0?nkF`050?nlG@3o_5/0okiO
0?nmGP3o_5h04`3o^e/01@3o^eX0okaM0?nmH03o_5d0okaN0180ok]K00D0okaL0?nkFP3o_F00ok]J
0?nlG@0?0?nkF`050?nlF`3o_5`0okeO0?nmG@3o_5d02`3o^e/02@3o_5`0ol5M0?n`E@34P3h0?B0?
0187101O91L0/UXj0?n8F@0;0?n;FP040?n;F`3oS5`0ohYI0?n<G0`0oh]J00@0oh]K0?n:F@3oS5/0
ohaL1P3oReX0203oRET0oheN0?n9F03oT680oh]J0?n;F`3oReX0ohYI303oReX00`3oRe`0ohaM0?n;
FP0:0?n;FP030?n<G@3oS5`0ohYJ00X0oh]J00<0oheN0?n<G03oReX02@3oReX00`3oS5d0ohaL0?n;
FP080?n;FP080?n<F`3oQUP0ogm?0?mgAP3oNdX0ohED0?n9F03oS5/40?n;FP030?n;F`3oSF00ohYI
00H0oh]J00<0ohaL0?n;G@3oRUX00P3oRe/90?n;FP030?n>G`3oS5d0oh]J00P0oh]J00<0ohUH0?n:
F@3oReX0203oReX00`3oREP0ohYI0?n;FP080?n;FP030?nBI03oRET0oh]J00P0oh]J00P0ohmP0?n;
F`3oReX0ohYJ0?n8E`3oNTT0og];0?n5E0<0oh]J00<0oh]K0?n=G@3oReX0103oReX02@3oRUX0oh]J
0?n6EP3oO4`0ogE60?mmC03oPU40ohYI0?n<F`060?n;FP030?n;F`3oS5/0oh]K00T0oh]J00<0ohaL
0?n=G@3oRUX02@3oReX20?n<G@/0oh]J01<0oh]K0?n<F`3oRUT0ohEE0?n1D03oOD`0ogY:0?mhB03o
Nd/0ogi=0?n1D03oREP0bUhn03TG3`000000TCDZ0?m^F@3oKUX0ofeH00H0ofaH00<0ofeH0?m]E`3o
KUX02P3oK5P0103oKEP0og1K0?m^F@3oKEP:0?m/F0040?m/E`3oKEL0og1K0?m]F@T0ofaH00T0og5K
0?mZE@2Y?c80;`h;000000154100acXi0?mFE@3oFUP02P3oEeD00`3oF5L0oeUG0?mJF0060?mGE@80
oeQF00@0oeMF0?mEE03oDe00oeYH0P3oDDl04@3oBdT0odQ70?m6A@3oAT@0odA30?m4@P3oAT@0odQ6
0?m:B03oBdT0odi<0?m@CP3oDU00oeEC0?mFE03oEUD0oeME0080oeQF0P3oF5L00`3oFEL0oeQF0?mF
E@0@0?mGE@050?mIE`3oF5L0oeQG0?mGE@3oEUD04@3oEeD01`3oEeH0oeME0?mKF@3oFEL0oeQG0?mG
E@3oEUD04`3oEeD01@3oFEP0oeME0?mJF@3oEeD0oeQG01P0oeME00X0oeQF0?mGE@3oG5/0oeUG0?mG
E@3oF5H0oeUI0?mPK@3oIh<0ofV81P3oJ8L01P3oIH80Nb4/0000000L3@P0ghaG0?n`K080ok1Z00D0
oj]V0?nMEP3oW5@0oiaC0?nOF@030?nLE00@0?nME@3oYF@0oj1L0?nLD`3oW5@0oimH0?nPF@3oW5@0
oi]C0?nLD`3oVU00ojEN07/j7P0J40H0oleB0?o<PBP0oooo0`0000000`39Ri00oooo0?ooo`090?oo
o`040?noaP0000000000000000D0oooo00D0omoS00000000000000000820P0040?ooo`030<V;T000
0000000000`0000000<0P61S0?ooo`3oool0203oool00`3onOh0S7Af000000020000000502HJ6`3o
l?D0oooo0?ooo`3ac]400`0000000`20P800oooo0?ooo`0;0?ooo`040?noaP0000000000000000<0
oooo00<0bH^@000000000000300000001@20H6<0oooo0?ooo`3oool0P82000<0000000<0omoS0?oo
o`3oool0103oool0103o_lH000000000000000030?ooo`040>>LXP0000000000000000/0oooo00<0
bH^@000000000000300000001P20H6<0oooo0?ooo`3oool0aZR/00d92@<0000000@06A8B06E6B020
NWh0iMOJb03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOZ
0?ooo`0A0?ofn@3DR7/0Kc`P08A:<P1i@RT0N44W07Do9@1nARd0ND<Y07Q2:01i@bT0MT0V07U3:@21
B2l0TEDm07m7;@1g@BL00P1i@bT0101lA2`0QD`c0899<01h@RP207U3:@030858;`1kA2X0N44W0080
ND<Y00X0LchV09iG<03@L3/0cflj0=Ie@P3LNT/0d70j0<m_>P3GM3l0egDn0P3GM3d00`3ELS/0hGa:
0=Yg@@030=Md?@040=Ac?03oSTX0okYM0?nmG0D0ok]K00@0okaL0?nkFP3o_Eh0okeN6`3o^e/0103o
_5`0ok]K0?nlG@3o_F4H0?nkF`050?nlG03o^eX0okaQ0?nmHP3o^eX04P3o^e/01P3o^eX0okaO0?nk
G03o^eX0okmS0?nkFQ80ok]K00@0ok]J0?nmG@3o_Uh0ok]J4@3o^e/00`3o_Ed0okYH0?nkF`0<0?nk
F`030?nnG@3o[eD0Kc/K0080000000<0LRdL0?n8F@3oS5/0303oReX00`3oRU/0oheM0?n;FP0<0?n;
FP030?n:F@3oSEh0ohYI00<0oh]J00H0ohYI0?n@H`3oSEh0ohaK0?n;FP3oRET30?n;FP030?n:F`3o
ReX0oh]J00`0oh]J00<0ohaK0?n;FP3oReX02@3oReX00`3oRe`0ohYL0?n;FP0:0?n;FP030?n9F03o
RUT0oh]J00T0oh]J00<0ohaL0?n:F@3oReX02@3oReX01`3oS5`0ohUI0?mkBP3oMdH0ogU80?n3DP3o
S5/01@3oReX00`3oRUT0oh]J0?n;FP060?n;FP030?n?H03oT640ohYK00T0oh]J00<0ohUH0?n:F@3o
ReX02@3oReX00`3oR5L0oh]J0?n;FP070?n;FP030?n9F03oRUT0oh]J0180oh]J00P0ohYI0?n?HP3o
Re/0oh]J0?n1D@3oN4L0og];0?n:F@<0oh]J00<0ohiO0?nAI03oR5P0103oReX01P3oS5/0ohQG0?mm
C@3oMdH0ogQ80?n5E0X0oh]J00<0ohYI0?n:F`3oReX05@3oReX00`3oRe`0oh]J0?n;FP0:0?n;FP0@
0?n3D`3oO4`0ogY90?mhA`3oM4H0ogU80?moC`3oR5L0oh]J0?n<F`3oS5`0cFA100<10@000000Z3DZ
0?m]F0P0ofaH00<0ofiI0?m`F`3oKeX02P3oK5P00`3oKEL0ofmJ0?m_FP0;0?m/F0030?m^F@3oKET0
ofeG00T0ofaH00T0ofiI0?m_FP3oEdH0@QDB0000000N1PL0lSPg0?mCD@3oF5L02`3oEeD00`3oFEP0
oeQF0?mGE@050?mGE@070?mED`3oDDl0oda;0?m8A`3oATD0odI40?m5@`020?m2@@080?m1@03oA480
odE30?m;B@3oD4h0oe=A0?mED`3oEU@20?mGE@80oeQF1P3oEeD00`3oEE@0oeYH0?mHEP0B0?mGE@04
0?mLF`3oEU@0oeQF0?mEE180oeME00D0oeMF0?mMG@3oF5H0oeQF0?mEE00E0?mGE@050?mKFP3oDe80
oeQF0?mGE@3oEUD0603oEeD01@3oGUh0oeUH0?mGE@3oF5H0oeED00@0oeME00<0oeID0?mLHP3oJ8@0
1@3oJ8L01P3oJHP0YSa>0000000G2PD0ogY70?naK@@0ok1Z00X0ojQR0?nNF03oW5<0oimJ0?nKD`3o
WeT0oieE0?nMEP3oX5`0oiYA0P3oW5@02`3oYF<0oieF0?nQG03oWEH0oj1J0?nJD@3oVU00Ue@Y00P6
0P3/RS00omVG02P0oooo0`0000000`39Ri00oooo0?ooo`090?ooo`040?noaP0000000000000000D0
oooo00D0omoS00000000000000000820P0040?ooo`040?noaP0000000000000000P0oooo0`000000
0`20H6<0oooo0?ooo`070?ooo`030?noaP0b8b@0000000<0000000D0S8:70?ooo`3oool0oooo0?oO
h`0300000003081PH`3oool0oooo00/0oooo00@0oko600000000000000000`3oool0103o_lH00000
0000000000080?ooo`<0000000D0P61S0?ooo`3oool0oooo0820P003000000030?oOh`3oool0oooo
00@0oooo00@0oko600000000000000000`3oool01@3o_lH00000000000000000oko600X0oooo00@0
oko60000000000000000203oool300000005081PH`3oool0oooo0?ooo`0o;2d00`0000000`1nEeX0
oooo0?ooo`3:0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
inX0oooo0140oo3b0<5iJP1b?B80Q4Xb07e6;01e@2H0ND8Y07a5:`1i@bT0MT0V07Q19`28CCD0NT<Y
07i6;@24BS80LchT07Q2:00207U3:@0307a4;024BS40MT0V0080ND<Y0100O4D[07Q2:@1lAB/0QD/c
07Q2:@1e?bL0WULa0<i_>`3BLC/0cflj0=Ie@P3LNT/0d70j0=5`>`3BLCh0eG<l0P3GM3d00`3ELc/0
gg]80=Uf@0020=Md?@040=Ed?@3YPD<0okaM0?nnF`X0ok]K00@0okmT0?nlF`3o^e/0okaL6`3o^e/0
0`3o_V00ok]L0?nkF`0H0?nkF`030?nkFP3o_F40ok]K0180ok]K00P0okaL0?njF@3o^eX0ok]K0?nm
G`3o^UT0ok]L0?nkFQ40ok]K00@0okaL0?nlG@3o_5/0ok]L4@3o^e/00`3o_V<0ok]J0?nkF`0;0?nk
F`090?nnG03o_E`0eg<g020@1`000000HBLH0?mkD@3oReX0ohaK00`0oh]J00<0ohUH0?n;FP3oReX0
2`3oReX01`3oS5`0oheN0?n;FP3oRUT0ohiP0?n:F@3oRU/0203oReX00`3oS5/0oh]J0?n;FP0G0?n;
FP030?n:F@3oS5/0ohaL00X0oh]J00<0ohYK0?n>H03oReX02P3oReX00`3oSf80ohYJ0?n;FP070?n;
FP050?n9F@3oSUl0oh]K0?n5E03oNDP00P3oN4L00`3oQUD0oh]J0?n;FP020?n;FP030?n=GP3oSV40
ohYI00L0oh]J00<0ohUI0?n>G`3oRET02P3oReX00`3oRUT0oh]J0?n;FP080?n;FP030?n8E`3oReX0
oh]J00L0oh]J00<0ohUH0?n:F@3oReX0203oReX00`3oRUT0oh]J0?n;FP070?n;FP040?n:F@3oR5L0
oh]J0?n3DP80ogM600<0oh=C0?n:F`3oReX00`3oReX00`3oRe`0oh]J0?n;FP030?n;FP060?n7EP3o
NDP0ogM60?mgAP3oQUP0ohaK2@3oReX00`3oRUT0ohiO0?n:F@0:0?n;FP030?n<G@3oReX0oh]J00T0
oh]J00<0ohaK0?n;FP3oReX01@3oReX01@3oS5/0ohYI0?n9F03oPe80ogU900<0ogQ700<0oga<0?n7
EP3oRUT00`3oReX01`3oSe`0ohIH04dO5@030@40[SH[0?m[EP3oKUT01`3oK5P00`3oKET0ofiH0?m]
E`0:0?m/F0030?m/E`3oJeD0ofmJ00/0ofaH00<0ofaG0?m`F`3oKEL02@3oK5P02@3oKeT0ofaG0;@i
;@090`80000001@51@3oADD0oeUG0?mGEP090?mGE@050?mGEP3oE5<0oeeK0?mHEP3oEeD00P3oEU@0
1P3oDe40odm=0?m;B03oATD0od910?m4@`<0odA200L0od=20?m6A03oBDL0odi<0?mBD03oE5<0oeID
00d0oeME00<0oeQF0?mIE`3oF5H04@3oEeD20?mHEP030?mKF@3oF5H0oeME0180oeME00@0oeQF0?mN
GP3oF5H0oeQF503oEeD01@3oF5H0oeME0?mKF@3oGEd0oeQF01P0oeME00D0oeQF0?mFE03oG5X0oeUH
0?mHEP090?mGE@030?mED`3oHW80ofR700<0ofR700H0ofV80?m]RP0o4AL00P000<MI<`3o[fd50?n`
JP040?n^JP3oYV00oi]B0?nKDP80oiaC0180oiiH0?nLE03oW580oiaB0?nME03oW5@0oj9M0?nMEP3o
XUh0oiiG0?nPG03oXUl0oiiI0=E`=`0<1P<0cWHZ0?o<M@3omoPW0?ooo`<0000000<0bH^@0?ooo`3o
ool02@3oool0103o_lH000000000000000050?ooo`050?oOh`000000000000000020P800103oool0
103o_lH000000000000000080?ooo`<0000000<0P8200?ooo`3oool01@3oool00`3onOh0/7Un0000
00040000000301TA4P3oj>`0oooo00<0oooo0`0000000`1aCU40oooo0?ooo`0;0?ooo`040?noaP00
00000000000000<0oooo00@0oko60000000000000000203oool3000000050820P03oool0oooo0?oo
o`20P8000`0000000`3ogn<0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo0`000000
0`3RW:80oooo0?ooo`080?ooo`040?noaP0000000000000000P0oooo0`0000001020P800oooo0?oo
o`3oool300000003038S903onOh0oooo0</0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWjP3oool0403oinH0YfA@09AG?`1lA2`0Q4/b07Do9@1kA2X0SU<j08E<
<P1f@2H0MT4W095E?01jA2X0OTH/0858;`1h@BL307U3:@0B07a5;021B2l0N48X07U3:@1i@RP0Nd@Z
07Q2:01kA2X0Qd`d07I1:02CDS40bFdk0=Ab>`3AL3/0cflj0=Ie@P3LNT/0d70j0P3AL3/02`3ELd00
f7Dn0=Md?@3ELS/0hGa:0=Yg@@3GM3d0eG@m0=9b?03oYU@0okaK00`0ok]K00@0ok]H0?nmH03o_5d0
okaM6`3o^e/0103o^eX0okmT0?nlG03o_5`H0?nkF`040?nnGP3o_Ed0ok]K0?nlG100ok]K00L0okYI
0?nlG03o_5`0ok]K0?nnGP3o_F00ok]J0180ok]K00D0ok]J0?nlG@3o_El0ok]K0?nkFP0?0?nkF`<0
okaL00<0ok]J0?nkF`3o^e/02@3o^e/01`3o_5/0olAN0?nLC00e70d00000020;1`3TFSX00P3oS5/;
0?n;FP030?n:F@3oSE`0oh]J00T0oh]J00H0ohYI0?n;FP3oRe`0ohaK0?n?H03oRUT<0?n;FP030?n<
F`3oRET0oh]J00X0oh]J00<0ohYI0?n9F03oRUT02P3oReX20?n<F`X0oh]J00<0ohYI0?n:F`3oS5`0
2P3oReX00`3oREP0oh]J0?n;FP090?n;FP070?n:F@3oReX0ohED0?mlC03oN4L0ogU80?n7EP030?n;
FP030?n;G03oSEh0ohUH00T0oh]J00<0ohUG0?n:F@3oReX01`3oReX00`3oRUT0ohiP0?n9F@090?n;
FP030?n:F@3oReX0oh]J00L0oh]J00<0ohUH0?n:F@3oReX0203oReX00`3oRUP0oh]J0?n;FP070?n;
FP060?n:F@3oReX0ohQG0?mhA`3oMdH0oge=1@3oReX00`3oRUT0oh]J0?n;FP020?n;FP070?n<F`3o
R5L0og]:0?mgAP3oNTT0ohAC0?n<F`0:0?n;FP030?n:F`3oS5/0oh]J00T0oh]J00<0ohUH0?n;FP3o
ReX0203oReX00`3oS5`0ohmP0?n;F`040?n;FP0;0?n<F`3oReX0ohYI0?n6E@3oO4/0ogQ70?mcA03o
MTL0og]:0?mnCP3oQE@01@3oReX01`3oS5`0ohIH09Xn:@050P40[CH[0?m/E`3oKUT0203oK5P00`3o
KeX0of]E0?m/F0090?m/F0030?m]F@3oKUT0ofaE00/0ofaH00<0ofeI0?m/E@3oKET02@3oK5P00`3o
KeX0ofiH0;@m<00200000006034;2`3aBDL0oeMF0?mIE`3oEU@0oeIE103oEeD30?mHEP080?mGE@3o
FeT0oeMF0?mBD@3oDDl0oda:0?m9A`3oAD<20?m2@@0:0?lo?P3oA480odE40?m6A03oAdH0odY80?m@
CP3oEE@0oeUG0?mKFA00oeME00<0oeQF0?mKF@3oEeD04@3oEeD00`3oF5L0oeeK0?mGE@0A0?mGE@05
0?mFE@3oF5H0oeQG0?mCDP3oFUT05P3oEeD0103oF5L0oeYH0?mIF03oEE<F0?mGE@070?mEE03oEeD0
oeQG0?mGE@3oGUd0oeUG0?mEE00<0?mGE@0:0?mHF`3oJ8<0ofR70?mXQ`3oJHP0ofj;0<HeA@020@40
MC8M0?n`K@L0ok1Z00D0ojiZ0?nTG`3oWE@0oieF0?nLE0020?nME@0@0?nMD`3oVTl0oieB0?nLE03o
Ve40oiaE0?nWI`3oWe/0oj9N0?nQG@3oZ6X0nH=300H30@1]@1H0olaW0?oXhRL0oooo0`0000000`39
Ri00oooo0?ooo`090?ooo`040?noaP0000000000000000D0oooo00D0omoS00000000000000000820
P0050?ooo`<0000000<0om3H0?ooo`3oool0103oool01@3oj>`00000000000000000P82000L0oooo
00<0VGYn0000000000000`0000000`0I4A80om3H0?ooo`040?ooo`0404/d=P000000000004`d=Pd0
oooo00@0oko60000000000000000103oool3000000030?o@f03oool0oooo00@0oooo00D0onS/0000
0000000000000820P0030?ooo`050820P000000000000000003ac]401P3oool0103o_lH000000000
000000040?ooo`0404/d=P000000000009MXK0/0oooo0`0000000`3od=P0oooo0?ooo`040?ooo`05
0?oXk0000000000000000020P8000P3oool01@3o_lH00000000000000000o:fd0<d0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWjP3oool04@3oi^H0Q4/b0818
;@1i@RP0Q4`b08A;<P1nARd0P4P_08iA>P1d@2D0ND<Y08I=<`1kA2X0QT`d08eA>024BS80OdL^0080
ND<Y00`0O4D[08aA>01g@RP0NT<Y07a5;01jA2X0ND<Y07A09@1jA2X0U58a0<m_>`3CLC/20=5`>`04
0<m_>P3FMD80g7Y;0=1`>P80dG0k00X0d70k0=Id?P3GM3d0eG<l0>1lB03IMd80dg8l0>V1A03oYeD0
okaL3`3o^e/01P3o_5/0okeN0?nkF`3o_Eh0okeM0?nlGQX0ok]K00D0okaM0?nlG03o_Ul0okaK0?nl
G@0F0?nkF`80okaL00<0okeN0?nlG03o_5`03`3o^e/02@3o_5h0okaM0?nkF`3o_5X0okaN0?nmGP3o
^e/0okeM0?nkFP0@0?nkF`050?nmG03o^eX0okiP0?nkF`3o_5`03`3o^e/0103o_5d0okeN0?nlG03o
_5`;0?nkF`090?nnG03^ZE80U5<W03LM3P000000JBdM0>]bBP3oRU/0ohiL00X0oh]J00<0oh]K0?n<
G03oReX0103oReX02`3oRUX0ohYI0?n=G@3oRe`0oi1R0?n9F03oSEd0ohYI0?n<F`3oRUT0ohaK00/0
oh]J00@0ohaK0?n:F@3oRe/0ohaK2P3oReX20?n<F`/0oh]J00<0oh]L0?n=G@3oReX02P3oReX20?n;
F`T0oh]J00<0oh]K0?n=GP3oReX02@3oReX03@3oSEd0ohaL0?n;FP3oReX0ohIF0?mlB`3oN4L0oge<
0?n4E03oReX0ohYI0?n=GP3oSUl02@3oReX0103oTF@0oh]K0?n;G03oS5/60?n;FP030?n:F@3oT6<0
ohYI00P0oh]J00<0oh]L0?nFJ@3oReX0203oReX00`3oREP0oh]J0?n;FP070?n;FP030?n<G03oSel0
oh]J00L0oh]J00P0ohUI0?nBIP3oRe`0og]:0?mjB@3oPe<0oh]J0?n<F`<0oh]J00X0ohYJ0?n?H03o
ReX0oh]J0?n;F`3oQUD0ogm>0?mgB03oNdX0ohED0P3oReX00`3oS5`0oh]J0?n;FP080?n;FP80oh]K
203oReX00`3oRUT0oheN0?n<G0090?n;FP030?n<F`3oSEd0oh]J0080ohaK00d0oh]J0?n9F03oQUD0
oh1?0?mmC03oNTT0ogU80?mkB`3oOTh0oh=C0?n8E`3oReX0ohaK00D0oh]J00L0ohaK0<MQ?`1;7Q@0
000008La9`3oL5X0ofiI00H0ofaH00@0ofeH0?m^FP3oL5/0ofiI2@3oK5P0103oKEP0ofiI0?m`F`3o
KEP:0?m/F0040?m]F@3oL5/0ofmJ0?m]F0P0ofaH00T0og1K0?mUD@2dA3L0HalI01H61P1h7Ad0_S`l
0?mBDP3oFEL00P3oF5H02P3oFEL0oeME0?mEE03oEE<0oeAB0?mAC`3oCTd0od]:0?m;B@3oB4H20?m4
@`070?m4@P3oAD<0odA30?m5A03oBdT0oda:0?m@CP020?mBD080oeID0P3oF5H00`3oF5L0oeUH0?mG
E@0=0?mGE@060?mGEP3oF5H0oeUG0?mIE`3oF5H0oeIE3@3oEeD01P3oEUD0oeQF0?mGE@3oFeT0oeQF
0?mIEa40oeME00D0oeIE0?mGEP3oFUP0oeQF0?mHE`0B0?mGE@070?mFE@3oEU@0oeQG0?mHEP3oFeT0
oeME0?mHE`0E0?mGE@090?mFE@3oEeD0oeQG0?mFE@3oGUd0oeQF0?mIE`3oEeH0oeIE00h0oeME00X0
oeQE0?mIG@3oHWH0ofZ80?mWP`2V<T4060H805@Z603oYfH0ok1[1`3o/6X0103o[f/0ojiY0?nUH03o
WEL20?nLE0040?nME@3oWUL0oj=R0?nPFP80oiaD00/0oiiD0?nNF@3oWEH0oi]B0?nPG@3oYfL0UF0j
0000000n90h0olUK0?oTd@0=0?ooo`080?olo`3oj>`0n=SK0>S8bP3;];H0`Zj_0:6GV02BS8`B0?oo
o`<0000000<0bH^@0?ooo`3oool02@3oool0103o_lH000000000000000050?ooo`050?oOh`000000
000000000020P8001@3oool0102GJ6`000000000002`NWh60?ooo`050>_9c000000000000000003;
];H01@3oool00`3H_;l0LDiA000000030000000303<S902UVY/0oo3e00H0oooo00D0f:fd00000000
00001`D50>BoaP0<0?ooo`040?noaP0000000000000000@0oooo00@0UfQ/000000000000/7Yn1P3o
ool01@3[bL`00000000000000000bkBf00<0oooo00D0P82000000000000000000;:OX`060?ooo`04
0<V;T0000000000002HJ6`@0oooo00D0f:fd0000000000003@T90>BoaP0:0?ooo`0409MXK0000000
00000;1jOPH0oooo00D0jlW<00000000000000000<^d]P020?ooo`040?o@f0000000000000000<h0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWjP3oool04@3o
j>T0JCLI078m8P1f@BL0Q4`b08iB>P1kA2X0MT4X08I<<`1e@BH0ND<Y07@n8`1kA2X0Nd<Y07i6;@25
BS<0OdH]0080ND<Y00D0O4D[095E?@1h@RP0OTH/07]4:P0207U3:@0307Q2:@1oAR`0c6dj00@0dG0k
00@0cflj0=Ie@P3LNT/0d70j0`3AL3/0203BLC`0f7E00=Md?@3ELS`0dg8k0?nBC03o_5h0okaK503o
^e/01P3o_5/0okeQ0?nkF03o_F40okaL0?nkFQP0ok]K00D0ok]J0?nlF`3o_5d0okiR0?nlG00F0?nk
F`040?nlF@3o_F00okaK0?nlG@l0ok]K0`3o_5`30?nkF`040?nnH03o^eX0okeM0?nkFQ00ok]K0P3o
^eX00`3o_Eh0okeM0?nkF`0?0?nkF`030?nlF`3o_5d0okaM00`0ok]K00P0olEQ0?nfF@2iHRl030H2
0000001m;ah0ogI=0?n?G@/0oh]J00P0ohYI0?n<GP3oRUT0oh]J0?n:F`3oSUl0ohYH0?n>G`80ohYI
1@3oReX00`3oS5`0oheN0?n:F@0;0?n;FP030?n:F@3oReX0ohaK00/0oh]J00<0ohaM0?n:F@3oReX0
2@3oReX00`3oRUT0ohUH0?n;FP090?n;FP030?n;F`3oReX0ohYI00T0oh]J0P3oRe`:0?n;FP030?n=
G@3oReX0oh]J0080oh]J00L0ogm?0?mhA`3oMdH0oh1?0?n<F`3oReX0ohYI00T0oh]J00@0ohYI0?n9
F03oRUT0ohaK1`3oReX00`3oRUT0oh]J0?n;FP070?n;FP030?n<G03oUVX0oh]J00L0oh]J0P3oRUT9
0?n;FP030?n<G03oSf40oh]J00P0oh]J00D0ohIC0?mhA`3oN4P0ohQG0?n<F`050?n;FP0=0?n=GP3o
RUT0oh]J0?n<F`3oPE00ogM60?mfA@3oODd0ohYI0?n;FP3oRUT0ohiO0?n<F`080?n;FP030?n:F`3o
Re`0ohYK00T0oh]J00<0ohaN0?n9F03oReX0203oReX03`3oRe/0ohaL0?n<F`3oRe`0ohUH0?n1D@3o
ODd0ogU80?meA@3oMdH0oga;0?n1D@3oQeH0ohaK0?n=G0080?n;FP070?n;F`35HCl000000000001e
9Ah0ofiH0?m]F0060?m/F0040?m]F03oL5/0og5L0?m]E`T0ofaH0P3oKEL00`3oLE`0ofaH0?m/F008
0?m/F0030?m/E`3oL5/0ofmJ00T0ofaH00@0ofeH0?mdG@3KDD407PT70P0000004P38=cL0oeiM0?mH
E`3oF5H0oeEC0?mBD03oCD/0oda:0?m8A`3oAD<0odA20?m2@03o@D00od0n0?m2@@3oAT@0odY90?mC
D@80oe9@00<0oeEC0?mHEP3oF5L00P3oF5H50?mGE@030?mIE`3oF5H0oeID00d0oeME00D0oeED0?mE
D`3oFeT0oeUG0?mEE00?0?mGE@030?mCDP3oGEd0oeUG0080oeED403oEeD01P3oEE@0oeQG0?mIF03o
E5<0oeaJ0?mFE1<0oeME00H0oeIE0?mLFP3oEeD0oeaJ0?mHE`3oEE@E0?mGE@070?mEE03oEeD0oeeK
0?mGE@3oFEL0oeQF0?mEE00D0?mGE@030?mFD`3oIGL0SRHb0080000000<0hH9?0?n_K03o[fT00P3o
[fT20?n`JP0=0?n_J@3o/6/0okEe0?ndM03o]GD0ojmZ0?nLE03oW5<0oiaD0?nKD`3oX5`0ojEU0?nP
G0020?nLE00;0?nSH@3oVe40oiaD0?nME@3oVe40oiiI0;M]?`000000?bL@0?o;FP3oh/P01@3oool0
1`3on?l0om3H0?6`]`3AT9D0UfQ/08ELG`13;S00200000000`040`<0oooo0?ooo`0@0?ooo`<00000
00<0bH^@0?ooo`3oool02@3oool0103o_lH000000000000000050?ooo`050?oOh`00000000000000
0020P8001@3oool01@3olo`00000000000000000oko600D0oooo00D0S8:700000000000000000?o`
m@040?ooo`030<V;T0000000000000<0000000<0IDE80?o`m@3oool0203oool01@2GJ6`000000000
00000000hYbR00/0oooo00@0oko60000000000000000103oool01@3olo`00000000000000000oko6
00D0oooo00D0S8:700000000000000000?o`m@030?ooo`050820P000000000000000001UATP01@3o
ool01@3olo`06A4B000000000000OUMJ00D0oooo00D0C3@f00000000000000000?7>d@090?ooo`05
0?oco000000000000000003o_lH01@3oool01@2<PXL00000000000000000oo3e00<0oooo00@03@T9
000000000000o:fdc@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOZ0?ooo`0?0?_;b@1lA2`0N48V07I1:01jA2X0PTT`07Q2:01e?bD0Re0h07m7;P1e?bD0MT4W
07m7;@1h@BL0LchT00D0ND<Y00@0O4D[07M19@1h@RL0N48X0P1i@bT00`23BB`0]F8e0==a>`040=5`
>`040<m_>P3FMD80g7Y;0=1`>P@0dG0k00H0eG@o0=Qf@03ELS/0iX530?nlG@3o_U/F0?nkF`050?nk
FP3o_5T0okeN0?nlF`3o_V<00P3o^eXH0?nkF`060?nkFP3o_F00ok]K0?nmGP3o_5h0ok]J503o^e/2
0?nkFP040?nlG03o_Ed0okeN0?nkFPd0ok]K00<0okaL0?nlF`3o_5/00P3o^e/01@3o^eX0okaL0?nl
G03o_F40ok]J0140ok]K00@0okaK0?nlGP3o_Uh0ok]J3`3o^e/00`3o^eX0ok]L0?nmGP0<0?nkF`03
0?o1GP3oaEl0/f<_0080000000<0>AL?0>]`B@3oS5/02P3oReX01P3oRUT0ohYK0?n>G`3oS5h0oh]J
0?n;G0X0oh]J00<0oheN0?n<GP3oRUT02`3oReX00`3oRUT0ohaK0?n;FP0:0?n;FP030?n<G03oS5h0
ohYI00/0oh]J00<0ohYI0?n;FP3oReX0203oReX00`3oS5`0oh]J0?n;FP080?n;FP030?n;F`3oS5`0
ohYI00T0oh]J00d0oheM0?n;FP3oReX0oh]J0?n<F`3oREX0ohED0?miB03oN4L0oh1@0?n8E`3oTV@0
ohaM00T0oh]J00@0ohmQ0?n9F@3oS5`0oh]L1P3oReX00`3oREP0ohYI0?n;FP070?n;FP030?n:F`3o
UFP0oh]J00L0oh]J0P3oRUT90?n;FP030?n:F`3oSV00oh]J00H0oh]J00H0ohaK0?n1E03oN4P0ogM6
0?n1D03oS5/60?n;FP0=0?n=G`3oR5X0oh]J0?n1D@3oN4L0ogM60?n1D@3oRUT0ohaK0?n;FP3oRUT0
ohYK0?n;F`090?n;FP030?n=GP3oReX0oh]J00L0oh]J00<0ohaL0?n;GP3oRe/02@3oReX01P3oSEh0
ohaK0?n6E@3oP500og];0?mgAP80ogI500D0ogm>0?n6E@3oREP0ohaK0?n=G@090?n;FP070?n;F`3o
R5T0@a/A0000001g9Qh0ofUE0?m`FP070?m/F0030?m^F@3oL5/0ofaH00T0ofaH00<0ofeI0?m]E`3o
KEL02P3oK5P0103oKEL0ofmJ0?maG03oKEP80?m/F00>0?m^F@3oLU`0oeA302T=2`000000@10A0?<m
>`3oEE@0ode;0?m;B@3oBDL0odQ60?m5@`3o@d420?m2@00:0?m1@03oAD<0odQ60?m>C03oCdd0oe=A
0?mJF03oF5H0oe]J0?mIE`80oeQF1`3oEeD00`3oEeH0oeME0?mGE@0>0?mGE@040?mCDP3oG5X0oeME
0?mHE`l0oeME00D0oeID0?mIF03oFEL0oe]I0?mFE@0A0?mGE@060?mED`3oFeX0oeUH0?mHE`3oEeD0
oeED4P3oEeD20?mEE0050?mJF@3oFEP0oeQF0?mFE03oEUD0503oEeD01`3oEE@0oeME0?mMF`3oFEL0
oeYI0?mHEP3oEE@0503oEeD02P3oEeH0oeYI0?mKFP3?=cT010420000001o>B40ojaW0?n_J03o]7<2
0?nfMP0P0?n`K@3o[FL0ojmX0?n_J`3o/W40ok=a0?nbL@3o/Fl0ojIR0?nME@3oWE@0oieE0?nMF03o
XV40oj5N0?nLD`3oW5@0ojIU0?nLD`3oW5@0oj9O0?nNF03oVDd0`6`i0000000i8`h0oj910>bKQ`3A
T9D0UfQ/08ELG`13;S0A000000030?o/m@3oool0oooo00l0oooo0`0000000`39Ri00oooo0?ooo`09
0?ooo`040?noaP000000000000000080oooo00@0on7Z0<V;T039Ri00/7Yn0`0000001@1UATP0bH^@
0<V;T039Ri00omoS0080oooo00D0bH^@000000000000Bc@f0?oco0040?ooo`0403l/;@0000000000
07iGFP@0oooo00<0oo3e0000000000000`0000000`39Ri00oooo0?ooo`090?ooo`030?oQjP0I4A80
00000080000000<0bH^@0?ooo`3oool00P3oool00`3oj>`0bH^@0?ooo`030?ooo`040?noaP000000
0000000000D0oooo00D0bH^@000000000000Bc@f0?oco0040?ooo`0403l/;@000000000007iGFP@0
oooo00<0P8200000000000000P0000001P39Ri00oooo0?ooo`3oool0oo?l09MXK0<0000000<0hYbR
0?ooo`3oool00`3oool01@2<NGh00000000000000000IDI800D0oooo00<0om3H0<V;T03oool00P3o
ool01@39Ri0000000000001;=3H0oo?l00@0oooo00@0?b`]000000000000OUMJ103oool01@1<=3H0
00000000000I4A80onS/00@0oooo00<0om3H0?oQjP3oool0a@3oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOZ0?ooo`030>bi[`23BS<0Nd@Z0080MT4W00`0Q4Xb
07Q2:01c?R@0Se<m08E:<`1b?B<0MT0V07U3:@1h@RP0MClU07I09P1i@RP307U3:@0307<n901nAR`0
N48X0080ND<Y00<0NT<W0;5S?03BL3d01@3AL3/0103?KcX0eWE20=ajB`3@L3X40=5`>`050<m_>P3A
L3/0c6dh0?nWE03o_U/06@3o^e/01P3o^eX0ok]K0?nmG@3o^e/0okiR0?nlG1P0ok]K00D0ok]J0?nk
F`3o_5`0okaM0?nnHP0G0?nkF`040?nlG03o^e/0okaK0?nmGPd0ok]K00<0ok]J0?nmH03o_5/00`3o
^e/0103o_5/0ok]J0?nlH@3o_EhB0?nkF`030?nkFP3o_V80okaK00l0ok]K00@0ok]J0?nmG@3o_5d0
okYI2`3o^e/0203o_E`0okaL0<QZ<@0A20<00000048J403oOU80ohaL2@3oReX01@3oSUl0oheQ0?n:
F`3oSEh0ohYI00`0oh]J00<0oheN0?n<G03oRUT0303oReX00`3oS5`0oh]J0?n;FP090?n;FP030?n=
GP3oSf00ohUI00T0oh]J00<0oh]K0?n>G`3oRUT02P3oReX00`3oSV00ohaL0?n;FP080?n;FP030?n>
G`3oSf00ohYI00T0oh]J00<0ohYI0?n;FP3oReX00P3oReX01P3oR5X0ohMF0?mjBP3oMTL0oga<0?n8
E`T0oh]J00H0ohYK0?nDJ03oRUT0oh]J0?n>G`3oRE/?0?n;FP030?n<G03oUFT0oh]J00L0oh]J0P3o
RUT:0?n;FP030?n:F@3oReX0oh]J00D0oh]J00D0ohYI0?mdAP3oLT@0ogY90?n9F0070?n;FP0<0?n:
F03oR5L0oga;0?mfA`3oNDT0ohIE0?n;FP3oR5X0oh]J0?n:F@3oSf00oh]L203oReX00`3oRe/0ohiQ
0?n9F@0E0?n;FP090?n4D`3oNdX0ogY90?mhA`3oMdH0ogY90?n0D03oQUD0ohYI0080ohaK00<0ohYK
0?n=GP3oReX01`3oReX0203oSE`0ohQI08<d8P000000NRLO0?mYE@3oLE/0ofeH1P3oK5P00`3oJeD0
og1K0?m/F00:0?m/F0030?m`F`3oKEL0ofaH00T0ofaH00<0ofeI0?m`F`3oKeX02@3oK5P02P3oKET0
ofQD0:Xe:P0N2@L0000008`O7@3o?Sd0odY90?m7A@3oA4830?m3@@0=0?m4@P3oAdD0oda:0?m>C03o
De40oeAC0?mHE@3oFEL0oeiN0?mFE03oFEP0oeQF0?mEE0080?mGE@030?mFE03oFeX0oeME00l0oeME
00D0oeMF0?mIF03oF5H0oeQF0?mFE@0?0?mGE@040?mJF@3oEeD0oeQG0?mEE100oeME00D0oeID0?mI
E`3oFeT0oeME0?mHEP0D0?mGE@050?mIF03oGE/0oeED0?mGEP3oEE@05`3oEeD01@3oGUd0oeID0?mH
E`3oEeH0oeED01@0oeME00`0oeQF0?mHE`3oDe80b2`/06HG5`0H1@D0000004XQ4`3oTUD0ojiZ0?n_
J@3o/Vh20?nbK`040?n_K03o[fT0ok1Z0?n`JP80ojmY00T0ok1Z0?n_JP3o[fT0ojAO0?nME@3oW5@0
oiaC0?nLE03oWEH00P3oW5@01`3oUU40oge30>QY>031FC80S40S07Xf700a5P/04P0000001`13;S00
KD]>09MXK03IUY`0hYbR0?o=e@3oo_l04P3oool3000000030<V;T03oool0oooo00T0oooo00@0oko6
00000000000000000P3oool00`3o_lH0000000000008000000050>C5b03oool0oooo0?oco00V6Q/0
0P0000001@0I4A80i:F[0?noaP3RW:80<R<T0080000000<06A4B0?oQjP3oool00`3oool01P2oZjd0
00000000000000003@T90?o@f0d0oooo00<0o:fd0000000000000P0000001P0o:bd0bH^@0<V;T02G
J6`09QXK06E5B0@0oooo00@0oko600000000000000001@3oool02@3olo`09QXK0000000000006A4B
0>BUZ`3o_lH0hYbR038S90020000000301TA4P3ohNX0oooo00<0oooo00X0P8200000000000000000
05Pm?`0000006A4B09MXK02`NWh0<R<T0`0000000`0I4A80oo?l0?ooo`040?ooo`030?kFfP000000
00000080000000L06A4B06E5B039Ri00/7Yn04/d=P000000IDE800<0oooo00T0oo?l02HJ6`000000
000001TA4P3TYJ/0oko60>:LXP0b8b@00P0000000`0I4A80on7Z0?ooo`030?ooo`0508aiOP000000
00000000000o;2d00`39Ri000`1UATP000000<V;T0360?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWinX0oooo0100fjJI07M2:020Abh0P4L^07]4:P2@Dc/0Nd@[
0899<021B2l0PTTa08Q==@20B2l0ND<Y07I19`1i@bT0ODH]0`1i@bT00`1h@RL0NT<Y07U3:@0207U3
:@0507e5:`2cHST0cFln0<U/>@3?L3/0103AL3/0103?KcX0eWE20=ajB`3@L3X40=5`>`040<e_>`3T
Od<0ojIC0?nnG`80ok]K00<0okaL0?nkF`3o^e/06@3o^e/20?nlG0050?nlGP3o^eT0okiQ0?nkF`3o
_5`05P3o^e/0203o^e`0ok]K0?nlG03o_5h0okeN0?nkFP3o_5`0ok]L503o^e/01@3o_5d0okaN0?nk
GP3o_5d0okaL00/0ok]K00<0okaM0?nkF`3o^e/00`3o^e/01P3o_5`0ok]J0?nlG@3o_F00ok]K0?nl
G0l0ok]K00@0okaL0?nlG@3o^eX0okeP403o^e/00`3o_5d0okaL0?nlG00:0?nkF`80okeL0100ojeC
0:Q_=P0a6P`060P507T_7P36ID40ohUI0?n;F`3oReX0ohaK0?n<G03oSUl0ohYI0?n<G@3oReX0oh]K
0P3oReX00`3oS5h0oh]L0?n;FP0;0?n;FP030?n;F`3oReX0oh]K00`0oh]J00<0ohaK0?n;F`3oReX0
203oReX0103oRUX0oh]K0?n;G@3oRe/90?n;FP030?n<F`3oS5`0oh]J00X0oh]J00<0oheM0?n;FP3o
ReX01`3oReX00`3oRUX0ohaL0?n<F`090?n;FP030?n=G@3oReX0oh]J00@0oh]J00H0ohUH0?moCP3o
NDP0ogM70?n0D03oRUT80?n;FP040?n:F@3oReX0oh]J0?n;FP80oheM00L0oh]K0?n;FP3oReX0oh]J
0?n>H03oSf40ohYI00L0oh]J00<0ohaL0?nFJ@3oReX0203oReX00`3oRUT0oh]J0?n;FP070?n;FP03
0?n:F@3oReX0oh]J00D0oh]J00H0ohYI0?mnC@3oN4L0ogi>0?n9F03oS5/60?n;FP060?n:F@3oPe@0
ogQ70?mhA`3oOTd0ohQG103oReX00`3oS5`0oheN0?n:FP080?n;FP030?n<G03oRUT0oh]J00T0oh]J
00D0ohaL0?n;FP3oReX0oh]J0?n<F`020?n;FP0:0?n9F03oQE@0oh1?0?mjB`3oN4L0ogU80?mkBP3o
Odh0oh=B0?n7E`80oh]J00D0ohaK0?n;FP3oReX0ohaK0?n;G0080?n;FP070?n;F`31G3d0@AXA0000
001o;bH0ofaG0?m^F@060?m/F080ofeH00<0ofiI0?m]F@3oK5P01`3oK5P0103oKET0ofeH0?m`F`3o
KUT90?m/F0050?m]F@3oK5P0og1K0?m]F03oKET00P3oK5P20?m[E`0C0?mYE@3oJ5<0ofE@0?mUD03o
HT`0/3/^024:20060@40>`d<0<0^;P3oAT@0odU70?m:B03oC4X0odi<0?m@CP3oDU00oeAB0?mFE002
0?mGE@060?mGEP3oFUP0oeYH0?mJF03oFEL0oeQF2@3oEeD00`3oF5H0oeQG0?mJF00>0?mGE@060?mH
EP3oEeD0oeYI0?mGE@3oFEL0oeQF3P3oEeD01@3oF5H0oeUG0?mGEP3oF5L0oeQF00l0oeME00P0oeMF
0?mGE@3oFeX0oeQF0?mIE`3oEUD0oeQF0?mFEA40oeME00H0oeQF0?mJF03oEeD0oeYI0?mFE@3oF5HD
0?mGE@80oeQF00D0oeeL0?mDD`3oFET0oeMF0?mHEP0B0?mGE@80oeQF00h0oeME0?mEE03^B4P0Yc@c
08<T901P5AD08PP701860`0^50X0L3PM08]C;03iRDl0ok1^0?naJ`80ok1Z0P3o[fX50?n`JP0;0?n_
J`3o/6`0ojiZ0?n^J@3o[FL0oj9K0?nLE03oTDh0AQl@03hL3`0O3PP02P0000003P0B2P<0<b8N04`d
=P1]Bdh0LDiA081WJ`20Oh00P8200:6GV02fYZL0bkBf0>c;cP3ac]40onO[6`3oool3000000030<V;
T03oool0oooo00T0oooo00@0oko600000000000000000P3oool00`3o_lH000000000000800000006
0>C5b03oool0oooo0?ooo`36]KX0<b<T1P0000000`071@D0P61S0?7>d@050?ooo`05081]L@000000
00000000002hVil03`3oool00`35Z:`0C3@f000000060000000300d92@3oool0oooo0080oooo00@0
oko600000000000000001P3oool00`36]KX0<b<T000000050000000300L51@20H6<0lLkA00D0oooo
00H0P71b0000000000003@T90=;7c00V6Q/60000000303l/;@3ne]X0oooo00H0oooo00<0o]KJ08ai
OP1<=3H01`0000000`0=2@T0oooo0?ooo`020?ooo`030<Je^P0c8b@0000000D0000000<01`D5081P
H`3ac]401@3oool00`3ojnd0P6Q/01TB4P07000000030<V;T03oool0oooo0<@0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWjP3oool04@3GY9T0LShT08aA>024
BC80ND<X07@n8`21B2l0SU8i07i6;@24BC80PDP_07]4:`1i@bT0LchT08I;=02;D3L0N48X0080ND<Y
00/0MT8W089:<01i@bT0ND<Y07I1:02OES40bVdj0<IZ=`39K3X0cW0n0=9a?0030=5`>`040<m_>P3F
MD80g7Y;0=1`>P<0dG0k00X0c6hj0?n>BP3o_V00okaK0?nkF`3o^eX0okeM0?o0IP3o_5X0okeM0P3o
^eXL0?nkF`050?nlG03o_f<0ok]J0?nmG@3o_5/06@3o^e/0103o_V80okaM0?nlG03o^eXE0?nkF`05
0?nkFP3o_V00ok]K0?nlG@3o^eX02@3o^e/00`3o_Uh0okaL0?nlG0050?nkF`050?nkFP3o_5/0okeR
0?nlG03o^eX04@3o^e/00`3o_Uh0okaM0?nkF`0?0?nkF`030?nmHP3o^eX0okaM00/0ok]K00<0okaK
0?nWD@1>:1@00P0000001@2;=R80ohiM0?n<FP3oTfH0ohaK00P0oh]J00<0ohaK0?n=GP3oS5`02`3o
ReX00`3oRUT0ohaO0?n;GP0;0?n;FP030?n:F@3oSEh0oh]L00X0oh]J00<0ohYI0?n;F`3oReX02@3o
ReX00`3oRUT0ohUH0?n9F@0:0?n;FP030?n=GP3oReX0oh]J00P0oh]J00<0ohYI0?n;FP3oReX01`3o
ReX00`3oRU/0ohmP0?n;FP050?n;FP080?n<F`3oRUT0ogm?0?mhA`3oNDP0ohED0?n;FP3oS5/50?n;
FP030?n=GP3oTVH0oh]J00<0oh]J00H0oheN0?n:F@3oReX0oh]J0?n<G03oRU/90?n;FP030?n9EP3o
ReX0oh]J00H0oh]J00<0ohiO0?nAH`3oRUT0203oReX00`3oT6<0oh]J0?n;FP030?n;FP060?n:F`3o
R5L0oga<0?mhA`3oQ5H0ohaK1@3oReX0203oS5/0oh]J0?n6E@3oNTT0ogQ70?mmC@3oR5L0ohaK1@3o
ReX00`3oS5/0oh]L0?n;FP080?n;FP030?n:F@3oReX0oh]J00P0oh]J00P0ohaL0?n;F`3oS5/0ohaK
0?n;FP3oR5P0oh5A0?mkBP80ogM600D0ogU80?mgB03oOTh0ohUH0?n8FP070?n;FP030?n<G03oRUT0
oh]J00L0oh]J00D0oi1M0<1N?@0000000000084Y8@080?m/F0030?m]F@3oKUP0ofaE00T0ofaH00<0
ofeI0?m`F`3oKeX02@3oK5P02P3oKET0og1K0?m`F`3oKUT0of]F0?mYE03oIe80ofE?0?mQB`3oFdH2
0?mI@`0:0?mLA@3oGTP0odPg05HG4@000000>Q0>0>0e<`3oDE00oeID0?mHEP@0oeME0P3oEE@01@3o
F5L0oeED0?mJF03oGUd0oeID00<0oeME00<0oeUG0?mHEP3oEE@01@3oEeD01@3oEUD0oeME0?mIE`3o
FUP0oeMF00d0oeME00@0oeED0?mHE`3oFUP0oeEC3P3oEeD01@3oEUD0oeQF0?mGEP3oF5H0oeUG0100
oeME00<0oeED0?mGE@3oF5L00P3oF5H00`3oEE@0oeME0?mGE@0?0?mGE@060?mFE@3oEE@0oeUG0?mG
E@3oFUT0oeEC5@3oEeD01P3oEE@0oeQF0?mHE`3oEE<0oeeK0?mHEa@0oeME00L0oeMF0?mJF@3oG5X0
oe5@0?m0?`2]:2H0EA4A0080000000X030D1038E2P2MAR@0oi5<0?nUFP3oXUP0oj1F0?nOE03oYV00
ok1[203o/6X00`3o/6d0ok1^0?n]J0040?n^J@030?nQFP3oW5<05@X500@0000000X0?QhA06D^6@2:
?R40aeT`0=5R>`3XLD@01@8100l80`3;LbP0ol:?9`3oool3000000030<V;T03oool0oooo0180oooo
00D0omoS00000000000000000820P0090?ooo`070?noaP2GJ6`09QXK0000000I4A80IDE80>BoaP07
0?ooo`0506E6B000000000000000003ol?D04@3oool00`3ohNX0bH^@04`d=P020000000304/d=P2G
J6`0om3H0100oooo00L0oko609MXK00V6Q/0000001TA4P1UADP0i;o600d0oooo00L0hYbR07iGFP0I
4Q80<R<T06E5B039Ri00ooWn00/0oooo00P0i;Jm06E5B00b8b@0000002HJ6`1UADP0bH^@0?o@f0H0
oooo00L0oko609MXK00V6Q/0000001TA4P1UADP0i;o600X0oooo00<0hYbR04`d=P0000000P000000
0`1UATP0bH^@0?oco0360?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWinX0oooo00/0biJ606ll8`2;DCT0PDP_07m7;`1e?bD0PDP_08aA>@1lA2/0Q4Xb07]4:P02
07U3:@04078m8`24BS80R4de07U2:080ND<Y00/0Nd@[08E;<@1i@bT0MT4X07U3:02nISH0bF`j0<IZ
=`39K3X0bFdk0=9b?`030=5`>`040<m_>P3FMD80g7Y;0=1`>P<0dG0k00<0iGa10?nhG03o_5/0103o
^e/01`3o^eX0okeO0?nmH@3o^EH0okaP0?nlG@3o^eX06`3o^e/01`3o^eX0okaL0?nmHP3o_5`0okeM
0?nkF`3o^eX05P3o^e/01@3o^eX0okYI0?nnH03o^e/0okaN01H0ok]K00@0okeN0?nmH03o_5d0okaL
2@3o^e/00`3o^eX0okeN0?nlG0060?nkF`050?njF@3o_Ed0okaM0?nlG03o^eX0403o^e/0103o_Ed0
okaN0?nkG03o^eX=0?nkF`80ok]J00<0okeQ0?nlG03o^e/02P3o^e/02@3o_e`0ok=G0:9E:00D2PD0
00000:I0:`3oNe40oi1N0?n<F`090?n;FP030?n9F03oSUl0oh]J00/0oh]J00<0ohYI0?n>G`3oRe`0
2`3oReX00`3oRUT0ohaN0?n;FP0;0?n;FP80oh]K2@3oReX00`3oS5/0oh]K0?n9F@090?n;FP030?n<
G03oRUT0oh]J00P0oh]J00<0oheN0?n;F`3oReX01`3oReX00`3oRU/0ohiO0?n;FP060?n;FP070?n8
FP3oReX0oge=0?mfAP3oMdH0oh1@0?n:F@050?n;FP030?n<G03oSV40oh]J00<0oh]J00@0oh]K0?n:
F@3oRUT0oh]J0P3oRUT90?n;FP030?n8E`3oReX0oh]J00H0oh]J00<0ohiO0?nAH`3oRUT0203oReX0
0`3oUVX0oh]J0?n;FP020?n;FP070?n:FP3oREP0og]:0?mgAP3oOe00oi1S0?n:F@060?n;FP050?n0
D03oN4L0og120?mnCP3oS5/01P3oReX20?n;F`030?n:F@3oReX0oh]J00H0oh]J00<0ohQH0?n=G@3o
ReX01`3oReX0403oR5X0ohiO0?n=GP3oRe/0ohUH0?n6E@3oPE40ogU80?mfA@3oMdH0ogU80?mmC@3o
QU@0ohYI0?n<F`3oRe/70?n;FP030?n:F@3oSUh0ohYK00L0oh]J0P3oSE`01@1B8AH0000008DZ8P3o
JeH0ofmI00L0ofaH00<0ofmI0?m[E@3oK5P0203oK5P00`3oKEL0og1K0?m]E`050?m/F080ofeI00T0
ofiJ0?m/F03oJeL0ofUC0?m/F03oI4l0of5<0?mPB@3oFdD00`3oF4802`3oFTD0oei80?mPB@3oHT/0
/cHY00l410000000C1<C0?m=C03oFUT0oeQF00@0oeME00P0oeED0?mGE@3oG5X0oeQG0?mKFP3oEeD0
oeUH0?mFE0D0oeME00<0oe]I0?mHEP3oEE@0103oEeD0103oFEL0oeAC0?mMF`3oE5<=0?mGE@030?mH
E`3oEeD0oe]I00l0oeME00D0oeED0?mIE`3oFEL0oe]I0?mED`0A0?mGE@030?mIF03oF5L0oeeK01<0
oeME00D0oeED0?mIF03oEU@0oeeK0?mIE`0E0?mGE@070?mEE03oF5H0oeYI0?mHEP3oG5X0oeME0?mE
E00C0?mGE@060?mGEP3oFeX0oeID0?m7A`3k?S`0O1`K0`0000001P0]50T0Pc/O0=UO<@3oSDX0ojUL
0?nRE`@0oj1F00<0oieC0?nZI@3o[f`01`3o/6X00`3o[f`0ojiX0?n^J@040?n^J@0A0?nWH@3oW580
hVHh0=5O=03oO4@0oiQA0?nLE@3oYfP0oj1L0?nKE03oVU40oiiG0?nQH@0;1P<0000008mB6`3o`hT0
9`3oool3000000030<V;T03oool0oooo0180oooo00D0omoS00000000000000000820P00G0?ooo`04
06E6B0000000000000000?l0oooo?P3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOZ0?ooo`0U0<>>O@1/>Qh0S54i0898<01mAR`0MT0V07i6;@25Bc<0MT4V07i7
;01h@BL0N48X07Y4:P1oAbh0Nd@Z07i6;01i@bT0N48X07a4:P1nAR`0OdH]07Q2:01i@bX0YE`g0<Y^
>`39K3X0b6/h0<M[>@38K3X0c6hl0<m`>`3AL3X0dG0k0<m_>P3FMD80g7Y;0=1`>P020=5`>`030<Y]
>P3gW500okeK00L0ok]K00L0ok]J0?nkF03o_V80okaM0?nnH`3o_5`0ok]J01/0ok]K00L0ok]J0?nl
G03o_Uh0ok]H0?nnH`3o^e/0ok]J01H0ok]K00H0ok]J0?nmH03o_F00okYJ0?nlGP3o^eXD0?nkF`04
0?njF@3o_F00okeN0?nmGPX0ok]K00<0okeN0?nkFP3o^e/01@3o^e/0103o^eX0okeP0?nlF`3o_F0A
0?nkF`030?nmGP3o^e/0okeP00l0ok]K00@0ok]J0?nmG@3o_Ed0ok]J203o^e/02`3o^eX0okaN0?o2
G`3o`ed0k7hn01H;1P000000BQhD0>eM?@3oSed0ohUJ00T0oh]J00<0ohaL0?n<F`3oREP0303oReX0
0`3oS5h0oh]K0?n;FP0:0?n;FP030?n<G03oSEh0oh]J00X0oh]J00<0oh]L0?n;FP3oReX0203oReX0
0`3oRe/0ohiO0?n9F`090?n;FP030?n<F`3oSEh0ohUI00P0oh]J00<0ohYI0?n;FP3oReX02@3oReX0
0`3oSUl0oh]J0?n;FP060?n;FP070?n9F@3oO4/0ogM60?meAP3oPE00oh]J0?n8FP030?n;FP030?n:
F@3oR5D0ohUI00D0oh]J00D0ohUH0?n<F`3oReX0ohUF0?n:F@080?n;FP030?n8E`3oReX0oh]J00H0
oh]J00<0ohiO0?nAH`3oRUT0203oReX00`3oUV/0oh]J0?n;FP020?n;FP070?n:FP3oODd0ogM60?mh
A`3oQUL0ohaK0?n:F@030?n;FP030?n8FP3oReX0oh1@0080ogI500<0ogU:0?n9F03oReX01P3oReX0
0`3oRUX0ohiO0?n:F@070?n;FP030?n:F@3oS5h0oh]J00P0oh]J00/0ohiN0?n=GP3oR5L0oh=C0?ml
B`3oMdH0ogI50?mgAP3oODd0oh1@0?n5E0020?n<G0T0oh]J00<0ohYI0?n<G@3oReX01`3oReX01`3o
S5/0oheL0:M2;0000000R2/S0?m/E`3oLe`01`3oK5P00`3oL5/0ofiI0?m/F0080?m/F0030?m/E`3o
KUT0ofmJ0080ofaH00X0ofeI0?m^FP3oKeX0ofaH0?m[E03oJE80ofA?0?mRC@3oHD/0oee70P3oEd40
2P3oF480oeU20?mKAP3oGdP0oem:0?mRC@3oIE00ofiG0?mbF`2a>2d20000000304TB4@3dBTP0oeMG
00@0oeME0P3oEE@01`3oFeT0oeID0?mNGP3oFEP0oeMF0?mFE03oEE@01`3oEeD01@3oFeT0oeUG0?mF
E@3oEeD0oeED0080oeUG00<0oeID0?mEE03oEeD0303oEeD0103oEeH0oeUG0?mIF03oEE<=0?mGE@05
0?mEE03oEE<0oe]I0?mJF03oEE<0403oEeD01P3oEE@0oeEC0?mIE`3oGE/0oeME0?mEE140oeME00H0
oeED0?mHEP3oFeX0oeUH0?mHEP3oEE@D0?mGE@070?mEE03oF5H0oeeK0?mFE03oGE/0oeQF0?mEE00B
0?mGE@070?mHEP3oFUT0oeeL0?mHE`3^?Sd0U2<R03l<30020000000700P3001<8A00UT8R0?Im@@3o
[Ed0oj]M0?nTF@070?nPEP030?nUG@3o/6X0ok1Z00D0ok1Z00<0ojmY0?n]I`3o[VT01@3o[VT04@3o
[6L0oieF0?nJD@3oWe/0oimH0?nLE03oW5D0oj9P0?nNE`3oVe<0oiiJ0?nRGP3oXV403`L300000027
Ca`0ol9n02L0oooo0`0000000`39Ri00oooo0?ooo`0B0?ooo`050?oOh`000000000000000020P800
5`3oool0101UATP0000000000000003o0?oooch0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWjP3oool06@32SGd0ND<Y08eA>@23BC40PDP_07U3:@1h@RP0N44W
07Y3:01e?b@0Md8X07U3:@1lAB/0T5@l07@n8`1h@RL0NT@Z07i6;01kAB/0SE4i07I19`1oARX0[Ehg
0<]]>`3:KCX00P39K3X03P36JSP0bF`j0<Y]>P3;KSd0d70n0=5`>`3?KcX0eWE20=ajB`3@L3X0d70k
0=Qd?P3cU4`0okYJ303o^e/01P3o_El0okaJ0?nlF`3o_F00okaL0?nmGa/0ok]K00L0okaJ0?nmGP3o
_5`0okeO0?nkF`3o_Eh0okaL01L0ok]K00D0okaM0?nmH03o_5/0okaN0?nlG00C0?nkF`80okaL00<0
okeM0?nlG03o_5d01`3o^e/00`3o_5d0okaK0?nlF`070?nkF`060?nkFP3o_5d0okeM0?nlF`3o_Eh0
okaJ3`3o^e/0103o_5d0okeM0?nlG03o_5d=0?nkF`040?nkG03o_5/0okaL0?nlGP@0ok]K0P3o_5d0
0`3o_5h0okiP0?nlG0020?nlG0080?o1GP3[X4h0QdTT028B2@070P80NCLU0?imDP3oSeh90?n;FP04
0?n<F`3oRUT0ohaM0?n<G0/0oh]J00<0oh]K0?n8F03oS5/02P3oReX00`3oS5`0ohaM0?n=G@090?n;
FP030?n:F`3oS5/0ohYJ00X0oh]J00<0oh]K0?n:FP3oReX0203oReX00`3oSE`0ohaL0?n;FP080?n;
FP030?n;G03oRUX0oh]J00L0oh]J00<0ohYJ0?n<F`3oS5/0203oReX0203oSf00ohQG0?moCP3oN4L0
oge<0?n3E03oRUT0ohaK0P3oReX00`3oS5h0oheN0?n;FP040?n;FP050?n:F@3oReX0oh]L0?nCI@3o
SEh0203oReX00`3oRUT0oh]J0?n;FP060?n;FP030?n>G`3oTF<0ohYI00/0oh]J00P0ohaK0?n;FP3o
P4l0ogI60?mmC03oR5L0ohaL0?n:F@80oh]J00T0ohaK0?n:F@3oQ5@0oga<0?mgA`3oOdh0oh]L0?n;
F`3oS5/01`3oReX00`3oSUh0ohYI0?n;FP070?n;FP80oheM00<0oh]K0?n;FP3oReX00P3oReX0403o
S5/0oh]J0?n9F03oQ5@0og]<0?mkB`3oNDT0ogU80?mmC03oOdh0oh=B0?n8E`3oREX0ohYK0?n;FP3o
S5`90?n;FP030?n;F`3oS5d0oh]L00L0oh]J00D0ohaK0<mV@`1B8AH0000008Lb:0020?m`FP030?m]
F03oK5P0ofaH0080ofaH00D0ofeH0?m_FP3oL5/0ofiJ0?m]F0060?m/F080ofeI00/0ofiH0?m/EP3o
KEL0ofUD0?mWDP3oI4l0ofA=0?mPB`3oGDL0oea60?mLA@020?mLAP0C0?mNA`3oGDL0of1:0?mUCP3o
Ie00ofMB0?mZE@3oJeH0ofaG0?m/F03oKeX0of9?0:M1=@1G6aH06@L6084P7`3;?ch0oe=B0?mHE`02
0?mFE@0:0?mHEP3oF5P0oeQG0?mKFP3oEeD0oeUG0?mFE@3oF5H0oeQG0?mHEPX0oeME00<0oeUG0?mH
E`3oF5H00P3oF5H00`3oEUD0oeME0?mGE@0:0?mGE@050?mHE`3oEeD0oeUH0?mHE`3oEU@03@3oEeD0
1@3oF5H0oeIE0?mKF@3oF5H0oeQG0100oeME0P3oFEL0103oFUP0oeID0?mHEP3oEUD@0?mGE@070?mE
E03oFeX0oeQF0?mJF03oEeD0oeQG0?mFE@0B0?mGE@090?mFE@3oEeH0oeYI0?mDD`3oGE`0oeMF0?mI
F03oEU@0oeIE0100oeME0140oeQF0?mJF03oFEL0oe1>0<Ho?P2F9B@0I1PG044@3`0C1@@0;1<9068[
5P21?b80aVdj0?n>C@3oV580ojEH0?nUF@0:0?nPEP030?nQE`3oYf40ojmZ00<0ok1Z00<0ojmZ0?na
K@3o[f/01`3o[VT01`3o[VX0ojYT0?nME03oX5X0oimH0?nOE`3oW5@00P3oW580203oVU80oj=Q0?nQ
GP3oVe<0BB4@0000001T>AD0olQi9`3oool3000000030<V;T03oool0oooo0180oooo00D0omoS0000
0000000000000820P00G0?ooo`0507UKG`00000000000000003Ub/`0o`3ooolm0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinX0oooo01L0`ham08U@=`1oAbh0
R4lf07M19`1h@RP0LchT08A:<P22BC00R4`e07m7;P1h@RP0O4D[08mC>`1lAB`0N48X07Y3:@1i@RP0
ND<Y08A:<P1k@bT0]V<g0<i_>P040<U/>P0=0<IZ>039K3X0bF`j0<U/>@3:K3/0dW8o0<m_>P3FMD80
g7Y;0<i_>P3ELSX0ojQE0?nnG00@0?nkF`060?nkFP3o_5`0okeM0?njF@3o_V<0okYI6`3o^e/01P3o
^eX0okaL0?nlG@3o_5d0okiN0?nkFQL0ok]K00@0ok]J0?nlG@3o_5`0okiR5P3o^e/0103o_5/0okaL
0?nlH@3o^UT60?nkF`030?njF@3o_F40okaL00X0ok]K00<0okeN0?nlG@3o^e/03`3o^e/40?nlG0h0
ok]K00L0okaL0?nlGP3o^eX0ok]K0?o1I@3o_5X0okaL0080ok]J103o^e/0203o_5`0ol5N0?nZE02P
ERX00`8101L91P2M?BP0ohUI2`3oReX00`3oS5/0ohYI0?n;FP0:0?n;FP030?n:F@3oRe`0ohiO00/0
oh]J0P3oRe`:0?n;FP030?n;F`3oS5`0oh]J00P0oh]J00<0ohUI0?n;FP3oReX02@3oReX00`3oSEh0
ohiO0?n:FP080?n;FP030?n?H03oReX0oh]J00L0oh]J00<0oh]K0?n;FP3oReX01`3oReX0103oRUT0
ohQG0?n<F`3oQ5@20?mgAP030?mjB@3oR5L0oh]J00X0oh]J00<0ohaL0?nFJP3oReh0203oReX20?n:
F@L0oh]J00<0ohiO0?n@HP3oRUT01`3oReX00`3oR5L0ohYI0?n;FP020?n;FP070?n0D03oMTH0oh1@
0?n;FP3oRUT0oi1R0?n:F@020?n;FP060?n8E`3oNTT0ogM60?mfA`3oQ5<0ohYI2@3oReX00`3oRU/0
ohaL0?n;FP070?n;FP030?n<F`3oRU/0oh]J00@0oh]J00D0ohUH0?moC`3oNdX0ogU80?mfAP020?mh
A`050?moC`3oREP0oh]J0?n<F`3oRU/00P3oReX00`3oRUT0ohUI0?n;FP080?n;FP030?n:F`3oS5h0
oh]J00L0oh]J00L0ohYJ0<eT@P020000000008<[8P3oKeX0ofeH00H0ofaH00<0ofiI0?m`F`3oK5P0
1P3oK5P0203oK5L0ofMB0?mWD@3oHD/0oei80?mLA`3oFdH0oeY40`3oFD<01P3oGDL0of9;0?mSCP3o
IU40ofaG0?m/F080ofeH0P3oKET50?m/F0030?m_FP3@CSl06PP60080000000T0a3Xh0?mJF03oF5L0
oeME0?mFE03oGEd0oe]I0?mFE03oF5L00P3oEE@00`3oEeD0oeYI0?mEE00=0?mGE@040?mHEP3oFUP0
oeUH0?mEE0`0oeME00@0oeED0?mIF03oF5H0oeQF3P3oEeD01@3oEE@0oeYH0?mIF03oEeD0oeED00l0
oeME0P3oEE@00`3oGU/0oeMF0?mGE@0B0?mGE@050?mHEP3oG5X0oeAC0?mIF03oEUD05@3oEeD01P3o
EU@0oeiN0?mIE`3oF5L0oeME0?mEE140oeME0100oeIE0?mGEP3oEeH0od]:0:<U901E4a<090L70040
000000002`D006@Z503bMcl0oi=>0?nQEP3oZE`0oj=I403oX5H01P3oY5d0ok=^0?n`JP3o/6X0ok1]
0?n`JPT0ojiY0100ojeY0?n[IP3oXV00oieF0?nLE03oX5/0oiaE0?nLD`3oVe@0oieE0?nLD`3oVU00
TSlN0000001I<Q<0om9i9`3oool3000000030<V;T03oool0oooo0180oooo00D0omoS000000000000
00000820P00G0?ooo`0509VATP00000000000000001aCU401`3oool00`3oj_<0oooo0?ooo`3o0?oo
oc<0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWjP3oool0
5P2jTH@0Re0h07E0901h@BL0PTT`07]4:P1kABX0PTT`07]4:`2<DCP0OdL^07Q2:01lABX0UeY108]@
=`1e@2H0P4P^07Q2:01i@bX0Re4i09AB<@3>KcX40<U/>P030<Y]>`3?LT40bF`j00<0bF`j00L0c6hk
0=5`>P3FMD80g7Y;0=1`>P3oYU<0okiM01D0ok]K00@0okaL0?nkF`3o_f@0okiN703o^e/01@3o^e`0
ok]K0?nkF03o`FL0ok]I01P0ok]K00@0okaL0?njF@3o`FH0ok]J5@3o^e/00`3o^eX0okeQ0?nlG007
0?nkF`030?nlG`3o^e/0ok]K00T0ok]K00<0okaN0?nlG@3o^e`0403o^e/00`3o^eX0okeO0?nlG00<
0?nkF`060?nkG03o^e/0okiO0?nmG@3o^e/0okaM2P3o^e/00`3o_ed0okYJ09mH:`020000000309e0
:`3oRe/0ohaK00T0oh]J00<0ohYI0?n;F@3oRe/02`3oReX00`3oRUT0ohaN0?n;F`0;0?n;FP030?n=
GP3oRUT0oh]J00T0oh]J00<0ohaM0?n:F@3oReX0203oReX00`3oRET0oheN0?n;FP080?n;FP030?n9
F@3oS5/0ohaK00T0oh]J00<0ohUH0?n;FP3oReX01P3oReX00`3oRUT0ohmR0?n:F@080?n;FP080?nB
IP3oReX0oh]J0?n5E03oNTT0ogM60?mlB`3oREP20?n;FP030?n9F03oReX0oh]J0100oh]J0P3oRUT7
0?n;FP030?n>G`3oTF<0ohYI00L0oh]J00L0ohUH0?n;FP3oReX0oh]J0?n0D03oMdH0oga<00<0oh]J
00/0ohYI0?n;FP3oReX0ohUH0?mkB`3oMdH0ogY90?n6E@3oReX0ohiQ0?n<G0080?n;FP030?n:F`3o
S5d0oh]J00H0oh]J00<0ohYJ0?n<GP3oRe`00P3oReX0103oRUT0ohMF0?n0D03oNTT30?mhA`050?mk
C03oQeP0ohYI0?n;FP3oS5/0103oReX00`3oRET0ohiO0?n=GP090?n;FP030?n<F`3oR5P0oh]J00H0
oh]J00L0oheL0?n<F`1=7Q@0000005dL5`3oJE@0ofeI00H0ofaH00<0ofeG0?m`F`3oK5P00P3oK5P0
2@3oJeL0ofQC0?mWD@3oI4d0oem90?mKAP3oFdD0oeY50?mJA0030?mJA@0:0?mNB03oIDl0ofE@0?mZ
E03oJeL0ofeG0?m/F03oKUT0og1L0?m^F@L0ofaH00`0ofmI0?maF`3oDd<07`X80000000Z2PX0mcdj
0?mGEP3oF5H0oeEC0?mKF@3oFUT20?mHEP@0oeME00<0oeeK0?mGE@3oEeD02`3oEeD01P3oEE@0oeeK
0?mCDP3oEeD0oe]I0?mJF0/0oeME00<0oeQG0?mIF03oF5H03`3oEeD00`3oF5L0oeUG0?mGE@0@0?mG
E@050?mHEP3oF5L0oe]I0?mEE03oF5H04@3oEeD01@3oF5H0oeME0?mIF03oFUP0oeQF01D0oeME0P3o
F5H0103oGE/0oeID0?mHEP3oF5HA0?mGE@80oeMF00D0oeIE0?mFE03o@D00XB<S02D61P0200000008
00H300177`l0i6@d0?n@C@3oVU<0oj=H0?nSF@3oXELB0?nPEP050?nOE@3oY5`0ok1Z0?naJP3o/F`0
2@3o[VT20?n_JP080?n^J`3oYEl0oiaD0?nLE03oW580oieF0?nOF@3oW5D20?nKDP050?nLE02E@R80
000005Tb4`3oeG/09`3oool3000000030<V;T03oool0oooo00T0oooo00@0bH^@0000000000000000
1@3oool01@3ogn<00000000000000000P82001L0oooo00<0i<G80000000000000P0000000`39Ri00
oo?l0?ooo`020?ooo`030?o@f02`NGh0S6Q/01D0oooo00@0bH^@0000000000000000o`3ooolL0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinT0oooo0180oogo
0;]dG@28CcL0O4@Z07I09P24Bc80OTD]08iB>P1i@bT0ND8X08iB>P21B2l0N48X07a5:P2HFT80Re0g
07Do9@1g@BL207U3:@0308M<=02cHCP0bF`j00@0bF`j00<0c6lm0=UiC039K3T00`39K3X01P3;KS`0
cFdj0=Ie@@3INDT0iXM50?noGQT0ok]K00D0ok]J0?noH@3o^e/0ok]J0?nmG@0L0?nkF`040?nmG@3o
_640ok]J0?nlG1P0ok]K00@0okeO0?nmGP3o^e`0okaL503o^e/0103o_E`0okeM0?nkF`3o_5`40?nk
F`030?nlG`3o^UT0ok]K00X0ok]K00@0okYH0?noH`3o^e/0okaL3`3o^e/0103o_5X0okiS0?nkF`3o
^e`80?nkF`040?nlG03o^UT0okiS0?noH`80ok]K00<0okaL0?nlH@3o^e/02P3o^e/02@3o_5/0okMI
08I68`0?1`@01@810;Y8<03oPeD0oheL0?n<F`080?n;FP030?n:F@3oSUl0ohaL00/0oh]J00<0ohUI
0?n;G@3oRET02P3oReX20?n;G0030?n:F@3oReX0oh]J00L0oh]J00<0ohaK0?n?H03oReX02@3oReX0
0`3oS5d0oh]J0?n;FP080?n;FP030?n9F`3oS5/0oh]J00P0oh]J00<0ohaN0?n;FP3oReX01`3oReX0
0`3oRUT0oh]K0?n;FP070?n;FP0<0?n8E`3oRUT0oh]J0?n<F`3oR5L0oge=0?mfA`3oNdX0ohMF0?n:
F@3oSf80ohYI1`3oReX0103oREP0ohaL0?n;F`3oRUX60?n;FP030?n;G03oSel0oh]J00H0oh]J00<0
ohiO0?nAH`3oRUT01P3oReX01@3oRUT0oiAY0?n:F`3oReX0oh5A0080ogM600<0ohEE0?n;FP3oReX0
0P3oReX02P3oS5/0ohED0?mkBP3oN4L0oge=0?n8E`3oR5X0oh]J0?n<G`3oRe`80?n;FP030?n=GP3o
ReX0oh]J00H0oh]J00d0ohaL0?n=GP3oRUT0ohUH0?n4E03oNTT0ogQ70?mgAP3oNDP0og]:0?n0D03o
R5L0ohYI00P0oh]J0P3oS5`00`3oRUT0oh]J0?n;FP060?n;FP030?n:F@3oREP0oh]J00H0oh]J00L0
ohaL0?n<F`2G?2L00000060M5`3oJ5<0ofeH00<0ofaH00/0ofeI0?m^F@3oK5P0ofaE0?m/EP3oK5L0
ofIA0?mUC`3oHT/0oee70?mJA@020?mI@`080?mKA@3oFdH0oei80?mKA@3oHD/0ofMA0?mWDP3oJUD6
0?m/F0030?m]E`3oLUd0ofaH00L0ofaH00`0og1J0?mXDP2j>Bh03`D300T20P1o8200odm>0?mJF03o
F5H0oeeN0?mHE`3oEU@40?mGE@040?mHEP3oFEL0oe]I0?mHEP`0oeME0P3oFEL30?mGE@030?mEE03o
FEP0oeYH00P0oeME00@0oeQF0?mIE`3oFEP0oeED303oEeD01@3oEUD0oeQF0?mFE03oFEP0oeUG00l0
oeME00D0oeIE0?mHEP3oEU@0oeeK0?mHE`0A0?mGE@060?mEE03oEeD0oeME0?mOGP3oFEL0oeED4`3o
EeD01P3oEE@0oeQF0?mHEP3oFEL0oeeN0?mFEA<0oeME0P3oF5L0103oE580ode=0<X`;`0`2@X20000
000600T40@0Y4@P0Lc<J0?E/=`3oW5@0oj1F0P3oXUL00`3oXEH0oj1F0?nPEP0C0?nPEP030?nQE@3o
ZV<0ok9_0080oji[00@0ojm/0?n`K@3o/6d0ojmZ0P3o[VP20?n/IP050?neL`3o]GH0okQh0?n`K`3o
WED00P3oW5@02P3oXUh0oj=P0?nKD`3oVe@0oi]B0?nLD`31FBl00000034N2`3o_gHW0?ooo`<00000
00<0bH^@0?ooo`3oool02@3oool01039Ri0000000000000000050?ooo`050?o`m@00000000000000
0020LGD0603oool00`1;=3H00000000000030000000304/d=P1UADP000000080000000<0P61S0?oo
o`3oool04`3oool01039Ri00000000000000003o0?oooa`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj@3oool05P3om_X0/FQ<08M==@1c?R<0P4P^08A<<`1n
AR`0T5Dl08=;<P2=DCT0ND8Y07Y3:P1i@bT0Nd@Z089:<01nABd0OTH]07Y4:P1i@bT0Nd@Z0:EK=039
KCX50<U/>P030<a_?@3HND`0bF`i00<0bF`j00H0bVdk0<]_?@3@LT80kXeA0?nfFP3o_5/L0?nkF`07
0?nlG03o_V40okeM0?nmH03o^eT0okaN0?nlG00I0?nkF`070?nmG@3o_Eh0okeM0?nlG@3o^e/0okaN
0?nlF`0D0?nkF`060?nkFP3o_El0okaL0?nmGP3o_5X0okeN4`3o^e/20?nlG0030?nmG@3o_5`0okaL
0080ok]K00@0okaL0?nkF@3o_E`0okaL2`3o^e/0103o_Ed0okeO0?nlF`3o_5`>0?nkF`030?nkFP3o
_El0okaL00<0ok]K00H0okaM0?nkFP3o_El0okeN0?nlG@3o_Ed60?nkF`040?nlG@3o_5`0okaM0?nk
G0P0ok]K00T0okaL0?nnG@3hYU40MDPS00X50`0^4``0QSHS0>ahC`3oSeh02@3oReX00`3oS5`0ohaK
0?n;F`0:0?n;FP80ohaK00<0oh]L0?n;F`3oReX0203oReX00`3oRe`0oheN0?n<G00:0?n;FP030?n=
G@3oRed0oh]J00P0oh]J00<0ohaL0?n;FP3oReX01`3oReX00`3oRUX0ohaL0?n;FP090?n;FP030?n<
G03oReX0oh]J00H0oh]J00<0oh]K0?n<G03oRUX0203oReX00`3oSUl0oh]J0?n;FP020?n;FP050?n4
D`3oNTT0ogQ70?mlC03oQUL02@3oReX00`3oSV00oheN0?n<G0060?n;FP030?n;GP3oSf40oh]J00H0
oh]J00<0ohiO0?nAH`3oRUT01P3oReX0203oRUT0oiEX0?n;G03oPE40ogM60?mkBP3oQ5@0ohaK0P3o
ReX01P3oSUl0ohUJ0?mkB`3oN4L0ogY90?n4D`<0oh]J00<0oh]L0?n<G03oReX01`3oReX00`3oS5`0
oheM0?n;FP030?n;FP80ohaK00h0oh]J0?n9F03oQ5D0ogm>0?mlB`3oN4L0ogY90?mmC03oPE00ohAD
0?n8F03oReX0ohaL0?n<G@P0oh]J00<0oh]K0?n;FP3oReX0203oReX00`3oRUX0oheM0?n;FP060?n;
FP0M0?n;F`38Hd00BahC0000001d:b<0ofaF0?m^E`3oJUH0ofYE0?mVDP3oIU40ofE?0?mQB`3oGTP0
oee60?mMA`3oFdD0oe]60?mLAP3oGDL0of5;0?mSCP3oIE00ofIA0?m[E@3oJU@0of]G0?m/F03oKET0
1P3oK5P01@3oKEP0ofmJ0?m_FP3oKeT0ofeI00H0ofaH00/0og5K0?mZE02a@3@0;0h;00P30`1851@0
bSlo0?mKF@3oEE@0oeaK0?mHEP040?mGE@060?mFE@3oEeD0oeQG0?mJF03oF5H0oeIE2@3oEeD01@3o
EeH0oeME0?mIE`3oFEP0oeQF00D0oeME00<0oeIE0?mHE`3oFEP0103oEeD20?mHEP030?mJF03oF5H0
oeIE00/0oeME00@0oeIE0?mGE@3oEeH0oeYH0P3oF5H00`3oEUD0oeME0?mGE@0<0?mGE@060?mHE`3o
F5H0oeUH0?mGEP3oF5L0oeID3P3oEeD01`3oEUD0oeME0?mGEP3oFEP0oeYH0?mFE03oFEL04P3oEeD0
203oEUD0oeQF0?mHEP3oE5<0oeiL0?mGEP3oFET0oeED403oEeD04P3oF5H0oeYI0?mGE@3oCdh0kDQ6
0:da<01n7Ad0C14A01T51@0O3@L0Cb@C08/m7`2SGS40hH150?nME03oXeP0oj9H0?nQEQH0oj1F00L0
oj5G0?nQF03oXEH0oj9L0?nTG03o[6H0ojiZ00<0ok9_00@0ok9`0?n`K03o[VP0ojiX0`3o[VT0203o
[fT0ojm[0?n`JP3oZ6<0oiaC0?nLE03oVe<0oj5M0P3oVe<01`3oXEd0ojIV0?mk@@0000005Ph50>jQ
C@3ojN@09P3oool3000000030<V;T03oool0oooo00T0oooo00@0bH^@00000000000000001P3oool0
1@1H?Cl000000000000/7b00/Z:T0080i<G800<0f;fo0?ooo`3oool04P3oool00`3onOh0YIBI05Pm
?`0800000003081PH`3oool0oooo01<0oooo00@0bH^@0000000000000000o`3ooolL0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinT0oooo01H0on[]09]G=`2<
DSX0N48X08iB>P28CSD0Nd@Z07m8;@1k@bT0R4he07<o9@1h@RP0ND<Y07U3:01d?b<0ND<X07I19`1i
@bT0N48Z0:UN=`3DMd/0af`j1@39K3X00`3<Kcd0egQ:0<Q/>P040<U/>P050<I[>@3nR4D0okaI0?nn
H03o_5`00P3o^eXM0?nkF`060?nlF@3o^e/0okiS0?nmG03o_f@0okaL6`3o^e/01P3o^eX0okiS0?nm
G@3o_F00okYI0?nkFQD0ok]K00D0ok]J0?nnH`3o^UX0okeM0?nkFP0B0?nkF`050?nkFP3o_F40okeM
0?nlG@3o_5`00`3o^e/00`3o_Eh0ok]J0?nkF`0:0?nkF`050?njF@3o_Eh0okaL0?nmGP3o^eX03P3o
^e/01P3o_5X0okeM0?nmH03o^e/0okeN0?nkF`80ok]J2@3o^e/0103o^eX0okeN0?njFP3o_5`90?nk
F`0:0?njF`3o`el0jgdm048T4@000000=AD>0?m/A`3oTV40ohaL0?n:FPP0oh]J00<0ohiO0?n=GP3o
R5P02P3oReX00`3oREP0ohaK0?n<G00:0?n;FP030?n=GP3oS5`0oh]J00P0oh]J00<0ohYI0?n;FP3o
S5/02@3oReX00`3oSUl0oh]L0?n:FP070?n;FP030?n<F`3oSUl0oh]J0180oh]J00<0ohmP0?n;F`3o
ReX01`3oReX00`3oRUT0oh]L0?n;FP020?n;FP030?n<F`3oREP0oh1@0080ogM600<0oh1A0?n;FP3o
ReX01@3oReX0103oRUT0oiM[0?n<G03oReX20?n:F@@0oh]J00<0oheN0?n?H03oReX01P3oReX00`3o
SV00oi5T0?n:F@070?n;FP0?0?n<F`3oPe80ogM70?moC`3oRUT0ohaK0?n;FP3oS5/0ohYI0?n3DP3o
MdL0ogU80?n0D03oRUT0ohaK00@0oh]J00<0oheM0?n;FP3oReX01@3oReX00`3oRUT0oheN0?n;FP02
0?n;FP80ohaK00l0ohMF0?n0D03oO4/0ogI60?md@`3oNDP0ogi>0?n1D@3oREP0ohUK0?n<F`3oReX0
ohYJ0?n>GP3oRe`0203oReX00`3oRU/0oheN0?n9F@070?n;FP030?n9F@3oRe`0ohiO00D0oh]J0P3o
S5/02@3oSUd0aV4o000000000000IQlH0?mTCP3oHDX0oei90?mJA@020?mH@P0:0?mG@@3oFT80oei7
0?mRB`3oHdd0of=>0?mXDP3oJUD0ofaH0?m^FP80ofeI00@0ofaH0?m^F@3oL5/0ofeH2@3oK5P00`3o
KUT0og1K0?m/E`060?m/F0090?m]F@3oKeT0mT/l05@H4P000000BA8B0?<n?P3oGUd0oeQF00L0oeME
00D0oeIE0?mKF@3oEE<0oe]I0?mFE@0;0?mGE@030?mJF03oFeT0oeEC00T0oeME00H0oeMF0?mIF03o
EeD0oeEC0?mJF@3oFEL>0?mGE@050?mHEP3oFeX0oeID0?mLFP3oEE@03P3oEeD01P3oEE@0oeQF0?mF
E03oFeX0oeQF0?mFE@l0oeME00L0oeIE0?mED`3oGEd0oeID0?mJF03oEU@0oeED0140oeME00P0oeIE
0?mEE03oF5H0oe]J0?mHE`3oFEP0oeME0?mEE100oeME00L0oeMF0?mJF@3oGUd0oeAB0>0f=@237ah0
:PL70080000000L07@/406X]5P32Ebh0ohE50?n/GP3oZUd0oj=I01L0oj1F00H0oj1E0?nQF03oYEl0
oj9I0?nRF03oXU/30?nPE@030?nQE`3oZV<0ojiY00T0ojiY00D0ok1^0?n^J`3o[VP0ojmY0?nQF`02
0?nLE00:0?nME@3oVe<0oiYB0?nSH@3oYfL0oiE?03LG2P000000fY8n0?oOccD0oooo00@0bH^@0000
0000000000001P3oool00`3ohNX06A4B000000040000000306E6B03oool0oooo01D0oooo00T0i;o6
07iGFP1;=3H0000000d92@1UADP0UfQ/0<V;T03ol?D05@3oool01039Ri00000000000000003o0?oo
oa`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj@3oool0
2`3oi^T0U58_08aB>`1h@BL0S58i08E;<@1kABX0O4D[07<n9022BC00LclU00<0ND<Y00T0MD0T07a5
;01i@bT0N48Y08e=;@30J3P0e7M;0<AZ>@37JcT01039K3X00`3<Kcd0fGU<0<U/>@030<U/>P090<Q/
>P3PN3d0ok9G0?nnF`3o_F00okaL0?njE`3o_fD0okeM0080ok]J703o^e/01P3o^eX0okaJ0?nnHP3o
^e/0ok]J0?noHP80ok]J603o^e/01`3o^eX0okaN0?nlG@3o_E`0okiR0?nkF`3o^eX0503o^e/01P3o
^eX0ok]L0?nlG03o_V40okaM0?nkFQ40ok]K0P3o^eX00`3o_5h0okeN0?nmGP020?nkFP030?nlGP3o
^e/0ok]J00`0ok]K00<0okYI0?nlG03o_V800P3o^eX:0?nkF`80ok]J00H0okiQ0?njF@3o_5h0ok]J
0?nmGP3o^eX=0?nkF`030?nkFP3o_Eh0okaM00T0ok]K00T0okaL0?o5G`3oWdl0UE0W0000000S3PP0
[dH^0?n7F03oSU`02@3oReX00`3oSUl0ohaL0?n;FP0;0?n;FP030?n<GP3oRUT0oh]J00T0oh]J00<0
ohaM0?n:F@3oReX0203oReX00`3oRUT0oh]J0?n;FP090?n;FP030?n;GP3oRe/0oh]J00L0oh]J00<0
oheN0?n>G`3oReX01`3oReX00`3oRUT0oheM0?n:F@080?n;FP030?n<G03oRU/0oh]J00H0oh]J00<0
ohYK0?n=GP3oReX00`3oReX0203oS5/0oh]J0?n4D`3oMTH0og=40?mmCP3oREP0ohaK1@3oReX01P3o
TF<0oh]K0?n;FP3oRe/0ohaK0?n:F`<0oh]J00<0oh]N0?n>H03oReX01P3oReX00`3oS5d0ohiO0?n;
FP070?n;FP0<0?n0D03oN4L0ogY90?n:F@3oS5/0oh]J0?n<F`3oR5L0oge>0?mbA03oNDP0ohIF0P3o
S5/30?n;FP030?n:F@3oS5`0ohYI00L0oh]J00P0ohaL0?n:F03oReX0oheL0?n:F@3oQ5<0ogi>0?mj
BP80ogI500H0ogM60?n0D03oQeH0ohYI0?n=G03oS5/30?n;FP030?n<F`3oSUl0oh]J00P0oh]J00<0
ohUH0?n:FP3oReX01`3oReX0103oS5l0ohiO0?n:F@3oRUX30?n<F`090?n;FP3oR5L0ohED0?n3DP13
6a40000006DM5@3oF4<0oe]40080oeQ200T0oeU30?mOBP3oHD`0ofA>0?m/E`3oJU@0of]G0?m^F@3o
KUX00P3oKET30?m/F0030?m]E`3oKUT0og9N00T0ofaH00@0ofeG0?maG03oKUT0ofeI1`3oK5P0203o
L5X0ofUA04PC3P000000EADE0?m<C03oG5/0oeIE203oEeD0103oF5H0oe]I0?mEE03oEE@90?mGE@05
0?mEE03oF5H0oe]I0?mHE`3oEE@02`3oEeD01@3oF5H0oe]I0?mKF@3oF5L0oeED00`0oeME00H0oeED
0?mHEP3oFUP0oe]I0?mGE@3oEE@=0?mGE@060?mDD`3oF5L0oeaJ0?mGEP3oEeD0oeED3`3oEeD01`3o
EE@0oeID0?mKF@3oEE@0oeeK0?mEE03oEUD04P3oEeD01P3oEE@0oeUG0?mIF03oEeD0oeYI0?mFEA40
oeME00L0oeQF0?mJF@3oFeX0oc`k0:TY:01S5QH03`<30080000000H080`40:=89@3oNd80oiE>0?n/
GP3oYe/I0?nPEP050?nPE@3oXed0oj1E0?nTGP3oX5L00P3oX5D30?nPEP030?nPE03oY5/0ojeV00P0
ojiY0180ok1]0?n_JP3o[FP0ojiY0?n^JP3oYf80oieC0?nLE03oWeP0oiaE0?nKD`3oWUP0oj=R0?nJ
DP3:EbP000000<f;=`3ohLM00?ooo`030>:LXP000000000000<0000000<0IDI80?ooo`3oool0o`3o
oomC0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinT0oooo
01P0onOZ091?;025C3@0O4D[08mD?01lA2/0MClU07U3:@1f@2H0S50h07m7;@1h@RP0ND<Y07M19`21
B2h0N48X07U3:@1lAB/0]F8g0<=[>03@M4L0`VXj0<Y_?P39K3T30<U/>P030<a_?@3IND`0bF`i00<0
bF`j00<0bfhk0?n/E`3o_U/00`3o^e/01P3o^eX0okeP0?nlG03o`6D0okiR0?njF1d0ok]K00L0ok]J
0?nkF`3o^e/0okaN0?nlG@3o_V<0okaL01T0ok]K00D0ok]J0?nlG@3o_5h0okaN0?nmH@020?nkFQD0
ok]K00@0okeN0?nkF`3o_F40okaL4`3o^e/20?nlG0060?nmGP3o_640okaK0?nlG03o_Eh0ok]L303o
^e/01@3o^eX0okeN0?nkFP3o_f80okaJ00P0ok]K00T0ok]H0?o0IP3o^eX0okeN0?nkFP3o^e/0ok]J
0?nlG03o_F003P3o^e/0103o_5`0okaM0?nmH03o^eX90?nkF`030?o3GP3o^EX0U50W0080000000<0
EB8F0?n0E03oReX02P3oReX00`3oSEh0ohYI0?n;FP090?n;FP80oh]L00<0ohYI0?n;FP3oReX01`3o
ReX00`3oS5/0oh]J0?n9F0090?n;FP030?n:F@3oREP0oh]J00P0oh]J00<0ohYI0?n<G03oReX01`3o
ReX20?n:F@030?n9F03oReX0oh]J00H0oh]J00<0ohaK0?n9F03oReX01`3oReX00`3oSEh0oh]J0?n;
FP0>0?n;FP060?n<F`3oPU80ogM60?mgAP3oNdX0ohUH1@3oReX00`3oR5L0ohYI0?n;FP020?n;FP06
0?n<F`3oRe/0oh]J0?n;FP3oReh0ohmQ1`3oReX20?n:F@H0oh]J00H0ohaK0?n5E03oNDP0ogQ70?n2
D@3oS5/20?n;FP060?n7EP3oNTT0ogA50?ma@`3oQE@0ohaK1@3oReX00`3oRUT0ohmP0?n9F@070?n;
FP0=0?n@HP3oRe`0ohYI0?n0D03oNdX0ogU80?mcA@3oMdH0oge=0?n3D`3oSEl0oh]J0?n<F`0@0?n;
FP030?n:F@3oReX0oh]J00L0oh]J01H0ohaK0?n<G03oReX0ohaK0?n:F@3oQUD0oh=B0?mnCP3oO4/0
ogY90?mlBP1j;Q/0000006DM5@3oEd40of190?mRB`3oHdh0ofMB0?mXD`3oJeH0of]E0P3oLE`00`3o
KET0ofaH0?m/F0060?m/F0030?m[E@3oKeX0ofeI00P0ofaH00@0ofaG0?mbGP3oKeX0ofaG1P3oK5P0
203oK5L0og=L0>YEA01L5a400`0000T20P3fB4L0oeYI203oEeD0103oEU@0oe]I0?mGEP3oEE@:0?mG
E@040?mEE03oGE/0oeMF0?mHE``0oeME00D0oeID0?mMF`3oF5H0oeeK0?mFE00;0?mGE@060?mFE@3o
F5H0oeeK0?mHE`3oF5H0oeED3P3oEeD0103oEeH0oeiM0?mHEP3oF5LB0?mGE@050?mLFP3oFeT0oeQF
0?mHEP3oEE@04@3oEeD0203oEUD0oeID0?mKF@3oGE/0oeMF0?mHE`3oEeD0oeED403oEeD01P3oF5H0
oeaJ0?mFE03`=cH0KaXJ02871P80000000L030D208@i703dKSX0ohI80?nOE@3oZE`0ojAI01L0oj1F
00H0oj1E0?nQE@3oYUl0oimD0?nPE@3oXUX20?nPE@L0oj1F00<0oimF0?nXHP3o[VT01`3o[VT00`3o
[fX0ojiX0?n^J@020?n^J@0=0?n/I`3oY5h0oiaD0?nOFP3oW5D0oi]C0?nKD@3oVU80oieC0?m_=000
0000_8<b0?oT`P110?ooo`060?oQjP1aCU4000000000000b8b@0i;o6o`3ooomE0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinT0oooo01T0onCW08138`2=DSX0
Qd`d07E09@1h@BL0OdH^07M2:01e?bD0QD/b08A:<P1h@RP0ND<Y07]4:P2=DST0N44W07M2:@2KES40
`fTh0<5Y>02oIcH0`FTh0<=Z>P39KSh0bfhl0080bF`j00<0bVdk0<e`@039K3X00P39K3X00`37JcX0
lIM>0?nmG0070?nkF`80okaL00L0ok]I0?nnH@3o^eX0okeO0?nnH@3o^eX0okaL01/0ok]K00P0ok]L
0?nlG03o^eX0okeO0?nkFP3o_El0okaN0?nlFaL0ok]K00P0okaL0?nkF`3o_5`0okiQ0?nmGP3o_5d0
ok]K0?nlG1<0ok]K0P3o_5`00`3o_El0ok]K0?nlG`0B0?nkF`040?nlG03o^e/0okaN0?nmGP80okaK
00<0okaM0?nkF`3o^e/0303o^e/0303o_5`0okeM0?nmG@3o_5d0ok]K0?nlG03o^e/0okeP0?nlG03o
_Eh0okaJ0?nlG0H0ok]K00@0okaL0?nkFP3o_5l0okaM3@3o^e/00`3o_5`0okaN0?nmGP090?nkF`0:
0?nmG03o^EX0`84o078l7P0D2`D0=aL?0:mG>@3oOe<0oh]J0?n;F`H0oh]J00D0ohYJ0?n<G03oSE`0
ohaL0?n;F`090?n;FP040?n<F`3oReX0ohaL0?n;F`P0oh]J0P3oRe/00`3oRUT0oh]J0?n;FP070?n;
FP030?n<F`3oReX0oh]J00P0oh]J0P3oS5`90?n;FP030?n<GP3oS5/0oh]J00H0oh]J00<0oh]K0?n=
G@3oRUX0203oReX00`3oSEh0oh]J0?n;FP060?n;FP030?n=G@3oRUT0oh]J00D0oh]J00P0ohaK0?n;
G03oPU80ogU80?mkBP3oPe<0ohUH0?n:FP<0oh]J00X0oh]L0?n;FP3oReX0oh]J0?n:F@3oS5`0oh]K
0?n;FP3oRe`0oheM1`3oReX20?n:F@D0oh]J00h0ohaK0?n5E03oLT<0ogM80?n2D@3oReX0ohYJ0?n9
F03oPE00ogY90?mjBP3oP4l0ohMH0?n<F`D0oh]J00<0ohYJ0?n;G03oS5`01P3oReX03@3oREP0ohAC
0?mnCP3oNTX0ogU80?mjB@3oO4`0oh1?0?n4D`3oR5P0ohYJ0?n=GP3oRe/01`3oReX00`3oRUT0ohaL
0?n:FP070?n;FP80oheM00<0ohaK0?n;FP3oReX00P3oReX0203oR5L0ohMF0?n4D`3oPe<0ogm>0?mn
C@3oO4/0ogY90`3oNDP02@3oNTX0ogm>0=UP>`1I8A@0000007X]903oJUD0ofeG0?m[E`020?m/F080
ofeI00@0ofiI0?maG03oKUT0ofeH1`3oK5P00`3oKET0ofmI0?m/E`080?m/F0040?m]F03oKeX0ofiJ
0?m]F@<0ofaH00`0ofeI0?m]F03oKET0og1K0?mVD`2UAc/0HQdG01X71P1k7ah0a3dk0?mAD03oF5H8
0?mGE@030?mIF03oF5H0oeIE00T0oeME00<0oeIE0?mHEP3oF5H00P3oF5H:0?mGE@060?mHEP3oEeD0
oeUG0?mFE03oFEL0oeQF0P3oEUD00`3oF5H0oeME0?mGE@060?mGE@040?mHEP3oEeD0oe]J0?mIE`80
oeQF3@3oEeD01P3oF5H0oeUG0?mJF03oE5<0oeUH0?mHEPh0oeME00P0oeQF0?mGE@3oF5H0oeYH0?mI
E`3oF5H0oeME0?mHEQ00oeME00@0oeQF0?mFE@3oF5H0oeYJ0P3oF5L00`3oEeD0oeQF0?mGE@0=0?mG
E@0C0?mGEP3oF5H0oeME0?mDDP3gAdH0_STh08HU9@1641006PH601040P0_5@X0P3`O09AD;035KCT0
oI5>0?nNE@3oXeL0ojAI0?nRE`0C0?nPEP80oj1G00D0oj5F0?nSFP3oXUP0oj9H0?nSG@020?nQE`h0
oj1F00<0oj]T0?n^J@3o[VT0103o[VT00`3o[VX0ojiY0?n^J@040?n^J@0<0?n]I`3oXUd0oieE0?nM
EP3oWeP0oi]D0?nLD`3oU4h0IB`E00000030RS<0onC4o`3ooonL0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinT0oooo0180onGV07m38@29D3L0PTT`07Do9@1k
A2X0TEDm07Q19`1f@2H0ODD/08A:<01h@RP0ND<Y07m7;P1kABX0MT0X0857;@2mIcP30<5Y>0050;mW
=P31JCP0`6Lf0<AZ>@38K3X00P39K3X01P36JSP0bF`j0<U/>P31J3P0k7i00?nhF@l0ok]K00L0okaK
0?o0J03o_5`0ok]K0?nlG@3o^e/0ok]J01`0ok]K00L0ok]J0?noH@3o_5`0ok]J0?nlGP3o^e/0ok]J
01L0ok]K00<0ok]J0?nnH03o_V<00P3o_5`00`3o^e/0ok]J0?nkF`0C0?nkF`030?nmG`3o_5`0ok]L
01<0ok]K00<0ok]J0?nnGP3o_Eh00P3o^eX>0?nkF`050?nlG03o^eX0okeP0?nnHP3o^UT03P3o^e/0
0`3o_5/0okiN0?nmG@0=0?nkF`030?nkFP3o_V<0okaL00T0ok]K00T0okaK0?o1GP3oZE<0@B8A0000
000J2PH0de@f0?n=G03oS5/0203oReX00`3oREP0oheN0?n;F`0:0?n;FP030?n9F03oRe/0oh]J00T0
oh]J00<0ohYK0?n;FP3oReX0203oReX00`3oRU/0ohiQ0?n;FP070?n;FP030?n:FP3oSUl0oheN00T0
oh]J00<0ohYI0?n9F@3oReX01P3oReX00`3oS5/0oh]K0?n;F`070?n;FP030?n:F@3oSEd0oh]J00l0
oh]J00P0ohaK0?n;FP3oRUT0oga<0?mgAP3oNDP0ohAC0?n<F`80oh]J00<0oi=X0?n;FP3oReX00`3o
ReX0103oSUl0ohaL0?n:F@3oRUT70?n;FP80ohYI103oReX01@3oS5/0ohIE0?mhA`3oMDP0ohEF0080
oh]J00@0ogmA0?mhA`3oMdH0ogi=2P3oReX03P3oRe`0ohaL0?n:F`3oS5/0oh]J0?n8E`3oP500ogY9
0?meA@3oN4L0ogY90?mlC03oPE40ohUH103oReX20?n:F@P0oh]J00<0oheN0?n<F`3oReX00`3oReX3
0?n<F`080?n:F@3oR5L0ohUH0?n8E`3oPe<0ogm?0?mjB@3oN4L40?mgAP0=0?miB03oNdX0oge=0?n0
D03oQE@0ohYI0?n;FP3oS5`0fF]600P20@000000N2HN0?m/E`060?m/F0030?m/E`3oL5/0ofaG00L0
ofaH00@0ofeG0?m/F03oLUd0ofeH203oK5P04P3oK5L0og5L0?m`F`3oK5P0ofaG0?m/F03oKeX0ofeG
0?mgHP3oL5/0ofmI0=e@@0040@40000000l30`36>CP0oeUH0?mFE@P0oeME00<0oeQF0?mIE`3oEeD0
2P3oEeD30?mHEP`0oeME00@0oeQF0?mJF03oFEP0oeEC1P3oEeD00`3oF5H0oeME0?mGE@030?mGE@04
0?mEE03oF5H0oeiM0?mEE140oeME00<0oeaJ0?mGE@3oEeD03P3oEeD01@3oEE@0oeME0?mHE`3oFEL0
oeaJ01<0oeME00H0oeED0?mHEP3oF5L0oe]J0?mIE`3oEE@@0?mGE@070?mFE@3oFEP0oeQF0?m?C`3o
BDT0_2/Y01H20P020000000800l60`117@l0[4`V0?mg?@3oX5L0oj9G0?nPEP3oXEHF0?nPEP050?nR
FP3oXUT0oj5H0?nTG`3oX5D0503oX5H00`3oXe/0ojiX0?n^J@030?n^J@030?n`KP3o[fX0ojiY00H0
ojiY00/0ojeW0?nOE`3oVe@0oiiG0?nKE03oX5`0oiE=08Tl70000000[74S0?oZeP3o0?oooi`0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj@3oool04P3oh^D0
MchL08Q==@22B300MClU07Q2:02?E3/0Nd@[0858;`1e?bD0MT0V07U3:@1oAbd0QD/b07<o9@1f@2P0
VeD^0<=Y>080`FTh00H0`FPi0<5Y>031JCP0`FTh0;iW=P35JSP20<U/>P060<IZ>039K3X0`6Lh0=Mc
?@3o/5P0okaL403o^e/20?nkFP050?nmGP3o_V40ok]J0?nmH@3o_Ed07@3o^e/01@3o^eX0okaL0?o1
IP3o^e/0okeP0080ok]J5`3o^e/01@3o^eX0okeO0?nmGP3o_5`0okeP01D0ok]K00@0ok]J0?nmHP3o
_Ed0okaL0P3o^eXA0?nkF`040?nlG03o_5/0okaI0?nlG0X0ok]K00X0ok]J0?nkF`3o_Ed0okeM0?nn
H`3o^e/0okaM0?nkFP3o_Eh0ok]J3@3o^e/01@3o_5T0okeQ0?nlG03o_5`0ok]J00/0ok]K00@0ok]J
0?nlG03o_Ed0okeL2@3o^e/00`3o_e`0i9Q902`G3002000000030;]B=P3oT5h0oheL00P0oh]J00<0
ohYI0?n=G@3oRUT02P3oReX20?n<G0030?n:F@3oReX0oh]J00L0oh]J00<0ohaK0?n:F@3oReX02@3o
ReX00`3oSEd0ohYI0?n;FP060?n;FP030?n:F@3oRe`0ohaL00P0oh]J00<0oheO0?n<G03oReX01P3o
ReX00`3oRET0oheN0?n;FP080?n;FP030?n=G@3oReX0oh]J00D0oh]J00<0oh]L0?n@HP3oRUT01`3o
ReX0103oRUT0oh]J0?n9F03oNdX20?mgAP040?n4D`3oS5/0oh]J0?nDJ0D0oh]J00@0ohYI0?n>G`3o
RU/0ohYI1`3oReX20?n:F@<0oh]J00h0ohQJ0?n8E`3oNdX0ogQ70?n<GP3oRe`0oh]J0?n1D@3oMTD0
ogQ70?mlB`3oRUT0ohYK0?nCJ0L0oh]J00`0ohQJ0?n<F`3oS5/0ohUH0?n6E@3oP500ogU80?mfA@3o
MdH0ogY90?mkC03oQeH20?n<F`D0oh]J00<0oi1R0?n;FP3oReX01P3oReX00`3oRe/0ohiO0?n;FP03
0?n<F`070?n;FP3oR5L0ohMF0?n5E03oOe00oga;0?mjB@030?mfA@080?mgAP3oN4L0ogY90?mmC@3o
PE40ogmA0?n8E`3oReX30?n<F`080?n9FP3oSEd0ohaL05XT60000000NbLO0?m/E`3oKEP50?m/F003
0?m]E`3oKUT0ofmJ00L0ofaH00<0ofeI0?m]F03oL5/02@3oK5P02@3oKUT0ofmJ0?m]F@3oKEL0ofeI
0?mbG@3oJeD0og9N0?m_FP020?m`FP070?mHAP0_3P`0000003T>3@3W>3L0oeYH0?mFE@060?mGE@04
0?mFE@3oFEP0oeQF0?mIE`T0oeME00D0oeED0?mGE@3oF5L0oeMF0?mEE00:0?mGE@050?mFE@3oEeD0
oeUH0?mHEP3oF5L01`3oEeD00`3oEU@0oeME0?mHEP020?mGE@050?mEE03oF5H0oeME0?mLFP3oEE@0
3@3oEeD01P3oEE@0oeMF0?mHEP3oEeD0oe]J0?mFE0l0oeME00D0oeED0?mLFP3oEE@0oeeK0?mHEP0A
0?mGE@80oeED00D0oeUG0?mFE03oFUP0oeeK0?mFE@0@0?mGE@070?mJF03oG5/0oe]I0?m:B@3G<c80
LQTH00H00@020000000702`B201G9a@0eV8c0?nRE`3oYe/0oj=I0?nQEP0D0?nPEP090?nPE@3oX5H0
oj1E0?nRFP3oX5D0ojIP0?nTG@3oWe@0oj1E01H0oj1F00H0ojUQ0?n]J03o[VT0ojmZ0?n`KP3o[fX8
0?n^J@0<0?n]J@3oY5h0oj1K0?nNE`3oVU<0oj=P0?nLE@3=FR`0000008M=5P3oeY<0ooOjo`3ooonK
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinT0oooo0180
on3S07U07P27C3@0R4lf07U3:P1lAB/0SU<j07m7;P2>DSX0M3lU07Q2:01kA2X0O4D/0817;`1e@2P0
SE0_0<5Y>P32JCP20<5Y>0030<AZ>P39KT00`FTh0080`FTh00P0aF/j0<U/>P39K3X0aVXh0<I[>P3=
Kcd0ojMG0?nnGAD0ok]K00D0ok]J0?o0IP3o_Ed0okeO0?nlG0020?nkFQ/0ok]K00L0ok]J0?nmG03o
_f@0okYH0?nmH@3o_5h0ok]J01L0ok]K00D0ok]H0?nmH03o_f80okeO0?nkF`020?nkFQ80ok]K00D0
ok]J0?nkF`3o_El0ok]L0?nmH00B0?nkF`050?nkFP3o^e/0ok]K0?nlG@3o^eX01`3o^e/0303o_5d0
okiR0?nkF03o_F00okYI0?nkFP3o^e/0okaJ0?nkFP3o_640ok]K0?nlG0d0ok]K0P3o^eX00`3o_5d0
okaN0?nkFP0=0?nkF`80okaM00<0ok]J0?nkF`3o^e/01P3o^e/0203o`El0oiM;07Y17`00000050L5
0<mA=@3oRET0oi1N203oReX00`3oRUX0ohYI0?n<G00:0?n;FP030?n?H03oS5`0oh]J00P0oh]J00<0
ohaK0?n;FP3oRUT02@3oReX00`3oS5d0ohYK0?n9F@070?n;FP030?n9F03oSEh0oh]J00L0oh]J00<0
ohaK0?n=GP3oREP01`3oReX00`3oREP0ohaL0?n;F`070?n;FP030?n<G03oReX0oh]J00H0oh]J00<0
ohQG0?n;FP3oReX01@3oReX02`3oRUT0oi5T0?n=GP3oS5/0ohQG0?mnCP3oN4L0ogQ80?n5E03oS5/0
oh]L00L0oh]J00<0ohiO0?n9F03oReX01P3oReX20?n:F@80oh]J00P0ohaK0?n7EP3oNdX0ogI50?n0
D03oReP0ohYI0?n1D@80ogQ700D0oh1@0?n:F@3oS5/0oh]K0?n>G`050?n;FP80ohaK00X0oheN0?n;
GP3oPU80oga;0?mgAP3oMTD0ogQ70?mmC@3oPE40ohQG0P3oS5/60?n;FP030?n<G03oR5P0oh]J00D0
oh]J00<0ohaK0?n=G03oSEh00P3oREP0503oQUD0ohAC0?n3DP3oOTh0og]:0?mgAP3oLd@0ogA40?mf
A@3oN4L0ogY90?mmC@3oOdl0oh5A0?n3DP3oQUD0oheP0?n?H03oRUX0ohYK0`3oReX0203oRUX0oheL
0?n<G02^ARh00P00070T7@3oK5L0ofiI1@3oK5P00`3oKEL0ofeH0?m]F@080?m/F0030?m]F@3oKeX0
ofaH00P0ofaH0140ofeG0?m`F`3oK5D0ofaH0?mbGP3oKET0ogIQ0?m[E@3oKEL0og5K0?mXD`33?S80
6`P600<10P228B00odY:0?mMG0070?mGE@030?mEE03oF5H0oe]I00X0oeME00@0oeIE0?mIF03oEeD0
oe]I303oEeD01@3oF5L0oeME0?mMF`3oEE<0oeIE00P0oeME00<0oeID0?mGE@3oF5H00P3oF5H00`3o
FEL0oe]I0?mFE00=0?mGE@040?mEE03oFeT0oeYH0?mIF080oeED3@3oEeD01`3oEE@0oeID0?mHE`3o
EeH0of1O0?mCDP3oEE@0403oEeD0203oEUD0oeME0?mIF03oF5L0oeYH0?mHE`3oEU@0oeED3`3oEeD0
1P3oFUP0oeaK0?m<C03l>c/0aBl_04@?3`<0000000H0DB<A0<EF;P3oO400oj1E0?nXG03oXELE0?nP
EP060?nPE@3oX5H0ojAN0?nPEP3oWU80oj=M0P3oX5D00`3oWeD0oj1F0?nPEP0F0?nPEP040?nSF`3o
ZfH0ojiZ0?n_J`X0ojiY00`0ojeX0?nXI03oWUT0oi]C0?nLE@3oXf00ojMW0==M;@000000Md<F0?o:
K`3ol^Wo0?oooi/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWj@3oool0103oh^00MC`K07E09P2<DCP20899<00;07Q29`1oAbh0S54i07U2:01jA2X0O4DZ07U3
:@22BC00Rd`]0;QT=P34JST00`31JCP00`34JcX0bFm10<5Y>0020<5Y>0080<9Z>@37K3`0bVdl0<M[
>@3ALC`0ojYF0?nnG03o_5/H0?nkF`050?nlGP3o_5`0okYH0?nnH`3o_5d00P3o_El00`3o^eX0ok]K
0?nkF`0I0?nkF`060?nmGP3o_5`0okiR0?nnGP3o_5X0okeN5P3o^e/01@3o_5X0okeM0?nkF`3o_El0
okaO0080okaM4`3o^e/01P3o_5`0okaM0?nlF`3o_Ed0okeN0?nlG100ok]K00d0ok]J0?nlG`3o_Eh0
okeM0?nmGP3o_5`0okeN0?nlG@3o^eX0okeO0?nlF`3o_El0ok]J00H0ok]K00H0ok]J0?nlG03o_5d0
okaL0?nlGP3o^e`=0?nkF`040?nlG@3o_5`0okeM0?nmG0`0ok]K00<0okaN0?nmG@3o_5d0203o^e/0
2@3o`5d0okiL0>RKB`1X>ad0000003LF3`2JA2d0mH1C0?n;F`080?n;FP030?n<G@3oSEh0oh]J00T0
oh]J00<0ohaL0?n;FP3oRU/0203oReX0103oS5/0ohYI0?n;FP3oS5/80?n;FP030?n=G@3oSUh0oh]K
00L0oh]J00<0oh]K0?n<G@3oReX0203oReX00`3oSEd0ohaL0?n;FP060?n;FP030?n:G03oS5`0oh]J
00H0oh]J00<0ohaL0?n<G@3oReX01P3oReX00`3oSV00oheN0?n:F@060?n;FP0;0?n>GP3oREX0oh]J
0?n<F`3oRe/0ohMF0?mlC03oMdL0oga;0?n2D@3oRUT01`3oReX00`3oS5X0ohYI0?n;FP050?n;FP05
0?n:F@3oReX0oh]J0?n;FP3oQUH00P3oN4L03@3oOTh0ohYH0?n0C`3oNTX0ogM60?mnCP3oRET0oh]J
0?n<F`3oReX0ohaL0?n:F@3oReX00P3oS5/03`3oRUT0ohQG0?n4D`3oOTh0og]:0?miB@3oNDP0oga<
0?n1D03oQ5@0ohUH0?n;FP3oS5/0ohaL0?n;F`070?n;FP030?n<G03oS5/0ohaK0080ohYI01@0ohMF
0?n6EP3oQE@0oh9A0?mnCP3oODd0og]:0?mjB@3oN4P0ogU80?mjB@3oNd/0ogi=0?n2D03oPU40ohEE
0?n8E`3oREP0ohYI0?n;FP<0ohaK00<0ohaL0?n;F`3oReX01@3oReX01`3oSE`0e6Q405LR5`020@40
KRPP0?m/EP3oKUT01@3oK5P00`3oKUT0ofmJ0?m]F@080?m/F0030?m`F`3oKUT0ofeH00H0ofaH0140
ofeH0?m^F@3oKUX0og9M0?m_FP3oLE`0of]E0?m`F`3oKET0ofeH0?m^FP3oK5P0]4<e038@3@000000
C1<C0<Xk>`020?mHE`H0oeME00D0oeQF0?mIF03oF5H0oeMF0?mFE@090?mGE@80oeUG00<0oeQG0?mH
EP3oEUD02@3oEeD0103oF5H0oeMF0?mIE`3oF5L20?mFE@X0oeME00L0oeQF0?mGE@3oEUD0oeQF0?mG
EP3oEeD0oeIE00X0oeME00L0oeIE0?mGEP3oF5H0oeQG0?mIEP3oF5L0oeMF00d0oeME00P0oeIE0?mH
EP3oF5H0oeaJ0?mIF03oEeD0oeQF0?mFE@l0oeME00D0oeID0?mIE`3oEeH0oeYI0?mEE0020?mHE`h0
oeME0180oeMF0?mIE`3oEUH0kTQ60<E1?`2U;bh0K1XJ02l:2P0500405`T406D^602LCRP0a6dj0>b6
B@3oVU80ojMK0?nTF@3oXELD0?nPEP070?nSFP3oWeD0oj1E0?nUG`3oXEL0oj=K0?nQE`0M0?nPEP04
0?nPE@3oXUT0ojUS0?naK`80ok5^00<0ok5_0?n`K@3o[FP01@3o[VP0303o/6l0ok5a0?nPF03oVe80
oieG0?nPF`3oXUl0og<g0000001M=A<0okQB0?oYfol0ooooV`3oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOX0?ooo`0A0?ono`3oYHl0KcPH07<n9028CCH0TEDl
08M==01f@BH0OdL]09EH@@2=DCT0O4@Z07]4:P1i@bT0PTT^0<1X>P33JCP01031JCP00`33JST0afdm
0<5Y>0040<5Y>0040<=Z>@31JCX0l9Q>0?noG1d0ok]K00H0ok]J0?nkF`3o_5h0okaN0?njE`3o_f@2
0?nkF`030?nkFP3o^e/0ok]K01L0ok]K00L0ok]J0?nkF`3o^eX0okaM0?nlG03o`6<0okeM01L0ok]K
00D0ok]J0?nlG@3o^UT0okiR0?noH`0E0?nkF`040?nmG@3o^e/0okeN0?nlGPl0ok]K00P0okaK0?nm
H03o^eX0okaL0?nnH@3o_V<0ok]L0?nkFPd0ok]K00@0ok]J0?nmG@3o^UX0okeO3`3o^e/00`3o_5h0
okaM0?njF@0;0?nkF`040?nkFP3o_Ed0okeP0?nlG0P0ok]K0P3o_E`01P3DL3D05``60000000n6100
ogQ?0?n=G0P0oh]J00<0ohYK0?n;FP3oReX02P3oReX20?n<F`T0oh]J00<0ohYI0?n<F`3oReX02@3o
ReX00`3oS5`0oh]K0?n;FP060?n;FP030?n;F`3oS5/0oh]J00P0oh]J00<0ohYI0?n;FP3oReX01P3o
ReX00`3oS5`0oh]J0?n;FP070?n;FP030?n:F@3oReX0oh]J00@0oh]J00<0ohQH0?n=GP3oRe`01P3o
ReX00`3oRUT0ohmQ0?n<F`040?n;FP050?n3DP3oN4L0ogA50?mjB`3oS5/01P3oReX0103oREP0ohaL
0?n;FP3oRUT40?n;FP0<0?n:F@3oReX0oh]J0?n:F@3oNTX0ogU80?n6E@3oRUT0ogQ:0?meA@3oNTT0
ohED1@3oReX0303oTfP0oh]J0?n<F`3oQeH0ogi>0?mjB@3oNDP0ogM60?mfA`3oNTd0oh=C0?n:F@80
ohaK0P3oReX00`3oRUT0ohiO0?n>G`040?n;FP0H0?n:FP3oS5/0oh]J0?n:FP3oQED0ogm?0?mlC03o
NdX0ogY90?mhA`3oMdH0og=50?mfA@3oNTP0oga<0?n0D03oQE@0ohQG0?n9F03oRUT0oh]J0?n<GP3o
Sf00ohYJ1`3oReX00`3oREP0ohaK0?n;FP060?n;FP060=9W@`060`40000005lN603oJeH0ofeH1@3o
K5P00`3oKUT0ofeH0?m/F0070?m/F0030?m]E`3oLE`0ofeI00P0ofaH00H0ofiI0?m]E`3oK5L0og1K
0?m]E`3oK5L30?m/F0080?maFP3oFdT0Fa/F0040000[2`/0hcPg0?mEE03oFEL70?mGE@030?mJF03o
FEP0oeQF00X0oeME00<0oeED0?mNG@3oEeD0303oEeD00`3oFEL0oeQF0?mHEP0<0?mGE@070?mEE03o
FEP0oeQF0?mHEP3oEeD0oeIE0?mIE`0<0?mGE@040?mNG@3oF5H0oeQG0?mEE0h0oeME00H0oeIE0?mI
E`3oGUd0oeID0?mHEP3oEE@A0?mGE@060?mEE03oGE/0oeID0?mGEP3oF5L0oeED3`3oEeD01P3oF5L0
oeUH0?m<B`3R=380FADD01020P80000000L08@h60;1=9P3oM3d0oha;0?nSF03oYe/0oj=I01D0oj1F
00P0oj1E0?nSF`3oYf40oj1F0?nRFP3oX5D0oj1F0?nPEAd0oj1F00H0oimE0?nPE@3oXe/0ojAN0?nN
D@3oXeX40?n`KP040?n`K03o[VP0ojiX0?n^J0<0ojiY00`0ojiX0?n]I`3oZfL0oj1J0?nJD`3oWEH0
oiUB0?mj>`0J30D0EC8B0?nnB`3ok=Oo0?oooi/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWj03oool0103ooOl0oij1070i6@1e@2D20858;`0:08=:<@1h@RP0
OdL]09MI@@2@E3`0OTH/07Q2:01i@bT0Te0_0<AZ>0H0`FTh00<0`FPg0<5Y>031JCP00`31JCP00`2n
IcP0e7<n0?ndF@0S0?nkF`050?nmG@3o^UT0okeQ0?o1I`3o^eX07@3o^e/00`3o_5`0ok]J0?nnHP0H
0?nkF`050?nkFP3o_5`0ok]K0?noHP3o^UT05@3o^e/00`3o^e`0okaL0?nnHP0>0?nkF`080?nkFP3o
_F80okeP0?njF03o_5`0okYI0?nnH`3o_V0@0?nkF`030?nkG03o_V<0okaI00d0ok]K00@0ok]L0?nk
FP3o_F00ok]L3@3o^e/00`3o_F00okYI0?nkF`070?nkF`090?nnG03o_ed0oii?06`i700000009`h9
0=aG>@3oSed0ohaK00P0oh]J00<0ohmP0?n;FP3oReX02@3oReX00`3oSUl0oh]L0?n;FP090?n;FP03
0?n<G03oReX0oh]J00H0oh]J00<0ohUI0?n9F03oS5/0203oReX00`3oRUP0ohUH0?n;FP070?n;FP03
0?n=GP3oRe/0oh]J00H0oh]J00<0ohaL0?n:F@3oReX01P3oReX00`3oS5`0ohmP0?n:F@050?n;FP04
0?n:F@3oSV00oh]N0?n:FPD0oh]J00<0ohYI0?nDI`3oRe/00`3oReX0203oS5/0oh]J0?n6E@3oNDP0
og=40?mnCP3oREP0ohaK0`3oReX01@3oRET0ohiP0?n:F@3oS5`0ohUH00@0oh]J00/0ohYI0?n:F`3o
RUT0oga<0?mhB03oQE@0ohIE0?mjB@3oMDD0og]<0?n9F0060?n;FP040?n=GP3oQE@0ogi>0?mhB080
ogM600H0ogQ70?n1D03oR5L0ohUH0?n;FP3oS5/40?n;FP80ohYI00P0oh]K0?n;FP3oReX0ohYI0?n6
E@3oPU80og];0?mjB@80ogQ800/0ogQ70?mgAP3oN4L0ogQ70?miB@3oOTh0oh=B0?n7EP3oREP0ohYI
0?n;FP020?n<F`80oh]J00<0oh]K0?n<GP3oReX01`3oReX00`3oRUT0oh]J0?n;FP050?n;FP80ohaK
00D0DR0F0000001O7QP0ofEA0?m`FP040?m/F0040?m/E`3oLE`0ofmJ0?m]F0L0ofaH00<0ofiI0?m^
FP3oKUT01P3oK5P0103oKEL0ogAP0?mbGP3oK5D60?m/F0090?m]F03oKUT0_c/_01X81P000000@10@
0?m;B`3oFEP0oeMF00L0oeME00<0oeEC0?mIE`3oEeD02P3oEeD0103oFeT0oeID0?mHEP3oEE@:0?mG
E@030?mEE03oFeT0oeUG00`0oeME00@0oeED0?mIE`3oG5X0oeID0`3oEeD00`3oEUD0oeID0?mIE`09
0?mGE@030?mIF03oEU@0oeQF0100oeME00@0oeEC0?mKFP3oEeD0oeQF4P3oEeD0103oEE<0oeeK0?mM
F`3oEeH?0?mGE@0A0?mGEP3oF5H0oeIE0?mFE03X?3d0I1HF01l61P0<0000000000<1000h5`X0/dlW
0?n:BP3oWE@0oj=H0?nTFP3oXEL05@3oX5H01@3oWe@0ojEO0?nRF@3oX5L0oj5I0200oj1F00H0oimD
0?nSG03oZF@0oj1F0?nQE`3oX5L20?nPEP040?nXHP3o[FT0ojeX0?n]J0L0ojiY00`0ojiX0?n^J@3o
[VX0oj1J0?nID@3oW5D0oiA90?ml>`0Y4@P0EC0B0?o0B@3oj]Ko0?oooi/0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj03oool04@3on_l0hHAN07Dl6P1g@2@0
MD4V07Do9@2>DcX0ND<Y07I19`1lAB`0RU0g07I19`1i@bT0N48X0;5U?`34K3`0`fTh00D0`FTh00<0
`6Lf0<5Y>031JCP00P31JCP01P30J3P0`fTh0?nGC@3o`640okmT0?nkFP80okaL8P3o^e/0203o^e`0
ok]K0?o1J@3o_5`0ok]J0?nlG03o^e/0ok]J6P3o^e/00`3o^UT0okiR0?nlH@030?nkF`030?nkFP3o
^e/0ok]K0180ok]K00D0okaL0?nkF`3o_V<0okaQ0?nlF`0D0?nkF`040?nkFP3o_5/0okiR0?nlG0P0
ok]K00`0okaL0?nkFP3o_5d0okiP0?nkFP3o^e/0okYI0?nmG@3o^eX0ok]K0?nkFP3o_El@0?nkF`04
0?nkFP3o_Eh0okaQ0?nkG0h0ok]K00<0okYH0?nmG`3o^e`0303o^e/00`3o^eX0okeO0?nkF`070?nk
F`090?nlF`3o_E`0okmL06dj700000000P0008Dc8@3oPeL0oheL00P0oh]J00<0ohiQ0?n:F@3oReX0
203oReX00`3oRUT0ohaO0?n<G0090?n;FP030?n:F@3oS5`0oh]J00P0oh]J00<0oh]K0?n;FP3oReX0
1P3oReX00`3oRe/0ohaK0?n:F@070?n;FP030?n9F@3oS5d0oh]J00L0oh]J00<0ohiO0?n;FP3oReX0
1@3oReX00`3oRe/0ohaK0?n:F@070?n;FP030?n:F@3oRUX0oh]J00D0oh]J00<0ohUH0?n:F@3oReX0
1@3oReX01P3oR5T0ogY;0?mgAP3oNTT0ohED0?n;F`80oh]J00H0ohYI0?nAI03oR5P0oh]J0?n9F03o
S5/30?n;FP0:0?n9F@3oREX0oge=0?mgAP3oOD`0oh1@0?mhA`3oMdH0oh1@0?n=GP@0oh]J00`0ohYI
0?n9F03oPU80ogU80?mhA`3oMdH0ogQ70?mlC03oPe80ohUH0?n;F`3oSf820?n;FP0:0?n;F`3oS5/0
oh]J0?n;FP3oRUT0ohiO0?n?H@3oPe40oh5@0?miB0<0ogQ70P3oMTH01P3oMTL0ogY90?mmC@3oPE40
ohAC0?n9F0<0oh]J00<0ohaL0?n;FP3oReX01@3oReX00`3oReT0ohYI0?n;FP070?n;FP030?n>G`3o
Re`0oh]J00<0oh]J00P0ohYJ0?n=G03oRUX0WChX00810@1O7QP0ofMA0?m_FPD0ofaH0P3oL5/00`3o
KEL0ofaH0?m/F0050?m/F0030?m^F@3oKeT0ofaH00@0ofaH00@0ofmJ0?m]E`3oM5l0of]C0P3oLE`0
0`3oKEP0ofaH0?m/F0030?m/F0030?m_FP3oKUT0[S``0080000000@0<0d<0?=8A`3oEeH0oeIE1P3o
EeD00`3oEE@0oeiM0?mFE00;0?mGE@030?mIF03oFEL0oeME00X0oeME0P3oF5H00`3oFeT0oeME0?mG
E@0:0?mGE@040?mEE03oF5H0oeiM0?mCDPH0oeME00<0oeED0?mED`3oEE@01P3oEeD00`3oFEP0oeeK
0?mGE@0?0?mGE@040?mHEP3oEED0oeiN0?mJF180oeME00<0oeQF0?mGE@3oFeX0403oEeD04@3oEeH0
oeQG0?mJF03oDe<0odM70=<_;P1/5aH01@01000000050P0060/408Xn7`3oR4P0oieD0?nOE@3oXUL0
oj5G01@0oj1F00L0oj5I0?nPE`3oXUT0ojEO0?nQE@3oX5H0oj5G01/0oj1F00X0oimE0?nPEP3oX5H0
oj5H0?nPEP3oXED0ojIR0?nPF03oX5H0oj1G1@3oX5H00`3oYE`0ojeY0?n^J@080?n^J@0<0?n_K@3o
[VT0ojeY0?nZJ03oWeT0oieG0?nCB03oQCl0IR`E05@a4P3oadT0oo7No`3ooonK0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinP0oooo0180ooSl0;ET>@20@ah0
MclS07a5:`1kA2X0T5@l07U3:@1g@BL0ODH/07i7;01i@bX0MT4X08m?<@2jICL0_6Hh0<5Y>P32JCP9
0<5Y>0030<M/>P3gVdl0okeL0080ok]K00@0ok]J0?nlGP3o_El0ok]J0P3o_V400`3o^e/0okeN0?nl
G00O0?nkF`080?nkFP3o_5`0okeN0?njF@3o_f@0okeO0?nlG@3o_5`J0?nkF`070?nmGP3o_5/0okaL
0?noI03o_5/0okaN0?nlFP0E0?nkF`050?nmGP3o_5X0okiQ0?nmG@3o_5d04`3o^e/00`3o_5d0ok]J
0?nnG`030?nlG0050?nkF`3o_El0okeM0?nlGP3o_Ed01@3o^e/00`3o_5d0okaN0?nkF`020?nkF`03
0?nmG@3o_5`0okaL0080okaL3@3o^e/01@3o^eX0okaM0?nmG`3o^e/0okaM00`0ok]K00<0okaL0?nm
GP3o_Ed00P3o_5`:0?nkF`050?nlF`3o_Eh0okeM0?nkF`3o_5/01`3o^e/02@3o]EP0Zg@i068e6@0C
2PD0AQ`B0<AQ?`3oPeH0ohiM0?n;F`060?n;FP030?n<G03oS5d0oh]J00T0oh]J00<0oheM0?n;FP3o
Re/02@3oReX20?n<F`L0oh]J00<0ohaK0?n;FP3oRUT01`3oReX00`3oRU/0ohaM0?n;F`070?n;FP03
0?n<G03oS5/0oh]J00H0oh]J00<0ohaM0?n>GP3oRUT01P3oReX00`3oRe/0oheM0?n;FP050?n;FP03
0?n:F@3oSF00oh]K00L0oh]J00<0oheN0?n;FP3oReX01@3oReX02P3oR5L0oh1@0?mjBP3oN4L0ogm?
0?n9F03oS5/0ohYI0?nAI03oR5P20?n;FP0I0?n:F@3oS5d0oh]K0?n;FP3oRUX0ogY:0?mfA`3oNTT0
og]:0?mhA`3oO4/0oh=B0?n<F`3oRe/0ohYI0?n9F03oQ5<0oga<0?mkBP3oNDP0ogM80?mkC@3oPE00
ohAD0?n9F@020?n<F`0;0?n;FP3oRUT0ohYJ0?n7EP3oQE@0oh=B0?n0C`3oOTd0oga;0?mjB@3oMTL0
0P3oNDP0203oNd/0ogi=0?n0C`3oPE00oh=C0?n7F03oRUX0ohUH1P3oReX00`3oRU/0oheM0?n;F`06
0?n;FP030?n<F`3oSE`0oh]J00H0oh]J00@0oh]K0?n=GP3oS5`0ohYJ0`3oReX0203oRUX0oheL0=9W
@`1>7aD00@00074Z8@3oJUH0ofiI1@3oK5P00`3oL5/0ofmJ0?m]F0060?m/F00>0?m]F03oKeX0og1K
0?m]F03oKUT0ofmJ0?m/E`3oLE`0ofaF0?mbG@3oKEL0ofiI0?m/E`3oKUX50?m/F0090?m`FP3oIU80
]TLi068O6@0B1@D0LA`K0;hl>`3oDU40oeQF00H0oeME00<0oeID0?mIF03oEeD02@3oEeD01@3oF5H0
oeME0?mJF03oEeH0oeQF00T0oeME0P3oF5H00`3oFEL0oeQG0?mGE@0:0?mGE@050?mHEP3oEU@0oeYH
0?mHEP3oF5L02@3oEeD20?mHEP060?mFE@3oF5H0oeQF0?mFE03oFEL0oeYI3@3oEeD00`3oEUD0oeMF
0?mGE@020?mJF0030?mIF03oEE@0oeME00h0oeME00L0oeID0?mHE`3oEUD0oe]J0?mEE03oFUT0oeQG
00`0oeME01<0oeMF0?mIE`3oFUT0oeQG0?m>CP3J@3l0[c8a080S8`1841000P4001`<1P0m6`h0Pd0Q
0:a[>P3NOT<0oiE@0?nRF03oXEL0oj5F0140oj1F00P0oj1G0?nRF@3oX5H0oimD0?nTG03oXEH0ojAL
0?nRFAd0oj1F00P0oj5H0?nRF@3oXEH0ojEO0?nRF@3oWU<0oj=K0?nOE@X0oj1F00<0oj5G0?nXHP3o
[VT01@3o[VT00`3o[fX0ojm[0?n_J`040?n^J@090?nVH@3oW5@0ohi50?n9@@29>a`0<Qd;0?nT<@3o
i<@0ooko0?l0ooooVP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOX0?ooo`0C0?oen`2KE2d0Pd@P08559P1e@2L0ND<Z07m7;P1i@bT0MT0U078m8`1g@RL0N48X
07m6:P2dHC<0_6Hg0;MR<P2kICP0^fDf0;mX=`020<5Y>0030<5X>03;L480`6Lf0080`FTh00<0_VLg
0?nJD03o_5/01`3o^e/20?nkFP060?nlF`3o`6D0okiN0?njF@3o_V80okaK0P3o^eXN0?nkF`80ok]J
00D0okiP0?nnGP3o^eH0okeQ0?nlGP020?nkFQP0ok]K00P0ok]J0?nlG03o`6@0okYH0?nnH03o_Eh0
okaI0?nkFQ<0ok]K0P3o^eX01@3o_V40okYI0?nmH@3o_Ed0ok]J0100ok]K0P3o^eX0103o_Eh0okeQ
0?nnHP3o_F020?nkFPP0ok]K00<0okeM0?nmH03o_5T01@3o^e/00`3o_Ed0okeN0?nlG00=0?nkF`80
ok]J00<0okeQ0?nlG@3o^eX0303o^e/01@3o^eX0okeN0?nlG03o_5`0ok]J00X0ok]K00@0okYI0?nm
GP3o_Eh0ok]J1`3o^e/02@3o_ed0olIQ0?nBA`0^6@`0000004@M4`3WFS/0ohmM0?n9FP060?n;FP04
0?n;F`3oSUh0oheL0?n;F`P0oh]J00<0ohaK0?n;G03oS5/0203oReX00`3oRUT0oheN0?n;FP080?n;
FP030?n<G03oS5/0oh]J00H0oh]J0P3oRUT80?n;FP030?n>G`3oRe`0oh]J00H0oh]J00<0ohYI0?n=
GP3oReX01@3oReX00`3oRUT0ohaL0?n;F`060?n;FP030?n:F@3oS5d0oh]J00H0oh]J00<0ohaM0?n;
FP3oReX01@3oReX0103oSEh0ohaK0?n;FP3oPE420?mhA`040?n4D`3oR5P0oi9T0?n8F0@0oh]J00<0
ohiO0?n<GP3oMTP00P3oNDP0203oM4H0ogY90?n6E@3oSUh0ohaK0?n7E@3oOdl0og]:0P3oMTD05`3o
NdX0ogi>0?n4D`3oRe/0ohiN0?n;FP3oREP0ohEE0?n1D@3oOdl0ogi>0?mhB03oM4D0og940?mdA03o
MTD0ogY90?mlC03oODd0oh9A0?n5E03oR5L0ohYH00H0ohaK00<0ohQH0?n;FP3oReX0103oReX00`3o
Re`0ohUK0?n;FP060?n;FP030?n9F03oS5`0oh]J00H0oh]J00<0oh]K0?n;FP3oRUT01@3oReX01P3o
SE`0iW59014710000000Ib0J0?m/E`D0ofaH00<0ofeG0?m`F@3oKUX01`3oK5P0203oKEP0of]D0?m]
E`3oKUP0ofmJ0?m`F`3oLel0ofYD0P3oK5P00`3oKEL0ofmJ0?m_FP060?m/F0030?mcG03RED@09P`9
0080000000<0^c<c0?mKFP3oEUD01@3oEeD01@3oEUD0oeUH0?mIF03oFEL0oeID00P0oeME00@0oeED
0?mIE`3oEU@0oeQF2P3oEeD01@3oEE@0oeQG0?mHEP3oFEL0oeED00/0oeME0P3oFEL00`3oF5L0oeID
0?mGE@0;0?mGE@060?mED`3oFUP0oeUG0?mIF03oEeD0oeIE303oEeD00`3oEE@0oeQF0?mLFP020?mI
E`030?mEE03oEeD0oeME00d0oeME00L0oeED0?mED`3oFeT0oe=B0?mMG@3oEeD0oeED00h0oeME00H0
oeYI0?mKFP3oAD@0l3Xi0:LX:@0U1`L300000005070b6P3FHC<0oh=40?n/G@3oYe`04`3oX5H20?nP
E@050?nQE`3oY5h0oj5G0?nVH03oX5D07@3oX5H02@3oX5D0oimE0?nPE`3oY5h0oj5H0?nSF`3oYV00
oimE0?nPE@0?0?nPEP030?nRFP3o[6D0ojiY00@0ojiY00<0ojmZ0?n`J@3o[VT00`3o[VT02P3o[fX0
ojeW0?nLE@3oS4@0oha30;Q@9@0G3@D0oiH_0?o@S@3onOgo0?oooiX0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj03oool03@3om?X0PT<O08127@2:C2d0PDT`
07Q2:01g@RP0N48X07Q19`21B2l0NT@Z07I1:@2TFcD00P2nIcT01034K3l0_FDg0;eV>030J3X20<5Y
>0030<9Z=`3;L4<0`6Tf0080`FTh00<0fWHo0?nlG03o_5/02P3o^e/0203o^eX0ok]K0?nkFP3o_V80
ok]J0?nkF`3o_fD0okaN0P3o^eXO0?nkF`070?njF@3o_F40okaM0?nnH@3o_V<0ok]H0?nkFP0H0?nk
F`060?nkFP3o^e/0okiP0?nlG@3o_V80okeP5`3o^e/01@3o_F40okaL0?nmG`3o_5`0okaI00d0ok]K
00X0ok]J0?noI@3o_5`0okeP0?nkG03o_Ed0okiN0?njF@3o_El0ok]J203o^e/00`3o_5`0okaI0?nk
F`040?nkF`050?nlF@3o_F00ok]K0?nlG@3o^eX03@3o^e/01@3o^eX0okeL0?nlG@3o_F00ok]J00`0
ok]K00<0okaL0?nkFP3o_F40303o^e/00`3o_5d0okeP0?nkF`070?nkF`080?nlF`3ob680g8Y401@:
1@00000020<20<QH>P3oU6480?n;FP030?n<F`3oSUl0oh]K00P0oh]J00<0ohYI0?n<G03oRe`0203o
ReX00`3oRe/0ohiO0?n;FP070?n;FP030?n:F`3oS5l0oh]K00L0oh]J00<0oh]I0?n:F@3oReX01P3o
ReX00`3oRUT0ohaL0?n:F@060?n;FP030?n<G03oSUl0oh]J00H0oh]J00<0oh]K0?n<F`3oReX01@3o
ReX00`3oRUT0ohiO0?n;FP060?n;FP030?n9E`3oReX0oh]J00D0oh]J00X0oi5T0?n:F@3oS5/0ohQJ
0?n0C`3oMDH0ogM60?mmC@3oTF@0ohQH103oReX02`3oRUX0oh5C0?m`@P3oN4P0ogA60?mhA`3oQED0
ohUH0?n5E03oOdl0ogU80080ogI500X0og]:0?n1DP3oR5L0ohQG0?n9F@3oPe80ogm?0?mmC@3oO4`0
ogU80`3oLT@02@3oMdH0og]:0?mnCP3oP500oh=C0?n7EP3oREP0ohYI0?n>G`030?n<F`@0oh]J00<0
ohYI0?n>GP3oReX01@3oReX00`3oRUT0ohQJ0?n:F`060?n;FP030?n:F@3oReT0ohYI00P0oh]J00<0
ohaL0?n;FP3oReX00`3oReX01`3oSE`0ohiL078^7P000000K28K0?mXDP3oKUT0103oK5P00`3oKEL0
ofiH0?m^F@070?m/F0080?m^F@3oKUP0og9N0?m_FP3oKEL0og1K0?m/F03oKEL20?m/F0030?m^F03o
K5D0ofmJ00D0ofaH00P0ofiH0?mdG@3oEdD0>18>0000000d30`0ecLe0?mIF0L0oeME0`3oFEL90?mG
E@80oeQF00<0oeUG0?mED`3oEeD0203oEeD01@3oEE@0oeEC0?mLFP3oFEL0oeED00X0oeME00D0oeIE
0?mIF03oF5H0oeQF0?mGEP0;0?mGE@070?mFE@3oEE<0oeQF0?mIE`3oFEP0oeQE0?mED`0<0?mGE@06
0?mEE03oF5H0oeaJ0?mFE03oG5X0oeMF403oEeD01P3oEU@0oeeK0?mIE`3oFeT0oeME0?mEE0d0oeME
00L0oeQG0?mLF`3oG5/0odI30:/Y:00o2`/00P000080000000L0BAl>0:a<:03cKCX0oiaC0?n/GP3o
YE/0oj5F0140oj1F0`3oX5D01P3oY5d0oiiB0?nQE`3oY5h0oj1F0?nPEA/0oj1F00X0oj1E0?nPEP3o
WeD0ojAN0?nPE@3oX5H0ojAN0?nRF@3oWeD0oj1E4@3oX5H00`3oWe@0ojAK0?n]I`030?n^J@030?n^
J03o[fT0ok1Z00D0ojiY00T0ojmZ0?nPF03oR480ohm50>IT<0060`40l8T]0?nlI@3om_<0o`3ooonJ
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinP0oooo01<0
ooCj08Q88`1n@Ad0QdTZ0858;`1h@RP0LclU07Q2:01d?b<0PTT`07e5;@26BR`0]F8f0;iV>02nJ3X0
bg=90;]U=`2lI3P0`6Tk0080`FTh00L0`FPg0<aa@`30IcH0`FTh0;iW=`3XTD/0okmL00h0ok]K00T0
ok]J0?nkF`3o^e/0okeQ0?nlG03o_V<0ol1V0?nkF03o^eX07P3o^e/20?nkFP040?nmGP3o_F00okYI
0?noI0<0ok]J5`3o^e/20?nkFP040?nlH03o_Ed0ok]H0?nnH@80ok]J4`3o^e/20?nkFP050?nmG@3o
^UT0ol5U0?nmG@3o^eX0203o^e/01`3o^eX0okYI0?nmH03o_Eh0okeQ0?nkF`3o^eX00`3o^e/01@3o
^eX0okaN0?nnH@3o_Eh0ok]J00L0ok]K00<0ok]J0?nlG@3o^e/0103o^e/01P3o^eX0ok]K0?nlG@3o
_V40okeM0?nkFPd0ok]K00@0okaM0?nkF`3o_V00okaL303o^e/0103o^eX0okeN0?nmGP3o_5`;0?nk
F`030?nmG@3o^UT0okeN00P0ok]K00T0ol=N0?nCB01N<QT00000020=2@3cHT00oiAQ0?n<F`3oRUX0
1@3oReX00`3oRUT0ohYK0?n=G@090?n;FP030?n:F@3oSUl0oh]K00P0oh]J00<0ohYK0?n>G`3oReX0
203oReX00`3oSEh0ohUI0?n;FP050?n;FP030?n;F`3oSUl0oh]J00L0oh]J00<0ohYK0?n>G`3oRUX0
1P3oReX00`3oRU/0ohaL0?n;FP050?n;FP030?n:F@3oSF00ohUI00h0oh]J00<0oheN0?n;FP3oReX0
1@3oReX01P3oTF@0ohYI0?n;FP3oReX0ohYI0?moC`80ogM600<0ogi@0?n<F`3oReX00`3oReX0403o
Oe00ogQ70?mcA@3oN4L0og]:0?n1D@3oP540og]:0?mhA`3oMdH0og=40?n0D03oPE40oh=B0?n0D03o
NTd20?mkBP0<0?meA@3oMTD0ogI50?mfA@3oN4P0ogi>0?n0D03oPe80ohUI0?n8E`3oRUT0oh]J0`3o
S5/00`3oReX0ohYI0?n;FP060?n;FP030?n>GP3oRUT0oh]J00H0oh]J00<0ohaK0?n:F@3oReX0103o
ReX00`3oRUX0ohiO0?n:F`070?n;FP030?n:F@3oS5/0oh]K00@0oh]J0P3oS5/01@3?DcH02P@307<U
7P3oJ5<0og9K00@0ofaH00<0ofeH0?m^F03oKET01P3oK5P0203oK5L0ofaE0?mbG@3oKeX0og5L0?m_
FP3oK5L0ofeH0`3oK5P0103oKeT0ofmJ0?m]E`3oK5L40?m/F0090?m]F@3oLE/0]CP]02L=2P000000
R2@R0?m:BP3oFeT0oeQF00H0oeME00<0oeQF0?mIF03oEE@02@3oEeD00`3oEE<0oeUG0?mHEP0:0?mG
E@050?mEE03oFeX0oeQF0?mIE`3oEUD02P3oEeD01@3oEE@0oeUG0?mHE`3oF5H0oeED00/0oeME00H0
oeED0?mIF03oFEL0oeME0?mHE`3oEeD20?mHEP030?mED`3oEeD0oeME00L0oeME00D0oeED0?mED`3o
GE/0oeQF0?mIF0020?mEE0h0oeME00L0oeED0?mFE03oFeT0oeID0?mIF03oF5L0oeED00d0oeME00L0
oeUG0?mKFP3oCT`0bRd]07DM700d2`X00P010080000000H0GRXD0>EX=`3oS4X0ojAG0?n/GP3oXUPB
0?nPEP090?nPE@3oWe@0oj=M0?nVH03oXED0oj=K0?nPE@3oX5H0oj1E01X0oj1F00L0oimE0?nPE@3o
XEH0ojMQ0?nSFP3oXED0oj9K0080oj1F00<0oj1E0?nPEP3oX5H0503oX5H01P3o[6H0ojmZ0?n^J@3o
[VP0ojm/0?n^JPL0ojiY00P0oimI0?n7@@3oT4L0mVXd00<20@3UPBh0ok5?0?obkOl0ooooVP3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOX0?ooo`0@0?ofo01n
@Ah0P4<N08Q9:@22BBl0MD0V07M19`1kA2/0PTT`07U3:@22BBh0/F4h0;iW>02mISP0_VHi0;mX>`80
_FHh00X0_VHh0<5Y>`33Jc/0`FTh0<=Z>P31JCP0_6Hg0=eh@@3o]UT0okaK4`3o^e/00`3o_5`0okaM
0?nkFP020?nmG`060?nkF03o_5h0okeN0?nkF`3o_5`0ok]L703o^e/02@3o_5`0ok]J0?nmH03o_V00
okaL0?nnH@3o_5/0ok]K0?nlG00G0?nkF`070?nlG03o^e/0okiP0?nlG03o_Eh0ok]K0?nkG00C0?nk
F`0?0?nlG@3o_5`0okiO0?nkFP3o_F00okaL0?nkF`3o_5`0ok]K0?nlGP3o_Eh0okiP0?nlG03o^e/0
okaL00P0ok]K00L0okaL0?nlFP3o_El0okaM0?nmG`3o^e/0okaL00D0ok]K00<0okaN0?nlF`3o^e/0
1@3o^e/20?nlG0030?nmG`3o_Eh0okaM00d0ok]K00D0okaL0?nlG@3o^e/0okiQ0?nkFP0;0?nkF`80
okaL00<0okeM0?nlG03o^e/02P3o^e/20?nlG0030?nlG@3o^e/0ok]K00@0ok]K00X0okaL0?o0G@3o
]eX0e8Y405@_5`0;10<0BahC09]=<`3nPeH0ohaK1@3oReX0103oRUX0ohaK0?n:F@3oSEd90?n;FP03
0?n<G03oRUT0oh]J00H0oh]J00@0ohYJ0?n;F`3oSEd0oh]L1`3oReX00`3oS5/0oheN0?n;F`070?n;
FP030?n<G@3oS5/0oh]J00H0oh]J00<0oh]K0?n<G03oReX01P3oReX00`3oS5`0ohYJ0?n;FP050?n;
FP030?n<G03oRUX0oh]J00D0oh]J00<0oheM0?n:FP3oReX01@3oReX00`3oSEd0oh]J0?n;FP090?n;
FP070?n<F`3oReX0ohQG0?n0D03oMdL0og];0?n3D`020?n:F@040?mmC03oN4L0ogM70?mcA@<0ogY9
0140ogU80?mhA`3oNDP0ogY90?meAP3oNDP0ogY90?miB03oNTT0oge<0?mnC@3oOdh0oh1@0?n6E@3o
QeH0ohUH0?n:F@030?n;FP030?n=G@3oS5/0oh]J00D0oh]J00<0oheM0?n;FP3oReX0103oReX00`3o
Re/0ohaL0?n;FP060?n;FP80oh]K1`3oReX00`3oS5/0oh]J0?n;FP050?n;FP030?n<G03oS5d0oh]K
00@0oh]J00L0ohaK0>I_B01/:Q`02@@207P/903oK5H0ofmJ00@0ofaH00<0ofeI0?m^F03oKEP00`3o
K5P20?m]F0040?mbG@3oKUP0og9N0?m/F080ofeI1P3oK5P00`3oKEL0ofiI0?m/F0030?m/F00:0?m]
F03oKET0ofiI0;a8>P0f4Ph00`4103L=3@2l>3L0oeQF0?mIE`D0oeME00D0oeMF0?mFE@3oFEL0oeMF
0?mHEP070?mGE@040?mGEP3oFUP0oeQF0?mHEPX0oeME0P3oF5H0103oFEP0oeQF0?mHEP3oEUD80?mG
E@030?mHEP3oFEL0oeUG0080oeQF2`3oEeD0103oEUD0oeYH0?mGE@3oFeX20?mHEP@0oeME00<0oeQF
0?mGE@3oEeD01@3oEeD0103oEUD0oeQF0?mIF03oFeT30?mHEPd0oeME00D0oeQF0?mFE@3oFUT0oeIE
0?mKFP020?mHEP030?mGE@3oEUD0oeME00P0oeME0P3oEeH04@3oEeD0oeED0>a7AP2X=3@0RRDT05lE
5@0O1`L02`8103HH301^<AT0U5@/0>Qn@`3oTTl0oiaD0?nSF03oXUP0oj5G00l0oj1F00H0oj1G0?nP
EP3oXUP0oj=J0?nQE@3oXU/20?nQF0030?nRF03oX5H0oj1F01L0oj1F00/0oj5G0?nPE`3oXEH0oj5G
0?nSF`3oX5D0oj9J0?nVGP3oX5L0oj9H0?nPE`0L0?nPEP050?n/I`3o[VX0ojm/0?n_J`3o[fX01`3o
[VT0203oYUl0ohe50?n=A03oM3P04PP40=Ej;@3o^dX0ooC[o`3ooonJ0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinT0oooo00/0M3/G07i07P1^>AT0N44V07Do
9@26C3@0R4de08iB>@1_>al0Ue@c0;iV>0030;eV>0030;]U=P2jI3D0_FHh0080_FHh00L0^fDf0<5Y
>P31J3P0^VDe0=Qe?P3o[EH0okeL01`0ok]K00D0okYI0?o1I`3o_f@0okYI0?nlGP0P0?nkF`050?nj
F@3o_Uh0okiQ0?nkFP3o_Ed06P3o^e/01`3o^UT0ol1U0?nmHP3o^e/0ok]L0?nkF`3o^eX04`3o^e/0
103o^e`0okeP0?noI03o_V0C0?nkF`040?nkF03o`FL0ok]J0?nlG0@0ok]K00<0ok]L0?nmGP3o_5`0
203o^e/0103o_5T0okiS0?nmG@3o_5`=0?nkF`050?nkFP3o_Eh0okaM0?nkG03o^eX02`3o^e/00`3o
_5T0okeO0?nkF`0;0?nkF`030?nlG03o_5d0okaL00L0ok]K00T0okaK0?nhFP2SEb/04@T40000001F
8QL0oh5D0?n@G@3oS5/01P3oReX00`3oRe/0ohiO0?n;FP080?n;FP030?n<F`3oSEh0oh]J00P0oh]J
00<0ohaM0?n:F@3oReX01P3oReX00`3oRUT0oh]J0?n;FP070?n;FP030?n=GP3oReX0oh]J00H0oh]J
00<0ohiO0?n:F@3oReX01@3oReX00`3oSEd0oheN0?n9F@050?n;FP030?n:F@3oRe/0oh]J00H0oh]J
00<0ohiQ0?n;FP3oReX01@3oReX00`3oRUT0oh]J0?n;FP050?n;FP030?n:F@3oReX0oh]J00@0oh]J
00D0ohED0?mgB03oN4L0ogQ70?mkBP020?mhA`040?mgA`3oLT@0ogU80?mfA@80ogQ700L0ogU80?mj
B@3oNTT0ogm>0?n4D`3oQUD0ohYI00<0oh]J00<0ohYI0?n;FP3oReX0103oReX00`3oRUT0ohmR0?n<
F`060?n;FP030?n>H@3oReX0oh]J00D0oh]J00<0ohaL0?n;FP3oReX01@3oReX00`3oRe`0oheM0?n;
FP060?n;FP030?n:G03oReX0oh]J00D0oh]J00<0ohaM0?n;FP3oReX0103oReX01P3oS5/0iFi700@1
0@000000BaHC0?mYE0D0ofaH0P3oKeX00`3oK5L0ofaH0?m^F@020?m_FP040?meH03oJE<0ofiI0?m^
F@P0ofaH00<0ofiI0?mbG@3oKEL0103oK5P02@3oKUT0ofmJ0?mMBP1_8a`0000002L:2P3><c80oeID
0?mGEP060?mGE@030?mHE`3oF5H0oeME00T0oeME00<0oeQF0?mJF03oEeD02P3oEeD00`3oF5H0oeiM
0?mCDP0:0?mGE@040?mEE03oF5H0oeEC0?mJF0h0oeME00<0oeMF0?mKF@3oEE@02P3oEeD0203oF5H0
oeEC0?mGE@3oEE@0oeMF0?mMF`3oFEP0oeID3`3oEeD01@3oEE@0oeQG0?mCDP3oHV40oe=B00d0oeME
0140oeMF0?mIF03oF5L0oe9A0?m2@@2c:2L0=`X;00400000000030@002PA202OAb@0oi1<0?nOE@3o
XEH0oj9G0?nQEP0?0?nPEP080?nPE@3oX5H0oj1F0?nQF03oX5L0ojIR0?nSFP3oX5DM0?nPEP060?nQ
F@3oX5H0ojAK0?nWH@3oX5H0oj1E8@3oX5H01@3oX5D0oj1F0?nVGP3o[fd0ojmZ00D0oji[00`0ojm/
0?n^J@3o[VP0ojmZ0?nSG03oUe00oi550?n<@P1880l0bG<[0?o3AP3onoCo0?oooiX0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj03oool0303of]H0L3XG07a0
7@1a>AX0MT0U07m8;P25C380PDP_08eB>01b?R@0YeXa0;iW>@<0_FHh00<0_VLj0<5Z?02mISP00`2m
ISP01@2kICH0`6Th0;eV=@3oWDl0ol1M01h0ok]K00X0ok]J0?nkF`3o_5`0ol9Y0?nlG03o^UP0okeO
0?nkFP3o^e/0ok]J703o^e/01P3o^eX0okaL0?o1I`3o_5`0okaM0?nlG080ok]J603o^e/01P3o_F00
okaM0?nkFP3o_F00ok]K0?nkFPl0ok]K00T0okeP0?nkE`3o_V80okeN0?njF03o`FL0okaL0?nlG@3o
^eX04@3o^e/01@3o^eX0okaO0?nmG@3o_5`0okaM00<0ok]K00<0ok]J0?nlGP3o^e`02@3o^e/01@3o
^eX0okeQ0?nkF`3o_5`0ok]J00`0ok]K00<0okaN0?nlG@3o_5`0303o^e/0103o^eX0okiS0?nlG@3o
_5`:0?nkF`030?nkFP3o_F40ok]L00L0ok]K00T0okaL0?noG@3iQ440@b<A0000001C8AH0ofI20?n;
FP3oSE`04@3oReX00`3oREP0ohaK0?n;F`070?n;FP030?n;F`3oSUl0oh]J00L0oh]J00<0ohUH0?n;
FP3oReX01P3oReX00`3oRe/0oheM0?n9F@070?n;FP030?n<F`3oReX0oh]J00@0oh]J00<0ohYI0?n;
FP3oRe/01P3oReX00`3oT640oh]J0?n;FP050?n;FP030?n?H03oRUT0oh]J00@0oh]J00<0ohaK0?nD
I`3oRUT01@3oReX00`3oS5`0oi5T0?n:F@050?n;FP030?n:F@3oQUD0ogQ800@0ogQ700P0ogM70?md
AP3oO4/0oga<0?mkC03oPU40ohME0?n9F0L0oh]J00<0ohYI0?nAI@3oS5d01@3oReX00`3oRUT0ohiO
0?n;F`050?n;FP030?n;F`3oS5`0oh]J00D0oh]J00<0oh]K0?n=GP3oReX01P3oReX00`3oS5`0oh]J
0?n;FP040?n;FP030?n9F@3oSEh0oh]L00H0oh]J00<0ohQJ0?n<G03oReX00`3oReX0203oREX0oheL
0?n;F`1U:A/0000004dG4`3oGd`0ofmJ103oK5P02`3oL5/0ofmJ0?m]E`3oKeX0ofeG0?mbG@3oMf80
ofaF0?m]E`3oK5P0og5L00P0ofaH00<0ofeH0?m`F`3oK5P0103oK5P0203oKEP0ofiI0=A3=P0F1`H0
000003P>3P3oC4/0oeYH1P3oEeD00`3oF5H0oeED0?mKF@080?mGE@050?mFE@3oFEL0oeUG0?mKF@3o
EUD0203oEeD0103oEE@0oeQG0?mFE03oFEP;0?mGE@030?mHEP3oEE<0oeiM00d0oeME00@0oeUG0?mG
E@3oGE/0oe=B3@3oEeD01@3oF5D0oeME0?mCDP3oG5X0oeED00h0oeME00D0oeIE0?mGE@3oFEP0oeEC
0?mMG0020?mEE0`0oeME00H0oeQG0?mKFP3oE5<0odY:0?ln?@1^61L30000000602D@1`1n>1d0hV@b
0?nHD@3oYe/0oj5G4@3oX5H0203oX5D0oj1F0?nRF`3oX5D0oimD0?nVG`3oXED0oj1E6`3oX5H0203o
X5D0oj9J0?nRF03oWe@0ojMS0?nSG@3oX5D0oimE803oX5H02P3oX5D0oj1F0?nRF@3oXU/0oj1G0?nQ
E`3o/g@0okEg0?neMP3o]7D30?neMP0<0?nfMP3o[fX0ojeV0?n]I`3oXE/0oimH0?n>A`3oTTD0H2XC
0:iU9@3o^3`0oo?^o`3ooonJ0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWinP0oooo00/0ojfI07@l6@1l@1d0KcPI07Do8`2?E3`0Re0h07]4:P2?ECd0RTdb0;YV
>@030;eV>0040;aV>032Jch0bW980;]T=P@0_FHh00@0^fHh0?n;B03o_Ud0okaK8@3o^e/0203o^eX0
ok]K0?njF@3o_f@0okYH0?nkF`3o_V<0okaL0P3o^eXK0?nkF`80ok]J00D0okeP0?nlG@3o^eP0okeQ
0?nlG@020?nkFQH0ok]K00L0ok]J0?nmG@3o`6H0okaK0?nmHP3o_5T0ok]J00T0ok]K0P3o^eX01@3o
_Eh0okaM0?noI@3o^e/0ok]J0080ok]K00L0ok]J0?nkF`3o_V80ok]H0?nlGP3o^e`0ok]J0100ok]K
00@0ok]H0?nmH@3o_Eh0okaM0P3o^eX00`3o^e/0okaK0?nmH00;0?nkF`040?nmG@3o_5`0okaL0?nl
G0`0ok]K00D0okaI0?nnHP3o^e/0okaL0?nkFP0:0?nkF`040?nkFP3o_Eh0okeP0?nlG0X0ok]K00@0
ok]J0?nlG@3o^e/0okaL1`3o^e/0203obF<0ok1F05L^5`00000020<10:i4;@3oR5T0ohYJ1P3oReX0
0`3oReT0ohiN0?n;F`080?n;FP030?n:F@3oSEh0ohYI00H0oh]J00D0ohYJ0?n;G03oS5h0ohYI0?n:
FP060?n;FP030?n8F03oS5`0oh]J00H0oh]J00<0oheM0?n;G03oRUT01@3oReX00`3oRU/0ohiN0?n;
F`060?n;FP030?n?H@3oSEh0oh]J00D0oh]J00<0ohQG0?n>GP3oReX01@3oReX00`3oREP0oh]J0?n;
FP040?n;FP030?n;F`3oRe`0ohUI00D0oh]J00<0ohaM0?nDJ03oR5P0103oReX01@3oS5/0ohYH0?n3
DP3oNTT0ogM600@0ogQ700@0ogM80?n0D03oR5H0oh]J0P3oSE`00`3oS5/0ohQG0?n:F@050?n;FP03
0?n:F@3oSf00ohaL00D0oh]J00<0ohaL0?n:F@3oReX01@3oReX00`3oSV40ohYK0?n;FP040?n;FP03
0?n:F@3oS5`0ohYI00H0oh]J00<0oheN0?n;G03oReX01@3oReX00`3oREP0ohYI0?n;FP060?n;FP03
0?n:F@3oRET0oh]J0080oh]J00T0ohYJ0?n<G03oS5`0`4`b00810@1@61@0oem<0?maF`3oKEP00`3o
K5P0203oKUT0og5L0?m`F`3oKUT0og1L0?m]F03oK5L0ofeG0P3oKEP00`3oLUd0ofeI0?m]F0060?m/
F0030?m_FP3oKeT0ofaH00@0ofaH00<0ofiI0?mcG034A3H00P0000000`0[2P/0gD=20?mIF0060?mG
E@030?mGEP3oFEP0oeEC00P0oeME00@0oeID0?mGEP3oG5X0oeMF2@3oEeD01@3oEeH0oeQF0?mKF@3o
FEL0oeIE00X0oeME00@0oeQG0?mIF03oEeD0oeED2P3oEeD01P3oEE@0oeQG0?mIF03oFeX0oeID0?mE
E0/0oeME00L0oeED0?mGE@3oFUT0oeEC0?mKF@3oF5H0oeID00d0oeME00L0oeED0?mGE@3oFEL0oeME
0?mMG@3oF5L0oeED00/0oeME00L0oeMF0?mJF@3oGUd0oe9@0?Lo?`2J92<0:`L70080000000L050L2
05LW502KAB@0lGXo0?n/G`3oYe/0oj9G0100oj1F0P3oX5D01@3oXUT0oj=M0?nQE`3oYF40oj1E01X0
oj1F0`3oX5D01P3oXUX0oj9I0?nLD@3oYEh0oj=K0?nPEP80oj1E7P3oX5H0303oX5D0oj1F0?nPEP3o
XUX0ojAN0?nPEP3oXe`0ojMR0?nRF@3oX5L0ojQR0?n]J0H0ojiX00/0ojiY0?n_JP3o[6L0oj1J0?nO
F03oTd`0oiA609I88P14;0h0oj8d0?oG/@3o0?oooiX0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWj03oool02`3^Sg00OD0M078l6`1j?Q/0MSdO08iB>P22BC40
Nd@[08M<<@2PF300_VLh00@0_FHh00<0_fPj0<5Z?@2lICL00`2mISP0202lISP0dg@o0?nkH@3o`FD0
ok]L0?nlG03o_V00okaL8`3o^e/02@3o_5`0okeP0?nkF`3o_Ul0okmT0?nlFP3o_5d0okeM0?nkFP0L
0?nkF`060?nmG`3o_5`0okiR0?nmG`3o^UT0okeO5`3o^e/01`3o_5`0okeO0?nkFP3o_El0okaM0?nm
GP3o_5h00`3o^e/01`3o^e`0okeN0?nlG03o_F40ok]K0?nmG@3o_5`01`3o^e/20?nlF`060?nlG@3o
^e/0okeN0?nkF`3o_Eh0okaK403o^e/02@3o_5d0okaL0?nmH@3o^e/0okaM0?nlF`3o_Ed0okYI0?nl
F`090?nkF`040?nlFP3o_5d0okeN0?nkF`80okaL303o^e/0103o_5d0okeP0?nkF`3o_5h;0?nkF`<0
okaL00<0okaM0?nkF`3o^e/01`3o^e/20?nlG0030?nlG@3o_5`0ok]K00D0ok]K00T0okiM0?neF@2T
IS<0CRXE0000001N9QT0e6U60?n9FP3oSeh01@3oReX0103oRe/0oheN0?n:F@3oS5/70?n;FP030?n<
G03oSEd0ohYI00L0oh]J00<0ohYK0?n=GP3oS5/01`3oReX00`3oRe/0oh]J0?n;FP060?n;FP030?n<
G03oS5/0oh]J00D0oh]J00<0oh]K0?n:FP3oRUT01P3oReX20?n<G@H0oh]J00<0ohiN0?n;F`3oReX0
103oReX00`3oRe/0oheO0?n:F@050?n;FP030?n;F`3oSel0oh]J00@0oh]J01X0ohaK0?n=GP3oReX0
oh]J0?n<F`3oRUT0ohMF0?n2D@3oNdX0ogU80?mhB03oN4L0ogm?0?mnC@3oNTX0ogM70?mbA03oNDP0
ogM80?mjBP3oO4`0oh9A0?n3E03oR5X0ohUJ0?n;FP80ohaK0P3oReX00`3oRUX0ohYI0?n;FP040?n;
FP030?n9F@3oSEh0ohYL00D0oh]J00<0ohaL0?n<F`3oRe/01@3oReX00`3oSEd0ohaK0?n;FP050?n;
FP80ohaL1@3oReX00`3oRe/0ohaL0?n;F`060?n;FP030?n9FP3oS5`0oh]J00@0oh]J0100ohaL0=e[
AP1S9QX00`4106/U7P3oJE@0ofmJ0?m/F03oKEP0ofiJ0?m_FP3oKEL0og1L0?m]EP3oKe/0ofiI103o
K5P00`3oKeX0ofiI0?m^FP050?m/F0040?m]F@3oKUP0ofeG0?m_FP@0ofaH00T0ofmJ0?mXD`2mBc`0
J24K01P71P1X6aX0^SPh0?mAD03oFEL0103oEeD0103oEUD0oeME0?mIF03oF5H80?mGE@80oeQF00<0
oeYH0?mIE`3oEeD01`3oEeD01P3oEUD0oeUG0?mHEP3oFUP0oeQG0?mFE0L0oeME0P3oEUD00`3oF5L0
oeUH0?mHEP020?mGEPT0oeME00H0oeIE0?mHE`3oFEL0oeQG0?mFE03oF5L;0?mGE@0:0?mFE@3oF5H0
oeME0?mJF@3oF5H0oeQG0?mFE03oEUD0oeUH0?mHEPT0oeME00T0oeID0?mGE@3oFEP0oeUG0?mKFP3o
EeD0oeQG0?mGE@3oEUD02@3oEeD04@3oF5H0oeUH0?mGE@3oC4/0bd0o09HT901Z6QT0?Ph=01840`0m
6`d0J2lI08Pn8033KS/0nh];0?nME03oYUX0ojAI0100oj1F00P0oj9I0?nRFP3oXED0oj=M0?nOD`3o
XEP0oj=K0?nQEaT0oj1F00<0oj5G0?nSF`3oX5H00P3oXe`00`3oWe@0oj9I0?nQF00Q0?nPEP090?nS
FP3oXEP0oimD0?nTG03oXe`0oj1E0?nRF03oXe/0oj5G00@0oj1F00<0oj9J0?n[IP3o[VX01P3o[VT0
2P3o[fX0ojMQ0?nPF03oX5P0oieF0?nGC01j=AT02PL30?B?<03oa7_o0?oooiX0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj03oool0303HNDl0O3lM07Pn7023
A1l0Lc/J08Y?=P1lAB`0N48Y08m=;P2kICL0^F@h0;]U=`<0_FHh00<0_FDg0;YT=@2jI3D00`2mISP0
302hI3L0jYI=0?nlF`3o^eX0ok]K0?nlG03o_F40okaL0?njF@3o`6H0okeM0?njFB80ok]K0P3o^eX0
1P3o^e/0okaL0?nmG@3o^UL0okeQ0?nnHP<0ok]J6@3o^e/20?nkFP050?nkF`3o_El0okYI0?nmH@3o
_f@00P3o^eXE0?nkF`80ok]J00T0okaN0?nmG@3o^UL0okiQ0?nmH03o^eX0okaN0?nlF`3o^eX0403o
^e/01@3o_Eh0okaI0?nmH@3o^UT0ok]J00l0ok]K00L0ok]J0?nkF`3o_5`0okeR0?nlG@3o^UT0okaM
00d0ok]K00@0okaL0?nkF`3o_Eh0ok]J2`3o^e/01@3o^eX0okaL0?nlG03o_El0okYI00/0ok]K00<0
okeM0?nkFP3o_El02P3o^e/0103o^eX0okaM0?nkF`3o^eX60?nkF`080?o3GP3o^U/0lh4o02<C2P00
0000DB0E0?mXA@3oSE`60?n;FP030?n:F@3oSEd0ohYI00P0oh]J00<0oh]L0?n<G03oReX01`3oReX0
0`3oSEh0ohYI0?n;FP060?n;FP030?n;G03oSEh0ohYI00D0oh]J00<0ohYK0?n=GP3oRe/01P3oReX0
0`3oRUT0ohmP0?n;F`050?n;FP030?n:F@3oSEh0oh]J00H0oh]J00<0oheN0?n;FP3oReX0103oReX0
0`3oRU/0oi1Q0?n;FP040?n;FP030?n=GP3oTF@0ohYI00D0oh]J0P3oREP00`3oS5/0ohMF0?mkBP02
0?mgAP090?mmC@3oNd/0ogQ70?mjB@3oRUT0ohaK0?n9F03oQUD0ogM90080ogQ700T0ogY90?mkBP3o
MdH0ogI50?ma@`3oNDP0oga<0?n0D03oQUD00P3oReX00`3oTF@0ohmR0?n;FP040?n;FP030?n<GP3o
S5`0ohUI00D0oh]J00<0ohaK0?n:F`3oReX0103oReX00`3oS5d0oh]L0?n;FP050?n;FP030?n=G@3o
Re/0oh]J00D0oh]J00<0ohaK0?n:F`3oReX01P3oReX00`3oSf00ohUK0?n;FP030?n;FP0=0?n;F`3K
JDD02`D30000001P7aP0ofUD0?m/F03oKEL0ofmJ0?mcGP3oKEL0og1K0?m_FP070?m/F0030?maG03o
KEL0ofaH00D0ofaH00<0ofaG0?m`F`3oKEP01@3oK5P00`3oKUT0kEY9030>2`02000000030;Ha<@3o
FUP0oeUG00D0oeME00<0oeMF0?mKFP3oEE@02@3oEeD00`3oFEL0oeME0?mGE@090?mGE@040?mGEP3o
FEL0oeQG0?mHEPT0oeME00@0oeEC0?mMF`3oEE@0oeQF2`3oEeD01@3oEUD0oe]I0?mKFP3oF5H0oeMF
00`0oeME00H0oeID0?mIE`3oG5X0oeQF0?mGE@3oEE@40?mGE@030?mEE03oFUP0oeME00H0oeME00D0
oeIE0?mGE@3oGeh0oe=A0?mJF0020?mEE0/0oeME00H0oeQG0?mJF@3oBdT0YbLV04lB4P0Q1PH20000
000701@70@1g=1T0kW4l0?nGD03oZ5/0ojQL0?nSF00@0?nPEP80oj1E00H0ojMQ0?nPE`3oXUX0oj5J
0?nPEP3oX5DH0?nPEP080?nPE@3oX5H0oj1E0?nVH03oW540oj1G0?nSG03oXEL20?nPEAh0oj1F00X0
oj1E0?nPEP3oXUT0ojQS0?nQE`3oWe@0oj9K0?nPE`3oX5D0oimE2@3oX5H00`3oWeD0ojEL0?n_J@06
0?n^J@0;0?n[J03oXed0oj1H0?nNE`3oX5T0oj=F06D[50000000l8Ta0?njC`3oo_h0o`3ooonI0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinP0oooo00`0eGM=
07m17@23A1l0Od4M07@l6P1oAb/0ND<Z07]3:02SEbh0_fTn0;YW>`2jICL30;eV>0030;eU=`2oJ3/0
_fTl0080_FHh00<0^fDh0<5Y>P3o/EX0103o^e/02@3o^eX0ok]K0?nkF`3o_Ed0ok]L0?njF03o_V<0
okmS0?njF@0T0?nkF`070?nkFP3o_5`0okaL0?njF03o`FL0okmT0?nkFP0M0?nkF`060?nlG@3o_Ed0
okeL0?o1I`3o_5/0ok]J5@3o^e/00`3o^eX0okeP0?nnH`020?nlG0030?o0J03o_Ed0ok]K0180ok]K
00@0ok]J0?nlG03o_EX0okmT4P3o^e/01P3o_5d0ok]K0?nmH@3o_Ed0okaQ0?nkFPd0ok]K00@0okaK
0?nlG@3o_F00ok]J303o^e/0103o_5/0okiR0?nkFP3o^eX:0?nkF`040?nkFP3o^e/0okiN0?nkFPX0
ok]K00<0ok]J0?nlH@3o^e/01P3o^e/00`3o_e`0ol5N0=1o?`020000000301P91P3HId@0oh]K00H0
oh]J00<0oh]K0?n?H03oREP04@3oReX00`3oRe/0ohiO0?n:F@070?n;FP030?n=GP3oRe`0oh]J00H0
oh]J00<0ohmP0?n;F`3oReX01@3oReX00`3oRU/0oheM0?n;FP060?n;FP030?n=GP3oReX0oh]J00D0
oh]J00<0ohaK0?n;FP3oReX00`3oReX00`3oR5X0oheN0?n;FP050?n;FP80ohYI1@3oReX07`3oS5h0
ohaM0?n1D@3oNTT0ogM60?mhA`3oP500ohEF0?mbA03oMdH0ohAC0?n<F`3oReX0ohQJ0?n<F`3oR5H0
og]:0?mfA`3oN4L0ogY90?n3DP3oPE40oge=0?mfAP3oMdH0ogQ70?miB03oNd/0oh1@0?n8FP3oSEh0
1@3oReX00`3oS5l0ohiO0?n;FP040?n;FP030?n=G@3oSEh0ohUI00d0oh]J00<0ohYI0?n;FP3oReX0
1@3oReX00`3oRUP0ohUI0?n;FP050?n;FP030?n=GP3oRU/0oh]J00<0oh]J00d0ohaK0?n9FP1Y:A/0
0000060O603oH4d0ofmI0?mcG`3oLE`0ofeH0?m_FP3oKUP0ofiI00H0ofaH00<0ofeG0?maG03oKUT0
1`3oK5P00`3oK5D0ofiI0?m/F0030?m/F0090?m]F03oLE/0of=?048E4@0000004PD40<Xb<03oEU@0
oeIE00H0oeME00<0oeUG0?mHEP3oEE@01`3oEeD00`3oEU@0oeaJ0?mHEP090?mGE@040?mEE03oFEL0
oeUG0?mHEPX0oeME00<0oeUG0?mHEP3oEeD0303oEeD0103oEE<0oeUH0?mGE@3oF5H=0?mGE@040?mJ
F@3oG5X0oeME0?mHE`P0oeME00<0oeQF0?mKF@3oEE@0103oEeD01P3oEE<0oe]J0?mEE03oF5L0oeED
0?mFE@T0oeME00L0oeIE0?mHEP3oF5L0oe=B0?lk>`2E8R40;0T900<0000000L0C24?0?U_>@3oSD/0
oiM@0?nVF@3oXeT0oj5F0100oj1F00D0oj1E0?nSF`3oXe`0oj5E0?nRFP020?nPEP030?nOE@3oX5H0
oj1F01L0oj1F00P0oj5G0?nXH`3oX5D0oimD0?nRFP3oX5D0oj1F0?nPEAl0oj1F00H0oimE0?nSFP3o
ZVT0oj=J0?nPEP3oXEX?0?nPEP040?nOE@3oXUT0ojYU0?n_JP@0ojiY00`0ojm]0?nZIP3oXET0oj5I
0?nOF03oXUT0ojAH070`60000000jhPa0?njA`3oo_ko0?oooiT0oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj03oool03@2lJCh0O3lM08=47`1o@Qh0Lc/I07]3
9P1jA2X0SE0c0;eW>P2kIS/0^VHk0;]V>`2mIcT00P2mISP0202kICL0`V/o0<E]@P2lICL0_FHh0;YU
>03NMch0okaJ2P3o^e/20?nlG0060?nkFP3o_V00ol5Y0?nlF`3o^e`0okaL8`3o^e/20?nlG0050?nl
F`3o`VX0okaM0?njF@3o_5`0703o^e/01P3o_5`0ok]J0?nkG03o_f80okaI0?nlG100ok]K00D0okaL
0?nlGP3o_5d0ok]K0?nlG0020?nkF`060?nlG03o^eX0okiQ0?nlG03o^e/0okaL4P3o^e/01@3o_5`0
ok]J0?nnH03o^eX0okaL0100ok]K00D0ok]L0?nlG03o_V<0okaL0?njF@0>0?nkF`030?njF@3o`6D0
okaL00`0ok]K00@0okaL0?nkFP3o_f<0ok]J303o^e/00`3o_Ed0okaL0?nkF`090?nkF`030?nkG03o
_Uh0okaL00H0ok]K00T0okaK0?noG03/OSh0:AH:0000000[4@/0og1:0?n7F@3oRe/01@3oReX00`3o
RU/0oheN0?n<F`080?n;FP030?n<G03oRU/0oh]J00L0oh]J00<0ohaK0?n9F03oReX01@3oReX00`3o
RET0ohaN0?n;G0070?n;FP030?n<G@3oReX0oh]J00D0oh]J00<0ohYI0?n;FP3oReX01@3oReX00`3o
RUT0oh]J0?n;FP040?n;FP030?n:F`3oSEd0oh]J00D0oh]J0P3oRUT50?n;FP030?n=GP3oSf00oh]J
00@0oh]J00/0oh=E0?mhB`3oMTH0ogU80?mnCP3oR5L0ohaK0?n0D03oKd80ogi>0?n9F0040?n;FP80
ohYI00X0ohED0?mkBP3oN4L0ogU80?mmC@3oQE@0ohQG0?n0D@3oNdX0ogU80P3oN4L0103oNDP0ogY9
0?moC`3oQeH20?n:F@030?n;FP3oRUT0oh]J00D0oh]J0P3oRe/50?n;FP030?n:F@3oSV00ohUI00H0
oh]J00<0oh]M0?n;FP3oReX01@3oReX00`3oS5`0oh]J0?n;FP050?n;FP030?n=GP3oReX0oh]J00<0
oh]J00P0ohYJ0>QM?0030@40H1lI0?mQC03oM5l0og1L0?m^F@80ofaH00<0ofmJ0?m^F@3oK5P01@3o
K5P00`3oKEP0ofiH0?m/F0060?m/F0030?m^F@3oL5/0ofaE00@0ofaH00T0ofiI0?m[EP3TAcT09`X8
0040001V61P0odI60?mHEP3oEeH0103oEeD0103oF5H0oeUH0?mIF03oF5H70?mGE@030?mFE@3oFeT0
oeQF00X0oeME00<0oeQF0?mIE`3oEeD02`3oEeD00`3oF5H0oeUG0?mGE@0:0?mGE@040?mHEP3oEeD0
oeeK0?mIF0d0oeME00D0oeQF0?mCDP3oHV40oeID0?mHEP0;0?mGE@060?mHEP3oFeT0oeME0?mGE@3o
FEP0oeiN0P3oF5H;0?mGE@0A0?mHE`3oEeH0oe=B0?mAD037<2l09@L800/0000000001@8002/C201n
=Q/0lfXf0?nJDP3oXUL0oj=I0?nRE`3oXEH03`3oX5H01P3oXEH0oj9I0?nXH`3oXEL0oj1F0?nQF1X0
oj1F00H0oj1G0?nPE@3oYV40ojMQ0?nQE@3oX5LQ0?nPEP070?nRF@3oWeD0oj=L0?nXH`3oXEP0oj1F
0?nRF@0C0?nPEP030?nOE03oY5d0ojeY00<0ojiY00D0ojiZ0?n`KP3oZ600oimG0?nOF0020?nPF006
0?nVF`22>Ad000000>R5<@3o^TT0ooono`3ooonI0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWinP0oooo01L0WUH_07Xo701m@Ad0Lc/K07Ln6`20ABD0OTH/0:iP
=`2hI3P0^VHj0;IS=P2gHcL0^FDj0;eX>P2nIcT0_6Hh0;mX?032JSd0_FHh0;YT>03KMSl0ok=I0?nl
F`0@0?nkF`090?nlGP3o_V80okeM0?nlG03o_f<0okeN0?nkFP3o_5d0okaL0240ok]K00P0ok]J0?nn
H03o^eT0ok]K0?noI03o_5`0okaM0?nlGQX0ok]K00P0okaK0?nnH@3o_Ed0okeN0?nmG`3o^eX0okeL
0?nlG0D0ok]K0P3o_5`0103o_Eh0okaM0?nlG@3o_V090?nkF`070?nkFP3o_5h0okeO0?nmG@3o_Eh0
ok]J0?nlG@0B0?nkF`050?nmG`3o_5/0okeP0?nkF`3o_Ed0403o^e/00`3o_5/0okaL0?nkG0020?nl
G0`0ok]K00D0okaM0?nlG03o_El0okeM0?nlG00;0?nkF`040?nmG@3o_5`0okeM0?nkG0/0ok]K00@0
okeN0?nmG@3o^e/0okaL203o^e/00`3o_5d0ok]K0?nmGP050?nkF`0;0?nlF`3o_Ud0okEH0<65@@1:
:1@02P@305dV6@2`ECP0ohQI0?n=F`3oRUX0103oReX00`3oRe/0oheM0?n;F`070?n;FP80oheM1`3o
ReX20?n;F`P0oh]J00<0ohaM0?n<G03oReX01@3oReX00`3oS5/0oh]K0?n;FP050?n;FP030?n<G03o
Re`0oh]J00D0oh]J00<0ohaL0?n;FP3oReX01@3oReX00`3oSEd0ohYI0?n;FP040?n;FP80ohaL1@3o
ReX02`3oSEd0ohiO0?n;FP3oReX0ohQH0?n4D`3oO4`0ogE50?meAP3oOdl0ohQG0080oh]J00D0ohUH
0?mhB@3oMDP0ohYI0?n<F`040?n;FP0:0?n:F@3oReX0oh]J0?n;FP3oQED0ogi>0?miB03oN4L0ogi=
0?n7F080ohYI0180ohMG0?n4EP3oPU@0ogi=0?mkBP3oNDP0ogQ80?mjBP3oOTh0oh9C0?n4E03oR5L0
ohYJ0?n;FP3oS5/0oh]J0?n>G`3oRUX40?n;FP030?n:F@3oS5`0oh]J00@0oh]J00@0ohYJ0?n:F@3o
Re`0oh]K103oReX20?n:FP030?n=G@3oRe/0oh]J00@0oh]J00<0ohYI0?n;FP3oReX00`3oReX0203o
SE`0ogmC07/`7P040@40JBDN0?m]F@3oKe/0ofeH0P3oK5P00`3oKUX0ofiI0?m]F0060?m/F0030?m_
FP3oKeT0ofeI00D0ofaH00@0ofeI0?m]F03oKe/0ofeH0`3oK5P02@3oL5X0ofeH0<99>`0o51000000
030<302h=cD0oeIE0?mHEP030?mGE@040?mFE@3oF5H0oeUG0?mIF0P0oeME00@0oeMF0?mGE@3oF5L0
oeQF203oEeD20?mHEP80oeQG00<0oeIE0?mGE@3oEeD01P3oEeD01@3oF5H0oeUG0?mFE03oFeT0oeID
00T0oeME00H0oeQG0?mGE@3oFeT0oeMF0?mHE`3oEUD:0?mGE@050?mHE`3oEUD0oeUG0?mIE`3oFUP0
303oEeD0203oEUD0oeME0?mGEP3oF5H0oeYH0?mHEP3oFeX0oeID2@3oEeD03`3oF5H0oeUH0?mCDP3o
DE00n4U80:H_;`1k7Ad0?@d=01@30`0O3PL0DR@C08Pk7@2JFc00hWi40?nPEP030?nQE`d0oj1F0P3o
XEP01P3oXUP0ojEN0?nOE03oX5H0ojAK0?nQEQL0oj1F00T0oj5G0?nRF@3oX5L0oj=J0?nSG03oX5D0
oj9I0?nSFP3oXEH07P3oX5H02@3oXUT0oj1F0?nOE03oXUX0oj=L0?nOE03oXEP0ojEO0?nPE`0I0?nP
EP030?nQE`3o[6H0ojiY0080ojiY00D0ok1[0?n/IP3oXed0oimG0?nPF@020?nPF0060?nYG`2@AB@0
00000>^8<P3o_DD0ookmo`3ooonI0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWinP0oooo01H0ST`Y07Xo7@1l@Ad0LC/J07Ln6`20@ah0S4`_0;IS=`2gHcH0]F4c
0<5/@P2eHSH0]V<g0;MS=P2mIc/0_FHh0;]U=`2hHc<0^fDh0<AZ>P3o/U`0okaL5@3o^e/02`3o^eX0
ok]K0?njF@3o_f@0okiN0?njF@3o^eX0okiS0?njF@3o^e/0ok]J01l0ok]K0P3o^eX01P3o_F80ol1V
0?nkFP3o_El0okiN0?nkFQX0ok]K0P3o^eX02@3o_V<0okaN0?nlGP3o_F00ok]J0?nlG@3o^e/0okeM
0?nmH00A0?nkF`050?nkFP3o_Ed0okiR0?nlG03o_6004P3o^e/01@3o^eX0okaL0?o0I@3o^eX0okaO
0080ok]J3@3o^e/00`3o^e`0okaM0?nmHP020?nmG@80ok]J2`3o^e/01P3o^eX0ok]K0?nmGP3o_600
okaM0?nlF@X0ok]K00D0okaI0?nmGP3o_Uh0ok]K0?nkFP090?nkF`040?njF@3o_F40okaK0?nlG0X0
ok]K00<0okaL0?nlG@3o^eX01P3o^e/01`3o]ET0PT@R00<100000000LblN0?n6F03oTV401@3oReX0
0`3oS5/0ohaL0?n=G`080?n;FP030?n<F`3oRe/0oh]J00H0oh]J00<0ohaK0?n:F@3oReX01P3oReX0
0`3oS5`0ohYK0?n;FP050?n;FP030?n?H03oS5`0oh]J00D0oh]J00<0ohUH0?n:F`3oRUT0103oReX0
0`3oRe/0oheN0?n;FP050?n;FP030?n:FP3oS5`0oh]J00D0oh]J00<0ohiO0?n;FP3oReX0103oReX0
203oSE`0ohUH0?moC`3oN4L0ogI50?mlB`3oQ5<0oh]I103oReX00`3oODd0ogQ:0?n9G@060?n;FP03
0?n:F@3oReX0oh]J0080oh]J0140ohaK0?n;G@3oQ5H0ogU80?mfA@3oNDP0oh1A0?n8E`3oS5h0ohiO
0?n;FP3oS5/0ohMF0?n4D`3oOdl0oga;0?mgAP020?mfA@080?mjB@3oOdl0oh=B0?n5EP3oRUT0oh]L
0?n<F`3oR5X20?n;FP030?n;G03oRe/0oh]J00@0oh]J00@0ohYK0?n?H03oRe`0ohYJ1@3oReX20?n:
F@H0oh]J00`0ohaK0?n;FP3oReX0ohYI0?n;G03oT640ng]A050O50000000D1PD0?mVDP3oKEP30?m/
F080og1K00<0ofeG0?m/F03oK5P0103oK5P00`3oLE`0ofmJ0?m]F0050?m/F0030?m^F@3oLE`0ofeH
00<0ofaH00T0ofiI0?meGP3oGd`0Sb`S0000000R2@T0/b//0?mDD`3oFEP00`3oEeD01@3oEUD0oeQF
0?mHE`3oF5H0oeMF00L0oeME00@0oeQG0?mED`3oGE/0oeID2@3oEeD00`3oF5H0oe]I0?mGE@080?mG
E@040?mFE@3oF5L0oeQF0?mIF0X0oeME00H0oeED0?mHEP3oFEP0oeeK0?mHEP3oEE@;0?mGE@060?mH
EP3oFEL0oeeK0?mKF@3oEE@0oeIE2`3oEeD01@3oEE@0oeYH0?mKF@3oEeD0oe]J00<0oeED00<0oeUG
0?mGE@3oEeD01@3oEeD01`3oF5H0oeaJ0?mNG@3oCdd0icPh06TE500F0`<00P0000001`0Y4@P0JBlH
0:m=:@3oS4X0ojaN0?nWF`3oXUL03@3oX5H20?nPE@070?nPEP3oXe`0oiiA0?nSF`3oYV00oj5G0?nP
E@0G0?nPEP030?nPE@3oX5H0oj=L0080oj9I00@0ojIQ0?nSF`3oX5D0oj1E6`3oX5H02@3oX5D0oimD
0?nPEP3oXEP0ojAN0?nPE`3oWU80ojIQ0?nPEP020?nPEAh0oj1F00X0oj1E0?nWGP3o[fX0ojmY0?n^
J03o/6T0ojQR0?nMEP3oWeP0oj1I0P3oX5P01P3oYUd0XU<]0000003NObh0ol140?oWeOl0ooooV@3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOX0?ooo`0;0896
901d>a`0NSlL07Lm7@1f?A/0M3/I09QC;`2fHcL0]f<f0;QT>@2jIS/00`2fHcL01`2iICP0_FLj0;aT
>02nIcT0]f<g0?nEC`3o_EX06@3o^e/0303o_5X0ok]K0?nkF`3o^eX0okmT0?niE`3o_5`0okmU0?nm
GP3o^e/0okaI0?nkFQd0ok]K0P3o^eX01P3o^e/0okiO0?nnH03o^EL0okeN0?nmG`<0ok]J5`3o^e/2
0?nkFP070?nmGP3o`6H0okaL0?noH`3o_Ed0okYI0?nlF@0C0?nkF`070?nkFP3o_E`0okeQ0?njFP3o
_Eh0okaN0?nkFP0@0?nkF`070?nkFP3o^e/0okeO0?nkG03o_F80okeM0?nlFP0<0?nkF`070?nmG@3o
^e/0ok]H0?nmG@3o_5`0okeR0?nkF00<0?nkF`040?nkFP3o_F40okaL0?nnH0/0ok]K00D0ok]J0?nm
H@3o^eX0okeQ0?nkFP090?nkF`040?nkFP3o^UT0okeM0?nlG0T0ok]K00<0ok]J0?nlG03o_Ed01P3o
^e/02@3o_Ud0okeL0=Ia=`0g70h0000006X[703oKTT0oi1N0?n;F`040?n;FP030?n8F03oS5h0ohiO
00L0oh]J00<0ohQJ0?n<F`3oReX01P3oReX00`3oRe/0ohaK0?n:F@060?n;FP030?n8F03oRUT0ohaK
00D0oh]J00<0ohYI0?n=GP3oS5/01@3oReX00`3oRU/0ohiO0?n<GP060?n;FP030?n<F`3oRUT0oh]J
00<0oh]J00<0oh]L0?n=GP3oREP0103oReX00`3oRUT0ohaL0?n:F@030?n;FP80ohaK00T0ohEF0?mj
B`3oMTD0ogM60?mmC@3oR5L0ohaK0?n:F@3oR5P00P3oReX01@3oQE@0ogM60?n1D@3oTfL0ohQH00@0
oh]J0P3oRUT40?n;FP0<0?n:F@3oTF<0oiEX0?n4E03oO4`0ogM60?mfA@3oOTd0ohQF0?n;FP3oRU/0
oh]J0`3oS5/01@3oRU/0oh=B0?moC`3oO4`0ogI60080ogI500X0ogQ80?mnCP3oPe80ohMF0?n:F@3o
SE`0ohYI0?n<F`3oSUl0ohYJ1P3oReX00`3oRUT0oh]J0?n;FP020?n;FP030?n;F`3oSUl0ohYK00H0
oh]J00`0ohaO0?n9F@3oReX0oheN0?n:F03oSUl0oiAU07H_7P000000CQPD0?mQCP3oLE/30?m/F003
0?m_F@3oKeX0ofeG00D0ofaH00@0ofeH0?m_FP3oL5/0ofaG103oK5P01@3oKEP0of]E0?m`F`3oKUT0
ofeH00<0ofaH00P0og5K0=i6>@0n4`l0000003L=3@3o@T40oeaK0?mGEPD0oeME00<0oeUG0?mKF@3o
EU@01`3oEeD0103oFEL0oeYH0?mEE03oEE@70?mGE@030?mED`3oFEL0oeYG00T0oeME00H0oeED0?mG
E@3oFEL0oeUG0?mGE@3oEE@80?mGE@060?mFE03oF5H0oeUH0?mED`3oFEP0oeED2P3oEeD01P3oEU@0
oeUH0?mIF03oEeD0oeQG0?mEE0/0oeME0P3oEE@01P3oEU@0oeUG0?mIE`3oGE/0oeME0?mFE@@0oeME
00<0oe]I0?mHEP3oEeD00P3oEeD01`3oEeH0oeaJ0?mEE@3h>ST0_Rh]06TG5P0?0P800P0000001P0Y
4PL0ZT`X0?mk@@3oWE<0ojaN0?nVFPh0oj1F00T0oj1E0?nOE@3oY5h0ojAM0?nQE@3oXed0oimD0?nO
E@3oX5D05@3oX5H20?nPE@080?nPEP3oYEd0oj1G0?nOE03oXed0oj9J0?nPEP3oX5DK0?nPEP80oj1E
00L0oimE0?nTG@3oYF40oj1E0?nQF03oYEl0oj9I0080oj1E8P3oX5H02@3oY5/0ojmY0?n_I`3o/FX0
ojmY0?nSG@3oVUD0oimG0?nQFP020?nPF0060?nVG02gI3L0000009QG803o^T80omW1o`3ooonI0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinP0oooo00L0SDd/
07@l6`1n@Ql0O3lN07Xn701/=aP0YEXb00@0]V<g00X0]F8f0;IS=`2fHcL0]V<f0;QT=`2mISP0a6a0
0<I[?03o/EP0okmL7@3o^e/0203o_5X0ok]K0?nkG03o_V80okaM0?nlF@3o`6P0ol1T0`3o^eXN0?nk
F`80ok]J00D0okeM0?nlGP3o_5/0ol1V0?nmH@020?nkFQ@0ok]K0P3o^eX02P3o_Eh0okYJ0?nlG@3o
_Ed0okeN0?njF@3o^ed0okmU0?nlF`3o^eXC0?nkF`070?nkFP3o^e/0okeM0?nmG03o`6@0okeN0?nl
F@0@0?nkF`050?nkFP3o_5d0okaP0?nlF@3o_V800P3o^eX<0?nkF`070?nlG@3o_5/0okaL0?nlGP3o
_5/0okaN0?nkFP0;0?nkF`80ok]J00@0okeP0?nlG@3o_5`0ok]J2@3o^e/01@3o^eX0ok]K0?nmH03o
_5h0ok]H00X0ok]K00@0okaL0?nkF`3o_F00okaM203o^e/0103o_5X0okaM0?nmGP3o^UT50?nkF`08
0?nnG@3oaV40oie>048S4@000000:A0:0<YB=@3oS5`50?n;FP030?n:F@3oSEh0ohYI00L0oh]J00<0
ohYI0?n=GP3oRe`01P3oReX00`3oRU/0ohaK0?n:F@060?n;FP<0ohYI1@3oReX30?n:F@D0oh]J00<0
ohYK0?n;FP3oRUT01@3oReX00`3oSEh0ohaN0?n;FP040?n;FP030?n;G03oSUl0ohYI00D0oh]J01H0
oheN0?n9F@3oReX0oh]K0?n6E@3oOdl0ogI60?mdA@3oO4/0ohAC0?n:F@3oS5/0ohYI0?n@HP3oSf80
oh]J0?n9F03oNTT0ogM60?n7F03oTfL0ohQH103oReX20?n:F@@0oh]J00`0ohYI0?n>H@3oT6<0ohaK
0?n9F03oQ5<0oga<0?meAP3oN4P0oh5A0?n9F03oS5/30?n;FP0?0?n<G03oRe`0oh]J0?n9F03oQE@0
ogm?0?mlC03oMdL0ogE50?mgAP3oNTT0oga<0?n1D03oREP0oh]J0080ohaK0`3oReX00`3oS5/0ohiN
0?n8F0050?n;FP030?n<G03oRe/0ohUI00@0oh]J00d0ohUI0?n=GP3oQeL0oi5T0?n<G03oS5d0ohaK
0?nAGP3HF3T02@@203PA3@3oGT/0og5K00<0ofaH00<0ofeG0?m`F`3oKEL01@3oK5P00`3oK5L0ofeG
0?m^F@060?m/F0030?m^F@3oK5D0ofaH00<0ofaH00P0ofeH0?mbG02mA3H020<20000000E1`H0hT91
0?mJF@D0oeME00@0oeID0?mIE`3oEeD0oeED1`3oEeD00`3oFEP0oeYH0?mGE@070?mGE@050?mFE@3o
EeD0oeaJ0?mGE@3oEeH01`3oEeD01@3oEUD0oeID0?mMF`3oEE<0oeQF00X0oeME00H0oeED0?mKF@3o
EeD0oeUH0?mDD`3oEUD90?mGE@80oeED00D0oe]I0?mHEP3oF5L0oeED0?mFE@0;0?mGE@050?mFE03o
FeT0oeaJ0?mFE03oFEL00P3oEE@50?mGE@0:0?mFE@3oF5H0oe]I0?mHEP3oFEP0oeaK0?mCD@3g>SP0
Ma`K01P41080000000L070`508Xm7P3QICD0oh550?nUF03oZ5`0oj=I00h0oj1F00P0oj1E0?nPEP3o
YV40oj5F0?nSG03oXU/0oj1F0?nPEAH0oj1F00L0oj1E0?nOE@3oYEl0oj=M0?nOE03oXU/0oj1G0080
oj1E6`3oX5H02@3oX5D0oj1F0?nPE@3oY5h0ojIQ0?nPE@3oXU/0ojEO0?nPEP020?nPEB<0oj1F01<0
oimD0?nPE@3oX5H0ojYT0?ndM03o/6d0ojaV0?nSF`3oXeT0oj=K0?nRFP3oWeP0oiYF0?nPF@2PDBd0
000002DD203oWcT0omVc0?l0ooooV@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOW0?ooo`080?oMf020A2@0NClM08=58@1f?A`0LS/K08537`2bGc030;IS=`03
0;UU>@2hI3T0]V<g0080]V<g00D0]V<f0;QT=`2mJ3l0ih]:0?noG00T0?nkF`090?nlGP3o_5d0okaK
0?noHP3o_V40ok]J0?nmGP3o_V40ok]I01l0ok]K00L0okaM0?nlG03o_5d0okmR0?nlF`3o_5X0okiP
00l0ok]K00D0okeN0?nkF@3o_V00okeO0?nlF`050?nkF`080?nkG03o_5d0okaL0?noHP3o_5/0ok]J
0?nmG`3o^eXC0?nkF`070?nmG@3o^e/0ok]K0?nnGP3o^eX0okiQ0?nlF`0@0?nkF`80okeM00@0okmR
0?nlF@3o_Eh0ok]J2@3o^e/02P3o_5`0okaM0?nmG@3o^eX0okaL0?nlF`3o_f80okaJ0?nmG`3o_5`;
0?nkF`050?nlG03o^e/0okeM0?nlG03o_Ed02P3o^e/01@3o_5`0okeM0?nlG03o_5h0okaL00T0ok]K
00@0ok]L0?nlGP3o_5d0okaL203o^e/0103o_5`0ok]K0?nmGP3o_5d40?nkF`0:0?nlF`3o`5d0mZaD
08eH:`0j7`l01P<206@/7@3VLDT0ohYJ0?n;F`@0oh]J00<0ohYJ0?n=G@3oSEd01`3oReX00`3oSEd0
oheN0?n;FP050?n;FP030?n;F`3oRUT0ohaK00L0oh]J00<0oh]K0?n:F@3oReX01@3oReX00`3oS5`0
oh]J0?n;FP050?n;FP030?n<G@3oReX0oh]J00<0oh]J00<0ohYJ0?n<G03oRe/0103oReX00`3oRUX0
oheM0?n<G0040?n;FP80ohaL00<0ohYI0?n6E@3oOTd00P3oNDP01`3oOTd0ohMH0?n;FP3oS5/0ohYJ
0?n;FP3oRUT00P3oT6<01P3oRUT0oga<0?mgA`3oODd0ohYJ0?n<G0D0oh]J0P3oRUT50?n;FP80ohYI
00d0oh]J0?n<F`3oS5/0ohYI0?n3D`3oMdT0ogQ80?meAP3oOdh0ohEF0?n;FP3oRe`0ohaM0080oh]J
0P3oS5/03`3oRUX0oh]K0?n8E`3oQUH0oh5@0?n0C`3oOD`0ogU90?mgA`3oNTX0oga;0?n0C`3oQ5<0
ohIE0?n8E`020?n;F`D0oh]J00<0oh]K0?n;FP3oReX0103oReX03@3oSV00ohYI0?n>G`3oRUT0ohaL
0?n;F`3oS5/0jW5:078]7P091080GR0I0?mVDP3oKeX00P3oK5P0103oK5L0ofiI0?m`F`3oKET40?m/
F0040?m]F03oKeX0og5L0?m]F0D0ofaH00@0ofiJ0?m^F@3oKUX0ofeH0P3oK5P02@3oKUT0ofYE0<9>
?P22:20040D405`G5P2`=SD0odi>0?mHE`030?mGE@050?mFE@3oEeH0oeUH0?mFE03oF5H01P3oEeD0
103oF5H0oeUH0?mKF@3oEUD70?mGE@060?mFE03oFeT0oeUH0?mGE@3oF5L0oeIE1P3oEeD01P3oEU@0
oeUG0?mIF03oEUD0oeQF0?mFE@P0oeME00D0oeQF0?mGEP3oF5H0oe]I0?mHE`0:0?mGE@040?mFE@3o
FUP0oeID0?mNG080oeQF00<0oeIE0?mGE@3oEeD02@3oEeD20?mIE`040?mHEP3oFUP0oeQF0?mHEPL0
oeME01<0oeMF0?mHEP3oEeH0oeID0?i;BP2]>ST0QR@S03d>3P0R20P03@8203LH3020>al0VE@/0<e`
>P3oTTh0oiiD0?nTF@3oXeT0oj5G00`0oj1F00P0oj9H0?nTG03oX5D0oj9J0?nRF@3oXEH0oj5H0?nP
EaH0oj1F00H0oimE0?nTG03oWe@0oj5I0?nUG`3oX5L20?nQF1`0oj1F00L0oj1E0?nTF`3oXEP0oiiC
0?nTG@3oXe/0oj5F0080oj5H00<0oj1G0?nPEP3oX5H08@3oX5H02@3oXEH0oj=K0?nUG@3oWeD0oj5H
0?nUH03oXUX0oj1E0?nVGP020?n`J`0=0?n[I03oX5P0oj5I0?nQF@3oXUX0oj9K0?nPF@3IMD40:Q8;
03lX3P2XKRT0ok510?oFZ03o0?oooiT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWi`3oool0203o_JL0Od<Q07Hm7023A1l0MchK07@l702PE2H0]60]102fHcL0
0`2iICT0^6@h0;IS=`020;IS=`070;ER=`2bH3D0ojeC0?nkF`3o_5`0okaM0?nkG0020?nkF`030?nk
FP3o^e/0ok]K0280ok]K0P3o_5`00`3o^UT0ok]K0?o1I`020?nkFP030?nlG@3o_5`0ok]K01h0ok]K
00D0okaL0?nkFP3o_Uh0ol5X0?nlF`020?nlG0D0ok]K00D0okaL0?njE`3o`6H0okiN0?nlF`0?0?nk
F`060?nlF`3o_EX0ol5V0?nmH03o_5/0okaL503o^e/01P3o_5`0ok]H0?noH`3o^eX0okaL0?nkG140
ok]K00@0okaM0?nnH`3o_5`0okaL203o^e/00`3o_Ed0okeP0?nkFP040?nkF`040?nlG03o_V<0ok]H
0?nlG0d0ok]K00<0okiS0?nkFP3o^e/02`3o^e/00`3o_El0okYJ0?nlG00:0?nkF`030?njF@3o_640
ok]K00T0ok]K00<0okeP0?nlG@3o^eX0103o^e/02@3o_5/0okmL0?nnG03LM3X040P40000001]:a`0
ogYA0?n=G0050?n;FP030?n=GP3oS5/0oh]J00L0oh]J00<0oh]K0?n;FP3oReX01P3oReX00`3oS5`0
oh]J0?n;FP040?n;FP030?n<F`3oSEh0ohYI00D0oh]J00<0ohaL0?n=GP3oRET01@3oReX20?n:F@H0
oh]J00<0ohYI0?n;FP3oReX00`3oReX00`3oS5/0ohYK0?n;FP030?n;FP060?n:F@3oOTl0ogI70?mg
AP3oNTT0ohAC0P3oRUT00`3oT680ohYI0?n;FP030?n;FP80ohUH00H0ohAD0?mgAP3oNdX0ohYI0?n;
FP3oREP50?n;FP80ohYI103oReX00`3oRUT0ohUH0?n;FP040?n;FP090?n:F@3oReX0ohUI0?n0D03o
MdL0ogQ70?mhB03oP540ohYI00@0oh]J00<0ohYK0?n?H03oRUT0103oReX0303oS5`0ohIE0?n1D@3o
O4/0ogU80?mhA`3oMdH0ogM70?miB@3oPE40ohIE0?n:F@80oh]J00<0ohYK0?n?H03oRET00P3oRU/0
1@3oREH0ohmQ0?n;FP3oSUl0ohUH00<0oh]J00L0ohaK0>U_B@040@40000003hC3`3oIU80ofiH0080
ofaH00<0ofeH0?m^F03oKET01@3oK5P00`3oK5L0og5L0?m`F`060?m/F0030?mbGP3oKEP0ofaH0080
ofaH00T0ofiH0?m_FP3kGD/0;0h;000000000040ZR`/0?mIF03oEeH0103oEeD00`3oEE@0oeUH0?mF
E0070?mGE@040?mEE03oFEP0oe]I0?mHEPP0oeME00<0oeeK0?mIE`3oEeD02@3oEeD00`3oFEL0oe]J
0?mFE0090?mGE@80oeQF00<0oe]I0?mIE`3oEeD02P3oEeD01@3oF5H0oeEC0?mMF`3oFeT0oeID00/0
oeME00D0oeIE0?mHEP3oF5H0oe=B0?mKF@0:0?mGE@0>0?mHEP3oF5L0oeMF0?mDDP3oCdd0XBPW0183
0`050@00000000<1000m70h0YTHS0?mn@`3oWeH30?nRE``0oj1F0P3oX5L01@3oWU<0oj9I0?nUGP3o
X5D0oj1G01L0oj1F00L0oj9I0?nPE`3oXEL0ojUT0?nPEP3oX5D0oj5H01`0oj1F00P0oj1G0?nQF@3o
X5H0oj5H0?nXH`3oXUT0oj5E0?nPEbD0oj1F00L0oj9I0?nPE`3oWe@0ojIP0?nZJ03oXEP0oj1F0080
oj1G1@3oX5H0103oX5D0ojaV0?n`JP3oYf030?nPF0090?nQF@3oXe`0iF@g0081000`8@`0omY>0?oD
C03o^T@0omFU0?l0ooooV@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOW0?ooo`080?nWRP20@b00MchL07e17@1a>QX0PT8N0:MG9`2cGR`40;IS=`030;QT=`2h
I3P0]V<g0080]V<g00X0[Ehe0>1h@P3o^E/0okYH0?noI03o`FT0okaL0?nkF`3o_5h0okeQ0P3o^e/2
0?nkFRD0ok]K00D0ok]J0?nkF03o`FT0okeO0?nkF`020?nlGP030?nkF`3o^eX0ok]J01d0ok]K00@0
ok]J0?noI03o`6H0ok]J0`3o_5`00`3o^eX0okeO0?nkFP0F0?nkF`050?nlGP3o_f@0okYI0?nmG@3o
_5/00P3o^eXB0?nkF`030?nkF03o`FD0okeP0080okaL00<0ok]K0?nkFP3o^e/03P3o^e/01@3o^UT0
okeO0?nkFP3o_5h0ok]J00H0ok]K00<0ok]L0?nlF`3o^e/0103o^e/0103o^eX0okaM0?nnH`3o_5d=
0?nkF`050?nkFP3o_Uh0okeM0?nkG03o^eX02P3o^e/00`3o_f<0okYI0?nlG00:0?nkF`80okeM2@3o
^e/0103o^UT0okeR0?nlG03o^eX50?nkF`080?nnG@2_Ic4020D20000000S3PP0lg=;0?n?G@3oS5/4
0?n;FP030?n9F03oRe/0oh]J00H0oh]J00<0ohaL0?n<F`3oReX01P3oReX00`3oRUT0ohaL0?n;FP05
0?n;FP030?n;G03oSUl0ohYI00`0oh]J00<0ohaK0?n;F`3oReX0103oReX00`3oRET0oheM0?n;FP04
0?n;FP0;0?n9F@3oSUl0oh]K0?n<F`3oReX0ohQG0?mlC03oMDD0ogM60?mjB@3oQUD00`3oReX00`3o
REP0oh]J0?n;FP040?n;FP040?n:F@3oO4d0ogQ70?n5E080oh]J00<0ohUH0?n;FP3oReX00`3oReX2
0?n:F@@0oh]J00<0ohaL0?n>G`3oReX0103oReX03`3oSV00ohYI0?n;FP3oR5X0oh=C0?mjB@3oMTH0
og530?moCP3oREP0oh]J0?n<F`3oReX0ohiO0?n:F@050?n;FP090?n<F`3oReX0oh]J0?n;FP3oREP0
oh5A0?mkBP3oN4P0ogU80080ogM600H0ogQ70?moD03oQeH0ohYI0?n9F03oRe/20?n@HP040?n:F@3o
RUX0ohYI0?n<G0<0oh]J0P3oS5/01@1X:Q`00000048D3`3oG4T0og1J00<0ofaH00<0ofeH0?m]F@3o
K5P01@3oK5P00`3oK5H0ofeI0?m/F0050?m/F0030?m^FP3oKUT0ofaH0080ofaH00P0ofmJ0?mbG03o
I500AQLB0000000O1`L0[b/Z0?mGEPD0oeME0`3oF5H60?mGE@030?mEE03oFEL0oeQF00T0oeME00<0
oeQF0?mJF@3oDe80203oEeD20?mHEP030?mIF03oEU@0oeME00P0oeME00D0oeED0?mGEP3oFeT0oe]J
0?mEE00:0?mGE@050?mEE03oFEP0oeUG0?mIF03oEE@02`3oEeD01P3oEE@0oeME0?mFE@3oGEh0oeaJ
0?mEE0T0oeME00h0oeUG0?mKFP3oEeH0ode<0>Hi>01/6aX03001000000020000:18905h[5`25?B40
ojYO0?nSF@80oj5F303oX5H01P3oX5D0oj9I0?nRFP3oXEP0ojMQ0?nNDaP0oj1F00H0oj9I0?nQF03o
XED0ojUS0?nTGP3oWe@L0?nPEP080?nPE@3oXET0oj5J0?nPE@3oY5d0ojQT0?nSFP3oX5DQ0?nPEP0;
0?nOE@3oX5H0oj1F0?nPEP3oXEX0oj5H0?nND`3oXeX0ojUS0?nSF`3oX5D0303oX5H00`3oYf00ok1Z
0?nSF`030?nPF0090?nRFP3ZISP01@810000002ON2`0oomQ0?oAB`3o^T@0omZU0?l0ooooV@3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOW0?ooo`080>Z9HP1o
@Ql0MchL07a0701_>Q/0STTP0:eJ9`2_G2T30;IS=`030;MS=`2kIS/0_6Ll0080]V<g00D0]F8g0;1P
=P3oTT/0ol1M0?nkF`020?nkFP80ok]K00L0ol5U0?o2J`3o_5X0okaL0?nnHP3o_F40ok]K00<0ok]J
8`3o^e/00`3o^eX0ok]K0?nkF`020?o1I@060?nkFP3o_F80okeQ0?nkFP3o^e/0ok]J6`3o^e/02@3o
^eX0okaI0?nkFP3o`6D0okaM0?nnGP3o_V80okaN0?nkF`020?nkFQD0ok]K0P3o^eX01P3o_f<0okaL
0?nmH03o_Eh0ok]K0?nkFQ40ok]K00P0ok]J0?nkF`3o_Eh0okiN0?nkF`3o_Eh0okaK0?nkFPh0ok]K
00D0ok]J0?nkF`3o_f@0okYH0?nmG@020?nkFP@0ok]K0P3o_Ed60?nkF`030?nkFP3o_Ul0okYI0080
okeM00<0ok]J0?nkF`3o^e/02@3o^e/0103o_Eh0okeM0?nmG@3o_5`90?nkF`050?nkFP3o_5d0okeN
0?nlG@3o^eX02@3o^e/30?nmG@030?nkFP3o^e/0ok]K00D0ok]K00@0ok]J0?nlG03o_Uh0ok]J1@3o
^e/0203o_U/0`fTb02hG30000000@AXA0?mbB`3oT5h0oh]K103oReX00`3oSEd0oheN0?n:F@060?n;
FP040?n9F03oS5/0ohaL0?n:FP@0oh]J0P3oRUT00`3oS5/0oh]J0?n;FP030?n;FP030?n9F@3oRe`0
oh]N00D0oh]J00<0ohYI0?n9F03oR5P0103oReX00`3oRUX0oheN0?n=GP060?n;FP030?n:F@3oReX0
oh]J00<0oh]J0P3oS5/01`3oR5L0oh=B0?mkBP3oMTH0ogY90?n5E@3oS5/01@3oReX00`3oRe/0oh]J
0?n;FP020?n;FP040?n;G03oQUH0ogQ70?mnCP<0oh]J00<0ohUH0?n:F@3oReX00`3oReX00`3oRU/0
ohYJ0?n;FP030?n;FP030?n?H03oU6P0ohQH00@0oh]J00L0ohmQ0?n:F@3oReX0oh]J0?n<F`3oR5P0
ogm?0080ogE600H0og]:0?n3DP3oREP0ohaK0?n>H@3oRET40?n;FP030?n:F@3oS5d0oh]J0080oh]J
0180oh]K0?n<F`3oS5h0ohUH0?n2DP3oODd0og]:0?mhA`3oMdH0ogI50?miB03oODh0ohIF0?n7EP3o
RUT0ohaK0?n<G03oS5/30?n;FP080?n<F`3oSE`0c58e000000145Q80oee:0?mdG@3oKEP20?m/F003
0?m^F@3oKUP0ofaH00D0ofaH00<0ofmJ0?m^F03oK5P0103oK5P00`3oKET0og1K0?m^F@030?m/F008
0?m`FP3oKUT0oTlo03`B3P000000C18B0?m2@@3oG5X40?mGE@040?mGEP3oEU@0oe]J0?mEE0D0oeME
00D0oeED0?mHEP3oEE@0oeUG0?mEE0060?mGE@050?mFE@3oFEP0oeME0?mLFP3oEE@0203oEeD20?mH
EP030?mKF@3oEUD0oeME00P0oeME00<0oeYH0?mFE03oFEP02P3oEeD01P3oEE@0oeMF0?mHE`3oDe80
of5P0?mFE0/0oeME00H0oeIE0?mHE`3oF5H0oeME0?mKFP3oEE@80?mGE@070?mFE@3oFEP0oeaJ0?mA
CP3oA4@0ac4`03D<30020000000900<1001@91@0^E@]0?n7B@3oZ5`0ojUL0?nPEP3oXU/0oj1G00T0
oj1F00T0oj1E0?nOE@3oX5H0oj9K0?nND@3oXed0ojIP0?nPEP3oX5D0503oX5H01`3oX5D0oj1F0?nR
FP3oXET0oiiB0?nSG03oXe/00`3oX5DH0?nPEP0;0?nPE@3oX5H0oj1F0?nRFP3oXU/0oiiC0?nUGP3o
Yf80oj5G0?nOE@3oX5D0803oX5H0303oX5D0oj1F0?nOE03oXEX0oj9L0?nOE03oXED0ojMQ0?nTG@3o
X5D0oj1F0?nPE@X0oj1F0P3oX5D01@3oXUX0oj5E0?nPEP3o[VP0oj5J0080oj5I00X0oj1H0?n<CP03
0@40000001dD203ohED0oo]L0?oEC`3o^T@0ombWo`3ooonI0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinL0oooo00T0eWiJ07i17`1g?Q`0MSdL08137`2UERH0
]5hY0:iK:02dH3400`2fHcL0202oJSl0^fLk0;UU>@2fHcL0[f0e0>Un@P3o^eh0okaL1P3o^e/03@3o
_5X0ok]K0?nlG03o_V00okeP0?nkFP3o_F00ol1V0?nmH@3o^e/0okiO0?nnH03o_Ed00P3o^e/00`3o
_5X0ok]K0?nkF`0P0?nkF`80okeP00L0ok]J0?nmG`3o_V<0ok]K0?nkF@3o_El0okaL0080ok]K00<0
okaK0?nkF`3o^e/04@3o^e/01@3o_5d0ok]J0?nmH@3o_5`0okeL0080ok]K0P3o_5h01P3o_5/0okiS
0?nnH03o_5`0okiO0?nlFaH0ok]K00L0okeO0?nmGP3o^e/0okiR0?nkF03o_Ed0okiO0180ok]K00L0
okaL0?nmGP3o_5d0okiR0?nkF`3o_5h0okaL00l0ok]K00D0okaM0?nmG@3o_F40ok]K0?nmGP030?nk
F`030?nlF`3o_Eh0okaM00L0ok]K00H0okaM0?nmF`3o_El0ok]J0?nlGP3o^e`:0?nkF`050?nlGP3o
_5l0okaL0?nlGP3o_5`0203o^e/01@3o_5d0okaL0?nmG`3o_5`0okaM00P0ok]K0P3o_5`00`3o_E`0
okaL0?nkF`070?nkF`040?nmGP3o^eX0okeN0?nlG0<0ok]K00T0okaL0?o1GP3o/5L0/G@i03HM3P0F
2@H0L2`M0<IR@03oREX0103oReX0103oSEd0ohaL0?n<F`3oS5/60?n;FP030?n=G@3oRe`0oh]J00D0
oh]J00<0ohYI0?n<F`3oRe/0103oReX0103oRUX0oh]K0?n=G@3oRUX40?n;FP030?n:FP3oRe`0ohaL
00D0oh]J00<0ohaK0?n<G03oReX00`3oReX20?n<F`<0oh]J00/0ohaK0?n;FP3oR5L0ogm?0?miB03o
N4L0og];0?n3DP3oRET0ohmP0?n<G0040?n;FP80oheM00P0ohYJ0?n;FP3oReX0ohaK0?n:F@3oMDP0
ogQ90?n:F@<0oh]J00<0ohUH0?n:F@3oReX00P3oReX00`3oRUT0ohmR0?n>H0040?n;FP030?n>GP3o
TF@0ohUI00@0oh]J00<0ohYI0?n;FP3oReX00P3oReX02`3oRe/0oi1S0?n<G03oPe80og];0?mhA`3o
N4T0oh5B0?n7EP3oRUX0ohaK00<0oh]J00<0ohiO0?n<F`3oReX0103oReX02`3oS5`0oh]J0?n<F`3o
SEh0ohMF0?n<G@3oR5P0oh1@0?mmC03oNd/0ogU80080ogU90180og];0?n0D@3oQUD0ohMG0?n9F03o
SU`0mGM>06HZ6`000000Hb8K0?mYE03oLE/0ofeH0?m/F03oKUX0ofmJ0?m^F03oKEP40?m/F0040?m^
FP3oLE`0ofiI0?m]F0<0ofaH0P3oKET03@3oL5/0ofiI0?m/F03oK5P0ofeI0?m`FP3=CCl0CAPC00@2
0@0_30`0/C8b0?mFE03oF5L00`3oEeD01@3oF5L0oeUG0?mIE`3oEU@0oeIE00D0oeME00@0oeQF0?mI
F03oEU@0oeQG1@3oEeD00`3oEUD0oeQF0?mGEP020?mIE`030?mFE03oEUD0oeME00@0oeME00H0oeQF
0?mHE`3oEeD0oeUG0?mHEP3oEUD60?mGE@070?mFE@3oEeD0oeYI0?mHE`3oEeD0oeQG0?mHEP090?mG
E@070?mIF03oEUD0oe]I0?mHEP3oF5L0oeME0?mFE@090?mGE@040?mIF@3oEeH0oeUG0?mIE`80oeQG
1`3oEeD04@3oF5H0oeYH0?mHEP3gBdX0bT500:P`<@1a71`0<@`<00<1000U4@X0H2`H0:=G;`34Lch0
jhM90?nNEP3oYUX0oj9G00@0oj1F00<0oj5I0?nQF03oX5H0103oX5H0203oX5L0oj=K0?nPEP3oY5h0
oj=K0?nQEP3oXUX0oj1E503oX5H02@3oX5L0oj=K0?nQE`3oXUX0ojEO0?nRE`3oXUT0oj5H0?nPE@0I
0?nPEP070?nQF03oXe/0oj5G0?nOE03oY5h0oj5G0?nPE@020?nRFB80oj1F0P3oXUT20?nPE@050?nU
G`3oX5D0oimD0?nRF@3oXeX03`3oX5H00`3oXUT0oj1F0?nSG0020?nRF@0@0?nPEP3oWeH0ojAL0?nP
F@3oXUX0ojEM0?nGE01C9QD0000008EI803oee80ooYM0?oiF`3omEP0olI70?o=R_l0ooooV@3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOW0?ooo`0C0;5UA@23
@b00MSdK07<l6`2>BB40/5/W0:]J9P2[FBL0/5`Z0;QU>P2gHcH0]V<g0;ER=@2bH380^6@g0;ER=`3<
Kcd0ojmJ0?nnF`0=0?nkF`0<0?nkFP3o_5T0ok]J0?nkF`3o_F40okiR0?nmG@3o^eT0okmT0?o2JP3o
_5T0ok]K0P3o^eXR0?nkF`080?nkFP3o^e/0ok]J0?nnH03o_5`0okYI0?nnH@3o_f<30?nkFPd0ok]K
00H0okYI0?o0IP3o_5/0okaM0?nlF@3o^eX70?nkF`80ok]J00D0okaN0?nmH@3o^UT0ok]L0?noI003
0?nkFQ@0ok]K0P3o^eX01P3o_Ed0okeQ0?nmG03o`6L0okaI0?nkFQ40ok]K00L0ok]J0?nkF`3o_5h0
okaL0?nnH`3o_Ed0okaI00h0ok]K0P3o^eX00`3o_5d0okaL0?o1I@030?nkF`030?nlG@3o_5/0ok]J
00P0ok]K00D0okaL0?nlGP3o^eP0okeN0?nkFP0:0?nkF`050?nkFP3o_F00ok]K0?nmH@3o^eX0203o
^e/01@3o^eX0ok]K0?nmG03o_V80okYI00T0ok]K00<0okaL0?nmG@3o_F002@3o^e/00`3o_Ed0okaM
0?nkFP040?nkF`030?o3GP3o[U@0ISHL0080000000@0QcDS0?n>G@3oRe/0ohUJ103oReX00`3oSEl0
ohUH0?n;FP050?n;FP030?n;G03oRUT0ohYI00D0oh]J00<0oh]K0?n?H03oReX01P3oReX00`3oS5`0
oh]J0?n;FP030?n;FP030?n:F@3oS5`0oh]J00D0oh]J00<0oheM0?n;F`3oReX00`3oReX0403oR5P0
ohiO0?n;FP3oReX0oh=B0?mlC03oN4L0ogE60?n0D@3oQeH0oh]J0?n<F`3oReX0ohYI0?nCIP3oRe/4
0?n;FP080?n9EP3oRUT0oh]J0?n<F`3oRUT0oge=0?mcA03oPe840?n;FP030?n9F@3oReX0oh]J0080
oh]J00<0ohYI0?n>H@3oSV00103oReX00`3oREP0ohUF0?n;FP030?n;FP030?n:F`3oSUl0oh]J00<0
oh]J00l0ohYI0?n<G03oReX0oh]K0?n;FP3oQeH0ogm@0?mfAP3oN4L0oga<0?n4DP3oReX0ohYI0?n@
H@3oRUT0103oReX02@3oRe/0oh]L0?n<G03oTVD0ohYI0?n?H03oReX0ohUH0?n:F@030?n<F`0=0?n8
E`3oQ5<0oh1A0?mkBP3oMdH0ogI50?mgAP3oNDP0lfi401X:1P000000BAHC0?mZE@030?m/F080ofmJ
00<0ofeH0?m/F03oK5P00`3oK5P00`3oKUX0ofmJ0?m/F0050?m/F0030?m`F`3oK5P0ofaH0080ofaH
00P0og9K0?mYE027:R802P<300`30`2l;Rd0oe9A0?mJF0<0oeME00D0oeQF0?mJF03oFUP0oeME0?mF
E@040?mGE@040?mEE03oFEL0oe]I0?mHEPP0oeME00<0oeUH0?mHE`3oF5L01`3oEeD01@3oEE@0oeYH
0?mFE03oFEP0oeAC00P0oeME00D0oeQF0?mKFP3oEeD0oeaJ0?mFE@080?mGE@80oeED00D0oeQF0?mI
E`3oFeT0oeME0?mEE0090?mGE@80oeED00H0oeQF0?mIF03oFeT0oeQG0?mEE03oEUD70?mGE@060?mI
F03oG5X0ode=0>@i>01X6aX04`D50P0000001`0Y4`/0^E@]0?mg@@3oS4`0ojMJ0?nVFP3oXUL0203o
X5H00`3oX5D0oj9I0?nPE`020?nPE@050?nSF`3oXeX0oj1F0?nSG@3oX5L00P3oX5DB0?nPEP0:0?nP
E@3oX5H0oj1E0?nUG`3oX5D0oj1F0?nTG@3oXEP0oimE0?nPEAL0oj1F0`3oX5D01P3oYEl0ojQR0?nQ
EP3oXEL0oj=M0?nPEP80oj1E7`3oX5H01`3oX5D0oj1F0?nOE03oXe`0ojMR0?nNDP3oXEH00P3oXe/0
0`3oX5D0oj1F0?nPE@0>0?nPEP080?nPE@3oWe@0ojIO0?nSF`3oWe@0oj5J0?nPEP3oX5D30?nPEP09
0?nOE@3oTTP0oiaF0?nVGP3oQDX0BAlA0000003RUcH0oomL00<0ooQJ00<0ooYK0?o8B@3o_f/0o`3o
oonI0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinL0oooo
0180/FA307Y07P1d?A/0NClL0:9C9P2`FbL0[EXW0;5L:02]FRL0]64e0;UU>P2gHcL0]F8f0;iY?`2h
I3P0]V<i0>Ul@P3o`ehB0?nkF`80ok]J0P3o^e/0203o_Eh0okeQ0?nkFP3o^eX0ol5/0?o0H`3o^UT0
ok]J9P3o^e/01P3o_Ed0okeN0?njE`3o_V80ol1X0?nlG0X0ok]K00@0okYI0?nnHP3o^eX0okiN3P3o
^e/0203o^eX0ok]K0?nkG03o_El0okYI0?nnHP3o`FL0okaK5P3o^e/01`3o^eX0okaL0?nmH03o_5T0
ok]J0?noH`3o^UT04`3o^e/01@3o_Ed0ok]K0?nmG@3o_V40ok]J00l0ok]K00P0okaL0?nmG@3o^eX0
okiR0?nlF@3o^eX0ok]L0?nmG@X0ok]K00D0ok]J0?nlG03o_V80okaL0?nkFP090?nkF`060?nkFP3o
^e/0okaM0?nmGP3o_Ed0ok]J2@3o^e/20?nlG0030?nmH@3o^eX0ok]K00T0ok]K00<0okeP0?nlG03o
^e/01`3o^e/00`3o_Ed0okeP0?nlG0040?nkF`080?o1GP3o/5L0cfhe014:10070P80R3HS0?n1E@3o
Sed40?n;FP030?n<F`3oSUh0ohaL00H0oh]J0P3oS5`50?n;FP030?n:FP3oReX0ohaO00H0oh]J00<0
ohYI0?n<G03oReX0103oReX00`3oRUT0ohUH0?n;FP040?n;FP030?n:F@3oRe/0oh]J00@0oh]J00T0
oh]K0?n9F03oP4l0ogQ70?mgAP3oMdL0oh=C0?n8E`3oS5/0103oReX00`3oS5`0oh]J0?n;FP030?n;
FP080?n@H`3oRe`0oh]J0?n;FP3oPE40ogE60?miB03oREP30?n;FP040?n:F@3oT6<0oi5S0?n:F@80
oh]J00<0ohYI0?n>H@3oSV00103oReX00`3oREP0oh]J0?n;FP030?n;FP030?n:F`3oSV00oh]J00<0
oh]J00d0ohiO0?n:F@3oReX0ohYI0?n;FP3oRe`0ohYI0?n4E03oN4L0ogM60?mhA`3oP500ohYI00H0
oh]J00D0ohaM0?n9F03oReX0ohaN0?n;FP020?n:F@030?n;G03oRe/0oh]J0080oh]J0140oh]K0?n=
G03oRUT0ohUH0?n7EP3oOdl0og]:0?mkB@1f;1X0000004LC3P3oD3`0ofI?0?mXD`3oK5P0ofiH0?m`
F`060?m/F0030?m`F`3oKUT0ofaH00@0ofaH00<0ofeG0?maG03oKUT00`3oK5P0203oL5X0oTlo048E
4@0000008`P90?m1?`3oFEL0oeUH0`3oEeD00`3oEE@0oeQG0?mHEP060?mGE@030?mFE03oGE/0oeUG
00T0oeME00<0oeYH0?mHEP3oEeD01`3oEeD0103oDe80oeiM0?mHEP3oEE@80?mGE@060?mFE03oFEL0
oeMF0?mHE`3oEeD0oeED203oEeD01P3oEE@0oeeN0?mHEP3oEE@0oeQF0?mEE0X0oeME00H0oeID0?mS
H@3oF5H0oeED0?mGEP3oEE@70?mGE@070?mFE@3oEeH0oeUG0>e3@P1W6AT0<@/;0184100200000007
04XU502fDR`0ohM90?nQEP3oYe/0ojAJ0?nQE`0;0?nPEP080?nPE@3oXUT0ojMR0?nOE03oXUP0oj1G
0?nPEP3oX5DD0?nPEP050?nQEP3oZ680oj=J0?nQE@3oXUX00P3oX5H00`3oX5D0oj1F0?nPEP0G0?nP
EP060?nQE@3oY5h0ojQS0?nPE@3oXeX0oj=K0P3oX5H00`3oX5D0oj1F0?nPEP0N0?nPEP0:0?nOE03o
X5H0ojQS0?nPEP3oWe@0oj5I0?nSF`3oX5D0oj1F0?nOEA40oj1F00D0oj1E0?nTGP3oXEP0oj=J0?nP
E`070?nPEP090?nLD@3oTTH0oj1G0?nBD@1T;1P0000007A>703ooe`0ooYJ00@0ooQJ00<0onQD0?nf
F03oool0o`3ooonH0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWinL0oooo0180XU`l074k6`1d?1/0OD4M0:MF9P2^FbL0[EXW0:mL:@2]FRL0[E`[0;=S>@2hI3P0
]F8f0<A^A02iICX0_FLj0?nYFP3o_U/G0?nkF`0<0?nkFP3o^e/0ok]K0?nlGP3o_5`0ok]K0?nlG@3o
`FT0ol1V0?njF03o^e/0okaL903o^e/0203o_5`0okeM0?nkFP3o_F40ol9Z0?nnGP3o^eX0okaL0`3o
^e/0103o_Ed0okmT0?nlG03o_5`E0?nkF`070?nlG03o_Ed0ok]K0?o1I`3o_f@0ok]J0?nlG00D0?nk
F`030?nkFP3o^e/0ok]K0080okaL00<0ol5X0?nlG@3o^eX04`3o^e/0103o_5`0okeM0?o1I`3o^UL>
0?nkF`090?nkFP3o^e/0okaL0?nmH@3o_V<0okYI0?nlG03o_F00ok]J00X0ok]K00@0okaL0?nkF`3o
_V80okaL2`3o^e/0103o^e`0okYI0?nlH@3o_5`;0?nkF`030?nmG`3o^eX0ok]K00P0ok]K00<0okaK
0?nmH03o^UT02@3o^e/00`3o_F00ok]J0?nkF`030?nkF`080?noG@3o_5/0oiA802HE2P000000<Q@>
0?5P?`3oSE`40?n;FP030?n:F@3oSf00oh]N00H0oh]J00<0ohYI0?n;FP3oReX01P3oReX00`3oSUl0
oh]J0?n;FP040?n;FP030?n:F@3oS5h0oh]J00@0oh]J00<0ohaK0?n:F@3oReX0103oReX00`3oSEh0
oh]J0?n;FP030?n;FP080?n4D`3oMdT0ogQ70?mhA`3oOTh0ohQG0?n9FP3oTF<50?n;FP030?n:F@3o
SEd0oh]J00<0oh]J00P0oi9T0?n;G03oReX0ohYI0?miB03oMTD0ogm?0?n:F@<0oh]J00@0ohYI0?nA
I@3oTF@0ohYI0P3oReX00`3oRUT0ohiQ0?n>H0040?n;FP030?n<G03oReX0oh]J00<0oh]J0P3oRUT4
0?n;FP0D0?n?HP3oReX0oh]J0?n;FP3oRUT0oh]J0?n<G03oReX0ohQG0?moC`3oMdH0ogQ70?mhBP3o
Pe<0oh]J0?n;F`3oRUT0oi5S0?n?H03oS5d40?n;FP030?n9F@3oSEh0oheN00@0oh]J0140ohYI0?n<
G03oS5`0oh]J0?n<F`3oReX0ohiL0>QL>`090`80BQ@?0?m@?03oGdL0oeY50?mKAP3oG4L0of1:0?mX
D`040?m/F0030?m]E`3oLE`0ofmJ00D0ofaH00<0og1K0?m_FP3oKUT00P3oK5P02@3oKeT0ofmJ0<e=
?@0?10@0000000X3103D?C`0oeIF0?mHEP030?mGE@030?mHEP3oGUd0oeID00H0oeME00<0oeED0?mJ
F03oEU@0203oEeD00`3oFEL0oeQF0?mHEP070?mGE@030?mEE03oFUT0oeUG00X0oeME00@0oeUH0?mN
GP3oEE<0oeQF2P3oEeD00`3oEeH0oe]J0?mHEP0<0?mGE@040?mED`3oFEP0oe]J0?mHE`L0oeME00P0
oeIE0?mHEP3oEeH0oeME0?m<C03?<S80HQLI01<30`80000000L020<008`o8P3oSD`0oiUB0?nNE@3o
XeT0oj9G00/0oj1F00H0oj5H0?nND`3oXUX0ojAM0?nPE03oXeXE0?nPEP070?nPE`3oXED0ojAM0?nX
H`3oX5H0oj9I0?nQF00I0?nPEP080?nPE`3oX5H0oiiC0?nTGP3oYEh0oimD0?nPE`3oXET20?nPEP03
0?nOE@3oX5H0oj1F01/0oj1F00T0oj1G0?nQF03oX5D0oiiC0?nXHP3oXUX0oiiC0?nPEP3oXET05@3o
X5H0103oXEP0oj9I0?nSG03oWU<20?nPE`L0oj1F0P3oXUL02@3oUT/0oi=60?nFC`1l=Qd000000081
003F]D80oo]K0?oiF`040?ohFP030?oiFP3o^UH0oooo0?l0ooooV03oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOW0?ooo`0B09EF>@1d?1`0PT@P08Y88P2`GBX0
[EXX0:eJ9`2]FbT0[EXW0:eK:@2`GS40]F<h0;QT>@2hI3P0]F8e0=Ai@P3o_Uh0ok]J8@3o^e/0203o
_5h0okiS0?nlGP3o^UT0okiO0?noH`3o_5`0ok]J0P3o_5dR0?nkF`090?nmG@3o_f80okmT0?nkF03o
_f<0okaM0?nkFP3o_5`0okaM01X0ok]K00T0ok]J0?nmH03o_5`0ok]J0?nnH@3o_Eh0ok]K0?nlG@3o
_5`0503o^e/01`3o_Ed0okaN0?nkFP3o_f80okaM0?nlG03o_5d04@3o^e/01@3o_El0ok]I0?noHP3o
_El0okaL00l0ok]K00D0okeN0?nlH03o_V80ok]J0?nlG00;0?nkF`050?nlG@3o_Ed0okaL0?nnH03o
_5/02P3o^e/00`3o_5d0ok]J0?nmGP020?nlG0L0ok]K00D0okaK0?nmG`3o_5/0okaO0?nlG0080?nk
F`040?nlG03o^e/0okeN0?nlG0L0ok]K00@0okaN0?nlF`3o_5`0okaL0P3o^e/02P3o_5/0okeL0>^T
D02:CbL0:AH;0000001d=2<0o7Q>0?n<F`3oSE`30?n;FP030?n<G@3oS5/0oh]K00H0oh]J00<0oheN
0?n;F`3oReX01@3oReX00`3oS5d0ohYJ0?n;FP040?n;FP030?n<F`3oReX0oh]J00<0oh]J00<0ohYJ
0?n=GP3oS5d0103oReX01@3oRe/0oheM0?n;FP3oRET0oh5A0080ogU800@0ogY:0?n2DP3oREP0ohaK
0P3oReX00`3oRe/0ohiN0?n:F@040?n;FP030?n<G03oReX0oh]J0080oh]J00P0ohYI0?n;FP3oRe/0
oh9A0?mfAP3oOTh0ohUH0?nAH`<0oh]J00@0ohYJ0?nAI03oT6<0ohYI0P3oReX00`3oRUT0ohmQ0?n=
G`030?n;FP030?n<G03oU6T0ohYI00@0oh]J00<0oi1R0?n;FP3oReX00P3oReX00`3oS5`0ohYJ0?n;
FP020?n;FP80ohYJ00h0oh]K0?n=G@3oReX0oh]J0?n9F03oPU80ogY:0?mdA@3oN4P0oh=D0?n8E`3o
ReX0ohiM0?n;F`@0oh]J00<0ohYI0?n;FP3oRUX0103oReX06@3oSEd0oh]J0?n;FP3oReX0oheL0?=f
C@1l<B0020<2060Q6`3oJUD0ofaG0?mYE03oIU40of==0?mOB@3oGDH0oea60?mLA`3oGTP0of1:0?mU
C`3oJE@0of]F0?m[E`3oK5P00`3oKET04@3oL5/0ofiI0?m]F03oK5P0ofmJ0?mYE@3@DT80P2TQ01@6
1@1B5AD0XS8a0?m=C03oF5H0oeME0?mFE@3oF5H0oeUG0080oeQF103oEeD00`3oEUD0oeMF0?mIE`02
0?mIE`030?mHEP3oEeD0oeME00<0oeME0P3oF5H20?mIE`H0oeME0P3oF5H20?mIE`030?mHEP3oEeD0
oeME00D0oeME00D0oeMF0?mGE@3oFEL0oeQF0?mIE`090?mGE@060?mHEP3oEeD0oeYH0?mEE03oG5/0
oeED2@3oEeD01P3oF5L0oeIE0?mIE`3oF5L0oeYJ0?mIE`D0oeME0100oeMF0?mIE`3oFEP0oeMF0?mA
D03RA480[C<c080U9@174Q40208101X<1`0f6@d0Od4R0;1Z>@3OOD@0oiIA0`3oXEL90?nPEP070?nQ
F03oWU<0ojAL0?nTG03oXEP0ojAL0?nOE0030?nPEP030?nPE@3oX5H0oj5G00d0oj1F00@0oj5H0?nP
E`3oXUT0ojAM0P3oXEH00`3oXe/0oj1E0?nPEP0F0?nPEP0:0?nQF03oXUT0oj1F0?nQF03oYEh0oj5H
0?nPE03oY5`0oj1F0?nPEAd0oj1F00P0oj5G0?nRF@3oX5L0oj5F0?nRF@3oY5h0oj5G0?nOE080oj=L
5P3oX5H01`3oX5L0oj5H0?nQEP3oY5`0oj9G0?nQF03oY5`00`3oX5H0503oXEL0oj9H0?nTF@3oYET0
ojAI0?nNE@3oVE<0oiMA0?nAC`3PNT40_VLe09Y@9`21AR00GB/F0000000_80`0djTm0?ojF`3onEX0
ooYK103onEX00`3onU/0olME0?ooo`3o0?oooiP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWiP3oool01P3on_`0VUTm070j601^>QX0U4dS0:iK:@80[EXW00d0
[U`Y0:eJ9`2]FBH0[U`/0;1P=@2cHSL0^6@i0;aX?P3_VTl0ok]J0?njF@3o_5d0okaL02@0ok]K00d0
ok]J0?nkF`3o_5T0okiR0?o0I03o^eX0okYI0?nmH03o_Uh0okaI0?nkF`3o_5X0ok]J01H0ok]K00L0
ok]J0?nlG03o_F40okYH0?nnHP3o^e/0ok]J00<0ok]K00P0okYI0?nmH03o`6<0okYI0?nkFP3o_V<0
ok]M0?nkF`80ok]J5`3o^e/20?nkFP060?nmG@3o`6H0okeP0?nlG03o_F80ok]K0P3o^eXB0?nkF`09
0?nkFP3o^eT0okeR0?o0H`3o^eX0okeP0?nkFP3o^e/0ok]J00h0ok]K00P0ok]J0?nkF`3o_F00okaK
0?nkF`3o_F40ok]K0?nkFP`0ok]K00H0ok]J0?njF@3o_5d0okaL0?nlGP3o^eX;0?nkF`050?nkFP3o
_5h0okaK0?nlGP3o_5/02P3o^e/01@3o^eX0okeM0?nlG03o_5d0ok]J00L0ok]K00@0ok]J0?nlGP3o
_5`0okeM2@3o^e/0103o_Eh0okaL0?nlG03o^eX50?nkF`050?nkFP3o_5d0okeP0?nlG03o^eX00`3o
^e/0203oaV40ok9G09eD:@0=1`<00`000:I0:`3oNe40ohiM103oReX20?n=GPH0oh]J00<0ohiO0?n<
FP3oRUT0103oReX0103oRUX0ohiO0?n;FP3oRUT40?n;FP030?n;G03oReX0ohYI00<0oh]J00<0ohYI
0?n;FP3oReX0103oReX01P3oQ5D0ogm@0?mgAP3oMdL0ogi>0?n6E@80ohaK00<0ohYI0?n;FP3oReX0
0P3oReX00`3oREP0ohaN0?n;FP030?n;FP030?n>G`3oReX0oh]J0080oh]J00D0ohYI0?nEJ03oREX0
ogU80?mmC@020?n:F@080?n@HP3oRUT0oh]J0?n;FP3oRUT0oi5U0?nAI03oRUT20?n;FP030?n:F@3o
SV40ohiP00<0oh]J00<0ohaK0?nBI@3oRUT0103oReX00`3oSF40oh]J0?n;FP020?n;FP030?n<G03o
RU/0oh]J0080oh]J00@0ohUH0?n@HP3oSEh0oh]K0P3oRU/02@3oReX0ohmP0?n;F@3oQUD0oge=0?mf
AP3oMdH0oh1A0?n8F0040?n;FP80oh]L1@3oReX00`3oSUl0ohaL0?n;FP020?n;FP050?5eC@0<0`80
000002T=2P3oIE400`3oK5P02@3oKeT0ofmJ0?m]F@3oKET0ofYD0?mTC@3oHDX0of1:0?mLA@020?mH
@P0;0?mJA@3oHD`0ofUB0?mZE03oK5P0ofmJ0?m]F@3oK5P0og9K0?mOC@1D6AD00P0000000`2O9bH0
oeQH0?mGEP030?mGE@030?mGEP3oFEP0oeIE00D0oeME00@0oeED0?mIF03oFEL0oeED1P3oEeD01@3o
EeH0oeQF0?mJF03oF5H0oeIE00D0oeME00D0oeED0?mHE`3oFEL0oeQF0?mEE0080?mGE@040?mHE`3o
FUT0oeUG0?mEE0P0oeME00H0oeED0?mIE`3oEeD0oeeK0?mIE`3oEE@80?mGE@80oeED00<0oeQG0?mI
E`3oHF000P3oEE@60?mGE@070?mHEP3oFEP0oeYI0?m=C03o@3l0/2`[02L:2P020000000600h60P1X
;aT0cEdb0?n?C@3oZU`0ojEI2P3oX5H20?nPE@050?nSG@3oXUT0oj5F0?nTGP3oWe@00P3oX5D80?nP
EP030?nQEP3oX5L0oj1F00L0oj1F00H0oimD0?nRF`3oXET0oj1E0?nVHP3oXe`20?nPEAD0oj1F00P0
oj1E0?nPEP3oX5H0oj9K0?nSG@3oX5D0oj=M0?nXI0<0oj1E6`3oX5H20?nPE@0;0?nPEP3oXEL0oj=M
0?nTGP3oWe@0oj5H0?nWI@3oY5/0oiiC0?nPEP3oX5D05P3oX5H20?nPE@0D0?nPE`3oXUT0oj9I0?nV
H@3oXEL0oj1E0?nPEP3oXEH0oj=I0?nXG03o[5d0ojaN0?nSF03oSd`0oga30?]a?03LHcD0R3`O04<N
3`030@040000000500l:0`0X5`P0@B`?0?oBC@3oof400P3onU/00`3one/0ooYK0?okF`020?ojF`03
0?ohFP3ogUd0oooo0?l0ooooV03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOV0?ooo`060?oSf@2CDBd0M3`K070j6P2NDbD0[EXX0P2]FRL02@2[FBL0ZUPV0:eI
9P2^FbT0/F4d0:mN<P2`Gc<0_f]30?naF0020?nkF`030?nlG03o_5h0ok]J02L0ok]K0P3o^eX02P3o
^UT0okmS0?nmH@3o^eP0ok]J0?noH`3o_Uh0ok]J0?nkF`3o_5XB0?nkF`060?njF@3o_El0okaK0?no
I03o^e/0ok]J1`3o^e/02`3o_5X0ok]K0?nkFP3o_fL0okaM0?nlG03o_f@0okeR0?nkF`3o_5T0ok]J
01L0ok]K00P0ok]J0?nkF`3o_5h0okmT0?nkFP3o^e/0okiR0?nkF`80ok]J4@3o^e/30?nkFP060?no
HP3o^EL0okeM0?noI03o_5/0ok]J3`3o^e/01`3o^eX0okaL0?noI03o_E/0okiR0?nkF`3o^eX0303o
^e/01P3o^eX0okiR0?nnGP3o^eX0okeO0?nkFP/0ok]K00H0ok]J0?nmH03o_5d0okeN0?nkF`3o^eX8
0?nkF`040?nlFP3o_Uh0okaL0?nmH0T0ok]K00@0ok]L0?nmGP3o_Ed0okaL203o^e/0103o_Uh0okaM
0?nmGP3o^eX60?nkF`030?njF@3o_El0okeM00@0ok]K00<0ol1M0?o5H@2/G2d00P000000101@8AD0
n7U@0?n@G@3oREX30?n;FP030?n>G`3oRUT0oh]J00D0oh]J0P3oS5`00`3oRe/0oh]J0?n;FP020?n;
FP030?n:F`3oSUl0oh]J00@0oh]J00@0ohYK0?n>G`3oReX0ohYI0`3oReX00`3oRU/0oh]K0?n:F@02
0?n<F`070?n3D`3oMdH0ogE40?mfA@3oPE00oh]J0?n<F`020?n;FP030?n>G`3oReX0oh]J0080oh]J
00<0ohYK0?n=GP3oReX00`3oReX00`3oS5/0ohMG0?n;FP030?n;FP070?n=GP3oP500ogQ70?n6E@3o
S5/0oh]J0?n:F@030?n;FP040?n:F@3oTFD0oi5T0?n:F@80oh]J00<0ohYI0?n>H@3oSV000`3oReX0
0`3oRUX0ohYI0?n;FP030?n;FP030?n9F03oREH0oh]J00<0oh]J00<0oh]K0?n;FP3oReX00P3oReX0
5@3oSUl0ohUH0?n<G03oSE`0ohiO0?n>H03oR5P0oheM0?n;FP3oS5/0oh]J0?n1D03oMdH0ogE40?mh
A`3oPE40oh]J0?n<F`3oReX0oheM0?n9F@040?n;FP030?n<F`3oRe`0oh]J0080oh]J00H0oi1N07H^
7P000000;0d:0?mGAP3oLE`20?m/F0030?m]F@3oKUT0ofaH0080ofaH01H0ofeI0?m]F03oLE`0ofeH
0?mUC`3oH4/0oem80?mJA@3oFD80oeQ10?mNB03oH4T0ofA>0?mZD`3oM5d0of9>05hM5`0000003@<3
09dX9`3oEeD0oeIE0`3oEeD00`3oFEP0oeYH0?mHEP040?mGE@050?mFE@3oFEL0oeID0?mLFP3oEUD0
1@3oEeD01@3oEE@0oeID0?mKF@3oFEL0oeED00H0oeME00@0oeUH0?mHEP3oEeD0oeQF1`3oEeD01@3o
EUD0oeUH0?mHEP3oFEP0oeMF00L0oeME00L0oeIE0?mEE03oF5H0oeUH0?mIE`3oEeD0oeED00P0oeME
00L0oeED0?mFE@3oFeT0oeEC0?mIF03oFUP0oeED00H0oeME00H0oeUG0?mKFP3oFUT0odY:0<4_;`1E
5A@2000000070040001E9aD0V4@V0>]Z>@3oXEL0oj]M0?nTF@0:0?nPEP060?nPE@3oX5L0ojEO0?nP
E@3oYEl0oj=K0P3oX5D<0?nPEP040?nRF@3oX5D0oj1F0?nPEP<0oj1E00P0oj=K0?nQF@3oW540ojAM
0?nSFP3oX5H0oj1E0?nOEA@0oj1F00/0oj1E0?nPEP3oWU<0ojEN0?nSFP3oXED0oj=M0?nVH03oX5H0
oj1E0?nOE00J0?nPEP0=0?nOE@3oX5D0oj1E0?nPEP3oXed0ojEO0?nRF@3oXEH0ojIP0?nVH@3oWU<0
oj1F0?nOE00H0?nPEP0C0?nPE@3oX5H0oj=L0?nQF03oXEL0oj=K0?nPE@3oXEH0ojAJ0?nZG@3o[El0
ojaN0?nLD`3oPTD0jVTg0<EI<02RB2L0FRTE01/;10040000000:00<2000Z5`P0Ic/G09YH8033L2P0
iH@_0?fD=P3oadL0oomS0?ogFP@0ooQJ00H0ooUK0?ohFP3omeX0ooEJ0?oQGP3ooOoo0?oooiP0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWiP3oool01@3og/d0
TDdZ08127P1a>QX0YEHW00@0[EXX00d0/e`X0:eJ9`2]FRL0/5lc0;1P=@2]GS80e74j0?o0I`3o_Eh0
okYI0?nkF`3o^eX0okYJ02X0ok]K0P3o^eX02`3o^e/0ok]J0?noH`3o_Eh0okYI0?nlF@3o`6L0okaM
0?njF@3o^e/0ok]J00/0ok]K00D0ok]J0?nmH03o_Uh0okYI0?nmH0020?nkFP`0ok]K00/0okaI0?nk
FP3o^e/0okiS0?nmH@3o^eX0ol5X0?nnHP3o^UP0ok]K0?nkFP0G0?nkF`80ok]J00H0okaL0?nnHP3o
^UT0okeP0?o0IP3o^eT20?nkFQ40ok]K0P3o^eX01@3o_5d0okiS0?nlG03o`6H0ok]J0100ok]K00L0
ok]J0?nlG@3o_V80ok]J0?nlH@3o_5d0ok]J00/0ok]K00H0okaN0?nmGP3o^eX0okaN0?nmG@3o_Uh;
0?nkF`060?nkFP3o_5d0okaM0?nlG03o_640ok]J2@3o^e/01@3o^eX0okeP0?nlGP3o_5`0ok]J00L0
ok]K00@0ok]J0?nlG03o_Ed0okeM2@3o^e/20?nlG@030?nkFP3o^e/0ok]K00@0ok]K00<0okaK0?nl
G@3o_640103o^e/0203o_5/0ok]L0;5M;P040@40000005/T603oQ5H0oiAR0`3oReX00`3oRET0ohYI
0?n:F@050?n;FP80oh]K00<0ohaK0?n;FP3oReX00P3oReX0103oRET0ohYK0?n<G`3oRUX30?n;FP03
0?n:FP3oRU/0ohmP00D0oh]J0P3oSEh01`3oQeH0ogi>0?mhA`3oMTD0og]:0?n6EP3oRe/00`3oReX0
0`3oS5/0oh]K0?n9F0030?n;FP80ohYI00<0oh]L0?n;FP3oReX00P3oReX02@3oSf80ohYI0?n;FP3o
ReX0ohaK0?n7EP3oN4L0og];0?n<F`020?n;FP080?n9F03oRUT0oh]J0?n;FP3oRUT0oi=V0?nAI@3o
RUT20?n;FP030?n:F@3oSV40ohiP00<0oh]J00<0ohYI0?n9F03oReX00`3oReX00`3oRU/0oh]J0?n;
FP020?n;FP0>0?n:F@3oSV00oh]J0?n;FP3oRUT0ohYJ0?n@HP3oS5/0oheN0?n<G@3oReX0oh]L0?n=
GP3oRe/30?n;FP090?n;F`3oQeL0oga;0?mgAP3oMTH0ogi>0?n6E@3oReX0ohYI00@0oh]J00<0ohaK
0?n:F@3oRUT00P3oReX02@3oTV40feLi00P30P0]3@X0oeU70?meGP3oK5P0ofaG0?m]F@020?m]F0<0
ofaH01D0ofeH0?maG03oLE`0ofiH0?m^FP3oK5P0of]D0?mXD@3oHdh0oea60?mJ@P3oF480oeY30?mS
B`3/ACH0D1PD0000001?51D0oclo0?mJF@3oFEL00P3oEeD0103oEE@0oeUG0?mHE`3oEU@50?mGE@04
0?mHEP3oF5L0oeME0?mEE0D0oeME00@0oeEC0?mMF`3oEeD0oeUG1P3oEeD01@3oEE@0oeYH0?mGE@3o
F5L0oeEC00H0oeME00H0oeED0?mED`3oFeX0oeYH0?mGE@3oEE@70?mGE@060?mEE03oFEL0oeUG0?mH
EP3oFUT0oeID203oEeD0203oEE@0oeID0?mLFP3oFEL0oeYI0?mGE@3oEE@0oeIE1@3oEeD01P3oFEL0
oeiK0?mBD@3M=SH0P1lO04<A4080000000L01P<006H_6@3IHSD0ohm=0?nYG03o[5d0oj9H00T0oj1F
00T0oj1E0?nPEP3oXe`0oj5H0?nPEP3oYUl0oj1F0?nPE@3oWeD03@3oX5H02P3oXEL0oj1G0?nPE@3o
We@0oj1E0?nSG@3oYV00oiiB0?nSF`3oXUT20?nPEAD0oj1F00T0oj1E0?nPEP3oX5D0ojIP0?nQF03o
WU80oj=M0?nRFP3oX5H00P3oX5DJ0?nPEP0=0?nOE03oX5D0oimE0?nTG03oYV40oj=L0?nOE03oXed0
ojIO0?nRF@3oX5H0oj1E0?nOE00I0?nPEP80oj1E00h0oj=L0?nRF03oXe`0ojAJ0?nUF03oZU`0ojeO
0?nOE@3oS4X0lf`i0;1@:P2=?R40JBlI03DH30D0000000d081<605<b4@2LFR@0hX@f0?nD?@3oYd<0
okm:0?oDCP3oe4d0om1<0?o<B`3ohe40ooUK0080ooQJ00T0ooUK0?ohFP3on5X0ooUK0?ogF@3onEX0
ooYK0?oPE@3oh<P0o`3ooonH0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWinH0oooo00L0om2m08i;9`1h?A/0PT<N0:aJ:02]FRP0[5XX0080[EXX01<0/5`Z0:aJ
9`2]FRL0[ed^0;1Q=P2/Gc80ojAE0?nmGP3o_5`0ok]J0?njF03o_V<0okiQ0?nlG03o^eX0okeN0?no
H`3o_5h0ok]I02`0ok]K00X0okeN0?nlG03o^eT0okeM0?noH`3o^eX0ok]I0?nmG@3o_V40ok]I0`3o
^e/01P3o_El0okeM0?nkF`3o_Eh0ok]L0?nlG1H0ok]K00T0okeN0?nlG@3o^eX0okiO0?nnH@3o^eX0
ok]I0?noH@3o_5/0603o^e/0203o_5`0okaN0?nkF`3o_f<0okeO0?nkF03o_F00okaJ4P3o^e/0203o
_5`0okaN0?nkF`3o_5X0okiP0?nkF`3o_V40okaM3`3o^e/01P3o_5`0okaK0?nnH03o_5`0okaK0?nl
G@T0ok]K00<0okaM0?nmG`3o_5/00P3o_5`01@3o^eT0okeN0?nmG@3o_5l0ok]J00T0ok]K0P3o_5`0
103o_Eh0okaK0?nlGP3o_5d80?nkF`80okaL00<0okeP0?nlG@3o_5h01`3o^e/01@3o_5`0ok]K0?nm
G@3o_5`0okaM00L0ok]K00@0okaK0?nmGP3o_Ed0okaM1P3o^e/0103o_5`0okeM0?nmG@3o^eX20?nk
F`090?nmG03o_Ud0o:A@0:IY=00[5`/09a0:08Xg903;IT<0ohYJ00<0oh]J00<0ohaL0?n<G@3oReX0
1@3oReX00`3oS5`0oheN0?n;FP030?n;FP80ohYJ00<0ohaM0?n;FP3oReX00`3oReX00`3oRe/0oheM
0?n;G0020?n;FP080?n:F@3oPe<0ogY;0?mgA`3oNDP0oh1?0?n8E`3oREX20?n<F`@0oh]J00<0oh]K
0?n=GP3oRUX00`3oReX00`3oS5/0ohaM0?n;FP020?n;FP090?n;F`3oSEh0ohaK0?n;FP3oS5/0ohQG
0?mkBP3oLT@0ohED00<0oh]J00<0oheN0?n<G03oReX00P3oReX00`3oRET0ohYJ0?n;FP030?n;FP03
0?n=GP3oSEd0oh]J0080oh]J00<0oheM0?n;FP3oReX00`3oReX00`3oTF<0oh]K0?n;FP020?n;FP07
0?n;G03oS5`0ohaL0?n:F@3oSEl0ohaM0?n>G`040?n;FP030?n:FP3oSEh0ohaL00<0oh]J00X0ohaK
0?n;F`3oRUX0ohQG0?n1D03oNDP0ogQ70?miBP3oPe<0ohYI0`3oReX03@3oS5d0oh]J0?n;FP3oSE/0
jG=;078]7P091080F1hH0?mVDP3oL5X0ofaH0?m]F@3oLE`00P3oKEP30?m/F0030?m]F@3oKUL0ofiJ
00<0ofaH01@0ofaG0?m`FP3oLE`0ofeI0?m/E`3oJeH0ofYD0=9:>@1?5Q402P8201T51P2P9R@0od91
0?m;B@3oC4X0odm=0?mDDP3oDe40oe]I0?mHEPD0oeME00<0oeQG0?mGE@3oFEL01@3oEeD01P3oEU@0
oeQF0?mHE`3oF5H0oeMF0?mHEP@0oeME00H0oeIE0?mJF@3oEU@0oe]I0?mGEP3oEUD50?mGE@060?mF
E@3oFEL0oeQF0?mKF@3oEeD0oeQF1`3oEeD0103oEeH0oeYI0?mFE@3oFeX20?mHEP030?mGE@3oEUD0
oeME00D0oeME00P0oeIE0?mJF03oFEP0oe]J0?mGE@3oEeH0oeQF0?mFE@<0oeME0P3oF5H03`3oEeH0
lDa;0:Xh=`2C:bX0HALG02L:2P0<1080>1X>074b6`2IE2h0iX150?nDD03oW5@0ojEI0?nSF0080?nP
EP080?nPE@3oXUT0oj=I0?nRF@3oYEh0oimD0?nQF03oX5LA0?nPEP080?nPE@3oXe/0oiiC0?nPEP3o
YEd0oj1E0?nRF03oXUTF0?nPEP080?nSF`3oY5`0oj1F0?nRF@3oY5h0oimD0?nQEP3oXUTL0?nPEP0;
0?nOE03oXeX0ojEM0?nQE`3oX5H0ojIP0?nUGP3oX5H0oj5H0?nRF@3oXEP06P3oX5H30?nQEP0Q0?nS
FP3oY5X0oimC0?nRFP3oTDd0iX560<Ac?P2MHC@0UU</08`o8@1P:QH0<aL=02TB2P0M3PL03`P302`J
2P0o90h0ICXG081B8P2CJRX0XgH_0<>>>03[ZdD0ol1@0?o5D@3oc5@0omAH0?oLF`3ofU/0omUI0?o:
B`3oa4L0olI80080olA700D0olE80?oXE@3onU/0ooQJ0?oiF`020?ohFP060?oiF`3omeX0ooYK0?oh
FP3oiED0olF@o`3ooonH0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWinH0oooo00D0oLZh08I68P1g?A/0We<W0:UH9`020:eJ9`0:0:]J:02]FRP0[EXW0:iK:02]
FRL0[U/Z0:YM=03NN400okEH0?nlF`P0ok]K00P0okeM0?nkF`3o^e/0okaL0?o1J03o`FT0okaK0?nk
FP<0okaL;03o^e/01`3o_5`0ok]J0?niEP3o_V<0okeP0?njF@3o^e`00P3o_5`O0?nkF`060?nlG@3o
^eX0okYI0?o0I@3o_f80ok]J0P3o_5`H0?nkF`070?nlG@3o^e/0okYI0?o1I`3o_5d0ok]K0?nlG00C
0?nkF`050?nlG03o^e/0okeN0?nnH`3o^eX00P3o_5`?0?nkF`050?nlF`3o_F40okiS0?njF@3o_5`0
1`3o^e/00`3o^eX0okaL0?nkF`040?nkF`040?nmG@3o_V40ok]K0?nkG0X0ok]K00<0okaL0?nkF03o
_V002`3o^e/00`3o_5X0ol1U0?nlG@090?nkF`030?nlG03o_F00okaL00P0ok]K00<0ok]L0?nnGP3o
^e/01`3o^e/00`3o_5`0okeP0?nkFP020?nkF`040?nlF`3o_e`0oZ9?03XO3`80000000<0Wd</0?n9
FP3oRe/00`3oReX00`3oQeL0oh]J0?n;FP040?n;FP030?n;F`3oSV40ohYI00D0oh]J00<0ohiO0?n;
FP3oReX0103oReX0203oS5/0ohQG0?n0D03oNDP0ogQ70?miB03oP580ohUH103oReX00`3oS5d0oh]L
0?n;FP030?n;FP030?n;G03oRU/0oh]J00<0oh]J00<0ohaM0?n;FP3oReX00P3oReX01`3oSEh0oi9U
0?n:F@3oReX0og]:0?mgAP3oO4/0103oReX00`3oSf00oh]L0?n;FP020?n;FP030?n9F03oRUT0oh]J
00<0oh]J00<0ohYI0?n9F@3oReX00P3oReX00`3oSf80ohYI0?n;FP020?n;FP080?n:F@3oREP0oh]J
0?n;F`3oR5L0ohmP0?nAH`3oRUX30?n;FP030?n<G03oRUT0oh]J0080oh]J00P0ohaL0?n?HP3oRUT0
ohaK0?n9F03oRUT0oh]J0?n=GP@0oh]J00P0oh]K0?n4DP3oNdX0ogQ70?miB03oOTh0ohMF0?n<G@80
oh]J00H0ohaK0>QaB@0910800000030?303oIU820?m/F0030?m]E`3oL5/0ofeG00<0ofaH00@0ofaG
0?m`F`3oL5/0ofeH0`3oK5P04@3oKET0og1K0?m_FP3oK5P0ofiI0?m_FP3oJ580/CP/00L30P080`80
TR@S0?m=C@3oE5<0ode;0?m7A@3oAD<0od=10080odA200P0odE30?m;B@3oDe40oeID0?mGE@3oFET0
oeEC0?mHEPD0oeME0P3oF5H00`3oGUd0oeEC0?mHEP060?mGE@030?mHEP3oFUP0oeQF00T0oeME00<0
oemO0?mFE03oEeD01`3oEeD01@3oF5H0oeID0?mKF@3oFEL0oeQF00T0oeME00@0oeQF0?mEE03oHF00
oe=A0P3oF5H40?mGE@0@0?mGEP3oF5L0oeQG0?mEE03oB4P0ZRTY03l>3P0;0@80000000H3000B20<0
XDTW0?nBC`3oVe<0oj5F0?nSF0T0oj1F0P3oX5L01@3oXeX0ojMP0?nLD@3oXEP0oj1G0140oj1F00L0
oj1G0?nQF03oXEL0ojQT0?nPE@3oWe@0oj1G00<0oj1F00<0oj5G0?nPEP3oX5H0403oX5H01P3oXEP0
oj1F0?nND`3oYUl0ojIR0?nQEP80oj1G703oX5H20?nPE`070?nOE03oXeX0ojUV0?nRF@3oX5D0oj1G
0?nRF@020?nPEP030?nOE@3oX5H0oj1F01X0oj1F0P3oXUL02@3oXEH0oieC0?nOFP3oSdh0hFLf09U2
8P1e=1X07`d700/50P030000000;008000081P80;a`;08A;7@2dJBT0oiHn0?noC`3obe<0oleD0?oC
EP3of5T00P3oeeT00`3oeeP0omAH0?oDE`040?oDE`050?oEF03oc4h0olA70?o4A`3oaDL00P3oa4L0
203o`DH0on9A0?oiF`3on5X0ooUK0?ohFP3onU/0ooQJ0P3onE/00`3on5X0oo1H0?nfL03o0?oooiP0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWiP3oool0403e
a[D0QDDP07Hm6`2JDR@0YELV0:QH9`2]FRL0ZeXX0:aJ:02^FbP0]5hZ0:]I9`2]FbP0XeL_0?nNE03o
_Ed80?nkF`030?nlG03o_F00ok]K00D0ok]K00T0ok]I0?o1I@3o`V/0okmT0?nkFP3o^e/0okaP0?nl
GP3o_5/00P3o^e/00`3o^eX0ok]K0?nkF`0O0?nkF`0@0?nkFP3o^e/0okaL0?nlG03o`6@0okaM0?nk
FP3o^e/0okYI0?nkF`3o`6P0okiR0?njF03o_5`0okaN0?nlG080ok]K00<0ok]J0?nkF`3o^e/06`3o
^e/01P3o^UP0ol1U0?o0J03o^eX0okaM0?nlGP80ok]K00<0ok]J0?nkF`3o^e/0503o^e/01`3o^eX0
okeN0?o2JP3o_5`0okaK0?nmG@3o^eX04`3o^e/01@3o^eX0okmU0?nlG@3o_5`0okeM0140ok]K00@0
okiR0?njF@3o_Ed0okaL103o^e/00`3o^eX0okeP0?nkH0050?nkF`050?nkFP3o_F00okiS0?nkF`3o
_5d02`3o^e/0103o_F40okiN0?nkF`3o_5`90?nkF`030?nkFP3o_f@0okeM00P0ok]K00@0ok]J0?nm
G@3o_Eh0okaL203o^e/00`3o_Eh0okYI0?nlG0060?nkF`030?nlG03o_5d0okaL00<0ok]K00T0okmL
0?n^E@2;BRD04@T400P30P2aAbl0oh5E0?n@G@3oS5/00P3oReX00`3oRUT0ohaM0?n:F@050?n;FP03
0?n<G03oRUT0oh]J00@0oh]J00l0ohiQ0?n9F03oReX0oh]J0?n<F`3oReX0ohEE0?mhB@3oMdH0ogQ7
0?mnC@3oRUT0oh]J0?n>H@3oRe/0103oReX00`3oSEh0oh]J0?n;FP020?n;FP030?n9F@3oSUl0oh]J
00@0oh]J00`0ohaL0?n;FP3oReX0oh]J0?n:F@3oR5L0ohYK0?n6E@3oMdH0ogQ70?n8E`3oSUl30?n;
FP030?n=G@3oRU/0oh]J0080oh]J00<0ohUH0?n:F@3oReX00`3oReX20?n:F@<0oh]J00<0oi1R0?n:
F@3oReX00P3oReX0103oSEh0ohYK0?n;FP3oSf020?n;FP070?n:F@3oReX0oh]J0?n;FP3oRET0ohiP
0?n:F@040?n;FP040?n9F03oReX0oh]J0?n9F080oh]J00<0ohYI0?n;FP3oReX00P3oReX0503oSEh0
ohYK0?n:F@3oOdh0ogQ70?meAP3oMdL0ohAC0?n:F@3oRe/0oi5O07@]7P000000=0l<0?mLB@3oKUT0
ofaH0?m]E`3oL5/0ofiI103oK5P00`3oKeX0og1K0?m]E`040?m/F00<0?m`F`3oKEL0ofaH0?m/F03o
KUT0oeA404DF4P0000007PL70?/m?03oEeH0oeQF0P3oEeD00`3oF5H0oeME0?m=C0020?m6A00:0?m5
@`3o@d40od=10?m4@P3oBTP0oe9@0?mED`3oEU@0oeME0?mHEP80oeME00<0oeQG0?mJF@3oDe801P3o
EeD01@3oF5H0oeME0?mJF03oFEL0oeIE00D0oeME00D0oeED0?mHEP3oFEL0oeeK0?mFE0070?mGE@06
0?mEE03oF5H0oeIE0?mOG`3oF5H0oeED2@3oEeD0103oF5L0oe=B0?mMGP3oFEL60?mGE@060?mGEP3o
FEP0oeAC0?m@CP3oADD0NahM0`0000001P0O3@H0NCLM0>YX>03oV540oj9H0?nRE`X0oj1F00D0oj5H
0?nNDP3oYV00ojAN0?nPE@0B0?nPEP060?nPE`3oXEP0oj1E0?nVH03oXed0oimE1`3oX5H00`3oXEP0
oj5F0?nPEP0:0?nPEP060?nPE@3oX5H0oj1E0?nRFP3oX5D0oimD0P3oYEh00`3oWe@0oj1F0?nPEP0H
0?nPEP050?nPE@3oX5H0oj1F0?nRF@3oXET00P3oWe@00`3oYf00ojAN0?nOE00M0?nPEP0=0?nQEP3o
XeP0ojEJ0?nVFP3oY5X0oj5F0?nTE`3oXeH0oiYC0?n7A`3QIC@0QSXM03hM3P040000000800L40@0O
4@L0:a/;06Hl5`2_IBL0lh`h0?ndBP3odUL20?oFE`80omAH00<0omEH0?oFE`3odeL02@3oe5L00`3o
eEP0om=D0?o9B@020?o4A`060?o5A`3oa4L0olA70?o3AP3ocTX0oo9G0P3onE/20?oiFP060?ogFP3o
nE/0ooQJ0?ohFP3omET0ol1^o`3ooonH0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWinH0oooo00P0ikf]07a07@1i?Q`0YePW0:YJ9`2UEbH0YePW0:]J:080[EXW
00H0[EXX0:]I9`2[FBL0^68a0?n[E03o_e`90?nkF`030?nlG@3o_5`0ok]J00D0ok]K0P3o^eX0303o
^e/0ok]J0?nkFP3o`VX0ol5X0?nlF`3o^UT0okeN0?nmH@3o_5h0ok]J0?nkF`80ok]J6P3o^e/01P3o
^eX0ok]K0?nnH03o_5T0okeP0?nmG`H0ok]K00/0ok]J0?nkF`3o^UT0okeN0?o1I`3o_V40ok]J0?nl
GP3o_V80okaL0?nkF`020?nkFQX0ok]K0P3o^eX01`3o^e/0okiR0?o1J03o_5`0okaK0?nmH@3o_Ed0
5`3o^e/01`3o^eX0ok]K0?nmG`3o`6H0okYG0?nkF`3o_El00`3o^eX?0?nkF`80ok]J00L0okiR0?o0
IP3o^eX0okeO0?nkFP3o^e/0ok]J00d0ok]K00/0ok]J0?o0I@3o_Ed0okeM0?nkFP3o^e/0ok]J0?nk
F`3o^eX0okeP0?nlG@070?nkF`050?njF@3o_f40okeN0?nmG@3o_5X02@3o^e/01P3o^eX0okaM0?nm
GP3o_Ed0ok]L0?nkFPP0ok]K00@0okaN0?nlG03o^e/0okaL1`3o^e/0103o^eX0okeN0?nlG@3o_5`6
0?nkF`050?nkFP3o_Eh0okeP0?nlG03o^eX01@3o^e/00`3o^eX0okaN0?nlG0030?nkF`090?nmG03o
aV40jg`n028B2@000000E24F0?mZA`3oSed0ohUJ0080oh]J00<0ohaN0?n;FP3oReX01P3oReX00`3o
RU/0oh]J0?n;FP030?n;FP050?n<F`3oReX0ohYK0?n9F03oPE400P3oN4L00`3oNDP0oh1@0?n;FP03
0?n;FP030?n=GP3oReX0oh]J0080oh]J00<0ohQG0?n;F`3oRET00`3oReX00`3oS5`0ohaM0?n;FP02
0?n;FP80ohaK00/0ohYI0?n;FP3oReX0oh]J0?n>G`3oSf80oh1?0?mgAP3oP500oh]J0?n>H0030?n;
FP030?n:F@3oREP0oh]J00<0oh]J00<0ohQG0?n:F@3oReX00P3oReX20?n:F@<0oh]J00P0ohaL0?n;
FP3oRUT0ohYI0?n;G03oT6<0ohmR0?n<G080ohYI00<0ohiP0?n=G`3oRUX00P3oReX00`3oRU/0oh]J
0?n;FP030?n;FP030?n?H03oReX0oh]J0080oh]J00<0ohYI0?n>G`3oS5/00`3oReX04P3oReh0ohUK
0?n;FP3oReX0ohUJ0?n3DP3oMdT0ogM60?mhA`3oP500ohaJ0?aT@@0C20D0>14=0?mMBP3oLE/0ofeH
0?m/E`80og1K103oK5P00`3oKET0og1K0?m/F0030?m/F080ofiI00X0ofmK0?m/F03oKeT0og9L0=]A
@@020000000000l30`33>CP0oe]I0P3oEeD02P3oEUD0oeYH0?mIE`3oEE<0oeQF0?mGE@3oE580oe1>
0?m8A`3oAdD30?m2@0080?m6A03oBdT0odm=0?mDDP3oEeH0oeME0?mNG@3oEUD40?mGE@050?mEE03o
EeD0oeQF0?mJF03oF5H01P3oEeD01@3oEUD0oeQG0?mHEP3oF5H0oeMF00L0oeME00H0oeIE0?mHEP3o
F5H0oeQG0?mKFP3oEE@70?mGE@070?mEE03oEeD0oeQG0?mGE@3oGEd0oeQG0?mEE0040?mGE@070?mG
EP3oFEP0oeaK0?mFE03oADD0WRLV03<<30020000000701d>1`117a40OSXO0?:1AP3oYe/0oj=I0?nQ
EP070?nPEP080?nPE@3oX5H0oj5J0?nTFP3oXED0ojEM0?nND`3oWeD>0?nPEP0:0?nOE@3oX5D0oj1F
0?nQF@3oXeX0oimD0?nSF`3oY5h0oj5E0?nOE@X0oj1F00<0oj9I0?nPE@3oX5D01@3oX5H20?nPE@08
0?nPEP3oXUP0oj=L0?nPE@3oWU<0ojMP0?nQE`3oXEDI0?nPEP0<0?nPE@3oX5H0oj1E0?nPE`3oXe`0
oj1F0?nND`3oXed0ojIP0?nND`3oX5H0oimE6`3oX5H03P3oXUL0ojEJ0?nXF`3oZed0ojUK0?nJD`3o
RDT0oh150?n>B`3oUD/0ogdl0>UU<027?1`04@P30`0000002`0P4@L0ABP@05/e5P27D200cGL_0?n[
A`3obe<0omiL0?oJF`3oeeT0omAH0140omAG00<0omEH0?o<D03oaDH00P3oa4L01P3oaDL0olA70?o4
A`3oa4L0ol150?oZE@80ooUK00@0ooII0?ofFP3on5X0ooUK0P3on5X00`3omET0olM]0?ooo`3o0?oo
oiL0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWiP3oool0
403T^j`0MchM099=8`2XF2P0Z5PW0:QH9P2VEbH0YePW0:]J9`2]FRL0[UXX0;5L:P2VEbH0nHXn0?nk
FP3o_E`:0?nkF`030?nkFP3o_5/0okeN00T0ok]K00/0okaJ0?nkF`3o^e/0ok]J0?nmGP3o_V40okeN
0?nkF@3o^e/0okiR0?noI0020?nkFP060?nlG03o_V00okaL0?nkFP3o^e/0okaK3`3o^e/01`3o^e`0
okeM0?nlF@3o_F00okeN0?nnH03o_5X03`3o^e/0103o_5h0okmQ0?nlG@3o^eT20?noI0050?nlG03o
^e/0okeO0?nmH03o_5/06`3o^e/02@3o_5`0okiQ0?nmGP3o^UT0okiQ0?nmG@3o^eP0okaM0?nmGP02
0?nkF`030?nlFP3o^e/0ok]K0140ok]K00X0okaL0?nmG`3o^UT0okiO0?noI03o_5/0okiO0?nlGP3o
^eX0okaK3`3o^e/01P3o_El0ok]I0?nlG03o_f@0okaL0?nnG`h0ok]K00X0okeN0?nkFP3o_Eh0okiR
0?nkF`3o_Eh0ok]K0?nmG03o_5/0okaL1`3o^e/01P3o_Eh0okaN0?nmG`3o^e/0okaM0?nmG@P0ok]K
00H0okaK0?nlGP3o^eX0okeR0?nlG03o_5d80?nkF`040?nlG@3o^eX0okeN0?nlG@L0ok]K00@0okaN
0?nlG03o_Ed0okaL1P3o^e/00`3o^eX0okeN0?nmGP020?nlG0D0ok]K00@0okeM0?nlG03o_Ed0okaL
0P3o^e/02P3o`Eh0i:5>074m7P0N4@P02P@308Pn:@3oP5@0ohmM0?n<F`3oReX20?n<G0030?n=GP3o
ReX0oh]J00<0oh]J00<0oheM0?n=GP3oREX00P3oReX02P3oS5/0ohUI0?n6E@3oOT`0ogI70?mhB03o
Odh0ohIF0?n8F@3oS5/40?n;FP030?n;F`3oRe`0ohYI00<0oh]J00<0oheM0?n<GP3oReX00`3oReX0
0`3oS5`0ohYJ0?n;FP020?n;FP030?n=GP3oRe/0ohYI0080oh]J00D0oh]K0?n6E`3oNDP0oh1?0?n:
F@060?n;FP030?n=GP3oRe/0oh]J0080oh]J00<0ohUH0?n:F@3oReX00P3oReX20?n:F@D0oh]J00@0
ohiP0?n<F`3oRe`0ohYJ0`3oReX00`3oRe/0ohaK0?n;F`020?n;FP030?n;F`3oReX0ohaK00<0oh]J
00<0ohaL0?n;FP3oReX00P3oReX0203oRe/0ohiO0?n;FP3oSEh0ohaL0?n:F@3oS5/0oh]L103oReX0
3P3oRe`0oh]J0?n5EP3oPE40m6Y008<a7@0@1`@0GAhH0?mXD`3oLE/0ofeI0?m^F03oKUT0ofmJ0P3o
K5P0103oKEP0ofiJ0?m^F@3oKET30?m/F00>0?m^F@3oL5/0ofiI0?m]F@3oKeX0ofeG0=]FA@2>;RD0
6`P704PB4P2Q;Rd0m4]:0?mHE`3oEUD20?mGE@80oeQG00@0oeIE0?mGE@3oEeD0oeIE0P3oF5H05@3o
F5L0oeID0?mBD@3oDDl0odi<0?m9A`3oAdD0odE40?m4@P3oB4L0odU70?m;B@3oD4h0oeAB0?mFE03o
EUD0oeQG0?mKF@3oEeD0oeMF0?mHEP050?mGE@060?mHE`3oEeD0oeYH0?mIE`3oF5L0oeID1P3oEeD0
1P3oF5L0oeID0?mIF03oEeH0oeQG0?mFE0D0oeME00T0oeID0?mGE@3oFET0oeQG0?mKFP3oEUD0oeUG
0?mHEP3oEUD00P3oEeD04@3oF5L0oeYH0?mHE`3oD500eD9109/Z:`1i7Qd0CQ@C01T81P0b5`d0EbLE
08Xm8@2oKS`0ohm>0?nNEP3oYUX0oj=H00L0oj1F00D0oj5H0?nQE`3oXEH0ojEN0?nRF0020?nRF@l0
oj1F00H0oj1G0?nSFP3oXEL0oj9K0?nTGP3oXEL20?nRFA00oj1F00d0oj5H0?nPEP3oX5H0oj1F0?nR
F@3oXeX0oj1F0?nTG@3oY5h0oj5F0?nRF03oY5`0oj5F01P0oj1F00<0oj1E0?nSFP3oXEP00P3oX5D0
1@3oYEh0oj9I0?nOE03oXEP0ojAL01T0oj1F0240oj5G0?nRF03oYEX0ojIJ0?nWF`3oWE@0oi=?0>^7
B@3OPTL0c7@n0:iM<@2;@B<0OCPN06X_6@157a007@`500D1000b5@X0J3LF05Db501V?1P0OdXN09i[
:`2jSc`0bJ120>6[AP3m_Dh0om5F0?oKF`3ogE/0om]J0?oGF@3oeUP0503oe5L0103oeEP0olmC0?o7
B@3oaDL50?o4A`040?o5A`3o`DH0on9B0?ohFP80ooMJ0`3onE/20?ohFP030?ogF03oegd0ooko0?l0
ooooU`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOV0?oo
o`060=6aY@1_>Q/0W54V0:MG9P2YF2L0ZeTX0P2WEbH0202XFBL0ZeTV0:iJ9`2^FbP0]5hY0?nRAP3o
_5D0ok]J303o^e/00`3o_5`0okeM0?nlG00@0?nkF`090?nkFP3o_5X0ok]K0?nkFP3o_5d0okmT0?nl
G@3o^UT0okYG0080ol1W00D0ok]H0?nkF`3o^e/0okaI0?nkFP060?nkF`80ok]J00D0okeQ0?nlGP3o
_Eh0ok]K0?nkFP0F0?nkF`80ok]J0P3o^e/01`3o_V80okiS0?nkFP3o_5`0ol1W0?noI@3o^eT00`3o
^eXH0?nkF`0:0?nlFP3o^e/0ok]J0?nmG@3o_V00okYG0?nlG03o`FX0okaK0?nkF`80ok]J4P3o^e/2
0?nkFP060?nkF`3o_V80okaP0?niE`3o_f@0ok]K0P3o^eX?0?nkF`060?nkFP3o_5/0okiR0?nkFP3o
^eP0okiQ0P3o^eX<0?nkF`090?nkFP3o_5`0okiP0?njF03o_fD0okeL0?nkF`3o_V00ok]J00T0ok]K
00D0okaN0?nmG@3o_V00okaK0?nkFP080?nkF`060?nkFP3o_5`0okeM0?nlG03o_V<0ok]J1`3o^e/0
1@3o^eX0okeP0?njF@3o_F00okaL00H0ok]K00@0ok]J0?nlG03o_Eh0okeN2@3o^e/00`3o_5`0ok]J
0?nkF`050?nkF`0A0?nlG03o_Ed0ok]K0?nkF`3o_5`0olMQ0?nOC`2BCBH0000002@?2@2/A2d0ohMH
0?n>G03oReX0ohYI0?n:F`3oSEd0103oReX0303oRUT0oh]J0?n>H03oS5/0oh]J0?n1D@3oNdX0ogI5
0?mhA`3oOTh0ohMF0?n<F`<0oh]J00P0oheM0?n:F@3oReX0oh]J0?n;F`3oRe`0ohYL0?n:F@<0oh]J
00<0ohYI0?n;F`3oReX00P3oReX00`3oSEd0ohaL0?n;FP020?n;FP0=0?n:F@3oT680oheN0?n:FP3o
S5/0ohUH0?mgA`3oNDT0ohMI0?n:F`3oReX0ohmQ0?n:F@030?n;FP070?nFJP3oRU/0oh]J0?n;FP3o
RUT0ohaL0?n:F`020?n;FP0=0?n:F@3oREP0ohYI0?n<GP3oSV40ohYI0?n>H03oReX0ohYI0?n;FP3o
SEd0oh]L0?n9F@020?n;FP030?n=G`3oSV40ohYI0080oh]J00<0ohYK0?n>H@3oReX00`3oReX00`3o
S5`0oh]J0?n;FP020?n;FP050?n<G03oRe/0oh]J0?n;FP3oSEh00P3oRe`00`3oRUX0oh]J0?n;FP02
0?n;FP0<0?n:F@3oReX0ohYJ0?YkD@0P3@P0000003P?2`3oEd40oei80?mRC@3oJE<0ofiH0`3oK5P0
0`3oKEP0ofmJ0?m`F`040?m/F0070?m^F03oKe/0ofaH0?m/F03oKUT0of=?05@I5@020000000909XV
9@3oF5H0oeUH0?mGE@3oEU@0oeYI0?mIF03oEeD0oeIE00@0oeME00@0oeUH0?mJF03oF5H0oeIE103o
EeD03P3oFUT0oeUG0?mED`3oDDl0odY90?m7A@3o@d40od900?m2@@3oAT@0odE30?m?C@3oDDl0oeID
0P3oF5H30?mGE@050?mIF03oEeD0oeQG0?mHEP3oEUD01@3oEeD01`3oEE@0oeEC0?mKF`3oEeD0oeUH
0?mHEP3oEUD01P3oEeD01`3oEE@0oeME0?mMG@3oDe80oeaJ0?mGE@3oEE@00`3oEeD01`3oEUD0oeUG
0?mLF`3oCdh0^b`/070L6`0f3@h00P0000001`0E2P@0MSHM0>Q_?03oUE00ojYL0?n[G@3oXUP01`3o
X5H0103oX5D0oj9I0?nVH@3oXEH20?nRF@80oj1E3@3oX5H30?nPE@050?nUGP3oWe@0oj1F0?nSG@3o
XEP00P3oX5DA0?nPEP090?nPE@3oX5H0oj1E0?nVH03oYEX0oiiC0?nSG03oXed0oj1F0080oj1E5P3o
X5H0303oWe@0oj1F0?nPE@3oXe`0ojMR0?nQEP3oWU<0ojAM0?nRFP3oX5D0oj1F0?nPEAT0oj1F00/0
oj=I0?nTFP3oZE`0ojaO0?nSE`3oQdL0iVTg0:=89@23>al0EBLD02lE2`050000000<00<2000L40L0
M4<L0>23=`3VR3P0lhlj0?o2D03ohEh0onEO0?oRG@3ogE`0omMH7@3oe5L00`3oe5H0olI:0?o4A`06
0?o4A`050?o5A`3oa4L0ol9:0?odF@3on5/00P3onEX01`3onE/0ooUJ0?ohF`3on5X0ooUI0?oZJ03o
h/P0o`3ooonG0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
inH0oooo0100i;jd06dh5P2UERL0YeLV0:QH:02UERD0YELV0:MG9P2WF2H0Z5TW0:YH9P2]FRP0bVT^
0?ndCP3o]U00okYI3@3o^e/20?nlG0030?nmH03o^e/0ok]K0180ok]K00@0ok]J0?nkF`3o^e/0okaI
0P3o_F40203o^eX0ok]H0?noHP3o`V/0okiR0?njF@3o^e/0ok]J0P3o^e/01@3o_E`0okiS0?nkFP3o
_Ed0okaL01d0ok]K0P3o^eX0203o^e/0okaL0?nmH@3o_F00ok]H0?nnHP3o`VX0okiS0`3o^eXJ0?nk
F`070?nkFP3o_5`0okiR0?nkFP3o_Uh0ol5W0?o0I@020?nkFQ<0ok]K0`3o^eX01`3o_El0ok]K0?nj
F03o_V80okeN0?nkF`3o^eX03P3o^e/0203o^eX0ok]K0?nkFP3o_5h0okaL0?o0IP3o_5d0ok]J303o
^e/20?nkFP050?nmH03o_5/0ol1V0?nmH03o_5`02P3o^e/01P3o^eX0okaN0?njF@3o_V40okeP0?nk
FPP0ok]K00H0ok]J0?nkG03o_Ed0okeO0?nlG@3o^eX60?nkF`060?nkFP3o^e/0okaM0?nlG@3o_Ed0
ok]J1P3o^e/0103o_5`0ok]K0?nmGP3o_5`70?nkF`030?nlG03o_F80okYI00D0ok]K00T0ok]J0?nn
GP3o_5`0okaI0?nkF`3o_5/0olAO0?nlF`2@C2H00P0000000`1O9aT0oh1D0?n;FP030?n;FP030?n?
H03oRU/0oh]J0080oh]J00T0ohUI0?n;G03oQED0oga<0?mhA`3oMdH0oga<0?n7E`3oRe/01@3oReX0
0`3oS5d0oh]K0?n:F@020?n;FP040?n:F`3oSUl0oheN0?n:FP<0oh]J00<0oheO0?n:F@3oReX00P3o
ReX00`3oS5l0oh]J0?n;FP020?n;FP080?n<G03oRUT0oh]J0?n;FP3oP540ogI50?n1D03oS5/20?n;
FP070?n=GP3oReX0oh]J0?n;FP3oRUX0oi9V0?n:F`020?n;FP0<0?n8F03oTfH0ohmQ0?n;FP3oRUT0
ohUH0?n;FP3oSUl0oh]J0?n=GP3oReX0oi1R0`3oReX00`3oSV40ohmP0?n:F@020?n;FP030?n:F@3o
Re/0oh]J0080oh]J00<0ohaK0?n:F`3oReX00P3oReX20?n<F`@0oh]J00L0ohaK0?n;FP3oReX0oh]J
0?n<G03oT6<0oh]L00@0oh]J00d0oheM0?n;FP3oREX0oi9Q08Pf8`00000090`90?mNB`3oHdd0oeQ2
0?mJA03oH4P0ofE?00<0ofaH00<0ofiH0?m]F@3oK5P00P3oK5P00`3oKEL0ofmJ0?m_FP020?m/F003
0?m`FP3oKEP0JR4J0080000000P0VRLV0?mCD`3oEeH0oeME0?mEE03oFEP0oeME0?mHEP@0oeME00<0
oe=B0?mKF@3oF5H01@3oEeD00`3oEE@0oeUG0?mHEP030?mHEP0B0?mEE03oEE<0oe=A0?m=C03oAD@0
od=10?m1@03o@d40odI40?m7A@3oBTP0oe9@0?mFE@3oF5H0oe]I0?mIE`3oEeD0oeED1@3oEeD00`3o
EUD0oeME0?mMF`020?mIE`T0oeME00@0oeEC0?mNG@3oF5H0oeUH0P3oEE@40?mGE@050?mIF03oFEL0
odM70:TZ:@0l3Ph00`0000001`1>8a80gf@f0?n6B@3oV540ojQK0?nTF@3oXEH01P3oX5H01P3oWeD0
oimD0?nQF@3oY5`0oj1F0?nSFa00oj1F00H0oj1E0?nREP3oZ680oj=M0?nOE03oXeX20?nPEP030?nP
E@3oX5H0oj1F00l0oj1F00/0oimE0?nPE@3oXED0ojIQ0?nQE@3oX5D0oj=K0?nRF@3oXED0oimD0?nP
E@0E0?nPEP090?nPE@3oX5H0oj1E0?nRF@3oZ6H0oj=J0?nPD`3oXET0oj=L01`0oj1F00/0oj9G0?nS
F@3oYU/0oj]M0?n>BP3oMCd0]e0Z06da6P1<8a80;a@:01@810040000000=01L>0`1L=Q<0RU8S0<ii
=03oZ4@0ojY70?n]B@3oae80ommN0?oQGP3ohUd0omUK0?oFE`0Q0?oDE`030?oBE03o`dH0olA700D0
olA700P0olM90?nlA03o^dD0ol950?oWE@3ojED0onaF0?o]EP80onYF00D0onQE0?ohFP3oo5/0oo9N
0?oNX@3o0?oooiL0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWiP3oool0403F/JD0PT<J0:QH:02WEbH0YePW0:eK9`2[FRT0YELV0:QH9`2WEbH0Z5TV0:iK:03F
MC@0okeB0?ndCP3o^5<?0?nkF`030?nlGP3o_5d0ok]K01H0ok]K0P3o^eX0303o^e/0ok]J0?nlG@3o
_5h0okaL0?njF@3o_5/0ol9[0?o0I@3o_640ok]K0?nlGB@0ok]K0P3o^eX02@3o^e/0okaL0?nlGP3o
_5d0ok]J0?o1IP3o`FT0okeP0?nkFP0J0?nkF`090?nkFP3o^e/0okaL0?nlGP3o_Ed0ok]J0?o0J03o
_f@0ok]J01L0ok]K00H0okaL0?nkF`3o_Eh0ol9Z0?nlG@3o^eXA0?nkF`050?nmG@3o^e/0okmQ0?nm
H03o^eX0303o^e/01`3o^eX0ok]K0?nmG@3o^eX0ok]K0?nmGP3o^eX02P3o^e/01@3o^eX0okaL0?nk
F`3o_El0ok]J00T0ok]K00@0ok]J0?nlG03o^eP0ol1V2@3o^e/0103o_5`0ok]L0?nnH`3o_Eh70?nk
F`030?nlG03o_5h0okeM00H0ok]K00@0okaL0?nkF`3o_5d0okeP1P3o^e/00`3o^eX0okeP0?nkG002
0?nkF`030?noG@3o/UL0OD8O0080000000<0LbhN0?n6F03oRe/00`3oReX00`3oS5l0ohYI0?n;FP02
0?n;FP0:0?n5D`3oNTT0ogI50?mhA`3oODd0ohYI0?n<F`3oRU/0ohaK0?n<G0@0oh]J00<0ohmP0?n<
G03oReX00P3oReX00`3oRET0ohaK0?n;F`040?n;FP060?n9F03oReX0oh]J0?n;FP3oRe/0ohaN0`3o
ReX0203oREP0oi1Q0?n;F`3oQUH0ogQ70?mfA@3oRU/0ohUI0P3oReX00`3oRUT0ohUH0?n;FP020?n;
FP0<0?n:F@3oReX0oh]J0?n;FP3oR5P0oi=W0?n>H@3oREP0oi9V0?n;FP3oREP0oh]K0`3oReX00`3o
T640oh]J0?n;FP050?n;FP030?n;F`3oSUl0ohYI00<0oh]J00<0oi5S0?n;FP3oReX00P3oReX01`3o
SUl0oh]K0?n;FP3oReX0ohUI0?n>G`3oRET00`3oReX0103oS5/0oh]J0?n<F`3oRUT20?n;FP0<0?n>
G`3oRe/0oh]J0?nAG`3^Gch040L401h91`3oED@0og9L0?m[E`3oHdh0oee60P3oFdD0103oITl0of]G
0?m^F@3oL5/30?m/F0030?m]F03oK5P0og5L0080ofiI00d0ofeH0?mJB01I71H00P41030;2`3W>3P0
oeIE0?mHEP3oEeD0oeQF0?mKF@3oF5L0oeED00<0oeME00<0oeED0?mIF03oFeX01`3oEeD00`3oFEL0
oeQF0?mGE@040?mGE@080?mGEP3oFEL0oeUG0?mED`3oE580ode<0?m8AP3o@d820?m3@@050?m4@`3o
AD<0od]90?mAC`3oEE@01`3oEeD01@3oFUT0oeEC0?mHEP3oF5H0oeIE00L0oeME00@0oeMF0?mNGP3o
EeD0oeQG103oEeD20?mGEP0?0?mGE@3oEU@0bS<c04D@400N1PH00P000000000G2P@0Pc/O0?I_>`3o
UU40oj9G0?nVFP3oXeT0oj5F00L0oj1F00L0oj9I0?nWH@3oX5D0oj1F0?nQF03oX5H0oj1E00h0oj1F
00H0oj5E0?nUGP3oYf80oj5G0?nQF@3oX5LE0?nPEP050?nSF`3oYf40oj5E0?nPE@3oXET00P3oX5H0
1@3oWeD0oj1F0?nQE`3oXUH0oj1E01@0oj1F00L0oj5G0?nYI03oYf00oiiC0?nPEP3oXU/0oj5H0080
oj1F00<0oj1E0?nPEP3oX5H04@3oX5H00`3oXEH0oj1F0?nQE`020?nRE`80oj5F00T0oj1F0?nCCP3o
MSh0gf<c07lh700h6@h08@h701D910060`400`0000002P0;1P80A2L?09EF8@2nKB`0oJQ80?nnD`3o
aDd0olaD0?oEF03ogE`20?oLF`030?oHF@3oe5L0omAG02@0omAG00X0ola?0?o6A`3oaDL0olQ90?nn
A@3o^T@0ol560?o9B@3oaDL0ol=60P3o`TH00`3okEH0ooEI0?oeF@040?oeF@040?oiF`3onUX0onUJ
0?oEVOl0ooooU`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOV0?ooo`080<bFO`2?BQd0Z5PX0:MG9P2XF2P0Z5PV0:UI:02XFBP30:MG9P030:1D9`3]T400okMA
0080okA>00<0ok]J0?nkF`3o^e/03@3o^e/00`3o_5`0okeM0?nlG@0I0?nkF`0E0?nlF`3o_5`0ok]I
0?nnH@3o_E`0okiQ0?nkFP3o_5`0ok]J0?nnH@3o_f<0okiP0?nkFP3o_5`0okiS0?o0I03o_5d0ok]J
0?nlG03o_5d0okaL0200ok]K0P3o_5`0303o^e/0okaK0?nnH@3o_f<0okaJ0?nkFP3o_fD0okiP0?nk
F`3o_5/0okaM0?nlG1H0ok]K00D0okaL0?nkG03o^eX0okeN0?nnH@020?nkFP030?noHP3o_5X0ok]K
0080okaL4@3o^e/02P3o_5`0ok]K0?nmG@3o_V40okYI0?nkF`3o_V40ok]I0?nlG03o_5d<0?nkF`05
0?nlG03o^e/0ok]K0?nnH@3o_5`00P3o_V000`3o^e/0okaL0?nkF`0;0?nkF`070?nmGP3o_V00ok]K
0?nnH03o^e/0okaL0?nkG0070?nkF`030?nkG03o^e/0okaN0080okeM00<0ok]K0?nlG03o^e`01P3o
^e/01`3o_5`0ok]K0?nlGP3o_Eh0okaO0?nkF`3o_5`01@3o^e/0103o^e`0ok]J0?nmGP3o_V030?nl
G0D0ok]K0P3o_5d00`3o_Ed0okaL0?nkF`040?nkF`030?nlG03o_5d0okaL0080okaL103o^e/06@3o
_E`0okeO0?nkFP3o_5`0okeL0?nnG03aWDd0TU`^024A200_4``0Sd0Z0>mcB`3oSE`0ohaK0?n;F`3o
ReX0ohEF0?mnCP3oNTT0ogQ70?mlC03oQ580ohYI0?n=G@3oRe/0103oReX00`3oS5/0oh]K0?n;FP02
0?n;FP030?n<G03oS5d0ohaK00P0oh]J00<0oheN0?n<G@3oReX00P3oReX00`3oS5`0ohiN0?n;FP02
0?n;FP060?n:F@3oRUX0ogY:0?mhA`3oP500ohaK0`3oReX00`3oS5`0oi5T0?n:F@030?n;FP0:0?n8
F03oS5/0ohaK0?n>G`3oTF<0oi9U0?n<F`3oRe/0ohYI0?n9F0@0oh]J00D0ohaL0?n;FP3oReX0oh]J
0?n=G@040?n;FP050?n<G03oReX0oh]J0?n;FP3oSEh0103oReX00`3oS5/0oh]J0?n;FP020?n;FP03
0?n<G03oS5/0oh]J0080oh]J01T0ohaM0?n;G03oReX0oh]J0?n<F`3oReX0ohaL0?n;FP3oSE`0mGM>
08<e8P0?1P@0D1/E0?mQC`3oKUT0ofaH0?m`F`3oKUT0ofaF0?mVD@3oH4/0oe]60?mKA@3oH4T0ofMA
0080ofaH0100ofeI0?m_FP3oK5L0ofiJ0?m`FP3FE4@0GQdG00P30P0M20L0WBh]0?mDDP3oF5H0oeIE
0?mIE`3oF5L0oeYH0`3oEeD01@3oEUD0oeQF0?mHEP3oF5L0oeID00@0oeME00D0oeQF0?mHE`3oF5H0
oeQF0?mFE@040?mGE@040?mIE`3oF5H0oeUG0?mHEP<0oeME0140oeIE0?mGE@3oEU@0oeEC0?m?CP3o
C4X0odU70?m6A03oAD<0odI40?m7AP3oBTP0oda;0?mBD03oEUD0oeED0?mIF0020?mHEP<0oeME00L0
oeIE0?mGE@3oF5L0oeQF0?mJF03oEeD0oeYJ0080oeQF01@0oeME0?mHEP3oF5L0oeED0?mBDP3lBTT0
/CHe080R8P1<4a805`D501L:1@157a00QchQ09MI<03POD<0oieD0?nOE@3oXEL0oj9H0?nQEP<0oj1F
00T0oj5H0?nOEP3oX5D0ojAL0?nPE@3oXe/0oj9J0?nPEP3oX5L0303oX5H02P3oXEP0oj1F0?nSF@3o
Xe`0oj5E0?nQE`3oXe/0oj1E0?nQE`3oX5L?0?nPEP060?nQF03oXEL0oj1F0?nUGP3oY5`0oj5F0P3o
Y5`00`3oX5D0oj1G0?nPE`080?nPEP030?nQF03oXEL0oj5G00T0oj1F0P3oXEP02@3oX5D0oj=K0?nV
G`3oXUX0oj1E0?nTG@3oYEd0oj5H0?nPEP020?nPEa40oj1F0200oj5G0?nRF03oXUP0ojAI0?nSF03o
WeD0oiaD0?nJD`3oU500k8550<e`>`2fICH0RTl[080o8@1V;QP0CB8B024?1`0?2@<04`X401X@1P0h
8@h0H3TF08==7`27F2@0V7Xb0;n@>P3TYD@0mZi70?o=F@3od5D0om9J0?oDG0@0omIH00<0omAH0?oD
E`3oe5L05`3oe5L20?oEE`80omAG0140om=G0?oDF@3oe5X0omAI0?oDE`3odeH0omEL0?oFH03oeEl0
om=H0?oBEP3odeP0om9M0?o3B@3obDT0olE80?o5A`020?o4A`80olM900D0olE70?o4A`3oa4L0olA7
0?oRDP020?ohFP80ooUK00H0ooQJ0?oiF`3on5X0ooYJ0?oZF@3ocXgo0?oooiL0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWi@3oool05`3oo_l0ahMX09]B8@2X
F2H0Z5PX0:MH9`2UERD0[EXX0:YI:02WEbH0Z5PX0:MG9P2QEBD0oj=60?neCP3o]4l0okA=0?niE`3o
^UP0okaI0?nlG03o_V80okeQ0080ok]J00@0ok]K0?nkFP3o^eX0ok]J1@3o^e/0103o^eX0okeN0?nl
G03o_5`D0?nkF`050?nkFP3o^e/0okaN0?nlG@3o_f<00P3o^eX:0?nkF`80ok]J00X0ok]K0?njF@3o
_V40ol1X0?noH`3o^UP0ok]J0?nmH@3o_V40ok]J0P3o^e/00`3o_5X0ok]K0?nkF`0N0?nkF`80ok]J
00/0ok]K0?nmG@3o`6P0okiQ0?njF03o^ed0okiS0?nlG@3o^eX0ok]K0?nkFP0F0?nkF`80ok]J00T0
okaK0?o0I@3o_V80okYI0?nlH03o_F40okaL0?nkFP3o_5T04P3o^e/01`3o^UL0okiR0?o1I`3o^eX0
okeQ0?nlGP3o^eX03@3o^e/30?nkFP060?nnH`3o^UT0okaM0?nmH@3o^e/0ok]J1`3o^e/0203o^eX0
okeP0?nlGP3o_5X0okaM0?nnH`3o_5`0okeN2`3o^e/0103o^eP0okmT0?nlG03o_Ed20?nkFPL0ok]K
00H0ok]J0?nmGP3o_5h0okiN0?nkF`3o^eX50?nkF`060?nkFP3o^e/0okeQ0?nmG@3o_5`0ok]J1@3o
^e/0103o_5`0okeM0?nlG03o_5`50?nkF`040?nkFP3o_F00okiN0?nlG0@0ok]K00<0ok]J0?nkF`3o
_6400`3o^e/00`3o_E`0iIA8034K3002000000040;eA=@3oTEd0ohQG0?moC`80ogI600<0oga;0?n4
D`3oS5/00P3oReX00`3oR5X0oh]M0?n:F@030?n;FP030?n:F@3oS5/0oh]K00<0oh]J00<0ohYI0?n=
GP3oReX00P3oReX00`3oS5`0oh]L0?n;FP020?n;FP030?n:F@3oS5/0oh]K00<0oh]J00<0ohUH0?n;
F`3oReX00P3oReX01`3oP540ogM60?mnCP3oS5/0ohiN0?n=GP3oRUT00P3oReX02`3oREH0ohUH0?n;
FP3oRe`0ohaL0?nBIP3oSV00oh]J0?n7E`3oTfL0ohiQ0080oh]J00<0ohYI0?n6EP3oReX00P3oReX0
1`3oREP0ohYI0?n;FP3oReX0ohYI0?n@HP3oRUT00P3oReX00`3oSEh0oh]J0?n;FP020?n;FP060?n9
E`3oReX0oh]J0?n;FP3oSEh0oh]L103oReX00`3oSUl0oh]J0?n;FP020?n;FP030?n=G@3oReX0oh]J
0080oh]J00`0ohUH0?n;FP3oSE`0lWI=01P91P000000:@d:0?mTD03oKEP0ofaH0?m`F`3oKeT30?m/
F00E0?m]F@3oK5L0of5;0?mMA`3oFT<0oem90?mWD03oKeX0ofiI0?mcG03oJUH0c40d00X40`080`80
MAdL0?m?C@3oF5L0oeED0?mIF03oEE<0oeUG00<0oeME00@0oeIE0?mHE`3oEE<0oeUH103oEeD01@3o
F5H0oeQG0?mIE`3oFEP0oeIE00<0oeME00D0oeIE0?mIF03oEU@0oe]I0?mHEP040?mGE@040?mEE03o
F5H0oeYH0?mJF@@0oeME0P3oF5H04P3oE5<0odi<0?m:B@3oAdD0od500?m2@03o@D00od=10?m8AP3o
DDl0oeAB0?mFE03oF5H0oeQG0?mKF@3oEeD0of5P0?mFE@<0oeME00L0oeQF0?mKF@3oFeX0oe9A0?U2
@@2;8b808@P70080000000H0:18905LW5@2QB2L0o8Q90?n[G@3oXeT80?nPEP060?nSG03oXEL0ojIP
0?nSFP3oWe@0oj1E3@3oX5H01P3oWe@0oj9K0?nQF03oXED0ojMR0?nQF@80oj1E3`3oX5H0203oX5D0
oj1F0?nPEP3oXe`0oimD0?nREP3oYV00oj=K0`3oX5D@0?nPEP040?nSFP3oX5H0oj1F0?nPE@80oj1F
0P3oXe`01`3oX5H0oj5H0?nXIP3oYEh0oj1E0?nOE@3oX5D05@3oX5H0303oXeP0ojMK0?nYG03oZed0
ojEH0?n@C@3oQdP0ogm40>m/>P2LAB<0KBlH03XI30@0000001402PH2034N2`18:Q00HSTH0:QS:03g
TST0ok170?o>E03oh5h0omYI0?oIFP3oeUP0om=J0?oDE`3oeUl0omAJ0?oDEP0L0?oDE`80om9F00h0
omEG0?oBEP3oeEH0om=L0?oDGP3odUP0om9F0?o@D`3oef00omEU0?oDH@3oe5D0om=G0?oEEP80om9F
0`3oe5L02@3oad/0olA70?o7B@3oa4L0olE90?o5A`3oa4L0olM90?o5A`040?o4A`0;0?oKC`3on5X0
ooQJ0?ohFP3onE/0ooQJ0?ohF`3on5X0ooYJ0?o_F03ogh`0o`3ooonG0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinD0oooo00T0oo_o0<IdE02LDB@0YELV0:QH
:02VEbH0YeLV0:EF9@2WEbL00P2WEbH00`2SEBH0]f0Z0?nZB`030?ndCP090?nfDP3o^e/0okYH0?nl
G@3o`6L0okmU0?nkFP3o^UP0okaM0080okmU00X0okiP0?nkFP3o^e/0ok]J0?nlF@3o^e/0ok]L0?nk
F`3o_5`0okeO4P3o^e/01`3o^eX0okaM0?nmH03o^eX0okeQ0?nlF`3o^eX0403o^e/20?nkFP030?nk
F`3o^eX0ok]J0080okmU0P3o^UT01@3o_5`0okmU0?nlG@3o_5T0ok]K0080ok]J7`3o^e/20?nkFP0;
0?nkF`3o_El0ol5Y0?nnGP3o^UL0okeO0?noI03o_5`0ok]J0?nlFP3o^eX05@3o^e/0203o^eX0okaJ
0?nkFP3o_V<0okmV0?nkFP3o_F00okmV0`3o^eX@0?nkF`80ok]J00P0okaJ0?noIP3o_F40okUG0?nn
H@3o_5`0ok]K0?nkFP`0ok]K00P0ok]J0?nkF`3o_Uh0okmU0?nlF`3o_V80ok]K0?nkFPH0ok]K00X0
ok]J0?nlH@3o_5`0ok]K0?nkFP3o_E`0okiR0?nkFP3o_Ed0okeN0P3o^eX70?nkF`80ok]J00D0okeO
0?nkFP3o_V00okeN0?nkFP070?nkF`050?nlG03o_V80ok]J0?nmH03o_5/01P3o^e/01@3o^eX0okaN
0?nkG03o_Eh0ok]L00D0ok]K00@0ok]J0?nmGP3o_5`0okeM1`3o^e/00`3o_Ed0okiN0?nkFP040?nk
F`0A0?nkFP3o_Ed0okaL0?nkFP3o^e/0ol9N0?nLC01d?Qh00`8101<81@37Cc40ogQ70?mjB03oNdX0
oh=D0?n:F@3oS5/0103oReX00`3oS5d0oh]I0?n9F@030?n;FP030?n:F@3oS5/0oh]K00@0oh]J00H0
ohaK0?n;FP3oReX0oh]J0?n=GP3oS5/40?n;FP060?n<G03oRe/0oh]J0?n;FP3oS5`0oheN0`3oReX0
1P3oNDX0ogY90?n9F03oS5/0ohYI0?n9F0@0oh]J00X0ohmP0?n;G03oRe`0oheN0?nDJ@3oRUT0oh]J
0?n8F03oTfP0ohiQ0P3oReX00`3oRU/0ohiO0?n:FP020?n;FP040?n:F03oReX0oh]J0?n;FP80ohYI
0`3oReX01P3oS5h0ohYI0?n;FP3oReX0ohaM0?n<G080oh]J00<0ohaK0?n<G03oReX0103oReX01@3o
RUT0oh]J0?n;FP3oREP0oheN00<0oh]J00/0ohYI0?n9F03oReX0ohYI0?nCH01e;ah0000002l>2`3o
EdD0og1K0?m]F0020?m`F`<0ofaH0140ofeI0?m]E`3oKEP0ofeI0?mXD`3oGdP0oeU20?mLA@3oH4X0
ofiF0?mHAP1_8a`0000001l81`3@=3<0oeQH0?mHE`020?mGE@030?mLFP3oFEL0oeIE0080oeME00D0
oeED0?mHE`3oFEL0oeQG0?mEE0030?mGE@030?mED`3oFUT0oeUH00D0oeME00@0oeEC0?mIE`3oGE/0
oeID103oEeD01P3oEE@0oeME0?mHEP3oFEH0oeeM0?mEE0D0oeME00P0oeEC0?mIF03oFUP0oeeK0?mD
DP3oDDl0od]90?m5@`80od900140od500?m6A03oBTP0oda:0?mDD@3oGUd0oeQF0?mFE@3oF5H0oeME
0?mGEP3oFeT0oeYH0?m3A038<300NAhN01P61P020000000602TA2@2@@R<0og]30?nRE`3oZed0ojEI
1@3oX5H00`3oX5D0oimE0?nSF`020?nPE@030?nVH03oXEL0oj1E00/0oj1F0`3oX5D01`3oXe/0oj9I
0?nNDP3oYEh0oj=J0?nPEP3oX5D03P3oX5H20?nPE@060?nPEP3oXET0ojEO0?nND`3oX5D0ojIP0`3o
X5DC0?nPEP0=0?nPE@3oXEP0oj5F0?nPE`3oYV00oj5H0?nQE@3oYf40ojEQ0?nQE`3oX5H0oimD0?nP
E@0C0?nPEP0=0?nQEP3oYEX0ojYL0?n[G@3o[El0oiiE0?n1A03oMcl0j6Lg0:i?:P1M:A@0=aP;00/6
00040000000C01hC1P1H<a@0MT@K0:1O9P3MPc@0oj]50?o3C`3ohEh0on=O0?oLG03og5X0omIG0?oC
E`3oeUl0omAG0?oEE03oded0om9F0?oEEP0I0?oDE`0B0?oCEP3odUH0omAG0?oDE`3oe5T0omMP0?oF
G`3odUT0om5E0?oBEP3oeF00omET0?oCF@3oe5D0omAG0?oDEP3oe5D0om9F1P3oe5L02`3oeEP0oleA
0?o4A`3oa4L0olM90?o4A`3oaDT0olE70?o4A`3oadT0olE700@0olA700D0om]@0?ohFP3on5X0ooQJ
0?oiF`020?ohFP040?oiFP3on5T0onmH0?oNS?l0ooooU`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?ooo`040?oko`3:MeD0Y5DU0:AF9@80YePW00P0YeLV
0:EF9@2^G2X0Z5PW0:MG9P2ODbD0dVh_0?neCP<0okA>00H0okE?0?nkF`3o^e/0ok]K0?nlFP3o^eX2
0?nkF`0:0?nlG@3o`6H0ol1V0?nnH03o^UT0okYJ0?noI03o_fL0okmR0?njF080ok]K00<0okaK0?nl
G@3o^eX03P3o^e/01@3o^eX0okeM0?nmHP3o_5h0okeP0080ok]J5`3o^e/0403o^eX0okaJ0?nkF`3o
^UT0okaL0?noIP3o_5d0ok]H0?njF@3o_f<0okmU0?nkFP3o^UT0ok]K0?nlF@3o^eXN0?nkF`0;0?nl
F@3o^e/0ok]J0?nmG`3o_fD0okaL0?njF03o_f<0okiS0?nkFP3o^e/00P3o^eXD0?nkF`<0ok]J00P0
okeP0?noI`3o^eX0okaN0?o0I@3o_5d0okYJ0?nlFQ00ok]K0P3o^eX0203o_5T0okmQ0?njG03o^eP0
okmT0?nlGP3o^e/0okaI303o^e/01P3o^eX0okaL0?nnHP3o^eX0okaK0?nnH@80ok]J1@3o^e/02`3o
_Eh0ok]J0?nkF`3o^e/0ok]J0?nkF`3o_Ed0okeN0?nmHP3o_640okYI00X0ok]K00D0okiP0?nmG@3o
_5l0okaL0?njF@060?nkF`070?nkFP3o^e/0okeP0?nmG@3o_Uh0okYI0?nkFP050?nkF`040?njF@3o
_F00ok]K0?nmG@H0ok]K00@0ok]J0?nmG@3o_Uh0okaK1@3o^e/0103o_5`0okeM0?nlG03o^e`40?nk
F`0>0?nlG03o^eX0okaL0?nkF`3o_5/0olEQ0?nlG03:JS003`P30000001i;AX0ofPo0?n<FP3oSE`2
0?n:F@030?n=G@3oReX0oh]J0080oh]J00<0oh]I0?n;FP3oReX00`3oReX00`3oRUT0ohaK0?n;FP03
0?n;FP80ohYI0P3oReX00`3oRUT0oh]I0?n:F@020?n;FP030?n:F@3oS5`0ohaM0080oh]J00P0ohYI
0?n;G@3oReX0ohaK0?n6E@3oMdL0oh5A0?n8FP80oh]J00X0oi1R0?n:F`3oRUT0oheN0?n<G03oU6L0
ohaL0?n:F@3oReX0ohmP0P3oReX03`3oR5P0oi5T0?n=H03oReX0ohUI0?n>G`3oUVX0ohYI0?n;FP3o
RUT0oi9U0?n;F`3oReX0ohYI0?n<F`040?n;FP060?n9F03oReX0oh]J0?n;FP3oS5`0ohQJ1`3oReX0
1`3oS5h0ohaL0?n;FP3oReX0ohYI0?n<GP3oRe`00P3oReX03@3oRUT0oh]J0?n;G03oReX0ohmM0=1E
=P060P40;`h;0?mGA@3oLe`0ofeH0?m`F@3oL5/00P3oK5P0103oK5L0og1K0?m_FP3oKEP20?m/F007
0?m]F@3oK5H0of9;0?mJA@3oGDH0f4Lf02@<2P02000000070<8f=@3oFeX0oeQF0?mEE03oFUP0oeQF
0?mEE0040?mGE@80oeUH00H0oeEC0?mGE@3oEeD0oeME0?mEE03oF5H20?mIE`060?mEE03oEeD0oeME
0?mGE@3oEE<0oeUH0P3oFEL02`3oEE@0oeME0?mGE@3oEeD0oeED0?mFE03oFeT0oeQF0?mIE`3oEU@0
oeED00@0oeME00L0oeIE0?mIF03oFEL0oeUG0?mHE`3oEE@0oeMF0080oeQF0140oe9@0?m<B`3oC4X0
odQ60?m1@03o@T00ocln0?m5@`3oB4L0ode;0?mAC`3oF5H0oeeL0?mEE03oA4@0V2HV02X;2`020000
000701T<1`26>b00cUdb0?mk@`3oYEX0ojIK0?nRE`040?nPEP070?nPE@3oX5H0ojAJ0?nVG`3oX5D0
oj=K0?nPEP020?nPE@/0oj1F0P3oX5D01@3oYUl0oj=M0?nNDP3oY5`0oj9I0080oj1E3P3oX5H20?nP
E@090?nPEP3oYUl0ojIO0?nPEP3oXEP0ojIP0?nOE03oWeD0oj1E0180oj1F0`3oX5D0203oX5L0ojIP
0?nSFP3oXEL0oj9K0?nUG`3oXEP0oj1F0P3oX5DC0?nPEP0<0?nRE`3oYU/0oj]M0?n^G`3oZed0oi9>
0?aa>`3QI3@0Z4`Z07Tg7@0e5PX06P`5100000005P091`40ART?09EG8`2hJR`0fWde0?bO?`3o`4h0
omEF0?oYH@3ohUh0om]L0?oIFP3odeL0omEG0?oFE@3odUP0omEP0?oBF03oeUl0omAG0?oEEP3odeLE
0?oDE`0B0?oEEP3oe5D0omEF0?oDE`3oe5D0om9F0?oFH@3oe680omEH0?oBE03odeP0omAQ0?oEH03o
dUT0omEF0?oDE`3odUH0omAE2`3oe5L00`3oeEP0om=F0?o6BP020?o4A`060?o6A`3oaDT0olE90?o5
A`3oa4L0olE70`3oa4L00`3oaDT0olI70?oECP050?ohFP050?oiF@3on5T0ooMI0?ocF@3olXl0o`3o
oonG0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinD0oooo
00h0oo_o0;i_C`2PE2D0Y5DV0:=E9P2VEbH0YePW0:MG9`2XF2P0YePW0:IG9P2QEBD0jGXd0?niD@<0
okA>00@0okE?0?ngDP3o^eX0ok]L2P3o^e/0303o_5h0okeO0?nmG@3o^eX0ok]I0?nlF`3o_f@0okiU
0?nlF`3o^e/0okaL0?nnH@80okmR00<0okaK0?nkF`3o^e/00`3o^e/01`3o_Ed0okiP0?nmG@3o_5d0
ok]K0?nlG@3o^e`07`3o^e/0103o_5/0ok]K0?nkF`3o^e/20?nmGP070?nkF`3o^eX0okeO0?noI03o
_f40ok]J0?nlF`020?noH`030?nlG@3o^e/0ok]K01h0ok]K00/0okeN0?nlGP3o^e/0ok]I0?nnHP3o
_F00ok]I0?nkFP3o_V40okaL0?nkFP0C0?nkF`0<0?nlFP3o^e/0okaL0?nmGP3o_5`0okYH0?nnH`3o
^e/0ok]J0?nlG03o_F00ok]J403o^e/02@3o_5X0okaN0?nlF`3o_5`0ol1T0?nlG@3o_5`0okiQ0?nk
FP0<0?nkF`070?nlG03o_5d0ok]K0?noHP3o_5`0okeM0?nlGP030?nkF`030?nkFP3o_Ed0okaL00@0
ok]K00L0okaM0?nlG03o^e/0okiQ0?nkF@3o_V40okaL00P0ok]K00H0okaM0?nkF@3o_f40okeM0?nm
G`3o^eX60?nkF`050?nlG03o_5/0okeO0?nmG`3o_Ed01`3o^e/01@3o_5`0okeN0?nlG03o_Ed0okaL
00@0ok]K00@0okaK0?nlG03o_Ed0okeM1@3o^e/30?nlG0030?nlG@3o^e/0ok]K0080ok]K00h0okaL
0?nmGP3o]eL0ok5A0?n]C@3o[DX0fHTm06dj7@0;1P<06`/709=5;@3oP5D0oheL0?n;FP80ohaL00D0
ohaK0?n;FP3oReX0oh]J0?n:F@020?n<G0<0oh]J00<0ohYJ0?n<G@3oRe/00`3oReX00`3oRUX0oh]J
0?n;FP020?n;FP030?n;F`3oS5/0oh]J0080oh]J00l0oheL0?n;F`3oReX0oh]J0?n<F`3oS5d0ohEE
0?mjBP3oOD`0ohaL0?n:F@3oS5/0ohiN0?n9F03oSf800P3oS5`00`3oRUX0ohUH0?n:F@020?n;FP05
0?n:F03oREP0oh]J0?n;FP3oRUT00P3oReX0303oRET0ohiO0?nDJ03oRUT0oh]J0?n:F@3oUfX0oh]K
0?n;FP3oRUT0ohmQ0?n=GP80oh]J00H0ohaK0?n=GP3oReX0oh]J0?n:F@3oS5d20?n;FP030?n:FP3o
SEd0ohYI0080oh]J00<0ohaK0?n:F@3oReX00P3oReX20?n<G@80oh]J00`0ohYJ0?n;G@3oSEd0oh]K
0?moD`2?>2@01P<205@L5P3oIU80og9L0?m]E`3oKEP30?m/F0030?m]F03oL5/0ofmJ0080ofaH00d0
ofeI0?m_FP3oKEL0ofiI0?m_FP3PEdH0TblT01P71P0h2`/0V2<R0>hm?03oDe80oeED0080oeUG00D0
oeME0?mFE@3oEeD0oeME0?mHE`020?mIE`@0oeME00D0oeED0?mHE`3oFeT0oeED0?mHE`030?mGE@05
0?mHEP3oEeH0oeYH0?mFE@3oF5H00`3oEeD01P3oEUD0oeQF0?mKF@3oFEL0oeME0?mHEP@0oeME00@0
oeUG0?mJF03oEU@0oeUH0P3oF5H50?mGE@0I0?mIE`3oFUP0oeQF0?mKF`3oEU@0oeAC0?mDD@3oD4h0
oda;0?m6A03l?C`0a38a09<T8`1<4a80;@/;01H61P0_50X0P3TN09=@:`35K3X0nHm=0?nOEP3oYeX0
oj=I0?nQE`030?nPEP070?nQE`3oY5/0oj5E0?nRFP3oXUT0oj5H0?nRF@0<0?nPEP080?nPE@3oXe/0
oiiC0?nRF@3oY5l0oj5F0?nRF@3oXUP@0?nPEP060?nTG03oXUT0oimD0?nUGP3oYEl0oj1E0P3oXUTC
0?nPEP030?nPE@3oXUP0ojAL0080oj1E0P3oY5d0203oWe@0oj5G0?nRF@3oXEP0oj1F0?nQF03oXET0
oj5G3P3oX5H0803oXEL0oj9H0?nSF03oXUL0oiEA0?25B037M3h0[F/j0:1P=02AB2H0KS4I05<U500h
6@h09Q4900h60`0C2`@0;QX:05Lc5020C1l0P5HT09U[;02jQSH0iJQ50?RiC03o`Dl0olQD0?oEF03o
g5/0omeK0?oJFP3oeeT0omIH0P3oe5L02@3odeH0omIK0?oFF`3odeT0omEM0?oBEP3oeEX0omAH0?oC
E`0?0?oDE`040?oEE`3oe5L0omAG0?oCE`80omAM00H0omAN0?oCEP3odeH0omEL0?oEH@3oeEl20?oC
EP060?oCE`3oeE/0om=J0?oDE`3oe5H0omAG0P3odeL00`3oeEL0omAG0?oDE`0>0?oDE`060?o:C03o
a4L0olA70?o4A`3oaTL0olE90P3oa4L00`3oaDL0olI80?o4A`020?o4A`080?o5B@3oaTL0olU:0?oh
FP3onE/0ooQJ0?oiFP3onET30?ofF@030?oiE`3oniT0oooo0?l0ooooUP3oool0103YjNT0dM7A0=7A
d@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?ooo`0>0?ojo`2lKDX0XU@U0:EE9P2R
E2D0XeLV0:MH9`2WEbL0YeLV0:]J:02TERD0]Ul[0?nLA03o]e030?ndCP80okE>00<0okQC0?nkG03o
^e/03`3o^e/20?nkFP040?nkF`3o^eX0okeN0?nlG@80okeM00/0ok]K0?njF@3o^UT0ol1V0?o0I@3o
_Ed0okYI0?nlG03o^e/0ok]L0?nlG00Z0?nkF`040?nkFP3o^e/0ok]K0?nkF`80okaN00H0ok]L0?nk
F@3o`6D0ol5Y0?o1J03o^eX20?nkF`030?nkG03o^e/0ok]K01h0ok]K00T0okaM0?nkF`3o^eX0ok]H
0?o2J@3o_Eh0okYH0?nkF`3o^e`05`3o^e/01`3o_Ed0okYH0?nnGP3o`FT0okaM0?nkF`3o^e`03`3o
^e/0203o^eX0ok]K0?nlF`3o_Ed0ok]J0?nnGP3o`6<0okYI3P3o^e/20?nlG0030?njF@3o_V<0okeO
0080ok]K00<0okeO0?nkFP3o^e/01`3o^e/00`3o_Ed0okaI0?noHP020?nkFPT0ok]K00D0okaL0?nk
F`3o_f@0okeN0?nkFP070?nkF`040?nlG03o^eX0okmT0?nlG0L0ok]K00@0okaL0?nlG@3o_Eh0ok]J
1P3o^e/00`3o_Uh0okeM0?nkF`040?nkF`80ok]L0180okiS0?njF03o^e/0ok]K0?nhF03o[Tl0ojQ9
0?nTAP3oZ4P0okAD0?nlG03o_U/0oim?05D^5P000000;14;0>YN?P3oSE`20?n;F`030?n;FP3oS5l0
oh]J00<0oh]J00<0oheM0?n:F@3oReX00`3oReX00`3oSf00ohYK0?n;FP020?n;FP030?n<F`3oReX0
oh]J0080oh]J00<0oheN0?n9F@3oReX00P3oReX04`3oS5`0oh]J0?n;FP3oS5/0ohQH0?mjBP3oMdH0
ohIE0?n?HP3oSEh0ohUH0?n;G03oReX0ohiO0?n;F`3oReX0ohYI0?n>H@3oSf800P3oReX02`3oRU/0
oi1S0?n;FP3oReX0ohUH0?n:F@3oReX0ohUI0?n>G`3oU6P0ohYI0080oh]J00D0ohmR0?n;F`3oReX0
oh]J0?n9F0030?n;FP060?n<G03oReX0oh]J0?n8F03oT6<0ohaL0P3oReX20?n<G0<0oh]J00H0ohaK
0?n;FP3oReX0oh]J0?n;F`3oRU/20?n;FP0=0?n;F`3oSV00oh]J0?n;FP3oOE80<Q<<0000000]3@/0
ofIA0?m]F03oLE`0ofaH0?m]F0020?m/F0030?m]F@3oKeX0ofaH0080ofaH00l0ofeH0?maG03oKUT0
ofmI0?mXE01U8AX01P810000001m7al0oe9@0?m8B03o@T80od=10?m7A@3oDe400`3oEeD00`3oEE<0
oeiM0?mGE@040?mGE@040?mFE03oFeT0oeME0?mHEP<0oeME00D0oeIE0?mHEP3oFeT0oeED0?mHEP04
0?mGE@040?mFE03oGE/0oeQF0?mHEPH0oeME00H0oeEC0?mKFP3oEE<0oeQF0?mGE@3oEUD50?mGE@0G
0?mCDP3oHF00oeID0?mHEP3oEE@0oeME0?mGEP3oEUD0oeME0?mCD`2i;Rh0:0T901820`0000000P40
02D?1P2:?Ad0n6/c0?n9@03oTTH0oi=80?nFB`3oVe400`3oX5H01P3oX5L0oimD0?nSG@3oYf40oj1E
0?nRF@`0oj1F00L0oj5H0?nPEP3oXEP0ojQT0?nOE03oX5D0oj5H0080oj1F00<0oj1E0?nPEP3oX5H0
303oX5H0203oX5D0oiiB0?nWH`3oW540oj1F0?nQF@3oXEP0oj1F0P3oWeD@0?nPEP090?nPE`3oX5H0
oj5E0?nND`3oZ6@0oj1E0?nOE03oXEP0oj9I00/0oj1F00<0oj9J0?nPE@3oX5H0103oX5H40?nRE`0:
0?nQEP3oWeD0oimF0?n?C@3oMCd0[T`W05dY5@0V4@P060X500T40P<0000000h00@0001X@1@1N=QD0
T5@P0>26=@3o]D/0ol=A0?o7DP3od5D0omUJ0?oLF`3ofEX0omUI0?oEF0T0omAG00D0om9D0?oEG`3o
dUH0omEG0?oDFP0?0?oDE`0:0?oBF03odeP0omAG0?oBEP3od5@0omER0?oEI`3odel0om1D0?oCE`80
omAJ00H0om9K0?oDE`3oe5L0omAG0?oEEP3oeELJ0?oDE`030?o>D`3o`dH0olA700<0olA700D0olE7
0?o4A`3oa4L0olA70?o7B@030?o4A`060?o5B@3oaTL0olI80?ogF@3onE/0ooUI1@3omUT00`3onE@0
oo5m0?oVa03o0?oooiH0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWi@3oool03P3on_l0^6Y90:1D9P2RE2D0Y5HU0:=E9P2SERL0YELV0:MG9P2VEbH0XUHU0<=U
;P3o/D`0okE@0`3o]4h20?neCP030?nfD@3o^eP0ok]L01<0ok]K00P0okaL0?nmGP3o_5`0ok]K0?nl
G03o^eP0okeP0?o1I@<0ok]K00/0okYH0?nnH03o`V/0ol5/0?nmGP3o^eT0ok]K0?nlG@3o_Ed0okaM
0?nkFP020?nkF`80ok]J:03o^e/0303o_5`0ok]L0?nkFP3o^UT0ol5W0?o1JP3o_5h0ok]J0?nkF`3o
_5h0okaL0?nkFP80ok]K00<0ok]J0?nkF`3o^e/06@3o^e/02P3o_5`0ok]K0?njF03o_Uh0ol5X0?nj
F@3o^eX0okaL0?nmG@3o^eXE0?nkF`080?nlG03o^e/0okeM0?o1J03o_V<0ok]I0?nmG@3o_5`20?nk
F`030?nkFP3o^e/0ok]K00`0ok]K00L0okaK0?nkFP3o`6D0ol1V0?nkFP3o_Ed0okaL00h0ok]K00D0
okiS0?o1I@3o_E`0ok]L0?nkFP090?nkF`040?nkG03o^UP0okiN0?nnH`80okaL2@3o^e/0103o^eX0
okiR0?nkF`3o_5d80?nkF`040?nkFP3o_El0ok]K0?nlG0H0ok]K00@0okYI0?nnH`3o^UT0okaL1P3o
^e/00`3o_F00okaL0?nkF`050?nkF`0>0?nlG@3o^ed0ok9C0?nYB@3oZ4L0ojY90?nbDP3o^e`0okeN
0?nkF`3o_5/0okiL0?ndF01W=Q/20000000408Th903oQ5L0ohaK0?n;FP80oh]L0`3oReX00`3oRe/0
ohiQ0?n9F0030?n;FP030?n:F@3oSUl0oh]K0080oh]J00<0ohYI0?n<G@3oRET01`3oReX03@3oSEh0
oh]J0?n;FP3oRe/0ogi>0?mgAP3oMDL0oh]L0?n;FP3oRUT0oh]J0?n:FP3oReX00P3oRUT0103oReX0
ohYI0?n?H03oSf020?n;FP0;0?n:F`3oU6P0oh]J0?n;FP3oRUT0ohUH0?n;FP3oRET0ohiO0?nDJ03o
RUT00P3oReX01@3oR5L0oh]J0?n;FP3oRUT0ohUH00<0oh]J00D0oi9V0?n;FP3oReX0oh]J0?n9F003
0?n;FP030?n:F@3oReX0oh]J0080oh]J00H0ohaL0?n;FP3oReX0oh]J0?n=G`3oRUT20?n;FP0A0?n<
F`3oREP0ohaK0?n?G@2H?bX0000002h?303oG4T0ofmI0?m]F@3oKEL0og5L0?m]F@3oK5P0ofiI0?m^
F03oK5L00P3oK5P05@3oKUT0ofeG0?m_F@3oKeX0ofaG07<T7@0000002@82070L6`3oDE00oeMF0?mG
E@3oDe40odI50?m3@@3oA480odU70?mED`3oFEP0oeaJ0?mHEP030?mGE@040?mHEP3oFUP0oeUG0?mE
D`D0oeME00<0oeYH0?mGE@3oEeD0103oEeD00`3oF5H0oe]J0?mEE0060?mGE@050?mHEP3oEeD0oeaJ
0?mIF03oEUD01P3oEeD08@3oF5H0oeYI0?mKF@3oEE@0oeQF0?mGE@3oEeH0oeUH0?mGEP3oD500lC/i
080P7`0O1@D00@000000000E2@<0?Qd?0=9W>03oWED0oiaC0?nLD03oU4P0ohm40?n>@`3oSD80ohi3
0?n?A03oUD/0oiU<0?nUGP3oX5D0oj1G0?nQE`0;0?nPEP070?nPE`3oXEL0oj1F0?nYI03oXe`0oimD
0?nPE`0<0?nPEP080?nOE@3oX5H0oj1F0?nQF@3oXUT0oimD0?nSG03oYV420?nPE@030?nQF03oX5H0
oj1F00h0oj1F00`0oj1E0?nPEP3oX5H0oj5H0?nQF@3oX5D0oiiB0?nWH`3oXe/0oimD0?nPEP3oXEP?
0?nPEP0?0?nQF03oXUX0oj9G0?nSF@3oYEX0oj=H0?nNE@3oVe<0oiMA0?nACP3oMCh0f5la07Pe6`0T
40P00P0000<0000000`00`8000/70P0O4`L0D2lB09IE8P38LRd0ojY60?o>E@3odEH0om=F0?oDF03o
eUP20?oGF0030?oEF03oe5L0omAG00P0omAG00D0om9H0?oDE`3ode/0omER0?oCD`080?oDE`030?oE
E`3oeEH0omAG0080omAG0P3oe5X02`3odU/0omAF0?oBE03oeE@0omEW0?oFI03oe5D0om5E0?oDE`3o
deP0om9H02@0omAG00<0omEH0?o:CP3oa4L01P3oa4L0303oaDL0olA70?o7B@3oa4L0olI80?o4A`3o
aDT0olI70?o5B03olEP0ooYK0?ogF080ooII00H0ooQI0?ofF@3omUT0ooaG0?oRI`3o_HWo0?oooiH0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWi@3oool03P3o
nOl0]fY70:9E9`2RE2D0YEHW0:9D9@2SEBH0YEHV0:EG9P2[FRL0XU@U0<e/;`3o^U80okE?0`3o]4h0
103o]Dl0okE>0?neCP3o^5<E0?nkF`060?njF@3o_V80okeM0?nlGP3o_5`0ok]J1P3o^e/20?nkFP09
0?nkF`3o^eX0okYI0?o0IP3o`VX0okmS0?njE`3o^UX0ok]J0080okeP00<0okaL0?nkFP3o^e/00`3o
^eXY0?nkF`080?njF03o_5`0ol5/0?noH`3o^UL0ok]J0?nmGP3o_F030?nkF`80ok]J703o^e/01`3o
^UT0okiS0?o0I`3o^EL0ok]K0?nnGP3o_Eh00P3o^e/00`3o^eX0ok]K0?nkF`0B0?nkF`090?nlF`3o
`VT0okiR0?njF@3o_5d0okeP0?nkFP3o^e/0ok]J00l0ok]K00D0okaL0?o0J03o_V00okYI0?nnGP02
0?nkF`030?nkFP3o^e/0ok]K00T0ok]K00L0okaL0?nnH`3o^e/0okaL0?nlG@3o^e/0ok]J00T0ok]K
00H0okaN0?nmH@3o^eX0okeN0?nlF`3o^eX70?nkF`050?njF@3o`6L0okaL0?nlG03o^eX01P3o^e/0
1P3o^eX0okaQ0?noH03o^e/0okaL0?nkFPH0ok]K00@0okeO0?nmG@3o_5`0ok]J103o^e/00`3o_5h0
okaL0?nlG0020?nkF`080?nlG03o^e/0okUH0?n^CP3oYDD0ojM70?nZBP3o]UH20?nkF`0@0?njF@3o
_F00ok]K0?nkFP3o_5/0oj]C05P_5`040@40000008Xh903oR5T0oi1M0?n;FP3oS5/0oh]N0?n:F`<0
oh]J00<0ohaK0?n9F03oReX00P3oReX00`3oRUT0ohaM0?n;FP020?n;FP80ohaL0`3oReX00`3oREP0
ohUI0?n;FP020?n;FP0;0?n?H03oRU/0ohUI0?mbA03oLd@0oh=B0?n;FP3oRUT0ohiO0?n?HP3oRUT0
0P3oReX01@3oTF<0oh]J0?n;FP3oR5P0ohUH0080oh]J00<0ohaL0?nEJ03oReX00P3oReX01@3oREP0
oh]J0?n;FP3oReh0oi9V0080oh]J00H0ohMG0?n:F@3oReX0ohYI0?n>H@3oTFD20?n;FP060?n:F@3o
REH0oh]J0?n;FP3oSEh0oh]L0P3oReX01`3oRET0oi1Q0?n;FP3oReX0ohQJ0?n?H03oRe/00P3oReX0
;@3oSEh0oh]L0?n;FP3oReX0ohYI0?n;F`3oS5/0oi1N0?mZAP0H2PH09`d:0?mKB@3oKUT0ofiJ0?m]
F@3oJeD0ofaH0?m^F03oKUT0og5L0?m]E`3oK5P0ofaG0?m]E`3oLUd0ofiI0?maF`3oGDX0KR<L0000
000Z2PX0dcDc0?mFE@3oEeH0oeME0?mIE`3oFeT0oeAB0?m7A@3o@d80od=10?m6A@3oDe80oeID0?mH
EP020?mGE@030?mHEP3oFEL0oeMF00@0oeME00@0oeQF0?mGE@3oFEP0oeQF103oEeD0103oEeH0oeME
0?mKF@3oF5H50?mGE@80oeQF00<0oe]J0?mED`3oEeD01@3oEeD03@3oF5H0oeME0?mHEP3oGEd0oeMF
0?mGE@3oEUD0oeUG0?mJF@3oDU00odY;0>@h=`124A000P00000010030@00>AX>09a69@3oOTD20?nS
F@0@0?nQEP3oX5H0oj1F0?nPEP3oW540oiU=0?nGC@3oTDH0ohM00?n8?`3oSd<0oi150?nGC03oVe40
oieC0?nPE@80oj5G0`3oX5H20?nPE@060?nRFP3oX5L0oiiC0?nTGP3oXe/0oj1E3@3oX5H02@3oX5D0
oj1F0?nPEP3oXe/0oj9J0?nPE@3oYf<0ojMQ0?nNDP0A0?nPEP0:0?nPE@3oWeD0oj1F0?nRF03oXe`0
oj1G0?nPE03oYEh0ojMR0?nNDQ80oj1F00`0oj9G0?nTF@3oY5X0ojYL0?nVG03oVU<0oi=>0?n9B@3o
N440_UD/09Y48P1981040000000=00<3000F30@09QH804T[4P2<DR00b7<]0?J?>@3oaU80omYK0?oG
F@3of5X0omMH0?oCE`0=0?oDE`060?oEEP3oeEL0omEK0?oDE`3ode/0omAK1P3oe5L03P3oeEH0om9F
0?oDE`3oe5L0om9F0?oDFP3ode`0omEK0?oEEP3oe5D0omAQ0?oEIP3oeFL0omEG0P3oe5L00`3oeEH0
omAG0?oDE`0X0?oDE`030?oAE@3oadT0olA700H0olA701@0olE70?o4A`3oaTT0olA70?o6B03oa4L0
olI90?o6AP3o`dL0onME0?odF@3om5L0ooMI0?oiF@3onUX0ooUJ0?ofF@3ooUP0on5Q0?niOOl0oooo
UP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?ooo`0=
0?okoP33LDh0XEDW0:9E9`2RE2H0Y5HW0:9E9P2SEBH0XeHV0:IG9`2/FRL0nX`n0?njDP030?ndCP80
okE?0`3o]Dh00`3o^eT0ok]K0?nkF`0?0?nkF`080?nmG@3o_5`0okeO0?nlF`3o_5`0okaM0?nlG03o
_E`A0?nkF`070?nkF@3o_f40okiQ0?nlG03o^eX0ok]K0?noI0020?noI@0:0?nlF`3o^eX0okaL0?nm
H03o_V00ok]K0?nkFP3o^e/0okaK0?nlFR@0ok]K00P0ok]J0?nmG`3o_f40ok]K0?njF@3o_5`0okmT
0?nmH@80ok]J00H0okiN0?nnG`3o_5`0ok]J0?nkF`3o_5XI0?nkF`0:0?nnH03o_El0ok]J0?nkF`3o
_V@0okeP0?njF@3o_5`0okiO0?nlG080ok]K00<0okaJ0?nkF`3o^e/03P3o^e/02@3o_Eh0okiQ0?nk
F@3o^e/0okiS0?nkF`3o^eX0okeO0?nlG@0?0?nkF`080?nnG`3o^e/0okaK0?noH`3o_Ed0okaM0?nn
G`3o_5`90?nkF`080?nkFP3o_5`0okiO0?nkF`3o_f<0okaL0?nlG@3o_5`90?nkF`040?nmG`3o_E`0
okeQ0?nkF`80okaL1`3o^e/01@3o_Ed0ok]J0?nlH03o^e`0okaL00H0ok]K0P3o_5`0103o_V80okaI
0?nlG@3o_5/30?nkF`050?nlG03o_Eh0okaL0?nmH03o_5d0103o^e/20?nlG00;0?nnG`3o^U/0ok9B
0?n]C@3oZ4P0ojY:0?naD@3o]ED0okaL0?nmG@3o^eX00P3o^e/03`3o_5`0okaK0?nnH@3o^eX0okiM
0?nmF`3KTdP0STlV01P=1P1?7a@0Y4`b0?9gCP3oSE`0ohYJ0?n=GP020?n<F`80oh]J00<0ohYI0?n<
G@3oRe/00P3oReX00`3oS5`0oheN0?n;F`020?n;FP0B0?n<G03oSEh0ohaL0?n;FP3oRUX0ohiO0?n>
GP3oS5`0oi1R0?n9F03oSEh0oh1A0?mgAP3oPU80ohaL0?n;F`3oReX0ohUI0P3oS5`20?n;FP060?n;
G03oRe/0oh]J0?n;FP3oT680oheM0P3oReX02@3oREP0oh]J0?n;FP3oReX0ohYI0?n;FP3oRET0ohiO
0?nDJ0020?n:F@060?n?H03oRU/0oh]J0?n:F@3oRUX0ohaL0P3oReX01@3oT680ohYK0?n;FP3oRe`0
oheM0080oh]J00H0oh]K0?n>GP3oReX0oh]J0?n;F`3oS5`20?n;FP030?n:FP3oSEd0ohaL0080oh]J
0100oh]K0?n;FP3oS5`0og]A09Lm:00H2PH0CQTC0?mQCP3oKUT0og1J0?m_FP3oKEP0ofaH0?m]F03o
KeT0ofiH0P3oKET0303oKUX0ofeH0?m^F03oLE/0geM706XR6`0H1`H05`H608dY:03oDE00oeQF0?mH
E`80oeUG0180oeED0?mGE@3oEeH0oeID0?mGEP3oCdd0odQ60?m3@@3oAT@0oda:0?mED`3oEU@0oeUH
0?mEE03oEeD0oeID0?mHE`3oEU@20?mIE`080?mFE03oEeD0oeME0?mHEP3oF5L0oeME0?mJF03oF5L5
0?mGE@060?mHE`3oFEL0oeQF0?mHEP3oF5L0oeIE0P3oEeD01@3oEU@0oeQG0?mGE@3oFEL0oe]I0080
oeQF0140oeMF0?mIF03oF5L0odi=0=Y4A02c=3@0O20P03d@3`090@408Q09058U502JCBX0/fXj0=n2
AP3oWED0ojEI0?nRF0030?nPEP0I0?nSFP3oXEH0oj=L0?nQE`3oWe@0ojAL0?nPE`3oWE80oi]A0?nH
CP3oU4X0oi160?n?A@3oSd@0oi560?nCB03oUT/0oiQ>0?nLDP3oXEX0ojAN0?nQE`3oXeX0oj5H0?nP
E@0<0?nPEP090?nQE`3oXeX0oj5F0?nPE@3oYF00oj5H0?nPE`3oY5`0oj=J0100oj1F00`0oj5G0?nS
FP3oXUX0oj1F0?nQF03oYEl0oj=L0?nOE03oXUP0ojAM0?nQF03oX5D<0?nPEP0Q0?nRE`3oXUP0ojAI
0?nVFP3oYU/0oiaD0?nHDP3oSdd0jHE80<E^>`2eI3D0We<]084l801V;QT0B20A03@H300=1P808A@7
02hJ2`14:140HCXG091G8P2LJR/0YgTa0;jG?`3T[4H0nkI<0?o3D03oeeT0om]J0?oHFP3oeeT0omIH
00d0omAG0P3oeEL02P3oe5P0omEI0?oEEP3oeEl0omAH0?oFFP3oeEP0omAF0?oEE`3oeEP20?oCG00>
0?oDF03odeH0omAD0?oFG`3oeV40omEK0?oCEP3odUH0omEK0?oEG@3oe5`0omAF0?oDE`3oeEL20?oC
Eb`0omAG01l0omEG0?oDEP3ob4`0olI70?o5B03o`dL0ol960?o3A`3oa4L0olI70?o6B03oa4L0okm6
0?o2B03o_TH0olI90?o5A`3oadT0ol=60?o1A`3ocT`0ooEI0?oaE`3omUT0ooQJ0?oiFP3oneX0ooMI
0?ocE`3oheX0oli_0?l0ooooUP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOU0?ooo`0=0?o2[02/GSD0X5@V0:9E9`2RE2D0XUDV0:9F9@2RE2H0XU@U0:=E9P2l
HRX0oje;0?nfD@030?ndCPD0okE>00<0okMC0?nkF`3o^e/02`3o^e/20?nkFP050?nnH@3o^UT0okiP
0?nmG@3o^eX00`3o^e/0103o^eX0okeP0?nlG@3o^eXE0?nkF`0>0?nkFP3o_5T0okaI0?nkF`3o^UT0
okaM0?o0I03o_fD0ok]J0?njF@3o^UP0okiR0?o0I`3o`6@20?nkFP030?nkF`3o_5T0okaI02@0ok]K
00l0okaJ0?nkFP3o^e/0ok]J0?noHP3o_V<0okaM0?njF@3o_Ed0ol1W0?noI@3o^UP0ok]K0?nkFP3o
_5T0603o^e/02`3o^eX0ok]K0?nkFP3o_Ed0okiS0?nlGP3o^UT0okeP0?o0J03o_Eh0ok]K0080ok]J
403o^e/02@3o^eX0ok]K0?nlF@3o_f@0okeN0?nkF`3o`6@0okmU0?nkF`020?nkFP`0ok]K00P0ok]J
0?nkF`3o_Eh0okiS0?nkF`3o_5h0okiS0?nkFPP0ok]K00T0okeM0?nmFP3o^UT0ok]J0?nmG`3o_Ed0
okYI0?nnH`3o_5h00P3o^eX60?nkF`80ok]J00D0okiN0?nlG@3o_V<0okeQ0?nkF0060?nkF`80ok]J
00D0okeO0?nkFP3o_V80okaL0?nkFP040?nkF`060?nlF@3o_5`0okeP0?nlGP3o_5`0okaI103o^e/0
3`3o^eX0okaN0?nkFP3o_V80okaL0?nkF`3o_5`0okYJ0?nbDP3oZDX0ojE50?nYB@3o/580okYJ0?nl
G0020?nkF`040?nlGP3o^eX0okeP0?nkFP80ok]K0P3o^eX02P3o_Eh0okaL0?nlF`3oc6@0fhQ201D;
1@0000002`D30<MK?@3oUF<20?n;FP060?n=G@3oRET0oh]J0?n;FP3oRUX0ohaO0P3oReX0103oRUX0
oh]K0?n?H03oS5/20?n;FP0<0?n8F03oRe/0oheN0?n=G03oReX0oheN0?n;FP3oRUT0oh]J0?n7E`3o
MdL0oh5A0P3oReX01@3oRe/0oh]J0?n;FP3oRUT0oh]K0080oh]J00D0ohYK0?n>GP3oReX0oh]J0?n:
F`030?n;FP090?n:F@3oReX0oh]J0?n:F@3oTV@0ohYK0?n9F@3oSUl0oiAX0080ohYI00D0oiAX0?n;
GP3oReX0ohaK0?n=GP030?n;FP050?n6EP3oReX0ohYI0?n:F@3oSEh00P3oReX01P3oSUl0ohYI0?n;
FP3oReX0ohaK0?n=G@80oh]J0P3oSUl02`3oRUT0ohYJ0?n=GP3oSUl0ohYJ0?mkD00]4@/00000028;
2@3jGdd0ofiH0080og1K01@0ofeH0?m/F03oKeX0ofeI0?m_FP3oK5P0of]E0?m]E`3oKeX0og9K0?m_
F@34?C406PP70000001m7Qh0odM70?mJF@3oF5L0oeUG0?mIF0@0oeME00<0oeUG0?mEE03oEE@00P3o
EeD01P3oD4h0odU70?m1@03o@d40od]90?mCD@80oeMF00@0oeQF0?mJF03oF5H0oeIE0P3oEeD01P3o
EU@0oeYI0?mHEP3oFEP0oeME0?mFE@80oeME00D0oeED0?mHE`3oFEP0oeID0?mKFP040?mGE@0>0?mF
E@3oEE@0oeQF0?mNGP3oFEP0oeUG0?mDD`3oEE@0oeUH0?mMF`3oDU40k3Xi07lO7`0N1`L200000007
01l@2@2KABD0j6Th0?n8BP3oZ5/0ojMJ0?nRE`020?nPEP80oj1E0P3oXUX0103oX5H0ojIO0?nRF@3o
X5D60?nPEP0?0?nPE`3oXEL0oimD0?nND`3oVTl0oiUA0?nAA@3oS440ohLn0?n=@P3oTTD0oi=80?nF
C03oWE80oj1F0080oj5G1@3oX5H30?nPE@050?nSG03oXed0oiiB0?nQE`3oY5d00P3oX5H00`3oWe@0
oj1F0?nPEP0<0?nPEP090?nOE03oX5D0oimE0?nVH03oYF40oj=K0?nPE@3oYUl0oj=M0080oj1F0P3o
X5D=0?nPEP0<0?nSF03oYe/0ojYL0?n^G`3oXeP0ohU:0?mh@@3=G380W4LV05/X5P1681405@X51000
00003@0L4@L0L44K06Pk6@30L2h0lY0k0?ncB03o_Dh0omUJ0?oVH03oged0omaK0?oIFP3oeEL04`3o
e5L03P3oeEH0omAG0?oFG`3ode`0om9G0?oDFP3oe5L0om9D0?oEF`3oeF<0omAQ0?oEF03odUD0omEH
0P3oe6401@3oe5T0om9F0?oBF03odUH0omAE02l0omAG0P3oe5D05@3odUH0om=G0?oDE`3odUH0om9D
0?oFH`3odEh0ol9:0?o4AP3ob4T0olI90?o0AP3o_dD0ol160?o4A`3oaTT0olQ80?o7B@3oaDL0olU9
0?o5A`020?o4A`070?o5B@3oaTL0olE80?o6B03onET0ooII0?ohFP020?ofF@050?ohF@3on5X0ooME
0?oVI@3oeHH0o`3ooonF0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWinD0oooo00L0oiii0:UK;P2PE2H0XUDW0:9D9@2VEbP0X5@V00<0XU@U00@0]UlZ0?n/B`3o
]U40okE>0`3o]4h40?neCP030?nfD03o^eX0ok]K00T0ok]K00D0okaJ0?nkFP3o`6H0okaK0?nlGP02
0?nkFPL0ok]K00<0okaM0?nkFP3o^e/06P3o^e/20?nkFP80ok]K00L0ok]J0?nmH03o_V80okeP0?nk
F`3o^UT0okeN0080ol5Y00@0okeO0?nkFP3o^e/0ok]K0P3o^eXS0?nkF`0=0?nkFP3o^e/0ok]K0?nm
G03o_V80okeQ0?nlF@3o^eX0ol5U0?o2JP3o_F00ok]J0?nkF`020?nkFQL0ok]K00L0ok]J0?nkF`3o
^eX0okeM0?nnH`3o_5`0okYH0080ol1X00@0okaM0?nkF`3o^eX0ok]J3`3o^e/02`3o^eX0ok]K0?nk
F`3o_V00okeQ0?nkFP3o_V<0ol5W0?nmG@3o^e/0ok]J00`0ok]K0P3o^eX01@3o_5h0okaP0?nkFP3o
_Ed0ol1S0080ok]J1@3o^e/20?nkFP090?nkG03o^e/0ok]K0?nkFP3o_600ok]K0?o0I@3o_V80ok]J
00T0ok]K00H0okaP0?nlG@3o^UT0okmQ0?nlF@3o^eX70?nkF`050?nnGP3o^eX0okiP0?njF@3o^eX0
103o^e/01P3o^eX0okaM0?nkF`3o_V00okeP0?nkFPD0ok]K00`0okiN0?nlG03o_Eh0ok=C0?n/C03o
Z4P0ojM70?n`D@3o]UL0ok]L0?nmG`3o^eX30?nkF`040?nlG03o^e/0ok]M0?nlG0<0ok]K00l0okaL
0?nlGP3o_Eh0okYJ0?o1GP3oTdL0E2hF0000000R3PT0nF=10?n?G@3oS5/0ohYJ0?n?H03oRUT00P3o
ReX00`3oRU/0ohiQ0?n:F@020?n;FP080?n8FP3oSUl0ohYJ0?n8F03oSV40ohiO0?n<G03oRU/20?n:
F@090?n<G03oReX0ohYI0?mmC@3oN4L0ohQG0?n<F`3oReX0oheN00<0oh]J00<0ohYK0?n;FP3oReX0
103oReX07`3oRUT0oh]J0?n;FP3oReX0oh]L0?n?H03oReX0ohQH0?nDJ@3oS5`0ohUI0?n>G`3oU6P0
ohYI0?n8F03oU6T0oh]N0?n;FP3oS5l0oiAW0?n:F@3oReX0oi9U0?n;G03oReX0ohaL0?n?HP3oR5P0
oh]J0?n<F`3oR5X00`3oReX0403oS5/0oh]J0?n;FP3oS5/0oh]K0?n9F@3oReX0oh]L0?n>G`3oRUT0
ohmL09<l9`0000008`/80?M=?`3oL5X20?m`F`040?m/F03oKEP0ofmJ0?maG080ofeH00`0ofaH0?m`
F`3oJe<0ogAN0?mLB@1/8Q/0104100d30`3M=SD0oe=B0?mKFP3oEUD20?mHE`80oeME00<0oeAC0?mH
EP3oFEL0103oEeD02`3oFUP0oeUG0?mED`3oCD`0odI40?m3@@3oAT@0oda:0?mGE@3oFEL0oeID0080
oeME00@0oeAC0?mHEP3oFeT0oeQF1@3oEeD01P3oDe80oeeM0?mHEP3oF5L0oeME0?mEE0<0oeME00D0
oeED0?mJF03oF5H0oeME0?mLFP020?mGE@060?mIF03oG5X0n4M608<P80194Q804`@40P000000201:
8a80[DdZ0?]mA03oX5H0oj]M0?nVFP3oXEL0oj1F0P3oX5D01`3oXEP0ojMQ0?nPEP3oX5L0oj9I0?nP
EP3oX5D01`3oX5H02`3oX5D0oimE0?nQF03oYV80oj=J0?nREP3oXEX0oieC0?nLD@3oVDh0oi=70080
oha10180ohe20?n@AP3oTdT0oiI<0?nJD03oX5H0oj5G0?nQEP3oX5H0oj5G0?nWHP3oXed0oimD0?nR
FP3oXEX0oimD0?nPEP3oX5D=0?nPEP<0oj1E00P0oj9I0?nYIP3oY5d0oimD0?nSG03oXed0oj5I0?nP
EP80oj1E3@3oX5H02`3oXeP0ojIJ0?nXF`3oZU`0oiE@0?U`?03;G380SclR05XY5P0h6@h0910800D0
000000`0Ab/@09QG9@38M2l0oiU00?n[A`3oa540ol5@0?oMG03ohUl0ommO0?oLFP3oeePF0?oDE`0@
0?oEEP3odUH0omEM0?oAE@3oeEH0omMP0?oFI03oeUl0om9F0?oAE@3oeET0omAN0?oEG@3odUP0om=G
0?oDE`80om9F00<0omEG0?oDE`3oe5L0:`3oe5L20?oBEP080?oEEP3oe5L0om5G0?oCE@3oeF@0omEU
0?oFI03oe5`20?oAE@060?oDE@3oeUh0olmD0?o0AP3oa4L0olI70P3oa4L20?o5A`060?o4A`3oaTL0
olI70?o5A`3oa4L0olM90`3oa4L01@3oaDL0olA70?o5B03o`TP0ooUI0080ooII00L0ooQI0?ofF@3o
mUT0ooMI0?odEP3oifD0omB20?l0ooooUP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0
103YjNT0dM7A0=7Ad@3WinOU0?ooo`030?VDK`2/G2d0XU@U0080XU@U00P0XUDW0:9E9P2REBH0XU@U
0:5D9@2dGRX0okE@0?neCP80okA>00@0okE>0?ndC`3o]4h0okA>0`3o]Dh00`3o^UL0ok]K0?nkF`07
0?nkF`040?njF@3o_f80ok]K0?nlGP`0ok]K00<0okYI0?nlG@3o^e/07`3o^e/20?nkFP80ok]K00/0
okaL0?nlH03o_600okaM0?nkFP3o^UP0okeQ0?o2J@3o`6H0okUF0?njF@0U0?nkF`80ok]J0P3o^e/0
203o_5h0okaP0?nlG03o^eT0okeP0?o2JP3o`6P0okaL6P3o^e/00`3o^eX0ok]K0?nkFP020?nlH005
0?nkFP3o_5d0ol5Y0?o1J03o^eX04@3o^e/20?nkFP080?nkF`3o_Ed0okeN0?nkF`3o_5h0ol9Y0?nm
GP3o^UT=0?nkF`080?nkFP3o^e/0ok]L0?nmG@3o^eX0okmT0?nnH@3o^eX40?nkF`030?nkFP3o_F00
okaL0080ok]K00L0ok]J0?nkF`3o_5h0okeM0?njF03o_V<0okYI00L0ok]K0P3o^eX01@3o^e/0okaM
0?nlF`3o`FL0okYI00H0ok]K0P3o^eX0103o_5`0ok]J0?noI03o^e`60?nkF`040?nlG@3o_5`0okiQ
0?njF0D0ok]K00`0ok]J0?n_D03oYDL0ojI70?nXA`3o]5@0ok]K0?nlG03o^e/0okaL0?nmH03o^e`3
0?nkF`040?nkFP3o^e`0okeO0?nlG0<0ok]K00l0ok]L0?nmGP3o_F00okeL0?o4GP3oZE@0[eh]0041
000E1`D0ScXU0?n4EP3oSE`0ohYK0?n;FP3oREP00P3oReX0203oS5`0ohaK0?n:F@3oReX0ohUI0?n;
FP3oSUh0oh]J0P3oS5`02`3oRUT0oh]L0?n;FP3oReX0oh]M0?n:F@3oQ5<0ogM60?mnCP3oSEl0ohYI
0080oh]J00<0ohYI0?n;FP3oReX00P3oS5`20?n;FP0A0?n?H@3oRUT0oh]J0?n8F03oT680ohYI0?n;
FP3oSEh0ohiP0?n;FP3oR5P0oiAX0?n<G03oRET0ohiO0?nDJ03oRUT0103oReX01@3oS5`0ohiO0?n;
FP3oReX0ohYI0080oh]J00D0ohaJ0?n:F`3oReX0oh]J0?n<G0030?n;FP060?n=GP3oReX0oh]J0?n;
FP3oRe/0ohYI0P3oReX02P3oS5/0oh]J0?n;F`3oI4804@H4024;2@3kCcl0og9L0?m]E`3oKET20?m/
F00:0?m]F03oLE`0ofaH0?m/F03oKEP0og9M0?m/F03oKeX0gU=202P;2@80000000D0]S0`0?mIE`3o
EUH0oeUH0?mIE`030?mGE@030?mHEP3oFeT0oeID00@0oeME00/0oe]I0?mHEP3oEeD0oeIE0?mGE@3o
DE00odA30?m2@03oA480odQ70?mED`020?mGE@050?mJF03oFEP0oeED0?mHE`3oEUD0103oEeD00`3o
GE/0oeUG0?mHEP050?mGE@030?mED`3oFEP0oeeM0080oeQF0P3oEUD01@3oF5L0oe5@0=Le=01j7Ql0
9PP900<0000000H0M3DM0?mnA@3oTdl0oiiE0?nVF`3oXUL30?nPEP070?nQE@3oYEl0ojMP0?nNE03o
XEX0oj1F0?nOE@090?nPEP080?nQF03oYf40ojIO0?nQE`3oXEX0oj5H0?nPEP3oXEH20?nQE`0@0?nP
EP3oWU@0oiaB0?nGC03oTdP0ohi30?n=@P3oST<0ohm40?nBB03oV4h0oieJ0?nQFP3oWeD0oj=K0?nQ
F@80oj1F00<0oimE0?nPEP3oX5H0303oX5H02@3oX5D0oj9F0?nWH@3oZFD0oimD0?nPEP3oXU`0oj5I
0?nPEP020?nPE@T0oj1F0`3oXEH00`3oX5H0oj9G0?nRE`020?nSF@070?j1AP3=GC80Td8S05DV5@0a
5``05`X500P40P040000000A030N2`22Bb00fWde0?nP@`3o/TX0okm?0?o=E03oe5P0omiM0?oNG03o
fUX0omUJ0?oFE`3oe5L0omAJ0?oCG03oeEH0503oe5L00`3odeH0om9F0?oDH@020?oDH0050?oBE03o
dED0omEH0?oDG03oe5X00P3oe5L00`3oeEL0om9F0?oEEP0a0?oDE`080?oBE@3odU@0omMV0?oHI@3o
e680omAE0?oBE03odeL30?oDG0060?oEF@3oeEH0omAG0?oDE`3odUD0olE70P3oa4L00`3oaDL0olA7
0?o4A`030?o4A`80olE70P3oa4L00`3oaDL0olA70?o4A`020?o4A`040?o5A`3oaDP0ol]90?ohF@80
ooII00L0ooQI0?ofF@3omUT0oo9I0?ocEP3ojVX0omRF0?l0ooooUP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?ooo`080>:2F02WFB/0XU@U0:9E9P2RE2D0
XeDV0:EG9`2REBD20:9D9@030=1/<03o^E40okA>0080okA>00<0okE?0?ndCP3o]Dh0103o]Dh0303o
]Dl0okeN0?noH`3o_V00okYI0?nkF`3o^UT0okeN0?noH03o`F/0okiS0?nkFP80ok]K00@0okaL0?nl
G@3o_5d0okaM2@3o^e/00`3o_5d0okaL0?nkFP0X0?nkF`<0okaL0P3o^e/0103o_5d0okiS0?noH`3o
_V020?nkFP040?nnH@3o_f@0okiR0?nkFP80ok]K0P3o_5d00`3o^e`0ok]K0?nkF`0L0?nkF`0@0?nk
G03o_5`0okaL0?nkF`3o^eT0okiR0?noH`3o_Eh0ok]I0?nlG@3o_V80okiQ0?nkFP3o^e/0okaL0?nl
GAD0ok]K0P3o_5`0303o^e/0okaL0?nnHP3o_V40ok]I0?nmH03o_f@0okaN0?nkF`3o_5`0okaM0?nl
G0`0ok]K0P3o_5`02`3o^e/0ok]I0?nnH@3o_5`0ok]J0?nmGP3o_V00ok]J0?nlG03o_5d0okaL00T0
ok]K0`3o_5`0103o_V40okaL0?nmGP3o_f420?nkF`030?nmGP3o^eX0ok]K00D0ok]K00T0okaL0?nk
F`3o_5h0okiQ0?nlF`3o_f40ok]L0?nkF`3o_5`01@3o^e/0203o_5`0ok]K0?nmG`3o^eT0okeO0?nm
H03o_5/0okaL103o^e/01`3o_5`0ok]K0?nlGP3o^e/0okeP0?nlG@3o_5`00`3o^e/03`3o^e`0ok]K
0?nmG`3o_5/0okaM0?ncD`3o[Th0ojU90?nZBP3o[e00okED0?njG03o_Eh0ok]J0?nlG0020?nkF`06
0?nkG03o_5`0okaN0?nmG@3o^e/0ok]L0P3o^e/0103o_5h0okaL0?nmH03o_5/30?nkF`0:0?nkG03o
_F00okeK0?nlF`3CS4@0D2/E00T50P0M2`P0[Dlc0?n6F080oh]K00L0ohaM0?n;FP3oRe/0oh]J0?n=
GP3oRe/0oheO0080ohaK00D0oheM0?n;F`3oRUX0oh]K0?n<F`020?n;FP070?n;F`3oQUL0ogI70?mi
B03oQeL0oh]K0?n:FP020?n;FP050?n=G@3oRUT0oh]J0?n;FP3oS5`00`3oReX0103oSEd0oh]J0?n;
FP3oS5/20?n;FP0F0?n:FP3oS5`0oh]J0?n9F@3oUFP0ohaM0?n:FP3oS5`0ohiO0?n;FP3oRUT0ohUH
0?n;FP3oRe/0ohaM0?n:F@3oReX0ohiN0?n<G03oRUX0oh]J0?n<G0<0oh]J00T0ohaL0?n;FP3oReX0
ohaL0?n;F`3oReX0ohYJ0?n<G03oS5d00P3oReX0303oRe/0oheL0?n3EP2O@b`04PL4058K5@3oHDh0
ofmI0?m^F03oKUT0ofaH0?m]F@80ofeH00h0ofaH0?m]F@3oKeX0ofiH0?m/E`3^FdT0T3H[01h:200L
1PH0R2<S0>M6A03oEeD0oe]J0?mGEP<0oeQF00`0oeQG0?mHEP3oEeH0oeQF0?mGE@3oF5H0oeUG0?mH
EP3oF5L0oeME0?mGEP3oEeD20?mHEP090?mIE`3oEeD0oe5?0?m=C03oAdH0od=10?m6A@3oDE00oeID
0080oeQF00L0oeME0?mHEP3oFUP0oeYH0?mEE03oFEP0oeQF0080oeME00D0oeQF0?mFE@3oFEL0oe]I
0?mIF0020?mHE`0>0?mHEP3oDe80i4E30;0g=P29:RT0DaDD01840`0D1`<0:A<:078j7`2VHcD0fWU1
0?nACP3oWeH20?nRF0070?nQF03oX5H0ojAM0?nRF@3oWU80ojAK0?nPE@020?nPE`D0oj1F00T0oj1G
0?nQF03oX5H0oj9I0?nSG03oXED0oj5H0?nSF`3oX5D00P3oX5L80?nPEP0B0?nQF03oX5L0oimE0?nQ
E`3oXe/0oi]@0?nHC`3oTdX0oi980?n?A@3oT4D0ohm40?nCA`3oUT/0oiQ=0?nKD03oWU@0oimE0P3o
X5H0403oXEL0oj1F0?nPEP3oXEP0oj5G0?nOE@3oXEP0ojEM0?nRF@3oX5D0oj=K0?nTGP3oXEL0oj1F
0?nPE`3oXEP70?nPEP0O0?nQE`3oXeP0oj=H0?nRF03oXUL0oiiE0?nID`3oV5<0oi1>0=ai@P2cI3H0
SU@]081::01d=Qd0CR@D02`D2`0C2@D050/501H=1P0`70/0B2XB07E67@23HRT0T7L_0:n5>03MXD<0
okQ=0?o<E03ocUD0om9F0?oCE`030?oGF@030?oFF03oeEP0omAG00D0omAG00@0omEG0?oBF03ode`0
omEH0P3oeEL30?oDE`0@0?oCF@3oeET0omAH0?oCE`3odeH0omEJ0?oEH03ode`0om=F0?oBE`3oe5P0
omEV0?oCG@3odeT0omAI0?oEE`80omEH00D0omAH0?oDE`3oe5L0omAG0?oEE`0O0?oDE`<0omEG0P3o
e5L02@3oeEL0omEH0?oEF@3oe5T0omEH0?oEE`3odeL0omAF0?oGH0020?oFG`040?oCF@3odUD0om=F
0?oEEP80omIO00@0omAM0?oCEP3oe5L0omAG0P3oe5T0103oeEP0omAG0?oDE`3oe5L20?oEE`D0omAG
00D0ola>0?o4A`3oa4L0olA70?o6B0050?o4A`80olE8103oa4L01`3oaDP0olA70?o5A`3oa4L0olE8
0?o<BP3omeT00P3omUT01`3on5T0ooIH0?odF03om5T0ooED0?o_M`3ohKP0o`3ooonF0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinD0oooo00@0mHiR0:IG:`2M
DRD0XUDW0P2RE2D01P2UERH0XeHW0:9D9P2RE2D0lgli0?nhD@D0okA>103o]Dh02@3o]Dl0okE>0?ne
CP3o^UP0okaM0?nlG03o`6<0okeM0?nkF`030?nkFP0C0?nkF`3o^UT0okYH0?nnGP3o`FT0ol9[0?o1
I`3o^eX0ok]I0?nkFP3o_5d0okeQ0?nmHP3o_5h0okYI0?nkFP3o^e/0ok]J0?njE`0d0?nkF`030?nk
FP3o^e/0ok]K0080okYI00H0ol5X0?o2J`3o_Ed0okYG0?nkFP3o_F020?nmH@030?nlF`3o^e/0ok]K
0080ok]J7P3o^e/0303o^eX0ok]K0?nkFP3o^UT0okeP0?o1J@3o_5`0okYH0?nlF@3o_F40okeN0?nk
FP80ok]K00<0ok]J0?nkF`3o^e/04P3o^e/02`3o^eX0ok]K0?nkFP3o`6H0ol5X0?nmH03o^eX0okeP
0?nmHP3o^eX0ok]K0080ok]J3P3o^e/0203o^UT0okeM0?o1I`3o_Eh0ok]K0?nmHP3o_Ed0ok]K0P3o
^eX90?nkF`080?nkFP3o^UT0okeM0?noI03o^EL0okiN0?nlG03o^e/20?nkFPH0ok]K0P3o^eX01P3o
_Ed0okmR0?nkFP3o_Uh0okaM0?nkFPL0ok]K00H0okiO0?nnHP3o^eX0okaN0?nlF`3o^eX50?nkF`04
0?njF03o_V<0ok]K0?nmH080ok]K00L0okaL0?nkFP3o]5H0oj]:0?nTA@3oY4H0oje<00H0ok]K00@0
okeP0?nlG03o_5`0ok]J0`3o^e/20?nmG@D0ok]K00@0okeM0?nkF`3o_5d0ok]J0P3o^e/04@3o_Ed0
okaL0?nmG03oaUl0m85004PV4`000000Ba`C0?mX@`3oReX0ohmN0?n>G`3oT680ohYI0?n:FP3oRU/0
ohiO00<0oh]J00L0ohiO0?n:F`3oReX0oh]J0?n<F`3oSEd0ohYI0080ogQ700P0ogi@0?n;FP3oRUT0
ohmP0?n;GP3oReX0ohYK0?n=GP80oh]J00T0oheN0?n:F`3oReX0oh]K0?n>G`3oRUT0oh]J0?n=GP3o
S5`00P3oReX02@3oREP0oh]J0?n8F03oUFT0ohaL0?n;FP3oRUT0ohUH0?n;FP020?n;F`050?n;FP3o
S5`0oi9V0?n:F@3oReX00P3oRUT01`3oReX0ohYK0?n<G03oReX0ohYI0?n<GP3oS5/00P3oReX0103o
SEh0oh]J0?n:F@3oS5`30?n;FP080?n=G@3oSE`0oh=F044K4P00000090`90?mQCP3oKUT20?m]E`06
0?m/F03oKeX0og9N0?m/E@3oK5P0ofeG0P3oL5/02@3oJ5@0O2HO000000000000MQdL0?mFE@3oFEP0
oe]I0?mGEP020?mGE@030?mEE03oFEL0oe]I0080oeME00@0oeIE0?mHEP3oF5L0oeUH0P3oEeD0503o
EE@0oeME0?mIE`3oFeT0oeEC0?mGE@3oEUD0oeME0?mIE`3oEeH0oe]I0?m:B@3oAT@0od=10?m5@`3o
Cdd0oe=B0?mHEP3oG5X0oeED0`3oEeD0303oEE@0oeQG0?mIF03oGE/0oeAC0?mFE@3oF5L0oe]I0?m@
CP3oAdL0cS<b038=3@80000000l020@1050T5037FS00ohQ:0?nTFP3oXeP0oj1F0?nPE@3oX5H0oj9J
0?nPEP3oWU<0ojMR0?nQF03oX5D01P3oX5H0203oX5D0oj1F0?nPEP3oXe/0oj5G0?nTF`3oYV80oj5I
0P3oWeD80?nPEP090?nPE@3oX5H0oj1F0?nSG@3oX5L0oiiC0?nUG`3oXe`0oimD00D0oj1F0P3oXEL0
4P3oWU@0oiU>0?nCB03oT4D0ohi30?n<@P3oSD80oi570?nHC03oUdh0oi]C0?nOE03oXEH0ojMR0?nU
GP3oWe@0oj1F0?nPE@X0oj1F00`0oj9G0?nTF@3oYe/0oj]M0?nTFP3oWUD0ohm=0?n3A`3oM3l0fF4d
07Lf7@0_5P/40000000<00/70P0J3`H0>R8>05hg5P2FF2@0a74`0?nUA@3of5X0omaL0?oJF`3of5T0
omIG4P3oe5L02P3odUH0omEF0?oDE`3odUH0om9K0?oCG03oeEd0om9H0?oAE@3oeEP20?oEI@080?oD
G@3oe5D0omAG0?oEEP3oe5T0om9F0?oCE`3oeF<20?oEER@0omAG0P3odUH02`3odeL0omAG0?oBEP3o
dUH0omEL0?oCG@3oe5h0om9H0?oCE@3odED0om=L0080omEV00@0omAN0?oAE@3odED0omAG0`3oeEHE
0?oDE`030?oEF03odED0olE800<0olA700<0olI80?o4A`3oa4L02@3oa4L00`3oaTP0olA70?o4A`02
0?o4A`040?o9B@3olEP0ooII0?ogF@80ooEI00D0oo=I0?odF@3omE@0onig0?oQ^@3o0?oooiH0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWi@3oool0103/QeL0
YePY09Y@9@2ODbH20:9D9@060:EF9P2UERL0XUDW0:=E9@3oSch0okQA1@3o]4h70?neCP040?neD@3o
_F40ok]J0?nkFPT0ok]K00<0ok]J0?nlF@3o^eX00P3o^e/01P3o^UP0okeP0?o0J03o`FP0okmT0?ni
E`80okYI00H0okeP0?noI03o_V<0okeR0?nkF03o^eX20?nkF`030?nlF@3o^eX0okaI0300ok]K00T0
ok]J0?nlF@3o^e/0ok]K0?nkFP3o_fD0ol1W0?o0J03o_5/00P3o^UT20?nnH`040?nlG03o^UT0ok]K
0?nkF`80ok]J7@3o^e/01P3o_5X0ok]K0?nkFP3o^UL0ol1W0?nnH`80okYI00D0okeO0?noI03o_5h0
ok]J0?nkF`020?nkFQ80ok]K0P3o^eX0203o^e/0okaK0?o0I@3o`FT0ok]J0?nlF`3o_f@0okiP0P3o
^e/20?nkFP`0ok]K0`3o^eX0203o`FT0okeR0?nkF@3o_V80okaP0?nkFP3o_5X0ok]J2P3o^e/0203o
^eX0okeN0?nnGP3o_5/0okiR0?nmH03o^e/0ok]J1`3o^e/00`3o^eX0ok]K0?o0I0020?nmGP030?nm
G@3o^e/0ok]J00D0ok]K00L0ok]J0?nkF`3o_V<0okaM0?nmH03o^e/0ok]J00@0ok]K0100okaJ0?nl
F`3o`6D0ok]J0?nmG`3o]UH0ojm?0?nWA`3oZ4P0oji=0?nfE03o_5/0okeO0?nmGP3o_5`0ok]J103o
^e/0103o_Ed0okeN0?nlG03o_5T30?nkF`030?nnGP3o_5d0ok]K0080ok]K00@0ok]J0?nmG@3o_F40
okaM0`3o^e/03@3o_5`0okaM0?nlG03oaEl0ojmE05L_5P0000002@<10:A0:@3oSEl0ohUH0?n:F@3o
Re`00P3oReX00`3oS5`0ohiO0?n;FP020?n;FP090?n?H03oRUT0oh]J0?n:F@3oSUl0oh=C0?mhA`3o
NDX0ohaK0080oh]J00<0ohYI0?n<G03oReX00P3oReX02`3oS5/0oh]J0?n8F03oT640ohYK0?n;FP3o
RUT0oh]K0?n;FP3oSUl0oh]L0080oh]J0140ohaL0?n9F@3oR5P0oi9V0?n<G03oReX0ohYI0?n9F03o
RUT0oi=X0?n>H@3oRUT0oh]J0?n;G03oRUT0oh]J0?n>H0020?n;FP090?n9F03oS5`0oh]J0?n;G03o
SUl0oh]K0?n;FP3oSEd0ohUH0080oh]J01L0oheN0?n8FP3oReX0oh]L0?n>G`3oT5h0X4L_0000000]
3P/0oeA30?maF`3oKUP0ofeG0?m/F03oKUT0og9M0?m]E`3oK5P0ofeI0?m/E@3oMEh0ofaG08h/8`02
0000000406LI6@3oCdl0oeUG0?mJF080oeUH00L0oeAC0?mHEP3oF5H0oeUH0?mFE03oEeD0oeED00<0
oeUG00H0oeED0?mFE@3oEE@0oe]I0?mGE@3oEeH20?mGE@0[0?mEE03oF5H0oeME0?mMG@3oF5H0oeIE
0?mIE`3oDe40od]90?m4@P3o@d40odE30?m@CP3oEU@0oeQF0?mGE@3oEE@0oeQG0?mED`3oFeT0oeeK
0?mGEP3oFeX0oeYI0?m<C@3J=SH0H1PH00H0000000000`80040M401h=Qd0d5hb0?nLE@3oZU`0oj=I
0?nPEP3oX5D0oj5H0?nSG@3oX5H0ojAM0?nPEP020?nPE@D0oj1F0P3oX5D0203oX5H0oj=L0?nPEP3o
XUH0ojIP0?nRF@3oX5H0oj1E203oX5H02`3oWe@0oj1F0?nRFP3oXed0oj5I0?nQEP3oZFH0oj9I0?nP
E03oX5H0oimE00T0oj1F0100oj5G0?nPEP3oW580oiQ>0?nDB@3oTDT0ohi20?n?@P3oQSh0oh]40?nF
B`3oVU00oiaA0?nOE@3oXUT0oj5G1P3oX5H0303oXUL0oj=I0?nWF`3oZed0ojeN0?nSF@3oUE00oh15
0>]Z>038Fc40WdHU04XQ4PD0000000`0710703XS3P1^?a/0YV0X0=b1=@3mUSd0okm@0?oWG`3ohEh0
omeL0?oIFP3oeUL@0?oDE`80om9F00h0om=G0?oDE`3odUH0omAJ0?oFG`3oeEd0omED0?oAE@3odeT0
omET0?oGI03oeEP0omAF0?oDE`80om9F00H0omEF0?oBEP3oe5`0omEK0?oDF`3oe5X20?oBEQl0omAG
00<0omEF0?oCEP3oe5D00P3oe5L03@3odUH0omEK0?oEH03oeUl0omAL0?oDE@3odED0omAE0?oEH03o
eF<0omAV0?oEF03odeD00P3oe5L00`3odUH0om=F0?oEEP0K0?oDE`030?oCE`3obDd0olA700<0olA7
00<0olM80?o6A`3oa4L00P3oa4L0103oaDL0olA70?o4A`3oaDL30?o4A`030?o6B03oa4L0olA70080
olA700/0olM90?ocE`3omUT0ooEI0?ofF@3omET0oo=I0?odF@3ome@0onig0?oQ^@3o0?oooiH0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWi@3oool0303SPE00
YePY09eB9P2JD2@0WE8U0:9D9@2ODbD0YEHW0:=E9P2TEBH0oia40?nfD@D0okA>1@3o]Dh0103o]4h0
okE>0?neCP3o^ULB0?nkF`0C0?nlF@3o_5X0ok]J0?nkG03o^e/0ok]J0?nmH@3o`6H0okmV0?nnH@3o
^EL0okYI0?nkF03o_5d0ol1V0?noI@3o`6H0okaK0?nkFP020?nkF`030?nlFP3o_5T0ok]J02h0ok]K
0P3o^eX01`3o_5T0ok]K0?njFP3o^eP0okmU0?o0IP3o_Ed00P3o^UT02@3o_V40ol1U0?noI@3o_5`0
ok]J0?nkF`3o_5T0ok]J0?nlFP0K0?nkF`090?nlFP3o^eX0ok]K0?njF@3o_V40ol1W0?nmH03o^UT0
okaN0080okmU00D0okaL0?nkFP3o^eX0okaI0?nkFP0A0?nkF`0=0?nkFP3o_5T0ok]K0?nlG03o`6L0
okiQ0?nkFP3o_E`0okmU0?nnH03o^UT0ok]K0?nkFP0<0?nkF`0;0?nlF@3o^eX0okaK0?noI@3o_F40
okYI0?nmH@3o_V00ok]H0?nkF`3o^eX02P3o^e/0203o_El0okmT0?nmH@3o^UT0okmR0?nlG03o^e/0
ok]J1P3o^e/20?nkFP050?nnH03o_Eh0okYI0?nmH@3o_5h00P3o^eX40?nkF`070?nkFP3o_5/0okiQ
0?nkFP3o_Ed0okaN0?nkFP040?nkF`80okaK00L0okEG0?nYB03oX4<0ojM70?naD03o^e/0okaL0080
ok]K00<0okiP0?nmG03o_F401@3o^e/0103o_F40ok]J0?nnHP3o^eX30?nkF`040?nmG@3o_5`0okeN
0?nkFP80ok]K00@0okaK0?nnGP3o_Eh0ok]J0`3o^e/01@3o_Uh0okYJ0?o2H`3eXe8050/500800000
00D0ZdH^0?nAG`3oS5`0oheN0?n;G0020?n;FP0B0?n;G03oReX0ohYI0?n;FP3oRUT0oh]J0?n:F@3o
ReX0ohYJ0?mmC@3oN4L0ohAC0?n;G03oSUh0ohUI0?n;FP3oREP0ohaL0P3oReX04@3oSEh0oh]L0?n:
F@3oSf00ohUH0?n;FP3oReh0ohmP0?n;FP3oS5X0ohUH0?n;FP3oRUT0oi5U0?n8F03oReX0ohYK0080
oh]J0180ohYI0?n9F03oRUT0oi=W0?n>H@3oRUT0oh]J0?n9F03oReX0ohYI0?n=GP3oRUT0oh]J0?n>
H@3oReX0ohYI0?n<G03oRe`20?n;FP0D0?n=GP3oReX0oh]K0?n>H03oRe`0ohUI0?n<G03oSEh0oi1N
0?mcB`0O30T0:P`:0?mC@P3oL5X0og1K0?m]E`3oK5P0ofaG0?m_FP3oKUT20?m/F00F0?m`F`3oM5d0
oei;08@Y8@0000008@P90<4`;P3oEE<0oeUH0?mKF@3oF5H0oeED0?mGEP3oEU@0oeUG0?mKF@3oEU@0
oeED0?mED`3oG5X0oeUG0?mDD`80oeME0240oeQF0?mFE03oG5X0oeID0?mFE@3oEE@0oeUG0?mKF@3o
FEL0oeID0?mEE03oEeD0oeIE0?mED`3oGUd0oeYI0?m@CP3oAdD0od900?m2@@3oBdT0oeAB0?mKF@3o
FUT0oeQG0?mGE@3oEeH0oe]J0?mDD`3e?3/0XBPW05LE5P0300000P0000001P1@9A@0`5H^0?n9BP3o
ZE`0oj]M0?nRF080oj1E00H0oj5G0?nSFP3oXUH0ojIP0?nPE`3oX5D50?nPEP080?nOE@3oX5D0oj1E
0?nUG`3oXe`0oimD0?nUGP3oX5L20?nPE@L0oj1F00/0oj1E0?nPEP3oWe@0oj=J0?nWHP3oXED0oj=K
0?nVH03oXUX0oj1E0?nOE00;0?nPEP0P0?nPE@3oX5H0oj1E0?nUG`3oXe/0oj9F0?nQEP3oWEL0oiU>
0?nFB`3oTdT0ohi30?n;@@3oS440oi140?nDBP3oVU00oieB0?nOE@3oXUP0oj=I0?nTFP3oZE`0ojaN
0?nYG03oVe@0oh=70?1]>`2`D2/0Td<S06@]600V4PT40000000<01XA1P0g8Pd0JSdI0:5N9`3VRCL0
oiXo0?n_B@3oeeX0onQP0?oRG@3ogU`0omYJ403oe5L20?oDE@060?oEEP3oe5H0om9F0?oFG`3oe640
omEL0P3odED0203oeE/0omAR0?oFG`3ode<0omEF0?oCE`3odUP0omAJ0`3oe5L01`3odUH0omAE0?oC
G03odEH0om=M0?oBGP3oe5H06`3oe5L04P3oeEL0omAE0?oDE@3oe5D0omAG0?oBEP3oe5D0om=M0?oD
HP3oeF<0omEF0?oDE@3odeD0om=L0?oDHP3oe640omEN0?oDE@80omAG00<0omEF0?oBEP3oe5D08@3o
e5L00`3oeUX0olm@0?o4A`040?o4A`050?o7B03oaTL0olA70?o4A`3oaDL00`3oa4L01`3oaTP0olA7
0?o4A`3oa4L0olI80?o6A`3oaDT00P3oa4L02`3oaDT0onYD0?ohF@3om5P0ooAJ0?oeF@3oleT0ooEJ
0?ogE03okWL0on6i0?l0ooooUP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOU0?ooo`070<ib@P2REBP0WU<W09]A902MDRD0X5@V0:=F9@020:AF9`030:EG9`3o
[dh0okE?00@0okA>00<0okE>0?neC`3o]Dh00P3o]Dh01P3o]E00okE>0?neCP3o]Dh0okMB0?nlG1P0
ok]K00L0okaJ0?nkF`3o^e/0ok]K0?nmG@3o_5h0okaL00<0okeO00P0okaK0?nkFP3o^eX0ok]I0?no
I@3o_f@0okiT0?nlG080ok]J00H0okaL0?nnHP3o_f80okiQ0?nlG03o^eX`0?nkF`0@0?nmGP3o_El0
okeO0?nkF`3o^eX0okaM0?noI03o_V@0okeP0?njF@3o^eX0okaL0?noHP3o_V00ok]K0?nkFQT0ok]K
00@0okaJ0?nkF`3o^e/0okaL0P3o_El20?nkF`80okmT00H0okiQ0?nkFP3o_5`0okiQ0?noHP3o_5/@
0?nkF`0>0?nlFP3o^e/0ok]K0?nlF`3o_El0okaL0?nkFP3o_El0okiT0?nlG@3o^UT0okeN0?nnHP3o
_5`=0?nkF`050?nlGP3o_5`0ok]I0?nnH03o_f<00P3o^eX00`3o_V00okaK0?nkF`050?nkF`050?nl
G@3o^eT0okaK0?nlF`3o_Eh00P3o^e/01@3o_f80okeN0?nlG03o_V40okaJ00L0ok]K00H0okaM0?nl
G03o_f00okmP0?nkFP3o_El60?nkF`80okaL00l0okeP0?nmGP3o^e/0okeN0?nfE@3o/E00oj];0?nY
B@3o[Dh0ok9B0?nhEP3o_V00okaK0?nnH03o^eX00`3o^e/20?nlG@030?nlG03o_E`0okaN0080ok]K
00H0ok]J0?nmGP3o_5d0okaL0?nmGP3o_5`20?nkF`80okaL01L0okeM0?nlG03o^e/0ok]K0?nlG03o
_El0ok]I0?nlGP3o_5/0ol1Q0?nkF@3o_F00ol1O0?nYD`3;Qd80NT8P01P<1`1C8QH0YE@f0?mlD@3o
S5d0ohaK0?n<G0030?n;FP0@0?n<G@3oReX0oh]K0?n;F`3oReX0ohAD0?mhA`3oPe@0oheM0?n;FP3o
Re/0oheM0?n<F`3oReX0oheM0?n:F@80ohYJ00@0ohaL0?n:FP3oReX0ohiN0P3oReX20?n<G0050?n;
FP3oTV@0ohYK0?n:FP3oSUl00P3oReX03`3oREP0oh]J0?n;FP3oRUT0ohUH0?n;FP3oSEh0oh]L0?n;
FP3oSf40ohYJ0?n;FP3oSEh0ohaK0?n;FP020?n<G0060?n;FP3oS5`0ohaM0?n:F@3oRe/0oheM0P3o
ReX0>`3oS5`0oh]J0?n:FP3oS5/0ohaM0?n0E02G@b`07@`803dC403cG4X0og9L0?m`F`3oKUT0ofeI
0?m_FP3oKEH0ofeH0?m^F@3oJeD0og1J0=iLBP1`8a`07@T700D10@2@:BT0odi>0?mKFP3oEeD0oeQG
0?mHEP3oEE@0oeYH0?mIE`3oF5H0oeQG0?mFE03oF5H0oeYI0?mGE@3oF5L0oeIE0?mIE`3oF5L0oeUG
0?mGEP3oF5H0oeED0?mFE@3oFEP0oe]I0?mHEP3oEeH0oeME0?mFE@3oEeD0oeYI0?mHE`3oEeD0oeUG
0080oeQF01T0oeEC0?mDDP3oCdh0odA20?m5@`3oBdX0oe5?0?=;BP2i?C`0WS0_078L700c3@d02P82
02hE2`1S;AP0TddZ0=Mi@@3mSTd0oiUC0?nUF@3oXeP0oj=I0?nTF`3oXEL0ojAM0080oj1F00<0oj9I
0?nPEP3oX5H0103oX5H0203oX5D0oj=K0?nND`3oXUX0ojIO0?nPEP3oXUT0oj9H203oX5H02P3oWeD0
oj=K0?nQEP3oX5D0oj9K0?nSG03oWe@0oj5H0?nSF`3oXEL;0?nPEP0:0?nRF@3oXe`0oj5F0?nOE03o
Xe`0ojAM0?nOD`3oXEH0oj=J0?nQF080oj1F0P3oXEL20?nPEP0Q0?nNE03oW500oiY?0?nHC03oUDT0
ohE00?Em?@3GLcP0^6Xe0:1I;`2ICbX0RclQ068/600n70l0<QL<01`=1`0D2`D0;a`<04//4P1]?a/0
PE0R09e];@2_O3<0d9Lo0>f`B@3o`500olEB0?o?EP3ofeX0om]K0?oIFP3of5T0omIH00T0omAG0`3o
eEL04@3oe5L0om=F0?oEF03oe5h0omEN0?oDEP3odUH0omAG0?oEHP3oe640omEL0?oCEP3oeEL0om=J
0?oDF`3oe5T0om=G0080omAG0P3odeL0103odeP0omAG0?oDE`3odeL20?oBF0060?oDF03oe5X0omAN
0?oCEP3oeET0omAG0P3oeEL@0?oDE`<0omEG0P3oe5L0203odeH0omAL0?oDGP3oeEh0omAF0?oCEP3o
e5D0omEJ0P3oeF003@3oeF80omAF0?oCEP3odeL0omEI0?oDF`3ode`0omAG0?oDEP3oe5L0omEG0?oD
EP3odeL09`3oe5L00`3oe5P0ola@0?o5A`050?o4A`050?o7B03oaDL0olA70?o4A`3oaDL00P3oa4L0
0`3oaDT0olI80?o4A`020?o4A`80olE70P3oa4L01@3oaDP0olM80?oGCP3on5X0ooIJ00<0ooAI00@0
ooEI0?ofE03okGL0on2ho`3ooonF0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWinD0oooo00`0bW130:5D:02LDB@0YEHW09eB9@2ODbH0X5@V0:9D9P2WF2L0]EhZ
0?ndCP3o]E020?ndCP030?neD@3o]4h0okE@00@0okE>00<0okE@0?neCP3o]Dh00P3o]Dh00`3o^5D0
ok]L0?nkF`0K0?nkF`030?nlG03o_5X0ok]K00H0ok]K0`3o^eX20?nkF`0?0?nkFP3o^e/0okaN0?nm
GP3o_5h0ok]K0?nkFP3o^UT0okeQ0?o2JP3o`6P0ol5Y0?njF@3o^UP0ok]J02h0ok]K0P3o^eX20?nk
F`070?nkFP3o^e/0okaO0?nmG@3o^e/0ok]J0?nlF`020?o2J`030?o1I@3o^UT0ok]K01/0ok]K0`3o
^eX20?nkF`080?nlGP3o_600ok]K0?njF03o_V<0ol5Z0?noH03o^UPC0?nkF`070?nkFP3o^e/0ok]K
0?nlG@3o_5h0ok]K0?njF0020?o0I@80ok]J303o^e/0103o^eX0ok]K0?nkF`3o_Ed20?nkFP030?o0
I@3o_V40okaI00@0ok]K00<0okYI0?nnGP3o_5`00P3o^e/0203o^eX0ok]K0?nlG03o_5h0ok]K0?nn
H03o_f@0okYG203o^e/01P3o^eX0okeM0?nkFP3o_F00ol5W0?nlF`H0ok]K00P0okUI0?n]C`3oZDH0
oii30?n[BP3o]eP0ok]K0?nlG0<0ok]K00@0okaN0?nlF@3o_Ul0okYI103o^e/0103o_5`0ok]L0?nm
G`3o^eX40?nkF`80okaL00@0okeO0?nkFP3o^e/0ok]K0P3o_5`0203o_Uh0okaM0?nnG`3o_Eh0ok]J
0?nkF`3o_F00okaI0P3o^e/01@3o_5`0okiN0?nmFP3o`Eh0ag`m0080000000D060T60=iYA@3oS5/0
ohiO0?n<G0020?n;FP0D0?n;F`3oSUl0oh]J0?n<F`3oQ5@0ogU80?mmC03oReX0oh]K0?n<G03oRUX0
ohaL0?n;FP3oRUT0oh]J0?n=GP3oRUT0oh]J0?n:FP3oRUT20?n;FP060?n=GP3oReX0oh]L0?n;G03o
ReX0ohYI0P3oReX0103oRET0ohYI0?n;FP3oRUT20?n;FP040?n8E`3oRUT0oh]J0?n9F080oh]J00@0
ohYI0?n;FP3oReX0ohYI0P3oReX01`3oSEh0oh]J0?n:F`3oSf00ohYI0?n;FP3oRe`00P3oReX03`3o
RU/0oheM0?n;FP3oRUT0ohUH0?moD`0]4@/0000001@71@3YFTT0og9M0?m`F`3oK5P0ofeI0?mbG@02
0?m/F0090?m_FP3oKUX0ofeH0?1;?00G1`H0000005LF5P3o@T80oeUH0080oeQF0P3oEeD0303oFEP0
oeQF0?mGE@3oEeD0oeED0?mHE`3oFEP0oeMF0?mEE03oEeD0oeED0?mJF080oeQF00H0oeME0?mFE@3o
FeX0oe]I0?mEE03oEeH30?mGE@050?mHEP3oFeX0oeED0?mHE`3oEUD00`3oEeD02@3oFeX0oeAB0?mI
E`3oFUP0oeIE0?m1@@2e9RD0Ca0A01H410020000000?00`5002<@280ohM90?nFD03oX5H0ojIJ0?nR
E`3oX5H0oiiC0?nUGP3oWe@0oj1G0?nQF@3oX5H0oj1E00H0oj1F00D0oj9I0?nWHP3oWe@0oj1F0?nQ
F@020?nPEP030?nPE@3oX5H0oj1F00H0oj1F00D0oj5G0?nYI03oY5d0oiiC0?nQF@0>0?nPEP070?nP
E@3oXeX0ojUT0?nTGP3oWU80oj5H0?nRFP030?nPEP030?nPE@3oX5H0oj1F0080oj5F00<0oj1F0?nR
E`3oXUL00P3oXUL02@3oXEL0oiMB0?mg@@3;Fc40Sd8U04HO400P3PL050X400D20@040000000=044V
3@2DEQh0cWD/0?nN?P3o^Td0olEA0?o=E03oeUP0omeL0?oJF`3ofEX0omMH0?oEE`0?0?oDE`080?oC
E`3od5@0omAP0?oEI`3oeF80om1D0?oBEP3oe5L20?oEF`80omEF00<0omAG0?oBEP3oeEH03@3oe5L0
1`3oe5T0omEP0?oDE@3oeEH0om=H0?oDE`3oeEH04P3oe5L0103odEL0om9D0?oDE@3oeV@20?oGIP04
0?oBE03odUD0omAG0?oDFP80omEK0P3oeEH01@3oe5L0omEG0?oEEP3oeEH0om9F03<0omAG00@0om5B
0?o3AP3oadT0olI7103oa4L0103oaTP0olA70?o4A`3oaDL30?o4A`030?o6B@3ob4T0ol150080okY4
0100ok]50?o3A@3ob4T0olM90?o5A`3oaDT0omE=0?oiF`3omeX0oneF0?oWE03oiUD0oo9H0?ocD03o
mHL0ooKWo`3ooonF0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWinD0oooo00`0bVm40:5D9`2LDB@0VU0T09aA9@2MDRD0We<U0:1D9P2RE2D0_F</0?ndCP3o]E02
0?neCP030?neD03o]4h0okE@00T0okE>00<0okIA0?njF@3o^e`07@3o^e/00`3o_640ok]K0?nkF`0A
0?nkF`040?nkG03o_5`0okaL0?nlG@80ok]K00L0okYH0?nlG@3o`V/0ol5Y0?o1K@3o_5d0okYI0080
ok]K0`3o_5d^0?nkF`<0okaL00P0ok]K0?njF03o_f@0ol9[0?o1J03o^EH0okYI0?nkFP80okaM00<0
okaL0?nkF`3o^e/06@3o^e/02`3o^e`0okaL0?nlG03o^UT0ok]J0?o1J03o`FL0okYH0?nkFP3o^e/0
okaM01<0ok]K0P3o_5`01`3o^eX0okYH0?o1I`3o_V<0okYG0?nkF`3o_5d03@3o^e/20?nlG0080?nj
F@3o`6H0ol5W0?nkFP3o_5`0okaM0?nkFP3o_5h70?nkF`80okaL00@0okYI0?nnGP3o_f<0okYI0P3o
_5`70?nkF`0A0?nlG03o^e/0ol5V0?nlG@3o^eX0okaL0?niF@3o[e00ojU90?nXB03oZTX0ok5C0?nj
F@3o_f<0okYG0?nkF`3o_5`01@3o^e/00`3o_5d0okiS0?nlG0040?nkF`030?nkG03o_5`0okmT0080
okaL103o^e/01`3o_V<0ok]K0?nlG03o_5`0ok]J0?o1I@3o_F400P3o_5`20?nkF`0A0?nlG03o_Uh0
okaL0?nkFP3o^e/0ok]J0?nlG03o_f<0okmL0>io?@0Y5@X0000002/A2`3oL4T0ohaK0?n?GP3oS5d0
0P3oReX01P3oRU/0oheM0?n:F@3oODd0ogE50?n4DP80oh]J00T0ohYI0?n<F`3oRUT0ohiP0?n:F`3o
ReX0oh]L0?n>H03oRUT00P3oS5`20?n;FP070?n:F@3oReX0oh]J0?n9F03oReX0ohYI0?n9F0020?n;
FP070?n:F@3oReX0oh]J0?n:F@3oReX0ohQG0?n;FP020?n:F@80oh]J00X0ohUI0?n;FP3oS5`0ohaK
0?n:FP3oRe`0ohYI0?n;FP3oRUT0oh]K0P3oReX03P3oS5/0oh]J0?n:F`3oSUl0oh]K0?n:F@3oS5/0
ohaL09I1:P0000005PH50=Q4=`3oLU`0ofmJ0P3oK5P03@3oKeX0ofaH0?m/F03oJeD0og1I0?mTD01n
:B4020<200/30`2i;2`0oeEC0?mHEP3oFUP00P3oEeD00`3oEE@0oeUH0?mFE0020?mGE@080?mHEP3o
GUd0oeEC0?mGE@3oFEL0oeQG0?mIF03oFEL30?mGE@030?mFE03oG5X0oeQF00<0oeME00D0oeQF0?mG
E@3oHV40oeME0?mHEP020?mGE@0I0?mHEP3oDe80of5P0?mLFP3oF5L0oeID0?mED`3oBTT0SR<R0102
0P020000000000d50@1B8a00ceX/0?n=B@3oWED0ojAI0?nRE`3oXEL0oj5F0?nWH@3oYEh0oj1E0?nQ
F0060?nPEP070?nPE`3oX5H0oj5G0?nYI@3oXeX0oj1F0?nPE`090?nPEP080?nRF@3oWeD0oj=K0?nX
I03oXe/0oj5F0?nPE`3oXEP70?nPEP030?nOE@3oX5H0oj1F0080oj1G00H0oj1F0?nPE@3oZF@0ojMQ
0?nPE@3oX5H20?nPE`D0oj1F0P3oXUL0303oXeT0oj=H0?nQE`3oWUD0oiYC0?nIDP3oQ4P0f60c0993
901N;1L05@X500<30080000001400@0000H40P0>2P@0818807m:7`3<MS00oiTl0?nd@P3o_4<0okm3
0?o2A03oaDH0olM90?o=C`3odU<0om9F0?oCE`0;0?oDE`0=0?oCF@3oe5X0omAG0?oDE`3odeD0omEW
0?oGIP3oeV@0om9F0?oDE`3odUP0omEH0?oDF00C0?oDE`060?oEF03odEL0om9H0?oDHP3oe5T0om9H
0P3oe5L00`3odeL0om=I0?oDE`030?oDE`030?oEEP3oe5L0omAG0080omAG00h0omEH0?oEF@3oeEP0
omAG0?oBEP3odUD0omES0?oHI@3oeFL0omAM0?oAE@3odEL0omAG0?oDF080omEH>03oe5L0103oeEL0
omAG0?oDE`3oeEH30?oDE`040?oBF03ob4`0ol=70?o5B@<0olA700<0olE70?o7B@3oaTP00P3o^T@0
0`3o_T@0oka50?o9B@020?o7B@040?o5A`3oa4L0ol=70?o3A`D0olA700X0olE90?oCC@3ome/0oo=I
0?oaF@3olUP0oo5I0?ocF@3oldl0ooZ/o`3ooonG0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWinD0oooo00D0bVm40:5E:02LDB@0WE8T0:9E9`0209eB900509aA
902ODbD0d6d`0?ndC@3o]E40103o]4h;0?neCP030?nhD`3o^e/0ok]K01`0ok]K00@0ok]L0?nmGP3o
^UT0okaL7@3o^e/20?njF0050?o2J03o`FX0ol9Z0?nnGP3o^UP00P3o^eX01@3o_Eh0okeO0?nmGP3o
_5`0ok]J0080ok]K0`3o^eXY0?nkF`080?nkFP3o^EH0ol1X0?o2JP3o_f@0okYH0?nkFP3o_Ed20?nl
H0030?nlF`3o^e/0ok]K0080ok]J6@3o^e/0203o^UP0okiN0?o2J`3o_Ed0okYG0?nkFP3o_Eh0okaN
0`3o^e/00`3o^eX0ok]K0?nkF`0>0?nkF`070?njF@3o^e/0ol9X0?nlG03o^UT0ok]J0?nmG`0>0?nk
F`050?nkFP3o_f<0ol9/0?nlG03o_5h0303o^e/01`3o^UP0okmT0?o0IP3o^eT0okeN0?nlG03o^eX0
1P3o^e/0203o_5/0okaL0?nhG@3oZTT0ojI60?nWA`3o[dh0okYJ0`3o^e/01`3o^UP0okeP0?noI03o
_5/0okaL0?nkF`3o^eX00`3o^e/01@3o^UT0okiQ0?nkFP3o_5h0ok]J00<0ok]K00@0okYI0?nnH03o
_5`0okaL0`3o^e/03`3o_Ed0okeQ0?o0HP3o^eP0ok]J0?nkF`3o_5`0okeP0?nkF`3o_5`0ok]K0?nk
FP3o_Uh0okeM0?nlG0020?nkF`0;0?nlG03o_5d0ol1M0?nYD`23AB802@D201@91@2mC380ohAF0?n?
G`3oSEh00P3oReX0403oSEd0oh5@0?mgA`3oN4L0ohQH0?n;F`3oReX0ohYI0?n<F`3oReX0ohUI0?n?
H03oRe/0oh]J0?n9F03oRUT40?n;FP0B0?n>G`3oRUT0ohYI0?nAH`3oSEd0oh]J0?nBI@3oReX0oheM
0?n?HP3oRUT0oh]J0?n:F@3oReX0ohQG0?n;FP3oS5d0oheO0P3oReX02@3oSf00ohYI0?n?H03oTF<0
ohYI0?n?H03oRU/0oh]J0?n>G`020?n:F@0?0?n>G`3oRe`0ohYI0?n<G03oRUT0oh]J0?n<G`3oTF40
ofi901D91P0H1`D0fd@g0?mcG03oKUT0ofaH0080ofeI00H0ofiJ0?m/F03oLE`0og9L0?ULBP0Y3@X2
000000050:l_;P3oFUT0oeYI0?mGE@3oEUD0103oF5H0403oEE@0oeQG0?mFE03oFUP0oeME0?mEE03o
F5H0oeUG0?mKF@3oF5H0oeME0?mHEP3oEU@0oeUG0?mKF@3oEU@20?mGE@050?mHEP3oF5L0oeaJ0?mG
E@3oEE@00P3oEeD02@3oF5L0oeME0?mKFP3oFUT0oeUH0?mGE@3oBd/0]Rh/04H@40020000000<0147
0`0_50X0HbdH0>Ea>@3oTTH0ohi20?n?@`3oVDh0oiiE0?nPE@3oYV00oj5I103oX5H02@3oX5D0oimE
0?nPEP3oXET0oj1F0?nND`3oYEl0oj=K0?nPE@080?nPEP070?nOE@3oX5L0oj5I0?nOE03oXUX0ojUU
0?nQE`090?nPEP80oj1E00D0oj1F0?nPE`3oXU/0oj5I0?nOE0020?nXH`030?nQE`3oX5D0oj1F00D0
oj1F00<0oj5F0?nSF03oY5X00P3oYe/0203oWUD0oiE@0?n=C03oRT/0j6Th0:589`1M:QL0;1<:1000
00001`0?2@@09QH803HP3@1D<A@0]6T/0?nI?P3o`5000P3oeeP30?oDF0050?oAE03obDd0olM80?o4
AP3o`T@00P3o`D<0203o`T@0olU=0?oBD`3odED0omAG0?oEF03oe5L0omEG0P3oeE/0203oe5L0omAE
0?oBE03oeF<0omEW0?oCF`3od5<0om=G5`3oe5L0103oeEL0omAG0?oEF`3oeEP20?oFG0040?oBEP3o
e5L0omAG0?oDE`80omEF0P3odUH03P3oeEP0omEF0?oEF@3oeE/0omAL0?oEF`3odUH0om9D0?oBEP3o
eF@0omQV0?oFI03od5<0om5E>`3oe5L20?oEEP070?oBEP3oe5L0omAG0?oDE`3oeEH0omAG0?oEG002
0?oEF`0:0?oDG03odeL0omEF0?oBE03ocU40ol160?niA03o_TH0ok]50?o0A`80olM900<0olA70?o6
B03oa4L01@3oa4L00`3oaDL0olA70?o4A`020?o4A`090?o5A`3oaDT0olA70?o7B@3oaDL0olE90?oC
C@3on5/0ooAJ00<0oo=I00<0oo9I0?o_E`3omI00o`3ooonG0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinD0oooo00H0c7120:5E:02LDB@0W54T09]A9P2NDbD3
09eB90040<el=`3o]U00okE@0?ndCPl0okE>00D0okMC0?nkF`3o_5X0ok]K0?nlFP0L0?nkF`030?nm
GP3o^e/0ok]K0280ok]K0P3o^eX0103o_V80okmR0?nnHP3o_5`20?nkFP080?nlG03o_fD0okiU0?no
I@3o^e/0ok]I0?nkFP3o_5`20?nmG`030?nmH03o_5d0ok]J0080ok]K00<0okaK0?nkF`3o_5X08@3o
^e/01@3o^eX0okeO0?noH@3o_f40okaL0080ok]J00H0okiR0?o0IP3o_Ed0ok]I0?nkFP3o_5d20?nm
G`030?nlG03o^e/0ok]K0080okaJ00<0okaK0?nkF`3o^e/0403o^e/0303o^eX0okiQ0?nnH03o_5X0
okYI0?nmH03o_f@0okeO0?nkFP3o_5/0okeP0?nmG`<0ok]K00<0okaJ0?nkF`3o^e/02P3o^e/01P3o
^eX0okmQ0?nkF`3o^UT0okiQ0?nnH080ok]J00D0okeO0?nlG@3o^eX0ok]K0?nlF`070?nkF`090?nl
G03o_5h0okeN0?njF@3o_f<0okaL0?nkF@3o_5d0okeN00L0ok]K01<0okaL0?nnH@3o_5d0okYH0?nn
HP3o^eT0ok]K0?nnH03o_5`0okQH0?nbDP3o[4`0ojU90?n]C03o[e40okEF0?nnG`3o_F00ok]J0080
okaL0`3o^e/20?nmG@050?nkFP3o_f@0okaL0?nlG@3o_5`00`3o^e/01@3o_V00ok]I0?nmGP3o_5/0
okaM0080ok]K0P3o_Eh01@3o^eT0okeN0?nmG03o_V00ok]J0080okaL00d0okeM0?nlF`3o_5`0ok]K
0?nlG03o_5d0okeM0?nlF`3o^e/0ok]J0?nlG03o_V00ok]J0080okaL0140ok]K0?nmG`3o`El0aGdo
03`P40030P40=1D>0;YG>@3oS5`0ohmN0?n:F@3oQUL0ogU80?mhA`3oPe@0ohaK0?n:FP020?n;F`0N
0?n<F`3oS5X0oh]J0?n;FP3oRe`0ohYI0?n:FP3oSEh0ohaL0?n;FP3oSEh0ohYJ0?n;F`3oS5d0oh]J
0?n:F@3oSE`0oh]J0?n;F`3oRUT0ohiN0?nAI03oRUT0oh]J0?n<G03oReX0ohQG0?n;FP3oSV00oi5S
0P3oRUT20?n<G00<0?n<G@3oRUT0ohaM0?n;F`3oReX0oh]K0?n<G03oRe/0oh]L0?n:FP3oRe/0oheN
0P3oRe/01`3oSel0ohUK0:97;P0F20D0A1DA0>iMB`3oLU`00P3oKEP03`3oKe/0ofmJ0?m]F03oKUT0
og9L0?MPCP2R?3008P/902`;2`2?8R80dd=20?mJF03oEeD0oeIE0?mHE`020?mIE`0<0?mGEP3oEUD0
oeUG0?mGEP3oFUL0oeME0?mFE@3oEeD0oe]I0?mGE@3oEUD0oeQF0P3oFEL0;`3oFEP0oeMF0?mEE03o
EeD0oeMF0?mKF@3oF5H0oeQG0?mGEP3oEeD0oeUH0?mGE@3oFEP0oeYH0?mKFP3oDe80i4E50:@^;P1n
7b00FaHF01/81`0^5@/0BR4B07Xg7@2_ISL0m8U:0?nME@3oYET0oj9I0?nPEP3oW5D0oiE:0?n>@`3o
SdD0oiE:0?nJD03oX5H0oj5F0?nRF03oXUX0oj1F0?nTG@3oXe`0oiiC0?nSF`3oXEP0oj1E00<0oj1F
00/0oj1E0?nPEP3oXEL0oj9J0?nPE`3oX5D0ojAM0?nRF@3oWe<0oj9I0?nSFP090?nPEP0:0?nQF@3o
XeX0oj1F0?nQEP3oY5d0ojEP0?nPE@3oXET0ojAM0?nRFP<0oj1F0200oj9H0?nTF@3oYeX0ojMK0?nR
E`3oVU<0ohm=0?F;B`3TPTH0_VPh09Q>:P20?b80P3/P05LW5@0c5P`03`L400h90`0X5`X0A2PA05Hc
5@1Z?aX0Uf8Y0:Em<`2aSc`0b9i10?>bB`3oaU<0omMH0?oIFP3of5X0omIH0?oDF0@0omAG01L0om=G
0?oDEP3oeEP0omAG0?oCE@3od5H0olaD0?o;C`3oaTT0olE70?nm@`3o^480okU40?o8BP3obTh0olmB
0?o@FP3ode`0omAG0?oDF03oeEP0omAG0?oCE`0G0?oDE`050?oDF@3oeEL0om9G0?oDG03odUD00P3o
e5`04@3oeU/0omEK0?oCF@3oe5H0om=F0?oDFP3oeF40omIP0?oEH03odUD0omAD0?oEEP3oeEX0omAM
0?oEGP3oe5`0omAF0080omAG00<0omEG0?oCE`3oeEL0:`3oe5L0103odeL0omAF0?oCE`3oe5H40?oD
E`0?0?oDF@3oe5/0omAK0?oDG03odeX0omAF0?oCE`3odeH0omAE0?oEG@3oe640omIQ0?oEHP3oeE`0
om=E0080om=F00`0omAF0?oEG@3oe5h0omAM0?oEGP3oe5L0omAF0?o>D@3oaDT0olA70?o5A`3oaTP2
0?o5A`<0olA700<0olI80?o5A`3oa4L00P3oa4L00`3oaTL0olE90?o4A`040?o4A`0?0?o6A`3oaDT0
olA70?o7B@3oaDL0olA70?oCC@3ome/0ooAI0?ocF@3omET0oo=I0?odF03okET0on>B0?l0ooooU`3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?ooo`050;iX
?@2NDbP0W54T09aA902LDBD00P2MDRD0102MDBD0WE8T0<]n=`3o]U050?ndCP80okE>0P3o]4h0103o
]E00okE?0?ndCP3o]4h50?neCP050?nlG03o_fL0okmU0?o0I`3o_V400P3o^UT20?nkF`050?nkFP3o
_5T0okaI0?nlFP3o_5T04`3o^e/00`3o^UT0okaL0?nkF`0Z0?nkF`80okaI00X0okaJ0?nkF`3o^e/0
ok]J0?nlF`3o_fH0okmU0?noI`3o_Eh0okYH0P3o^UT01@3o_V@0okmU0?o0J03o_F00ok]I0080ok]K
00<0ok]J0?nlFP3o_5T08@3o^e/01P3o^eX0okaI0?nkF`3o^e/0okYI0?nmGP80okmU00L0okeM0?nk
F@3o_5/0okmV0?o0IP3o_V80okYI0080ok]K00<0okaJ0?nlF@3o^e/04P3o^e/20?nkFP0=0?nkF`3o
_5/0okmW0?noI03o_5`0okYI0?nnH`3o`6H0okmU0?nkFP3o^e/0ok]J0?nlF@0;0?nkF`0=0?nlFP3o
^eX0ok]K0?nkFP3o_f@0okeQ0?njE`3o^eX0okmU0?nmG@3o^eX0ok]K0?nlFP050?nkF`030?nkFP3o
^e/0okeM0080ok]J00L0okiN0?noH@3o^EL0okaL0?noI@3o_Eh0ok]K0080ok]J103o^e/20?nkFP09
0?nlG03o_F<0ok5@0?nSA@3oWd80ojY90?neE@3o_5/0okaL0080ok]K00P0ok]J0?njF@3o_F00okaM
0?nmH@3o_V<0ok]K0?nkFP80ok]K00H0ok]J0?nlF`3o_V40ok]K0?nmGP3o_5h20?nkFP0>0?nkF`3o
^eX0okeL0?nlGP3o^e/0okeM0?nlGP3o_F00okYI0?nlF`3o_V00ok]J0?nmHP3o_5/20?nkF`030?nk
F03o_5h0okeQ0080ok]J00T0ok]K0?nmG@3o_5`0okeN0?nkF`3o^eX0okaL0?nmH@3o_Ed00P3o^eX0
403o_Ed0ol5P0?nmFP3MMSX0>Al>0000001[:Q`0ofY60?nEHP3oODd0ogI50?n0D03oS5`0oheM0?n;
FP3oRUT20?n<F`050?n;FP3oSEh0oh]J0?n;F`3oSEh00P3oRUT07@3oS5/0oh]J0?n9F03oSUh0oh]J
0?n<G03oRe`0ohYI0?n=G@3oReX0ohYK0?n?H03oRET0ohQG0?n;FP3oRUT0oi1S0?n:F@3oREH0oh]J
0?n<G03oSEh0oh]J0?n;F`3oRUX0oh]K0?n>G`3oReX0oh]L0080ohYI00<0ohiO0?n;FP3oRUT00P3o
ReX0;03oSEd0oh]J0?n;FP3oRe`0ohMI04dN5000000060L60?5NC03oKUP0of]E0?m]E`3oKeT0ofeI
0?m]E`3oLE`0ofaF08d]900;0`80000006DH603oDU00of5P0?mGE@3oEUD0oeMF0?mHEP3oFeT0oeIE
0?mEE03oFEP0oeQF0?mJF03oEE@0oeQF0?mIF03oFEL0oeID0?mDD`3oEeH0oeQF0?mIF03oF5H0oeME
0P3oFEL00`3oG5X0oeEC0?mJF0030?mEE0080?mKFP3oEUD0of1O0?mPG@3oD500cS4a098T8`194Q82
0000000G00/50P1P:aL0eV4e0?nFD@3o[Uh0ojQK0?nTFP3oXUd0oimD0?nRF@3oXeX0oj1E0?nOE@3o
XUT0oiiC0?nDB03oST80ohe10?n=A@3oVe00oj9J0?nWH@3oX5H00P3oX5D30?nPEP80oj1E00T0oj1F
0?nTF`3oYV40oj9I0?nQE`3oYV00oj9I0?nPEP3oX5D01P3oX5H03@3oX5D0oj1F0?nOE03oXe/0ojIP
0?nRF@3oWe@0oj=M0?nVH03oX5L0oj1F0?nPE@3oWe@00P3oX5H0303oXUL0ojAJ0?nZG03o[5h0ojeO
0?nGD@3oOd@0dEdb0;QC;@29?200DbDD00/40P@0000000`01@@104@X401jAQh0a78_0=f3=@3oVcl0
ok]>0?oQGP3oj600on5N0?oKG03ofEP80?oDE`0K0?oBEP3oe5D0om=G0?oEEP3odUH0omIO0?oEH`3o
deT0om=C0?oDE@3oe5h0omAR0?oDH03oeUL0om=F0?oBD`3oce00olY>0?o3A`3o_D80ol120?nm@P3o
`TL0olU<0?o<C`3od5<0omAG0080omEH3`3oe5L03P3oe5D0om9F0?oDEP3oe5L0omAE0?oCF@3ode`0
omIY0?oEI@3odel0om=E0?oAEP3odED0omEM0P3oe6801`3oeE/0om9D0?oCE`3oe5L0omAE0?oBEP3o
deH00P3oe5L20?oBER/0omAG00D0om=G0?oDE@3odUH0om9F0?oDEP020?oDE`060?oDE@3odeL0omAQ
0?oEH`3oe640omIS0P3oe5D20?oAE@0>0?oEF`3oe640omAR0?oFH@3oeUl0om9D0?oDE@3odeL0omAG
0?oEEP3oe5D0om=F0?oDE@3oeEH90?oDE`030?o>C`3oa4H0olA700P0olA700<0olE70?o7B@3oa4L0
0P3oa4L05P3oaTL0olE90?o4A`3oa4L0olM90?o4A`3oaDL0olA70?o5A`3oa4L0olM90?o5A`3oa4L0
om9<0?ogFP3oleT0ooIJ0?oeFP3olEL0ooEH0?oZG@3ogj?o0?oooiL0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWi@3oool00`2iJ3h0WU<X09aA900209aA9006
0:5D9P2MDBD0WE4U09aA8`3HQC/0okE@0P3o]4h00`3o]Dl0okE>0?ndCP0=0?neCP050?nhE03o_f@0
okiR0?noI03o_F000P3o^UT02P3o^UP0okYI0?nnH`3o`FT0ol1X0?o1J03o`FT0okeP0?njF@3o^eX3
0?nkF`@0ok]J2@3o^e/00`3o^eX0ok]L0?nlH@0a0?nkF`030?nlF@3o^eX0okaI0080ok]K0P3o^eX0
103o_V40okiS0?o0I03o_5h20?njF@060?njFP3o_fD0ol5X0?o1JP3o_F00okUG0P3o^e/30?nkFR00
ok]K0P3o^eX30?nkF`80okiS00@0okeP0?njF@3o^UP0okaL0P3o`FP00`3o_5`0okYI0?nkF`030?nk
FQ40ok]K00d0okaI0?nkFP3o^e/0ok]K0?nmH@3o_V<0okiR0?nkFP3o_5`0okmV0?o1J@3o_5h0ok]K
0080ok]J2`3o^e/03@3o_5X0ok]J0?nkF`3o^e/0okiS0?nlG03o^UT0ok]K0?o0J03o^e`0ok]J0?nk
F`3o^eX00P3o^e/00`3o^eX0okeN0?nkG0030?nkF`030?nkFP3o^e`0okiS0080okaL00<0ol1V0?nn
H`3o^eX00P3o^eX0303o^e/0okaL0?nkFP3o/E80oj]:0?nXA`3oYdL0oj]?0?nfEP3o_f00okiR0?nj
F@@0ok]K00H0ok]J0?nkF`3o_Eh0okeQ0?njF03o_V820?nkF`0@0?nkFP3o^e/0ok]J0?nkFP3o_Ed0
okaL0?nmH@3o_640okYI0?nkF`3o_fD0okaK0?nlF@3o_5`0okaK0?o0I0<0ok]K00D0ok]J0?nmH03o
_El0okeM0?nkFP020?nkF`060?nnGP3o^eX0okiQ0?nlF`3o^eX0ok]K0P3o_Ed01@3o^eX0ok]K0?nk
F`3o_Ed0okaL0080ok]K00d0okaM0?o1H@3oaf<0oj9?044R4@0000009a0:0;Q6;P3oNdT0og]:0?n8
E`3oReX0oheN0080oh]J0180ohYI0?n<F`3oRET0oh]L0?n>G`3oReX0oheO0?n<GP3oRET0oheM0?n:
F`3oReX0oheM0?n9F@3oSEh0ohaO0?n;FP3oRe/20?n:F`030?nBI`3oReX0ohUH0080ohYI01l0oi1S
0?n;FP3oRe`0ohUI0?n:F@3oREP0ohYI0?nDI`3oRe/0ohYI0?n9F03oRUT0ohaM0?n;FP3oRe`0ohaL
0?n<F`3oSEh0ohQH0?n9F03oRe/0oh]J0?n9F03oSU`0YDdb0000000J1`D0jDPj0?mdG@3oKEL0ofaH
0080ofiH00@0ofaE0?m_F03oLUd0TRhU0P0000003`1S61T0odm>0?mHEP3oFEP0oeME0?mHEP3oFEP0
oeQG0?mEE03oEeH0oeQF0?mHE`3oEeD0oeID0?mKF@020?mHEP050?mGE@3oF5H0oeeK0?mHEP3oFEL0
0P3oEE@0103oEU@0oeaJ0?mGE@3oFUP20?mEE0080?mFE03oGEd0oeME0?mNG03oG5X0odY:0<@_;`1D
5QD30000000;03lL3P37FC00ogQ20?nBC`3oZE/0ojAI0?nSG@3oYUl0oj5G0?nRF`3oX5D00`3oX5H2
0?nPE@090?nRF@3oYF00oieB0?nDB03oRD00oi550?nCB@3oVdl0oj5G0080oj1F00T0oimE0?nPEP3o
WU<0ojAM0?nUH@3oX5H0oj9J0?nTGP3oX5L00P3oX5D50?nPEP0;0?nPE@3oX5H0oj1F0?nPE@3oYV40
oj=L0?nND`3oXUX0ojEN0?nRF@3oX5H00P3oX5D03@3oX5H0oj5F0?nRE`3oY5X0ojUL0?n]GP3oWeD0
ohA70>1U=P2NB2L0NCHM058U500^5@/01@000000300]70/0LT<K0;5V;03mUSd0oia10?ncB`3obU@0
onIP0?oTGP3oged0om]K0?oFE`H0omAG01@0om=G0?oBEP3odUH0omAG0?oBEP3ode/0omIR0?oFI@3o
de`0om5E0?oDE`3oeEd0omIP0?oEF03oe5D0omAG0?oDEP3oe5D0om9F0?oDE`<0omEH00h0om9H0?o@
E03ocE00olQ<0?o5B@3o`4<0ol120?o1@`3oa4H0olM:0?o;C`3od5<0om5G0?oEF0L0omAG0140om9F
0?oDE@3oeEH0omAG0?oCEP3oeEP0omAT0?oDH@3oef40om9H0?o@D`3odUP0omAK0?oDGP3oeUh0omAN
0?oDEP020?oDE`040?oEEP3odeH0omAE0?oEEPX0omAG00<0om5E0?oDE`3oe5L0803oe5L0103oe5H0
om9F0?oBEP3oe5D20?oDE`040?oBEP3oe5D0om=L0?oFI@80omES00T0omEO0?oEE03oe5D0om5E0?oD
EP3odel0omEP0?oCG`3oeUl00`3odUH20?oDE`040?oBEP3oe5D0om=F0?oBEQ40omAG00<0om9E0?o6
A`3oa4L02@3oa4L00`3oaDL0olM90?o4A`020?o4A`060?o6A`3oaDT0olA70?o4A`3oadT0olE7103o
a4L0303oadT0olE70?o5B@3ogE00ooII0?ocF@3olET0ooAI0?odF03oleP0oneN0?oMZol0ooooU`3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?ooo`030<Y`
A@2SERT0VU0T0080W54T0P2MDRH0102MDBD0VU0S0>29?03o]E020?ndCP030?neC`3o]Dh0okA>00h0
okE>00<0okUG0?nkFP3o^eX00`3o^e/20?nkFP030?nlGP3o_F40okaQ0080okeQ00h0okaL0?nkFP3o
^eX0okYI0?njF03o_5`0ol9Y0?o1I`3o`VX0ol9[0?nnH@3o^UP0okYI0?nkFP80ok]K1@3o^eX00`3o
_5d0ok]K0?nkF`0f0?nkF`<0ok]J0P3o^e/20?nkFP050?nnGP3o_F40okeQ0?nlG03o^eX00P3o^UT0
1`3o`VX0ol9Y0?o2J@3o_5d0okYH0?nkFP3o^e/00`3o^eXN0?nkF`80ok]J0P3o^e/02`3o^eX0okaL
0?nmH@3o_F40ok]K0?njF@3o^eX0ol9Y0?o1J@3o`6H0okYJ0080ok]K00<0ok]J0?nkF`3o^e/03`3o
^e/30?nkFP0:0?nkF`3o_5`0okeP0?nmH@3o_5`0okYH0?nnHP3o`V/0okmR0?njF@d0ok]K0100ok]J
0?nkF`3o^e/0ok]K0?nnH03o^e/0okYH0?nmGP3o`FH0okYI0?nkFP3o^e/0okaK0?nmG@3o^UT0ok]J
0`3o^e/05`3o^eX0ok]K0?nkF`3o_F00okeN0?nkF`3o`FP0okmS0?nkFP3o^5L0oja;0?nXB03oYdL0
oje>0?niF03o_5/0okaL0?nlG@3o_Ed0okYH0?nmG@3o_f<0okYJ00<0ok]K0`3o^eX01@3o_Ed0ok]J
0?nmG@3o`FL0okaK00<0ok]K00H0ok]J0?nlG03o^e`0okaM0?nlGP3o_Eh40?nkF`0:0?nmGP3o^eX0
okmR0?njF@3o^e/0ok]J0?nlG03o^UT0okiQ0?nmH080ok]J00X0ok]K0?nlG03o_F00okaM0?nkFP3o
^e/0okaL0?nlG@3o_Eh0ok]J0P3o^e/03@3o_Uh0okYI0?nkF`3o^e`0okeN0?o5H@3aUdX06`h70000
00020000/TDY0?n<F03oReX00P3oRe/05P3oS5/0ohUH0?n;FP3oReX0ohaK0?n;FP3oRU/0oheM0?n;
FP3oSEd0ohaK0?n;F`3oSEh0ohYK0?n:F@3oRe/0oh]J0?n:FP3oS5/0oheN0?n:F`3oReX20?n:F@06
0?n;G03oSEh0ohQH0?nAHP3oRe`0oiAX0P3oRUT20?n;FP0E0?n?H03oRe/0oi9U0?n:F@3oReX0ohaK
0?n:F@3oSEh0oh]J0?n<F`3oRU/0ohYI0?n<GP3oRe`0ohUH0?n?G03oN4l08`l:01h91`3/B3X0ogIO
0080ofmJ00`0og9M0?m/E@3oKUT0og5J0?mWD@2?;2<02@<200P30P2i;B`0oeED0?mMF`3oEeD20?mE
E0030?mKF@3oF5H0oeED0080oeUG02T0oeQF0?mEE03oF5H0oeYH0?mHEP3oEeD0oeED0?mJF03oEU@0
oeUH0?mGE@3oEUD0oe=B0?mQH03oEE@0oeQG0?mGE@3oEU@0oeEC0?mLF`3oEeD0oe]J0?mJF03B=cL0
EA@D034=30050000000000H3001]<AX0g6<e0?n@CP3oXeP0ojQK0?nUE`3oYEl0oiiC0?nQF@3oXeX0
oj1F0?nPE@020?nPEP090?nPE@3oX5H0ojMR0?nUGP3oXEL0oj=L0?nRF@3oWe@0oiM=0080ohe200`0
ohm40?nICP3oXEL0oj1E0?nTG@3oYEl0oiiC0?nQF@3oXe/0oj5G0?nPEP3oX5D70?nPEP070?nNDP3o
YEl0ojIP0?nND`3oX5H0oj=K0?nRF@020?nPEP0>0?nPE@3oX5H0oj1F0?nRE`3oXeT0ojAI0?nRE`3o
RT/0mW0l0:]=:@1G:1D0@Ah@02/C2P0>1P@40000000<03HO3P1]?QX0X5dW0>>:>@3o[TL0okU;0?o6
DP3oe5P0on=N0?oNG03ogE/0omQI1`3oe5L01@3oeEH0omAG0?oDE`3oe5D0omAK0080omEU00X0om=G
0?oBE@3oeEP0om=L0?oEG@3oe5T0om5G0?oDE`3oeEH0om9F2`3oe5L20?oEF0050?oBEP3odED0oliB
0?o9C03o`TD00P3o`D<0603o`T@0olA60?o5B03obTh0om1D0?oBF03oeUL0omAG0?oBEP3odED0om=I
0?oFI@3oeFP0om=O0?oEDP3odeH0omAG0?oFG`3oefH0omAJ0?oBF03odUH0omAG0?oEE`80om9F00<0
omEF0?oDE`3oe5L03P3oe5L00`3odeP0om9H0?oAE@0I0?oDE`<0omEF0P3oe5L02@3oe5D0om5E0?oB
E03oeF<0omEU0?oFI03oeFP0omAH0?oAE@020?oBEP050?oDF@3oeEd0om=L0?oCG03oeEX00P3odUH2
0?oDE`@0om9F6P3oe5L00`3oc500olA70?o4A`090?o4A`030?o7B03oaDT0olA70080olA700L0olI7
0?o5B@3oa4L0olI80?o7B@3oa4L0olE700<0olA700`0olM90?o5A`3oadT0onYG0?ocF@3olUT0oo9H
0?ogF@3olEP0oo9G0?o/J@3oiloo0?oooiL0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWi@3oool01@3]S6D0XUL[09YA902JD2@0Ve4T0080WU<U00@0WE8U09Y@
8`3NR3`0okE@103o]4h00`3o]Dl0okE>0?neCP0<0?neCP030?neC`3o^EH0ok]K0100ok]K00D0okaM
0?nlG03o_5d0okaM0?nlG0020?nkF`80ok]J00<0okiQ0?noI03o_f<00P3o_f@0203o_5`0okYI0?nk
FP3o_5`0ok]J0?nlG03o_V@0okiR0P3o_f<0103o_5d0ok]J0?nkFP3o^e/60?nlG3@0ok]K0`3o_5d2
0?nkF`030?nkFP3o_5`0okmT0080okmS00T0okeO0?nkFP3o^eT0ok]J0?nnH@3o_V<0okmS0?nmH03o
^eX00P3o^e/40?nlG1X0ok]K0P3o_5d03P3o_5`0ok]K0?nkFP3o_5`0okmT0?noH`3o^e/0ok]I0?nk
FP3o_V00okmS0?nnH@3o^eX0ok]K103o_5`=0?nkF`070?nlG03o_5d0okaL0?nkF`3o^eX0okiQ0?no
HP020?nkF@040?nmG`3o_f<0okeM0?nkFP<0okaL203o^e/0303o^e`0okaL0?nkF`3o^eX0okaN0?nn
H@3o^eX0okYH0?noHP3o_5h0ok]J0?nkF`80okaL0P3o^e/0303o_5/0okaL0?niFP3o]5@0oji=0?nW
B03oYTT0ok1@0?neE@3o_V40okaL0?nlFP80okaL0`3o^e/02@3o_5`0ok]I0?nnH@3o_V40ok]K0?nn
HP3o_5`0ok]J0?nlG0020?nkF`0@0?nlG03o_5/0okiQ0?nnGP3o_Ed0okeN0?nnH@3o^eX0ok]L0?nl
F`3o_5`0okiR0?nkFP3o_Ul0ok]I0?nlF`80okaL03D0okaN0?nmG`3o^eX0okeO0?nkF`3o_5`0ok]K
0?nlGP3o^eX0okiQ0?nkF@3o_5`0okaK0?nlG`3o^e/0okeN0?nlG03o_5/0okaM0?nmG@3o_5`0ok]L
0?nkF`3o_5d0okeO0?nkF`3o^eX0okmO0?naEP2fLC<0J3HH00l7101U:1X0^5`k0?n3F03oSU`0oh]J
0?n<F`3oS5`0ohaK0?n<G03oS5d0ohaK0?n<G03oSEd0ohYJ0?n9F@3oReX0ohaK0?n=G@3oRe/0ohaK
0?n:FP020?n;F`0S0?n;FP3oSEh0oh]J0?n<G03oS5d0oi5T0?n@H`3oR5P0oi1S0?n;G03oU6T0ohUH
0?n=GP3oR5T0ohaL0?n:F@3oReX0oheM0?n:FP3oS5`0ohaK0?n=GP3oRU/0oh]K0?n<G03oRUX0oheM
0?n<G03oSE`0ohAG09m9<00R3PT0<@l<0>IJB03oMEl00P3oKUT05`3oKe/0ofiI0?m^F03UGdd0PBPP
01`91`090`80OBDT0?m@CP3oFeT0oeYH0?mHEP3oEU@0oeUH0?mGE@3oFEL0oeQG0?mGEP3oF5H0oeUG
0?mFE03oFEL0oeQF00<0oeUG00<0oeYH0?mHEP3oEeD00P3oFEL07`3oFUP0oeIE0?mIE`3oEeD0oe]I
0?mGE@3oFEP0od]:0:lf=P249BD0EaHE02@8200C1`@0>1T=07Xg7@2;DB/0f7Q10?nHDP3oWeH0ojEM
0?nSF03oY5d0oj9I0?nQEP3oXEP0oj1F0?nQE`3oWeD0oj=K0?nRF@3oX5D00P3oXeX00`3oXEH0oj1G
0?nPEP020?nPEP0<0?nQF03oX5H0oj9H0?nRF`3oVU00oiA90?n<@`3oTDL0oiI;0?nKD@3oX5H0oj5G
0P3oX5H0:`3oXEP0oj1G0?nPE@3oXEH0ojEN0?nPEP3oX5@0oj9H0?nUGP3oXUH0oj5G0?nSF@3oXeX0
oj5F0?nOE@3oWE@0oiYC0?n?C@3UOT@0c7<n09eM<P21BbP0P3XO06@^6@0j6Ph05PX501D:1@0C2`D0
8aH904X[4`1]?a/0P4lQ08][;@2`QCL0d9To0?2ZA`3oa540oleD0?o?EP3odEL0omMH0?oIF@3oeeT0
0P3oeUP20?oDF@0>0?oEF03oe5L0om=G0?oDG@3oeEl0omEK0?oAE@3odeH0omAI0?oDH03oeE`0om=E
0?oDEP3oe5P20?oCF@<0omAG0`3oeEL90?oDE`<0omEG0`3oe5L00`3oeET0omAI0?oDF@020?oDE`0G
0?oBEP3oe5/0om=N0?o@FP3obDl0olU:0?o7B@3o`TH0okY20?njA03o_TX0olQ<0?o;C`3oce80om5E
0?oCF03oeET0omIM0?oDF03oeE/0om=G0?oDE`3oeEP06P3oe5L00`3oeEL0om9F0?oDE`050?oDE`@0
omAI00L0omAG0?oEE`3oe5L0om9F0?oDF03oeEh0omEO0080omIO0`3odeH01P3odUH0omEJ0?oDH03o
e5h0omAP0?oCG@80om=F0P3oeEL01P3oe5T0om=I0?oDF@3oeET0omAH0?oEE`80omAG1@3oeELP0?oD
E`030?oBF03ocU40olE800H0olA700H0olE70?o4A`3oa4L0olA70?o5A`3oaTP40?o4A`070?o6A`3o
aDT0olA70?o6B03oaDL0olA70?o7B@030?o4A`0<0?o7B@3oaDL0olM90?o_E`3oleT0oo9H0?oaF03o
mET0oo5H0?odE`3olGD0ooC]o`3ooonG0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWinD0oooo00/0n9E`0:=G;02GCb@0UdlS09Y@902MDR@0XUDW0:1C9@2ID2@0
h8Tl0?neD0040?ndCP030?neD03o]Dh0okE>0080okE>00<0okE@0?neC`3o]Dh0103o]Dh01P3o]E00
okE>0?neCP3o]Dh0okE@0?nhER80ok]K00<0ok]L0?nkFP3o^e/01@3o^e/02P3o^eX0okYH0?nlG03o
`VT0ol9Z0?o0J03o`V/0okeQ0?njE`3o^UP20?nkFP030?nkF`3o_640okeP0080okeP00<0okeM0?nk
FP3o^e/00`3o^e/30?nkFSD0ok]K0P3o^UP0303o_f@0ol9Z0?o1K03o_V<0okYH0?nkFP3o^e/0okeN
0?nmH03o_F40okaL0?nkFP80ok]K0`3o^eXL0?nkF`0;0?nkF@3o_f@0ol9Z0?o1J@3o_Eh0okYI0?nk
FP3o_Ed0okeP0?nmG@3o^eX00P3o^e/20?nkFQ00ok]K00D0okaN0?o2J`3o`6P0okaM0?nkF@020?nm
H0030?nmGP3o^e/0ok]K0080ok]J203o^e/03@3o_5h0okYI0?nlG03o`FT0okmR0?njF@3o_5`0okUJ
0?n`DP3oYdL0ojM60?nYB03o/U801@3o^e/01`3o^UL0okmT0?noH@3o^eX0okaN0?nnGP3o^e/00P3o
^eX30?nkF`80ok]J00L0ol1U0?njF@3o_5`0okaL0?nmH03o_5d0okYI0080ok]K00D0okaI0?o0J03o
_Eh0okeL0?nlG0020?nkFP070?nkF`3o^eX0okmS0?nnHP3o_5/0okaL0?nkF`020?nkFP040?nnGP3o
`6D0ok]K0?nmG@80ok]J00`0ok]L0?nmH03o_5`0okaL0?nkFP3o^e/0okiS0?njF03o_5`0ok]K0?nl
G03o_F020?nlG00h0?nlF`3o_F00okeM0?nlG03o/U<0oj550?n^C02^J3401P@10000000Q3PT0lG59
0?nBH03oS5/0ohYI0?n=GP3oRe/0ohYI0?n>G`3oRe/0oh]J0?n<G03oReX0ohaN0?n;FP3oRUT0oheN
0?n:FP3oSUl0ohQH0?n?H@3oRe/0ohmP0?n9F03oRU/0ohaL0?n;FP3oS5/0ohYI0?n@HP3oRe`0oiAY
0?n9F03oTF@0ohMG0?nDI`3oSEh0oi1Q0?n8F03oSUl0oi5S0?n=G@3oS5`0ohYI0?n<G03oRUT20?n<
G00:0?n;FP3oQUX0?aTA000000090`80gUY80?m`F`3oK5P0of]D0?m]F@80og9M00P0nd`m01/81`00
0000BA8A0?m5A03oFEP0oeAC0?mGE@@0oeQF00l0oeUG0?mGEP3oF5H0oeME0?mMF`3oEeD0oeQF0?mG
E@3oF5H0oeUI0?mEE03oEeD0oeQG0?mIE`3oF5H00P3oEE@01`3oFEP0oe]I0?mVI@3oDU40odQ70:<Y
:00d30/00P000000300E2@@0>Q/>08Xn8@3oQTL0ojIK0?nSF`3oXEL0oj=J0?nRF@3oXED0oj1F0?nP
E@80oj1F00D0oj9J0?nQE`3oY5`0ojMQ0?nQE@030?nPEP0:0?nPE@3oX5H0oj1F0?nQF@3oXe/0oimE
0?nUG`3oZF<0oj5G0?nPE@<0oj1F01T0oiaA0?nAA@3oST<0ohi20?nBA`3oVe<0oj1F0?nOE03oYV40
ojIP0?nNDP3oX5H0oj9G0?nTF@3oYUX0ojMK0?nVF`3oVe<0oi9?0?n=C03oOT@0e5lc08Xn8@1]<AX0
4PP400<0000000`00`8101T>1P0[5`X0>R8?07U87P3:MS40oia10?nhC@3of5X0omUH0?oGF03oe5P2
0?oFE`0;0?oDE`3oeEH0omEF0?oDE`3oeEH0omAG0?oDG03ode`0omAG0?oDE@3odeP00P3oefH00`3o
eF00om9F0?oDE`0E0?oDE`030?oEEP3odUH0omEF0080omAG00d0omEG0?oEF`3ode`0om=L0?oDFP3o
eEH0om9D0?oAE@3oeV<0omQU0?oEI@3oeEP0om5E00L0omAG00d0om=G0?o=D@3obDd0olM80?o4AP3o
_4<0ol120?o4A03o_dH0olU?0?o=D`3oceD0omAG0080omEH4@3oe5L01@3oeEL0om9F0?oEEP3odUH0
om=G00<0omAG0140omEF0?oCF@3ode`0om=M0?oCFP3oeEP0om9F0?oEEP3odU@0om9F0?oEH`3oeFL0
omEU0?oEJ03oe5L0om9D0?oBE@0o0?oDE`030?oEF03obdl0olA700L0olA700H0olM90?o4A`3oa4L0
olE70?o4A`3oaTP40?o4A`040?o6A`3oaDT0olA70?o6B080olA700l0olI90?o4A`3oa4L0olA70?o7
B@3oaDL0olU90?o_EP3olEL0ooAH0?oaF03om5P0oo5H0?ocEP3oli<0o`3ooonH0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinD0oooo00D0oYYg0:AH;@2MDRD0
UTlS09U?8`0209Y@900409mC9@2ICbD0lIA00?neD0@0okA>00<0okE@0?neCP3o]Dh00P3o]Dh00`3o
]E00okE?0?neCP040?neCP030?neD03o]Dh0okE>0080okE>00<0okE@0?nkFP3o^e/08@3o^e/00`3o
^eX0okeM0?nkF`070?nkF`@0ok]J0`3o^e/0203o^eX0okYH0?nkF`3o`V/0ol5X0?o0J03o`VX0okiR
0P3o^UT0203o^eX0okYI0?nmG`3o_V<0okiR0?nnH`3o_F40okYI0P3o^eX20?nkF`<0ok]J00<0okaI
0?nkFP3o^e/0:`3o^e/40?nkFP0;0?nkF`3o^eX0okYI0?o0IP3o`FT0ol5Z0?nmG@3o^UL0okYI0?nk
F`3o_V<00P3o_V801@3o_El0okYI0?nkF`3o^e/0okaJ00<0ok]J5@3o^e/30?nkFP060?nkF`3o^eX0
okUF0?noI03o`FT0okmT0P3o^UT0103o_5d0okiS0?nnH`3o_Ed20?nkF`80ok]J303o^e/20?nkFP0:
0?nkF`3o^eT0ol5W0?o1J03o`6H0okYH0?nlG@3o_F40okiS0?nlG080ok]K00<0ok]J0?nkF`3o^e/0
0`3o^e/03@3o_F00ok]J0?nkFP3o_5`0okUH0?neE`3oZTl0ojE50?nYB03o[e40okQL0?nlGP3o^e/0
0P3o^eX30?nkF`0D0?nkFP3o^e/0ok]J0?o0I03o`6L0ok]J0?nmH03o_V80okaL0?nkF`3o^eX0ok]K
0?nkFP3o_Ed0okYH0?nmGP3o_640okaJ0?nnGP3o_F430?nkF`80ok]J00D0okiR0?nmG@3o^UL0okiP
0?nlG0030?nkFP050?nnH03o_F40okYI0?nmH@3o^e`00P3o^eX03@3o_5/0okiQ0?nlG@3o_5h0ok]K
0?nkF@3o_V80okeN0?nkF`3o_5d0okaI0?nkG03o_F000P3o_5`05`3o^eX0okeL0?nmG@3o_5`0ok]J
0?nlF`3o^U/0ojU90?nZA`3o/500okmP0<1V<P0/5PX0000004<K4@3oLDX0oiIT0?n>GP3oReX0ohiO
0?n;FP3oRUT0ohaM0080ohYI0P3oS5`02`3oRe`0oh]J0?n<F`3oRe/0ohUH0?n<G03oRUT0oh]L0?n:
F@3oS5`0oh]J0080ohYI04<0ohUH0?n;FP3oS5`0oh]L0?nDJ@3oQeL0oi5T0?n9F03oSf00ohYK0?n:
F@3oRU/0oh]J0?n7E`3oS5`0ohUH0?n<G03oS5/0oheM0?n>G`3oReX0oiIT09i7;`0000002@<20<0j
;P3oLUd0ofaH0?m_FP3oK5D0og5L0?mTDP2K<2H0000000`30`2P:BL0oe9A0?mQH03oEU@0oeUG0?mE
E03oFEL0oeMF0?mIE`3oFeT0oeAC0?mGEP3oFEL0oeUH0?mED`3oF5H0oeUG0?mIF03oEU@0oeMF0?mI
F03oF5H0oe]J0?mFE@3oEeD0oeaJ0?mJF03oGeh0odQ80>Xh>02B9B@06PL60080000000T080l8064/
603`JcL0oiiH0?nYF`3oYE/0oj1F0?nWHP3oXEL00P3oX5D20?nPEP0A0?nSF`3oXED0oj9F0?nWH@3o
XUT0oj1F0?nPE@3oX5H0oj1E0?nPEP3oX5D0oj9K0?nRF@3oWe@0ojAM0?nWHP3oXEH00P3oX5D20?nP
EP80oj1E01D0oj1F0?nRF@3oXe`0oiU?0?nAA@3oR3l0oh]50?nGC@3oWE80oj9G0?nWFP3oZE`0ojeN
0?nVF@3oTDh0ohQ90?mnA03QISL0UT4S05PY5P0d60d0100000003@0B2`D0?B@?05Xc5P1]?QX0/fP[
0?nH?P3o]4`0om5G0?oQGP3ofe/0omUJ0?oGF03oe5L00`3odUH0203oe5L0om9F0?oEF`3oeUl0omEM
0?oDE@3odU@0om9F0P3oeF@00`3odeL0omAE0?oCE`020?oBEP030?oEEP3oe5L0omAG00h0omAG01D0
om=G0?oBEP3odUH0omEF0?oDE`3oe5D0omAG0?oEG@3oeUl0omAL0?oDE`3odED0om9F0?oDH`3oeFD0
omIT0?oDG@3odU@0om9F0?oDE`3oe5H00P3odUH90?oDE`0@0?oEE`3oe5L0om=I0?oFGP3od5@0oke:
0?o0A`3oaTH0ol540?o0@P3o_D80ol560?o:C@3oce80om1D0?oBEP80omEH1P3oe5L03`3oe5H0om9F
0?oBEP3odUH0omEG0?oDE`3oeEH0om9F0?oDF@3oeUl0omEM0?oFG`3oeUd0omAE0?oBEP020?oAE@09
0?oDH03oeFD0omEU0?oDH@3ode/0om1C0?oDE@3odeL0omAG00@0om9F@@3oe5L01@3oeEL0olm@0?o4
A`3o`dL0olE700H0olA700<0olU90?o5A`3oaTL00P3oaDL0103oaTP0olA70?o4A`3oa4L20?o5A`03
0?o7B@3o`dL0ol160080ol1600l0ol990?o0AP3oaTL0olM90?o6A`3oaDP0olY:0?o^E@3om5P0oneF
0?obF03om5P0oo5H0?obF@3ohg/0o`3ooonH0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWinD0oooo00/0okJQ0:UL<`2FCb<0VU4V09U@902IDBD0VU0S0:9C9P2F
Cb@0o9]50?neD0040?ndCP030?neD03o]Dh0okE>00<0okE>00<0okE?0?neCP3o]Dh00`3o]Dh00`3o
]E00okE>0?neCP030?neCP030?nhE@3o_5`0ok]K0240ok]K0P3o_5`00`3o^eX0ok]K0?nkF`0>0?nk
F`0?0?nlF@3o_5X0okaI0?nlF@3o^eX0ok]K0?nkFP3o^UT0okYH0?nnH@3o`6P0ol1V0?o0I`3o_V@0
okYH00<0okYI00H0okaL0?noI@3o_fD0okmU0?noIP3o_F020?njF@<0ok]K00@0okaJ0?nkFP3o_5T0
okaI:P3o^e/00`3o^eX0okaI0?nlF@030?nkF`060?nkFP3o`6P0ol1W0?o0I`3o_V40okYH0P3o^UT0
1@3o_F40okmU0?noI@3o_V80ok]J00<0ok]K00<0okaJ0?nlF@3o^eX04`3o^e/01`3o^e`0ok]J0?nl
F@3o^eX0ok]K0?nkFP3o_Eh00P3o`6L01`3o_Uh0okYI0?nkFP3o_V80okmU0?nnH@3o^eP00P3o^e/0
0`3o^eX0okaI0?nkF`090?nkF`0>0?nkFP3o_5T0ok]J0?nkFP3o_Eh0okmU0?o0I`3o_5/0okYI0?nn
GP3o_fH0okeO0?nkFP3o^e/20?nkFP0C0?nlG03o^eX0okaK0?niF@3o[Tl0ojM70?nWAP3o[4`0okEC
0?nmHP3o`FT0okaN0?nkFP3o_V80okmT0?nmG03o^e/0ok]J0?nlF@020?nkF`<0ok]J0140okiS0?no
I`3o_5d0okaK0?nmH03o_5d0ok]J0?nlG`3o^eX0ok]K0?nkFP3o^e/0okiR0?o0I03o^eX0okeO0?nn
GP030?nkFP0>0?nkF`3o^UT0okiS0?nlGP3o_V40okeQ0?njF@3o^eX0ok]K0?nlF@3o_fD0okaK0?nn
HP3o^e/20?nkFP80okeP00l0ok]J0?nmH03o^UT0okYI0?nmG@3o_5h0okiR0?njF@3o^eX0okeM0?nk
FP3o_Uh0ok]K0?nlG03o_Ed00P3o_5`0603o]5<0ojI70?nVB03o^5L0okeM0?o:I@3oVDd0LS`L0000
000Z4@/0eEDg0?n>H03oSed0oh]L0?n<G03oRUT0oh]L0?n=GP3oR5P0ohYK0?n;F`3oRUT0ohUH0?n;
FP80ohaL02P0oheL0?n9F03oSUl0oh]J0?nBI@3oRUT0ohmP0?n9F@3oQeL0ohYI0?n9F03oRe`0oiAX
0?n:F@3oRe/0ohQG0?n9EP3oRUT0ohaL0?n:F`3oSf00ohMG0?n>GP3oRU/0ohiO0?n;FP3oSEd0ohYI
0?nEH@3oM4`07P`800H20@36?C00og=L0?m]F@3oLUd0of]G0?mbG@3jHDh0D1PD0P0000002`2W:BT0
oeiL0?mIE`3oDe<0oeQG0?mLFP3oDe80oeQG0?mIE`3oEE@0oeQF0080oeUG00`0oe=A0?mJF@3oFEL0
oeYH0?mEE03oEeD0oe]I0?mJE`3oGE/0oeED0?mFE03oG5X20?mMG0030?m:B@2f;2/0>@h=00800000
01804PP406`a6P2eDR`0ogI00?nTF@3o[680oj=J0?nRF@3oY5d0oj1E0?nOE03oX5D0oj5G0?nTGP3o
Y5X0oimD0?nUGP3oX5H20?nPE@090?nPEP3oX5D0oj1F0?nPEP3oY5d0oj1F0?nND`3oY5h0ojAK00<0
oj1E00d0oj1G0?nPE@3oX5D0oj1F0?nQE`3oYV40oj=L0?nPE@3oXUT0ojMQ0?nSF`3oWU<0oiQ<0080
oiI600T0oie<0?nHC`3oPDH0ogM10>5T=P2YC2T0GBXF03LH30091@40100000003P0]6`/0KChJ08Y@
8P2/IRT0li0k0?neB`3odEL0onEO0?oSGP3og5`0omUJ0?oGF03odeH0omAE0P3oe5L02P3oe5H0omIO
0?oDH@3oeUl0om=F0?oDE@3oeEd0omES0?oDH@3ode<20?oDE`030?oCEP3oe5D0omAG00l0omAG00<0
omAE0?oBEP3oeEH00P3oe5L03`3oe5D0omAL0?oDH@3oe640omEM0?oBEP3oeE@0omAG0?oDH@3oeF<0
omIO0?oBEP3oe5D0omAG0?oBEP020?oDE@030?oCE`3oe5L0omAG00`0omAG00`0omEF0?oCFP3oeE/0
om5G0?oDH@3oe5T0omEI0?oBF03oce<0olY?0?o5B`3o`dH20?no@P0=0?o1@`3oaDP0olY;0?o>D@3o
e5D0omMH0?oEF@3oeEP0omAG0?oDE@3odU@0omAN0?oEH0020?oDH@0;0?oDFP3oe5D0omAE0?oDE@3o
deT0omMT0?oDH@3oeF<0omEP0?oBE03oe5D00P3oe5L00`3oeEH0omAE0?oDE@020?oCE`030?oBEP3o
e5L0omAG04@0omAG00L0om9F0?oDE@3oe5D0olE70?o4A`3oaDL0olI700<0olA700H0olE80?o6B@3o
`dH0ol190?o0AP3o`4D20?noA@090?o2B03oaDP0olI70?o5B03oaTP0olI90?o8B@3o`TH0oka50080
oke500@0okm70?nmA@3oa4L0olM90P3oaDP02@3obDT0oo5G0?ocF@3ojeH0oo1G0?oeF@3olEP0onUF
0?oPN03o0?oooiP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWi@3oool02`3oa;00[5hf09M?8`2KDBH0VU4U09U?8`2GD2@0V4lS09Q?903kVd@0okE@0080okA>
00<0okE?0?ndCP3o]Dl01@3o]Dh00`3o]Dl0okE>0?neCP030?neCP030?neC`3o]Dh0okE>00<0okE>
00<0okI@0?nkF03o^e/08P3o^e/0103o_5/0ok]J0?nmGP3o_5dH0?nkF`040?nlFP3o^e/0okaJ0?nl
F`<0ok]K00<0ok]J0?nlG03o_F000P3o_F000`3o_V00okaM0?nkFP020?nkFP040?njF@3o_5`0okmU
0?noI080okmU00`0okeN0?nkFP3o^eX0ok]J0?nlF`3o_V40okmQ0?nnH@3o_f80okeN0?njF@3o^eXU
0?nkF`<0okaJ0`3o^e/02@3o^eX0okeN0?nmH03o_F00okeN0?nkF`3o^eT0ok]J0?nnGP020?noI@08
0?nnHP3o^e/0ok]J0?nkFP3o_El0okmQ0?noHP3o_Eh20?nkFQ40ok]K0P3o_5X30?nkF`0?0?nmGP3o
_F00okeN0?nkFP3o^eT0ok]J0?noH`3o_fD0okeN0?nkFP3o_5/0okiQ0?noH@3o_El0ok]J00T0ok]K
01D0okaJ0?nkF`3o^eX0okeM0?nmH03o_5d0ok]J0?njF@3o_V@0okmS0?nhF03o]UD0ojm?0?nUB03o
ZTT0oji=0?ndE@3o^UX0okaL0?nkF`3o_5X00P3o^e/0;P3o_Eh0okeO0?nlG03o^eX0okiR0?noIP3o
^eX0ok]K0?noHP3o_V00ok]K0?nmG@3o_5d0ok]J0?nmH03o_5d0okaL0?nkF@3o_V40okeN0?nkFP3o
_Ed0okeP0?nkFP3o^e/0ok]J0?nmGP3o_Ed0ok]J0?nmH03o_Eh0okaL0?nnH@3o_E`0ok]K0?nmG@3o
_5h0okYH0?nnH@3o^eX0okaM0?nnG`3o_5X0okaN0?nkFP3o_5d20?nlGP0Y0?nmG@3o^e/0okaL0?nm
H03o_V00okaK0?nlG@3o_Eh0ok]J0?nmH03o_Ed0okeK0?nlG@3o^e/0okeM0?nmGP3o_E`0okaM0?n[
B`3oZ4T0ok=F0?nkF`3o_Ed0okaM0?o2H03o_Eh0]W<i03DL3@000000AQ/B0<AO?`3oT5l0oheK0?n<
F`3oRe/0ohaL0?n=G`3oRU/0ohaK0?n:F@3oRe/00P3oS5`04`3oRe/0ohaK0?n<G03oS5`0oh]K0?n;
FP3oSf00ohaM0?n8F03oTVD0ohiP0?n:F@3oRe`0oiEY0?n:F@3oREP0oi5U0?n=H03oRUP00P3oSEd0
1P3oRUT0ohaL0?n;G03oSEl0oh]J0?n=G@80oheL00D0[e0e020<200f4@h0iEY80?m`F`020?m_FP0D
0?m`F`3iHTl0XSld02d?2`0Y2PX0Q28Q0=I4@`3oF5H0oeQG0?mIF03oF5H0oeQG0?mGE@3oFUP0oeQF
0?mHE`3oFUP0oeME0?mJF@3oEeH20?mHEP0P0?mIE`3oEeH0oeiM0?mED`3oF5L0oe]J0?mHE`3oDU80
eT=20:<b<@1M5QH0>Pl>01X61P0W4PT0MC@L08e79P2gHcD0l8]>0?nMDP3oZEd0ojYQ0?nQE`3oXUT0
oj1E0?nRF03oXeX0oimE0?nTG@3oXed0oj5F0?nRFP3oXUP20?nPE@090?nSFP3oY5/0oj1F0?nRFP3o
YEh0oj1F0?nOE@3oXUX0oj1F0080oj1E02L0oj1F0?nRF@3oY5d0oj9H0?nOE@3oYEl0ojEN0?nRF03o
XeP0ojMN0?nWG@3oWeH0oI1>0=n0A@3:Md40]Flm0:AI<025>ah0JBlF04XP3`0f60`06P`700d60`0L
4@H0@BH@06Xn6P1mBQh0REXU0:Me<03?V400h:U60?FgC03o`e40om5F0?oIF@3ogE/0om]K0?oIF03o
eeT00P3oeEd04@3oe5D0om=F0?oDE03oeUl0omIQ0?oDF`3odeH0omAG0?oDF`3ode`0omAK0?oEE`3o
e5L0omEG0?oDEP3oeEL0om=H00H0omAG00/0omEG0?oCE`3odeL0om=G0?oDE`3odeL0omAE0?oDFP3o
eEh0omEM0?oEF@020?oCEP080?oDF`3oeV80omAP0?oEG`3odUH0om9E0?oDEP3oe5X20?oCG0070?oE
FP3oe5L0omAG0?oDE`3odeL0omAF0?oCE`0@0?oDE`080?oCE`3oe5H0omEK0?oCE@3oe5T0omEL0?oD
F03oeEP30?oCE`0P0?oCEP3odeP0omEM0?oDGP3odeh0om9K0?o@EP3ocE00ola<0?o8BP3o`DH0okM2
0?nh@P3o^4<0okm80?o:C@3ocE40om1C0?o@E03oe5/0omAL0?oEG03ode`0omEH0?oDEP3oeEL0omAG
0?oDF03oe5H0om=G0?oDEP3oeEL80?oDE`030?oEF03odUP0om9G02d0omAG1@3odeL30?oDE`040?oC
E`3odeH0om=F0?oDF@H0omEM00<0omAF0?oCEP3odeH00P3odeH0103oe5H0omAP0?oCH@3oa4`30?no
AP030?o3B03oaDP0olE800<0olE800<0olA70?o2A`3o`dL00`3o`TH0203oa4P0olE80?o8B@3oaDP0
olA70?o6A`3oaDT0olA70P3oaDL00`3oadP0olQ90?o5A`020?o5B0030?o4A`3oaDP0olY:0080ooAH
00H0ooAI0?oaF03omET0ooAH0?o]F03ogYgo0?oooiP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWi@3oool0103of<d0[F0j09M?8`2ID2D209Y@900509M@902I
Cb<0STXP0?ZI@`3o]U00103o]4h40?neCP030?neD03o]Dh0okE>00d0okE>00<0okYG0?nkF`3o^e/0
8`3o^e/00`3o_5`0okaI0?nkF`0Y0?nkF`@0ok]J0`3o^e/01`3o^eX0ok]K0?nmH03o_F00okiN0?nm
H@3o_Ed00P3o^eX0203o^eT0okYH0?nkFP3o`V/0ol9Z0?o2J@3o`V/0ol1T0P3o^UTZ0?nkF`<0ok]J
0`3o^e/03@3o_Ed0okeP0?nmH@3o_Ed0ok]J0?njF@3o^eT0ol1X0?o2JP3o`FT0okmT0?njF03o^UT0
5@3o^e/20?nkFP<0ok]K0P3o_F00103o_Eh0okYI0?njF03o_Ed20?o2J@030?nmG@3o^UT0ok]K00X0
ok]K00L0ok]J0?nbDP3oZTX0ojQ70?nWA`3o[e00okeM0080ok]J00@0ol5W0?o1I@3o^UT0okYI1P3o
^e/20?nkFP80ok]K00L0okaP0?nlH@3o_Eh0okiS0?o2J`3o`FD0ok]I00H0ok]K00H0okaL0?nmGP3o
^UL0okeP0?o2J@3o_5d20?nkF`080?nkFP3o^e/0okaL0?nnGP3o_5`0okeO0?o0I`3o_5/20?nkFP0a
0?nkF`3o_5d0okiN0?nlFP3o`FT0okeM0?nkFP3o^e/0okaM0?nlG03o^e/0okmS0?njF@3o^eX0ok]K
0?nmG03o_V<0okaQ0?njF@3o_5`0ok]K0?nmGP3o_V80ok]K0?nmG03o_Ed0ojiC0?nWA`3o]EH0okeL
0?nnGP3o^eX0okaM0?nlG03o^eX0ol1M0?nbG@3<Jc@050/400L20P1i;al0ogiD0?nCH@3oRUX0ohiO
0?n:F@3oSUl0oh]K0?n>G`020?n;FP060?n<G03oRe/0oh]J0?n<F`3oRUT0ohmP0P3oReX02@3oRe/0
oh]L0?n>H03oReh0ohYI0?n;G03oU6T0oh]J0?n=G@020?n:F@0M0?nBI@3oR5T0oh]J0?n=GP3oSf00
ohUH0?n:F@3oSUl0oh]L0?n:F`1Q9QT0000000H20@3ZFdT0ofiH0?m`F`3oKEL0og5L0:8b:00D1`D0
000005LF5@3oDU80oeYH0?mGE@3oFeT0oeME0?mCDP3oGE/00P3oF5H04@3oFeX0oeQF0?mFE03oHF00
oeED0?mHE`3oEeD0oeiM0?mLFP3oEE<0oeQF0?mED`3oHf<0oe=B0<Tf=@123Ph07`H6008000000100
8a0707hj7`3aK3X0oi9=0?n/H`3oZf80oj5F0?nRFP3oX5D0oimE0?nPE@3oXUT0ojMQ0?nOE03oX5H0
oj5I0`3oX5D01`3oX5H0oimD0?nWHP3oYf40oj1E0?nSFP3oXUX00P3oX5H0303oX5D0oj1F0?nPEP3o
X5D0oj9J0?nXH`3oZ6@0oimD0?nQF@3oXe`0oj=I0?nRF080oj9G00L0ohQ:0=mW=`2=?b80EBHD03LH
3P0O3PL00`4100@0000001D0;Q/<07E3702mKR`0n8he0?nP>@3o[3d0ok]70?oFF@3ogUd0omeL0?oK
F`3oeeP0om=G0?oDE`3odUD0omIQ0?oGIP3oeV@0om=I0?oDE@3oeEP00P3ode`01@3oeEH0omAG0?oD
E`3odeL0om9F0140omAG00d0omAE0?oCF03oeFP0omEU0?oGIP3odeP0om5E0?oBEP3oeEP0om=M0?oC
G03oeEP0omEF0080omAG00<0om9F0?oEEP3oe5H06`3oe5L03`3odeL0om=I0?oEHP3od5<0om9F0?oD
FP3oeV@0omAW0?oFIP3oeFD0om=G0?oBE03odeH0omEF0?oDE`030?oCG0030?oEF`3oe5L0om=G0080
omEH00D0omAG0?oCE@3ocE40ola=0?o5B0020?o1@`050?o2A03o`DH0olI90?o8C03ocE<0503oe5L0
0`3odUP0om9G0?oDE`0V0?oDE`050?oCEP3odU@0om9D0?oBE03oeF800P3oefH0103oeFD0omQV0?oE
I@3odUP20?oBE0040?oBEP3oeEH0omEF0?oEF@H0om=L0P3oeEH40?oDE`030?o@E03oaTT0olE700<0
olA700<0olI80?o4A`3oa4L02@3oa4L00`3oaTP0olA70?o7B@020?o4A`050?o6A`3oadT0olA70?o5
A`3oa4L00P3oadT40?o4A`0:0?o5A`3oaDP0ooAH0?odF03olUT0oo5H0?oeF@3okEL0oo5N0?ohmOl0
ooooV03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?oo
o`060?ono`35Le<0UdlS09U@9@2JDB<0Ve0T0P2ICb<00`2AC200nYY30?neD0030?ndCP060?ndD@3o
]4l0okA>0?ndCP3o]500okI@0P3o]4h40?neCP030?neD03o]Dh0okE>00H0okE>00<0okE@0?njF03o
_5`0903o^e/00`3o^UT0okaL0?nkF`0a0?nkF`80ok]J00<0ok]K0?nkFP3o^e/00`3o^e/00`3o^eX0
ok]K0?nmG@030?nmG@030?nlG03o^e/0ok]J0080okYH00P0okmR0?o1K03o`FT0ol9[0?o1J@3o^UL0
okYH0?njF@80ok]K103o_5`Q0?nkF`80ok]J103o^e/0103o_5d0okeM0?nmG@3o_5`20?nkFP050?nj
F03o_V80ol9[0?o2J`3o`FP00P3o^eX20?nkF`80okaL00<0ok]L0?nkF`3o^e/0303o^e/20?nkFP80
ok]K00D0ok]J0?nkF`3o_Ed0okeM0?nkF`020?nkFP040?o2JP3o`FX0ol5V0?nkF@80ok]K0P3o_5`0
5P3o^e/0okIG0?n^C`3oZDP0ojM70?nZBP3o]5D0okaK0?nlG03o_Ed0okYI0?nmG@3o_5`0ok]K0?nj
F@3o_f80ol5X0?nnH03o^UP0ok]K0?nlG03o^e`20?nkF`030?nnH`3o_Uh0ok]J0080okaL00L0okaM
0?nlG03o^eX0okmU0?o1K03o_F00ok]I0080okaL0P3o^e/02@3o^eX0ok]K0?nmG@3o_5/0okiN0?o1
J@3o_F80ok]I0?nlG0020?nkF`80okaL00@0ok]J0?nlG03o`6D0ok]J0`3o^e/01@3o_5d0okYI0?nm
GP3o_V40ok]J0080ok]K00<0okaL0?nmG@3o_f@00P3o^e/01@3o_5`0ok]K0?nkG03o_V00ok]J0080
okaL02L0okiP0?nkFP3o]UL0ojU90?n[CP3o^e/0okaL0?nkF`3o_Uh0ok]J0?nkF`3o_Ed0okaN0?no
GP3o`Eh0oia<02TG2`000000<a<<0?IP?P3oS5h0ohaL0?n>G`3oRUT0oheN0?n;FP3oSUl0oh]J0?n<
F`3oRe/0ohaL0?n:F@3oSEh0oh]L0?n:F@3oReX0ohmQ0?nAI03oREP00P3oRUT05@3oRe`0oiAX0?n?
H03oSUl0ohUH0?n:F@3oSEh0ohmQ0?n;FP3oS5`0ohUI0?n<GP3oS5/0oh]J0?n>G@2`ECT0000000P2
0@3CASX0ofmI0?maG0020?m_F@0:0:0g;@000000000003X=3@3oCD`0oeUH0?mHEP3oFeT0oeME0?mM
F`80oeQF00H0oeYH0?mED`3oF5H0oeME0?mKF@3oF5H20?mGE@0J0?mJF03oEeH0oeUH0?mCDP3oG5/0
od4o09XW9P0g2`/02041000000050P009Q070<IL<P3oUE00oiYC0?nYH`3oYET0oj5G0?nPE`3oX5H0
oimE0?nRF@3oZFD0oj=J0?nPEP3oX5L20?nPEP0M0?nPE`3oX5H0oj1D0?nVH03oXe/0oj1E0?nRF@3o
X5L0oj1F0?nOE@3oX5H0oj1G0?nPEP3oXED0ojMQ0?n[I@3oXeP0oj=I0?nSFP3oXET0oiiE0?nME03o
T4d0ogDo0:a>:P1K:AH080h701@:1@060`400`0000005P040P408Q@706Dm602SGbP0ji4m0?noC`3o
aU40olaC0?oBEP3oeUH0ole>0?o7AP3oa4D0olE80?o>C`3ode<0omEP0?oEI`3oeF<0omEF0?oCEP3o
eEP20?oDFP<0omAG0P3oeEH;0?oDE`<0om9H00H0omAG0?oBEP3oe5D0omAR0?oGIP3oeVL20?oBE003
0?oBEP3oeEL0omAJ0080omAJ103oe5L20?oEEQL0omAG0`3odUP03P3oeEP0omAG0?oDE`3odED0om=E
0?oEI03oefH0omAQ0?oFG`3odeT0om9F0?oBE03odUL0omAG103oe5X00`3oe5L0omEF0?oDE`020?oD
E`<0omEF1P3oe5L01`3oeEP0omAG0?oDE`3odeH0oliB0?o8C03o`dD00`3o`T@0103o`dD0olA60?o9
CP3oceDB0?oDE`030?oEF03odED0omAG0100omAG1@3odUP0203oe5P0omAG0?oDE`3oe5L0om9E0?oB
E03od5@0om=I0P3oeFL01`3oeFD0omEW0?oEI`3oeEd0om1D0?oBE03odeD00`3oe5L00`3odeT0omAJ
0?oDFP030?oDFPL0omAG1P3oeEH60?oDE`030?o;C03oa4L0olA700<0olA700<0olI90?o4A`3oa4L0
0`3oa4L00`3oaDL0olA70?o4A`030?o4A`030?o6B03oa4L0olE700<0olA700@0olE70?o4A`3oaTP0
olA70P3oadT50?o4A`080?o9B03olUT0ooEI0?obF@3olEP0oo1F0?o`E`3ojfOo0?oooiT0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWi@3oool02`3oo?l0^F]7
09M?8`2GD2@0VDlS09UA9@2GCb<0Ue0T091:8@3jVT<0okE@00@0okA>3`3o]Dh30?ndCP050?ndC`3o
]4h0okE>0?nhD`3o_fD00`3o^UP01@3o^UT0ok]J0?nkFP3o^eX0okaK00<0okaN00D0okeN0?nlGP3o
_5h0okaN0?nlG0030?nkFPD0ok]K1`3o^eX50?nkF`030?nkFP3o_Eh0okeN04/0ok]K00X0ok]J0?nj
F03o_Ed0ol9Z0?o2J`3o`FX0ol5/0?nnH`3o^eP0okYH0P3o^eX00`3o^e/0okeN0?nlGP020?nlGP03
0?nlG03o^eX0ok]K0080ok]K1@3o^eXO0?nkF`030?njF@3o^UP0okaL0080ol9[00X0ol1U0?njF@3o
^eT0ok]J0?nlG03o_5h0okeN0?nlG@3o^e/0ok]J0P3o^e/20?nkFQ00ok]K00X0okYH0?nlG03o`V`0
ol1W0?naD@3oZdT0ojQ70?n[C03o]EL0okaM0`3o^e/00`3o^eX0ok]H0?nlG0070?nkF`080?nkG03o
`fh0okmU0?nmG@3o_5/0okeM0?nlGP3o_5d20?nkF`80ok]J103o^e/01`3o^eT0ol1X0?o0J03o_5`0
ok]J0?nlGP3o_Ed00P3o^e/02P3o^eX0ok]K0?nkF`3o_E/0ol9Z0?noI@3o^eX0okaL0?nlG@3o^eX2
0?nkF`0;0?njF@3o_F40ol1X0?nlF`3o_5d0okaL0?nkF`3o_5X0ok]H0?o1J03o_F000P3o_5`0703o
^e/0ok]J0?nnHP3o^UT0okaL0?nlG@3o^eT0ol1T0?nmH@3o^eX0okeL0?njF`3o[E40ojI50?ncD`3o
^eT0ol5W0?njF@3o_5/0okiN0?nlG@3o^e/0okeO0?njF@3o_5`0ol1O0=V<A@0G30H20000000K0<ML
?P3oS5/0ohiN0?n=GP3oRe/0ohaL0?n:F@3oSf00ohUI0?n9F03oSEh0ohiO0?n:F@3oReX0ohiO0?n<
G03oSEd0oh]J0?n:F@3oR5L0ohYI0?n;G03oUFT0ohiO0?n@H`3oSf00ohUH0080ohYI01/0ohaL0?n;
G03oRU/0oh]J0?n=GP3oSUd0oh1G030C30080`80fDDi0?mdG@3oL5X0og9L0?mWE02^=b`00@000185
1@2G92<0oeAD0?mHE`3oFEP0oeEC0?mGE@3oFEP0oeME0?mED`3oHf400P3oEeD02`3oFeT0oeME0?mG
E@3oF5H0oeeK0?mGE@3oFUT0oeID0?mJF@3n@400EADD00<0000000@09A0708<l803oMD80oi]C0P3o
YE`01`3oX5D0oj5F0?nRF@3oX5H0oiiC0?nWH03oXEP00`3oX5H02@3oXEL0oj9J0?nPE@3oX5D0ojQR
0?nPE@3oWe@0oj9F0?nQE`020?nPEP0?0?nRFP3oXEP0oimC0?nUGP3o[6H0ojML0?nUF03oWeH0oiaD
0?nDD03oSTd0ogI00=IP<`1h=ad08@h700@0000001T01@@10149100U5PT0FC@E0:1M9`3BNS<0ojm9
0?oBE@3odeH0omAG0?oEE`3oeET0omEL0?oDF`3oeET0om5E0?oDEP3odU/0okE60?nl@P3o`d@0olA7
0?o@E03odUP0omEH00P0omAG0P3oeEH30?oDE`0=0?oEE`3oe5X0omAJ0?oBF`3odeP0om9F0?oBE03o
e5D0omIU0?oEI`3oeFH0om9D0?oBEP0G0?oDE`@0omEF0P3oe5L20?oEEP0=0?oBFP3odU/0omAJ0?oE
F`3oe5T0omEF0?oAE@3odU@0omAJ0?oEJ03oefH0omEV0?oEH`020?oBE0050?oBF03odeP0omAS0?oC
G03odUH07`3oe5L03P3odE@0olM:0?o4AP3o`dD0ol940?o1@`3o`T@0olA70?o9C@3od5<0om=F0?oD
E`3odUP0omEH1@3oe5L60?oEEP070?oDE`3oeEP0om5F0?oEEP3oeEL0om9F0?oDFP020?oBF`040?oD
FP3odU/0omEK0?oDF@<0omEF00H0om9D0?o@E03oeEP0omIT0?oEJ03oeV@20?oEI`050?oGI@3odED0
om9D0?oBE03odeH09`3oe5L00`3ocU40olA70?o4A`040?o4A`030?o6B03oa4L0olA700T0olA700<0
olI80?o4A`3oa4L00`3oa4L0103oaDL0olA70?o6B03oa4L20?o7B@<0olA700X0olE70?o4A`3ocD/0
ooAH0?oeF@3olUT0oniF0?obEP3omEL0on=Vo`3ooonI0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWinD0oooo00l0oo_o0<IcC`2ECb<0V50T09U?8`2KDBD0Ve4T
09M@902ABb80n9Q30?neD03o]4h0okE>0?neC`3o]4h05P3o]Dh00`3o^E<0ok]K0?nkF`020?nkF`<0
ok]J00<0okaL0?noH`3o_f80103o_f800`3o_f<0okeN0?nkFP050?nkFP030?nkF@3o_El0okmU00D0
okmU00<0okmV0?nlG03o^eX00P3o^eX30?nkF`040?nlG03o_5d0okaL0?nmGP@0okeO00<0okaM0?nk
F`3o^e/01P3o^e/20?nlFP80ok]K0P3o_5Xo0?nkF`80ok]J00<0okaL0?noHP3o_V800P3o_f80303o
_Ed0ok]J0?nkFP3o^eX0okaK0?noH`3o_fD0okmS0?noI@3o_f80ok]J0?nkF@<0ok]K103o_El00`3o
_5d0ok]K0?nkF`030?nkF`040?nlFP3o^e/0okaJ0?nlFa@0ok]K00D0ok]J0?nmGP3o_V<0okmR0?nn
G`030?nkFP080?noH@3o_fD0okmU0?nmGP3o^eX0ok]I0?nlF`3o_5h20?nmG`030?nlG@3o_5X0ok]K
00<0ok]K00d0okaJ0?nkF`3o_5`0ok]K0?nfEP3o/E00ojY:0?nYB@3o[Dd0ok=C0?njG@3o_f80okiP
0080ok]J00h0okiQ0?noI@3o_f@0okiO0?nlF`3o^eX0okaL0?nmGP3o_5`0ok]J0?nmH03o_5`0okaN
0?nlFP80ok]K00`0okiP0?noHP3o_V00ok]J0?nmG@3o_f<0okmU0?nlG03o^eX0okaM0?nmG`3o_5d3
0?nkF`0^0?nlF`3o_V40okiP0?nkFP3o_5`0okmT0?nmH03o^eT0okaL0?nmG`3o^e/0ok]J0?nmGP3o
_F00okYH0?nkF`3o_f80ok]K0?nkFP3o_Eh0okaL0?nnH@3o_Ed0okYH0?nnHP3o^e/0ok]J0?nlGP3o
_Eh0okaM0?njE`3o_f40okeM0?nlG@3o_V00okaN0?nmGP3o_5d0ok]J0?nmG`3o_5d0oje@0?nTAP3o
[D`0okYL0?nmGP80okaL0P3o_Ed05`3o_5`0okeO0?nlG@3o^e/0okeO0?nkFP3o_eh0ojaG0:if>@1I
<1T04`P507P`7`3@ID80ohQK0?n>G@3oS5`0oh]M0?n;F`3oSEd0ohaL0?n;G03oRe/0ohaK0080oh]J
0P3oS5`03P3oSUl0oh]N0?n@H@3oT640oh]L0?nAH`3oRe/0oheM0?n<G03oSUl0ohaK0?n=G@3oS5d0
ohaL0P3oSEd0I@3oQeT0[E4e02lB300/3P`0feQ80?mdG@3oKeT0kV1>084[8`0R2`P0208307DR8P3o
D4l0oeQF0?mIEP3oFEL0oe]I0?mGE@3oFEP0oeUG0?mJF03oF5H0oeYH0?mJF@3oE5@0oe]J0?mJF03o
G5X0oe5@0>a:BP2o>CP0QbPW04TB4@0A0`<06@/6048N4@2@ARP0Xf8c0<mj@`3oVeL0ojAH0?nUG@3o
XUT0oj5F0?nUGP3oXe`0oieB0?nTF`3oX5H0oj5H0?nRFP3oX5D0oj=M0?nUGP3oX5L0oj5G0?nUG@3o
WeD0oj5G0?nRF@3oXUH0oj9E0?nWGP3oZEh0oj9F0?nKD`3oVUP0oI1@0>9oA036KC/0]F<e08Q79`20
>b00Gb/G04hS4`0P3PP04P/4020B200]6@/0BR`B06a06`2>E280Uf@Z0:R6>03:WD40jJ]70?niC@3o
d5X0omQK0?oFF03oeEL0omEJ0?oDH03oe640om=I0?oDEP3oeET0omAN0?oDG@3oe5T0omAF0080omAG
00T0om=G0?o=D@3oad`0olA70?o3A@3oadX0ole@0?oAE@3oe5T00P3oe5/02P3oeET0omAF0?oBE@3o
e5T0omAQ0?oEH@3oeE`0om9E0?oBEP3odeL20?oDG@030?oDGP3oe5T0om=F0080omAG0`3oeEL80?oD
E`040?oDEP3odeL0omAF0?oCE`80omAG0P3odeL03`3oe5T0omAK0?oDF`3oe5/0omEI0?oCE`3odUH0
om9E0?oDF03oeF40omAP0?oFH@3oeEl0omAF0?oBEP020?oCEP070?oDG03oe5h0omAM0?oDG`3oeET0
om=F0?oCE`020?oDE`090?oEE`3odeT0omAI0?oFF@3oe5/0om=F0?oEG@3oe5T0omEG01/0omAG01T0
om=G0?oDEP3oe5H0omAG0?oDEP3odeL0omAG0?oEF03odeL0om5D0?o?D`3oc500olQ>0?o6C03oaDT0
ol960?noA@3o`DL0olA90?o;C`3odE<0olmD0?oAE03oe5H0om=J00<0omEQ0`3oeV40103oeEH0om=F
0?oDEP3odUD20?oCEP070?oDG03odel0omAN0?oDG@3oe5h0omAO0?oDFP030?oCEP<0omAG1P3oeELY
0?oDE`030?oEF03odED0olQ:00H0olA700@0olE80?o5A`3oa4L0olA70P3oaDL20?o4A`050?o5B03o
a4L0olA70?o4A`3oaTP0103oa4L0103oadP0olE90?o4A`3oaDP20?o4A`030?o6B03oa4L0olA700<0
olA700P0ommB0?odF03omET0oo5G0?o`E`3okeL0oo9H0?oYR?l0ooooV@3oool0103YjNT0dM7A0=7A
d@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOU0?ooo`0;0?ono`3FRfT0TD`P09A=902G
Cb<0VU0T09YA9@2ID240UTlS0=f7?03o]E00103o]4hG0?neCP030?niE03o^e/0ok]K01D0ok]K0`3o
_5T0103o_5X0okaI0?nlF@3o_5T40?nkF`0=0?nkFP3o^UT0okYI0?njE`3o_fD0okeQ0?o1J@3o_fD0
okmV0?noI`3o`6L0okiR0?nkFP060?njF@030?nnGP3o_fH0okmV0080okmU0P3o_fH01@3o_V80okYI
0?njF@3o^UT0ok]J00<0ok]K00@0ok]J0?nlF@3o_5T0ok]J0`3o_5T00`3o^eX0ok]K0?nkF`0i0?nk
F`050?nkFP3o_5T0ok]J0?nlF@3o^eX00P3o^e/02@3o^eX0okYI0?nkFP3o`6L0okmW0?noIP3o`6L0
okiR0?nkFP030?njF@080?nnH03o`6H0okmU0?noIP3o_fD0ok]H0?njF@3o^eX20?nkF`050?nkFP3o
_5T0okaJ0?nlF@3o^eX04P3o^e/00`3o^eX0okaI0?nlFP030?nkF`050?nkFP3o_V<0okmW0?o0IP3o
_V800`3o^UT01P3o_V40okmU0?o0IP3o_f@0okMF0?n]C080ojI600@0oje=0?niEP3o_5/0okaL1@3o
^e/0103o^eX0okaI0?nkFP3o^eX20?nkF`0K0?noI@3o_f40okaM0?njF@3o^UP0okeP0?noI@3o_fH0
ok]K0?nkFP3o^e/0okaI0?nkFP3o_5X0ok]K0?nkFP3o_5T0ok]K0?njF@3o_F80ol1W0?nnH03o^UT0
ok]J0?nnH`3o_f@0ok]H0080ok]K00d0ok]J0?nlF@3o^e/0ok]K0?nlGP3o`6P0okaL0?njF@3o_V00
okiR0?nlF`3o^eX0okaI0080okYI00<0okmU0?nmGP3o^e/00P3o_V<09@3o_5X0ok]J0?njF@3o`6@0
ok]L0?nmG@3o`6H0ok]J0?njF@3o_600okiS0?nkF03o_V40ok]J0?nkF`3o_V<0okIE0?nP@`3oZTT0
okUH0?nmGP3o_V80okeM0?nlG03o_5d0ok]P0?nlG03o_Ed0okaM0?nkFP3o_F00okaK0?nmGP3o_Ed0
okiN0?o8H`2/GBl00P0000003P1:7QD0n7I=0?nAG@3oRe`0oheN0?n:F@3oS5/0ohYK0?n=GP3oSUl0
oheN0?n:F`3oS5`0oh]K0P3oS5`0303oUFT0oi5T0?n;FP3oR5L0ohUH0?n:F03oSUl0ohaL0?n>G`3o
S5`0ohYI0?n<F`80ohQI01d0ER<F000000000000eeE60?mgH@3oMf00oe92030?3@000000Ba8B0>`g
=`3oG5X0oeID0?mMF`3oEE<0oeYI0?mHEP3oF5D0oeaJ0?mHEP3oFeL0oeQG0?mIF03oG5/0oeeJ0?mH
E`3o?Cd0WR`/02X92P020000000=01T;1P1m=a`0bUhe0?n5C@3oYeX0oj]Q0?nPE03oWeD0oj=M0?nO
E03oXEL0ojIP0?nPEP020?nPE@050?nTGP3oXUX0oj1C0?nTGP3oYF400`3oWe@03@3oX5D0ojIP0?nU
F03oYeP0ojiP0?n`IP3oTT`0ohM90?a_>`39Fc00UD@V060Z5@0g5`/0100000005`091P80Bb`B06@i
602BE2<0bgHa0?nO@03o]4X0olMB0?oVG`3oheh0ommT0?oKI03oeUd0om9D0?oDE@3oeE/0omES0?oD
GP3oe5D0om9F0?oCE`3odUH0omAE00@0omAG00<0omEF0?oDE@3odUH00P3oe5L03@3odeH0omEK0?oE
HP3oe680ol]F0?o1A03o`T80ol930?o:D`3odf40omIT0?oFG03odUH00P3oe5L20?oDE@030?oEEP3o
e5L0omAG00X0omAG0P3oe5D03@3odeH0om9F0?oDE`3oe5L0omAF0?oDE@3oeE/0omIR0?oDH@3oeV80
omAN0?oBEP3odeD00P3oe5D01P3oe5h0omAS0?oFHP3oeF<0om=L0?oDE@<0omAG00@0om=F0?oBEP3o
e5D0om9F2@3oe5L20?oEEP060?oDE`3oe5h0om9D0?oDGP3ode`0om=F4`3oe5L01`3odeL0omAE0?oD
E@3oe5D0om=F0?oDE@3odUH00`3oe5L20?oDE@030?oCE`3oe640omAR00<0omAR00<0omAQ0?oCF@3o
deD00P3odED02P3oe5D0omEF0?oEG`3oefD0omES0?o:EP3o_D/0okU60?nnA03o`T<20?o2@P070?o3
AP3obTd0oliA0?oADP3oe5D0omEG0?oEEP020?oDE@<0omAG00<0omEG0?oCFP3odUH0?03oe5L00`3o
cU80olE90?o4A`070?o4A`040?o7B@3oa4L0olA70?o5A`<0olA700D0olI80?o4A`3oa4L0olA70?o6
B0030?o4A`030?o5A`3oaTL0olE900L0olA700L0olE70?o4A`3oaDL0onMF0?oaF03okEH0onmG00<0
oo1G00<0ooJ_0?ooo`3oool0o`3ooonG0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWinH0oooo00X0f9^0095;7P2DC2D0U4dQ09U@902JD2D0VDlS09I=8@3LR3/0
okE@0`3o]4h01@3o]E00okE>0?neCP3o]Dh0okE@00H0okE>00<0okE?0?neCP3o]E002`3o]Dh00`3o
^E@0ok]L0?nkF`0R0?nkF`060?nkG03o_5X0ok]J0?nlG@3o_5/0okaJ0P3o_5T0103o^eX0ok]K0?nk
F`3o^e/30?nkFP030?nlF@3o_5h0okmT00D0okmT00@0okeQ0?nkFP3o^eX0ok]J103o^UT02@3o_V80
ol1X0?o0J03o`6H0okmW0?o0J03o`6T0ol1V0?njF0020?njF@050?nkFP3o^e/0ok]K0?nkF`3o^eX0
0P3o_5T01@3o_5X0ok]J0?nlF@3o_5T0okaJ03H0ok]K103o_5T0203o^eX0ok]K0?nkF`3o^eX0okYI
0?nmG`3o_fD0okiS0P3o_f@0303o^UT0ok]J0?njF@3o^UT0ok]H0?o0IP3o`6P0ol1W0?o1J@3o_V80
okaI0?njF@<0ok]K00@0okaJ0?nkFP3o^eX0okaI403o^e/0103o^eX0okaI0?nlF@3o_5X20?nkF`0<
0?njF@3o_F00ol5U0?nmH`3o/eP0oj]90?nXA`3oZTT0ok=E0?noJ03o`FT0okmU0P3o^eX01@3o^e/0
ok]J0?nlF@3o_5X0ok]J0080ok]K00D0okeO0?nlG@3o^e/0okaL0?nlF@020?nkF`0;0?nkFP3o_El0
okmT0?noI03o^e/0okYI0?nkF`3o`6P0ol1V0?nnHP3o^UP00P3o^e/01@3o_5X0ok]J0?nkFP3o^eX0
ok]K0080ok]J0P3o_V802@3o^UT0okYH0?nmG@3o`6L0okaL0?njF@3o^e/0ok]J0?nkF0020?nkF`0j
0?nmG`3o_F40ok]K0?njF03o_f80okmU0?nkF`3o^UT0ok]I0?nkFP3o_V<0okiR0?nkF@3o`6H0okmU
0?njE`3o^eX0okaL0?o0I03o^e/0okeN0?nnH`3o^UL0ok]K0?nmH03o^UT0okiQ0?nmH@3o/500oj=6
0?naC`3o_F80okaN0?nmH@3o_5`0ok]J0?nmGP3o_5h0okaK0?nnH03o_5`0ok]J0?nmH03o^UT0okaL
0?nmH@3o^eX0okmQ0?nkG02aGc0030H20000001?81@0ogeC0?nAH03oS5l0oh]J0?n:F080ohaK00h0
ohYI0?n9F03oS5/0oh]J0?n=GP3oS5/0ohQE0?n=GP3oSf80oh]J0?n8E`3oREH0ohmQ0?n>H@80oh]J
00D0oh]L0?n=GP3oS5d0oiIT0:]@=@020000000I0;@h;@3oM5h0ofYE0:Th;@0L2PP00@0009/Y:@3o
BTX0oeiM0?mIF03oEeD0oeQG0?mIF03oF5L0oe]I0?mIE`3oF5H0oeUH0?mIE`3oFUT0of1N0?m=C02V
:RT0IAhN01`61P020000000C03LH2`2@@B80jgE40?nKD03o[f00ojYP0?nSF@3oYEl0oj5G0?nQE@3o
Xe`0oj5E0?nPE@3oWU80ojMQ0?nND`3oX5D0oj=M0?nRF@020?nPE@0=0?nNDP3oZ640ojUO0?nVE`3o
[Ed0ojQQ0?n7B03oMd00aeT`09A18P1G9aD0@Ah@01@910040000000B01dB201c@Q/0TU<S0=9j<`3g
U3`0okI:0?o3D@3of5T0onIQ0?oRIP3ogFL0om]Q0?oCE@3oe5L0omAN0?oEH03oe5`0omAE0P3oe5L0
1P3oe5D0omEF0?oDE`3oe5L0om=G0?oDE@80om9F00X0omAG0?oBEP3oeE@0omAN0?oEI03oeV80omEH
0?oBE03odeD0omAJ0P3oeF002@3oeEh0om1A0?o9C03o`T@0ol520?o7B03oce00omIG0?oEF0080?oD
E`040?oBEP3oe5D0om9F0?oCEP<0omAG00P0om=F0?oEF03oeF<0omAT0?oFI03oe640omAG0?oEE080
om9F00L0omAJ0?oDH@3oeF00omAQ0?oEG@3oeEH0om9F0080omAG00D0omEF0?oCEP3oe5D0omAE0?oE
EP0@0?oDE`060?oEEP3oded0om=O0?oBEP3oeEd0omAE0P3oeEH80?oDE`040?oCE`3oe5D0om9F0?oB
EP80omAE0`3oe5L01@3odUH0omAE0?oDE@3oe5/0omIU0080omAT00H0omES0?oFI@3oeF00om9F0?oD
E@3odED20?oBEP050?oDEP3oeUl0om=Q0?oEH03oeV000P3oeF000`3oeEP0om=F0?oBEP030?oDE`0:
0?oEEP3oe5D0om9F0?oGF03oeET0om=G0?oCE03ocE00olQ;0?o4AP80ol1200D0ol540?o5B03oadX0
ola@0?oBE@030?oEF080omAG00@0omEF0?oDF`3odEL0omEF>@3oe5L0103oeEP0oliB0?o4A`3oa4H?
0?o4A`050?o6B03oa4L0olA70?o4A`3oaTP00P3oa4L0103oaDT0olE70?o6A`3oaDT70?o4A`070?o7
B@3oaTL0olM90?oaE`3okeH0onaF0?o`E`020?o_E`030?oaF03okK40oooo0?l0ooooV03oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOV0?ooo`0:0=f]V`2?BA/0
Ue0S09==8P2GCb<0VDlT09aB902GCb<0gHPl0?neD0<0okA>00P0okE@0?neCP3o]Dh0okE>0?neD03o
]Dh0okE@0?neC`D0okE>00<0okE@0?neCP3o]Dh00`3o]Dh00`3o]Dl0okE>0?neCP040?neCP030?ni
EP3o^e/0ok]K02@0ok]K00@0ok]J0?nlG03o_5d0ok]J2P3o^e/70?nkFP<0ok]K103o^eX01@3o_5h0
okiR0?nnHP3o_F40okeR0080okiR00<0okeQ0?nlF@3o^eX00P3o^eX30?njF@030?nnHP3o`VX0ol5Y
00@0ol5Y00<0ol5X0?nlF@3o^UT00P3o^UT40?nkF`L0ok]J<@3o^e/40?nkFP<0ok]K0P3o^eX01@3o
_F40okiR0?nmHP3o_V<0okeN0080ok]J00D0okYI0?njF03o_5/0ol9Y0?o0J@020?o1J@030?nmG`3o
^UT0okYI0080ok]K1@3o^eX=0?nkF`0F0?nlF`3o/E40ojY90?nXA`3oZ4P0ok9B0?nhE`3o_5d0okiS
0?nnHP3o_640ok]J0?nkF@3o^UT0okmR0?o2J`3o`FT0okeQ0?nlG@3o_Ed0okaL0?nkG080okaI00<0
okaM0?nkF`3o^e/00P3o^e/20?nkFP<0ok]K00<0okiR0?nmH@3o_5l00P3o^UT01P3o_Ed0ol5Y0?o0
J03o_5`0okYI0?nkF`80ok]J00`0okYI0?nkFP3o^e/0ok]J0?nlG03o_V80okaL0?njF@3o^UP0ol1V
0?o1IP3o^e/20?nkFP0:0?nlF@3o^eX0ok]J0?nmG`3o_640ok]K0?njF@3o`FH0okiS0?niEP80ok]J
01`0okeQ0?nnH03o^UT0okiQ0?o0IP3o^UX0ok]K0?nlG03o_F00ok]H0?nlG@3o_F00okYI0?nmG@3o
_5h0ojY80?nUBP3o_5/0okaM0?nlF`3o_f@0okiR0?nkFP3o_E`0okiP0?nmG@3o_5`0okeN0P3o_5d0
3P3o^e/0okeO0?nkFP3o_V00okaQ0?noGP3o`Eh0oh]3058]6@000000?1TA0?mXAP3oTV00ohiN0`3o
ReX06P3oRUT0ohmP0?n:F`3oSV40oh]J0?n;G03oSf00oh]J0?n?H@3oReX0ohYI0?n?H03oSF00ohIE
0?nBI03oReX0ohiO0?n<G03oUV@0ogYB02XA30000000^C/_0?m^F03oI540B1DA0P0000000`2Q9bP0
oeYH0?mLF`020?mIE`0<0?mLFP3oFEP0oeQF0?mJF03oEE@0oeYH0?mKFP3oFUP0oeUH0>dl?@2G92<0
>Pl?0`0000007`1N:QD0ogQ70?n>D@3oWE<0ojYN0?nSEP3oY5h0ojEO0?nQE`3oXe/0oj1F0?nPE@3o
Xe/0ojMQ0?nPE@3oWe@0oj=L0?nOE03oWeD0oiiC0?nXH03oZf@0ojMJ0?nYFP3oUU@0m6lm0<EF;P26
>b00F2LD03@G3@0Q3`P01@0000004P1<;180S5<R0:=N9P3oX4<0oji90?o5DP3ocE@0on9I0?oSJP3o
g6H0omMH0?oEE@3oe5P0omEM0?oDGP3oeE/0om=G0?oDE`80om9F00T0om=G0?oDE`3odUH0om9F0?oD
EP3oe5L0om5G0?oAE@3oe5/00P3oeFD02@3oeF@0omAF0?oBEP3odUH0omEK0?oDGP3oeEd0om9H0?oB
EP020?oDE`80om9F00d0om=G0?oEF03odeH0olmB0?o5B03o`D<0ol950?o7BP3odEH0om=G0?oEEP3o
dUH0om=G0080omAG00/0omAE0?oBE@3oeF80omEV0?oEI03oeFD0omIJ0?oBE03odED0om9F0?oDE`02
0?oDGP050?oEGP3oded0omAG0?oBEP3odeL00P3oe5L30?oBEP030?oEEP3oe5L0omAG01@0omAG00d0
omEF0?oBEP3odUP0omAL0?oBF@3oe5`0omAG0?oCEP3oeEH0om9F0?oEEP3odUH0omEF0080omAG00D0
om=G0?oAE@3odED0om9D0?oEH0020?oEI@060?oEI03oeFD0omEW0?oCF@3odU@0om5E0`3odUH0203o
e5T0omAN0?oDGP3oe5h0omEN0?oDGP3ode`0omEF0P3odUH30?oDE`H0om9F303oe5L01`3oeEP0omAH
0?oCEP3odE@0oliA0?o9C03o`T@00P3o`4801@3o`T@0olE80?o4BP3ob4h0om5E0080omEH00<0omAG
0?oEE`3oded0>P3oe5L01@3odUD0olE90?o3AP3oaDT0olE700T0olA700<0olE70?o4A`3oa4L00P3o
a4L01@3oaDL0olA70?o4A`3oaDL0olM90080olE700@0olQ70?o5A`3oaDL0olE80P3oaDL20?o4A`06
0?o5A`3oa4L0olA70?o7B@3oaTT0ol]:0P3okeL01P3olEL0oo1G0?o`E`3okeL0oo=G0?oX^_l0oooo
V@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOV0?ooo`0>
0?34]02BC200UDlT09M?902DCB80VE4U09]A9@2ID2@0eH<i0?nfD03o]Dh0okE@0?ndCP3o]E050?ne
CP030?neD03o]Dl0okE>00@0okE>00<0okE@0?neCP3o]Dh00`3o]Dh20?neC`H0okE>00<0okYG0?nl
G03o^e/09@3o^e/0103o_5`0okaM0?nlG03o_5`U0?nkF`050?nlG03o_5d0okaN0?nlGP3o_5d00P3o
_5h00`3o_5d0ok]K0?nkF`020?nkF`<0ok]J00D0okaL0?noI@3o_f@0okmT0?noH`030?noI0030?nm
G@3o^eX0ok]J00D0ok]J00<0okiQ0?noH`3o_f<00`3o_f<00`3o_V@0okiP0?nkFP030?nkFP<0ok]K
00<0ok]L0?nlG03o_5`01@3o_5`U0?nkF`<0okaM00`0okaN0?nlG03o^e/0ok]K0?nkFP3o^e/0okiR
0?noI03o_V80okmT0?nnH@3o_5X40?nkFP80okmS00/0okiS0?nnI03o_Ed0okYJ0?ngE`3o/e80oja<
0?nYB@3oZd`0ok5A0?niF@020?nlG0D0ok]K01H0okaK0?nkF`3o_F00okaM0?nnH03o_5`0ok]K0?nk
G03o^eX0okiP0?noI@3o_V<0okiR0?nlG@3o_5/0okYI0?nmGP3o_V@0okiR0?noH`3o_5d0ok]J0P3o
^e/30?nlG00>0?nkF`3o_5d0okaM0?nkF`3o^eX0okaK0?noH`3o_f@0okmS0?nlFP3o^UT0okaN0?no
H`3o_V420?nkFP0<0?nkF`3o_5d0okaM0?nlG03o^eX0okeO0?noH`3o_V00ok]I0?nlG03o_V40okmS
0`3o_5`08P3o^e/0okaK0?noH`3o_5`0okYI0?nkF`3o_f<0okaM0?nkFP3o^UT0okmS0?nlF`3o^eX0
okeO0?nnH03o^UP0okaO0?n]D03o[4/0ok]O0?nmGP3o_5`0okeN0?nlG03o_V<0okaK0?nmGP3o_5`0
okeP0?nlG@3o_Ed0okeP0?nmG@3o_Eh20?nmG`<0okaM01X0okiO0?o1H03o]e/0Zf/e02<C2P0<1@@0
BahD0<iT@P3oRUX0oheM0?n;FP3oS5/0oheO0?n<G03oRUT0oheM0?n;G03oSf00ohYJ0?nBI03oReX0
ohaL0?nCI`3oRU/0ohmQ0?n;F`80oheM04d0ohaM0<=H>`0X40/0<a0=0=iHA`3oIE40ZD<f03@A3P0K
20P0NQdM0<Lo?`3oF5L0oeUG0?mJF03oGE/0oeYI0?mHEP3oFUT0oe]I0?mGE@3aC4/0a3hm098`<01R
6AX06`L701060`0L30H0JCDN09]J<@3>LCd0oi1B0?nPF03oYeh0ojAH0?nSFP3oXe/0oj1E0?nTGP3o
YEh0oj5E0?nWH03oYUh0oj1E0?nQF03oXel0oimG0?nHD@3aQTT0c7Q60:QT>02=Ebd0Pd<U06@_6P17
7a40:18:01L;1P0@2@@05`h6038N301P>1P0P54R081R:@2JM300a8lk0>^WC03o_U@0olYI0?o;E03o
d5D0omAI0?oLH`3of5h0omAG0?oDEP3oeEL0omEI0?oDFP020?oEF0070?oDF03oe5H0omAE0?oEEP3o
eV00omIO0?oDG@030?oCEP80omIP00D0omIO0?oCF03odUH0omAF0?oEF0030?oEF@@0omAG0P3oeEL0
103oe5T0omEH0?oDE`3odeL20?oCEP0=0?oEG03oeEh0omEN0?oEH03odUT0olY>0?o8B@3oaDL0olA6
0?o7C`3ocUT0om9O0?oEG@020?oCEP030?oCE`3oeEL0omEI0080omEI00@0omEJ0?oCF03odeL0omEG
0P3oe5L20?oEE`030?oDE`3oeEL0omAG00`0omAG00<0omAI0?oEF03oeEP00P3oeEP04@3oe5P0omAG
0?oDE`3oe5L0om=G0?oCEP3oe5D0omAG0?oEH03oeEl0omEL0?oDF`3oeUd0omEQ0?oBEP3odUD0om=G
00<0om=F00L0omIO0?oFH03oeV00omEP0?oFH03oeEd0omAF0080om=F0P3oeEL00`3odeL0omAI0?oD
FP020?oEF@050?oDFP3oeET0omAG0?oCE`3oeEL00`3oe5L00`3oeEL0om=G0?oEE`020?oEE`030?oC
E`3oeEL0omAG01X0omAG0P3oeEP0403oe5L0om=F0?o@E@3ocU80ol]>0?o6BP3oaDP0ol960?o3A@3o
a4L0olM:0?o8C03ocE00om1D0?oBF@3oe5XO0?oDE`030?oEE`3oe5T0omEH00T0omEH1P3oe5L50?oC
EP070?oEFP3odU/0ol=:0?noA@3o_dH0ol170?o3A`040?noAP050?o2A`3oadP0olM80?o6B03oadP0
1P3oaTP0103oaDL0ol160?noAP3o`4H20?noAP0:0?o2B03o_dH0ol560?o2B03o_dH0ol560?o5A`3o
aTP0olM80?o6B080olM800X0olE70?o7B@3okUL0onYF0?o[EP3olEP0onaE0?o/EP3ole@0ooKVH03o
ool0103o_lH0000000000000003o0?ooocD0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWiP3oool02P3jbKP0VU<W09=<8@2CC240U4dR09==8`2ID2D0W54T0<Yl
=P3o]U030?ndCP030?neD03o]Dh0okE>00<0okE>00<0okE@0?neC`3o]Dh0103o]Dh00`3o]E00okE>
0?neCP030?neCP030?neC`3o]E00okE>00D0okE>00<0okI?0?nkF03o^e/09`3o^e/00`3o^UT0okaQ
0?nlG@1>0?nkF`050?nkFP3o^UP0okYH0?njF03o_F400P3o`V/01@3o`VX0ol5Z0?o2J`3o`V/0ol5U
00<0okYH00L0okYI0?nkFP3o^eX0ok]J0?nlG03o_600okeN0080okaN0P3o_Eh0103o_5h0ok]J0?nk
FP3o^eX50?nkF`L0ok]J703o^e/0403o_5`0okaK0?ngF03o[4/0ojM70?n[B03o[Dd0okYP0?o2J`3o
`FT0ol9[0?o0J03o^UL0okYH0?nkFP3o_5`20?nkF`060?o0IP3o_5d0okaP0?nmG@3o^e/0ok]J0`3o
^e/40?nkFP80ok]K00<0okiN0?nlG03o^e/00`3o^e/02`3o^eX0okYH0?nkF`3o`FT0ol5Z0?o2J`3o
_Uh0okYI0?nkFP3o^e/0okaN0080okeN0P3o^eX20?nkF`<0ok]J00T0ok]K0?nkFP3o^UL0ol1V0?o2
J`3o_fD0okYI0?nkFP3o_5`00P3o_Eh0203o_5`0ok]K0?nkF`3o^eX0ok]H0?noHP3o`F`0ol1U0P3o
^eX0D`3o_Eh0okaN0?nlF`3o^e/0okYG0?noH@3o`6H0okYH0?nkFP3o_Ed0okaN0?nkF@3oZ4`0oie4
0?n`D03o_5`0okeN0?njF03o_fD0okYI0?nlF@3o_5d0okiR0?nmG@3o^eP0ok]L0?nnHP3o^eX0ok]K
0?nmGP3o_5d0okeL0?nnH`3o^e/0okiQ0?njF03o_Eh0okeP0?noH03o/UL0WeDZ018910060P40ZT<]
0?n3E@3oTV80oh]L0?n:F@3oS5`0oheN0?n;F`3oSEh0ohQG0?n9F03oTVH0ohQH0?n:F@3oU6L0oheN
0?n;F@3oT640oh]J0?n:G028=R<0000000h40`3UETD0_Cdb00/30P000000CA<C0?mCD03oFUT0oeME
0?mIE`3oGeh0oeAC0?mNG03oG5/0oeYK0?mBD03X=SD0AA<C0080000001P00`4003TI3@2OB2P0oh=<
0?nQEP3oXUL0oj=H0?nZI@3oXeX0oj5H0?nPE@3oWe<0oj]V0?nWF`3oZE`0ojQN0?nSF@3oVE80oiQL
0?n@EP3oNT<0/U0Z064Z5`0J30H40000000>00D40@0M4@L0<al<06Hm5`2FF2T0jXho0?o1D03oeEP0
om5D0?oGHP3of6L0omMQ0?oBE@3oe5H20?oEEP80omAG00d0omEF0?oEF03oeE/0omEK0?oCF`3odEH0
om5E0?oBE@3of6L0omMV0?oEI`3odeX0om9D00D0omAG00@0om9F0?oEEP3oeEH0omEF0P3oe5L0103o
eEH0om9F0?oDFP3oeE`20?oEF`030?oEF03oe5H0om5E0080om9D00H0omMV0?oEI@3oeFL0omEU0?oB
E`3odU@90?oDE`080?oCEP3obD`0ol940?o1@`3o`T@0ol]@0?oCEP3oeEP20?oDE`D0omEF00<0om9F
0?oDE`3oe5L00P3oe5L0103oeEH0omAF0?oEF03oe5`50?oEF`0:0?oDE`3oeEH0omEF0?oAE@3odU@0
om1C0?oEF`3oefP0omEW0?oEI@80omEW00/0omES0?o@E03odU@0om5E0?oEEP3oe5L0omAJ0?oEF03o
e5d0omIL0?oBE0170?oDE`H0omEF00d0oleA0?o8B@3oa4H0ol=50?o2@`3o`D<0okm40?o1AP3oadl0
oliD0?oBE@3odUH0om=G0080omAG00@0omEF0?oEE`3oe5X0omAL2@3oeE/00`3oeET0omEF0?oEEP02
0?oEEP030?oBEP3odU@0om9D00<0om9D00<0om9B0?oFI03oeFL00P3oeFL00`3oeVL0omEV0?oEI`03
0?oEI`030?oEIP3oeE/0om5D00<0om9D00<0om9E0?oDE`3oe5L00`3oe5L00`3odE80olE90?o4A`03
0?o4A`030?o6B03oa4L0olA700@0olA700<0olE70?o4A`3oa4L03P3oa4L0203oaTL0olE90?o4A`3o
a4L0olM90?o4A`3oadT0olE70`3oa4L0203odTd0onmG0?o_E`3ol5L0oo1H0?o_E`3olEL0on5DH@3o
ool0103o_lH0000000000000003o0?ooocD0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWiP3oool01@3ofL`0X5L/09=<802FCb<0UdlS0080U4dQ00<0VDlS0<]o
=`3o]U000`3o]4h00`3o]E00okE>0?neCP030?neCP030?neD03o]Dl0okE>0080okE>00<0okE?0?ne
CP3o]E001@3o]Dh00`3o]Dl0okE@0?neCP060?neCP030?nhDP3o^eX0ok]K02L0ok]K00<0ok]J0?nm
GP3o^eX0DP3o^e/70?nkFP<0ok]K00D0ok]J0?njF@3o^UT0okYI0?nmGP020?o1JP060?o1J03o`FT0
ol5Z0?o1JP3o`FL0okYG0`3o^UT30?nkFP050?nmG@3o_V80okeR0?nmHP3o_F400P3o_F800`3o_V40
ok]J0?nkFP020?nkFP@0ok]K1`3o^eX<0?nkF`090?nlG03o^UX0okAE0?nZBP3oYdL0ojY90?n^C`3o
^UX0ok]K00<0ok]J00d0okaI0?nkF`3o_5`0ok]J0?nmGP3o^e/0ol1W0?o1J@3o`6P0ol9[0?noI03o
^UT0okYH0080ok]J00<0okaN0?nmHP3o_F400P3o_F420?nkFP030?njF@3o_5`0okaL00D0ok]J0P3o
^e/20?nkFP80ok]K00D0okYH0?nkF`3o`FL0ol5Y0?o1JP020?njF@050?nkFP3o_5`0okeQ0?nmH@3o
_F800P3o^eX0103o^e/0okaJ0?njF@3o_5T20?nkFP0:0?nmH@3o`VX0ol5Z0?nmGP3o^UT0ok]J0?nm
H03o_F80okaN0?nkF080ok]J00P0okYG0?o0J03o`6L0okaM0?njF@3o_Ed0okeQ0?nlGP80ok]J00d0
okiS0?o0I@3o/e80ojY90?nUA`3o^5P0okiP0?o1J@3o_5d0ok]J0?nmH03o^eX0ol1W0080okaL0200
okiP0?o0IP3o_5`0okaL0?noIP3o_F00okaL0?nnH`3o^e/0okYH0?nnH@3o_5h0okiR0?njE@3o_El0
okiR0?o3GP3/OCh07Q080000001F8QH0ofa80?n?GP3oSf00ohiO0?n;F`3oSEd0oh]I0?n?H03oUFT0
oi1Q0?n8E`80ohYI00T0oiAV0?n=G03oRUT0oi5Q0<5L?@0000005PL60<i0<P2]?3400P0000008`12
40l0mde<0?mIE`3oFeT0oeYH0?mLF`3oHf80oeUG0?mAD03^@D00PR<Q01<41@000000004102`E3@1G
9Q<0/e8]0?nKF@3oYeP0oimB0?nWH@3oXe`0oj=K0?nQE@3oXUD0ojeS0?n[G@3oZ5h0oiiH0?n;BP3o
Pd/0oga=0=UT=`21>al0;1@900@0000000d00`4001`A1P0o9A00IC/J09iL:`3:MCP0oj]70?oFE`3o
geP0omeW0?oJI`3oeUX0om=C00<0omEF0P3odUH03P3oe5`0omEM0?oDGP3odUP0om9F0?oAE@3ode`0
omMV0?oEIP3oe5h0omAE0?oAE@3oe5T0om9F0P3oe5D02`3odeH0omEF0?oDE`3oe5L0om=G0?oDE@3o
e5X0omAN0?oEG@3oe5h0omEK0080om9F00@0om5E0?oEDP3oe680omIU0P3oeFH00`3oded0om9E0?oB
EP020?oDE`@0omEF203oe5L01`3oe5H0om9F0?oBEP3odUH0omEF0?o9C@3oa4L00P3o`T@01@3oadd0
olmD0?oEEP3oe5T0omEM0080omAN00D0omEN0?oDGP3oe5h0omAJ0?oCEP020?oBEP060?oAE@3odU@0
om=M0?oEI`3oeFH0omEU0P3oeFH01@3oeFD0om=H0?oAE@3odED0om9F00<0omAG00<0om9F0?oEEP3o
eEH00P3oeEH02@3oeEL0omAG0?oEEP3oeEH0omAL0?oAE@3oe5h0om=O0?oCEP0b0?oDE`/0om9F1P3o
e5L00`3odeL0om9F0?oBEP030?oBEPH0omAN0180omEN0?oFGP3oe5h0om1J0?o9D`3oaDX0ol950?o1
A03o_480ol130?o4B@3obDd0ole@0?o?D`3odU@0omEF0?oDEP3oeF840?oEIP030?oEI@3oeF@0omEV
00<0omEV00<0om=N0?oAE@3odED00`3odED60?oDE`030?oDEP3oeEH0omEF00P0omEF2P3oe5L00`3o
ce<0olE70?o4A`040?o4A`030?o5A`3oa4L0olA700@0olA700<0olE70?o4A`3oa4L02P3oa4L01P3o
aDL0olA70?o4A`3oa4L0olI70?o5B@80olA700<0olM90?o4A`3oaDT0103oa4L0103oeTh0onmG0?o_
E`3ol5L20?oaF0030?o`DP3of800oooo0600oooo00@0oko60000000000000000o`3ooole0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinH0oooo00D0onWR0:AK
<P2ABal0Td`T09I?8P0309A=8@030<Qk=@3o]U00okA>0080okA>00@0okA@0?neCP3o]Dh0okE@0P3o
]Dh00`3o]E00okE>0?neCP020?neCP030?neC`3o]Dh0okE@00D0okE>00<0okE?0?neD03o]Dh00P3o
]Dh0203o]E00okE>0?neCP3o]Dl0okE>0?nhDP3o^eX0okaJ1`3o_5T00`3o^eX0okaI0?nlF@050?nl
F@030?nlFP3o^e/0ok]K01D0ok]K00<0okaL0?njF03o_5d0H03o^e/20?nlF@80ok]J0P3o_5T01@3o
^eX0ok]K0?nkF`3o^e/0ok]J00<0okYI00D0okeQ0?o1J@3o`6P0ol1X0?o0IP020?o0J0030?o0I`3o
^eX0okYI0080okYI0`3o^eX00`3o^e`0okmU0?noI0040?noI0030?noI@3o_El0okYI0080ok]J103o
^e/20?nlF@040?nkFP3o_U`0okIF0?n_C080ojQ700@0oji?0?neEP3o_5`0okaL0P3o^e/03@3o^eX0
okaL0?nnHP3o^eX0okeM0?nmH03o^eX0ok]K0?nkFP3o_5X0ok]J0?nlF@3o^eX00P3o^e/04`3o^UT0
ok]H0?nnH@3o`6T0okmW0?o0I`3o`6H0ok]J0?njF@3o^UP0ok]J0?nlG03o_F40ol1T0?noI03o_fD0
okiR0?nkF`3o^eX00`3o^e/0103o_5T0ok]J0?nkFP3o^eP20?nkFP040?nkG03o^e/0ok]I0?nlG@80
ol1W00X0ol1X0?nkF03o^UT0okYI0?nkG03o_fD0okiS0?noI03o_5h0okYI0P3o^eX02@3o_5T0ok]H
0?njE`3o_V<0ol1X0?nnHP3o^EL0okYI0?nlGP020?nnH`170?nmG@3o^eX0ok]H0?nmGP3o_fD0okiR
0?njF03o^e/0okaP0?nmH@3o[Dd0ojY70?nUB03o_Eh0okUG0?nkF`3o_V<0okaP0?noI`3o_Ed0okUF
0?nmG`3o_F40okmT0?njF@3o_5d0okmU0?nmH@3o^UL0ol1T0?nmG@3o^eP0ol1T0?nmG03o`6@0okaK
0?nmG@3o_5d0okiR0?nkFP3oaVL0bglo01490`0000004PL40=IQ@P3oTEd0oi1Q0?n>H@3oRUT0oheN
0?n@HP3oSV40ohYH0?n8E`3oRUP0ohQE0?n9E`3oSUl0oi9R0?n7F0106A007PX80;/m<P3A@SD03@@3
00@20P1m8b80od];0?mNG03oFeX00P3oGU`01@3oFeX0odI60<@c<P1_6aX020820080000000D0?Ad@
0:189`3oR580ojMK0?nYE`030?nVGP0:0?nUEP3o[5l0ok9U0?nVG03oUU<0oge20>EW>P30FSL0UdL]
04HN40D0000001d07a4703lU3`1_@Ad0Yf@a0=1i?03oUch0ol5>0?oWH`3oiVX0on5X0?oIF`3odE@0
omAG0?oBEP3odUD0omEK0?oEH03oeUl0omAL0?oDE@3odED0omAE0?oDH03oeF<0omIU0?oCF@3odeH0
omEF0?oDE@020?oBE0030?oBEP3odUP0om=I0080omAG01<0omIO0?oCH@3oeV00omAN0?oEEP3odUH0
om=E0?oCD`3ode`0omIU0?oEH`3oe6@0omIO0?oEE03odeH0omAG0?oBF03odUH0om=F0080omAE00H0
omEF0?oBF03oe5L0omAG0?oEEP3oe5D20?oBEP80omAE0`3oe5L01@3oeEL0om9F0?oBEP3oe5D0omEN
0080omEP00/0omIO0?oEH03oeV<0om5G0?o:C03o`dL0ol=30?o2A@3obT`0omAF0?oHI@020?oDI007
0?oEI03oe6@0omIU0?oCG03oe5@0omAE0?oBEP020?oDE`040?oEEP3oe5D0omAE0?oCEP80omAE00<0
om9F0?oDE`3oe5L02@3oe5L01`3oeEH0om=G0?oCG03oeEd0om9D0?oFG`3odEL00P3oeEHK0?oDE`03
0?oEEP3oe5D0omAE0080omAE00<0om=F0?oDE@3oe5D0103oe5D50?oDE`030?oCE`3odUH0om9F0080
om9F00@0omAE0?oBF03oeUl0omAQ203oeF000`3oeUl0omEH0?oDE@040?oBEP030?oCE@3oe5D0omAE
00<0omAE1P3oe6@04`3oeF<0omAT0?oEI03oeFD0omIV0?oAF@3oce40ol]?0?o8B`3o`4D0okm20?o2
@P3o`D<0olA:0?o:C@3ocU40om5E0?oCE`3oeUL00P3oeEH00`3oe5D0om9F0?oBEP040?oDE@030?oD
EP3oe5L0omAG01d0omAG00<0om5F0?o5A`3oa4H01@3oa4L00`3oaDL0olA70?o4A`040?o4A`040?o6
B03oa4L0olA70?o6A`P0olA700<0olE70?o4A`3oa4L01P3oa4L0103oadT0olA70?o4A`3oaDL30?o4
A`080?oHC`3okeL0onmG0?o`E`3olEP0oneG0?oXC03om=]Q0?ooo`040?noaP000000000000000?l0
oooo=@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOV0?oo
o`040?ono`2hJTD0TT`P09A=8P80UTlS0P2DCB400`38MC<0okE?0?neCP020?ndCP80okE?00@0okE>
0?neC`3o]Dh0okE?3@3o]Dh01P3o]Dl0okI?0?nfC`3o]Tl0okE>0?neC`80okE>00D0okE?0?neCP3o
]Dh0okM@0?nmGP070?o0I@030?noI@3o`6D0ol1U00D0ol1U00<0okmT0?nkFP3o^eX03`3o^eX00`3o
_Ul0okiQ0?nnH@050?nnH@030?nnHP3o_V<0okeO00D0okiQ00<0okmR0?nlGP3o^eX01`3o^eXI0?nk
F`030?nlFP3o^e/0ok]K0480ok]K0`3o_5X0103o^e/0okaJ0?nlFP3o_5/40?nkF`<0ok]J00<0okaL
0?nnH03o_V001@3o_V000`3o_5d0ok]J0?nkFP040?nkFP090?nlG03o`6H0okeR0?ngG03oYd`0oj15
0?nPAP3oZDh0okQJ0080ok]J00T0okYI0?nlG03o_5/0ok]I0?noH@3o_V00okmU0?nnH@3o_F400P3o
_V40103o_f40ok]K0?nkFP3o^eX70?nkF`@0okaJ103o^e/00`3o^eX0okiR0?nnH@020?nnH0030?nm
G`3o^e/0ok]J0080ok]J00H0okaJ0?o0I@3o_fD0okmU0?o0IP3o_El30?nkFP030?nkF`3o_Ul0okiQ
0080okeP00/0okeQ0?nkFP3o^eX0ok]K0?nnH@3o_F00okiO0?nlG03o^eX0okYJ0?njE`020?noI00:
0?noIP3o_Eh0ok]I0?nkFP3o_5/0okeO0?nnHP3o_fD0okiQ0?nlG@80ok]J00l0okiR0?noH`3o_V00
ok]I0?nkFP3o_El0ok9G0?nRA@3o[4/0okYI0?noI@3o_Eh0ok]I0?nmG@3o_F000P3o_Eh0FP3o_V<0
okiO0?nlF`3o^e/0okmU0?o0H`3o_5/0ok]J0?noI03o_f<0okYH0?noH@3o`FT0okaK0?o1J03o^UL0
okiS0?nmH03o_f<0okYH0?o0IP3o`F40n:A@0:AX=`1::1<05PX7098k9@3HK4H0ohaM0?n@H@3oS5d0
oh]K0?n=GP3oSEd0ohUF0?n@H@3oTFD0oi1Q0?n>G`2kG3`0?AP@00d4101=6QD0?A@@0000001e8R80
kT]90?mMF`3oHEl0oEIE0<Q2@02[=cP0Pb4P048A4P0?0`@08a0905<U502>AbT0ag4i0>j:CP3oXf80
ojeM0?nUFP3oWe`0ni1C0=b0A@2iL3h0[VLl09Y?;P1m>1l0EBDC04LQ500`5`h04`T501lB200b7Ph0
E38I07937`2>Fb<0WVT[0;R4=`3EY4/0mkQB0?nlCP3oaE40omMK0?oOIP3ogFD0omUP0?oFF080om=E
00h0omEL0?oEH03oeF80omEF0?oCE@3odeH0omAJ0?oDG03oe5X0omAK0?oEG03oeUd0omAL0?oEG080
omAE0P3odeH03`3oeUh0omIQ0?oFH@3oeF80omAJ0?oCE@3odeH0om9F0?oDF03oe5`0omEL0?oCF`3o
eEX0om9F0?oCEP020?oDE`050?oEE`3odeH0om=F0?oCEP3oe5X00P3oeEd0103oe5d0omIM0?oFG@3o
eE/30?oDEP<0om=F00L0om=L0?oFH@3oeV40omEP0?oFH@3oeV80omAK0080om=F0`3oe5H04P3odeH0
omAK0?oDG03oe5`0om=L0?oDG03oeE`0omAH0?oEE`3odUH0olY?0?o3B@3o`DD0ol=60?o9C03oce40
om=E0?oDE`80omAF3@3oe5L00`3oeEL0omAF0?oCE`030?oCE`80omEG00@0omAG0?oDF`3odUH0omAL
0P3oe5X0103oeUX0omAG0?oEE`3odeL50?oDEP030?oEEP3oeU`0omIM00<0omIM00<0omAM0?oFG@3o
eUd00P3oeUd00`3oeEd0omIK0?oDE`040?oDEP030?oBEP3odeH0om=F00<0om=F00<0om=L0?oFHP3o
eV402@3oeV400`3oe5H0om=F0?oCEP030?oCEP@0omAF00<0om=F0?oEF03ode`0103oe5`00`3ode`0
omAL0?oDG0020?oDG0030?oCG03oe5P0om=F00@0omAF1P3oe5L60?oDEP030?oDE`3oe5H0omAF0080
omAF00D0omAG0?oEF03oeEP0omAH0?oBE@020?o>E00;0?o:C@3oadT0olA70?o1A@3o`TH0ol980?o7
BP3obDd0oliC0?oBE@3odeH00P3oeEPQ0?oDE`030?oEE`3odeD0olM:00L0olA700@0olE80?o4A`3o
a4L0olA70`3oaDL30?o4A`030?o6B03oa4L0olA70080olA700D0olI80?o4A`3oa4L0olA70?o5A`03
0?o4A`030?o5A`3oa4L0olA70080olA700<0olE70?o4A`3oaDL00`3oa4L00`3oaDL0omeB0?o_E`02
0?o`E`040?o`F03ol5@0omUV0?olnV40oooo00@0oko60000000000000000o`3ooole0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinL0oooo00P0aG5<09==8`2D
CB40U4dT09UA9@2IDB<0TddR0<QY;P@0okA>603o]Dh0103o]E00okE>0?neCP3o]Dl30?neCP030?nf
D03o_5T0ok]J00h0ok]J2@3o^e/80?nkFP030?nnGP3o_F40okeQ00H0okeQ00<0okeP0?nmG`3o_V<0
103o_F400`3o_F80okeM0?nkFP080?nkFPL0okYI00<0okaK0?o2JP3o`VX01P3o`VX00`3o`6P0ol9Z
0?o2JP050?o2JP030?o2J`3o_F00okYG00L0okYI00<0ok]J0?nkF`3o^e/01`3o^e/@0?nkFSh0ok]K
00h0okYJ0?n^C@3oZDP0ojM60?n/BP3o]UH0okeJ0?nmG03o^e/0ok]J0?nnGP3o`FD0ok]J0?nkF`80
okYI00<0okeP0?nmH@3o_F400`3o_F400`3o_F80ok]J0?nkFP020?nkFP80okYI00D0ok]H0?o1J03o
`VX0ol9Z0?o1J0020?o2JP030?o1J03o^UT0okYI0080okYI0P3o^e/00`3o_5`0ok]K0?nkF`0:0?nk
FP<0ok]K00P0ok]J0?nkF`3o_F00okeQ0?nlH@3o_F40okaQ0?nlF@80ok]J00L0okYI0?njE`3o`FL0
ol9Z0?o0J03o`V/0ol5W0080okYH00`0ok]J0?nkF`3o^e/0okYI0?nkFP3o_Eh0okiP0?nmH@3o_5`0
ok]J0?njF@3o_5`20?o0I`0N0?o1J@3o_5`0okYH0?njF@3oZ4/0ojI90?nfEP3o^UT0okYH0?o0IP3o
`FT0ol1X0?nmG@3o_F80ok]J0?niE`3o_5h0ol5Y0?o1I`3o_Uh0okYI0?nkF03o`VX0ol9Y0?nkF@3o
_5`0ol9Z0?o0I@3o_E/0ol9[0P3o_5d02@3o_V40ol1V0?nmG@3o_V<0okeO0?nmH@3oa6@0ok]N09QB
:P020000000;058R5P3oOe@0ohaK0?n<G03oSV40oi9U0?n9F03oUFT0ohaL0?n<G@1d;Ah00P000000
2@0<10<0000003@<3@3f@3l0oemO0?mED`3J>CL0MR0O02d<2`030000000=07<e7@3oQTl0oi5?0?nS
EP3o/f`0oi==0?m_>@37GCH0OCXR04HP4@0b5P/060/700@30P030000000>01dA201S>ah0WEd_0>>5
?@3oXd80okY;0?o3D@3odU/0on1M0?oMF`3ogFH0omYW0?oFI03odED20?oDE@0=0?oCF03ode`0om=L
0?oCG@3oe5H0omEF0?oDE@3od5<0omEO0?oFI@3oeF<0omEV0?oEG0020?oAE@060?oBEP3odeP0omEM
0?oEG@3oeU`0omEM0P3oe5D00`3odUH0omEG0?oDE@020?oDE@0:0?oDEP3oe5L0om5G0?oDE@3odeD0
om=M0?oEI03oeF00omMU0?oEI@80omEV00<0om=H0?oAE@3odED00`3odUH0103oe5X0omEM0?oDG@3o
ded20?oEG@040?oDF`3odUH0om9F0?oBEP@0omAG1@3odUH@0?oDE`090?oFE`3odeL0om5D0?o5B`3o
_T<0ol=30?o5B03ocU80omIG0080omEF00<0omEG0?oDE`3oe5L0103oe5L50?oAE@030?oCF`3oeFL0
omEV0080omEV00P0omET0?oBGP3oeEl0omIS0?oFJ@3oeFH0omEU0?oDFP@0om5E00<0om9D0?oBEP3o
dUH0103odUH00`3oeE`0omEM0?oEG@020?oEG@030?oCG@3oeEd0omEM0080omEM00<0omAN0?oEF`3o
dUH0103odUH70?oDE`/0om9F=03oe5L03`3odeL0omIL0?oEF03odeH0olmE0?o;DP3oad/0ol=50?nn
@`3o`D<0ol=50?o4AP3oaTT0ola?0?oBE@020?oEF1h0omAG00<0oliB0?o4A`3oa4L01`3oa4L00`3o
aTP0olA70?o4A`0<0?o4A`040?o6B03oa4L0olA70?o5A`@0olA700<0olI80?o4A`3oa4L00`3oa4L0
0`3oaDL0olA70?o4A`030?o4A`070?o[E@3okeL0onmF0?o^F03ol5L0oni90?o__@1R0?ooo`040?no
aP000000000000000?l0oooo=@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOW0?ooo`080?n/T@2IDBL0UTlS09A=902DCb<0TddR09A=8@2_G2T40?ndCP<0okE>
00<0okE?0?neCP3o]Dh0103o]Dh00`3o]E00okE>0?neCP0;0?neCP040?neD03o]Dh0okE>0?neD0@0
okE>00<0okQC0?nkF`3o^e/07P3o^e/;0?nkFP030?nmH03o^e/0ok]J00<0ok]J2P3o^e/70?nkFP03
0?nlF`3o_5h0okaN00h0okaN00<0okeN0?nlG03o^eX01`3o^eX00`3o^UT0okYH0?njF0060?njF003
0?o0I@3o`V/0ol9[00D0ol9[00<0ol5Z0?o2J`3o`V/01@3o`V/00`3o`V`0okeN0?njE`070?njF003
0?nkFP3o^e/0ok]K0340ok]K00d0okUH0?n/C03oZ4L0ojQ70?n/B`3o]eP0ok]K0?nlG03o^eX0okmQ
0?nlF@3o_5`0okeM00D0ok]K1P3o^eX40?nkF`<0ok]J1P3o_5h00`3o_Eh0ok]K0?nkFP020?nkFP<0
okYH00D0okiP0?nnI03o`F`0ol9[0?o1JP020?o2J`030?o2JP3o^eX0okYH0080okYH1P3o^e/01@3o
^eX0ok]K0?nkF`3o^e/0ok]L0080ok]K0P3o^eX30?nlGP040?nmGP3o_Ed0ok]K0?njF@80okYH00X0
okeO0?o2J`3o`FX0ol9Y0?o2J`3o^UT0okYH0?njF@3o^eX0ok]K0P3o_5h0:P3o_Eh0ok]K0?nlG03o
]ED0ojU60?neG03o`f/0ol9[0?nnH03o^e/0okaM0?nlGP3o^eX0okYH0?nmG@3o`V/0ol9Z0?nlH@3o
^UT0okaI0?nkF`3o`FX0ol9[0?noH`3o^EL0okeQ0?o2J`3o`FP0okYI0?o2K03o_fD0okYE0?noI@3o
^e/0ol1X0?njF@3o_V40okeP0?nmGP3o`VD0okEJ09YC:`80000000T0HRHJ0?n5F03oT680oheN0?nA
H`3oR5L0oiAW0?nCH`2iF3X00`00000050030@40NQlO0?mBD03oFeX0[Rd/02P92@0=0`@0000000<1
00178Q80^UTd0?n6B`3oTU40oh5=0<iK<02<@2<0@AlC024?200B2@@01@81100000003`11:1@0SUHY
0=^3>03oWD00oki>0?o5DP3oc5<0omEL0?oPJ03offT0om]S0?oEE@3odeD0omAG0?oBF`020?oEF`03
0?oAE@3odU@0om9F0080omET00@0omEU0?oDI`3odeD0om9D0P3odUH01@3oe5X0omEK0?oEF`3oeE/0
omEI00@0omAG00h0omEF0?oBE03odU@0om9D0?oDH@3oefP0omEW0?oFIP3oeFL0omQW0?oDH@3odU<0
om9D0?oDE@80omEF00@0omEH0?oBF03oded0omAL0`3oeE/00`3oe5L0omEF0?oEEP030?oDE`H0omEF
00<0omEG0?oDE`3oe5L05@3oe5L00`3odeD0om9D0?oBE0020?oBE00=0?oCG03oefP0omEW0?oEIP3o
aED0ok=10?n_?P3o[d00ol1A0?oAH`3oeVP0omAU0?oDE@050?oBE0030?oBEP3oeEH0omEF0080omEF
00X0omEH0?oEF`3oeE/0omAJ0?oFG`3odU`0omAG0?oDFP3oeE/0om9K0P3oeE/00`3odeP0omEF0?oE
EP020?oEEPL0omAG00<0omEG0?oEEP3oeEH0203oeEI=0?oDE`030?oBFP3oeEP0omAG0080omEH00D0
om=F0?oBE@3oce80olM<0?o2A0020?o1@`050?o3A@3oa4H0ol=90?o9C@3od5@0703oe5L0103odE80
olE70?o4A`3oaDL70?o4A`030?o6B03oaDL0olA700L0olA700<0olI70?o6B03oa4L00P3oa4L00`3o
aTP0olA70?o4A`050?o4A`030?o6B03oa4L0olA700D0olA700/0olE70?o4A`3oa4L0ol=70?o/E@3o
l5L0oo5H0?o_E`3olEL0oma:0?ommP1R0?ooo`040?noaP000000000000000?l0oooo=@3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOW0?ooo`090?oYiP2IDRP0
TD/S09E@902CCB00VE4U09M@8`2QE2D0ok9=00<0okA>0`3o]Dh00`3o]Dl0okE>0?neCP0<0?neCP03
0?neD03o]Dh0okE>00<0okE>00<0okE@0?neCP3o]Dh01P3o]Dh00`3o^5<0ok]K0?nkF`0Y0?nkF`03
0?nlG03o^UT0ok]K03L0ok]K4@3o_5`90?nkF`030?njF@3o^UP0okYH00H0okYH00<0okiP0?o2K03o
`V/01@3o`V/00`3o`FX0ol9Z0?o2J`060?o2J`030?noI`3o^UP0okYH00H0okYH00<0okYI0?nkF`3o
^e/01`3o^e/50?nmG@0?0?niF@3o[Dh0ojM80?nWB03o[4`0ok=E0?nlG03o_5d0ok]K0?o0J03o_F40
okaK0?nkFP3o^e/0ok]J00h0ok]K00@0ok]J0?nkF`3o^e/0ok]K203o^eX30?nkF`80ok]J00D0ok]K
0?nlG03o^ed0okeQ0?nkF`040?nlG0@0ok]K00D0okYI0?njF03o^UP0ok]J0?o1JP020?o2J`050?o1
J@3o`V/0ol9[0?o2J`3o_F400`3o^UP01@3o_5T0ok]J0?nkFP3o^eX0okaL0080okeM00D0okaL0?nl
G@3o_5h0okeN0?nmG@020?nlG0<0ok]K00X0okYI0?niEP3o_f@0ol9[0?o2J@3o`f/0okeU0?n[BP3o
[4/0okYJ0P3o_5`0203o_Ed0okaL0?nkF`3o^eP0ol1W0?o1J@3o`V/0ol1V0P3o^eX0203o_5T0okYI
0?o0IP3o`V`0ol9[0?nlF`3o^UL0okmT0P3o`Vd06@3o^UP0okmT0?o3KP3o_V@0okeP0?noI03o_F40
ol5W0?nnH@3o_F00okeN0?nmHP3o_Ul0okYN0>Ul?`0R4PP0000005lW6@3oLDX0ohmO0?n>H03oTF<0
oi5Q0?n1EP0i5`l00P0000003P060P40KQdK0<dc<P1Z71/070L700@10@090`002@@1034G3@2fDbl0
behg08Y19P1M:QL05@X50`0000004@020@0020H201H>1@0V5@`0Q50U0=Am<`3oWT00ok]>0?o=E03o
df@0omEW0?oHJP3oeeh0omEG0?oDF03oeEH0om=G0080omAE00L0om=O0?oFI`3oeFH0omEX0?oDGP3o
dUD0om9H0080omAJ00X0omAK0?oEF`3oeE/0om9H0?oEE`3oeEH0om9D0?oAE@3odeH0omEU0P3oeFL0
1`3oeFH0omEW0?oEI@3odeT0om5D0?oBE03oe5D00P3oeEH0103oe5L0om9H0?oBF03oe5P20?oEF003
0?oBF03oe5L0omAG00@0omAG00@0om9F0?oEEP3ode`0omAG2@3oe5X50?oDE`030?oCEP3odU@0om9D
00<0om9D00<0omIL0?oGIP3oeFL00`3oeFL01`3oeVH0omEW0?oEI`3oeFL0omIX0?oDHP3oe5D01@3o
dU@00`3odeL0omAG0?oDE`030?oDE`<0omEH00P0omAG0?oBE@3obD`0ol540?noA03o`dP0olU@0?oC
F0/0omAG00D0om=I0?oEEP3oeF<0omAG0?oEE`1[0?oDE`030?oCE`3ode`0om9H00H0omAG00@0om=F
0?o?DP3obTd0olA60`3o`T@01`3o`DD0olI:0?o<C`3od5<0om=F0?oDE`3oeEP05@3oe5L00`3odE@0
olA70?o4A`020?o5A`L0olA700<0olI80?o5A`3oa4L0203oa4L00`3oaDL0olA70?o4A`030?o4A`03
0?o5A`3oa4L0olA700<0olA700<0olI80?o4A`3oa4L00P3oa4L0103oaDL0olA70?o4A`3oaDL20?o4
A`030?o1A`3ojEH0oo1G0080oneG00<0oo5D0?oKN@3omnh0HP3oool0103o_lH0000000000000003o
0?ooocD0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj03o
ool02`3?Mdd0TD/Q099<8`2DCR80TddR09M@902HD2<0oje;0?neC`3o]Dh0okE?0280okE>00<0okMA
0?nkFP3o^e/0:@3o^e/00`3o^eX0okeN0?nkF`1d0?nkF`P0ok]J00`0okaL0?noH`3o_f<0okeQ0?ni
G@3o]5L0ojM;0?nSAP3oYd/0ok=G0?nnHP3o`VX20?nnH0040?nmH03o_f<0okmR0?nmG`P0ok]J00<0
okYI0?nkFP3o^eX01@3o^eX00`3o_5`0ol1V0?noI@050?noI@80okiT1`3o_fD00`3o_f<0ok]K0?nk
FP020?nkFP050?nkF@3o^eX0ok]J0?nkFP3o^eT0203o^e/00`3o_5d0okeN0?nmGP060?nmGP030?nl
GP3o_Eh0okaN0080okaN00D0okeN0?nnH`3o`6H0okmS0?nmH@030?nnHP030?nmG`3o^eX0ok]J00@0
ok]J00d0ok]I0?nlG`3o_fD0ol1U0?nlH@3oYD/0oii30?ndF03o_f40ok]H0?njF03o_El0okeP0080
okiQ00/0okeN0?nkFP3o^e`0okaK0?nlG03o_V40okmT0?o1J`3o`Vh0ol9Z0?nmG`020?njF0090?nl
G@3o`FT0ol9/0?o0J03o_5h0okiO0?o0I@3o_V@0okmS0080okiS01D0okmT0?noH`3o_V<0okiS0?nn
H03o_Uh0okiO0?nfFP2JGbl07A0700T40P1R:1X0f6]60?n?H@3=HD00>1H?000000020@401P4201H5
1@0I1PL00P000000700100001P<202LB2P0W4`/060/701D=1@0Z6@/0=R0@04d]5P1oC2@0UFTa09j0
>`2^S3d0gZA20?njCP3od5l0omUZ0?oHJP3ofFH0omEF0?oCE03odeH0om9E0?oCF03oe5`0omER0?oG
J03oeFD20?oEG`050?oEH03oe5/0omAI0?oDF@3odeT00P3oeET01`3oe5/0omEQ0?oEH@3oeV40omER
0?oEH@3oe5d0103odUH20?oCEP<0om9F00<0om=F0?oEG`3oeF40103oeF400`3oeEl0omEQ0?oEH@02
0?oEH@030?oEF`3odUH0om9F0080omEF1@3odeH0203odEH0omAG0?oEG@3oeEd0om=N0?oFGP3oeeh0
omEN103oeUh00`3oeEh0om=H0?oCEP030?oCEP030?oCE`3oe5L0omAG00T0omAG00<0omEG0?oCE`3o
deL05@3odeL04P3odE@0olY<0?o5AP3o`T<0olE70?o<C`3odED0omAG0?oEF03oeEL0omAF0?oCF03o
e5P0omAK0?oDFP3odeH0omEK0?oBEAT0om=G00<0omEG0?oDE`3oe5L06`3oe5LL0?oCE`030?oEF03o
deX0om=J01T0om=J00@0omAJ0?oDG03oeE`0omAJ0P3odeX50?oEFP0A0?oDFP3odEP0oliE0?o>D`3o
b4l0olI:0?o4B03o`DH0ol150?o3B@3oaD/0olQ>0?o<DP3od5D0om=G0?oDFP3oeE/00P3oe5/:0?oC
FP040?oEF`3odUP0om1D0?o7BP80olE70P3oaDP80?o5A`030?o5B03oaDL0olE700@0olE700<0olM9
0?o5A`3oaDL01@3oaDL00`3oaTL0olE70?o5A`040?o5A`0B0?o6B03oaDL0olE70?o5A`3oaTP0olE8
0?o8B03oaDP0olI80?o5B03o`dL0om==0?o[EP3okeL0oo5G0?o]E`3okE40ooG@903oool0303ogn<0
_j^]07UPH`1<=3H0<b<T00d92@0000003@T903<S901<=3H0LeMJ0?oOh`H0oooo00X0k=kO081aM@1U
ATP0<b<T00L51@0000003@T903<S901cG5l0f;bo1`3oool30820P0030<2`/P3oool0oooo00@0oooo
00@0omoS0820P020P800P8201P3oool0103ogn<0P8200820P020P8040?ooo`080?noaP0000000000
0000003oool0oo3e0:FJV`1<=CH30000000304`e=P2IRi00onS/00P0oooo00X0lLkA07UTJ00c8b@0
6A8B0000000/7b00LDiA0:FJV`3onOh0a/C40`20P8000`3oko40oooo0?ooo`030?ooo`030?oioP2U
VY/0C3Df00<0000000<0?b`]0?o@f03oool0103oool00`3H_;l0LeaO03<S90020000000500L51@0c
8b@0F3do07iGFP2bX:<01@3oool30820P0030?oOh`3oool0oooo00l0oooo00`0oo3e09>1Q01UATP0
?b`]03<S90071@D0000001TB4P0c8b@0LeaO0<^d]P3onOh90?ooo`0:0=W5b020J6`0IDI803<S900=
2@T0000003<S900o;2d0LeaO0?oXk080oooo00D0onoa0820P020P800P8200<30`0070?ooo`030:bG
VP1UATP0<b<T0080000000D03@T903<S901H?Cl0OfU/0>C5b0050?ooo`<0P82000<0omoS0?ooo`3o
ool0103oool0103ogn<0P8200820P020P8070?ooo`050?odmP2bXZ@0P6Q/06E6B00V6a/00P000000
100c8b@0DSTk081aM@3oj>`50?ooo`040>cNg`20LGD0IDI803<S9080000000D03@T903<S901[BTd0
P7Yn0>C5b01b0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
inP0oooo00`0okfW08Q76`2@Bb40T4XQ09A?8`2CCB80V54S0?nMA`3o]E00okA>0?neC`3o^4l50?ne
CP030?neD03o]Dh0okE>0180okE>00<0okE?0?neCP3o]Dh01@3o]Dh00`3o]e40ok]K0?nkF`0[0?nk
F`030?nkFP3o_5`0ok]K07T0ok]K0P3o_5`0203o]ED0ojU90?nVAP3oYdH0ok1A0?nkGP3o_EX0okiQ
0P3o^eXG0?nkF`L0okaI0P3o^eX70?nlF@030?nkFP3o^e/0ok]K00<0ok]K00@0okaL0?nmH@3o^e`0
ok]K1`3o^UT00`3o^UP0okiS0?o0I`070?o0I`030?noI`3o`6L0ol1W00@0ol1W00<0ol1X0?nnGP3o
^UT0203o^UT30?nkFP060?njF@3o^UP0okYH0?n^C03oZTL0ojm@0P3o_f@40?noI@050?nnH`3o_F<0
okiS0?o1J03o`g400P3o`g801@3o`fh0ol9_0?o3K`3o`FX0okUF00<0okYH00h0okUG0?njE@3o_E`0
okiS0?o3KP3o`g80ol9/0?nmH03o`6L0ol9[0?o1I`3o_f80okmU0?nmH080okiR00T0okeN0?nmH03o
_5d0ol9M0?nUC@1j@1d020@201<7101c;Qd02@0000004@0L4@H0CBhF08M@9@2UHB`0eGhg0?nUB`3o
dU/0onEU0?oXI@3ogfL0omYP0?oDF`3odeT0omEU0?oEK03oeVT0omEX0080omIY00@0omIR0?oCF@3o
dU80om=C0P3odU@00`3odE@0om1A0?oBDP030?oBDP070?o@D`3oe680omAR0?oDHP3oeF<0omAT0?oF
H`040?oDI0030?oGH03oe5L0omAE00<0omAE00<0om9F0?oBF03odUP00P3odUP00`3odeP0om9F0?oB
EP090?oBEP040?oEE`3odUP0om9H0?oDE`80om9F203oe5D00`3odeL0om5E0?oCE@0G0?oDE@030?oC
F@3oe640omAQ01H0omAQ00@0omIQ0?oEHP3odE`0ol=>0P3o/cl0203o_DH0olYD0?oFGP3oe5h0om=T
0?oFH`3oeF00omIO703oe6400`3oeEd0om=E0?oDE@0J0?oDE@030?oCE@3oe5D0omAE01T0omAE00<0
om=E0?oCF`3oeF<06`3oeF<01@3oe6@0omIO0?oDH`3oeF<0omAT00P0omES0180omAT0?oFI@3of6@0
omAP0?o:E`3o_d`0okI40?nd@P3o/3h0ojln0?nd@@3o`4/0olUD0?o@GP3odf80omIT0?oGI@3oeV@7
0?oEH`040?oFI03oeF<0olQA0?o4A`<0olE800<0olQ70?o8B@3oaDP01P3oaDP00`3oaTT0olI70?o9
B@050?o5B0040?o9B@3oaDP0olE80?o8B@<0olE800<0olM90?o5B03oaDP02@3oaDP02P3oaDL0olA7
0?o7B@3oa4L0olE70?o4A`3o`4H0on=B0?o[EP3olEP20?oYE@030?oZI@3ok]T0oooo0240oooo00<0
ooWn0;1iOP0000002P0000000`3o_lH0oooo0?ooo`030?ooo`030?oco00V6Q/0000000P0000000<0
Bc@f0?oco03oool0103oool300000003081PH`3oool0oooo00@0oooo00@0oko60000000000000000
1P3oool0103o_lH000000000000000040?ooo`060?noaP00000000000000003olo`0<R<T1`000000
0`0I4A80om3H0?ooo`050?ooo`030?b]]0000000000000H0000000<0Bc@f081jOP0000000P000006
0?ooo`030<V;T0000000000000@0000000H0oko60?ooo`3oool0oooo0?oco01;=3H90000000303<S
903oool0oooo00<0oooo0`0000000`3o_lH0oooo0?ooo`0?0?ooo`030?noaP000000000000P00000
00<0<R<T0?o@f03oool01P3oool00`3RW:80000000000007000000<0oooo00D0omoS000000000000
00000820P0050?ooo`030?oco01;=3H0000000P0000000<0IDE80?ooo`3oool00`3oool300000003
0?noaP3oool0oooo00@0oooo00@0oko600000000000000001`3oool00`1aCU400000000000070000
00D0oooo00<0oo?l02HJ6`000000200000000`1UADP0oooo0?ooo`1`0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinP0oooo00h0ooKh09197@2CCB80T4XQ095;
8@2DCB@0VE4S0?n;?@3o^540okA>0?neC`3o^4l0okE>0?neD0<0okE>00@0okE@0?neCP3o]Dh0okE@
0P3o]Dh00`3o]E00okE>0?neCP020?neCP030?neD03o]Dh0okE>0100okE>00<0okIE0?nkF`3o^e/0
:@3o^e/0103o^eX0ok]K0?nmH03o_5ag0?nkF`80okaL00T0okQH0?n`D@3oZDT0ojM60?n[C03o]EX0
ok]M0?nnHP3o_5T01@3o^e/00`3o^eX0okaI0?nlF@0D0?nlF@030?nlFP3o_5T0okaI0140okaI00H0
ok]I0?nlG03o^e/0okYI0?nlFP3o^eX60?nlG0030?nlFP3o^eX0ok]J00h0ok]J00<0ok]K0?nlG03o
_5`01P3o_5`00`3o^eX0okYH0?niE`030?niE`050?ngE@3oZdP0oj]90?ndE@3o_f@0103o_V<01@3o
_V@0okmT0?nnH`3o_f@0okiS00D0okeR00<0okeS0?nkG03o^UP00P3o^UP0203o^EL0okYE0?njE@3o
^E@0okeJ0?o2J@3o`FP0ol5Y0P3o`VX0103o`6H0ol5W0?o0I@3o`6H20?o1I`090?noIP3o_F00okeP
0?nmH03o^UX0olML0?o4FP34IBd02`D300@0000001002@H202hK2`1U>aP0S58T0;ia;`3MPCP0oie2
0?niDP3ogV<0onQV0?oUIP3ohFX0omUV0?oCG`3oeEd0omET0`3oefh00`3oefd0omIY0?oGJ0030?oF
J@030?oFK03oefP0omIP00@0omEP00<0omAQ0?oDHP3oe6800`3oe6801@3oe640omAR0?oEH`3oe5X0
om9B00@0om9D00<0om=D0?oBE03oe5D0603oe5D00`3odED0omAE0?oDE@090?oDE@030?oDE`3odeL0
omAE01H0omAE00<0om=I0?oFHP3oe640603oe6402@3oeV<0oleJ0?nmB@3o^T40ojXl0?noA`3oc5D0
om=O0?oFH@020?oDH@030?oEH03oe640omAQ01T0omAQ00<0omIR0?oDGP3odeD06`3oe5D00`3oe5H0
omAG0?oDE`0K0?oDEad0omAE00@0om9F0?oDF03oe5L0omED2`3oe5D0403oeEH0omIG0?oFF@3odUH0
om9C0?o<D03ob4`0olE50?nn@@3o`400ol530?o4A`3obDX0ola=0?oAD`3odeL20?oEEP070?oCEP3o
e5D0omAE0?oDE@3oe5H0olY:0?o4AP040?o4A`030?o5B@3oaDP0olA700L0olA700<0olM90?o6A`3o
a4L0103oa4L00`3oadT0olA70?o4A`0B0?o4A`0<0?o7B@3oa4L0olE70?o4A`3o`dP0on5B0?o_F03o
keL0onUE0?oZEP3olGh0ooko8P3oool00`2UU9T000000000000400000003038S901UADP0Bc@f00<0
000000<0oko60?ooo`3oool00`3oool02@1UADP000000000000000006A4B0;f2Q`39Ri00/7Un01TA
4P030000000306E5B03oool0oooo00<0oooo0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP00
00000000000000H0oooo00@0oko60000000000000000103oool01@3o_lH00000000000000000OUMJ
0080000000@0RV1S0<V;T039Ri00Bc@f0`0000000`0b8b@0ooWn0?ooo`030?ooo`030?oco00I4A80
00000080000000@0<R<T09MXK02`NWh06A4B0P000000101H?Cl000000000000000060?ooo`08038S
9000000000000000002GJ6`0bH^@08YPH`3o_lH30?ooo`0607iGFP00000000000000000b8b@0/7Un
0P3o_lH01039Ri00Bc@f0000000c8b@50?ooo`<0000000<0oko60?ooo`3oool03`3oool00`3o_lH0
0000000000020000000306E5B01;=3H0000000@0000000<0<R<T0?oioP3oool0103oool00`3RW:80
0000000000020000000601TA4P2TLGD0bH^@06E5B00I4A8000000`3oool01@3ogn<0000000000000
0000P82000D0oooo00H0OUMJ0000000000000000038S902`NGh20?noaP040<V;T01;=3H0000006E5
B0D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00<0hYbR
0000000000000P0000001P1<=3H0bH^@0<V;T01UADP03@T9000000D0oooo00H0OUMJ000000000000
0000038S903HW:820?noaP040<V;T00V6Q/0000006E5B780oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWj03oool03P3ooOl0f7eF08i97`2CC280SdXS095;8P2B
C280dVh`0?niD@3o]4h0okE?0?ngC`3o]Dh0okE?0`3o]Dh00`3o]E00okE>0?neCP030?neCP030?ne
D03o]Dh0okE>0080okE>00<0okE?0?neCP3o]Dl01`3o]Dh00`3o]Dl0okE>0?neCP060?neCP030?nf
D03o^580okYG01H0ok]K5P3o^eX00`3o^e/0okeN0?nnHP150?noHS00ok]J00P0okED0?n^C@3oYdP0
ojU80?n`D03o]ED0okYI0?nlG080ok]I1P3o^eX00`3o_V80ol1V0?noI@0Y0?noI@060?nnI@3o_fD0
okeP0?noH`3o_V40ok]H803o^eX20?nkF`<0ok]J00@0ok1?0?nZBP3o]UP0okmR0`3o_V400`3o_F00
okiQ0?nnH@020?nnH@030?nnH03o^eT0okYI00<0okYI1P3o^UP03@3o`6P0ol5[0?o1JP3o`F/0ol=]
0?noIP3o_V<0okmU0?o1J@3o`FP0ol5V0?nlGP3o_f<00P3o_f@0303o_V<0okmS0?nnGP3o_Eh0ol1P
0?2YD@2OJS80JCLI030I2`040P403@T3038P2`80000001L00`8100l810139a00SehX0:N??03<YDL0
m[YA0?oFH@3of680omUR0?oEH`3oeV<0omEO0?oFH`3oeFD0omEO0?oEG@3oe5/0om=E0?oCE`3oeEh0
omIR0?oDH@040?oFJ@80omI[00<0omMY0?oEI`3oeF<00`3oeF<20?oFI0060?oEI@3oeEd0omAI0?oE
F@3oe5H0om5E0`3odUD0103oe5D0om=F0?oCEP3odeH60?oBEP030?oEG03oe5h0omEM00l0omEM00<0
omAI0?oCEP3odeH01P3odeH40?oDE`80omAH00@0omEH0?oDE`3oe5L0omAG3P3oeEL40?oDE`030?oC
F03oe5H0om=G01L0om=G00`0omEL0?oDF03oeUX0omEG0?oDE03oc500olM90?o0A03o`dD0olI:0?o?
DP3odULL0?oCE`030?oDEP3oeEL0omAH05P0omAG00<0omAI0?oCF`3oeEP03@3oe5L30?oEF00A0?oD
E`3odeH0om5D0?o>D@3obTd0olM90?o4A`3o`TD0ol=60?o3B03oaTX0olY=0?o=D@3od5D0olmD0?oA
E03obT`01P3oa4L20?o5A`L0olA700@0olE80?o5A`3oa4L0olE7103oa4L01@3oaDL0olA70?o4A`3o
aDL0olA70080olE700<0olA70?o7B@3oa4L01@3oa4L0103oaDP0olA70?o5A`3oaDL20?o4A`070?o5
A`3oa4L0olI80?o2AP3of4l0oneG0?o_F0020?o]E`030?o[DP3ojZ@0oooo0240oooo00P0YIBI01<=
3P000000000000d92@2HOGl0o]KJ0?oioP@0oooo00<0omoS0:bKW`3od=P0103oool01P1nEeX00000
0000000c8b@0bkBf0?oioP<0oooo00<0ooWn07m/K@0000000P0000000`2oZjd0oooo0?ooo`020?oo
o`<0000000<0P61S0?ooo`3oool0103oool0103o_lH000000000000000060?ooo`040?noaP000000
0000000000@0oooo00<0oko60000000000000P0000000`1H?Cl0i<G80?ooo`030?ooo`0509j1Q000
000000000000002hYjP0103oool01P2TLGD00000000000071@D0bjjd0?oioP<0oooo00<0i<G806E6
B00000000`0000050?ooo`050?o@f000000000000000003T][d01P3oool01P3;];H0000000000000
0000QG1b0?oioPD0oooo00<0omoS0;:BUP3oool0103oool3000000030?noaP3oool0oooo00l0oooo
00@0oko6061?D@3;];H0o]KJ0`3oool00`3ol?D0i<G804Li>`03000000030:JBUP3oool0oooo0080
oooo00L0/X^@0000000000000000075>D@3TaLP0ooWn00@0oooo00D0f;bo0?ooo`3oool0oooo0?oO
h`03000000030820P03oool0oooo0080oooo00H0UfQ/00000000000081HG0<^d]P3onOh50?ooo`03
0=W1a02bPXL0oooo00@0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP00000000000000
00D0oooo00L0/X^@0000000000000000075>D@3TaLP0ooco00<0oooo00<0on_]0;:RY03oool00`3o
ool01P2GJ6`000000000000o;2d0bkBf0?oioP@0oooo00<0onoa0;:RY02bPXL0LP3oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOY0?ooo`0=0?o8^`2:AA/0T4XQ
095;8`2@BR40SdXR0:YH9`3o/T`0okA>0?neD03o]E40okA>0?ndC@020?ndCP040?neD03o]E40okA>
0?ndC@80okA>0P3o]E001`3o]Dh0okA>0?ndCP3o]4h0okA=0?ndCP3o]E001@3o]4h20?neD0030?nf
D03o]Dh0okE>00D0okE>00H0okE@0?neCP3o]4h0okI@0?nhE@3o^UTC0?njF0030?njF@3o^e/0ok]K
01H0ok]K00<0okeS0?nlG@3o_Ed0@`3o_Ed^0?nkF`070?ncD`3o[4`0oj960?n[BP3o[e40okUI0?nl
F`0<0?nkFb`0ok]J0P3o^e/00`3o^e`0okeP0?nlF`060?nlG0D0ok]K00<0ok]J0?njF@3o^UT00`3o
^UT00`3o`6@0ol9[0?o2J`020?o2J`030?o1J@3o`V/0ol9[0080ol9[00<0ol5Y0?nlG@3o^UP00P3o
^UT02@3o^UP0ok]I0?nkFP3o_5/0okEE0?nYB@3o/e@0okaN0?nmGP020?nlGP090?nmG@3o_5d0okaL
0?nkF`3o^UX0okeN0?o2K03o`VX0ol5X0080ol9[00@0okeP0?njF03o^UP0ok]I0P3o^UP02`3o_V40
ol9^0?o1K03o`fd0ol1V0?njFP3o_F00ol9Z0?o0J03o_f@0okeM0080ol5W0140okmR0?nnH`3o_F80
okiR0?noH@3o_Eh0okEI0<a/=@0K3PL0000000`70`0O4@L01P@10?jQ?P3ogU80ojdm03DR30020000
000M00800000000000000000000;1@<0<A`<09eP:03gTd<0olEI0?oAG@3oefD0omYY0?oFG@3odeT0
omMX0?oEI`3oeFP0omEL0?o@DP3oeE80om=A0?oEJ03oefP0omEW0?oGJ`3oeF00omAE0?oBEP3oe5L0
0P3odUH02P3oe5L0om9F0?oAE@3odED0om9D0?oEF`3oeFP0omEW0?oEI@3oefH20?oEI`030?oEI@3o
deL0om9D0080om9D0`3oeEH20?oDE`030?oCF03odU/0omEK00<0omEK00<0om9K0?oDFP3oe5X0103o
e5X00`3odU/0omAJ0?oDFP030?oDFP030?oDE`3oe5H0omEF00H0omAG00<0om=E0?oBE03odU@00P3o
dU@01@3od5<0om9F0?oAE`3odeP0omMV00H0omEW00<0omIV0?oEI`3oeFL01@3oeFL00`3oe5d0om9D
0?oBE0050?oBE0030?oBE@3oe5L0omAG00D0omAG00<0om=H0?oBF03odUP01P3odUP20?oDE`050?oA
E`3oeF00om9F0?oBF`3oeEP01@3oe5L01`3od5<0olA:0?noA03o`T@0olM90?o?DP3oeEP0MP3oe5L0
0`3odUH0omEK0?oDF@0C0?oDE`070?oEF03oe5L0om=F0?o@EP3ocE40olE;0?o0A@020?o2A0030?o3
A@3o`T@0ol9500P0olA700<0olI80?o6A`3oa4L01@3oa4L0103oaTP0olA70?o4A`3oaTP70?o4A`03
0?o5B03oadT0olA70080olA700<0olM90?o4A`3oa4L0103oa4L00`3oaTP0olA70?o4A`050?o4A`09
0?o6B03o`DH0ome@0?oaF03okeL0oneG0?oYE03ohTd0ooCL0240oooo00H0bH^@0000000000000000
01TA4P3od=P=0?ooo`050>:LXP00000000000000003ohNX01P3oool01@3ol?D00000000000000000
LDiA00@0oooo0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0
oko60000000000000000103oool00`3o_lH0000000000002000000030?oco03oool0oooo00<0oooo
00D0ooWn000000000000000007iGFP040?ooo`0404/d=P000000000005Pm?`H0oooo00<0oo?l00d9
2@0000000P0000050?ooo`040?noaP0000000000000000L0oooo00D0OUMJ00000000000000000?o`
m@0=0?ooo`<0000000<0oko60?ooo`3oool0603oool01@3ac]400000000000000000IDI800<0oooo
00D0omoS000000000000000004`d=P0;0?ooo`050?oOh`000000000000000020P8000`3oool01@3n
e]X00000000000000000P75e00h0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP000000
0000000000@0oooo00D0oko6000000000000000009MXK00;0?ooo`050?b]]000000000000000003o
hNX0N`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOY0?oo
o`030?oho02CBah0T4XQ0080TD`P00H0Sd/S0:9D9P3oZDT0okIA0?neC`3o^4lB0?neCP030?neC`3o
]Dh0okE>00D0okE>00<0okE@0?neCP3o]Dh01@3o]Dh01P3o]Tl0okI@0?nfD03o]U00okM@0?nkFRd0
ok]K00<0okaL0?nkFP3o^e/0K03o^e/0203o_5/0ok]K0?nhF03oZ4P0oim30?nXB03o[4`0okIG3P3o
^e/;0?nkFPX0ok]K00<0ok]J0?nlG03o_5h00`3o_5h00`3o_Ed0okaN0?nlGP030?nlGP030?nlG03o
^eX0ok]K00<0ok]K00<0ok]I0?njF03o^UP00P3o^UP01`3o_5/0ol5Y0?o2J`3o`V/0ol1V0?noI@3o
`VX0103o`V/0103o`6P0okUF0?njF03o^UP30?njF@030?nkF`3o^eX0ok]J0080ok]J00D0ok]K0?nk
G03o_5`0okaL0?nkG0020?nkF`030?nlG03o_5h0okaN0080okaN00<0okeN0?nkF`3o^eX00P3o^eX2
0?njF@0>0?n]C03oWdH0ol1W0?o1JP3o`V/0ol9Z0?nkF`3o^UP0ok]K0?nlG03o_5h0okaL0?nlF@3o
^eX20?njF@0S0?o0I`3o`VX0ol=^0?o2J`3o_Eh0okYH0?nkFP3o^EL0okaL0?o3K@3o`F`0okiR0?nj
E`3o_V00ol9[0?o0J03o^UT0ol1V0?noI@3o_5d0okmT0?noH`3o_F80okiQ0?o5I`3o^5d0e78i02hG
3@0000002PH308A<8P34L300:aP;054c5@3oiU`00P3oj5/02@3obTd0HclG01@=1@0000003@/504Xi
5`0Z8@`071D700X70`020000000B00D2001gAR40oiDo0?nmCP3obEl0omAR0?oHEP3ofV@0omYY0?oF
I@3odU80om9D0?oCD`3oef<0omMV0?oIJ@3oeF80omAD0`3odED02@3odUP0omQS0?oIJ@3oeFD0omEV
0?oEJ03oe5D0om9D0?oBE@020?oDE`0E0?oDFP3oeE/0omEK0?oEF`3odU/0omAG0?oEEP3odUH0om5E
0?oBE@3ode<0om9F0?oFHP3oeFL0omMV0?oFI03oeFL0omIW0?oGJ03odel0om9B0080om9D00D0om5E
0?oEEP3oeEH0om9F0?oDE`040?oDFP80om9K00<0omEK0?oDE`3oeEH01P3oe5L40?oEEP040?oDE@3o
de/0omEH0?oDE`h0om9H00<0om=H0?oDE`3oe5L01@3oe5L00`3oe5D0om9D0?oBE0040?oBE0030?o@
E03oeEl0omEX00<0omEW0`3oefH0103oeVH0omEM0?oCHP3oeF<30?oEI`030?oEJ03oeEh0om9D0080
om9D00X0om9E0?oAE@3odU@0ola@0?o4B03oaD<0ol540?o5B@3odUD0om=G103oe5L00`3oe5X0om9K
0?oBF`050?oBF`80omAJ1`3odU/00`3oe5X0omAG0?oDE`0@0?oDEa00omEF?@3oe5L00`3odED0om=H
0?oDE`0H0?oDE`030?oAE`3ocU80olU;0080ol9400<0ol950?o4A`3oa4L03P3oa4L00`3oaTP0olA7
0?o4A`080?o4A`80olE70`3oa4L00`3oadT0olA70?o4A`040?o4A`030?o6B03oa4L0olE700D0olA7
00<0olI80?o>B`3oj5D00P3ol5L0103oie<0onYB0?oTJ`3om>PP0?ooo`060?oco00I4A8000000000
000I4A80om3H3P3oool0101nEeX000000000000V6Q/80?ooo`0404/d=P000000000003l/;@@0oooo
0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0oko600000000
00000000103oool01@3o_lH00000000000000000OUMJ00L0oooo00@0OUMJ000000000000F3do103o
ool300000003075>D@3oool0oooo00D0oooo00@0F3do00000000000000001@3oool0103o_lH00000
0000000000070?ooo`0404`d=P000000000007iGFPh0oooo0`0000000`3o_lH0oooo0?ooo`0I0?oo
o`04038S90000000000003<S90<0oooo00D0bkBf0000000000000000081jOP0;0?ooo`050?oOh`00
0000000000000020P8000`3oool01@3;];H00000000000000000_j^]00h0oooo0`0000000`3o_lH0
oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00D0UfQ/00000000000000000?oco00;
0?ooo`0409MXK0000000000003l/;G`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWj@3oool02`3ojNT0Y5LZ091:8@2>BR80UdlS091;8`2ICb@0oh`n0?niD@3o
]Dl0okQ?00L0okE>00D0okE@0?neCP3o]Dh0okE>0?neD0060?neCP030?neC`3o]Dh0okE>00D0okE>
00<0okE@0?neCP3o]Dh01@3o]Dh01`3o]Tl0okI@0?nfD03o]U00okI?0?nfDP3o^UX0;@3o^e/00`3o
_5d0okaL0?nkF`1Y0?nkF`090?nlF`3o_V00okYJ0?neE@3oZ4X0ojU60?nYB@3o[Td0okUH00<0ok]J
1P3o^e/50?nkFP030?nlGP3o_F40okeQ00<0okeQ00<0okeP0?nmH@3o_F400P3o_F400`3o_F00ok]K
0?nkFP030?nkFPD0okYI00<0okYG0?nmHP3o`V/00`3o`VX00`3o`FT0ol9Z0?o2JP030?o2JP030?no
H`3o^UP0okYI00<0okYI00<0ok]J0?nkF`3o^e/00`3o^e/20?nkFP050?nkF`3o^eX0okeM0?nmG@3o
^eX00`3o_5T00`3o_5X0ok]K0?nkF`020?nkF`80ok]J00@0okaL0?nmH@3o_F40okeP0P3o_F40103o
^e/0ok]J0?nkFP3o^eX20?njF@060?nmG@3o`VX0ol5Y0?o1I`3o`FT0ol5Z0`3o^UT07P3o^eX0okeM
0?n^D03oXdH0ok1B0?nmH03o_5`0okaI0?njF03o^EL0okiN0?o1J@3o`VT0ol1[0?nnH`3o^eX0okeO
0?nlGP3o_5T0okYH0?njF@3o`6H0ol9[0?o2K`3o_f40okYH0?niE`3o_5`0ol=]0?noI080okUG00d0
ol9Z0?o0I@3o^UD0ol1T0?noH`3o_fD0ol1V0?nkF`3o_f<0olAS0?o4I@3o[5P0PTDT0080000001D0
8Q<80;Ye<`3ocUX0KSlJ0000002DM2h0onUR0?oXH03oiE/0onMK0?o_G@3oZT<0JD<J00h90`000000
@34C0:1n;`2FMRh0DT0I02/S3P0?30D00`0000007`1C<Q80a7<g0?n[BP3o^T/0om5L0?oPK03ofe`0
omAC0?oCD@3oeFL0omEZ0?oDG03od5<0om=F0?oBF03oeEP0omAR0?oGI@3oefH0omIQ0?oEE03odU<0
omAE0?oDFP3oeEd0omAL0?oBF03od5<0om=L0?oGIP3oeF@00P3oeFD01@3odUP0om5E0?oDE@3oeEH0
omEG0080omEM00<0om=L0?oCG@3oeEP00P3odUH0303odeL0omAG0?oDE`3oeEH0omAF0?oBEP3oe5D0
om9D0?oCE@3odU@0om=L0?oEI@80omEV00H0omIT0?oEIP3oeFH0omEX0?oEF03odU@20?oAE@@0om9F
00P0om=L0?oEG@3oeEd0omEM0?oCG@3ode`0omAN0?oEF0<0om9F103oe5L70?oBEP030?oCE`3oe5L0
omAG00d0omAG00T0omEG0?oEEP3oeEH0om9F0?oCE`3ode/0om1C0?oCF`3oeE/00`3oe5L40?oEEP03
0?oEE`3oe5L0omAG00D0omAG00`0om1E0?o8BP3o`dH0ol540?o8B03ocE00om=D0?oBEP3odeD0om9F
0?oDH@3oe6L60?oEIP80omEU1P3oeFH00`3oe6L0omES0?oBEP070?oAE@030?oCE@3odUH0om9F00D0
om9F00<0om=G0?oEF`3oeEd01P3oeEd00`3oded0omEM0?oEG@060?oEG@030?oEF`3oeEH0om9F00L0
om9F203oe5L00`3oeEL0om9F0?oBEP0?0?oBEQX0omAG00<0om9F0?oBF03oe5L0603oe5L01@3oeEP0
om9D0?o1A03o`T@0ol950100olA700<0olI80?o4A`3oa4L0503oa4L00`3oaTP0olA70?o4A`050?o4
A`080?o6B03of4h0oo1H0?o`E`3okUP0onYF0?oVDP3ohi8Q0?ooo`050;1iOP000000000000000039
Ri003`3oool0100I4A8000000000001UATP80?ooo`040<V;T0000000000000d92@@0oooo0`000000
0`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00@0oko60000000000000000
103oool01@3o_lH00000000000000000bH^@00L0oooo00@0bH^@000000000000<b<T103oool30000
0003081PH`3oool0oooo00D0oooo00@0LDiA00000000000000001@3oool0103o_lH0000000000000
00070?ooo`0401TB4P00000000000>:LXPh0oooo0`0000000`3o_lH0oooo0?ooo`0I0?ooo`040;1i
OP000000000001TB4P<0oooo00D0VI6B00000000000000000;n[[@0;0?ooo`050?oOh`0000000000
00000020P8000`3oool01@2ITI800000000000000000lLkA00h0oooo0`0000000`3o_lH0oooo0?oo
o`040?ooo`040?noaP0000000000000000@0oooo00@0<R<T000000000000?b`]303oool0100b8b@0
00000000001aCU5l0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWinT0oooo00`0oo[k0;amG`2@BR40T4XQ08m:8@2BC2<0S4PP0<9U;03o_5<0okE?0?neCP3o]E06
0?neCP030?neC`3o]Dh0okE>00D0okE>00@0okE?0?neCP3o]Dh0okE?0`3o]Dh01@3o]Dl0okE>0?ne
CP3o]Dh0okE?00L0okE>1@3o]U00103o]Tl0okI@0?njE@3o_5`[0?nkF`050?nlG03o_5h0ok]J0?nl
F`3o^e`0?03o^e/;0?nlFPD0ok]K1@3o^eX00`3o^e/0okeO0?nnH0080?nmH0030?nlG@3o^eX0ok]J
0080ok]J00d0ok]K0?nkFP3o^eX0okaM0?nkF@3o_5d0okIG0?nWC`3oXTL0oj150?nWC03o]ed0okiS
0080okmV0P3o_fD00`3o`6H0okaL0?nkFP090?nkFP030?nmGP3o_f40okmQ00<0okmQ00<0okiP0?no
H@3o_f400P3o_f400`3o_V00ok]K0?nkFP030?nkFPL0ok]K00<0okaK0?nkF`3o^e/00P3o_5X20?nk
FP030?nlFP3o_5/0ok]K00<0ok]K00T0ok]J0?nlFP3o_El0okiP0?nmH03o_El0okeP0?nmG`3o_5X0
103o^eX01@3o^UT0okiN0?nnH@3o`6H0okmT0080okmU1@3o^eX02`3o^eT0okaK0?nnH@3o_f40okeQ
0?nnH03o_V40okaN0?nmG`3o_Eh0okeP0080ok]K00<0ok]J0?nkF@3o_5`00P3o_f@0J`3o_V@0okiR
0?nkF@3o^eX0ok]K0?neE03oXTH0oj560?njG`3o_V00okaL0?njF03o_5d0okmU0?noI03o_F40okaL
0?nlG@3o_5h0okeN0?nmG`3o`6L0okiS0?o0I03o_El0okYG0?nkG03o_V80ol5Y0?nlG03o^UP0ok]I
0?o1JP3o_F40okUD0?noH@3o`6H0okYH0?o1J@3o`6@0okiP0?nlGP3o`F@0olEU0?2VE@2PICD0JCTN
01`?1`0/6P`0TEHU0;n@@03o^U80oliK07I47P000000?bP@0?kEE`3oj6@0onMO0?oVG@3oiU`0onEI
0?oZFP3ok5/0gKA708eJ8`12:a4020H203/^4`2FOC80dJe10>^nC02h[4D0VGTb06UC7P1:>QT0:b<=
00D40@0V5PT0CBdB07]=9@2XMS80bI<k0>R]BP3oaf00omQK0?oKE`3ofET0omIO0?oGIP3oeUl0omAK
0?oCF03odeX0omAI0?oDGP3oe640omEI0?oCF03oe5`0omIO0?oFH03oeU/0om=F0?oDE03oeE`0omAP
0080omEO00D0om9F0?oCE@3odEH0omAH0?oEHP020?oFH@0A0?oDG`3oe5T0omAF0?oCE`3odeD0om9D
0?oCF03odf00omEQ0?oFH@3oeF80omAP0?oCEP3odEH0omAF0?oCEP3oeEP00P3oeE/01@3oeEX0omEK
0?oDEP3oe5H0om=G0080omAG00D0omAF0?oCEP3odeH0om=E0?oDF`020?oDGP090?oEG@3oe5d0omEM
0?oEG03oe5d0om=G0?oCEP3oe5H0om9F0080om=F00D0omAF0?oFH@3oeV40omIQ0?oDH0030?oFH@05
0?oEF`3odeH0om=F0?oCEP3oeEH00P3oe5H01@3odeL0omAL0?oCG03ode`0omAK0080om=L00d0omAK
0?oCE`3oe5P0om=F0?oCF@3oe5d0omEH0?oDG03oeEH0omAF0?oEEP3oe5H0om=G0080omAF00<0om=G
0?oDE`3oe5L0203oe5L02`3oeEP0om=H0?o@E@3obe00olA80?o2A03oaDL0olM<0?o>D`3odeP0omEG
0140om=G2@3oe5L70?oDEP030?oDE`3ode`0omEM00H0omEM00<0omAM0?oFG@3oeEd01P3oeEd00`3o
de`0om=G0?oDEP070?oDEPL0om=F00<0omEE0?oEF`3oeF801P3oeV400`3oeF40omIQ0?oFH@070?oF
H@X0om=F1`3oe5H00`3odeL0omAL0?oCG0060?oCG0<0omAK00<0omEJ0?oDG03ode`00P3ode`00`3o
e5/0omAF0?oDEP060?oDEPP0omAG00D0omEH0?oFE`3od540olQ90?o5A@020?o2A@P0olE700<0olE8
0?o7B@3oa4L01@3oa4L0103oaDL0olA70?o5A`3oaTP50?o4A`050?o6B03oa4L0olE70?o5B03oaDL0
2@3oa4L00`3oaDL0olA70?o4A`040?o4A`090?o6B03oadT0omiA0?ocF@3okEL0onYG0?oXDP3oiV/0
onkI0200oooo00D0on_]00d92@000000000003l/;@0?0?ooo`050?oXk0000000000000000020J6`0
203oool01@3od=P00000000000000000om3H00<0oooo0`0000000`20H6<0oooo0?ooo`040?ooo`04
0?noaP0000000000000000H0oooo00@0oko60000000000000000103oool01@3o_lH0000000000000
0000omWQ00L0oooo00@0om3H0000000000000000103oool300000003081PH`3oool0oooo00D0oooo
00@0P61S00000000000000001@3oool0103o_lH000000000000000060?ooo`050?oIh@0000000000
0000003ogn<03P3oool3000000030?noaP3oool0oooo01T0oooo00@0bH^@00000000000000000`3o
ool01@20J6`00000000000000000n=_N00/0oooo00D0omoS00000000000000000820P0030?ooo`05
081]L@00000000000000003oko403P3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000
0000000000000`3oool01@3oj>`00000000000000000NE]O00/0oooo00D0onc`0000000000000000
081`LP1l0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinX0
oooo00T0jKVX07`n5P2@Bb80TD`R095;8@2:Aal0ZUPX0?nTA`3o]e005`3o]Dh00`3o]Dl0okE>0?ne
D0090?neCP030?nfC`3o]U00okI@00@0okI@00<0okQ?0?nhE03o_5`0;03o^e/00`3o^eX0okaL0?nl
GP0V0?nkF`030?nkFP3o_5T0okaI0080okaI00<0okaJ0?nlF@3o_5T00P3o_5T00`3o^eX0ok]K0?nk
F`040?nkF`@0okYI00<0okaK0?o0I`3o`6P00P3o`6P00`3o`6L0okmW0?o0J0030?o0J0030?noI`3o
^e/0okYI00P0okYI00<0ok]J0?nnH`3o_fD00`3o_fD00`3o`6@0okmU0?noI@020?noI@0A0?nmH03o
^UT0okYI0?nkF@3o^UT0okYH0?o0I03o_Ed0okeQ0?ncD`3o[Td0ojM70?nZA`3o/Dl0okQG0?noG03o
^eX01P3o_5TI0?nkF`040?nkFP3o_5T0okaI0?nkFP80okaI00L0okaJ0?nkF`3o^e/0ok]K0?nkFP3o
^UT0okaI0080ol1X0P3o`6H00`3o`6P0ol1S0?njF@040?njF@080?nkF03o_V<0okmU0?o0I03o_f@0
okmU0?nnH`3o_5T20?njF@@0ok]K00D0ok]I0?nkF`3o_5d0okYH0?nlF@020?nlG00Z0?njF@3o^e/0
ol1X0?o0J03o`6H0ol1W0?nkF`3o^UP0okYI0?nkFP3o_F40okmU0?noI03o`6D0ok]J0?njE`3o^UP0
okaJ0?nkF`3o^eP0okYE0?nnI@3o_fD0okmW0?nlG03o^5L0oj]80?nQA03o[U80okmT0?njF@3o^EL0
okeR0?o1J03o^e`0okUF0?niE`3o_V00okmT0?nmH@3o_V00okmU0P3o^EH02@3o_5h0ol1U0?noJ03o
_5`0okYG0?nnG`3o`fh0okaK0?niE`020?noH`0S0?niE`3o_F40okiR0?nmH03o`FP0okYH0?nnH@3o
cVT0ojQE0;9P;`0R4`X00000014:102KFBL0okUE0?oJH`3ocET0om5L0;f7>@000000<B0=0?o0C03o
kFL0onQZ0?oUDP3oiUh0onMN0?oVF`3oie`0onIK0?oVF03omEl0onUP0?nX@`1I>AL00P0000002P0b
9`h0aj0m0?ooKP3ooel0oom[0?oPD`3M[DT0[8/d07EM8@0N5`X30000000M03HP3P24C200_Fl]0?ND
@P3ocU`0on9M0?oKE`3ofEd0omEQ0?oFG`3oeF00omAG0?oADP3oeEd0omES0?oDHP3odeT0omAQ0?oG
H03oe5L0om9E0?oAE@3oeUl0omAQ0?oDG`3ode<0omAG0?oAE`3odeH00P3oeF001P3oe640omEK0?oA
E@3odU@0omAE0?oDH080omES00`0omIO0?oDE03oe5D0om9F0?oDE@3odUH0omAE0?oBE03odUH0omEK
0?oDH@3oef020?oEH0080?oDE`3oe5D0omAE0?oCE@3odUH0omIO0?oGI03oeF<20?oDI080omAE00P0
om5G0?oDE`3oe5L0omEF0?oDE@3odUP0om5E0?oCEP80om9H0P3oe5L30?oDE@050?oBEP3oe5D0omAE
0?oDE@3odeL00`3oe5L01@3oeEH0omAE0?oDE@3odUH0omEP0080omAQ00L0omEP0?oFH03oeUl0omIY
0?oBEP3odUP0om9F0080om9D00@0omAE0?oBE03oeEP0omIU0P3oe6@01P3oe680omAT0?oDI03oe680
omEH0?oBE080omAE103oe5L01@3odUH0omAE0?oDE@3odUH0omAE0080omEF00P0ole@0?o7BP3o`D<0
ol940?o9C03oce<0omIJ0?oEF4<0omAG00<0om=G0?oDE@3oe5D01@3oe5D00`3odeH0omAE0?oDE@07
0?oDE@T0omAG203oe5D00`3odUH0omAP0?oDH@060?oDH@050?oFH03oe640om=M0?oCG03oe6800`3o
e6400`3oeEh0omAE0?oDE@060?oDE@030?oAE@3oe5D0omAE00@0omAE00T0omEF0?oAE03oaDX0ol14
0?o1A@3o_d<0ok900?na@03o^d@01`3o_DD00`3o_TL0ok]50?o3AP070?o5B0030?o9B@3oa4L0olA7
00@0olA700@0olE70?o4A`3oaDL0olI7103oaDL00`3oa4L0olE70?o5A`080?o5A`80olA700P0olM9
0?o;BP3olEP0onaG0?oYEP3okEH0onMH0?oFWb40oooo00D0bkBf0000000000000000081aM@0?0?oo
o`050?7>d@000000000000000020P8002@3oool3000000040>:LXP3oool0oooo0?ooo`<0000000<0
P61S0?ooo`3oool0103oool0103o_lH000000000000000060?ooo`040?noaP0000000000000000@0
oooo00@0oko600000000000000002@3oool3000000040?o@f03oool0oooo0?ooo`<0000000<0P61S
0?ooo`3oool01@3oool01020H6<000000000000000050?ooo`040?noaP0000000000000000H0oooo
00@0o:fd00000000000000003`3oool3000000030?noaP3oool0oooo01T0oooo00@0OUMJ00000000
00003@T90`3oool0101aCU40000000000000000<0?ooo`050?oOh`000000000000000020P8000`3o
ool0101nEeX0000000000000000?0?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH00000
0000000000030?ooo`050?7>d@000000000000000020P8002`3oool01@3ne]X00000000000000000
P82007`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWjP3o
ool00`3oh]`0P3lC08e98P02091;8P0409A?8`2FCB<0ohHk0?niDAL0okE>00<0okE?0?neCP3o]Dh0
2@3o]Dh00`3o]Tl0okI@0?nfD0060?nfD0030?nhEP3o^e`0ok]K02/0ok]K00<0ok]J0?nmGP3o^eX0
3`3o^e/;0?nkFPD0ok]K00P0ok]J0?njF@3o^UT0okYI0?njF03o^eX0ol5U0?o2JPP0ol5Y00<0ol1U
0?njF@3o^UT0103o^UT40?nkFP030?nlF`3o_V80okiR00<0okiR00<0okeR0?nnHP3o_V800P3o_V80
0`3o_F80ok]K0?nkFP030?nkFPH0ok]K2P3o^eX30?nkF`0<0?nnG`3o_F00okaI0?nnH@3o^ET0oj]:
0?nXB03oYdL0oj];0?neE@3o^UX0okaL5@3o^e/60?nkFP<0ok]K00X0ok]J0?njF@3o^UT0okeQ0?o2
JP3o`FT0ol1X0?o0J@3o`FT0okiS0`3o^UT30?nkFP80okiR0P3o_F400`3o_V80okeP0?nkFP020?nk
FP<0ok]K1@3o^eX0103o_5T0ok]J0?nkFP3o^eX20?nkF`080?nkFP3o^UT0okaM0?o0J03o`FT0okiS
0?noH`3o^UP20?njF@060?nlF`3o_V80okiR0?nmH@3o_V80ok]K0`3o^eX20?nlF@070?nkFP3o^UL0
okiR0?o1JP3o`FT0okmT0?njF0020?njF@0C0?nmH@3o_F00okiP0?nlG03o/e80ojA40?n]D`3o_fL0
okiP0?njF@3o^eX0okaM0?nnHP3o^e/0okaI0?o1J@3o_V<0okUF0?nlF@020?nmH00o0?noI03o`6T0
okUG0?nkFP3o`6D0ol9Z0?nmH03o^eX0okmR0?o2J@3o_E`0ok]L0?o0I@3o^UX0okaM0?nnH@3o_Ed0
ol1V0?nlE`3o_640ZE/]03dQ4@0000001P<10:9M:03oY4/0oliH0?oEH03ocf00oliH0?o@E`1hAQh0
00000=64=`3olV@0onUU0?oVF@3oiE@0onAA0?oUF@3oied0onIQ0?oXH03oiU/0onAE0?oZG`3omF80
om9B0;Ad:`0G3@D0000001PC1`25J2T0om==0?ooJ03onE`0oomZ0?ooGP3oj5H0m/I?0;bG=P1gGR@0
<bLB00<0000001l05`d8050_4`2VHbL0n9=00?o1F@3ogV00omME0?oAE03oeUh0omEQ0?oBF03oe5h0
omEM0?oCE@3odU@0omIO0?oFI@3oeUX0om9F0?oFG03oeEd0omEL0?oDE@3odED0omEC0?oEI03oe6@0
om=L0?oBDP3oe5H0omEF0080omAE00h0omAL0?oDGP3oe5h0omEM0?oCE`3odU@0om5E0?oEF`3oeVH0
omEU0?oEHP3odUH0omEE0?oBEP<0omAE00P0omEF0?oDE`3odUP0om9F0?oDE`3oe5`0omIO0?oEGP80
omAN0P3odUH02`3oe5D0om5E0?oBE03oeF40omEU0?oEH`3oeFD0omAL0?oBE03odED0om9F0080omAG
103odUH:0?oDE`070?oBEP3oe5D0om9D0?oEEP3oe5d0om9D0?oCG0040?oDE`<0om9F00T0om9H0?oF
G`3oe5h0omAN0?oEG@3oe5h0omAO0?oEG@3odUP00P3odUH30?oAE@060?oBE@3odUP0omES0?oEIP3o
eFD0omET0P3oeFD02P3oeVD0omAK0?oBDP3obT`0ol=40?o2A03o`TD0olU<0?oBEP3oeEH60?oBEP03
0?oCE`3oe5L0omAG05d0omAG00<0omAF0?oBEP3odUH01`3odUH00`3oeEH0omAE0?oCE@030?oBEP03
0?oCE`3oe5L0omAG00H0omAG1`3odUH01P3odU@0olY90?o4AP3o`DH0olA60?o4A`80ok]200<0oki5
0?o0AP3o`4H01@3o`4H00`3o`DL0ol160?o4A`070?o5A`030?o6B@3oadT0olI900@0olI90P3oadT0
0`3o_dH0ok]50?nmA0020?nkA@040?nmA@3o_TH0ok]50?nlA@80ok]500<0oke50?nkA@3o^dD00P3o
^dD01P3o_TD0olI90?o6B@3obDT0olm<0?obF080onYF00<0onaF0?oUH`3on_P08@3oool01@2ITI80
0000000000000000YIZK00l0oooo00D0i<G800000000000000000820P0090?ooo`<0000000@0bH^@
0?ooo`3oool0oooo0`0000000`20H6<0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo
00@0oko60000000000000000103oool0103o_lH000000000000000090?ooo`<0000000@0oko60?oo
o`3oool0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000000000D0oooo00@0
oko600000000000000001P3oool01039Ri00000000000000000;0?noaP040?oco03oool0oooo0?oo
o`<0000000<0oko60?ooo`3oool0603oool01@3onOh00000000000000000<b<T00<0oooo00@0IDI8
0000000000000000303oool01@3ogn<00000000000000000P82000<0oooo00@0IDI8000000000000
00002`3o_lH0103olo`0oooo0?ooo`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000
0000000000000`3oool01@3TaLP00000000000000000P82000/0oooo00D0i<G80000000000000000
081PH`0;0?noaP030?oioP3oool0oooo06h0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWjP3oool02@3ok>T0/64h08Y77@2>BR80TD/R095;8`26AAl0dfd`0?nj
D@070?neCP030?neC`3o]Dh0okE>00d0okE>00<0okE?0?neCP3o]Dh0203o]Dh00`3o]U00okI?0?nf
D0080?nfD0030?niE03o_5`0ok]K02/0ok]K00<0okaL0?njF03o_5`0203o^e/00`3o^eX0okYH0?nj
F0020?njF0030?nkFP3o`F`0ol9Z00<0ol9Z00<0ol5Y0?o2JP3o`VX00P3o`VX00`3o`F`0ok]J0?nj
F0030?njF0D0ok]J00<0ok]K0?nlGP3o_6000`3o_6000`3o_5l0okaP0?nlH0020?nlH0030?nmG@3o
^eX0ok]J00<0ok]J1P3o^e/;0?nkFQD0ok]K00<0ok]H0?nnGP3o`FD00P3o_5`00`3o^e/0okEF0?n/
C0020?nWA`030?n/C03o^5P0okaL01@0ok]K00H0okYI0?njF03o^eP0okmT0?o2J`3o`FT20?o2JP05
0?o2J`3o_5h0okYH0?njF03o^UT00P3o^eX0103o_5`0okaP0?nlH03o_5h20?nlH0040?nlGP3o^eX0
ok]J0?nkFP<0ok]K1@3o^eX:0?nkF`0?0?njF@3o^UP0okiR0?o2J`3o`FT0ol9Z0?nmH03o^UP0okYI
0?nkFP3o_5`0okaP0?nlGP3o_Ed0okiQ0080ok]J0P3o^e/40?nkFP030?njF@3o^UP0okiP0080ol9Z
00@0okeQ0?niE`3o^eX0okaM0P3o_600;@3o_5h0ok]J0?nkF`3o^e/0okaK0?o1J@3o`6P0okiS0?n]
C03oZDT0okIH0?nmH03o_5d0okYH0?nmH@3o`V/0okeO0?nkF03o^e/0okeN0?nlG03o_V00ol9[0?nm
H@3o^UT0okeM0?nmH@3o`FL0okaM0?nkFP3o^e/0okmU0?nnH@3o^eX0okiS0?o0J03o^eX0ol5X0?nm
GP3o^UL0okiP0?nlF`3oaFL0ojeD06Th70020000000/00`70`3?Pc/0olUG0?oHIP3oceP0olmN0?o>
G03od5P0ojm?01<;1P1/@aT0omiB0?o^FP3oiEL0onAE0?oVGP3oif40onMT0?oUF`3oiEL0onEF0?oV
G@3oiUL0onEH0?oVGP3okU/0on=F0?o8D@2dLRX02`L30000000R70/0OVDX0?oUE`3oled0oo5H0?oe
H@3onel0ooQO0?oXH03oee00gK1207EM:@0W7P`30000000P01@=1P0/60d0ODPN0?nFAP3oaeX0omYK
0?oFF`3odUH0om=E0?oDHP3oeEl0om9D0?oDFP3oe5`0omAI0?oAE@3oeEH0omEV0?oEHP3oeE80om9F
0?oEEP3oeE/0omAL0?oDFP3odUH0om9E0?oEI03oefH0omEW0?oCF03oe5D20?oEEP040?oDE`3oeEH0
omEF0?oBF080omAL00d0omEK0?oDE`3oe5D0om9D0?oFG03oeFL0omMV0?oDHP3odUH0om9D0?oCE`3o
e5L0omEF0080om9F0P3oeEH20?oDE`80omEF0180om9F0?oEFP3oe5`0omEK0?oDG03oe5T0om9D0?oD
E`3odED0om9D0?oEF`3oeFL0omMV0?oFIP3oeFL0omIL0?oBE03odUD70?oDE`070?oCE`3oe600om=M
0?oBE03oe5X0omAG0?oEEP080?oDE`030?oBEP3oeEH0omEF00@0omEF103oe5L20?oEEP030?oDEP3o
e5L0omEK0080omAL00@0omEK0?oDG03oe5`0omEL0P3oe5L02P3odUH0oliB0?o7B03oa4@0ol=40?o7
B@3odF00omEW0?oGIP3oeVH30?oGIP050?oFHP3odU@0om9D0?oBE03odUD0J03oe5L00`3odUH0omAG
0?oDE`0@0?oDE`030?o;C@3oadH0olE70080olE700@0olI70?o4A03oa4@0olA61`3oa4L00`3oaTL0
olA70?o7B@070?o4A`030?o7B@3oaDL0olI900<0olA700H0olI70?o5A`3oaDL0ol=70?o2AP3o`dH2
0?o2AP030?o1A`3oaTT0ol9600<0ol9600<0ol970?o2AP3o`TH00P3o`dH01`3o`dL0olA70?o4A`3o
a4L0omU>0?oVD`3ojED00P3okEH00`3odgl0oooo0?ooo`0P0?ooo`050820P000000000000000003H
_;l03`3oool01@3TaLP00000000000000000P82000T0oooo0`0000001039Ri00oooo0?ooo`3oool3
00000003081PH`3oool0oooo00@0oooo00@0oko600000000000000001P3oool0103o_lH000000000
000000040?ooo`040?noaP0000000000000000T0oooo0`000000103o_lH0oooo0?ooo`3oool30000
0003081PH`3oool0oooo00D0oooo00@0P61S00000000000000001@3oool0103o_lH0000000000000
00060?ooo`030<V;T0000000000000`0000000@0oko60?ooo`3oool0oooo0`0000000`3o_lH0oooo
0?ooo`0H0?ooo`050<^d]P00000000000000001H?Cl00`3oool0101UATP0000000000000000<0?oo
o`050?oOh`000000000000000020P8000`3oool00`1UATP000000000000<000000040?noaP3oool0
oooo0?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000030?ooo`050>C5
b0000000000000000020P8002`3oool00`3TaLP000000000000=000000030?oOh`3oool0oooo06h0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWjP3oool02P3o
oOd0mJjK08=15@29Aal0SDXS08m:8@2:B200/UdY0?n_C@3o]E040?neCP030?neC`3o]Dh0okE?00L0
okE>00<0okE?0?neCP3o]Dh01@3o]Dh20?neC`X0okE>00<0okI?0?nfD03o]U00203o]U000`3o^580
ok]I0?nlG@040?nlG@H0ok]K1@3o^eX00`3o_V<0okmT0?noI0020?noI080okmS103o_f@00`3o_5d0
ok]J0?nkFP080?nkFP030?nmG`3o_f<0okmS00@0okmS00D0okiR0?nmH03o_f@0okiQ0?nkF`050?nk
FPD0ok]K2`3o_5`l0?nkF`050?nlG03o^eT0okiQ0?nlG@3o_Uh00P3o_5d02P3o_5`0okIG0?n^C`3o
ZTX0ojU90?n/C03o/U40okIF0?njFP3o_5d20?noI0050?noH`3o_f@0okmT0?nnHP3o^e/0103o^eX0
0`3o^e/0okiR0?nnI0030?noH`040?noI03o_5`0ok]J0?nkFP<0ok]K1`3o_5`:0?nkF`060?nlF`3o
_5d0okaM0?nlGP3o_5`0ok]K0`3o^eX20?noH`040?noI03o_V80ok]K0?nkF@80ok]J00D0okiR0?nn
H`3o_f<0okmS0?nlG@020?nkFP030?nkF`3o_5`0okaL00H0okaL00H0ok]K0?nkF@3o^eX0okmT0?no
H`3o_F020?nkFP070?nlF`3o_f80okiR0?noH`3o_5`0ok]K0?nlG0020?nlG@0:0?nkF`3o_5`0okiQ
0?noH`3o^e/0ok]I0?nkFP3o_V40okmR0?nmG`80ok]K07D0okaK0?nnH`3o/E@0ojQ80?neE03o_V40
ol1T0?nmG@3o^eX0okeN0?o0I@3o_5`0okeL0?nnHP3o_f80okeN0?nmH03o^UT0okeM0?nnH@3o_El0
okmR0?nkF`3o_Eh0okeO0?nnH03o_5`0okiP0?nnH@3o^eX0okeO0?nnH03o_Ed0ol5S0?nnG`3]XE40
Re`]05H^5`0?20@0;AX<08QN:03;Td<0okmD0?o?G03oce/0oleK0?o>FP3ocU`0om5M0?b]C@1;;1@0
>B@>0?oCD@3okV80onMR0?oUF03oiEL0onQ[0?oWI03oiUP0onIL0?oVF`3oiUX0onMK0?oVF`3oiUT0
onEI0?oVFP3oied0onUJ0?oVG03Za4d0Rg0Z054c5@0C30D09al=08M_:@36[d@0on9F0?ocG03oleh0
oo9J0?odG`3om5h0oniH0?o/F@3oi5P0d[Y709J<=024KRh0HTdN02/R3P0A3@L040T402PG2P1/@A`0
P6@a0:9l<P3@Uch0ol5F0?o=EP3odeD0omQO0?oHGP3oe5H0omEG0?oFH@3oeE`0omEF0?oDEP3oe5`0
omIO0?oDFP3odUD0om9D0?oEGP3oeEl00P3odeP04@3oe5P0om=H0?oCF03oe5d0omEO0?oDF@3oe5D0
om9E0?oDFP3oe600omEP0?oDF03odeL0omAG0?oDF@3oeE/0omAJ00<0omAG00<0omAE0?oEFP3oeF00
0P3oeEh02@3odeL0om=F0?oBE@3oe5P0omIP0?oEG`3oeF00omAJ0?oDE@020?oCE`060?oDF03odeP0
omAJ0?oEF03oeEL0omAG0P3oe5T00`3oe5P0om=H0?oDE`020?oDE`0A0?oCEP3oe5D0omAL0?oEH03o
eV<0om=M0?oDF`3oe5L0omAF0?oCEP3oe5D0omEG0?oFG`3oeF00omEO0?oFH03ode`00P3odeH01@3o
e5L0omEG0?oDE`3odeT0omAI00<0omEI0P3oeEL20?oDE`D0omEG0P3oe5L20?oEE`040?oDE`3oeEL0
omEG0?oEE`@0omAG00X0om=F0?o@D`3obdh0olE70?o3A@3oaDX0olQ>0?oAEP3oe5T0omEI0P3oe5T4
0?oDE`<0om=F00<0omAI0?oEG`3oeEl01@3oeEl01@3oe5T0om=F0?oCEP3odeH0omAF00<0om=F00P0
omEN0?oEH03oeF00omEO0?oFH03oeF00omMP0?oCG@<0om=F00H0om=G0?oEE`3oeEL0omEG0?oEF03o
eEX20?oEF@050?oCF@3oeET0omEI0?oDF@3oe5L00`3oeEL40?oDE`L0omEG;P3oe5L0103oeEP0om=H
0?oBEP3odeL<0?oDE`040?oDF03oe5L0olmB0?o;C0H0olI700<0ol540?o2A03o`dH0403oa4L00`3o
adT0olA70?o4A`030?o4A`030?o5A`3oa4L0olA700<0olA700D0olI80?o5A`3oa4L0olA70?o7B@02
0?o4A`80olE70P3oa4L00`3oaDT0olI70?o5B@030?o4A`070?o6A`3ohE80onYF0?o/E`3oj5D0onUJ
0?ogk@0R0?ooo`05081PH`00000000000000003hemX03`3oool01@3[b/`00000000000000000P820
00T0oooo0`000000103FU9T0oooo0?ooo`3oool300000003081PH`3oool0oooo00@0oooo00@0oko6
00000000000000001P3oool0103o_lH000000000000000040?ooo`040?noaP0000000000000000T0
oooo0`000000103ob<l0oooo0?ooo`3oool300000003081PH`3oool0oooo00D0oooo00@0P61S0000
0000000000001@3oool0103o_lH000000000000000060?ooo`030<V;T0000000000000`0000000@0
oko60?ooo`3oool0oooo0`0000000`3o_lH0oooo0?ooo`0F0?ooo`030?oioP3;];H09QXK00<00000
00D0YY:F0?ooo`3oool0oooo079>D@03000000`0oooo00D0omoS00000000000000000820P0030?oo
o`0306E6B0000000000000`0000000@0oko60?ooo`3oool0oooo0`0000000`3o_lH0oooo0?ooo`04
0?ooo`040?noaP0000000000000000<0oooo00D0lLkA00000000000000000820P00;0?ooo`030>C5
b0000000000000d0000000<0omoS0?ooo`3oool0KP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`00
1`3oool0103YjNT0dM7A0=7Ad@3WinO[0?ooo`080?oFb`2mKDT0PD4H091:8P2=BB00SDXP08Q77`3l
XDL;0?neCP030?neC`3o]Dh0okE>00X0okE>00<0okE@0?neCP3o]Dh0203o]Dh00`3o]Tl0okI@0?nf
D0040?nfD0030?neCP3o]E00okEA0080okE@00L0okMC0?o0IP3o`V/0ol9Z0?o2J`3o`FL0okeJ00D0
okYI1@3o^e/;0?nkFQ@0ok]K00<0ok]J0?nmG@3o^e/0?P3o^e/50?nkFP<0ok]K0`3o^eX00`3o_5h0
okeR0?nmH@020?nmH@0?0?nlGP3o_Ed0okYG0?nnHP3o^eP0okYG0?njF03o_El0ol9[0?nnIP3o/EP0
oia30?nK@`3oYDP0okAD0080okYI0`3o^e/60?nkFQ<0ok]K103o^eX20?nkF`030?nkFP3o^e/0okeP
0080okeR00<0okeP0?nkF`3o^eX00P3o^UT01`3o_F40ol9Z0?o0J03o`V/0okeQ0?njF03o^eX00P3o
^e/40?nkFP@0ok]K0`3o^eX30?nkF`040?nmH03o_F40okeQ0?nkF`80okYI00D0okmS0?o1J@3o`VT0
okmS0?njF@020?nkF`060?nkFP3o^UT0okaI0?nmH03o_5`0okeK0P3o_F401`3o_5`0okYI0?nlH@3o
`FL0ol9Z0?nlGP3o_5T00P3o^eX0E@3o_5X0okeN0?nmH@3o_F40okYI0?nmGP3o`V/0ol5W0?nkF@3o
_5`0okEC0?nVAP3o[Dl0ok]J0?nmFP3o`6@0okmQ0?nkFP3o_F00okeN0?nkFP3o`6D0ol1V0?njF@3o
_Ed0ok]J0?nkF`3o`6H0okeO0?nmG@3o^UT0okiR0?nnH03o_Ed0ok]H0?o0I@3o_Eh0okYG0?o1I`3o
_Uh0ol9P0?nkH@3oVdX0^V@c00d710000000;Q/=091C903oa5T0om5N0?o>G03ocET0oliM0?o>G03o
cE`0oleJ0?o?G@3o`5D0;Q/=0000002/S3P0onaP0?oUEP3oiUh0onIL0?oUF03oj6H0onEA0?oWG@3o
iUP0onIG0?oWG`3oiEX0onEK0?oTFP3oiE/0onEI0?oUEP3oiEP0onAE0?oWF`3oiU`0ooEP0?oBD@1]
AQ/00P0000002@0>2`@0aihl0?oaF`3ooVD0oo=I0?o`F@3olV80oo1E0?oaF`020?oaGP080?obE`3o
mUl0ooYR0?o<D@2iU3<0M5`U03DY4@0<2@<30000000H05<a502VHBH0oiI30?niE03od5D0on5N0?oN
H@3ofEX0om9D0?oCG03oeF<0omAK0?oBEP3oe5X0omAN0?oDF03odUH0omEF0?oDE@3oe5`0omEU0?oF
H@3odED0om=F0P3oeEd02`3oeE/0omEG0?oBEP3oe5D0om9F0?oDEP3oe5D0omES0?oEI@3oe680om9B
0080om9F0P3oeEd0103oe5X0omAE0?oDE`3oeEH20?oBEP090?oDE`3oeEH0omEF0?oEEP3oeEL0omAG
0?oAE@3odU@0omAP0080omEU00l0omEM0?oBEP3odUH0om9F0?oDFP3oeEh0omEM0?oBF`3odUH0omAJ
0?oDE@3oe5h0om=O0?oDE@3odUH01`3oe5L40?oEEP<0omAG00X0om9F0?oBE03odeL0omET0?oEIP3o
eFD0omEV0?oEI@3odUD0om5E0P3odUH01P3oe5T0omAN0?oEG@3oeEd0omEN0?oEF080om9F0`3oe5L4
0?oBEPD0omAG00T0om=G0?o:C@3o`dH0ol530?o2A03ob4l0om5D0?oBF03oeEP05`3oe5L00`3oeEL0
omEF0?oEEP050?oEEP<0omAG103odED02@3oe5h0omEW0?oEIP3oeFH0omES0?oEIP3oeFL0omIQ0?oD
E@020?oAE@050?oBE03odUH0om9F0?oBEP3oe5X01@3oeEd00`3oeEh0omEM0?oDE`030?oBEP@0omAG
1`3odUHQ0?oDE`030?oCF@3oe5L0om=G00/0omAG00<0om=F0?o9B`3oaTL01`3oaTL00`3o`D@0ol94
0?o5AP050?o4A`030?o5A`3oa4L0olA70080olA700<0olE70?o4A`3oa4L00`3oa4L01P3oadT0olA7
0?o4A`3oaDL0olA70?o5A`X0olA700<0olE70?o4A`3oaDL0103oa4L00`3oaDT0olI70?o5B@030?o4
A`060?o9B@3okUL0onaG0?oZEP3okUL0onF98`3oool01@1UATP00000000000000000oo3e00l0oooo
00D0omoS0000000000000000081aM@080?ooo`050?oQjP00000000000000003o_lH00`3oool30000
0003081PH`3oool0oooo00@0oooo00@0oko600000000000000001P3oool0103o_lH0000000000000
00040?ooo`050?noaP00000000000000003olo`01`3oool0103ohNX000000000000000040?ooo`<0
000000<0P61S0?ooo`3oool01@3oool01020H6<000000000000000050?ooo`040?noaP0000000000
000000H0oooo00@0oko60000000000000000203oool3000000040?noaP3oool0oooo0?ooo`<00000
00<0o:fd0?ooo`3oool05@3oool00`3o_lH0<R<T000000030000000301TA4P3onOh0oooo0080oooo
00D0P61S00000000000000000?oOh`0;0?ooo`050?oOh`000000000000000020P8000`3oool01020
H6<000000000000000080?ooo`<0000000@0oko60?ooo`3oool0oooo0`0000000`3o_lH0oooo0?oo
o`040?ooo`040?noaP0000000000000000<0oooo00D0omoS0000000000000000081PH`0;0?ooo`05
0?oOh`000000000000000020P8001`3oool01@20P8000000000000000000omoS0700oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWk03oool00`3gVX@0OSdA08i9
8@0208]8800307Xo6`3/UT80okI@00@0okE>00<0okE@0?neCP3o]Dh00`3o]Dh00`3o]Dl0okE>0?ne
CP050?neCP030?nfC`3o]Dh0okE>00d0okE>00<0okI?0?nfD03o]U002@3o]U001P3o]Tl0okE@0?nj
E@3o^eX0okaJ0?nkFR/0ok]K00<0okaM0?nlH03o^eX0<@3o^e/20?nlF@040?nkFP3o_5X0okaI0?nk
FP80ok]K0`3o^eX02@3o_Eh0okmT0?noI03o_V80okmT0?noI@3o_5h0okYI0?nkFP020?njF@0E0?nj
F03o_F00ol1X0?o0J03o_fD0ol=/0?nnHP3o_V00ok]H0?njF03o^eX0ok]K0?nlG03o^ET0ok5?0?nX
A`3oYDD0oj]:0?nbDP3o_5/0okaL01D0ok]K00@0ok]J0?nlF@3o^eX0okaI0`3o^e/0403o^UT0okaN
0?noI@3o_V<0okmT0?nmH@3o^UT0ok]J0?njF03o^eX0ol1V0?o0J03o`6T0ol1V0?nkFP3o^eT20?nk
F`<0ok]J00<0okaI0?nkFP3o^e/0103o^e/00`3o^eX0okaI0?nlF@020?nkF`0=0?nkFP3o^e/0okiS
0?noI03o_F40ok]J0?njF@3o^eX0ol1V0?o0J03o`6L0ok]J0?njF@020?nkF`030?nkFP3o^UT0okYI
0080ok]K01@0ok]J0?nkF`3o_f@0okeQ0?nlF@3o^eX0okaM0?o0IP3o`6P0okeM0?nkFP3o_5T0ok]H
0?nkFP3o^e/0okiR0?noI03o_600okYI0?nmHP80ol1W0140ok]I0?nkFP3o_5T0okaI0?noH`3o^eX0
oja;0?nUA@3o/EP0ok]H0?njF@3o_Eh0okeO0?njFP3o`6H0okiR0?nkF@020?nmGP0L0?nkFP3o_V40
okaK0?nmGP3o_F00ok]K0?nnH@3o_Ed0okaN0?nlG@3o_V<0okaM0?njF@3o_F00okeQ0?nlF@3obFL0
ojMB09MA:P091@@0000001X@202KF2D0oj]=0?oLH@3oce/0oliO0?o=FP80oliM02T0oleL0?o>G03o
c5P0om5K09YI:@0000003PT20?o@D03oiUd0onIL0?oUD@3oiV40onAG0?oXIP3oiE@0onMN0?oUE`3o
iel0onEF0?oVFP3oiU/0onIJ0?oUF03oiUP0onEG0?oVF03oiUT0onIK0?oUF`3oiEP0onUJ0?oSFP2]
KBP0@2TB000000091`<0SG0/0>nmA@3omed0ooQO0?o`F@020?oaG00=0?oaFP3ol5d0oo1G0?oaHP3o
lEP0ooIQ0?olG03oof@0o=iF0;ZD>P2=Kbl0G4PJ020I2@030000000A038M2`2VGbP0jHTh0?nXD03o
c5H0on=P0?oRH`3ogEl0omAG0?oBE03oeUX0omIU0?oDF`3odED0om=L0?oFG`3odeP00`3oe5D05P3o
e5H0omES0?oEH`3oeUh0om5E0?oEF03oeUl0omMP0?oCE`3oe5L0omAE0?oBE03oeED0om9H0?oBEP3o
eE@0omES0?oDI03ode`0om=C0?oCEP3oe5h20?oFG`050?oDF03oe5L0omAG0?oBEP3oe5D00`3oe5L0
4P3oe5H0om9F0?oBEP3odUH0om=K0?oAE@3oe5D0omEM0?oDH`3oe6L0omES0?oBE03oe5/0om=C0?oB
F`3oeF00omIP0?oDG080om9F00D0omAG0?oEEP3oe5D0om9F0?oEEP0:0?oDE`030?oBEP3odeH0om9F
0080om9F0P3oe5L02P3odUH0omAE0?oDFP3oe6D0omAT0?oEH`3oe6D0om=K0?oBE03oe5D20?oBEP06
0?oDFP3oef00omIP0?oFG`3oef00omAJ0P3odUH20?oDE`0:0?oEE`3odeL0om9C0?o:B`3o`T@0okm3
0?o0AP3obDl0omAG0?oEF2D0omAG00<0omEF0?oCEP3odUH00`3odUH00`3oe5D0om9F0?oDE`020?oD
E`050?oAE`3oe5D0omAE0?oBE03odU`00`3oe6@0403oeF<0omAT0?oDI@3oeF<0om=G0?oEE03oe5D0
omED0?oAE@3odUH0om=F0?oDFP3oeUl0omEP0?oFH03oeUl30?oEH0040?oEEP3odUH0om9F0?oBEP@0
omAG0`3oe5D01@3odeH0om9F0?oDE@3oe5D0om=G0180omAG00<0om=I0?oBE`3oe5L02P3oe5L00`3o
cTd0olI70?o6A`070?o6A`030?o4A03o`T@0olE800@0olA700<0olE70?o4A`3oa4L00`3oa4L00`3o
aDT0olA70?o4A`030?o4A`030?o7B@3oa4L0olA70080olE9203oa4L00`3oaTL0olA70?o4A`070?o4
A`030?o5B@3oaTL0olE900<0olA700H0om=<0?o[E`3ok5L0onYG0?o/D03ojkTS0?ooo`0406E6B000
0000000000000100oooo00D0oo3e0000000000000000081PH`080?ooo`050?noaP00000000000000
003ohNX00`3oool300000003081PH`3oool0oooo00@0oooo00@0oko600000000000000001P3oool0
103o_lH000000000000000040?ooo`050?noaP00000000000000003o_lH01`3oool0103o_lH00000
0000000000040?ooo`<0000000<0P61S0?ooo`3oool01@3oool01020H6<000000000000000050?oo
o`040?noaP0000000000000000H0oooo00@0oko60000000000000000203oool3000000@0oooo0`00
00000`39Ri00oooo0?ooo`0D0?ooo`030=Rf_@000000000000<0000000<06A4B0?o@f03oool00`3o
ool01@20P8000000000000000000lLkA00/0oooo00D0omoS00000000000000000820P0030?ooo`04
081PH`0000000000000000P0oooo0`0000040?ooo`<0000000<0oko60?ooo`3oool0103oool0103o
_lH000000000000000040?ooo`<0000000<0LDiA0?ooo`3oool02@3oool01@3ogn<0000000000000
0000P82000L0oooo00@0P8200000000000000000L@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`00
1`3oool0103YjNT0dM7A0=7Ad@3WinO/0?ooo`080?o9^@2LE2T0RdPP08i:8P2;B200PT@N0=V1>@3o
^E830?ndCP80okE@00@0okA>0?neD03o]4h0okA>1@3o]Dh01@3o]Dl0okE>0?neCP3o]Dh0okE?00L0
okE>00<0okE?0?neCP3o]Dh01@3o]Dh00`3o]Tl0okI@0?nfD00<0?nfD0030?nhEP3o^e/0ok]K02/0
ok]K00@0ok]J0?nnGP3o_5d0okaK903o^e/50?nlF@040?nkFP3o^e/0ok]K0?nkFP80okYI00L0okeO
0?o0IP3o`6H0okmV0?o0IP3o_fL0okeP00D0okYI00T0okeO0?noI`3o`6H0ol1T0?o0IP3o`6L0okeP
0?nkF03o^UT00`3o^e/01@3o^eX0okeQ0?nmGP3o^EL0okeO0080ok]J0P3o^e/20?nlG0070?nhF03o
[Dd0ojI60?nWA`3oZd`0okIF0?nmG00?0?nkF`<0okaI00<0okaJ0?nkF`3o^e/00P3o^eX01@3o_V<0
okmW0?noIP3o_fL0ok]J0080okYI00<0ok]H0?nmH03o`6L00P3o`6H00`3o_V80okYI0?nkFP020?nk
F`040?nkFP3o_5X0okaI0?nkFPP0ok]K00<0ok]J0?nlF@3o_5T00P3o^e/01@3o^eX0okiS0?o0IP3o
`6H0okiO0080okYI00@0ok]J0?noI@3o`6H0okiS0P3o^eX00`3o^e/0ok]J0?nlF@030?nkFP060?nl
F@3o^e/0okYH0?nmGP3o_fL0okmS0P3o^UT01@3o^eX0ol1W0?nnHP3o_5T0ok]J0080ok]K00D0okaI
0?nkF`3o_5`0okmU0?noI`020?nkFP0D0?nnH`3o_fL0okeQ0?nkF@3o^eP0ok]J0?nkF03o_f80okeQ
0?njE`3o^eX0ol1U0?n`D03oZDP0oj]:0?nlH@3o^e`0okUG0?nmHP3o_El20?nkFP0<0?o0I03o_5X0
okeQ0?nmH@3o^UT0okeP0?njF@3o_V00okeQ0?nmG`3o^UX0okeM0P3o_F00203o_5T0okaQ0?nlG03o
_E`0olQX0?o2G`3oRT<0CRXF0P0000008P0b7Ph0eHDl0?oLHP3oe5T0oliO0?o>G@3ocEX0oliN0?o=
F@3ocU/0oliJ0?o>F03ocET0o[E=00`70`000000YVT/0?o]G@3oiEP0onEK0?oUE`3oiV40onEG0?oW
J03oiEP0onEI0?oVG@3oieX0onML0?oVF`3oiE/0onII0?oUEP3oiEL20?oVF00Q0?oVFP3oiE/0onII
0?oVF03oiE/0onYK0?oiH03oaTd0_WP/01lD2000000061@508AW:`3bfU80ooaN0?obG@3ol5T0oo5L
0?o`GP3ol5T0oo1L0?oaFP3olF00oo5J0?o`FP3omUd0oomP0?ooJ03om5P0ikM809]j;`1ZEAh0<bX>
00<0000002<06Ph407U67@34Lc00oiQ70?nlE@3ohE/0on9T0?oHH@3odeD0om=F0?oBE03oeEd0omAQ
0?oBF@3odUH0omIO0?oEH`3oe5L0om9F0?oBE03oe5D0omAF0?oCF@3oe640omES0?oCEP3odUH0omEM
0?oDHP3oe5`0omAE0?oBF03oeEH0om9D0?oBEP020?oDE`0=0?oCEP3oeF00omAR0?oDHP3odeP0om5E
0?oBEP3oeUl0omAR0?oCF@3oe5D0omAG0?oCE`020?oDE@0F0?oDE`3oe5T0om9I0?oDE@3oeEP0omAK
0?oBF03oeU`0omAG0?oCEP3odUH0om=M0?oEH`3oe680omEM0?oBEP3oe5D0om=E0?oEG@3oeF<0omAQ
0?oEH080omAE00H0omAG0?oEE`3oe5D0om9F0?oDE@3oeEL;0?oDE`050?oCE`3oe5D0omAE0?oBEP3o
e5D00`3oe5L0103odeH0omAE0?oEF`3oeF<20?oDHP0<0?oEH`3odeT0omAE0?oAE@3oe5D0om5E0?oE
G@3oe6<0omAR0?oFI03od5/0ol940P3o`4<0103ob4/0om5D0?oEF@3odeL20?oDE@030?oBEP3oe5L0
omAG02h0omAG0`3oe5D0103odUH0omAE0?oDE@3odUH40?oDE`80omAE00<0om=E0?oCF@3oe6800P3o
e6801@3oe640omAR0?oDHP3oe6<0om9F00<0omAE00@0om5E0?oDE@3oe5D0omAE1`3oe6801@3oeEl0
omAE0?oDE@3oe5D0omAF00<0omAG00D0om=G0?oDE@3oe5D0omAE0?oCEP030?oDE@060?oEE`3oe5L0
omAG0?oDE`3oe5P0omAE1`3oe5L0103odUP0om=F0?o=C`3ob4L90?o6A`030?o5A@3o`T@0ol=500<0
olA700<0olE70?o4A`3oa4L03@3oa4L20?o5A`@0olA700D0olE90?o4A`3oa4L0olA70?o7B@040?o4
A`030?o5A`3oa4L0olA70080olA700<0olE70?o5B@3oaDT00P3oa4L01`3ob4L0onQD0?oZEP3okEH0
onUF0?oLA`3omnT08`3oool0101UATP0000000000000000A0?ooo`0401TA4P000000000006E6B0P0
oooo00@0bH^@0000000000003@T9103oool300000003081PH`3oool0oooo00@0oooo00@0oko60000
0000000000001P3oool0103o_lH000000000000000040?ooo`050?noaP000000000000000039Ri00
1`3oool01039Ri0000000000000c8b@40?ooo`<0000000<0P61S0?ooo`3oool01@3oool01020H6<0
00000000000000050?ooo`040?noaP0000000000000000L0oooo0`0000000`3od=P0oooo0?ooo`04
0?ooo`040?o@f00000000000000000@0oooo0`0000000`1nEeX0oooo0?ooo`0C0?ooo`030?o@f00I
4Q80000000<0000000<06A4B0?o@f03oool0103oool01@2UVY/00000000000000000bkBf00/0oooo
00D0omoS00000000000000000820P0030?ooo`050820P000000000000000003oj>`01P3oool0103o
d=P000000000000000040?ooo`<0000000<0hYbR0?ooo`3oool0103oool0103o_lH0000000000000
00040?ooo`0404/d=P000000000004`d=P`0oooo0`0000000`20J6`0oooo0?ooo`050?ooo`04081X
K0000000000000000740oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWk03oool02@3on?L0g8M[08Q5702>BR40SDXR08]87`2kI2d0okaC0?nfC`090?neCP030?ne
C`3o]Dh0okE>00D0okE>00D0okE?0?neCP3o]Dh0okE>0?neC`030?neCP030?neC`3o]Dh0okE>00D0
okE>00<0okI?0?nfD03o]U003@3o]U000`3o^ED0ok]K0?nkF`0/0?nkF`030?nlG03o_5d0okaN01<0
ok]K0`3o^eX0103o_5d0okmR0?noHP3o_V420?noHP030?nlGP3o^eX0ok]J00<0ok]J00@0okeN0?o0
IP3o_fD0okmT0P3o_fD0103o_El0ok]J0?nkFP3o^eX20?nkF`030?nmG@3o_El0okeO0080okeO00<0
okiO0?nlG@3o^e/01@3o^e/20?nlFP030?nkF`3o_5X0okaJ0080ok]K00L0okaL0?nnH03o^eX0okiO
0?nmG@3o_5h0okaM00@0ok]K00X0okaL0?niF@3o/U80oja<0?nYB@3oZTX0ok9B0?ngF03o^e/0okaL
1@3o^e/20?nkFP050?nmG@3o_f80okiQ0?noHP3o_El00`3o^eX01@3o_5`0okmV0?noI03o_f@0okmS
00<0ok]J00D0ok]K0?nlGP3o_Ul0okeO0?nnG`050?nkF`030?nlFP3o^e/0okaJ00T0ok]K00/0ok]J
0?nmG@3o_V80okiR0?noHP3o^eX0okYI0?nlFP3o_V40okmT0?noIP020?nkFP050?nkF`3o_Eh0okeO
0?nmG`3o_5d00`3o^e/20?nlFP80ok]J00D0okeO0?nnHP3o_F00okYI0?nkFP030?noI0060?nlF`3o
^eX0okaL0?nnG`3o_Eh0ok]J0P3o^e/04P3o_Ed0okmQ0?nmG`3o^eX0okaL0?noI03o_Eh0okaN0?nk
F`3o_Eh0okeO0?nkF`3o_5`0okiQ0?nlG@3o^UP0okeP0?o0IP80ok]J0140okeN0?nmH@3o_V00okaL
0?nfE@3oXTH0ojU90?nfEP3o_El0okiP0?nlG03o^UP0okiR0?nkF@3o^e/0okmS0?nlF`020?nmH00U
0?nkFP3o_F00ok]K0?nmH03o_5`0okeO0?nkFP3o_f80okaL0?nmG`3o_5`0okmO0?o0H03KU4X0SddU
03lR4P0>20@0@2DA09AR:`3LWD@0ol5H0?oCG@3ocel0oleI0?o>F@3ocUd0oleJ0?o=F@3ocEP0oleI
0?o=F`3ocUh0omMQ07iF9`030P40VV@Y0?oUF0020?oVF`1>0?oWG`3oie`0onEH0?oUF03oiV40onMN
0?oWG`3oiU`0onIK0?oVFP3oiU/0onIJ0?oVF@3oiET0onEJ0?oVF03oiEL0onML0?oVF`3oiET0onIF
0?oWG03oiUP0onIL0?o[G03okUd0l/Y>09Yg;P1ZA1`05`h602HN3026JRL0]JY00?SLD`3omEd0oo5M
0?o`F@3olEd0oo5J0?oaG`3olEP0oo5L0?oaF`3olE`0oo5M0?obF03omf00ooQK0?o_FP3ohe/0h<Y<
0;JN?@2FNS40Le`Q04Tk5@0K5@P03@P202HF2@1>;A<0SUDV09me<`2cT3/0kK1;0?oBH@3ofUP0omQF
0?oEG03oe5P0omAI0?oDF`3odeL0omAE0?oEH03oe5l0om=F0?oFF03oeE`0omAL0P3odeL0303oe5T0
omEK0?oEF@3odeH0omAD0?oDH03oeV00omAD0?oBEP3odeP0omIM0?oDF@80om9F01H0omEG0?oDEP3o
eEL0omEJ0?oDF`3oeEP0om=G0?oBE@3oe5/0omEQ0?oFH03oeU`0om=G0?oEG03odUH0om9H0?oFH03o
e5X0om=F0?oCE`3oe5L0omEG0P3oeEH02@3oe5L0omEG0?oDE`3oe5L0om=G0?oDF@3ode`0omAK0?oE
FP020?oCE`0C0?oBE@3oeEX0omAR0?oEH03oeF40om=J0?oDE@3odUD0om=F0?oEG@3oe5d0omEN0?oE
FP3odeH0om=G0?oDE`3oeEL0omAG0?oEE`090?oDE`040?oDEP3oe5L0om=G0?oDEP<0omAG00<0om=G
0?oDEP3oe5X00`3oe5/03P3oeE`0om=E0?o?D`3obDd0ol=70?o3AP3o_TP0olYD0?oCG`3oeF80omIP
0?oDE`3oe5H0om9F0P3odeH01@3oeUd0omEN0?oDG@3oeEh0omAK0080om=F00<0omAF0?oDE`3oe5L0
0`3oeEL00`3odeL0omAG0?oDE`0Z0?oDE`040?oCE`3oe5H0omAG0?oCE`<0omAF103oe5L30?oCE`03
0?oDE`3oe5/0omAK00D0omAK00@0omAJ0?oDEP3odeL0om=G103odeH00`3oeE`0omAR0?oEH@050?oE
H@090?oCF03odeH0om=F0?oCEP3odeL0om9H0?oBE`3odeH0omIM00<0omEN00D0om=K0?o:CP3oaTP0
olE60?o8B0030?o6B0H0olI700@0olA60?o3A03oa4H0olM80P3oaDL40?o4A`050?o5B03oaTL0olA7
0?o4A`3oaDP01P3oa4L0103oaDP0olA70?o5B03oaDL30?o4A`030?o7B@3oa4L0olA700D0olA700<0
olE70?o4A`3oa4L0103oa4L20?o5B@080?o4A`3oaDP0omI>0?o^EP3ojUH0onQE0?oQC03oiZ`T0?oo
o`0406E6B0000000000000000140oooo00D0/7Yn0000000000004`d>0?o`m@060?ooo`050?ohnP0V
6Q/000000000001H?Cl0103oool300000003058i>`3oool0oooo00@0oooo00D0i:F[000000000000
00000>BUZ`050?ooo`040>BUZ`000000000001<=3P@0oooo00H0oko6000000000000000003l/;@3o
nOh50?ooo`050?olo`0o;2d000000000001[BTd0103oool300000003081PH`3oool0oooo00D0oooo
00@0P61S00000000000000001@3oool0103o_lH000000000000000070?ooo`0404`d=P0000000000
0;1jOPH0oooo00@0eY>I000000000000UfQ/103oool4000000030=Rf_@3oool0oooo0100oooo00<0
f;bo075>D@000000100000000`25L780oo3e0?ooo`050?ooo`050>cFfP00000000000000001iI6P0
2`3oool01@3ogn<00000000000000000P82000<0oooo00D0bkBf00000000000000000=Rm_`060?oo
o`040=JCV@000000000009MXK0@0oooo0`0000000`1UADP0ooWn0?ooo`040?ooo`040<V;T0000000
000001<=3P@0oooo00D0f:fd0000000000001`D50>BoaP0;0?ooo`0409MXK0000000000005Pm?`L0
oooo00@0JdY=000000000000UfQ/L@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinO]0?ooo`080?o>`@2DCbL0SDTP08i:8P2ABb<0UDlS0?nQAP3o^e8A0?neCP03
0?neC`3o]Dh0okE>00D0okE>00<0okE?0?neCP3o]Dh00`3o]Dh00`3o]U00okE>0?nfD00@0?nfD003
0?nfD@3o^UT0ok]K02d0ok]K00<0okaL0?nnGP3o_Eh01@3o^e/0103o^UT0okYH0?njF03o_Uh20?o2
J`060?o0J03o`V/0ol9/0?nmH03o^UL0okYH0`3o^eX00`3o_5`0okeN0?nlGP030?nlGP030?nlG03o
^eX0ok]J00@0ok]K1@3o^eXG0?nkF`80ok]J00<0ol5V0?nmF`3o_Ed0203o^e/0403o^UX0ok9B0?nY
B@3oYdL0ojU90?naDP3o^UX0okaL0?njF@3o^UL0ol1U0?o2J`3o`6P0ol9[0?nmG`3o^UP20?nkFP06
0?nlG03o_5h0okaN0?nmGP3o_5d0ok]J0`3o^e/30?nkFQ<0ok]K00T0ok]J0?niEP3o_fD0ol5/0?o1
JP3o_5`0okYH0?nkFP3o_5`00`3o_5h0103o^eX0ok]K0?nkF`3o^e/20?nkFPL0ok]K00`0ok]J0?nj
F03o_F40ol9[0?nmH03o^EL0ok]J0?nlG@3o_5h0okeM0?nkFP3o^e/30?nkFP<0ok]K00T0okYI0?nn
H@3o`FT0okiR0?njF03o_5`0okeN0?nlG@3o^eX00`3o^e/0>`3o_Ed0ok]J0?o0J03o`FL0ok]J0?nl
F`3o_5h0okaL0?nkFP3o^e/0ok]H0?nmH@3o`FP0okaM0?nlG03o_5h0okaL0?n]C@3oZTT0okIK0?o1
J03o_5/0okeM0?nkG03o^e/0okaM0?nmH@3o^UT0okeM0?nlF`3o_Uh0okiS0?nkFP3o_5`0ok]J0?nn
H03o_5d0okaK0?nkFP3o_F40okeM0?nmG03o_eh0oi9:06Hf6P0;1P<0000003HO3@3TQ3X0olQJ0?oF
H@3ocUX0oleJ0?o>F`3ocE`0oliN0?o<F03ocUd0oliJ0080olaH00T0oliL0?o?GP3of5h0oiU20109
102;Eb40onAG0?oVF03oiEP00`3oiEL0203oiEH0onEH0?oUE03oi5X0onIJ0?oTFP3oiE/0onEI0`3o
iEL04P3oiET0onEJ0?oTFP3oiUT0onEF0?oVF`3oi5X0onIG0?oUE`3oiUX0onEI0?oUF`3oi5D0onEK
0?o^GP3oieP0omEH085B7`80000001X05Q86099d:P3olUh0oo=L0?obFP3olE/0oo9N0?o`E`3ol5X0
oo5I0?obH03ol5P0oo1I0?o`F`3ol5L0oo9R0?oaF`3olEP0ooAL0?ohG@3onU/0oniP0?oLD03obd/0
`YXi05505`<0000000h02PH202TF2@1Q>AL0]FT[0?fZB@3oe5P0om5D0?oEG03of680om9F0?oEEP3o
e5L0omEG0?oBF080om9K00D0om=F0?oEF`3oefH0omES0?oBEP020?oDE`80omEF00/0omAG0?oEEP3o
e5L0omEK0?oEF03oeEH0om9D0?oDHP3oeFD0omEK0?oBE0040?oDE`050?oDF`3oe600om9D0?oDFP3o
deP00P3odUH01P3oeEP0omAK0?oEF03oeEH0om5E0?oCF`80omEW00<0omAQ0?oBE@3oe5L02`3oe5L3
0?oEEP80omAG00l0omEF0?oDE`3oe5/0om9K0?oEF`3oeEP0omEF0?oCD`3oe5D0omIQ0?oFI`3oeFL0
omAN0?oBE03odUH05P3oe5L0203oeEP0om5F0?o8CP3o`4D0ol530?o3A@3oc4l0omAE0P3oe5L30?oE
EP80omEK00<0om9K0?oEF`3odeT00P3oeEH02P3odED0om9D0?oFG03oefH0omEW0?oFIP3oefP0omEM
0?o@D`3odUE70?oDE`030?oEE`3oeEH0omEF00D0omEF103oe5L20?oEEP030?oDFP3ode/0omAJ0080
omEK00T0omAJ0?o;CP3o`dH0olI60?o4A`3ob4P0olY90?o5A`3ob4P00`3obDT02@3oaTH0ol140?no
A03o_d<0ok<o0?nc@@3o_4@0okU40?o4A`030?o7B@030?o4B03oaTP0olI700T0olA700<0olE70?o4
A`3oaDL0103oa4L00`3oadT0olA70?o4A`020?o4A`040?o6B03oa4L0olE70?o5B@H0olA70P3oaDT0
203oa4L0olI80?oYE@3oie<0onQE0?oWC03ogXD0ooWg903oool01@20H6<00000000000000000ooWn
0140oooo00@06A4B000000000000IDE81P3oool01@2bXZ@00000000000000000S8R900@0oooo1000
00000`3od=P0oooo0?ooo`030?ooo`0606E5B000000000000000000I4A80ooWn103oool0101UADP0
00000000000o;2d40?ooo`030?noaP00000000000080000000<0/7Un0?ooo`3oool00`3oool01@3H
_;l00000000000000000S8R900@0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`000000
0000000000D0oooo00@0oko600000000000000001`3oool01@20NWh00000000000000000omoS00@0
oooo00D0oo?l01TA4P00000000000?oQjP040?ooo`D0000000<0hYbR0?ooo`3oool03P3oool00`3T
aLP00000000000030000000306E5B03ohNX0oooo00P0oooo00D0UfQ/00000000000000000>:LXP0:
0?ooo`050?oOh`000000000000000020P8000`3oool01@3onOh00000000000000000P61S00D0oooo
00D0oo?l01TA4P00000000000?oQjP040?ooo`@0000000<0bH^@0?ooo`3oool00P3oool01@3onOh0
6A4B000000000000?b`]00D0oooo00D0UfQ/00000000000000000>:LXP0:0?ooo`050?oco0000000
00000000003o_lH01@3oool01@3olo`03@T9000000000000on7Z0740oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWkP3oool01`2bI400RTLO08e9802@BR40QDDO
0?n<?@3o^e804@3o]Dh00`3o]Dl0okE>0?neCP050?neCP030?neC`3o]Dh0okE>00<0okE>00<0okI@
0?neCP3o]U004@3o]U000`3o]E00okUG0?nlG00D0?nkF`030?nkFP3o^e/0ok]K00P0ok]K00<0okaL
0?nlG@3o_5d00`3o_5d0103o_5`0ok]K0?nkF`3o^UT20?njF0070?nmG`3o`V/0ol9Z0?o0IP3o`F/0
ol5/0?nnH0020?njF0030?nkFP3o^e/0ok]K00H0okaL;03o^e/0203o_5`0ok]K0?nlGP3o_f80okYG
0?nlG03o^e/0ok]J0P3o^e/20?nlG@0<0?nmG@3o_5`0ok]K0?ndDP3o[4/0ojY90?nLA03oZe80okmX
0?o2J`3o_5/0okYH0P3o^e/50?nlG1L0ok]K00P0okaL0?nlG@3o_5d0okaL0?nkF`3o^UT0okYG0?o0
I`80ol5Z00<0okaK0?nkF@3o^e/00`3o_5`<0?nkF`80okaM00L0okaL0?nkFP3o^e/0ol5X0?o1JP3o
_V00okYH0080ok]K00<0okaL0?nkF`3o^e/00P3o^e/02`3o^eX0ok]K0?nkF`3o_5d0okaL0?nkF`3o
^UP0okmU0?o1IP3o_5d0okYH0080okaL02`0ok]K0?nkFP3o^e/0ok]K0?nlG03o_5d0ok]J0?nnH`3o
`FT0okeR0?njF@3o_5d0okaL0?nkF`3o_5`0ok]K0?njE`3o_V00okmU0?nkF03o^e/0okaL0?nkF`3o
_5`0okaK0?niF@3oXTH0ok5?0?nkF`3o_5`0okaK0?nkFP3o`FH0okeQ0?nkF`3o_5d0ok]J0?nkG03o
_V40ok]J0?nlG03o^e/0okmP0?njE`80okaL00d0okiO0?nkF`3o_e`0ol1M0?nVD`1V=QX020@20000
000N4PL0fgdg0?o7F`3ocET0om1M0080oleI0180oliO0?o=F@3ocV00oleI0?o<F03ocUX0olaH0?o=
F@3oceh0oliL0?oCFP3oa5@0JSdI01L?1P3oceH0onUJ0?oWG`3oie`40?oUEP030?oUE`3oiEH0onEG
0080onEG02L0onEF0?oUF`3oiEX0onIJ0?oVGP3oiET0onII0?oUF@3oiEP0onMN0?oUF03oiUd0onEF
0?oVE`3oiE/0onII0?oUF03oiEL0onIK0?oVFP3oiUP0onaJ0?oQF03;PC40;A`;000000030`40BCXF
0>2b@@3oj5d0ooEJ0?oaF@3ol5/0oo5N0?o`F@3ol5X0oo1H0?oaG`3olEX00P3ol5X03`3ol5T0oo5M
0?oaF`3ol5P0oo1K0?obF`3om5P0ooIQ0?obHP3ojEH0oli>0;VD=`1]Eal06Q@7008000020000000:
00X40P1>;a<0[6HY0?nH@03ob5<0olmE0?oFG03offP0omML0?oDE`80om9H0P3oe5L0303odUP0omEH
0?oBE@3oeF00omEX0?oFG`3odUH0omEH0?oDFP3odUP0omEG0?oEEP80omAG0P3oeEP01`3oe5L0om9F
0?oEFP3oe680omAN0?oCF@3oe5D00P3oe5X00`3oeEP0omAG0?oDE`020?oDE`050?oCEP3odUH0omAG
0?oDE`3odeP00P3oeEP0303odUP0omAF0?oBE03oe640omEW0?oFI03odU80om5E0?oDE`3oe5P0omAJ
0?oEF100omAG00/0om9H0?oEF03oeEP0om9H0?oDE`3odUD0omAE0?oDHP3oefP0omIV0?oEG@020?oB
E0050?oCE`3oeEP0omAJ0?oEF03odeT0103oe5L00`3oeEH0omAG0?oDE`060?oDE`060?o@D`3oad/0
ol540?o2A03oaDP0ole@3P3oe5L40?oEF080omAG00T0om=G0?oBE03odU@0omAG0?oFIP3oeFH0omMV
0?oEI`3ode/00P3odU@00`3odEL0omAG0?oEF0020?oDFP030?oEF@3oe5X0omAG00D0omAG00@0omEG
0?oDE`3oe5L0omEF>`3oe5L01@3oeE/0om=I0?oEEP3od5@0olU;00@0olI70P3ob4P60?o6A`80olM8
00D0olI60?o0A03o`DD0olA70?o3A`040?o4A`050?o8A`3ob4T0olM90?o7B@3o`T@00P3o^T@20?nl
A080okY400D0ol550?o8B@3oadT0olM90?o6A`030?o4A`030?o5A`3o`dL0ol=70080ol=700@0olA8
0?o3A`3oa4L0olE91P3oa4L20?o5B@070?o4A`3of4l0onAB0?oXE03ojU@0omY>0?o_d`0U0?ooo`05
081PH`00000000000000003ogn<04@3oool01P3RW:800000000000000000UfQ/0?oco0<0oooo00<0
oo?l04`d=P0000000P0000000`3ac]40oooo0?ooo`020?ooo`@0000000<0Bc@f0?oQjP3oool00P3o
ool00`3RW:80000000000003000000050:FDV@3oool0oooo0?ooo`3TaLP00`0000000`1aCU40oooo
0?ooo`020?ooo`030?noaP000000000000<0000000<0bH^@0?ooo`3oool00P3oool01@1UATP00000
000000000000i<G800@0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`00000000000000
0080oooo00@0on7Z0<V;T039Ri00UfQ/0`0000040<V;T0040?oQjP3oool0oooo0>C5b0<0000000<0
YIBI0?ooo`3oool00P3oool0101nEeX000000000000o;2d50?ooo`<0000000@06A4B000000000000
i;Jm0P3oool00`3olo`0oooo0?ooo`0:0?ooo`03081aM@00000000000080000000<0bH^@0?ooo`3o
ool02@3oool00`3ohNX06A4B00000002000000030<V;T03oool0oooo00<0oooo00D0i:jd0?ooo`3o
ool0oooo0?oOh`03000000030820P03oool0oooo0080oooo00D0bH^@0000000000009QXK0?oco004
0?ooo`0407iGFP000000000007iGFPD0oooo1@0000001@3TaLP0oooo0?ooo`3oool0bjjd00<00000
00<0LDiA0?ooo`3oool00`3oool00`3ohNX06A4B00000002000000030<V;T03oool0oooo0080oooo
00<0onS/0<V;T03oool00`3oool01@39Ri0000000000001;=3H0oo?l00@0oooo00@0OUMJ00000000
0000OUMJLP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinO^
0?ooo`080<f>L`2;B1l0RTLO08e98023A1d0gW<c0?naC03o^5430?neCP030?neD03o]Dl0okE>00D0
okE>00<0okE@0?neCP3o]Dh00P3o]Dh00`3o]Dl0okE>0?neCP050?neCP030?neC`3o]Dh0okE>00D0
okE>503o]U000`3o^eL0ok]K0?nkF`060?nkF`D0ok]J0`3o^e/30?nkFP070?nlGP3o_600okaP0?nm
GP3o_600okeN0?nkG0020?nkFP<0okYH00@0okiQ0?o2J`3o`VX0ol5Z0P3o`VX0103o_F40okYH0?nj
F03o^eX50?nkF`030?nkFP3o_Ed0ok]J0340ok]K0`3o^eX20?nkF`090?nlG03o^UT0okiP0?noI03o
_5h0okeN0?nlH03o_5`0ok]J0080okYH00X0ok]K0?o1J`3o`VT0ol9[0?nnH`3o[dl0ojU80?nXB03o
ZTX0okAE603o^e/20?nkFP80ok]K00d0ok]J0?nlG03o_600okaP0?nlG03o^eX0okYI0?nnH`3o`VX0
ol5Z0?o0I03o^UP0okYI00`0ok]K0P3o^eX20?nkF`0:0?nkFP3o_El0okaN0?nlG03o^eX0okaK0?o1
JP3o`6T0okmT0?nkF@L0ok]K00`0ok]J0?nkF`3o^e/0ok]J0?nmGP3o_Ed0ok]J0?njE`3o`6L0ol1T
0?njF@3o^eX30?nkF`0;0?nkFP3o^e/0ok]J0?nlG@3o_Eh0okaK0?nkG03o`FL0ol1X0?nkFP3o^e/0
0P3o^eX01`3o^e/0okiS0?nmG@3o^UT0okmT0?nnHP3o^UT00P3o^e/03P3o^eX0okaN0?nmG@3o^e/0
ol5X0?nmG@3o[dl0ojQ80?nlG03o_5d0ok]K0?nnH@3o^eP0ok]J0P3o_5`05@3o`FD0okeP0?njF@3o
_5d0okYJ0?nlH@3o_Ed0ok]K0?nlG@3o^e/0okiQ0?nnG@3o`eh0ok=K0?n@B`0g7@h0000000P40@10
9A40jjA:0?o?F@020?o>FP060?o=G03ocUX0oliL0?o=G03ocUd0oleJ0`3ocU`02@3oc5P0oliO0?o=
F@3ocUT0omYR0<ae=P000000O4lN0?oYF0020?oVF@070?oWF`3oj600onIO0?oVG@3oiUP0onEG0?oT
E@020?oUE`040?oVH@3oie`0onIQ0?oVF@80onEH00h0onEI0?oVF`3oiEH0onEF0?oUE`3oiUX0onEI
0?oWG03oiEH0onML0?oUE`3oie`0onEH0?oVF`80onEG00H0onML0?oVF@3ok5T0on1K0<Ek<00O50L2
0000000804m0603]b4d0ooYM0?ofG03ol5X0oo9L0?o`F@3ol5X20?o`F@090?oaH@3ol5X0oo1J0?o`
FP3ol5L0oo1H0?obIP3olEX0oo1K0080oo1I00T0oo9J0?ocI@3oled0ooAI0?oOE@2aSS@0JeDO030W
3P0G4PL00`0000002`0`70/0/VL[0?nH?`3o^4/0olaC0?oLG@3ogVL0omYT0?oFEP3oe5X0omEK0080
omAG00P0omEF0?oDE`3oe5L0omAF0?oEH03oeFL0om=O0?oBE@80omEK00L0omAG0?oDEP3oe5L0omAJ
0?oDE@3oeEh0om9F0080omAG00d0om9E0?oFH@3oefH0omES0?oBEP3oe5L0omAJ0?oDG03oeEP0om9G
0?oBF03oe5L0omEF00T0omAG00P0omAE0?o@E03oeF40omMV0?oDH03od5@0om=F0?oDFP80omAL00@0
omEH0?oDE`3oe5L0omAG0P3oeEHA0?oDE`0>0?oBEP3odeD0omAR0?oEI`3oeV@0omIR0?oBE03odED0
om9F0?oEF@3oe5`0omEK0?oDG03oeEL30?oDE`<0omEF00<0omAG0?o=D03o`dD00P3o`D<00`3obD`0
om=F0?oEF00K0?oDE`0;0?oAE`3odU@0om9E0?oEH`3oeFL0omMV0?oFIP3oeFD0omAJ0?o@E03oe5D0
0P3oeEH00`3oe5X0omAL0?oEF`020?oDG0030?oEE`3oeEH0omAG0080omAG103oeEHb0?oDE`040?oE
EP3ode/0om1A0?o6B@D0olI700<0olM80?o6A`3oaTL01`3oaTL01@3oaDH0ol940?o2A@3oadT0olI7
00D0olA700D0olI80?o6A`3oa4L0olA70?o5A`040?o4A`030?o5A`3oadT0olE70080olA700D0olE7
0?o7B@3oadT0olM90?o4A`030?njA0050?nnA03o^T@0ok]50?nkA@3oaDT00`3oadT30?o4A`040?o7
B@3o`dT0olA60?oODP80onID00<0onM@0?oRP@3om>/09@3oool01@20P8000000000000000000lLkA
0180oooo00T0IDE8000000000000000001TA4P2mPXL0bH^@0;1iOP0I4A800`0000000`1UADP0oooo
0?ooo`030?ooo`<0000000H0F3do000000000000OUMJ0<V;T01;=3H30000000801TA4P2`NGh00000
00d92@1nEeX0bH^@0;1iOP0I4Q830000000308b2Q`3oool0oooo0080oooo00D0oko6000000000000
<b<T06E5B0020000000408YPH`39Ri00bH^@04/d=P<0000000<0<R<T0?oioP3oool00`3oool30000
0003081PH`3oool0oooo00D0oooo00@0P61S00000000000000000P3oool00`3o_lH0000000000008
000000050?noaP3oool0oooo0?oioP1;=3H00P0000001@0=2@T0bH^@0?noaP3o_lH0RV1S00<00000
00<0S7Un0?ooo`3oool00`3oool3000000030<V;T0000000000000<0000000<0oko60?ooo`3oool0
2P3oool01@0o;2d00000000000000000S75e00d0oooo00<0o:fd0000000000000P0000001P0I4A80
UfQ/0<V;T02GJ6`0Bc@f03<S90<0oooo00D0omoS00000000000000000820P0040?ooo`090?oco01;
=3H000000000000I4A80bH^@0?noaP3a[[@0<R<T0080000000<03@T90?oQjP3oool0103oool30000
00070;1iOP0000003@T909MXK039Ri00UfQ/01TB4P030000000308b2Q`3oool0oooo00@0oooo00<0
o:fd0000000000000P0000001P0o:bd0bH^@0<V;T02GJ6`09QXK06E5B0@0oooo00T0oo?l04/d=P00
0000000001TA4P39Ri00oko60>:LXP0b8b@00P0000000`0I4A80on7Z0?ooo`1a0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWinh0oooo00P0lLZk08a88@2<BB40
RTLP08e98P2:B1l0oiI20?niD@<0okE>0P3o]Dl60?neCP030?neC`3o]Dh0okE>00X0okE>00<0okE?
0?neCP3o]Dh01@3o]Dh@0?nfD0<0okI?00@0okIA0?nfD03o^ED0ok]I0P3o^e/20?nkFP090?nkF@3o
_V80okmU0?noI@3o_f@0ol1U0?nnH`3o^e/0ok]I00@0ok]J00L0okeO0?noHP3o_f40okiQ0?noH@3o
_V40okaL0080ok]J4`3o^e/0103o_5`0ok]J0?nlG@3o_5hP0?nkF`030?nlF`3o_5X0ok]K0080ok]K
00<0ok]J0?nkF`3o_El00P3o_F002`3o_El0ok]J0?nkFP3o^eX0ok]H0?nnH`3o`6L0okiS0?nnH03o
^eX0okaL0080ok]J00H0okeO0?noHP3o_V40okmR0?nlG@3o^eX20?nkF`0:0?nlG03o^UT0ok=C0?n]
C@3oZDT0ojY:0?n`D03o]UH0okYJ0?nlG0/0ok]K0P3o_5X30?nkF`040?nlG03o_F00okeO0?nmG`<0
ok]J00@0okiQ0?noI03o_fD0okeN0P3o^eX01@3o_Eh0okmQ0?noH@3o_5h0ok]I00T0ok]K0P3o_5X2
0?nkF`090?nlG03o_El0okeP0?nlG03o^eT0ok]K0?noH`3o_f@0ok]K0080ok]J00@0okmQ0?nnH@3o
_5h0ok]J0`3o^e/0403o^eX0okaK0?nkF`3o_5X0okaM0?nmH03o_5X0ok]J0?nlG03o`6D0okaL0?nj
F@3o^eX0okiQ0?nmGP3o^eX40?nkF`0:0?nlGP3o_Eh0ok]J0?nkF`3o_f<0okeP0?nkF@3o_Eh0okiQ
0?nlG080ok]K0140okeN0?nlG03o^eX0okmU0?nmHP3o^e/0okmQ0?nlG@3o^el0okaL0?nmGP3o^eX0
okaM0?nnH@3o^eP0okeO0?nnG`020?nlG00<0?n^C`3oXDD0ok1@0?nmH03o_Eh0okaN0?nlG03o_V00
okaK0?nlG@3o_5l0ok]K0P3o_Eh05`3o_5`0okaO0?nlFP3o_El0okaL0?noH@3o`Ed0okeN0=^@B020
AB<0?B0?0000001?;A@0Z7`g0>V/C03ocU`0om5M0?o>G@3ocU`0oleJ0?o>G03ocET0oleJ0080oliL
0200oliJ0?o=F`3ocU`0oliJ0?o=G03ocE/0oleJ0?o@F`2lMC@06@l601L?1P3P^4T0onQI0?oVG03o
iET0onIJ0?oUF@3oiUP0onQV0?oVF03oiEP0onEG0?oUE@3oif00onIH0?oVF@3oiEH0onIK0?oWG@3o
iEP0onEK0?oVF080onII02@0onIK0?oVFP3oiUX0onII0?oVF`3oiUT0onEK0?oUF@3oiUX0onII0?oU
F03oie`0onEH0?oVF@3oie/0onIG0?o]G@3`ce40ZXhh07i@7P0g8Pd061@706]D7`2_UST0h/i<0?od
G03ole`0oo5L0?oaFP3olE`0oo1H0?o`F@3olE`0oo5K0?oaH03ol5L20?o`FP040?oaG03ol5P0oo5L
0?oaF`80oo1J02H0oo1I0?obG03om5L0ooMQ0?ocGP3_eU00_;150:FK>02BM2/0ED<H02dT3P0H4`L0
1`<204LZ4P20BQl0RETV0:]g<P3OYD@0ol1C0?o=F@3ofET0omeM0?oIH@3oe5L0om9F0?oEFP3oeEP0
omAF0?oEE`3odeL0omEP0?oEG03oe5X0omEI0?oGH03oeVD0omEI0?oDEP80omAK01@0om=I0?oDE`3o
e5H0om=F0?oEE`3oe5L0omAF0?oFF`3oeEd0omAJ0?oCE@3odED0omAL0?oEH@3odeD0om=F0?oDE`3o
e5/0omEJ0?oCE`80omAG00T0om=G0?oDE`3oe5L0omAG0?oCE`3oeEL0omAG0?oDEP3oeEX00P3oeEd0
2@3oe5T0om9F0?oCEP3oeEd0omAQ0?oEGP3oe5H0om9F0?oDF@020?oCG0070?oEFP3oeEL0omAG0?oE
E`3oe5H0omEG0?oCF0070?oDE`030?oEE`3odeL0om=G0080omAG01X0om=G0?oCEP3oe5T0omIN0?oD
G@3oeEd0omAH0?oBEP3odUD0om=G0?oDH03oeF00omEQ0?oEF`3odUH0om9E0?o?D`3obDl0ol570?o0
A@3oad/0ola@0?oCEP3oeEP0omEG0?oCEaT0omAG00<0omEG0?oCE`3odeL00P3odeL20?oDE`0C0?oC
E`3odeH0om=F0?oFF`3oeEh0omAM0?oEG@3oeEh0omAG0?oCEP3odUH0om=F0?oCF03oeF40omAQ0?oE
H03oe640omAL0?oBE@020?oCEP090?oDEP3oe5L0omEK0?oDG03oe5/0om=L0?oDFP3oe5L0omAF00<0
omAG00@0omAF0?oCE`3oe5H0omAF7@3oe5L00`3oeEP0omAF0?o:CP020?o7A`030?o8B03oaTL0olI7
00@0olI700<0olY90?o6A`3oaTL01@3oaTL0103oaTH0ol940?o3A@3oaDL60?o4A`050?o5A`3oa4L0
olA70?o4A`3oaDP00`3oa4L00`3oaDL0olA70?o7B@030?o4A`030?o5B03oaDL0olA70080olA70`3o
aDL01@3oa4L0olM80?o4A`3oaDL0olE800<0olA70P3oaDP02@3oaTP0olQ90?o4A`3obd/0onUF0?oV
D`3oie@0onAQ0?obh00V0?ooo`050;RWZ000000000000000002bXj@04P3oool00`3onOh0Ofa]0000
00070000000305Pm?`2UVY/0ooWn00@0oooo00L0onoa000000000000000008J1Q02UU9T09QXK00D0
000000D0>BLY0?kFfP3oool0/YbR020F5`050000000300d92@1aCU40on_]00@0oooo00L0i:F[0000
00000000>BLY0?o`m@2<LGD06A8B00D0000000<06A8B08aaM@3oj>`01@3oool300000003081PH`3o
ool0oooo00D0oooo00@0P61S00000000000000000P3oool00`3o_lH0000000000008000000070?no
aP3oool0oooo0?ooo`3oj>`0S8:703<S90060000000300d92@20H6<0n>OX00@0oooo00L0omoS0000
000000001`D50?ooo`2UU9T0<b<T00<0000000<0oko60?ooo`3oool02@3oool01P3ofN4000000000
00000000LDiA0?odmPh0oooo00<0o]KJ06aGFP0000001P0000001@071@D0oooo0?ooo`3oool0omoS
00<0000000<0P8200?ooo`3oool00`3oool00`3oj>`0S8:701XB4P060000000300d92@2iUiX0oooo
00@0oooo00L0omoS0000000000003@T90?oioP2UU9T04`d>00D0000000<03@T9075>D@3ojnd01`3o
ool00`35Z:`0C3@f000000060000000300d92@3oool0oooo00<0oooo00<0onS/061CEP0000001P00
00000`17=CH0lLkA0?ooo`1b0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWinl0oooo00P0[5db08E57`28AQl0RdTR08Q7802oHb/0oje;0?ngD1<0okE>00<0okE?
0?neCP3o]Dh01P3o]Dh00`3o]U00okE>0?neCP040?nfD0030?neC`3o]E00okE@0080okE>00<0okIA
0?nfD03o]U00103o]U002@3o]Dl0okE@0?neD03o]E40okE>0?ndCP3o]U00okQB0?nkF@030?nkF`06
0?nlFP3o_5T0okaI0?nkFP3o_5T0ok]J903o^e/00`3o^eX0okeN0?nkFP0F0?nkF`040?nkFP3o_5T0
okaI0?nkFP80ok]K00H0okYH0?nkG03o_fD0ol1W0?noI`3o_V830?njF@0=0?nkFP3o_V<0ol1U0?o0
IP3o_V<0ok]H0?nkF@3o_Uh0okiR0?nkF03o_Ed0okYI0?nkFP0:0?nkF`090?nlG03o^e/0okAD0?nZ
BP3oYDD0ojU90?n`D03o^ET0okaL00L0ok]K00<0ok]J0?nlF@3o_5T00P3o^e/04@3o^UT0ok]J0?o0
I`3o_fL0okiR0?nlF@3o^UT0okeM0?noIP3o_f@0okiT0?njF03o^eX0ok]K0?nlFP3o^eX0okaI00`0
ok]K00D0okaI0?nkFP3o^e/0ok]J0?nmGP020?o0IP060?nlF`3o^UT0okeM0?noI03o_fH0okaM0P3o
^e/00`3o^eX0okaJ0?nkF`050?nkF`0>0?nkFP3o_5X0ok]K0?nkFP3o_V<0okmU0?njF03o^eP0okiN
0?o0I@3o_5T0ok]J0?nkF`3o_5X30?nkF`<0ok]J00P0ok]K0?o0I@3o_5/0okYH0?nmH03o_f80okaI
0?nkF`<0ok]J00<0ok]K0?nkFP3o_f@00P3o^eX0=P3o_V<0okaN0?nkF`3o^eX0okaI0?nkFP3o_5/0
okmT0?nmG@3o_5`0okmT0?nkF`3o^eX0ok]I0?nlG03o`6@0okaL0?nlGP3o]5H0ojM60?n[B03o^5/0
okiP0?nkFP3o_F40okeK0?njF@3o_Ed0okiQ0?nlGP3o_5`0okYI0?nkG03o_Ed0okeR0?nkF`3o^UT0
olAP0?nkF`3XOD00LC/K004000000000I3TH0>61>@3odEd0om1M0?o=F@3oc5P0oleK0?o=F@3ocUd0
oleL0?o>F`80oleG00D0oleI0?o=F`3oceh0oliL0?o<F0020?o>G00K0?o?GP3ocET0m:];00<10@00
0000dXDc0?o]G03oie`0onEG0?oUF03oiU/0onEK0?oUE`3oie`0onIL0?oUF@3oiEL0onEB0?oWGP3o
iEL0onII0?oUF@3oiUT0onEI0?oUF`3oiEP0onIL0080onEK01H0onEH0?oVF@3oiEP0onML0?oUF@3o
ie/0onEG0?oVFP3oiUP0onEG0?oWG03oiET0onAE0?oWF`3oiEH0onII0?oUF`3oiUP0onUL0?ofG@3o
h5T0]G</0`0000002`28KBL0onaN0?ooGP3oleh0oo1H0?o`F`3olE`0oo5I0?oaG03ol5L0oo1I0080
oo5K01D0oo5M0?o`FP3ol5L0oo1I0?oaG@3olE/0oo1G0?oaGP3ol5P0oo1G0?o`F03olE`0oo1N0?ob
D`3onV00oomV0?oZEP3g`dL0b9hk07eT9@0/8P`00`000000400J3`L0Ec<E08mC8`3URCT0olA@0?oR
G`3ohUd0omQN0?oBF03odED0omEK0?oEG03odel0omEF0?oDE@3oe5H20?oBEP0<0?oDE`3odUL0om=Q
0?oEH03oeE/0om=F0?oEH03oe6@0omEH0?oCE`3oe5D0om9F0`3oe5L04@3odUP0om9F0?oCF@3oe5L0
om9F0?oBF03oeF40omEM0?oBEP3odED0omEO0?oDH@3odeT0om9D0?oEE`3oe5D0om9F00P0omAG00<0
omEF0?oDE@3odUH00P3oe5L03@3odeX0omAR0?oDHP3oeEd0om=E0?oDE@3oeU`0omES0?oEH@3ode<0
om9F0?oDE`3oeEH00P3odUHA0?oDE`030?oCEP3odUH0omAE0080omAG01@0om5E0?oCF@3oeF80olaH
0?nlB03o`T@0ol130?o5A`3obU00om9P0?oEHP3oeF<0om=G0?oEE03oeEH0omAG0?oDE@3odUH0omAE
0?oCEb@0omAG0P3oe5D00`3odUH0omAE0?oEEP020?oDE`0B0?oDEP3oe5D0omEH0?oDH@3oe680omEP
0?oFHP3oeUl0om=F0?oDE@3odED0omED0?oDF`3oeF<0omAR0?oFHP3oeV<0omEH0P3oe5D20?oDE`03
0?oEEP3oe5D0om=F0080omAE4`3oe5L0103oc500olM90?o6A`3oaTL20?o6AP030?o7B03oaTL0olI7
00T0olI700L0olM80?o8B03oaDH0ol540?o3A@3oa4L0olE900`0olA700@0olE70?o4A`3oa4L0olM9
2P3oa4L20?o5A`030?o5B03oa4L0olA700H0olA700P0olI70?o7B@3oa4L0oma@0?oVE03oj5@0onM@
0?oQRRL0oooo00D0o]KJ000000000000000007iGFP0D0?ooo`080?oQjP39Ri00IDE800d92@000000
6A4B06E5B03T][d>0?ooo`060>:LXP1<=3H0000004/d=P2`NGh0oo3e0`3oool01`3ogn<0OUMJ038S
90000000C3@f0<V;T03olo`03@3oool01P2TLGD00000000000000000UfQ/0?oco1/0oooo00@0oko6
00000000000000002`3oool01`3;U9T0Bc@f000000000000?b/]0<V;T03olo`03@3oool0103:Ri00
Bc@f0000003o_lH;0?ooo`050<V;T000000000000000003ohNX04@3oool0203ohNX0bH^@06E5B00I
4Q80000004/d=P1UADP0i:jd3`3oool0203ogn<0UfQ/04/d=P0000003@T906E5B039Ri00oo?l303o
ool01`3ac]40OUMJ038S90000000C3@f0<V;T03olo`02`3oool00`3ohNX0bH^@04`d=P0200000003
04/d=P2GJ6`0om3H00L0oooo00P0oko609MXK01;=3H0000001TA4P1UADP0bH^@0?oioW@0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWk`3oool02@3o]Z80Od0H
08e98P2:B280ST/R08Q7803oY4L0okM@0?neD00B0?neCP@0okI@00<0okE?0?neD03o]Dh01@3o]Dh9
0?nfD0030?nfD@3o]U00okI@00/0okI@00<0okE>0?nhEP3o^e`0;@3o^e/00`3o^eX0ok]K0?nmGP0=
0?nkF`040?nlF@3o^eX0okaI0?nkFP80ok]K00H0okYH0?nlG03o`6L0ol1X0?o1J@3o_V<30?njF@06
0?nkF`3o_V80okmS0?nnH`3o_F00ok]J0`3o^e/02P3o^eX0okaJ0?njF@3o^UT0okaL0?nmH03o_5/0
okaP0?nkF`3o^eX;0?nkF`090?nlG03o]5@0oje=0?nYB@3oYdL0ojm@0?nfE`3o^e/0okaL0080ok]K
0`3o^eX20?nkF`0<0?nkFP3o`6H0ol1X0?o1J@3o_5h0okYI0?nkFP3o^e/0okmT0?nnH`3o_F00ok]J
0P3o^e/20?nkFP030?nlFP3o^e`0ok]K00X0ok]K0`3o^eX0203o^e/0okYI0?nkFP3o`FT0okmU0?nk
FP3o^UT0okaN0P3o_V<30?nkF`80ok]J1`3o^e/0303o^eX0ok]K0?nkFP3o^e/0ol1T0?noI@3o^UT0
ok]J0?nmH@3o_F80okYI0?nkF`80ok]J103o^e/02@3o^eX0ok]K0?njF@3o_f@0okiR0?njE`3o^e/0
okiR0?nkF`030?nkFP080?nkF`3o^eX0ok]K0?nlG@3o`FT0ok]H0?nkFP3o_V820?nkF`@0ok]J01H0
okeQ0?nnH@3o^eX0okeR0?nmG@3o^e/0ok]J0?nlG@3o_5`0okeP0?nkF`3o_V80okaL0?njFP3oZTT0
ojE50?n_E03o_5d0okeN0?nkFP3o^eP0okeP0P3o_5`0103o_Eh0okaJ0?nkF`3o_V820?nlG@1[0?nj
F@3o_Uh0ol=Q0?:MCP1R=1T030D20000000`6``0khTk0?o1FP3ofel0om1L0?o>G@3ocE`0oleI0?o=
F`3ocET0oleJ0?o<F03ocU`0oliJ0?o=E`3ocET0oliK0?o=FP3oc5P0olmN0?o>F`3ocEh0olaH0?oA
G`2CIBl0000006U2603ohET0onUI0?oUF`3oiET0onIG0?oUF`3oif80onEG0?oUE03oif40onEH0?oW
FP3oj600onIF0?oUE`3oif80onIK0?oVFP3oiEP0onEI0?oVF03oiET0onEF0?oUE`3oiEH0onEG0?oU
EP3oiET0onIJ0?oUF@3oie`0onEF0?oUF03oiUP0onEI0?oVFP3oiE/0onEI0?oUF`3oiET0onEG0?oV
F`3oiUX0onEF0?oZG03ojE`0oZ4l07Q<7@0000000P4104`l5@2fTCD0oo1L0?ogG`3ol5X0oo1G0?o`
F@3olE/0oo5N0?oaF`3ol5L0oo1J0?o`G03ol5P0oo5M0?oaF`3ol5L0oo1H0?o`F@3olE`0oo5H0?oa
H`3olE/00`3ol5P02P3ol5`0oo5L0?oeG03oo6P0oomP0?oaF03jaDT0eZTo0:n;<`1@?aP30000000>
018:101@;Q@0O4LO0;i_;@3oeEX0onAQ0?oLF`3ofE`0omEK0?o@E03odeT0omES0?oEFP3odEL20?oB
EP0=0?oDE`3odUH0om9F0?oDE`3odeL0omEM0?oEH03oe5L0om=E0?oFI@3oe680om=I0?oDEP020?oB
EP0@0?oDE`3odUT0om9L0?oBEP3oe5L0om9F0?oEEP3oe5L0om9F0?oEG@3oe5h0om9H0?oAE@3oeEX0
omAT0?oEH`80om=G00<0omEF0?oBEP3oeEH0203oe5L04P3oeEL0om9F0?oBEP3oeEH0om=G0?oBEP3o
eE/0omIO0?oEGP3oeE@0om5E0?oBE03oeF80omQS0?oDHP3ode<0om=G0?oEEP80om9F00<0omEG0?oD
E`3oe5L0403oe5L05P3odUH0omIG0?oCE`3oce40olE;0?o3@`3o`4D0olI?0?o=F03oeV00omAG0?oD
E@3odED0om=H0?oDI03oeF<0omIU0?oDG03oeE@0om9F0?oDE`3odeL30?oBERL0omAG0`3odUH02@3o
e5D0om9F0?oDE`3oe5L0om9F0?oDE@3oeEX0omEP0?oDGP020?oFG`0=0?oDE`3odUH0om9F0?oCE@3o
dU@0omAN0?oFI@3oeV@0omIU0?oGI03ode/0om=E0?oBEP020?oDE`050?oDEP3odUH0om9F0?oBEP3o
e5H01`3oe5L00`3odUL0ole<0?o5A`040?o6A`030?o6AP3ob4P0olI700D0olI700D0olQ80?o6A`3o
aTL0olI70?o8B0020?o6A`050?o7B03o`4D0ol950?o4A`3ob4P02@3oa4L00`3oaDL0olM90?o4A`03
0?o4A`030?o6A`3oa4L0olA70080olA700D0olE70?o4A`3oa4L0olA70?o5A`0=0?o4A`070?o5A`3o
aDP0on=D0?oVE03oiU<0on1?0?oZ_P0X0?ooo`04038S90000000000003<S96P0oooo00@0oko60000
000000000000;P3oool01039Ri00000000000000003J0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWinl0oooo00/0ooWm0:IH;026AAh0SdXS08U78028Ab80n80i
0?neCP3o]E00okE>0?neD0040?neCP030?neC`3o]Dh0okE>00@0okA>00<0okA=0?ndCP3o]Dh03P3o
]DhI0?nfD0030?nhE`3o^e/0ok]K02d0ok]K00<0okaN0?nmGP3o^eX00`3o^e/30?nkFP80ok]K00P0
ok]J0?nkF03o^eX0ol5/0?o2J@3o`F`0okeR0?njF@80ok]J00H0ok]K0?nmH03o_640okeQ0?nlGP3o
^eX30?nkF`@0ok]J1P3o^e/0103o_V80okaQ0?nkFP3o_5d20?nkFP`0ok]K00P0okaL0?naD@3oZDT0
ojM70?nXA`3o/E80okYJ0?nlF`80ok]K00`0okYH0?nkF`3o`FP0ol9Z0?noI@3o^UT0okYH0?nkF`3o
_F00okaQ0?nmH@3o_5`30?nkF`<0ok]J3P3o^e/20?nkFP050?nkF`3o^eX0okiS0?o3JP3o`FH00P3o
^UT0103o^eX0okeQ0?nnGP3o^eX20?nkF`80ok]J203o^e/02P3o^eX0ok]K0?njF@3o_F00ol1X0?no
H`3o^UP0ok]K0?nnGP3o_El20?nkF`80ok]J103o^e/0303o^eX0ok]K0?nkFP3o_V40ol5X0?nlG03o
^UT0okeO0?nmG@3o^eX0ok]K0?nkFP80ok]K0P3o^eX0203o_V80ol1X0?nkF`3o_5/0okeQ0?nkFP3o
^e/0ok]J0`3o^e/01@3o_Ul0okmT0?njF@3o_Ed0okaN00@0ok]J0140ol1X0?nlH@3o_5`0okaL0?nk
F`3o^eX0ok]K0?nbE03oY4D0oja;0?niF@3o_5`0ok]J0?nnGP3o`6H0okaK0?nlG0020?nkFP090?nm
H03o^eX0okeN0?nkF`3o_Eh0ol1M0?nmG03YO3h0<a/=0080000000L0Ec8E0?jYBP3of680omAO0?o<
F03ocU`0oleJ0080oleI01D0oliM0?o=F@3ocUd0olaG0?o>G03ocUd0olaH0?o=E`3ocU/0oleJ0?o>
G`3ocET0oleJ0?o<F03ocUX0olaI04@X4P0[6`/0ok960?ofH03oiU/00P3oiET00`3oj6@0onII0?oW
G0020?oUEP0<0?oVH03oiEP0onIL0?oWI`3oiEH0onEG0?oUF@3oiEP0onIL0?oUE`3oieX0onIM0P3o
iUX0103oiEL0onMM0?oUF03oiUP20?oUE`0Q0?oVF@3oiET0onML0?oUE`3oiET0onML0?oUE`3oiEP0
onIK0?oUF03oiUT0onML0?oUF03oiEH0onIJ0?oUE`3ojEX0oo9N0?oLE`3oZT00>bD>0000000;20<0
?S4B0=g3B@3ome`0oo9O0?oaG03ol5P0oo1K0?o`FP3olEd0oo5K0080oo1H00D0oo1K0?o`F@3olV@0
oo5I0?o`F0020?o`F@040?oaG@3ol5X0oo5N0?oaF@80oo1H00d0oo1I0?o`FP3olEd0oo1H0?odGP3o
nV00oomL0?ohF`3ofe40lKi70;B@=@1]F24040d60080000000l01@8104DW4P1]?Q`0`Fl`0?nSA03o
eeT0omQH0?oEF@3oeU`0omEH0?oDE`3oeF<0omER0?oBEP3oeEH00`3oe5L03`3oeEH0om9F0?oDE`3o
eEL0omEM0?oCG03oeEP0omAH0?oEHP3oeFL0om9F0?oCEP3odU/0om=K0?oBEP040?oDE`0>0?oCE`3o
dUH0omAG0?oDE`3odeT0om=M0?oCG03oe5L0om5E0?oFH@3oeFH0omIO0?oCEP3oe5L20?oEEP/0omAG
00l0om9F0?oDEP3oe5L0omAG0?oBEP3oe5/0omIL0?oCG03odUH0omAD0?oFG`3oeFD0omEV0?oDF`3o
dED00P3oe5L00`3oeEH0omAG0?oDE`0?0?oDE`080?oEF03oe5L0ol]>0?o1@`3o`T80olA40?o:C@3o
dUP30?oDE`0=0?oCG@3ode`0omEM0?oDFP3odUH0om5E0?oBE03oeF00omIT0?oDI`3oeF@0om9E0?oB
EP020?oDE`80omEF:P3oe5L00`3oeEL0om9F0?oBEP020?oBEP<0omAG00D0om=G0?oBEP3odeT0omEM
0?oDG@020?oEG@0:0?oEF03odUH0om5E0?oAE@3odU@0omEP0?oEIP3oeV@0omEU0?oEH`<0om5E00L0
om=G0?oDE`3oe5L0omAG0?o=CP3oadH0olQ800D0olI700<0olQ60?o8B03oaTL00P3oaTL00`3ob4P0
olI70?o:B@070?o6A`030?o2A@3o`T@0ol=600/0olA700<0olI70?o4A`3oa4L00`3oa4L01@3oaTP0
olA70?o4A`3oa4L0olI80080olA700<0olI70?o6B03oaDL0303oa4L01`3oa4H0omA=0?oWE03oiE80
on=?0?oRHP3onOD0:03oool01@39Ri000000000000000000hYbR06L0oooo00@0oko6000000000000
0000;P3oool01039Ri00000000000000003J0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWio00oooo00P0ol_008U67@29Ab00RdPP08U78@2ECR<0oje<0?neD@80
okE?103o]Dh00`3o]Dl0okE>0?neCP0A0?neCP040?nfC`3o]Dh0okE>0?neCQX0okI@00<0okUA0?nj
EP3o^e/08@3o^e/40?nlG0<0ok]K00L0ok]J0?nmG`3o_f@0okmS0?noI03o_El0okYH0080ok]J00H0
okaL0?noI03o_f<0okmT0?nmH03o^eX30?nkF`<0okaM00<0okaL0?nkF`3o^e/03P3o^e/20?nlG004
0?nnH03o_5`0okaM0?nlG@80okaL2@3o^e/20?nlG0050?nlG@3o_5/0okYJ0?neE03oZdl00P3oY4P0
103o[Th0okAC0?nhE`3o_El20?noI0070?noHP3o^e/0ok]K0?nkF`3o_5`0okaM0?nlG00@0?nkF`<0
okaL00d0ok]K0?nkFP3o_5/0okmS0?nnH@3o^eT0okYI0?nmGP3o_f<0okmT0?nkFP3o^e/0okaL0080
okaM2@3o^e/20?nlG00:0?nkF`3o^eX0okiQ0?noH`3o_5d0ok]I0?nlGP3o_f@0okeN0?nkF`<0okaL
103o^e/30?nlG0080?nlF`3o_V80okiR0?nlG03o^e`0okmS0?nmH03o^eX20?nlG080ok]K0P3o_5`0
1P3o^eX0okeM0?nnH03o^eP0okeP0?noHP<0okaL00D0ok]K0?nlG03o^e/0ok]J0?nnH@020?nlG003
0?noH@3o_5`0okaL0080okaL00H0ok]J0?nmGP3o_5`0okeL0?noHP3o^e/20?nlG00B0?nlF`3o_Ed0
ok]I0?noHP3o_5h0oj];0?n[BP3o^ET0okmQ0?nmGP3o_Ed0ok]K0?nlG03o_5d0okeL0?nlG@3o_Ed0
okaL0P3o_eh04`3o^5X0d8Y407Y2800W5@X030L305@`5@2XOcP0ok9@0?o<FP3od5`0oleH0?o>F`3o
cE/0oliK0?o=FP3ocUd0oleK0?o=F@3ocU`00P3ocET0:`3ocU`0oliJ0?o>FP3ocUX0oliK0?o=G03o
c5P0oleJ0?o=F@3oce`0olUJ09=D9@0D30D0ejU10?o`GP3oiUP0onMJ0?oUF03oiUX0onEG0?oVF@3o
iEL0onMK0?oVFP3oiV00onEH0?oVG03oifD0onIK0?oWGP3oiEL0onIM0?oUF@3oiEd0onEG0?oVFP3o
iUT0onMK0?oUF03oiET0onII0?oVFP3oiU`00P3oiUT01`3oiEP0onEI0?oVF`3oiUP0onIJ0?oWF`3o
iEP00P3oiUT05@3oiEX0onEI0?oVFP3oiUT0onEH0?oUFP3oiU/0onEI0?oYF@3ojEX0omQD0;JC>@20
Eb80=B8<01@?1P1QCQd0V8Td0>C9B@3oke/0oo=M0?oaFP020?o`FP030?oaG03olET0oo5M0080oo1J
00D0oo1I0?oaG@3olEX0oo5L0?o`F@020?o`FP060?o`F03ol5X0oo5M0?oaFP3olEh0oo1H0P3ol5X0
9P3ol5T0oo5H0?obH03om5/0ooEM0?obG03ok5H0onEH0<J`@@2DQC80Q7P/06UC7`0`9Pl04Pd5018;
1@0T50T0FSDF081>8@25JR/0ai8m0?nmCP3ocUH0om1G0?oEE`3of600omQO0?oCF03odeT0omAQ0?oE
F@3odeH0omAI0?oDE`3oeEL0omAG0?oEE`3oe5T0omEI0P3oe5L20?oDGP080?oCF03odeH0omEM0?oE
G`3odeH0omAG0?oCF@3oe5T20?oDE`80omEF0P3oe5L00`3oe5T0om=I0?oEF0020?oDE`80omAP00T0
omAH0?oBE@3oeEX0omEN0?oEG03odeH0omEG0?oEF03oe5T00`3oe5L0103oeEL0omAG0?oDE`3oe5L3
0?oEE`030?oDE`3oeEL0omEH0080om=I00T0omAH0?oCE`3odUD0omEJ0?oDH03oe5`0omAF0?oBEP3o
e5P00P3oe600103oeEd0om=G0?oDE`3oeEP20?oDF@<0omAG0P3oeEL30?oDE`090?oAE03ocE00olQ;
0?o3AP3o`dL0olM;0?o>D@3odeH0omAG00<0omEG0P3oe5L0403oeEL0om=I0?oDF@3odeT0omAI0?oE
E`3odeH0om9F0?oEFP3oeEl0omAP0?oDGP3odeL0om9F0?oCEP3oeEX20?oEG`050?oEG@3oe5H0om=F
0?oDE`3odeP00`3oe5T0103oe5L0omEG0?oDE`3oe5L30?oEEal0omAG103oeEL40?oDE`060?oEE`3o
eEP0om=I0?oDF@3odeT0omAI0P3oe5L0203oeEL0om=F0?oBEP3ocUL0olI;0?o4A`3o`dL0olI80P3o
b4T30?o8B0060?o5AP3oaTD0olI70?o3AP3oaDL0ol]90P3oadP00`3oaTL0olU80?o6B0030?o5A`06
0?o7B03o`dD0ol940?o3AP3oa4L0olI81@3oa4L01P3oaTP0olA70?o4A`3oaDL0olA70?o5A`@0olA7
00D0olI80?o4A`3oa4L0olA70?o5A`020?o4A`030?o6A`3oaDP0olE700<0olA700@0olI80?o4A`3o
aDL0olE81@3oa4L01P3obdX0on9C0?oVE03oi5<0omiI0?o]d2T0oooo00L0ooWn07iGFP0000000000
00d92@2<LGD0onS/06D0oooo00@0oko60000000000000000;P3oool01@3a][d00000000000000000
biBI0=T0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWl03o
ool00`3omo/0oij508526P0208e98P0308Q68P3JRC`0okE@00H0okE>00<0okE?0?neCP3o]Dh0103o
]Dh00`3o]E00okE>0?neCP0:0?neCP040?nfC`3o]Dh0okE>0?neCQ`0okI@00<0okMC0?nkFP3o^e/0
3P3o^e/40?nkFP<0ok]K00H0ok]J0?nmG@3o_F40okeP0?nmH@3o_Ed20?nkFP090?njF@3o_5d0ol1X
0?o2J`3o`VT0ol1X0?njE`3o^UT0ok]J0080ok]K00<0ok]J0?nkF`3o^eX00P3o^e/20?nlGAT0ok]K
00H0ok]J0?nlG03o_Ed0ok]K0?nnH`3o_5d20?nkF`<0ok]J0P3o^e/01P3o_5X0okaN0?nmH@3o_F00
okaN0?nkFP80okYI00T0ol5X0?o2JP3o`FX0okIE0?n/B`3oYdL0ojU80?n/B`3o^5P0503o^e/20?nk
FP80ok]K00X0okiN0?nlH@3o_Uh0ok]J0?njF@3o_V<0ol9Z0?noH`3o^UL0ok]J3@3o^e/30?nkFP09
0?nkF`3o_5`0okeQ0?nmH03o^eX0okeM0?o2JP3o`6L0okaK00X0ok]K00X0ok]J0?nkF`3o^e/0okeP
0?nnGP3o^eX0okmS0?o1J03o_F40ok]J1@3o^e/02@3o^eX0ok]K0?nlG03o_F00okaM0?njF@3o_fD0
okeP0?njF@040?nkF`080?nkFP3o^e/0okeM0?nmGP3o^UT0okmS0?nmGP3o^eX20?nkF`80ok]J00`0
okaL0?nlG@3o_Eh0ol5W0?nlF`3o^e/0ok]J0?nkF`3o^eX0okeM0?nlG03o`6L20?nkFP060?nmH03o
_5`0oji@0?nYB03o]5P0okaK0P3o^e/01@3o_Uh0ok]J0?nmH03o_5/0ok]J0080okaL01@0olET0?n/
E03aP3l0DB/E0000000B2`@0FC<E0?B<?@3odE`0om1Q0?o=E`3ocEX0oliL0?o=FP3ocET0oleJ0?o>
G@3oc5P0oleJ0?o?GP80oleI0300olaG0?o>G03ocUX0oleI0?o<F03ocEX0oliK0?o=F@3ocEX0oliJ
0?o=F`3oe5h0W5XW0000002;FR80onmM0?oVF@3oiEH0onIJ0?oUF03oif80onEG0?oWH03oi5D0onQU
0?oVGP3oiV00onEH0?oVG03oj6H0onIK0?oVGP3oiEH0onMO0?oUF03oiUT0onEH0?oUE`3oiET0onEH
0?oWG03oiEL0onIK0?oUF@3oiEL0onIG0?oUF03oiUX20?oUE`080?oVF@3oiEL0onEH0?oUF@3oiEP0
onEG0?oUF03oie`20?oUF00<0?oUF`3oieX0onEH0?oWG03oiE/0onEH0?oUE`3oiel0onUH0?oYG02f
N2h071460P000000301nI2H0omQ?0?ohG03onF40oo5K0?o`FP3ol5P0oo1I0?oaG03olEX0oo1I0?o`
F`80oo1I00H0oo1H0?oaGP3olEX0oo1K0?o`FP3ol5P30?o`F@060?oaG`3olEX0oo1L0?o`EP3olF40
oo5M0P3ol5T03@3ol5L0oo9Q0?o`F@3olET0oo5M0?ocFP3on5/0oo1I0>nmA`22J2L0<RP?01`E2@06
0`800P0000003`0;1P<0JS`J0>28>@3o]T`0olMA0?oDF03oge`0omQH0?oFE`3odED0omEP0?oCG@3o
dU@0omAG0?oCF`020?oDE`030?oEEP3oeEL0omAG0080omAG00T0om9H0?oFE@3oeEH0omAG0?oBE`3o
eFP0omIQ0?oEEP3oeEL00P3ode`00`3oeEH0omEG0?oBEP0;0?oDE`0=0?oBEP3oeE80om=O0?oEI@3o
dUH0om5E0?oDE`3oe5`0omEK0?oBEP3oe5L0omEG0?oEEP0?0?oDE`80omEF00d0omAG0?oCEP3odED0
om=O0?oEIP3oeF@0omAE0?oAE@3odUH0omAJ0?oCG03oeE/0omAE0080omAG00X0om9F0?oEEP3od5@0
ol970?o2A03o`D<0olA70?o?D`3odUD0omEH503oe5L03@3oeEL0omAG0?oDE`3oe5L0om9E0?oCG@3o
eFD0omIT0?oEI@3oe5D0om9D0?oBEP3odeP00P3ode`00`3oeEd0omEI0?oEEP020?oDE`040?oCE`3o
eEH0om9F0?oEERP0omAG00<0olmC0?o6A`3oaTL02`3oaTL0403oaTH0olQ70?o7B03obTT0olI70?o8
A`3obDT0olA60?nnA@3o_dD0ol150?noA@3oaTH0olE70?o3A@3oaDH20?o5A`<0ol9600<0ol560?o4
A`3oaTT00P3oaDL00`3oa4L0olE70?o5B0040?o4A`030?o6B03oa4L0olA700D0olA700<0olE70?o4
A`3oa4L0103oa4L00`3oaTL0olE80?o4A`030?o4A`060?o6A`3og4l0oneF0?oVE03ogT`0onG7;03o
ool01P1nEeX000000000000000006A4B0?kFfPL0oooo00<0oo3e0?oQjP3oool0FP3oool0103olo`0
hYbR07iGFP00000_0?ooo`0501TB4P00000000000000003ac]401P3oool00`3olo`0oo3e0?ooo`3?
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWio40oooo00L0
on7M08U88@29Ab00SDTR08U78037LS<0ok]B00H0okE>00<0okE?0?neCP3o]Dh0103o]Dh00`3o]E00
okE>0?neCP0>0?neCQ`0okI@00<0okI?0?nhD`3o^UT01P3o^e/30?nkFP060?nlFP3o^e/0ok]K0?nk
FP3o_5X0okiS0P3o_V800`3o_V<0ok]K0?nkFP020?njF@050?nnHP3o`VX0ol1X0?o1J@3o_V400P3o
^UT20?nkF`@0ok]J2`3o^e/00`3o_Eh0okYI0?nkF`0E0?nkF`050?nkFP3o_5`0okaP0?nmG@3o_640
0P3o^UT03P3o^e/0ok]J0?njF@3o_F00okiS0?nnHP3o^e/0ok]J0?njF03o_f@0ol9Z0?o0I`3o_V80
okYI0P3o^e/00`3o_5/0okQE0?naC`020?nXB0040?n/C03o/e@0okaK0?nlG0h0ok]K0P3o^eX20?nk
F`040?njF@3o_El0okiR0?nnH080ok]J00D0ol1V0?o1J@3o`6H0ok]J0?nkF`020?nkFPd0ok]K00`0
okaI0?nkFP3o^eX0okeQ0?nnHP3o_F00ok]I0?nmGP3o`VX0ol1W0?nlF`3o^e/20?nkFPL0ok]K00D0
ok]J0?nkF`3o^eX0okeN0?nnHP020?nlF`030?o1I`3o`FD0ok]K0080ok]J103o^e/02@3o^eX0ok]K
0?nkFP3o_F80okaN0?nlF`3o`FL0okeQ0?nkFP070?nkF`040?nmHP3o_5/0okiR0?noI080ok]J0P3o
^e/03P3o^eX0okaL0?nmH@3o^eX0okeN0?nnH@3o^e/0ok]J0?nkF`3o_5X0okaP0?nlGP3o^UP0okmR
0`3o^eX20?nlG00@0?nfEP3oWdH0oji=0?nmG03o^eX0okaL0?nlF`3o`6H0ok]J0?nkF`3o_5/0okaL
0?o4HP3ob6@0lXi605X`5`80000000l0>R4?0>n9>P3oeF00omEL0?o=G03oc5P0oleI0?o>G@3ocU/0
olaH0?o=G03ocUX0oliK0?o=FP3ocUd00P3ocEX0<@3ocUX0olaH0?o=F@3ocE/0olaH0?o=G03oceh0
oleI0?o>G@3oceh0oleG0?oEG@3oUd003`P40000003?[D80onEL0?oUF03oiET0onEH0?oUE`3oiE@0
onEH0?oVG03oiEH0onQU0?oVGP3oiUl0onEH0?oVG03oifL0onIH0?oWFP3oiEP0onEF0?oUF03oi5X0
onMN0?oUEP3oiUd0onEG0?oVFP3oieX0onII0?oVG@3oiET0onAG0?oUE`3oiEP00P3oiUT20?oVF007
0?oUE`3oiEP0onIJ0?oUF@3oiEL0onII0?oVFP020?oUE`0G0?oWG03oiET0onEF0?oVF@3oiEP0onEI
0?oUE`3oiEH0onMO0?o_G03oZ3l0N4`M01dB1P000000?S<B0;ZE>03oeTh0ooeP0?obF`3ol5`0oo1J
0?o`F03ol5T00P3olEd00`3ol5X0oo1I0?o`F0020?o`F@0>0?oaH03olEX0oo1K0?oaFP3ol5P0oo1J
0?oaGP3ol5P0oo5Q0?o`FP3ol5L0oo5K0?o`F@3ol5P20?o`F@0>0?o`E`3olE`0oo9T0?o`F03olEl0
oo5K0?oeFP3ooEd0onQG0>Bf@`2VQ380Gd`L02LO300200020000000A01lA1`1a@A/0`g0_0?nTA03o
aE80omiM0?oTGP3ofeX0omAG0?oBEP3odUP0omEQ0?oAE@3odEL0omEM0?oDFP3oe5L00P3odUH00`3o
e5P0om5E0?oEF0020?oDE`0>0?oBEP3oeEH0om5G0?oDF@3oeF<0omAS0?oCD`3odUT0omIO0?oDFP3o
dUH0om=G0?oBEP3oeEH80?oDE`030?oEEP3odUH0omAG0080om9F00/0omIS0?oGH03odED0om5E0?oD
F`3oe5h0omEK0?oDE@3oe5L0om9F0?oDE@0?0?oDE`0G0?oEEP3odUH0omAF0?oDE`3odUH0om5E0?oE
H03oef<0omIQ0?oEDP3odeD0omAJ0?oFG`3oe5h0omEJ0?oBEP3obU00olA70?o0@`3oa4@0olA70?o?
DP3oe5P06@3oe5L20?oBEP0A0?oDEP3oe5L0omAG0?oBEP3odeT0omIT0?oEH`3oefH0omEK0?oBE03o
dED0om9F0?oFG@3oe5h0omEP0?oCG03oeEH00P3oe5L0103oeEH0om9F0?oDE@3oeEHP0?oDE`030?o?
D`3obDT0olI700d0olI700<0olI60?o6A`3obTT00P3oaTL00`3oadP0olI70?o8B0030?o5A`070?o6
A`3oaTH0ol940?o5A`3oadT0olE60?nkA@020?nmA@040?njA@3o`dL0olM90?o9B@80olE700<0ol56
0?nnAP3o`4H00P3o`4H00`3oaDL0olI80?o4A`020?o4A`030?o7B03oaDL0olA70080olE71P3oa4L0
0`3oaTL0olE80?o4A`030?o4A`050?o?C03okEH0onMD0?oUD@3oeg`0;@3oool00`3olo`09QXK0000
00020000000303<S903RW:80oo?l00@0oooo00<0o:fd04`d=P3o_lH0GP3oool00`3ne]X0oooo0?oo
o`0]0?ooo`0606E6B000000000000000001UATP0oo?l0`3oool0103od=P0/7Un01TA4P3ogn<C0?oo
o`050>C5b0000000000000000020P800^03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0
103YjNT0dM7A0=7Ad@3WinOa0?ooo`080?o/k@2aIT<0RTPP08Q7802;B280YeLW0?nlE03o]E050?ne
CP030?neC`3o]Dh0okE@00@0okE>00@0okE@0?neCP3o]Dh0okE@3@3o]DhM0?nfD0030?neCP3o^540
okUF00<0ok]K00L0okYI0?nlG@3o_fD0okmU0?noI03o_f80ok]H0080okYI00X0ok]I0?o0J03o`6H0
ol1V0?o0I`3o^eX0okYI0?nkFP3o^e/0ok]J0`3o_5T00`3o^eX0ok]K0?nkF`0B0?nkF`030?njF@3o
_5`0okaL0180ok]K00L0ok]J0?nlG03o_5d0okaL0?nmH@3o_5`0okmT0080okmU00h0okaK0?njF@3o
^UL0okiS0?o0I`3o`6H0okaK0?njF@3o^e`0ok]J0?nlF@3o^eX0okaJ0?nkF`80okaL00L0ok=D0?nY
B03oYTH0ojM70?n`D03o^e/0okeM00/0ok]K0180ok]J0?nlF@3o^e/0ok]K0?njF@3o_F40ol1U0?nm
G@3o^UT0okYH0?nnH@3o`6H0okiS0?njF@3o^e/0ok]J0?nlF@3o^eX=0?nkF`0>0?nlF@3o^e/0ok]K
0?nmG`3o`6H0okeP0?njF03o`6@0ol1V0?nnH`3o^eX0ok]K0?nlF@3o^eX70?nkF`<0ok]J00P0ok]K
0?o0I03o_El0okYG0?nmH@3o`6H0okaM0?nkF`80ok]J103o^e/20?nkFP060?nlG03o_f@0okaN0?nl
F@3o_fD0okeQ0`3o^eX20?nkF`040?nkFP3o^e/0okaI0?noH@80okaK00@0okmU0?nlG@3o^eX0ok]J
0P3o^e/0203o^eX0okeM0?nnH`3o^e/0ol1T0?nlG03o^eX0ok]K0P3o^eX04P3o_5`0okaN0?nmH@3o
_F40ok]K0?nkFP3o_5T0okaL0?nmH03o_E`0okeN0?n]C03oYTL0ok9A0?nnGP3o_F00okaK0?nlG`<0
ok]J01T0ol5P0?o;I@3oXDl0_fDa028B2@0000001P@107Q47@3i[d`0omeQ0?o@G`3oc5P0oleI0?o=
G03oc5P0oliL0?o>F@3ocUX0oliN0?o<F03ocU/0oliL0?o=F@3oc5P0oliM0080oleI0380olmN0?o>
FP3ocE`0oliN0?o=F@3ocU/0oliM0?o<F03ocEX0oliK05<_50000000>bD>0?oNE`3oiEH0onEG0?oU
F`3oiUT0onMQ0?oUF@3oiEL0onEE0?oUF03oiUh0onEK0?oVG`3oiEP0onIK0?oWHP3oiEL0onAE0?oU
E`3oiEP0onIL0?oVFP3oiUd0onEG0?oUF03oiUX0onEH0?oUF`3oiEL0onEH0?oVFP3oiEL0onIJ0?oU
F03oiET0onIM0?oVF080onII0P3oiEL02@3oiUT0onEK0?oUE`3oiEL0onII0?oUF03oiEL0onEJ0?oU
F`020?oUE`090?oVF`3oiEP0onEH0?oUE`3oiET0ooIN0?o_F`3oZ3l0D3<C0080000000H0ASPD0=R_
@03ooEX0ooeU0?oaFP3olE/30?o`F00=0?oaG03olET0oo5N0?o`F03ol5T0oo1H0?o`E@3olEd0oo9N
0?oaG03olET0oo5Q0?oaF@020?o`F0060?oaF@3olE`0oo1H0?oaH03olET0oo1H0P3ol5T03P3ol5P0
oo1I0?oaHP3olEX0oo1I0?oaGP3oleT0ooUL0?ooG@3omU`0lKi70;NB=`22J2H0?S8C0`000000500F
3@H0LD4K0;Y[;03^S3T0okY>0?oXH03oheh0om]K0?oEEP3oe5L0om9H0?oGH03ode/0om9F0?oCG`3o
eUl0omEG0?oAE@3odUH0omEH1@3oe5L20?oBEP0;0?oDE`3ode/0omMT0?oCG03odU@0omAJ0?oEH03o
de`0omAE0?oCE`3oe5D02P3oe5L0403odeH0om9F0?oDE`3oe5D0omAM0?oDH@3oeEd0om9D0?oBE`3o
eF00omAR0?oEEP3oe5H0omEF0?oDE@3odUH@0?oDE`0>0?oDEP3odUH0om9F0?oBF03odeH0om=L0?oE
H`3oe680omEK0?oDE@3oeEH0om9K0?o7E03o^D420?o3@`040?o9CP3oeUL0omEI0?oEEQ`0omAG00H0
omEG0?oDE@3odUH0omAE0?oCE`3oe5L20?oDE@050?oEH03oe680omMT0?oFG`3odUD00P3oe5D02`3o
de`0omEQ0?oDHP3oeEd0om9F0?oDEP3oe5L0omEF0?oDE@3odeH0omEF01H0omAG00D0omEH0?oBEP3o
cTl0olM90?o5A`070?o6A`030?o7B03oaTL0olI700@0olI700<0olE70?o6AP3obDP02@3oaTL00`3o
aDH0ol940?o3AP020?o4A`070?o6B03oaDL0olE70?o5A`3oa4L0olE70?o4A`020?o5B0030?o0A@3o
_DD0oki50080oke500`0olE80?o7B@3oaTT0olE80?o6B@3o`DH0okm50?o0AP3o_TD0ol560?o6B@3o
aDP30?o4A`040?o9B@3oaDL0olI80?o5A`80olA700H0olE80?oKD03oj5@0onIC0?oLC`3olnX^0?oo
o`030;:LXP000000000000@0000000<0Bc@f06E5B01;=3H00`0000000`3o_lH0oooo0?ooo`2<0?oo
o`030:FJV`000000000000<0000000<0Bc@f06E5B00c8b@00`0000000`3ogn<0oooo0?ooo`0A0?oo
o`050>C5b0000000000000000020P800^03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0
103YjNT0dM7A0=7Ad@3WinOb0?ooo`070>bkZ`26A1X0RDLP08Y78@2<BB80i88i0?nmD`0<0?neCP05
0?neD03o]Dh0okE>0?neCP3o]Dl00`3o]Dh00`3o]E00okE>0?neCP050?neCQH0okI@0`3o]Tl40?nf
D0060?nfC`3o]U40okI?0?nfC`3o^5@0ok]H0P3o^eX00`3o_5`0okeP0?nmG`020?nmG`040?nkFP3o
^e/0ok]K0?nkF`80okaJ00<0ok]K0?nlF`3o^e/07P3o^e/00`3o_5d0ok]J0?nlF`080?nkF`0?0?nk
FP3o_Eh0okiQ0?noHP3o_5h0ok]L0?njF@3o^e/0okiP0?noI03o_5l0okYI0?nkFP3o_5`0okeP0080
okeO00D0okaK0?nkF`3o^e`0ok]K0?nlF`080?nkF`080?nfEP3o/E40oja<0?nYB@3o[Dd0ok=C0?nh
F03o_5`70?nkF`090?nkG03o_f80okmQ0?nmG`3o^eX0ok]K0?noH`3o_fD0okeO0080ok]J00<0okaN
0?nmG`3o_5`04@3o^e/0303o^eX0okiP0?nnH03o^eT0okYI0?nnH@3o_fH0ok]K0?nkF@3o_5d0okeP
0?nlG@80ok]K00<0okaJ0?nkF`3o^e/01`3o^e/02@3o_V40ok]L0?nkF03o_F00okiR0?nkF@3o^e/0
okeO0?nlG@070?nkF`090?nmG@3o_V00ok]J0?nkFP3o_V<0okaJ0?nkF`3o_El0okaM00D0ok]K01<0
okaN0?nnH@3o_5X0okiR0?nmGP3o^UT0okeN0?nlG03o^e/0ok]J0?nkF`3o_Eh0okeO0?nkFP3o_F00
ok]K0?nlG03o_Eh0ok]K0080ok]J00H0okeO0?nlG03o_V<0okaL0?nlF`3o_5d20?nkFP0X0?nnH03o
_Ed0okiR0?nkF@3o_5d0okaK0?n_C`3oY4H0oja;0?nkG03o_5d0okeO0?nkF@3o_5`0okeL0?o2H03o
]EP0^W/m05L^5`0S4PX00000060i6@30R3X0oKI@0?o?G03odeh0oleJ0?o=F03ocE`0oliK0?o=F`3o
cET0oleJ0?o>G@3ocET0oleK0?o>F`3ocU`0oleI0?o>FP80oliK0P3ocU`0<`3ocEX0oliL0?o>G03o
cET0oleH0?o=FP3ocET0oleK0?oDH02bO3H00P4104``4P3oaD/0onQJ0?oUE`3oiU/0onEK0?oUE`3o
iUP0onEH0?oVFP3oiU`0onEH0?oUE03oiEL0onIP0?oUF@3oiEP0onEG0?oUF03oie`0onIK0?oUF03o
iU/0onEH0?oVFP3oiUd0onEI0?oVF@3oiET0onEH0?oVFP3oiEP0onEJ0?oVFP3oiUT0onIK0?oVF@3o
iEP0onIK0?oVF@020?oVF0040?oVFP3oiEL0onEJ0?oUG080onIH01P0onML0?oUFP3oiEP0onIJ0?oU
F03oiUP0onII0?oUF03oiU`0onEG0?oVF@3oiEP0onIJ0?o^G@3og5H0bZ0m08MM901<<18040d504Df
5@2EMR/0`K=20?o]F@3oleh20?oaF`0<0?oaFP3olET0oo5K0?o`F@3olEh0oo5J0?obH`3olEX0oo5I
0?oaF`3ol5P0oo1J0P3olE/0503ol5X0oo1I0?o`F@3ol5T0oo5L0?oaF03olEh0oo1H0?oaF`3olE`0
oo1I0?o`F03ol5T0oo1J0?oaF`3ol5L0oo5M0?oaG`3olUX0ooIO0P3on5`07P3liED0h/i=0<VfA02]
TSH0NV4T04lm5`0/8Pd01`H202PG2P1?;Q<0MDDL09UU:P2lTcd0l;9:0?o5DP3ofeT0omQJ0?oFF03o
e5X0omAK0?oCEP3oeUd0omEO0?oDE`3oe5P0omIN0?oDFP3oeEH0omAG0?oEE`80omAG0180omEG0?oD
EP3oeEL0omAG0?oEF03oe5/0omAI0?oCEP3oeEX0omIR0?oDE`3odeD0omEK0?oCG03oe5T0om=G0?oD
E`3odeL70?oDE`0C0?oCE`3oeEL0omAG0?oDE`3oe5/0om=L0?oEE`3oe5H0omAN0?oEH@3oeUl0om=G
0?oDE@3oe5d0omEM0?oDF@3odeL0omAG0?oCE`0=0?oDE`0F0?oEE`3oe5H0om=G0?oDE`3oeEL0om=F
0?oFF@3oe5/0ol]C0?o8B`3oadT0ol540?ni@`3o`D`0oleF0?oCEP3oe5H0omEI0?oEG@3oeE`0om=F
0?oCE`80omAG0P3odeLI0?oDE`080?oEE`3odeL0omAF0?oCE`3oe5L0om=G0?oDEP3oe5T20?oDG005
0?oEFP3odeL0omAF0?oCEP3oeE`00P3oeF40303odeh0om=F0?oCE@3odeH0omIJ0?oEG@3oe5d0omEM
0?oCEP3oe5H0omAG0?oEE`<0om=G00<0omEG0?oDE`3oe5L0103oe5L0103oeEL0olmA0?o8B@3oaDL8
0?o6A`030?o7B03oaTL0olI700D0olI700H0olM80?o7A`3oaTH0olM60?o6A`3ob4T60?o6A`030?o5
AP3o`T@0ol=60080olA700D0olE80?o4A`3oa4L0olA70?o5A`050?o4A`80olI80P3oaDL00`3oa4L0
olI80?o5A`020?o5B0050?o3A`3o`dH0ol970?o2AP3o`dL00P3oaDP03P3oaDL0olE80?o4A`3o_TH0
okm60?o0AP3o_TH0ol560?o6B@3ocd`0onID0?oTD`3oiU80onBA<03oool00`3TaLP0P75e04`d=P09
000000030?o8c`3oool0oooo08`0oooo00<0ooco0:FDV@1H?Cl02@0000000`3ogn<0oooo0?ooo`0A
0?ooo`050>C5b0000000000000000020P800^03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOb0?ooo`080?oakP2gJDP0PT8H08E57P26AR00XU@U0?nOA`3o^e8?
0?neCP050?neD03o]Dh0okE>0?neCP3o]E001`3o]Dh=0?nfD0040?neC`3o]Dh0okE>0?neD180okI@
00<0okQD0?nkFP3o^e/0;03o^e/03`3o^eX0okeN0?nlG@3o^eX0okYH0?noI03o`VX0ol9X0?nkF`3o
^UP0ok]J0?nlG03o_5h0ol5X0?nmH@040?nkF`030?nkFP3o^e/0ok]K0100ok]K00H0okYJ0?n]C@3o
Z4P0ojI60?nZB@3o]UH20?nlG0<0ok]K00L0okYJ0?niEP3o`FL0ol9Y0?nlG03o^UP0ok]K0080okaP
00<0okeM0?nkF`3o^e/00P3o^eXB0?nkF`060?njF@3o^eX0ol5X0?noI03o^UP0okYI0P3o_5h0103o
^eX0ok]K0?nkF`3o^eX<0?nkF`060?nkF03o_fH0okiR0?njF03o^e/0okeN303o^e/01@3o`F@0ol5W
0?nlG03o^e`0okaN0080ok]K00<0ok]J0?nkF`3o^e/00`3o^e/0203o^eX0ok]K0?o0I@3o^eX0ok]L
0?nlH03o^e/0ok]J103o^e/01@3o^eX0okiR0?nmG`3o_5d0okaN00D0ok]K00H0okaL0?o1I@3o^UT0
okaM0?nlG03o^eX20?nkF`060?nmG03o_f@0ok]K0?nmG@3o_5`0ok]J0P3o^e/06`3o]5H0ojQ80?nW
A`3o^EP0ok]K0?nkFP3o_5d0okeN0?nnG@3o[5@0YEPZ02hG300000001P@107m8803oX4D0oliJ0?oC
HP3oc5P0oleJ0?o=F03ocf00oleI0?o=FP3ocET0oleL0?o>G`020?o=F@0>0?o?H03ocET0oleI0?o=
F`3ocU`0olaH0?o=F@3ocE/0oleJ0?o<F03ocEX0oliJ0?o=F@3ocEL30?o=F@0?0?oCGP3o_E40=1h=
034Q3@3ob4`0onYH0?oUF@3oieX0onML0?oUE`3oiU`0onIK0?oUF03oiET0onIJ0080onEF01L0onEH
0?oVH03oiET0onEG0?oUEP3oiEP0onMS0?oVGP3oiEL0onIJ0?oUF03oiET0onEG0?oUF03oiE/0onEG
0?oUF03oiET0onEG0?oUF03oiET0onEH0?oUE`020?oUEP060?oUF03oie`0onAJ0?oUF03oiEL0onIJ
0P3oiEP02P3oiUT0onEG0?oUF03oiET0onEG0?oUF03oiEL0onEH0?oVFP3oiEL20?oUF00:0?oUFP3o
iUT0onEH0?oUE`3oiET0onYN0?o`F`3oheH0bX`e00P40@80000000d0DD0G0?o=BP3ome`0oo9K0?oa
FP3olF00oo5O0?o`F@3ol5/0oo1J0?o`F@3olE`0oo5K00@0oo1I00@0oo1K0?o`F03olEd0oo5M1@3o
l5T01@3ol5X0oo1K0?oaG@3olV00oo1G00@0oo1I0100oo1H0?o`FP3ol5`0oo1G0?oaGP3olEd0oo1H
0?obF@3omU/0oo]M0?o`F@3ogU80om1=0;bD=`1??aH02`L30P0000004P0>20<0:1D903lU402jKBd0
okU=0?oMF`3ofEP0omIH0?oCE`3oeEH0omAG0?oDF@3oeF00omEH0?oBE03oeV00omAN0?oAE@T0omAG
00`0omEG0?oBEP3oe5L0omAG0?oDFP3oeE/0omAG0?oBE03oeF00omMV0?oEE03odUH=0?oDE`0>0?oE
EP3odUH0omEF0?oDE`3odUH0omEK0?oDG03oe5T0om9D0?oEF`3oeV@0omMQ0?oBE03odUHC0?oDE`09
0?oEF03oe5L0oliA0?o4A03o`d<0ol530?o5B03odU<0omEH0080om=L00P0omEF0?oBEP3odU@0omIR
0?oHI@3oeF<0om=E0?oCERH0omAG00<0om9F0?oDEP3oeEH00P3oe5L00`3oeEH0omAJ0?oDG0020?oD
G0090?oEEP3oe5D0om9D0?oDFP3oefH0omEU0?oEJ03odeX0om5E00@0omAG00<0om1D0?o:C03oaTL0
2@3oaTL00`3obDP0olM90?o8B@050?o6A`80olQ80P3oaTL00`3oadP0olM50?o6A`060?o6A`030?o5
AP3o`T@0ol=60140olA700H0olE70?o4A`3oa4L0olA70?o5A`3oadT20?o4A`030?o5A`3oa4L0olA7
00<0olA700/0olE70?o4A`3oa4L0olE70?o7B@3o`DD0omeA0?oQD`3oi580oma<0?odh`0c0?ooo`03
0?78c`2GJ6`0IDE80080000000@06A4B06E5B02GJ6`0lKo6TP3oool00`3olo`0Y75e04/d=P020000
000403l[;@2GJ6`0bH^@0?oQjQ@0oooo00D0i<G800000000000000000820P02h0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWio<0oooo00P0ok^V08m:8`24A1d0
RdPQ07m27P3LLS<0okaC0?nfC`@0okE>00<0okE@0?neCP3o]Dh01@3o]Dh00`3o]E00okE>0?neD003
0?neCP030?neD03o]Dh0okE>00D0okE>103o]U00103o]Dh0okE@0?neCP3o]DhL0?nfD0030?nfD@3o
^eX0ok]K02@0ok]K0`3o_5`0303o^e/0okYI0?njF03o`6H0ol5Y0?o2K@3o_F40okYH0?nkF`3o_5`0
okeM0?nlG@80ok]K00<0okYI0?nmHP3o^eX05`3o^e/0203o^UX0ok=C0?nZBP3oZ4P0ojY:0?ncE03o
^U/0ok]K0P3o^UP01@3o`FX0ol9Y0?nlF@3o^UP0ok]J0080okeM0`3o^e/20?nkFQ40ok]K00X0okaL
0?nkF`3o^UP0okeN0?o2J@3o_Ed0okYH0?nkF`3o_Ed0okaL3P3o^e/02@3o_5`0ok]K0?nlF@3o_V40
ol5W0?nlG03o^UT0okaM0?nlG00:0?nkF`070?nlG03o^UL0okiS0?o1J03o^eT0okaL0?nlG@070?nk
F`070?nkG03o_5`0okaL0?o1J03o_5`0ok]J0?nlG0060?nkF`040?nlG03o_5d0ol1V0?nkFP80okaL
00l0ok]K0?nkFP3o^e/0okaL0?nkFP3o_Uh0ol5W0?nlF`3o_5`0ok]K0?nkFP3o^e/0okaL0?nkFP3o
_F000P3o_5`0403o^e/0ok]J0?nkF`3o^eX0okeN0?o0I03o[dl0ojM70?ncD`3o^e/0okaM0?o1I@3o
_UT0okiQ0=F2?P0M3`L20000000605Pc5P3o[d`0olYH0?oBFP3od5d0oleJ0P3ocET02P3ocUX0oleL
0?o=F@3ocET0oliK0?o>FP3ocEX0oleI0?o>F`3ocUd20?o=F@050?o>G03oc5P0oleI0?o<F03ocUd0
0P3ocET0103ocUX0oleH0?o<F03ocUd20?o=FP0<0?o?GP3oeeh0dgPe0081003cVc/0oniK0?oWH03o
iEP0onAJ0?oUF`3oiEP0onEI0P3oiEP03P3oiEH0onEG0?oVH@3oj600onEG0?oVH03oiET0onEH0?oU
EP3oiEP0onIM0?oWFP3oiEP0onMO0P3oiEL02P3oiE/0onIJ0?oUF03oiE/0onEH0?oUF@3oiE/0onEH
0?oUE`3oiU`20?oUF00;0?oUF@3oiEP0onEG0?oWG03oi5X0onEH0?oUE`3oiUX0onEH0?oVF@3oiUX0
0P3oiEP01`3oiET0onML0?oUE`3oiEP0onEG0?oWG@3oiET00P3oiEP04`3oie`0onEK0?oUE`3oiEP0
onEI0?oUE`3ok5h0onQI0?nmB02[KBT071460000000F4@D0QV/U0?oPFP3ole/0oo9J0?oaH03olE`0
0`3ol5T0103ol5X0oo5J0?obH@3ol5P40?o`F@060?o`FP3ol5P0oo9T0?oaFP3ol5T0oo1J0`3ol5T0
103ol5X0oo1I0?o`FP3olF420?o`FPD0oo1I02H0oo1J0?o`F@3olE/0oo9U0?oaFP3ol5T0oo9J0?od
FP3ome/0oo5J0?oUE03ofU40h;5206]E800>2@<00P00000000030P405@X503HP3@2EEb<0mjI50?o@
E@3odEH0om=G0?oGF03oe5/0om=K0?oBEP3oe5T0om9H0?oDE@3oe5L0omER0?oBEP3oeEH0om9H0?oC
F0L0omAG00h0omEG0?oDE`3oe5L0omAG0?oDF@3oe5X0omAG0?oAE@3oeV<0omEO0?oAE@3odUH0om=H
0?oBF0d0omAG00d0omEF0?oDE`3oe5L0omAG0?oDFP3odeT0omAG0?oBE03oeU`0omEW0?oEF`3odU@0
omAG0080om9H3P3oe5L02@3oeEP0om9E0?o6C03o`T@0ol140?o3A@3oadX0om5D0?oCE`030?oDE`0:
0?oCF@3oe5X0omAJ0?oDE`3odED0omAN0?oEI`3oeFD0om=L0?oAE@80omAG00<0omEH0?oBF03oe5L0
8`3oe5L20?oEEP050?oEE`3oe5L0omAG0?oDE`3oeEP00`3oe5X02@3odeP0om9F0?oBE03odED0omIS
0?o9DP3o_T@0olA60?o7B@030?o6A`80olM8103oaTL00`3obDP0olM90?o6A`050?o6A`030?o8B03o
aTL0olI700<0olI700<0olI60?o6A`3oaTL0103oaTL00`3oaDH0ol940?o2A@020?o4A`030?o6B03o
a4L0olA700d0olA700<0olE70?o4A`3oa4L0103oa4L00`3oaTP0olA70?o4A`030?o4A`060?o7B03o
adT0ol970?o3AP3oa4L0olm<0P3ohe<00`3ohTT0omb40?oknP3o0?ooojT0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWl`3oool0203onOX0a7=C07`o5`27AQl0
R4LS0:IG:03oWTD0okU@103o]Dh00`3o]E00okE>0?neCP070?neCP0:0?neD03o]Dh0okE>0?neCP3o
]E00okI?0?nfD03o]Dh0okIB0?neC`80okE>9@3o]U000`3o^580ok]J0?nkF`0F0?nkF`<0ok]J0P3o
^e/03@3o^eX0okaL0?nmGP3o_5h0ok]K0?nkFP3o^UT0okiR0?o2J`3o`FT0okmT0?njF03o^eX01@3o
^e/01`3o_5X0ok]L0?nkFP3o^e/0okaK0?nmGP3o_f@05@3o^e/02P3o^eX0ok]K0?nlG03o^e/0okIF
0?nWB@3oYDH0ojQ70?n^C@3o^eh20?o1K0030?nlG03o^eX0ok]K01@0ok]K00`0ok]J0?nkF`3o^e/0
ok]J0?nlG@3o_5h0ok]K0?njF03o_Uh0ol5Y0?nlG@3o^UP>0?nkF`0:0?nkFP3o^e/0ok]K0?nlG03o
_Ed0ok]K0?nlG03o`FT0okiS0?njF0T0ok]K00T0ok]J0?nkF`3o^e/0okeM0?nlG03o^eX0okiR0?no
H`3o^UT02P3o^e/01@3o_5d0ok]J0?o0I@3o`FH0ok]J00L0ok]K00D0okaM0?nkFP3o_V80ol5U0?nk
FP050?nkF`030?nlG@3o^e/0okmQ0080ok]J103o^e/0103o_5`0okaJ0?o1IP3o^UP40?nkF`80okaL
01@0okeQ0?nkFP3o^UX0ojY:0?n/C03o^UX0okeM0?o1H@3o_5`0ojMB0:aL;@080`800000028C202H
F2H0ol9F0?o?F@3od5d0oliM0?o=FP80oleI00H0oleJ0?o>F`3ocET0oleI0?o<F03ocE`20?o=F@03
0?o>FP3ocU`0oleI0080oleI01<0oliK0?o=F@3oc5P0oliJ0?o=FP3ocET0oliJ0?o=E`3ocET0olmN
0?o=G03ocET0oliM0?oDG03oY4P09QD;03lX403ofE@0onYI0080onEH01@0onAG0?oUF03oiEP0onEG
0?oUF03oiET0onMO0?oUF03oiV40onQP0?oUE`3oiV00onEI0?oUF03oiEL0onEH0?oUEP3oiEL0onEH
0?oVF@80onEG00P0onML0?oUF@3oiEP0onIJ0?oUE`3oiEP0onEF0?oUF@@0onEH00D0onEI0?oVF`3o
iEP0onEG0?oUF@020?oUF00C0?oUE`3oiUX0onEH0?oUEP3oiEP0onEI0?oUF03oi5X0onIJ0?oUEP3o
iEP0onEG0?oWGP3oiEH0onEI0?oUF03oiEH0onEK0?oUFP030?oUF0050?oVF`3oieT0onMI0?oEE01W
@AP00P0000002@0>2P@0`i/i0?o^F@3on5`0oo=I0?oaGP3ol5T0oo1J0?o`F0030?o`F@040?oaG`3o
lEX0oo1J0?o`F0@0oo1I00<0oo9O0?oaF`3ol5X01P3ol5T01@3olEX0oo9V0?o`F03ol5T0oo1J00H0
oo1I00H0oo1H0?oaGP3olEd0oo1F0?o`F`3olEX20?obF@070?obFP3olET0on1C0=R[@02<KbX0<RH?
00`:0`0300000009030L3027D240hH<g0?nlC@3oc5<0omIM0?oMGP3oeUP0om=G00<0omAG00D0omAE
0?oBE`3oeF80omAK0?oBEP020?oDFP80omAG00<0omEF0?oDE`3oe5L02P3oe5L02P3odU@0omAR0?oD
H@3odU@0om9F0?oEFP3odUP0omEF0?oDE`3oeEHA0?oDE`090?oBEP3od5@0omES0?oEI@3odeL0om5E
0?oDF@3oeE/0omAJ0080omAG0P3oeEH70?oDE`090?oEF03ocE<0olA80?o1@`3o`T<0ol940?o=D03o
e5L0omEH00X0omAG00P0om9F0?o@D`3oeE/0omQV0?oFH@3odED0om9D0?oBE`80omEK00@0omAJ0?oD
E`3oe5L0omAG0P3oeEHU0?oDE`030?oBF03odeH0ola?0080olI701<0olQ80?o7B03obDT0olU90?o3
A@3o`DD0oki40?o7B03obDT0olI80?o6A`3oadP0olE90?o5A`3oaTL0olE70?o6A`3oadP0olI70080
olE7103oaTL00`3oadH0olQ90?o6A`040?o6A`030?o7B03o`d@0ol540080olA700<0olE70?o4A`3o
a4L0203oa4L01P3oaDT0olE70?o4A`3oa4L0olE70?o5B@H0olA70100olI80?o4A`3oa4L0olA70?o3
A`3oa4H0ol550?o2B@3oaDT0olA70?o9B@3oge40on=C0?oTC`3ogEX0onoJo`3ooonZ0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWio@0oooo00L0onKN0;=V@P27
AQh0R4LP07m27@3<JRl0okE?00/0okE>0P3o]Tl00`3o]Dh0okMA0?neC`060?neCP050?nfC`3o]Dh0
okE>0?neCP3o]Tl09@3o]U00103o]U40okQD0?njF03o_5`90?nkF`0B0?nlFP3o^e/0ok]K0?nkFP3o
_5d0okiO0?nmG`3o_5`0ok]K0?nkFP3o_5`0ol1V0?nnI03o_fD0okaL0?nkFP3o^eT0okaL0P3o_f80
0`3o^e/0ok]J0?nkF`0:0?nkF`80okaL00@0okeR0?nmG@3o^eT0okeN3@3o^e/04P3o_5X0ok]K0?nk
F`3o^e/0okaM0?nmG`3o_Ed0ok]J0?nkF@3o_Ed0okmT0?nkG`3o]580oji=0?nWB03oYdX0oj]?0?nf
EQL0ok]K00/0okeO0?nlG@3o^eX0ok]I0?nnI03o_V80okYI0?nkFP3o_F00okiQ0?nkFP0<0?nkF`0=
0?nlFP3o^e/0ok]K0?nmG`3o_5h0ok]K0?nlG03o_f@0okiP0?nkFP3o_Eh0okiQ0?nlG0090?nkF`0:
0?nlG03o_Eh0okaM0?nkF`3o_fD0okaL0?nlF@3o_F00okaN0?nkFPH0ok]K00T0okaL0?nmG`3o_5`0
okaL0?nmH@3o^eX0okaJ0?nmH03o^eX01@3o^e/01`3o_5h0ok]K0?nnH03o_F00ok]J0?nmG`3o^eX0
103o^e/01P3o_Eh0okaJ0?nnG`3o^eT0okeO0?nlGP<0ok]K00P0okaL0?nlG@3o_El0okaK0?nlG@3o
_5`0ok]K0?nlFP80okaL01@0okiP0?nlF`3o_5h0okaL0?nlF`3o^ET0oji>0?nYB@3o_E/0ol5P0?n]
E02dLcT0GC4H00X60`0K40L0KD0L0<ND@03o`UP0om5M0?o?G0<0oleI00P0oliK0?o>FP3ocU`0oleH
0?o=FP3ocUd0oliK0?o>FP80oleI00P0oliM0?o=FP3ocEX0oliK0?o=F03ocU/0oleJ0?o>F`80oleJ
00H0oliJ0?o>F@3ocEP0oleI0?o?G03ocEX20?o=F@080?o@G03cYDP0?b@?00<30@2nUCT0oneL0?oV
F`3oiET20?oVFP0<0?oUF03oiEL0onIL0?oUF03oiET0onMO0?oUF03oiUl0onIN0?oUE`3oiUd0onEI
0`3oiEP01@3oiEL0onEH0?oUF03oiET0onIM0080onEH00D0onMK0?oUF03oiEP0onIK0?oUF@020?oV
F@0:0?oUF03oiUT0onMK0?oVF@3oiEP0onII0?oVF03oiEP0onEG0?oVF080onEH00X0onEG0?oVF`3o
iEP0onEH0?oVFP3oie/0onEH0?oUE`3oiUL0onMJ0P3oiEP00`3oiEL0onMK0?oUE`020?oUF00F0?oU
F@3oie/0onEI0?oUF03oie/0onEJ0?oVG03oie`0on1F0;VP?@2MNbl0F3PE01D>1P15=a@0Q6PV0<>]
@@3kj5H0ooQN0?obFP3ol5d0oo5J0?o`FP80oo1I00D0oo5J0?oaF`3olE/0oo5L0?oaFP030?o`F@07
0?oaF@3olE`0oo1I0?oaG03olE/0oo1K0?o`FP040?o`F@80oo5J00@0oo5K0?oaG`3ol5P0oo5K1@3o
l5T07@3ol5L0oo5M0?oaFP3olEh0oo5O0?o`EP3olE/0oo5I0?obF@3om5X0onmI0>S@C@33]d@0Yidj
08E/:017>1D0;R@>01`F200D3@H0AbTB07=47020E2D0fYa00>n_B@3o_Th0ol]C0?oIFP3ofeX0omMI
0080omEG00d0omAF0?oCG03oe5d0om=F0?oEGP3oeV40om=I0?oDF03oe5/0omAI0?oCE`3oe5L0omEG
00H0omAG00l0omEG0?oDE`3odeL0om=F0?oEG03oeET0om9E0?oDE@3oe600omAJ0?oDE@3oe5L0omEK
0?oDE`3odeL03@3oe5L20?oEE`050?oDE`3odeH0omAJ0?oDGP3oeU/00P3oe5H05@3oeF80omIQ0?oE
G03odeH0omAI0?oDFP3oe5/0omAH0?oDE`3odeL0omAF0?oCEP3ocE80olQ<0?o4A`3o`T@0olE80?o8
C03od5<0omAG0?oEF00:0?oDE`80omEG0180omAG0?oCE`3oeEL0omEN0?oDGP3oe5d0om=G0?oCEP3o
e5/0omIQ0?oEH03oe5L0om5E0?oCE`3oe5X0omAK0?oEFP3oeEL20?oDE`80om=G603oe5L01@3oeEL0
om9D0?o>CP3obDT0olM70080olI700<0olQ90?o7B03oaTL01P3oaTL02@3ob4P0olM80?o4AP3oaDL0
olA60?o6B03ob4P0olM90?o7B0020?o2AP090?o3AP3oaDL0olI80?o;B@3oadL0olE70?o5AP3oaTL0
olE700<0olI700@0olM80?o4A@3o`TD0olE70P3oa4L00`3oaDL0olA70?o4A`020?o4A`030?o7B@3o
a4L0olA70080olA700H0olE70?o4A`3oa4L0olA70?o5A`3oaDP20?o4A`0:0?o5A`3oa4L0olI80?o3
A`3oaDP0ol160?o5A`3oaTP0ol=60?o5A`80olA700L0olI80?o;B@3ogE40onAC0?oQD@3ogFX0oo;I
0?l0ooooZ`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOe
0?ooo`070?oNf02;B280SDTR08]87`1g?A/0nYa60?nfD00I0?neCRP0okI@01T0okE>0?nhE03o^e/0
ok]K0?nkFP3o_5X0ok]K0?nkFP3o^eP0okmR0?noI@3o`6H0okeP0?njF@3o^UL0okeP0?o0J03o`6H0
okeM0?njF@3o^eX0ok]K0?nlF@3o^eX0okaI00l0ok]K00H0ok]J0?nkF`3o_F40ok]K0?nlG@3o_5h2
0?nkFP030?njFP3o_Ed0ok]K00L0ok]K01@0okaI0?nkFP3o^e/0ok]J0?nnHP3o`6H0okmT0?nkF`3o
^UT0okiP0?o0IP3o_V80okYI0?nlG03o^ET0ok1>0?nXA@3oYTH0ojU80?ncE080okaL3`3o^e/03P3o
^eX0okaI0?nkF`3o^UT0okeP0?noI@3o_El0okYI0?nlG03o`6P0okiQ0?njF@3o^e/0ok]J3P3o^e/0
2`3o_5T0ok]J0?nkFP3o_F40ol1V0?nmG@3o^eX0ol1W0?nnH`3o^eX0ok]K0080ok]J203o^e/02P3o
_5X0ok]J0?nlG03o_f@0okeN0?nlG03o_fD0okeQ0?nkFP3o_5T70?nkF`80ok]J00D0okeP0?nnH03o
_5/0okmU0?nmGP020?nkFP@0ok]K0P3o^eX01@3o_5d0okiP0?nkFP3o_V<0okeN0080ok]J0`3o^e/0
1P3o_5T0ok]K0?nmH03o^eX0ol1T0?nkFP@0ok]K00<0ok]J0?noI03o_5`00P3o_Eh00`3o^eX0ok]K
0?nkF`020?nkF`040?nnHP3o^eX0okaM0?nkFP80ok]K0100okaK0?nmH03oZd/0ojA40?nmE`3oUdT0
XePZ02/F2P000000=Ql>0:eS:`3oZd/0omYO0?o?GP3oc5H0oliM0P3ocET01`3oceh0olaH0?o>G03o
cET0olaH0?o=FP3ocU`00P3ocET01`3oc5P0oliL0?o<F03ocET0olaH0?o>GP3oc5P00P3ocET0103o
cUT0oleG0?o=F@3ocUX30?o=F@030?o<F03ocEP0oleI0080oliM00T0ol5D02hI30000000IT4H0?oV
F03oi5X0onEI0?oUF03oiU/00P3oiEL02P3oiE`0onEI0?oUF03oiE80onEF0?oUF03oi5D0onEF0?oU
F03oiEH20?oUF0070?oVG@3oiU`0onEF0?oWJ03oiU/0onIH0?oUG@060?oUF00H0?oVFP3oiEL0onEK
0?oWFP3oiEP0onEG0?oUF@3oiEH0onEH0?oTE`3oiEL0onEH0?oUE`3oiUL0onEG0?oUF03oiUP0onML
0?oUF@3oiEP0onIJ0?oVE`3oiEL0onEH0P3oiUX02`3oiUT0onEH0?oUF03oi5D0onIJ0?oUEP3oiUd0
onEF0?oWG03oiUX0onEG0080onEH00L0onEG0?oVFP3oiUd0oneJ0?ohGP3NXSl0BRlB0080000000T0
C3dF0>Nh@`3onU`0oomM0?oaF`3olEX0oo5M0?oaF`3ol5P00`3ol5T0103olEd0oo1H0?oaG@3olEX3
0?o`F@070?o`F03ol5T0oo5O0?oaFP3olE/0oo5L0?o`F0040?o`F@070?o`F03ol5L0oo5N0?o`E`3o
lEh0oo5L0?o`F0040?o`F@<0oo1H00D0oo5N0?o`F03olE/0oo5Q0?oaFP020?o`F0090?oaF@3onUd0
oomP0?ofF`3ocdd0`YTi07UO8`11=A@03P/40080000000T01P@004P[4@2YI2T0oiLn0?nhC@3ofe`0
on9N0?oIFP3odeL00P3oe5L0303odUH0omAE0?oDE`3oe5T0omIR0?oCF@3ode<0omAO0?oEG@3odUH0
omAG0?oEEP/0omAG00d0om9F0?oDE`3oe5D0omAG0?oEHP3odUP0om5E0?oCF@3oeF00om9F0?oEEP3o
e5L0om9F0100omAG0P3oe5D05@3oeEH0omAF0?oEF`3oe640omIR0?oCF03oe5D0omIN0?oDHP3oe5/0
om9F0?oEF03oeEH0olY=0?o1@`3o`480ol530?o7BP3odE@0omIJ0?oEF00C0?oDE`0;0?oDE@3odeH0
omAG0?oDE`3oe5D0omIM0?oFHP3oeF00om9F0?oAE@3odeT00P3oe6401P3oe5`0omAE0?oDE`3oe5L0
om=F0?oDEA00omAG00@0omEH0?oBF03ocdh0olA61@3oaTL00`3oadT0olQ80?o6A`0?0?o6A`0<0?o5
A`3ob4P0olE70?o7B03oaTL0ol]:0?o6B@3oaDL0olA70?o8A`3o`d@0olM90P3oaTT0203ob4P0okU2
0?ni@03o_4@0olE90?o5B03oadT0olA70`3oaDL00`3oadT0olA70?o4A`030?o4A`040?o5B03oa4L0
olA70?o4A`<0olE700H0ol960?o3AP3o`dP0ol150?o4B03oaDL60?o4A`060?o7B@3og500onIC0?oP
DP3ofeH0oo7To`3ooon/0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWioH0oooo00T0]fU508E57`2:B200Od4M0<mk=P3o^U80okE>0?neD03o]Dl01`3o]Dh00`3o
]Dl0okE@0?neCP070?neCP030?nfD03o]Dh0okE>0080okE>:@3o]U001P3o]e00okUC0?nmH@3o`6L0
okmT0?njF080okYI00T0okiQ0?noI03o_f@0okaN0?nkF`3o^e`0ok]J0?nlF@3o_5X0503o^e/20?nk
FP050?nmHP3o_5d0okaP0?nlG03o^eX0103o^e/00`3o_5d0okYI0?nkFP020?nkFP80ok]K00T0okYH
0?noHP3o`6P0okiR0?njF@3o^eX0okeQ0?noI03o_V800P3o^e/02`3o^eX0okaI0?nlF`3o^e/0ok=D
0?n/C03oYdL0ojQ80?n`D03o]UL0okaL00d0ok]K00/0ok]J0?nlF@3o^e/0ok]J0?noI03o`6P0okaM
0?nkF03o_5h0okiS0?nlGP020?nkF`030?nlF@3o^e/0ok]K00`0ok]K00d0ok]J0?nlF@3o^e/0ok]J
0?o0J03o_f@0okaI0?nlH03o_f@0okeM0?nkF`3o_5T0ok]J00T0ok]K0`3o^eX01P3o`6H0okUG0?nk
F`3o_V<0okaN0?nkF`80ok]J1P3o^e/20?nkFP050?nmG`3o_F40okYI0?nlGP3o_F000P3o^eX50?nk
F`060?nkFP3o^e/0okmT0?nmHP3o^e`0okeN0P3o^eX50?nkF`040?nnH03o_V<0okYH0?nmG`80ok]J
0`3o^e/01@3o^eX0okeN0?nmGP3o_V80okeM00<0ok]K0P3o^eX0103o_F00ok]J0?nmHP3o^UT20?nk
F`080?nkFP3o_5`0okaN0?nfF@3o[TT0okE>0<Yb=P0b6`d20000000;07A27@3oZd/0omMN0?oGG@3o
cE/0oleL0?o=F@3ocEX0oliK0?o=F03ocUd00`3ocET02@3ocU`0oliJ0?o=FP3ocET0olaH0?o>G03o
cU/0oleI0?o<F0020?o>G080oleI00<0oliM0?o<F03ocET00P3oc5P20?o=F@0<0?o<F03ocET0oleI
0?o<F03ocET0olaH0<BA@00000007A460?n`A03oke`0onEI0P3oiEP01`3oiEX0onEH0?oUF03oieh0
onEJ0?oUF03oj6000P3oiEP01P3oiEH0onEH0?oUF03oiEL0onEH0?oUE`80onIN00/0onEG0?oVH`3o
iU/0onEH0?oUE03oiEH0onEH0?oVG03oiE/0onEG0?oUF@020?oUF0060?oUE`3oiUP0onEH0?oUF03o
i5L0onML0P3oiEP02@3oiE/0onEI0?oUF03oiET0onIH0?oUEP3oiEP0onEI0?oVG@030?oUF00A0?oU
EP3oiUT0onEH0?oUF@3oiEP0onEK0?oUF03oiUl0onIM0?oUE`3oiE`0onEH0?oUE`3oiEP0onEI0?oV
FP3oiEL00P3oiEP04P3oiUd0onEK0?oVFP3om5`0olQ<0<^1<@14:Q40000001lH2@1fGB80ikU40?ol
G@3ol5P0oo1L0?o`F`3olEd0oo1G0?o`F0<0oo1I00D0oo1L0?o`F@3olEd0oo1G0?o`F0020?o`F@05
0?o`F03ol5L0oo1L0?oaG03olF800P3ol5P50?o`F@070?o`F03ol5d0oo1K0?oaG03ol5X0oo1G0?o`
F0060?o`F@050?o`G03olF00oo1I0?oaH@3olEd00P3ol5P02@3ol5T0oo=J0?ohG03ooel0ooEK0?oB
CP3Q/D40R6`X00h90`030000000501@:1@1::Q80NdLO0=^0=@3o_dl00P3oheh00`3ofU/0omAG0?oD
E`020?oDE`0<0?oDE@3oe5L0om9F0?oDG@3oe5`0om5E0?oEEP3oeV40om9D0?oDE`3odUH0om=G2`3o
e5L03@3odeH0omAG0?oBEP3odUP0omEO0?oDE`3odU@0om=L0?oFHP3odUH0om5G0?oDE`3oeEH04@3o
e5L04`3odUH0omAE0?oDE`3odUH0omEM0?oEH03oe5/0om5E0?oBEP3oeV40omIS0?o<D03oaDT0ol53
0?o2@`3oa4L0olY=0?o@E03oeET05`3oe5L01P3oe5H0omAE0?oBEP3oe5L0omAF0?oDFP80omEP00H0
omEK0?oAE@3ode<0om9L0?oEI03oeF<20?oDE@040?oDE`3odUH0omAE0?oBEPT0omAG00@0omEH0?o@
E03obTh0olM71P3oaTL00`3oadT0olQ80?o6A`0:0?o6A`030?o7B03oadT0olI700L0olI700D0olY9
0?o6A`3oadP0olE70?o8B0020?o7A`0;0?o6A`3ob4L0olI70?ni@`3o^T40oke40?o4A`3oaTL0olM9
0?o4A`3o_TD00P3o^dD0103ob4L0olE80?o5B03oa4L20?o5A`070?o6B03oa4L0olA70?o6B03oa4H0
oki50?o4A`020?o3A`030?o4A`3oaDL0olA700L0olA700D0ola:0?oTE03ohU80on5?0?oMPP3o0?oo
ojd0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWmP3oool0
2038WHH0QD@O08E57`25AAh0[U/W0?nbC@3o]U00okE@4P3o]Dh00`3o]U00okE>0?neCP020?neCR@0
okI@00@0okE>0?neC`3o]Dh0okA>0P3o]U00103o^4l0okUD0?nkF`3o_F020?nkFP80ok]K0P3o^eXH
0?nkF`070?nkFP3o_5d0okiR0?nkF`3o_5h0okaL0?nkFP040?nkF`80ok]J00d0ok]K0?njF03o_5`0
okmT0?o1J03o_F00okYH0?nkFP3o_El0okeR0?nlGP3o^eX0ok]K00<0ok]J0`3o^e/02@3o_5`0okMH
0?n/C03oZDP0ojM70?n/C03o]UL0ok]K0?nlG00:0?nkF`<0ok]J00P0okaM0?o1I`3o`V/0ok]K0?nk
FP3o_F00okeR0?nmG080ok]K00<0ok]J0?nkF`3o^e/03@3o^e/02P3o^eX0ok]K0?njE`3o_V80ol9Z
0?nlG@3o^eX0okeR0?nmH03o^e/20?nkFPX0ok]K0P3o^eX0203o_V00ol5V0?njFP3o^eX0okeP0?nl
F@3o^e/0ok]J1`3o^e/30?nkFP040?o1J03o_Ed0okaM0?nmG@L0ok]K00T0ok]J0?nkF`3o^e/0okmR
0?njF03o_F00okeN0?nkF`3o^eX00`3o^e/20?nkFP050?nlG03o_Ul0okeM0?nnGP3o^eX0103o^e/0
1P3o^eX0okeP0?nmGP3o^e/0okaM0?nkFP<0ok]K00H0ok]H0?nnH`3o_5d0okaL0?nkF`3o^eX20?nk
F`0F0?nmG@3o_V80okaL0?nmG03o/Td0ohlm07e0700G30D0000002TG2@33Kbl0okmE0?oGG@3oce`0
oliM0?o=F`3oc5P0oleI0?o<F03ocUh0oliL0?o=FP80oleI00P0olmN0?o=FP3ocET0oleI0?o>FP3o
c5L0oleJ0?o=F@80olaH00P0oliM0?o=FP3ocET0olmN0?o=FP3ocET0olaH0?o>F0<0oleI00`0oliO
0?o=FP3ocET0oleH0?o<F03od5X0ODLO00T50P2fLb`0ooAL0?oUFP3oiET20?oUF0040?oVF`3oiEP0
onEF0?oTE@80onEH00<0onQX0?oUF03oiEP00`3oiEP01`3oiEL0onEH0?oUE`3oiUh0onMN0?oUF03o
iET00P3oiEP01@3oiUX0onMM0?oUE`3oiUT0onEG0080onEH01@0onIL0?oUE`3oiEP0onEH0?oVG03o
iEP0onEI0?oVF`3oiEX0onEH0?oUF@3oiUd0onEI0?oUF03oi5X0onIJ0?oUF03oiEL0onEI0?oWG080
onEH00<0onEG0?oVFP3oiET00P3oiEL01P3oiel0onEG0?oUF`3oiET0onEH0?oVFP<0onEH00<0onEI
0?oVFP3oiET00`3oiEP01`3oi5X0onEI0?oVF@3oke/0oo1K0?o9C02:F2800P0000001P0N60T0ZhLb
0?oiG03om5X0oo1I0?o`FP80oo5N00P0oo1G0?o`F@3ol5T0oo1H0?o`F@3olE/0oo5L0?oaG`H0oo1I
00@0oo5M0?o`F03olE/0oo5K1@3ol5T20?o`F0060?o`F`3ol5T0oo5L0?oaH03ol5T0oo1H1@3ol5T0
1P3ol5P0oo1I0?o`G@3ol5X0oo1H0?obH@80oo1H0P3ol5T0203oleX0ooQL0?omGP3okeP0l/180>Jh
@`34VcP0G4PK0`0000002@0>20<0?bD?06Dl6@2bJBX0njE50?oLG03ogE`0omYJ0?oDF0030?oDE`0:
0?oCE`3oeEH0omEF0?oDE`3oe5`0om5E0?oBEP3oe680omEL0?oDE`80omEF303oe5L03@3oe5H0omAG
0?oBEP3oe5X0omAM0?oEEP3odU@0omEK0?oGH`3ode<0om5G0?oEEP3odeL04@3oe5L00`3oeEH0om9F
0?oCE`020?oDE`0;0?oCG03oe5d0omAH0?oAD`3ocU80okI40?nl@P3o`D@0olE80?o@DP3oeeP0703o
e5L20?oBEP0=0?oCE`3oe5L0omAE0?oDFP3oeEh0omEM0?oBEP3oe5D0om9F0?oEH`3oeFH0omES0?oB
EP020?oDE`030?oBEP3oe5H0omAG0080omAG00@0om=G0?o?D03oadT0olA61`3oaTL20?o8B0`0olI7
00<0olU80?o6A`3oaTL01P3oaTL00`3obTT0olI70?o6A`020?o6A`030?o5A`3ob4L0olI70080olI7
00<0olE50?o4A03oa4H00P3oa4L00`3oaDL0olA70?o1AP020?o0AP80olE700<0olI80?o4A`3o^dD0
0P3o^dD01`3oaDP0olM90?o2A`3oaDT0ol960?o4A`3oaTP00P3oa4L00`3oadT0olA70?o4A`040?o4
A`070?o5A`3o`dL0om==0?oTD`3oh540on9A0?oX`P3o0?ooojd0oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWmP3oool00`3oi^80XUPb0852700208I67`030>N6
>`3o]Tl0okI@00H0okE>00<0okE@0?neCP3o]Dh03P3o]DhG0?nfD0040?nfC`3o]U00okI@0?neC`@0
okI@0P3o]Tl:0?nfD0040?nfC`3o]U00okMB0?njF1P0ok]K0P3o^e`20?nlG@030?nlG03o_V00okaL
0080okaL0P3o^e/00`3o_V40okmS0?nmH0020?nkFP060?nnH@3o_f<0okeO0?nkFP3o^e/0okaO0P3o
_5`;0?nkF`090?nhF03o]5@0oji>0?nYB@3oZd/0ojm@0?ndE@3o^UX0okaL00<0ok]K0P3o_5`20?nk
F`090?nnH03o_f<0okiQ0?nkFP3o_5h0okiR0?noH`3o_5/0ok]K0080okaM403o^e/01@3o_5`0ok]K
0?nkF@3o_5l0okeQ0080ok]J00H0okmT0?nnGP3o^eX0okaL0?nlGP3o_5`90?nkF`0;0?nkG03o_5`0
ok]J0?nnH@3o_V<0ok]J0?nmGP3o_f40ok]K0?nlG03o_5d01`3o^e/20?nlG0090?nkF`3o_El0okeM
0?nkF03o_V40okeN0?nkF`3o_5d0okaL00@0ok]K00T0okaL0?nkF`3o_5`0okiR0?nlF`3o_f40okeP
0?nkF`3o_5`0103o^e/0203o_5`0ok]K0?nmG`3o_5`0okmQ0?nlG03o_5X0okaL0`3o^e/01@3o_5/0
okaN0?nmG@3o^eT0okeM0080okaL0P3o^e/0103o_5`0ok]K0?nnH03o_5d20?nlG0050?nkG03o^e/0
ok]K0?nlG03o_V000P3o_Ed02`3o_5`0ojiF0:MZ<`0n80d03`P301<;1@1hCb<0hZ150?o3E@3ocUX0
om1L0080oliK0P3ocEX30?o>F`80oleI00@0oliK0?o>G@3ocET0oleJ0P3ocET02`3ocUX0oleK0?o=
F@3ocET0oliK0?o=F@3ocEP0oleI0?o>F`3ocU`0oleJ0080oleI00L0oliK0?o>FP3ocET0oliJ0?o>
G03ocEX0oleI0080oliK00L0om=L0<V;?@0E30D0XV/Z0?oWF@3oj5T0onIJ0080onEH0280onIM0?oU
F03oiEP0onML0?oVG03oiEP0onEG0?oUEP3oiEP0onIK0?oXHP3oiEL0onEH0?oUE`3oiEP0onEG0?oV
GP3oied0onEH0?oUE`3oiEH0onEH0?oVF@3oiUX0onEG0?oUF03oieh0onEI0?oUF03oiUT0onIL0?oU
E`3oiEP0onII0`3oiEP01@3oiET0onEH0?oUF03oiEP0onIH0080onEH00<0onII0?oVFP3oiEP00P3o
iEP02@3oiU/0onEG0?oVG03oiU`0onIK0?oVG@3oiEP0onEI0?oVF@020?oVF`050?oUF03oiET0onEJ
0?oVF@3oiUX00`3oiEP00`3oiU`0onII0?oUF0020?oUF00@0?oUF@3oiUX0onML0?oYF@3oheL0l;]8
09Ql<01^AQ/04P`5038X3`1nHbD0]:8l0?cUE@3ole/0oo9J0?oaG080oo5K00<0oo1I0?o`FP3ol5T0
0P3ol5X01P3ol5P0oo5L0?oaG03olE/0oo1I0?o`FP80oo1I00L0oo1J0?o`F@3olEd0oo5I0?oaFP3o
lE/0oo1J00@0oo1I0P3ol5X01@3olE/0oo5N0?o`E`3olEd0oo5J0080oo1J1@3ol5T0803ol5X0oo1H
0?oaGP3olEd0oo5J0?oaG`3ol5X0oo1I0?obFP3omE/0ooIK0?odFP3ok5X0on5D0>;8B`2mYSh0S7L/
05m<700j;Q405A46018:1@0V5PT0CblC07]97P2GLc00dY]00?neB`3obU@0om=G0?oFF03oeeT0omEH
0`3oe5L0303oe5T0om=H0?oDEP3oeEh0omEM0?oBEP3oe5/0omEP0?oEE`3oe5L0omEH0?oCF0T0omAG
00L0omEG0?oDE`3oeEL0om=H0?oEF@3odeL0om9E0080omEM00H0om=E0?oCE`3oe5`0omEM0?oDE@3o
e5L20?oEF0h0omAG0P3oeEL20?oDE`0<0?oEF03odED0ola>0?o8B`3o`dH0ok]30?o2B`3obTh0oliB
0?oEF@3oeUl0omEN0P3oe5L20?oEF0030?oCF03oe5L0omAG01H0omAG0P3oeEL30?oDE`80omEI00`0
om=I0?oDE`3odeH0omEH0?oFH@3oeV00om=H0?oAE@3odU80olY;0?o4AP3o`dD20?o7B0040?o6A`3o
aDL0olM80?o7B0<0olI700<0olM80?o6A`3oaTL01P3oaTL20?o7B0040?o6A`3oadP0olI70?o7B0L0
olI700d0olM80?o6A`3oaTL0olI70?o8B@3ob4P0olI80?o7B03oadL0olQ80?o3A@3o`T@0ol=60080
olA700<0olE70?o6B03oa4L0103oa4L20?o5A`070?o1A@3o`dH0ol970?o4A`3oaDL0olI80?o4A`03
0?noAP050?o5B03oaTP0olE80?o5B03o`DH00P3o_dH0203o`TL0olI80?o4A`3obDT0on9B0?oSD@3o
ge40on6Oo`3ooon^0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWioL0oooo00P0on?S0:5I<P1n@1P0RTPQ08947P3oVT<0okQA0?neC`D0okE>00<0okE@0?neCP3o
]Dl03P3o]DhA0?nfD0040?neC`3o]Dh0okE>0?ndCQX0okI@00<0okIA0?njE`3o^e/04P3o^e/03P3o
^eX0okaL0?nkFP3o_F00okmR0?nlG`3o_Ed0ok]J0?njF03o_f<0ol5Y0?o0I@3o^UP0ok]J303o^e/0
0`3o_F00okaL0?nkF`060?nkF`080?nlG03o^UX0ok5B0?nXB03oYdL0ojU80?ncD`3o^eX30?nkF`08
0?nlH03o_5h0okaL0?njF@3o`FL0ol9Z0?nnGP3o^eXD0?nkF`0:0?nkFP3o^e/0ok]J0?nlGP3o_5`0
ok]J0?nkF03o`VP0okaK0?njFA00ok]K00H0okaL0?nlG@3o^eX0okeQ0?o2JP3o_5`;0?nkF`070?nk
FP3o^e/0okaN0?nkF`3o_V80ol1V0?njF00:0?nkF`050?nlGP3o_5`0okeO0?nnHP3o^UT01`3o^e/0
1@3o_5`0okaM0?nlF`3o`FL0okYH00H0ok]K0`3o_5`00`3o_V40ok]J0?nkF`030?nkF`040?nkFP3o
_5`0okaL0?nnHPH0ok]K0100okaJ0?noH`3o^eX0okmL0?noG@3oW4`0UE0X00<10@010@00<1`;0;QZ
;P3o_e@0om1K0?o>G03ocEL0om1R0`3ocET00`3ocEX0oliL0?o=F@020?o=F@0=0?o=FP3oc5P0oliJ
0?o=FP3ocU`0oleI0?o>G@3ocU`0oleH0?o=F@3oc5P0oleI0?o>F`030?o=F@050?o>G@3ocET0oleI
0?o=F@3ocU/01P3ocET20?o<F00;0?oIG`3oU4007106050b503ok5X0onEH0?oTFP3oiUT0onEH0?oU
F@3oiEH00P3oiEP0103oiEH0onEH0?oUF03oj6020?oUF0070?oVF`3oj680onEF0?oUF03oiEL0onEH
0?oUE`020?oVGP080?oUF03oiEL0onMX0?oUF@3oiEP0onEG0?oTE`3oiEP20?oUE`80onEH00D0onAG
0?oUF@3oiEP0onEH0?oUEP020?oUF0050?oUF@3oiE/0onEG0?oUF03oiET00`3oiEP01@3oiUT0onIK
0?oUF@3oiEL0onMN00@0onEH00L0onEK0?oUF03oiEL0onEH0?oUE`3oiE/0onAJ00@0onEH00<0onIJ
0?oUF@3oiEP00P3oiEP00`3oiET0onIJ0?oUF@030?oUF00C0?oUE`3oiU/0onII0?oVF03ojUT0jK=5
03/U3P081@80000003H[403Y^d@0on9D0?ohG03om5X0oo1I0?oaG03olEl0oo1J0?o`F0040?o`F@06
0?o`EP3olEh0oo5K0?o`FP3ol5T0oo1H103ol5T01@3ol5P0oo9T0?oaF`3ol5T0oo1J00L0oo1I00L0
oo1H0?obH`3olEh0oo1H0?o`F`3ol5T0oo1H00L0oo1I00L0oo1G0?oaG03olEl0oo1H0?o`G03ol5X0
oo1H0080oo5L00X0oo5H0?obFP3olUX0oo=J0?obFP3Q]4<0Q6HU03P/400Q6@X01PD20P0000002@03
0@00OdXO0?nF?`3o^T`0ol9A0?oGF@3ogE`0omUJ0?oGF0080?oDE`060?oDFP3oeFD0omEM0?oBE03o
e5X0omEH0P3oe5L00`3oeEH0omAG0?oDE`0>0?oDE`080?oAE@3odeL0omEU0?oDGP3odED0omAG0?oE
F`3oeET20?oDE`030?oEEP3oeEL0omAG00h0omAG00H0olU<0?o2A03o`D<0ol940?o8C03odUD20?oE
F0090?oBE03oeV@0omEV0?oDH03odED0om9H0?oEF`3oe5`0omEG0080omAG00<0omEF0?oEE`3oe5L0
6@3oe5L0103oeEL0om=F0?o?D03oadT50?o6A`0:0?o9B@3oaTH0okm40?o2A03oa4H0olM90?o5A`3o
aTL0olI60?o7B080olE700D0olI70?o5A`3oaDL0olE70?o7B0020?o6A`040?o9B03oadP0olI70?o:
B@h0olI700H0olQ80?o7B@3oadH0ol=50?o2A03o`dH50?o4A`060?o5A`3o`dL0olA70?o5A`3o`DH0
olE80P3oa4L0103oaTP0olA70?o4A`3oaDL70?o4A`0;0?o5B03oaDT0olA70?o4A`3oaDL0olA70?o7
A`3oeTd0on9B0?oNA`3of:00o`3ooon_0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWioL0oooo00L0ooko0?nm[01n?aL0Q4DN08Y8802kHRX0ok9=00H0okE>00<0
okE@0?neCP3o]Dl0203o]Dh00`3o]U00okE>0?neCP030?neCP/0okI@0P3o]E000`3o]Tl0okI@0?nf
D00P0?nfD0030?nhC`3o^EH0ok]K00/0ok]K0`3o^eX03@3o^e/0ok]J0?nlG@3o_Eh0ol1U0?nkFP3o
^UL0okaL0?o1J@3o_fD0okYG0?nkFP3o^e/00P3o^eX>0?nkF`030?nkG03o_F40ok]K00@0ok]K0100
okaL0?nkF`3o]UH0oje=0?nWA`3oZDP0oja;0?ndE@3o_5`0okiR0?nmGP3o^e/0okaK0?o1J@3o`6H0
okeM0`3o^eXB0?nkF`0<0?nkFP3o^e/0ok]K0?nlGP3o_640ok]K0?njE`3o`6H0okeQ0?njF@3o^e/0
ok]J303o^e/02`3o^eX0ok]K0?nkFP3o_F00okaL0?njF03o_F00okmR0?njF@3o^e/0ok]J00P0ok]K
0P3o^eX0203o^e/0okeO0?nkFP3o^e/0ol5W0?nlGP3o^e/0ok]J1P3o^e/20?nkFP060?nkF`3o_5d0
ok]J0?o1IP3o_Eh0ok]J1@3o^e/20?nkFP060?nlG@3o^e`0okeM0?nnH`3o^e/0ok]J103o^e/20?nk
FP040?nlG`3o_V00okmU0?nkF0D0ok]K00@0okaM0?nkF`3o_F00okeN103o^e/30?nlG0050?nlGP3o
_E`0olEQ0?njF`3>M3P00`0000001P1c@AT0okQ=0?oHG`3ocET0oleJ0?o?H@80olaH00D0oleI0?o<
F03ocET0oliM0?o>G0020?o=F@040?o<F03ocE`0oliL0?o=E`80oleI00L0olaH0?o>G`3oc5P0oleI
0?o=FP3ocET0oliM0080oleI00X0olaH0?o>G@3ocE/0oleI0?o<F03ocET0oliK0?o=F@3oc5P0oliL
0`3ocET0703ocEX0om1K0?o5EP1=;1@0000009am<03oiUP0onIJ0?oUG@3oiEP0onEG0?oWGP3oiET0
onEH0?oVG03oiUh0onEG0?oUF03oj6@0onEI0?oUF03oiUT0onIJ0?oUE`3oiEP0onEG0?oUF03oiEL2
0?oWG0070?oUF03oiEL0onMX0?oUF@3oiEL0onIO0?oWHP020?oUF0080?oXH03oiET0onEH0?oWG03o
iU`0onEG0?oUF03oiE/30?oUF0050?oUEP3oiEL0onEH0?oUF03oiE/00P3oiET00`3oiUX0onEH0?oW
G`020?oUF0030?oTFP3oie`0onEH0080onEH00<0onIJ0?oTE@3oiET00P3oiEP00`3oiUT0onIK0?oU
F0020?oUF0030?oVF@3oiUX0onEH0080onEH00D0onEG0?oVFP3oiU`0onEH0?oUE`030?oUF00B0?oW
G@3oiET0onEI0?oZFP3oh5L0cH4b04/_4P020@40000004`l5P3CYSd0oniH0?ogF`3ol5T0oo1G0?oa
GP3ol5P0oo1J1@3ol5T0103olEX0oo5O0?o`F03olEh50?o`F@070?o`F03ol5T0oo5N0?oaG03ol5/0
oo1J0?o`F0050?o`F@080?o`F03ol5T0oo1G0?obGP3ol5T0oo5N0?o`FP3ol5P70?o`F@080?o`F03o
l5L0oo9T0?oaG03olE/0oo1I0?oaG03ol5/40?o`F@080?oeF`3onUd0oomO0?oBC@2SP2l0C3`F02dT
3@0>2`@20000000900P30@1N=AH0eG`d0?n/B03o_dh0om5F0?oPG@3ofU/0omMH00H0omAG00`0omEF
0?oDE`3oe5D0omIP0?oCG03odED0om9H0?oDG@3oe5D0omAG0?oBEP3oeEL>0?oDE`0>0?oEEP3oeEL0
omAE0?oCF@3oeF@0omAM0?oBE03oe5X0omEM0?oDF@3oe5L0omEF0?oBEP3oeEL;0?oDE`030?oEF03o
bdh0olI90080ol5300@0olI90?o>D@3odUD0omAI0`3oeEH03@3odeH0om=I0?oEH`3oeFD0om=H0?oB
EP3oe5X0omAN0?oEF`3odUH0omAG0?oEEP3odUH05@3oe5L0103oeEP0om=F0?o;C@3oa4H20?o6A`03
0?o7B03oaTL0olI700<0olI70P3oaDL02@3oaTL0olE70?o9B@3ob4L0okm50?o1B03obDT0olM90?o8
B0030?o4AP<0olI700<0olQ80?o6B03oaTL03@3oaTL0203ob4P0olM80?o6A`3oaDL0olI90?o4A@3o
`T@0ol=6103oa4L01@3o`dH0olI80?noA@3o`TH0olE700<0olA700<0olE70?o4A`3oa4L00P3oa4L2
0?o5A`@0olA700<0olI70?o6B03oaDT00P3oa4L01`3oaDL0olA70?o=BP3ohe80on1=0?oFLP3oo_l0
o`3ooon_0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWioP0
oooo00L0oo_o0>:7I01o@AT0QDDO08137@3oRSd0okQ@00D0okE>00<0okE@0?neCP3o]Dh03@3o]Dh0
0`3o]E00okI@0?nfD0020?nfD0030?neD03o]e00okE>02X0okI@00@0okM@0?njE@3o^eX0okaL103o
^e/03P3o_5X0okaI0?nkFP3o^e/0ok]J0?nmH@3o_f@0okaQ0?nlG03o^UP0okeP0?noI@3o_f<0okYG
0P3o^e/00`3o_5X0ok]J0?nkF`0C0?nkF`80okaL01<0ok]J0?nkF`3o^e/0okaL0?njF@3o/U00ojY9
0?nVAP3o[4h0okQL0?nmH@3o^eX0okaK0?o1J@3o_V<0ok]J0?nkF`3o_5T0ok]J0180ok]K0P3o^eX0
2`3o^e/0okeK0?noI@3o_5h0okYI0?nmH03o_fD0okaK0?nkFP3o_5X0ok]J00`0ok]K00T0okaI0?nk
FP3o_5/0okiS0?nmG@3o^EL0ol1T0?nlG@3o^UT02`3o^e/01`3o_5T0ok]J0?nmH@3o_600okYI0?no
H`3o_Ed00P3o^eX70?nkF`060?nkFP3o^e/0okiS0?nlG@3o^e/0okeO0P3o^eX70?nkF`060?nmGP3o
_5h0okeO0?nlGP3o^UT0ok]J1@3o^e/0103o_5`0okeN0?njF@3o_V420?nkFP<0ok]K00H0ok]J0?nk
F`3o_5d0okeN0?nmH03o^eX30?nkF`0B0?nlF@3o_Ed0ok]K0?nnGP3o^e/0ol9N0?noG@3oS4@0V54X
00D20@000000B2TA0:mS9P3o^dT0om1J0?o<F03ocET0olmM103ocET00`3ocEX0oleI0?o=FP030?o=
F@030?o=G03ocEX0olaH0080oleI00D0oleJ0?o=E`3ocUX0oleL0?o=FP020?o>G080oleI00P0olaH
0?o=F@3ocET0oleI0?o<F03ocET0oliJ0?o=F@80olaH00d0oliL0?o=FP3ocET0oleJ0?o>GP3oe5d0
Zf8/000000061@80olI<0?oUF@3oiUX0onAE0080onEH00P0onII0?oUF03oiEP0onEH0?oUF`3oiEL0
onEH0?oVFP80onEH00D0onEG0?oUEP3oiEP0onEH0?oUE`020?oUF080onEF00L0onEH0?oUE`3oiV00
onEI0?oUE`3oiUX0onEK0080onEH00d0onEK0?oTE@3oiEP0onEF0?oUF@3oiU/0onEH0?oUE`3oiUX0
onEG0?oUF03oiUX0onIK0080onEH00L0onIO0?oVFP3oiUX0onMN0?oUE`3oiUX0onEI0080onEH00<0
onEI0?oWG03oiEP00P3oiEP00`3oiEL0onIJ0?oUE`020?oUF0030?oVF@3oiU/0onEH00<0onEH00<0
onIJ0?oVF`3oiEP00P3oiEP00`3oiEH0onIJ0?oTFP030?oUF0080?oUE`3oiUX0onIK0?oUF@3oieT0
ooEM0?oME@2EGb@30000000:08]_:@3ogU80oomP0?oeF`3ol5P0oo5M0?oaF`3ol5`0oo1J0?o`F0<0
oo1I00D0oo1H0?o`E`3olF80oo1J0?o`F`020?o`F0<0oo1I0P3ol5P01@3olEd0oo1J0?o`F`3ol5/0
oo1H00H0oo1I00H0oo1H0?oaFP3olF<0oo1I0?o`G03ol5T20?o`F0H0oo1I0P3ol5P01`3olEh0oo5L
0?o`D`3olV80oo1J0?o`F@3ol5P0103ol5T0203omE/0ooeO0?olG@3mbT/0a9Xi079I8P0`9Ph00`80
0P0000002@0G3@D0FC@E09UJ9P3^TS`0oke>0?oIFP3oiel0omaK0?oFE`060?oDE`0:0?oCE`3oe5L0
om9F0?oCF@3oeF80om1C0?oDE`3odel0omEJ0?oDE`80om9F3`3oe5L03P3odUH0om=G0?oDE@3oeU`0
omES0?oDFP3odU@0omEK0?oDH@3oeET0omAG0?oEEP3odUH0omEG203oe5L02@3oeEP0omAG0?o:C@3o
`DD0ol530?o1@P3oaTT0om1C0?oEF0040?oDE`0@0?oBEP3oe5D0om=G0?oDE@3ode`0omAT0?oEGP3o
dU@0omAE0?oCG03oeV00omAE0?oEEP3oe5L0om=F0?oEEPh0omAG00@0omEH0?oBEP3odE80ola;103o
aTL00`3oadP0olI70?o6A`090?o6A`0;0?o7B03oaDL0olI70?o6A`3obDP0ol970?o0AP3o`DD0olM9
0?o7A`3oadP00P3oa4L20?o6A`040?o9B03oadP0olQ80?o5A`P0olI700T0olM90?o7B03oaTL0olI7
0?o7B@3o`dH0ol530?o5A@3oa4L00P3o`dL00`3oaDL0ol960?o4A`020?o4A`030?o5A`3oa4L0olA7
0080olE7103oa4L20?o5B@D0olA700@0olE80?o5B@3oa4L0olE70P3oa4L0103oeTh0on=B0?oJC`3o
m^Wo0?oook00oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
n@3oool01P3ok^/0[VY808I67P23A1h0TT`Q0?^XBPD0okE>00/0okE?0?nfC`3o]Tl0okE>0?nfD@3o
]Dl0okE>0?nfC`3o]U00okE>0?neC`020?neCP80okI?00<0okE?0?nfD@3o]U00<@3o]U00403o]Tl0
okI@0?nhD`3o^e/0okeN0?nkFP3o^UT0okiQ0?noI03o_V<0ok]I0?nmG03o_f80ol1T0?nlGP3o_5`3
0?nkF`030?nlF`3o^e/0ok]K01P0ok]K00l0ok]J0?nnH03o^U`0okMF0?nbD03oYTP0oj960?n[C03o
]5<0ok]K0?nnH03o_Eh0ok]J0?nkF`3o_5X04`3o^e/01P3o_5h0okmR0?nlG@3o^eX0okmT0?nnH`80
okaK00@0okiP0?nmG03o^e/0okaK3@3o^e/02`3o_5X0okiQ0?nlG03o_5d0okmU0?nnG`3o_5/0okeO
0?nlG@3o^e/0okaK00T0ok]K00P0ok]J0?nnG`3o_5d0okaL0?noI@3o^e/0okeN0?nlGPT0ok]K00L0
okaN0?nlG03o_5/0okmS0?nkF`3o_Ul0okaM00H0ok]K00D0okaL0?nmG`3o_5`0okeO0?nkF`020?nl
G@H0ok]K00H0okeP0?nkFP3o_Eh0okaK0?nlG@3o^e`40?nkF`050?nlG@3o_5`0okeQ0?nkF`3o_5d0
0`3o^e/04@3o_5`0okeO0?nkF`3o_V80okaL0?noG03o`Eh0ojUB0:IX<`1491802`H302@E2@29F2L0
iJ=60?niB03o`DT0olQE0080oliK103ocET00`3ocE`0oliM0?o>F`020?o=F@090?o=F`3ocEP0oliL
0?o>F`3ocET0oliJ0?o=FP3ocUd0oliJ0080oleI00<0oliL0?o?GP3ocEP00P3ocET01`3ocUT0oliJ
0?o>FP3ocET0oleJ0?o=F@3ocUX00P3ocET20?o>G080oleI00X0oliJ0?o=F03od5/0fIi401<:1@0N
4`P0bi@h0?oXFP3oiUX0onII0P3oiEP02@3oiUX0onEI0?oUF03oiUT0onMM0?oUE`3oiEP0onIJ0?oV
F0020?oUF0050?oVF03oiEP0onEH0?oUF03oiEL00P3oiEP20?oUE`80onEH00@0onEF0?oUE`3oiEP0
onEG0P3oiUX20?oUF0050?oWG`3oiEP0onEH0?oVFP3oiU/00P3oiEP02`3oiUT0onIJ0?oVF@3oiEP0
onIH0?oWG@3oiUP0onIK0?oUF@3oiEX0onIH0080onEH00<0onIG0?oVF@3oiEP00P3oiEP01`3oiU/0
onEG0?oUF03oiEP0onIJ0?oWF`3oiUT00P3oiEP0103oiEX0onEH0?oUE`3oiET20?oUF0030?oUFP3o
iET0onIJ0080onEH0P3oiUT00`3oie`0onEJ0?oUF@020?oUF00E0?oVF@3oie/0onEG0?oVFP3ojET0
onUJ0>c1BP2bRC@0NDdN020D200Z8@d0G4TK0:JA=@3/g580ooML0?oaF@3olEX0oo5K0?oaG@3olET0
oo5L00@0oo1I00D0oo5J0?oaF03olEd0oo5L0?oaFP060?o`F@070?oaF`3olEX0oo5N0?oaF`3olEX0
oo5K0?o`F0060?o`F@040?oaF`3ol5P0oo5M0?oaG@80oo5J203ol5T0203ol5P0oo5L0?oaF@3olE/0
oo9Q0?oaF03olE/0oo5J0`3ol5T05`3olET0ooAK0?ohG03omE`0oN1C0>G?C@3=_4L0Y8Pb06]E801C
A1T0<RP?018=1P0Z6@X0AbXB06Dk602LJ2/0_IHn0=nZA`3o_Dh0omII0?oIFP3of5T0omAH00D0omAG
00D0omEG0?oCF03oe5/0omAH0?oCEP020?oFGP030?oCE`3oeU/0omAL0080omAG00<0om=G0?oDE`3o
e5L02P3oe5L0403oeEL0om=G0?oDE`3odeH0omAI0?oEG03oeEP0om9F0?oEG@3oeF00om=I0?oCE`3o
de`0omIM0?oDF03oe5L20?oCE`<0omAG00X0omEI0?oAE@3obDd0olA90?o2A03o`TD0olM:0?o>D@3o
dE@0omEH1P3oe5L04P3oe5H0omAG0?oDE`3odeH0omEJ0?oDG03odeH0om9E0?oDE`3oeF40omAM0?oD
EP3odeH0omEJ0?oFG@3oeEX0omAE0?oDE`80om=G0`3oe5L0103oeEP0om=F0?o=D@3ob4T60?o6A`03
0?o7B03oaTL0olI700T0olI700<0olM80?o6A`3obDT00P3oadP01P3oadL0olI70?o7B03oaTL0olI8
0?o7B080olI800d0olI70?o7B03obTT0olE70?o2AP3oa4H0olI70?o7B@3oadL0ol=60?o4B03oaTL0
olI80080olI700`0olM70?o6A`3oaTL0olQ80?o4AP3oaDD0oke40?o1AP3oaDL0olA70?o4B03oaDL3
0?o4A`030?o7B@3oaDL0olE700<0olA700<0olM80?o4A`3oa4L00P3oaDT50?o4A`090?o5B03oa4L0
olE70?o4A`3oadP0oma?0?oSD@3ogDd0onFW0?l0oooo/@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOj0?ooo`070?31/P25A1`0R4LO07a0703=NcH0okUB0?nd
D0020?ndCP<0okE>00<0okE?0?neCP3o]E000`3o]Dh00`3o]E00okE>0?neCP050?neCP030?neD03o
]U00okI@02d0okI@00<0okE>0?neD03o]Dl00`3o]U002@3o]e00okQF0?njFP3o^e/0ok]I0?o0IP3o
_5/0ok]K0?nlGP020?nkFQ/0ok]K00P0ok]J0?njF@3o`FL0ol1W0?njE`3o^eX0okIG0?nZC080ojI7
00@0ok1@0?njF@3o_5`0okaL4`3o^e/02P3o^eX0ok]K0?nlG03o`6L0ol5X0?nkF@3o_Ed0okeR0?nl
G03o^e/20?nkFPh0ok]K0`3o^eX01`3o`6D0okYI0?nkFP3o_V00okaM0?nkF`3o^eX02`3o^e/02@3o
^eX0okYI0?noHP3o_5`0okYH0?nnGP3o_5d0ok]K0?nkFP080?nkF`060?nkFP3o_Ed0ol5W0?nlG03o
_5d0okaL0P3o^eX70?nkF`060?nkFP3o_V80ok]J0?nlGP3o_5`0ok]J1P3o^e/01@3o^UT0okeO0?nk
FP3o_F00ok]J00D0ok]K00<0okaI0?nmG@3o_V<00P3o^e/05`3o^eX0ok]K0?nkF`3o^e/0ok]J0?nm
GP3o_El0okeN0?nkF`3o^eX0ol5N0?n?AP1[>A`07Q08000000129Q00gWlh0?niD03oeEd0ol5;0?nk
AP3o^d/0oleJ00<0oleI00@0oleH0?o?H@3oc5P0oleL0`3ocET00`3oc5H0oliL0?o=F@020?o=F@03
0?o=F`3ocUd0olaH00<0oleI00H0olaH0?o>FP3ocU/0oliM0?o=FP3ocU`30?o=F@030?o<F03ocUd0
oleI0080oleI00h0oliM0?o=FP3ocET0oleI0?o>G03ocE`0oliJ0?oBG01/?Q`000000>nG>P3olE/0
onEG0?oVFP80onEH00<0onIL0?oUF`3oiEL01@3oiEP01P3oiUd0onMJ0?oUF03oiEL0onMP0?oUEP80
onEH00D0onEG0?oUF03oiEP0onEH0?oUEP030?oUF0050?oVG03oiEP0onEG0?oVGP3oiU/00`3oiEP0
3@3oiUT0onEH0?oUF03oiUX0onEH0?oUE`3oieh0onML0?oVF`3oiET0onEG0?oUF03oiU/00`3oiEP0
103oiU`0onEG0?oUF03oiEP20?oUE`80onEH00<0onEI0?oVF@3oiEH00P3oiEP00`3oiET0onIJ0?oU
E`030?oUF0030?oUE`3oiU/0onEG00<0onEH00<0onIK0?oVFP3oi5D00`3oiEP00`3oiET0onIJ0?oT
E@040?oUF0080?oVF@3oiEL0onIJ0?oUF03okEX0ooEM0?o3B`1jCAh200000006028J2P2_Rc<0onmH
0?ohG03ol5T0oo1H0P3ol5X00`3olUh0oo1I0?o`F@040?o`F@050?o`F03ol5/0oo1G0?obI03ol5L0
1@3ol5T20?o`F0050?o`FP3olE/0oo9S0?o`FP3ol5P0203ol5T01P3ol5/0oo1I0?o`F03olV<0oo5I
0?o`F0P0oo1I00P0oo1H0?oaFP3olE`0oo1I0?oaFP3olV@0oo5J0?o`F0H0oo1I00P0ooQL0?ooG`3o
n5`0on5C0?W8B`2gTSL0LE/R02PP3@<0000000L081<705@a5@2mKBh0oj520?o?EP3og5/0omMH00P0
omAG0P3oeEH02@3odeL0om=K0?oCG03oe5L0om=I0?oGH`3oeE/0om5E0?oEE`0A0?oDE`0<0?oEEP3o
dUH0omAG0?oDE`3ode`0omEM0?oEE`3odUH0omES0?oFI03oe5P0omAG0P3oeEH01@3oe5L0omEH0?oC
E`3odUD0olI90080ol5300<0ol=50?o:C@3oeUX03P3oe5L04@3oe5H0omEF0?oDE`3odUH0omEJ0?oE
G@3oe5X0om9F0?oCFP3oef<0omEU0?oCE`3odeH0om9F0?o?CP3obDT0olE700L0olI700<0olY90?o6
A`3oaTL02@3oaTL20?o8B0h0olI701@0olM80?o5A`3oaDL0olI70?o7B03oaTL0olE60?o7B@3oadL0
olQ70?o9B@3oaTH0ol=70?o4A@3oadH0olU90?o6AP3oa4@0ol540?o6AP<0olA700H0olE90?o5B03o
a4L0olA70?o7B@3oaDL60?o4A`030?o5A`3oadT0olA700T0olA700D0om9;0?oRD@3oed@0omUo0?ol
o@3o0?oook40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
nP3oool01`3ol>`0Yehk07m16@28Ab80Z5LV0?nkDP3o]U001`3o]Dh01@3o]E00okE>0?neCP3o]Dh0
okE@00L0okE>00<0okE@0?nfD03o]U009`3o]U00103o]Tl0okE@0?neCP3o]4h80?nfD080okE>00@0
okE@0?nlG@3o_5d0okeM703o^e/03`3o^UT0ok]J0?o1J@3o_Uh0okUG0?nkFP3o_Eh0okeM0?niF03o
[e00ojU80?nXA`3oZDX0ok9B0?nkG@0D0?nkF`050?njF@3o_F40ol5/0?nlG03o^e/00P3o_Ed20?nk
F`030?nkFP3o^e/0ok]K00l0ok]K00D0okiP0?o1IP3o_EX0ok]J0?nlG@020?nkF`030?nkFP3o^e/0
ok]K00/0ok]K00@0okmU0?o1IP3o^eX0okaL303o^e/01@3o^UT0okeN0?nnH@3o^eX0okeM00X0ok]K
00@0okiN0?noI03o^eX0okaL203o^e/00`3o_Ed0okmT0?nlG0020?nkF`030?nkFP3o^e/0ok]K00<0
ok]K00@0okaM0?nmH@3o^eX0okaM1@3o^e/02@3o_5`0okiN0?nlG@3o_5`0okiK0?nmG03o^U/0/V@a
01@:1@020000000808mB903o_U<0om1J0?oCG03obUH0ok930?njA@3ob5@40?o=F@030?o>FP3ocEX0
oleI0080oleI00<0olaH0?o?GP3ocE`00`3ocET00`3oc5P0oliM0?o=F@030?o=F@060?o>FP3oc5H0
oleI0?o=F@3oc5P0oliM0`3ocET00`3oc5P0oliM0?o=F`030?o=F@0>0?o>FP3ocET0oleI0?o=F@3o
cUX0oleI0?oDG@3oZd/04@X408AD803ohEH0onaJ0?oVG03oiEL60?oUF0030?oVG03oiEL0onEH0080
onEH00D0onEG0?oUF03oiEL0onMQ0?oUEP020?oUF0050?oUE`3oiEP0onEH0?oUF03oiEL00`3oiEP0
103oiel0onEH0?oUF03oiEL30?oUF0070?oTFP3oied0onEH0?oUF03oiEH0onIM0?oUF0020?oUF@05
0?oVFP3oiEP0onEH0?oUF03oiEX00`3oiEP00`3oiU/0onMJ0?oUF0020?oUF0030?oVF@3oiEH0onEH
0080onEH00<0onII0?oUEP3oiEP00P3oiEP00`3oiUT0onEJ0?oUF0020?oUF0030?oVF@3oiEH0onEG
00@0onEH00<0onII0?oVFP3oiEP00`3oiEP00`3oiUT0onEK0?oUE`040?oUF00D0?oVF`3oiUX0onEG
0?oUF03ok5X0omeE0?nbA@1_AQX0000000D40@0`9`l0]90e0?o^F03olUX0oo5I0?o`F03ol5X0oo5L
0?oaG`3ol5P50?o`F@050?o`F03ol5/0oo1H0?oaGP3ol5P01`3ol5T0103ol5/0oo1H0?oaF`3olE/:
0?o`F@050?o`F`3olEX0oo9U0?oaF`3ol5P01P3ol5T00`3ol5P0oo1I0?oaFP020?o`F@050?o`F`3o
l5T0oo9S0?o`G03ol5L01P3ol5T02@3olET0ooAK0?ohG03olUX0onIF0?oMDP3J[D40KELP01hH2@02
0000000;00010@0D2PD0:1H;08=<803oUcl0oleD0?oDEP3oe5P0omMH0?oDF03oeUL01P3oe5L02@3o
eEH0omAG0?oEF03oe5X0om9H0?oCD`3oef80omEM0?oBEP0C0?oDE`80omEF0P3oe5L20?oDFP0:0?oC
EP3oeE/0omMS0?oGIP3odUD0omAG0?oBF03oeEP0omAG0?o:C@<0ol9400<0olE90?o?D`3oeEP0403o
e5L03@3oeEL0omEF0?oDE`3oe5L0omEG0?oDFP3odU/0omAG0?oBDP3oa4T0ol140?o2A03oadP01`3o
aTL00`3ob4P0olI70?o6A`090?o6A`040?o8B03oaTL0olI70?o8B0`0olI700<0olQ80?o6A`3oaTL0
0`3oaTL01P3oaDL0olQ70?o6A`3ob4L0olQ60?o1A080olM800L0olI70?o8A`3oa4L0ojlo0?n^?`3o
`DD0olM80080olA70P3oaDL20?o4A`030?o5A`3oa4L0olA700@0olA70P3oaDL00`3oaDT0olA70?o4
A`070?o4A`050?o6A`3ogU00on1:0?oLKP3omoL0o`3ooonb0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWio/0oooo00H0okRR08i:8`22@ad0R4LP0?n;?03o_U87
0?neCP050?neD03o]Dh0okE>0?neCP3o]E001`3o]Dh00`3o]E00okI@0?nfD00S0?nfD0030?neC`3o
]Dh0okE@00d0okI@00H0okI?0?neCP3o]Dh0okE@0?nhE@3o^eXE0?nkF`0:0?nlG03o_5d0ok]K0?nj
F03o_Uh0ol9Y0?nmG@3o^UP0ok]K0?nlG080ok]K00X0okaL0?nkFP3o/E40ojU90?nXB03oZDT0ok5B
0?njFP3o^e/0okeN3P3o^e/02@3o_5`0okaM0?njF@3o_5/0ol5W0?nnH@3o^eX0ok]K0?nlG00B0?nk
F`080?nlG03o_5d0okYI0?nnH`3o`F`0okaI0?nlF`3o_5`>0?nkF`070?nlG03o^eX0okaK0?o1I`3o
_5h0ok]L0?nlG00;0?nkF`060?nlG@3o_5/0ol5X0?nmG@3o^eX0okaL203o^e/01P3o_5`0ok]K0?nl
G03o_V40ok]J0?nkG0L0ok]K00D0okaM0?nkF`3o_V<0okYI0?nkG0050?nkF`040?nkG03o_5`0okYI
0?o0IPL0ok]K00<0okaL0?nmG`3o^UP00P3o^e/02P3o`5d0okAH0?nBA`1/>A`00P4100D30@0j8Pl0
gGhg0?o9E`3od5X20?o=F@040?o2D03o^4@0ol9>0?o<F080oleI00<0olaH0?o>G03ocE/01@3ocET0
1`3ocUd0oleI0?o=F@3ocET0oleL0?o>G@3ocUX00`3ocET00`3ocUd0oleG0?o=F@020?o=F@070?o?
GP3ocEX0olmN0?o=FP3oc5P0oleL0?o?GP030?o=F@0>0?o>G@3ocEP0oleI0?o=F@3oc5P0oleH0?o@
FP3o`e@0MT<M01L?1P3o]TL0oo9L0?oUF03oiEL20?oUF0030?oUE`3oie`0onEG0080onEH00D0onIK
0?oUE`3oiEP0onEH0?oUE`020?oUF0030?oUE`3oif40onEF0080onEH00D0onEG0?oUF03oiEP0onEH
0?oUE`030?oUF0060?oWG`3oiEP0onEH0?oUE`3oiU`0onEG0P3oiEP01@3oiEL0onMJ0?oXH03oieX0
onEJ00<0onEH00D0onEK0?oUF03oiEP0onEH0?oVF@030?oUF0030?oUE`3oiUT0onEI0080onEH00<0
onEI0?oVF03oiEL00`3oiEP00`3oiUT0onEG0?oUF0030?oUF0070?oUF@3oiEP0onEH0?oUF03oiEH0
onIJ0?oTFP030?oUF0030?oUE`3oie/0onEH00@0onEH00<0onII0?oVFP3oiET01@3oiEP00`3oiUX0
onEI0?oUF@020?oXF@030?oTE`2eO2l03`T40080000000D0MUhS0?oTE03olUX0ooIK0?oaF@020?o`
F@80oo5L00<0oo1J0?o`F03ol5T0103ol5T01@3ol5P0oo5P0?oaG@3ol5P0oo1J00P0oo1I00D0oo5O
0?oaFP3ol5T0oo1J0?o`F0070?o`F@060?o`FP3ol5P0oo5J0?oaGP3ol5T0oo1J103ol5T00`3ol5P0
oo5L0?o`F@030?o`F@050?o`FP3ol5P0oo1H0?obH`3ol5T00P3ol5X50?o`F@0;0?oaF@3olUX0ooAJ
0?obFP3ok5P0onYG0?[6BP2;KbT08Q/:00l:10030@000P0000002@091080FcHE0=Z6=`3ob580ol]C
0?o@EP3ofEX0omUH0?oDF0090?oDE`0;0?oEF03oe5L0om5E0?oCF@3oeF<0om9D0?oAE`3oe5X0omEH
0?oDE`3oeEH04`3oe5L0403odUP0omEH0?oCEP3ode/0omMX0?oDHP3odUH0om9H0?oAE`3oadd0ol94
0?o0@`3o`T@0olE90?oBE@3oeEPD0?oDE`030?oCEP3odE00olM900<0olM800P0olM70?o8A`3o`d@0
ol140?o5AP3oaDL0olI70?o4A`80olQ82@3oaTL01@3ob4P0olM80?o6A`3oaTL0olY901<0olI700D0
olQ70?o4AP3ob4L0olQ80?o7B0040?o6A`0<0?o6AP3o_d@0okm40?o4A`3oaDP0olE70?o0A03o^T@0
oke50?o7B@3ob4L0olA70`3o`dL30?o4A`030?o7B@3oaDL0olE900H0olA700L0olE70?o4A`3oa4L0
ole:0?oOC`3off40on[K0?l0oooo/`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOl0?ooo`070>JSRP2DD2X0P48L095<8@3/S3d0ok]A0?nfC`050?neCP030?ne
C`3o]Dh0okE>00<0okE>00<0okI?0?neCP3o]Dh00`3o]Dh00`3o]E00okI@0?nfD00J0?nfD0030?nf
C`3o]U00okI@0080okI@00<0okI?0?nfD03o]U00403o]U000`3o]Tl0okE>0?neCP030?neCP040?ng
D@3o^5<0okYH0?nkG0X0ok]K00X0okeN0?nlG@3o^eX0ok]J0?nnH@3o_f80okYI0?nkFP3o_El0okiR
0P3o^eX50?nkF`090?nlG03o^e/0okMG0?nbD@3oZTX0ojU90?n/C@3o/U80okUI00@0ok]K00<0okeK
0?nmG@3o_5l0103o^e/01@3o_Eh0okaM0?nkFP3o_5/0okmS0080ok]J00<0okaN0?nnH@3o^eX04P3o
^e/02@3o_5d0okaL0?nkF@3o_Ul0okiP0?nkFP3o_Ul0okiQ0?nlF`0=0?nkF`080?nlG03o_Eh0ok]J
0?noHP3o_V00okYI0?nmG`3o_5`;0?nkF`060?nlGP3o^eX0okiP0?nkF`3o_5/0okiQ203o^e/0203o
^e`0okaL0?nkFP3o_Ed0okeN0?nmG`3o_5h0ok]J1P3o^e/01P3o_5`0ok]K0?nmGP3o^eX0okiQ0?nl
G0D0ok]K0P3o_5`0103o_5d0okeN0?nmGP3o^e`50?nkF`0H0?nlG@3o_Ed0ok]J0?nmG`3o_E/0ol9O
0?njF`3oYU40X64`03XO3`030P40:QP:08UM:03/ZT/0olaI0?o@F`3ocUX0oleH0?o?G03obUL0oka8
0?o1C@3oc5P0oleI0P3ocU/0203ocU`0oleH0?o=F@3ocET0oliK0?o=F03ocUd0oleH0`3ocET00`3o
cUh0oliL0?o=F0030?o=F@030?o>G@3ocU/0oleI0080oleI00@0olmM0?o=F@3ocET0oleI0P3ocU/0
0`3ocU`0oleI0?o=F@020?o=F@0>0?o>F`3ocET0oleI0?o>G03ocUd0oliJ0?o6E@28CR80000008e[
:@3ol5/0onIH0?oUFP3oiET20?oUF0060?oUF@3oiUX0onEH0?oUF03oiET0onIJ0P3oiEP00`3oiEL0
onMO0?oUF0020?oUF0050?oVF03oiEP0onEH0?oUE`3oiel00`3oiEP03P3oiUh0onEG0?oUF03oiEP0
onEG0?oUF03oiET0onIJ0?oWF`3oieh0onEH0?oUE`3oieh0onEG0P3oiEP02`3oiUX0onEI0?oUF03o
iEP0onII0?oVFP3oiET0onEH0?oUF@3oiUX0onII0080onEH00<0onII0?oUFP3oiUT00`3oiEP00`3o
iEX0onII0?oUF0020?oUF0030?oVE`3oiUX0onEH0080onEH00<0onIJ0?oWF`3oiEP00`3oiEP00`3o
iU/0onIH0?oUF0030?oUF0040?oVF@3oie`0onEG0?oUF@<0onEH00@0onII0?oWF`3oiEP0onEI0`3o
iEP05P3oiUT0onML0?oUE`3oiEX0onEH0?oXFP3ocdl0]i`l08iN900V60X061<7065<7@2JQ340kmM@
0?ogG03omE/0oo1I0?oaFP3olEd0oo5K0?obG03ol5/60?o`F@060?oaF`3olEX0oo9O0?o`F03ol5/0
oo1J1@3ol5T01`3ol5P0oo5K0?oaF`3olUl0oo5K0?o`FP3olEX0203ol5T02P3olE`0oo5N0?o`F03o
lEd0oo1I0?oaF`3ol5X0oo5I0?oaG03ol5/60?o`F@080?o`F03olE`0oo5M0?oaF@3olV00oo1I0?o`
FP3olE/40?o`F@80oo5I01H0oo5J0?ocFP3olET0nM]B0=G1B02TV3T0S6lZ065>700k;a807AL900D3
0@0b7P`0GSHG08IJ9P2fPSH0gj520?njCP3obU@0omUJ0?oKF`3ofEX0omIH203oe5L03@3oe5H0omAH
0?oDGP3oe5X0omEE0?oDH03oeUh0omAF0?oEF@3oeEX0omAG0?oEE`3odeL04P3oe5L03`3odeL0omEJ
0?oDGP3oeU/0om1C0?o4C@3o^dD0oke30?o4AP3oaT`0ol]A0?oAEP3oeEP0omEG0?oDEP0;0?oDE`05
0?oEF03oeEL0om1D0?o:C@3ob4X00P3oadP80?o6A`0@0?o8B03oaTL0ol=60?o7B03ob4P0olQ90?o6
A`3o`dH0olQ80?o6B03oadP0olI80?o7A`3oadP0olI70?o8B0l0olI700P0olM80?o5A`3oadP0olI6
0?o6A`3oadL0olA60?o8B@@0olI700D0olQ80?o6A`3oaTL0olI70?o5AP020?o2A080olA70P3oaDL0
1@3oa4L0olE70?o4A`3oaDL0olI80080ol5600L0ol960?o6A`3oaTP0ol960?noAP3o`DH0olU90080
olE700X0ol=70?o2A`3o`TL0olE70?o4B03oaDT0om1;0?oOD@3ofEd0ongEo`3ooond0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiod0oooo00H0ol6d08i<9P20
@ad0P48M0?n<?@3o^E820?neCP030?neD03o]Dh0okE>00H0okE>00<0okI@0?neCP3o]Dh0103o]Dh@
0?nfD0030?neD03o]Dl0okA>0080okI@00<0okE?0?neCP3o]4h05@3o]U00103o]Dh0okI@0?nfD03o
]Dh40?nfD0P0okE>0140okMC0?nkFP3o^e/0ok]J0?nkF`3o^eX0okiN0?noI@3o_El0okYH0?nlF`3o
_fL0okmR0?njF@3o^e/0ok]J0?nlFP090?nkF`80okaL00L0okIF0?n/B`3oYdH0ojM70?n^C`3o^ET0
okaL00H0ok]K0P3o_5T02P3o_5d0okeM0?noI03o_5T0okYI0?noH`3o_640okYI0?nkF`3o_5XA0?nk
F`80ok]J00P0okaL0?nnH`3o_Uh0ok]H0?nnHP3o_5d0okYI0?nkFPd0ok]K00P0ok]J0?nkF`3o^e/0
okiQ0?niEP3o_Eh0ol1W0?nkF`80ok]J2@3o^e/20?nkFP060?nnGP3o_V<0ok]J0?noI@3o^e/0ok]J
203o^e/01`3o^eX0ok]K0?nmH@3o_5`0okiR0?nlG@3o^eX01P3o^e/01`3o^eX0ok]K0?nmGP3o^eP0
okeP0?nlG@3o^eX01@3o^e/20?nkFP040?nmGP3o_5`0okaQ0?nkFPD0ok]K00X0ok]L0?nmGP3o_5`0
okeO0?nkFP3o^e/0okmL0?o1GP3aP3l0OD8Q0P000000401Q=aL0f7`f0?o5EP3oeUd0olaI0?o<F03o
ceh0oliK0?o=F@3obeL0oki:0?nmB03obeL0olmN0?o=E`3ocU`30?o=F@030?o=F03ocUX0olmN00<0
oleI00@0olaH0?o>G03ocU/0olaH0`3ocET00`3ocEL0oleI0?o=F@020?o=F@030?o<F03oceh0oleJ
00<0oleI00L0oliM0?o>FP3ocE`0oleI0?o=FP3ocUl0oleJ0080oleI0P3ocUX03P3oc5P0om1K091C
900000006@l60?oBD03oi5P0onII0?oVFP3oiET0onEH0?oUE`3oi5L0onII0P3oiEP00`3oiEH0onEJ
0?oUF0050?oUF0060?oUE`3oiEH0onEH0?oUF03oiEL0onIQ0P3oiEP00`3oiEL0onMR0?oUEP020?oU
E`060?oUF@3oiE/0onIH0?oVGP3oiEP0onEG0`3oiEP01@3oi5X0onEH0?oUF03oiEP0onMN00<0onEH
00L0onEK0?oVF03oiEL0onEH0?oUF@3oiE/0onIJ00<0onEH00H0onEK0?oVFP3oiEP0onEH0?oUE`3o
ie/40?oUF0030?oVE`3oiUT0onEH00<0onEH00<0onML0?oVF03oiEP00P3oiEP0103oiEL0onEI0?oV
FP3oiEL20?oUF0040?oUE`3oi5L0onEK0?oUE`<0onEH00@0onEG0?oUF@3oiUX0onEI1@3oiEP00`3o
iUd0onEG0?oUF@020?oUF00:0?oaF`3oc4h0R5LQ01X?1@0000007QP90:j:<`3oddh0oomO0?ocFP80
oo1I00D0oo1H0?oaG@3olEX0oo5M0?o`F0050?o`F@030?o`F03ol5T0oo5N0080oo5K0P3ol5P50?o`
F@070?o`F03ol5T0oo5L0?oaF`3olE`0oo1K0?o`F0080?o`F@080?o`F03ol5T0oo5Q0?oaF`3olE`0
oo1I0?oaG03ol5X90?o`F@80oo1H00D0oo5L0?oaGP3ol5L0oo5P0?oaF`020?o`F0H0oo1I00T0oo9J
0?ohG03ooUh0oomP0?[HD@2iU3L0Q6TV05M56P0D4@H00`000000201;:a80]fX/0>j?>@3oY4<0om1G
0?oTGP3ogU`0omMI2P3oe5L20?oBEP090?oCE`3oeEd0omAS0?oAF03oe5T0omIO0?oBF03odUH0omAF
01@0omAG00h0omEH0?oHFP3odE80olM80?ni@03o/cl0oka40?o<D03odel0omES0?oEEP3odeL0omAE
0?oBEPD0omAG00D0omEH0?oDE`3odE80ol]=0?o6AP030?o6A`030?o8B03oaTL0olI700X0olI70180
olU80?o6A`3oaTL0olQ80?o6A`3obDP0olU90?o3AP3o`dD0olI70?o9B@3oaDH0ol=50?o4AP3oaTT0
olM80?o5A`3ob4P50?o6A`080?o9B@3ob4P0olI60?o3A@3ob4P0ol=50?o8AP3ob4L<0?o6A`030?o7
AP3o`T@0ol9400<0olA700<0olE60?o5A`3oaDL02@3oa4L03P3oaDL0olE80?o4A`3oaDP0olM90?o1
AP3o_DD0ok]60?o7B@3oaDP0om=<0?oRD@3ogDH0onZoo`3ooone0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWioh0oooo00D0_gMI08I67`1j?aX0We<U0?naCP0B
0?neCP/0okI@00<0okE>0?neD03o]Dl00P3o]U000`3o]E00okE?0?ndCP0G0?nfD080okE>00<0okI@
0?neCP3o]U001P3o]U090?neCP0;0?nhD@3o^eX0okmU0?nmH03o^UT0okiN0?noIP3o_El0ok]J0?nk
F`3o_5T03@3o^e/02@3o_5`0okUI0?naDP3oZTX0ojE50?nYB@3o/E80okYJ0?nlG0030?nkF`0=0?nk
FP3o_5T0ok]K0?nmG03o`6P0okeQ0?njE`3o_5`0ol5Y0?nlF@3o^e/0okaJ0?nkFP0A0?nkF`80ok]J
00P0okaL0?o0IP3o_F40okaL0?nnH`3o_Uh0ok]J0?nlFPd0ok]K0P3o^eX0203o_E`0ol1U0?nmG@3o
^eX0okiQ0?njF@3o^e/0okaI2P3o^e/0203o^eX0okYI0?noHP3o^eX0okeN0?nnH`3o^e/0ok]J203o
^e/01`3o^eX0okaM0?nmH@3o^eX0okeQ0?nlG03o^eX01`3o^e/01P3o_5T0okeP0?nmG@3o_Eh0okYI
0?nkFPL0ok]K00D0okeP0?nkF`3o_El0ok]K0?nkFP040?nkF`0;0?nkFP3o_F00okYJ0?nmH03o_5/0
ok]K0?nlG03oaUl0okeL0:]K;@040@400P000000202UGbT0ol5D0?oLH03odE`0oleI0?o>G03ocET0
oliM0P3ocET01@3oa500okU40?o2CP3oceh0oliM00@0oleI00<0olaH0?o>F`3ocUX00`3ocET00`3o
cEL0oliL0?o>G`040?o=F@030?o>G03ocEP0olaH00<0oleI00<0olmN0?o>G03ocET00P3ocET01P3o
cUd0oliK0?o<F03oc5P0oliL0?o?GP@0oleI00X0olmN0?o=F@3ocET0oK9>000000030P40/g4[0?o]
F`3oiEL0onII0P3oiEP0103oiEL0onEK0?oVG@3oiEL20?oUF0050?oVFP3oiEP0onEH0?oUF03oiUL0
0`3oiEP01P3oiUT0onIJ0?oUF03oiEP0onEG0?oVH@80onEH00L0onEG0?oWH@3oiE@0onIO0?oVGP3o
ied0onEK0080onEG00L0onMM0?oWG03oiEL0onEH0?oVFP3oiUl0onEG0080onEH00L0onML0?oTE@3o
iEP0onEH0?oUEP3oiE/0onIJ0080onEH00<0onEI0?oUF`3oiEP00P3oiEP00`3oiEL0onIJ0?oUF002
0?oUF0030?oVF@3oiUd0onEH0080onEH0P3oiEL00`3oiUT0onEI0?oUF0020?oUF0030?oVE`3oiUP0
onEH00<0onEH00<0onML0?oVFP3oiEP00`3oiEP00`3oiEX0onIJ0?oUF0050?oUF0030?oVF@3oiUX0
onEG00<0onEH00@0onEG0?oUF@3oiU/0onEI0P3oiEP02`3okU/0onaJ0?n[@P2GH2D020@20000000n
<A80X7h_0?o[F@3om5/0onmI0080oo1I00D0oo5J0?oaG03ol5T0oo5K0?o`F0050?o`F@050?o`F03o
lEX0oo5J0?oaF`3olEh02@3ol5T0103olE`0oo1J0?oaF`3olE/20?o`F0L0oo1I0P3ol5P0103olEd0
oo1I0?oaF@3olV@=0?o`F@030?o`F03olF00oo5J0080oo5N00<0oo1I0?o`F03ol5T01`3ol5T0203o
me`0oomP0?ooG`3oiE@0fji109Ae;01MBA`08Q/:0`000000200X5`T0MdHM0<mh<`3oWd80ol]C0?oT
G`3og5/0omMH2P3oe5L0303oeEH0omAE0?oAE`3oe5X0omIO0?oBF03odU@0omIO0?oEF`3oe5D0omAG
0?oDEQ80omAG00h0omEH0?oAE03obd`0ol=30?o0@`3o`dD0olMB0?oAG`3oeeP0om=F0?oGI03oef00
omEH0?oEE`80om9F00D0omEH0?oAE@3ocD`0olQ80?o6A@0A0?o6A`050?o9B03oadT0olI70?o6A`3o
b4P00P3oaTL05`3oadP0olE70?o6A`3ob4P0olE60?o3A@3oa4H0olI90?o7B03o`dD0ol550?o6AP3o
aTP0olI70?o5A`3ob4L0olI80?o6A`3oaTH0ol=50?o7B03oaDL0olQ800X0olI700@0olM90?o6A`3o
aTL0olM60P3o`T@30?o4A`030?o6A`3o`dH0olI700<0olA700<0olE80?o4A`3oa4L0103oa4L0103o
aDP0olA70?o5A`3oa4L30?o5A`060?o4A`3oaTP0omaA0?oQB`3oeG40oo[fo`3ooone0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWioh0oooo00H0oLk306hd2@28
Ab00MSdJ0>R??P3o^54A0?neCPH0okI@00<0okE@0?neCP3o]Dh07`3o]U020?neD0/0okI@103o]Dh0
0`3o]Tl0okI@0?neD0030?neCP060?nfD@3o^eP0okaK0?nkF`3o^eX0okaI403o^e/00`3o_5`0okAD
0?n[B`020?nXA`040?n`D@3o]UL0ok]K0?nlG080ok]J00d0ok]K0?nlFP3o_f@0ol5Y0?njF@3o_5/0
okiS0?nlGP3o^UX0ok]K0?nkG03o_F00ok]J0100ok]K0P3o^eX01`3o^UT0ol1W0?nlG@3o^e`0okiR
0?nlGP3o^e/00P3o^eX>0?nkF`080?nkFP3o_V80ol1V0?nlG03o_V80okaL0?nkF`3o^eX:0?nkF`80
ok]J00D0okiP0?o1I@3o_5T0okeO0?nkF`020?nkFPP0ok]K00L0okaI0?nmG@3o_V<0okaL0?nlGP3o
^e/0ok]J00H0ok]K0P3o^eX0103o_V00ok]L0?nlG@3o_5`70?nkF`050?nkFP3o_El0okaK0?nlG@3o
_5`01P3o^e/00`3o^eP0okmQ0?nlGP020?nkFP0;0?nkF`3o_ed0ol1M0>Uk?@1P<aT02@D20000001R
>1L0lHXl0?o<FP3oded00P3ocET02P3ocU/0oleL0?o=FP3oc5P0oleI0?o9E@3o^dH0okY50?o:F03o
cU`40?o=F@040?o=E`3ocUX0oliL0?o<F0<0oleI00<0oliL0?o>G@3ocEX0103ocET0203ocU`0oleI
0?o=F@3ocET0oleH0?o>G03ocE`0olaH0P3ocET00`3oceh0oleL0?o=F@020?o=F@80oliL0`3ocET0
2`3ocUd0oleJ0?o<F03od5X0WW<b00000017;A40on5F0?oWF03oiUX0onEI0080onEH00<0onEG0?oU
F03oiU/00`3oiEP01P3oj600onEH0?oUF03oiEL0onQP0?oVFP80onEH00L0onIK0?oVG`3oiEP0onEH
0?oUE`3oiV40onEH0080onEG00H0onMP0?oUEP3oie`0onIL0?oVH@3oiEH20?oUF0070?oVF@3oiET0
onEH0?oUF03oiET0onEG0?oTE@020?oUF0030?oUE`3oiUh0onEH0080onEH00<0onAJ0?oUF`3oiET0
0P3oiEP20?oUE`<0onEH00<0onEI0?oUEP3oiEP00P3oiEP00`3oiET0onML0?oUF0030?oUF0030?oU
E`3oiUT0onEH0080onEH00<0onEG0?oVFP3oiET02P3oiEP00`3oiET0onIJ0?oVFP050?oUF0030?oV
F`3oiE/0onEH00@0onEH00X0onEI0?oUF`3oiUX0onEG0?oUF03oj5T0ooIN0?oUF03>RSH020D20P00
0000101ZDal0ommB0?ooH03oleX20?o`F@060?o`F03ol5T0oo5L0?obGP3ol5T0oo1H1@3ol5T01P3o
l5P0oo1K0?o`G03olEd0oo1G0?o`F0H0oo1I0P3ol5P01@3ol5/0oo1I0?oaGP3olEh0oo1H00/0oo1I
00D0oo5N0?oaFP3olEd0oo1F0?o`F00:0?o`F@80oo1H0P3olE`01@3ol5H0oo5N0?oaG@3ol5T0oo1H
00L0oo1I00T0oo5I0?oeF`3ooEh0ooUL0?oODP3gaDT0^Y8g05U76`0D3`H00`000000200X5`T0Dc4D
0:EQ:03oY4<0omAG0?oRG@3ofeX0om=G2P3oe5L03@3oeEL0om9F0?oDE`3odUH0omAL0?oDFP3odU@0
om=L0?oEHP3oe5D0omAG0?oBEP3oeEL03`3oe5L04P3oeEP0omAG0?o?DP3ob4/0ol530?no@P3oaDD0
olI<0?oCEP3oeUl0omEM0?oBF03oe5L0omES0?oDHP3oce<0olU;0?o7APH0olI700<0olM80?o6A`3o
aTL03@3oaTL00`3oadP0olI70?o6A`060?o6A`80olE700<0olI70?o8B03oa4H00P3oa4L02P3oaTT0
olI60?o4A@3oa4D0olQ80?o4A`3oaTL0olQ70?o6A`3ob4P;0?o6A`090?o:B03oaTL0olI70?o6A`3o
a4@0ol940?o2A@3oa4L0olE70080olA700D0olI70?o5A`3oa4L0olA70?o6B0080?o4A`030?o5B@3o
aTL0olE70080olA700D0ol=60?oBC03ogTh0olmH0?oZf03o0?oookH0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWoP3oool01`3oo_l0iZfI08m<9@21@a`0ZE`Y
0?n`C@3o]e002@3o]Dh0103o]U00okI?0?neCP3o]Dl20?neCP030?nfC`3o]U00okI@0080okI?803o
]U000`3o]Tl0okI@0?nfC`0;0?nfD0030?nfD@3o]Tl0okIA0080okI?2P3o]Dh0103o]Tl0okQC0?ni
EP3o^eT>0?nkF`0?0?ngE`3o]5<0oje<0?nYB@3oZdX0ok1@0?niF03o_5`0okmR0?nnH@3o^eX0okiP
0?o0H`3o_Eh0ok]K0080okaM1`3o^e/00`3o_5`0ok]K0?nlG0080?nkF`0<0?nkG03o_5`0ok]K0?nm
GP3o_V40okaJ0?nlF`3o_f80ok]K0?nlFP3o_5h0okaL3@3o^e/0103o_5`0ok]K0?nlG03o_V820?nk
FP040?nnH03o^eX0okaL0?nmG@/0ok]K00P0ok]L0?nlG03o_V40ok]K0?nmH03o_5d0okaL0?nmG@T0
ok]K00L0ok]J0?nlG`3o_El0okeN0?nlG@3o^e/0okaL00P0ok]K00H0okaM0?nlG03o_El0okeP0?nl
F`3o^e`60?nkF`050?nlG03o_Ed0okaL0?nnH03o_5`01P3o^e/0503o^e`0okaM0?nmGP3o^e/0okaL
0?nlF`3o_E`0okUJ0?bRC`2AFbd0:AH;00/60`0]6P/0Uf@/0?f`C03obUP0om5K0?o?FP3ocEP0olmN
0P3ocU/30?o=F@050?o;E`3o_4T0okU50?o0C03ocUX0103ocET00`3ocUd0oliL0?o=F@040?o=F@03
0?o>G03ocET0oleI0080oleI00@0oliK0?o=F`3ocU/0oleJ0P3ocET00`3ocEP0oliJ0?o=FP020?o=
F@030?o=FP3ocUd0oleJ00@0oleI00<0oleH0?o>FP3ocEL00P3ocET02`3ocU/0oleI0?oCG03o]E00
;AX;05Ti5P3obTh0onYJ0?oVF@3oiU/0onEI0080onEH00<0onEI0?oVG03oiEL00P3oiEP00`3oiU/0
onEH0?oUF0020?oUF00?0?oWF`3oiUX0onEH0?oUF03oiU/0onMN0?oUF@3oiEP0onEI0?oWH03oiEX0
onIN0?oUE03oif80onEF0080onEH00<0onEI0?oUF03oiEP00P3oiEP01`3oiUX0onEI0?oUF03oiEP0
onEL0?oVG@3oiEL00P3oiEP00`3oiUX0onIM0?oUF0020?oUF080onIJ0`3oiEP01`3oiE/0onEH0?oU
F03oiEP0onEI0?oVF`3oiUX0103oiEP00`3oiEX0onII0?oUF0020?oUF0030?oUF@3oiUX0onEH00<0
onEH00<0onIJ0?oVF`3oiEP00`3oiEP00`3oiUX0onMK0?oUE`030?oUF0030?oUF@3oiUT0onIJ00D0
onEH00<0onEI0?oVF`3oiUX0103oiEP0103oiET0onEH0?oVG03oiUT20?oUF00D0?oWF@3ojET0omAA
0<jQ?P24I2H0:1T:01PB1`16>1D0Rg8[0=k6BP3ol5T0oo9J0?oaFP3ol5X0oo5J0?oaF`3olEd0oo5K
0?o`F@3ol5X50?o`F@050?oaFP3ol5T0oo5M0?oaF@3olE`0203ol5T20?o`FP050?oaFP3olE`0oo5N
0?oaF`3ol5P0203ol5T01`3ol5X0oo5K0?oaEP3olEd0oo5K0?oaGP3olE`0303ol5T01P3ol5X0oo5J
0?oaG03olEl0oo1H0?oaG@80oo1I00<0oo1J0?o`F@3ol5T00`3ol5T05P3olEX0oo=J0?oeF`3om5/0
onYF0?oTE03_e4h0`ja008ij;@1lHR@0Dd@I020H2@0C2P@07a8803`T3P1hBb00U7@a0;b?>`3YZ4H0
olUD0?oCE`3oe5L20?oFF0030?oEE`3oe5L0omAG00L0omAG00X0omEH0?oDF@3odeH0omAG0?oEH03o
e5T0om=G0?oEG@3oeUl0om=G0P3odeP;0?oDE`0E0?oEF03oe5L0oliC0?o6B`3o`TD0ol940?o5A`3o
bdh0olmB0?oAEP3ode@0olaA0?o:B`3oaTP0olM70?o1AP3oaDL0olU80?o6A`3oa4H0olE600<0olM8
303oaTL00`3oadP0olQ80?o6A`0;0?o6A`040?o8B@3oaDH0olQ70?o7AP80olM80P3oaTL02P3ob4P0
olM80?o3AP3oaDH0olI70?o8B@3ob4P0olE60?o4AP3oaTP20?o6A`030?o7B03oaTL0olI700<0olI7
00L0olM80?o6A`3oaTL0olA50?o2A03o`TD0olE700D0olA700<0olE70?o4A`3oaTP01P3oa4L0103o
aDP0olA70?o5B03oaTP20?o4A`050?o5A`3obdT0oma<0?oPO@3olml0o`3ooong0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo0@3oool01@3o`k@0WUH^
07i16`32IBh0ok9=00D0okE>00<0okI?0?neCP3o]E00203o]DhR0?nfD0030?ndCP3o]U00okI@00T0
okI@0`3o]Dh40?nfD0/0okE>00<0okE@0?neCP3o]Dh00P3o]Dh00`3o^5@0ok]J0?nkF`080?nkF`0:
0?nlG03o^5P0ojU90?nXB03oYdL0oj]<0?nfE@3o_f@0ol9Y0?nlG1<0ok]K00<0okaL0?nmH03o^eX0
0`3o^e/01P3o_5d0okeM0?nkFP3o`6D0ol5W0?nkFQ<0ok]K0P3o_5`0103o^eX0ol5X0?nnH`3o^UT?
0?nkF`050?nlG03o^eX0ol1T0?o0I@3o^eT0303o^e/0103o_5`0ok]J0?nnH@3o^e`:0?nkF`040?nl
G03o^e/0okaM0?nnHPT0ok]K00@0okaL0?njF@3o_V80okaM1`3o^e/0103o_5`0ok]K0?nnH`3o^UP3
0?nkF`0>0?o0G@3o^5X0o8I104hX500000001`@205@`5@3kT3h0olYH0?o>FP3ocET0olaH0?o=FP3o
cE`60?o=F@040?o=FP3o`U00ok]60?o0C0<0oleI00<0olaH0?o=F@3ocU`0103ocET00`3ocEX0oliJ
0?o<EP040?o=F@030?o>G03oc5P0oleI00<0oleI00<0oliL0?o<F03ocET00P3ocET00`3oc5P0oliM
0?o<F0030?o=F@030?o=G03ocUd0olaH00<0oleI00P0oliM0?o=FP3oe5d0ol9E05@`5@0L4PL0om9@
0?oVF080onEH00D0onAG0?oUF03oiEP0onEH0?oVFP030?oUF0030?oUE`3oieh0onEI0080onEH0P3o
i5L20?oUF0070?oUF@3oiUT0onIF0?oXH`3oiUT0onEF0?oVG`030?oUF0030?oVF@3oiEP0onEH0080
onEH00H0onAG0?oUF03oiEP0onEH0?oWH03oi5X30?oUF0030?oVFP3oi5X0onEH0080onEH00<0onEF
0?oUF03oiEP00P3oiEP01P3oiEX0onEH0?oUF03oiEP0onEG0?oUEP<0onEH00<0onEG0?oVF`3oie`0
103oiEP00`3oiUT0onEH0?oUF0030?oUF0030?oWG03oiET0onEH00<0onEH00<0onEI0?oUF03oiEP0
0`3oiEP00`3oiE/0onIJ0?oUF@040?oUF0030?oUF@3oiE/0onEI00D0onEH00<0onEK0?oUEP3oiET0
1P3oiEP03`3oieh0onEG0?oUF03oiEP0onII0?oWF@3oee80RUHR01`A1P0000001PD208AV9@3obd/0
onYG0?ofF`050?o`F@030?obH`3ol5H0oo1J00P0oo1I00@0oo5L0?oaG`3ol5P0oo1J2@3ol5T00`3o
l5P0oo5J0?oaG0020?o`FPL0oo1I00<0oo1J0?oaG03ol5X00`3ol5T00`3olEl0oo1H0?o`F`0>0?o`
F@060?o`F03olE/0oo9U0?oaF@3ol5/0oo1J2@3ol5T02P3olUX0oo=J0?ocFP3ol5T0onaH0>noA`2R
P2l0FTDJ01TB1`020@020000000601D;1@1b@a/0aW4`0?nTA03oae40omAG0P3ofU/00`3of5P0omAG
0?oDE`0<0?oDE`070?oBF03oeEH0omAR0?oEH`3oe5L0omEG0?oDFP020?oDE`030?oEE`3oe5L0omAG
00L0omAG00<0omEH0?o>D@3o`dH00P3o`T@00`3o`4D0olE70?o6A`090?o6A`080?o8B03oadL0oki5
0?o6AP3obDT0olE70?o4A`3oadP60?o6A`030?o8B03oaTL0olI700P0olI700D0olU90?o8B03o`dD0
ol=50?o7B00=0?o6A`0=0?o8B03oaTL0olI70?o6A`3obDT0olM90?o1AP3oa4H0olU90?o5A`3oaTP0
olA70?o:B@020?o6A`030?o2A@3o`T@0ol5400D0olA700@0olE70?o3AP3oa4L0olI81`3oa4L20?o5
A`<0olA700<0ola:0?oNC@3ofWP0o`3oooni0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0oooo0P3oool01`3oZYT0P48I08137@3oRC/0ok]C0?neC`3o]E00
0`3o]Dh00`3o]E00okE>0?neCP070?neCR00okI@00<0okE>0?neC`3o]U001P3o]U000`3o]Tl0okE@
0?neCP090?nfD0X0okE>00<0okI@0?neD03o]Dh0103o]Dh0103o]U80okYG0?nkFP3o_5`30?nkF`0<
0?nkFP3o_5`0ok]J0?neEP3oZ4X0ojU80?nVAP3oYDT0okQK0?nkFP3o^e/0ok]J5@3o^e/02P3o_5/0
okYH0?nkF`3o_E`0ok]J0?o0I03o`FL0okaK0?nkF`3o^eX?0?nkF`070?nkFP3o^e/0okaM0?nmGP3o
^UT0okiN0?noHP020?nkFPh0ok]K0P3o_Eh00`3o^UP0okiQ0?nkFP0;0?nkF`80ok]J00@0okeM0?nl
G03o_V<0okiN2`3o^e/0103o_Uh0okaN0?nmGP3o^UT80?nkF`050?nkFP3o_5d0okeR0?nnGP3o^eX0
1@3o^e/01@3o^eX0ok]K0?nmG@3o_F00okYJ00<0ok]K00@0ol1M0?o4G`3o[E@0YEL[0P000000100E
30D0ZV8[0?o@FP3odU`40?o=F@030?o>G`3ocEX0oleI00<0oleI00`0olaH0?o=FP3od5l0okm;0?nl
A`3obED0oliJ0?o=F@3ocE`0oleG0?o>G@3ocEX40?o=F@030?o>G`3ocET0oleI00@0oleI00<0oliL
0?o=F@3ocET00P3ocET00`3ocUX0olaH0?o<F0030?o=F@030?o=G03ocEX0oleI0080oleI00<0oleK
0?o?GP3oc5P00P3ocET03@3ocEX0oliO0?o=F@3oce`0omUO0:mT:`000000PEDP0?oXF@3oiEP0onEG
0?oWF`3oiEL00`3oiEP01P3oiE/0onEH0?oUF03oiEP0onEI0?oUEP80onEH00L0onEG0?oWG`3oiel0
onIJ0?oUE`3oiUX0onMP0080onEG00<0onEH0?oUE`3oiV400`3oiEP01`3oiEL0onEH0?oUF03oiEP0
onEI0?oXH03oiEL00P3oiEP01`3oiEH0onIE0?oUF03oiEP0onEG0?oVG@3oiE/00`3oiEP00`3oiET0
onIK0?oUF0020?oUF0030?oVG03oiEL0onEH0080onEH00<0onMM0?oVF`3oiEP00P3oiEP00`3oiEL0
onII0?oUF@040?oUF0030?oVFP3oiEP0onEH00<0onEH00<0onML0?oUF03oiEP00P3oiEP00`3oiUT0
onAE0?oUF@040?oUF0030?oUE`3oie/0onEG00D0onEH00<0onMM0?oUF@3oiEP00`3oiEP00`3oiEL0
onEI0?oWG`060?oUF0030?oUF@3oie`0onEI00<0onEH00/0onMI0?oaG03oa4X0S5PR01P@1P000000
20H208M[:03lf500ooeM0?ocFP030?o`F@040?o`F03olE`0oo5M0?o`F`T0oo1I00D0oo1H0?oaG@3o
l5/0oo1J0?o`F0090?o`F@050?oaG`3olE/0oo1I0?o`F`3ol5P01@3ol5T00`3ol5P0oo5J0?o`F@02
0?o`F@050?o`F03ol5/0oo9S0?oaFP3ol5/00`3ol5P;0?o`F@070?o`F03ol5T0oo9S0?oaGP3ol5D0
oo5L0?o`F@020?o`F0T0oo1I00P0oo9J0?oeF`3on5`0l]5>09im;P1LAaX0=BX?00d:10<0000000T0
BB/A0<ef<@3oXD80okY<0?o?EP3ogUd0omaK0?oGF@3oeEL03@3oe5L02`3oeEH0omAG0?oCF@3oef<0
om=I0?oBEP3oeUX0omEH0?oEEP3oe5L0omAF00H0omAG00<0omEH0?o>D@3o`T@00P3o`T@<0?o6A`0:
0?o8B@3oadT0olI70?o8B03oaDL0ol550?o6AP3oadT0olI70?o6AP80olI700@0olY80?o5A`3oaTL0
olQ80`3oaTL01`3oaDL0olI70?o6AP3oaTH0olU90?o6A`3oaTT00P3oaTL00`3oadP0olQ80?o6A`05
0?o6A`030?o7B03oaTL0olI70080olI700<0olU80?o7B@3oaTL0103oaTL0303oadP0olI70?o6A`3o
bDT0ol=50?o0A@3obDH0olM90?o7A`3o_D@0oke30?o1A080olA700H0olE70?o4A`3oa4L0olM90?o4
A`3o`dD80?o4A`80olE90P3oa4L0103oc4T0ome=0?oGBP3ol=Go0?oookT0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool20?ooo`060?omo`2eIdD0OT8K
09UA8`3oXTH0okU@103o]Dh00`3o]E00okE>0?neCP070?neCQd0okI@00<0okI?0?ndCP3o]U001@3o
]U00103o]Tl0okE@0?neCP3o]Dh<0?nfD0/0okE>00<0okE@0?neCP3o]Dh01@3o]Dh03P3o^580okYJ
0?nlG03o^e/0okaL0?nnHP3o]UL0ok1@0?nSAP3oXDD0ojm=0?nbDP3o_EX0okaL503o^e/02@3o^eX0
ok]K0?nkF`3o_F00okaL0?niE`3o_5`0okmQ0?nkF`020?nkFPl0ok]K00P0ok]J0?nkF`3o_5`0okiR
0?nmG@3o_5h0okiS0?nkFPh0ok]K00@0ok]J0?nkF`3o_Eh0okaK0P3o_V<<0?nkF`070?nkFP3o_5`0
okeN0?nkFP3o_F40okaN0?nkFP080?nkF`060?nkFP3o_5`0okeN0?nkFP3o_fD0ok]I1`3o^e/01P3o
^eX0okeM0?nlGP3o^UX0okeP0?nkFPL0ok]K00@0okeN0?nlF`3o_640okaK0`3o^e/02@3oaF00ojeE
0>Qj?@1P<aT00000018:101Z?AT0lX/l0?oEG@040?o=F@030?o=FP3ocUd0oleI00H0oleI00D0oliL
0?o8EP3o^dH0ol=?0?o=FP020?o=F@030?o?H03ocEX0olaH00@0oleI00<0oliJ0?o=F@3ocET00`3o
cET00`3oc5P0oliM0?o=FP030?o=F@030?o>F`3ocEP0olaH00<0oleI00<0oleJ0?o=F@3ocET00`3o
cET00`3ocUh0oleI0?o=F@020?o=F@0;0?o>G@3oc5P0oleI0?oCG@3oVD409A@900000034W3d0onMI
0?oUF03oieX0103oiEP00`3oiEX0onEG0?oUF0020?oUF0080?oWG`3oi5X0onEH0?oUE`3oiEP0onIQ
0?oWG03oiU`20?oUE`060?oTD@3oiEP0onEH0?oUF03oiEL0onIQ0`3oiEP01`3oiEL0onEH0?oUF03o
iEP0onIJ0?oWI`3oiEL00`3oiEP01`3oiE/0onEH0?oUF03oiEP0onEF0?oUF03oiET00P3oiEP00`3o
iEL0onEH0?oUF0020?oUF0030?oUE`3oiUX0onEG0080onEH00<0onEG0?oWG03oi5L00`3oiEP00`3o
iUX0onEI0?oUF0020?oUF0030?oUF@3oiUP0onEG00D0onEH00<0onIK0?oUE`3oiEP00P3oiEP00`3o
iEL0onIJ0?oUF@040?oUF0030?oVF`3oiEP0onEH00D0onEH00<0onEJ0?oUF@3oiEP01@3oiEP00`3o
iEX0onII0?oUE`050?oUF0040?oVF@3oi5X0onAJ0?oUE`80onEH00@0onaJ0?ofG@3GVC/0A2XA0P00
00001@1:>QH0k;]50?ocFP3ooUh0oo9J00<0oo1I00@0oo5I0?oaG`3ol5X0oo1L2@3ol5T01@3olEh0
oo1J0?o`G@3ol5T0oo1H00L0oo1I0P3ol5P01@3ol5/0oo5M0?oaG@3ol5/0oo1H00@0oo1I00<0oo5H
0?o`G03ol5T00`3ol5T20?o`F0050?oaGP3ol5P0oo1M0?oaG@3ol5P0303ol5T01`3ol5P0oo1I0?o`
EP3olF00oo1H0?o`G03olEh00P3ol5P:0?o`F@080?odFP3ooEd0oomO0?oUE02nUSP0JeHO04Li5@0T
70/30000000802/G2P2QGBL0oiPn0?n_B@3obe<0on1N0?oMG03ofEP=0?oDE`0B0?oEE`3odUH0omAG
0?oBEP3oeV00om=K0?oCD`3oeEP0omEM0?oBEP3oe5L0omAE0?oEE`3oeEP0om5G0?o?D`3oc4/0olE5
0P3o`T@<0?o6A`030?o8B03oaTL0olI70080olI70100olE70?o6A`3oaTT0olI70?o1A@3ob4P0olQ7
0?o7B03oa4H0olI70?o7B@3oadP0olE70?o6A`3oa4H0olQ80P3oa4H00`3oaTL0olQ80?o6A`020?o6
A`030?o7B03ob4P0olI700D0olI700<0olM80?o6A`3oaTL02@3oaTL00`3ob4P0olI70?o6A`020?o6
A`0=0?o5A`3oaTL0olQ80?o6B03o]T80okA00?o1A03oaDL0ol560?o0AP3o`TH0olE70?o4A`020?o5
A`030?o4AP3oa4L0olA700@0olA700P0olE70?o7B@3oaDT0olA70?o7B03og4d0omM40?oQVOl0oooo
^P3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooo`<0
oooo00H0klVl08=47@1n@A`0Td`Q0?BTA`3o]e030?neCP030?neD03o]Dh0okI?00H0okE>00<0okI?
0?nfD03o]U005@3o]U020?nfC`80okI@0P3o]Dl20?nfD0050?neC`3o]U00okI@0?nfD03o]Tl04@3o
]U090?neCP030?nfC`3o]Dh0okE@00P0okE>00/0okI@0?niE03o^5D0ok=C0?n`D@3oZ4P0ojU90?n^
CP3o]UL0ok]K0?nlG00B0?nkF`090?nlG03o_f80okaL0?nlF`3o_f@0okaL0?nkFP3o_El0okaL0080
ok]K00<0okaL0?njF@3o_5d03@3o^e/20?nlG@060?njF03o_El0okeP0?nlF`3o_V00okeM303o^e/0
2@3o_5/0ok]L0?nmH03o_5d0okeM0?nnH@3o^e/0okeM0?nlG00;0?nkF`060?nmG@3o_5/0okaL0?nn
H`3o_5/0okaN2@3o^e/01P3o_5d0okaN0?nlG03o_F40okeL0?nmG@P0ok]K00D0okeM0?nlF`3o_El0
okaK0?nlG@070?nkF`0D0?nmGP3o^e/0okeM0?nlGP3o_5`0ok]K0?nlG03o`Eh0okYJ0>BKC02=EBX0
<QX=000000119Q40X6T^0?VcCP3od5X0omAM0?o>FP3ocEP20?o>G0030?o>F`3ocUX0oleI00@0oleI
00H0oleL0?o>F`3ocU`0olUE0?nmB@3o_dX20?o=F@030?o>G03ocU/0oleJ00<0oleI00<0oleH0?o=
F`3ocUd0103ocET00`3ocUX0oleH0?o=F0040?o=F@030?o>G03ocU/0oleI0080oleI00<0oliJ0?o=
F@3ocEP0103ocET20?o>FP<0oleI00d0oliL0?o>FP3ocET0oliJ0?2dC`0U5PX0000007i@803oi5L0
onEH0?oUF@3oiUX0onII00<0onEH00`0onIJ0?oUF03oiEP0onEH0?oVF03oiUX0onIK0?oUF03oie`0
onMH0?oVFP3oiEL20?oUF0030?oUF@3oif<0onEH0080onEH00<0onEG0?oVH@3oiEP00P3oiEP01P3o
iEL0onEH0?oUF03oiEP0onII0?oVG0@0onEH00<0onMN0?oUF03oiEP00P3oiEP00`3oiU/0onII0?oU
F0020?oUF0050?oVFP3oiUT0onEH0?oUF03oiET00P3oiUX30?oUF0030?oUE`3oiUT0onII00<0onEH
00<0onMJ0?oVF`3oiET00P3oiEP20?oVF@030?oVFP3oiEP0onEH0080onEH00<0onII0?oVFP3oiEP0
103oiEP20?oVFP@0onEH00@0onII0?oVFP3oiU/0onIH0`3oiEP0103oiUT0onIK0?oUF03oiET40?oU
F0030?oUF@3oiEL0onIK0080onEI103oiEP20?oVF@030?oWG@3oiUT0onEG0080onEH00/0oneK0?oL
E03O^DH0Xg/_04@/4@0:1`<0?S8C07mT9@3D`4P0ooIK0?oeF`030?o`F@050?oaFP3olE/0oo5L0?oa
F03olE`01`3ol5T01P3ol5P0oo5L0?oaFP3olEd0oo1I0?oaG@T0oo1I00@0oo5L0?oaF`3olE/0oo5L
0P3olE/01@3ol5P0oo1I0?oaF`3olE`0oo5K00H0oo1I0`3olE`0103olE/0oo1G0?oaG@3olEX=0?o`
F@070?oaF`3olE`0oo5I0?oaH03ol5T0oo5J0?oaG00:0?o`F@0F0?obFP3ome`0ooQN0?o]F03efe40
c[i60:N>=@27JRL0HdhM03T^4@0;20<0714703dS3`1[?aX0WFP/0;J8>@3<Wd80m[]>0?oDE`3ogU/0
omYJ0?oFF0d0omAG00l0omAF0?oDF03oe5/0omAE0?oEF03oe680om9F0?o>C@3obDT0olI70?o9B03o
bDH0ol=40?o2A03oaDL02`3oaTL00`3ob4P0olM90?o8B0040?o6A`060?o7B03oadL0olI70?o6A`3o
adP0olQ80P3oaDH02P3ob4T0olM70?o5A`3obDT0olI70?o5A`3oaTL0olM80?o6A`3obDP40?o6A`03
0?o7B03ob4P0olI70080olM800<0olI70?o7B03oadP01@3oaTL20?o7B@@0olI700<0olM80?o6A`3o
aTL0103oaTL20?o7B00A0?o3A@3o`d@0ol940?o5B03o`TH0ol560?o2A`3oaTP0ol=70?o0A`3o`4H0
olE70?o7A`3oa4L0ol560?o2A`3oaDP00P3oaDL01`3oaTP0olE70?o4A`3odDX0omQ^0?o[aP3ooOh0
o`3ooonj0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0
oooo103oool01P3o_K80NchG07a0702mI2/0okaC0?nfD080okE>00<0okE@0?neCP3o]Dh01P3o]DhF
0?nfD0030?neCP3o]4h0okI@01`0okI@303o]Dh00`3o]U00okE>0?neCP070?neCP080?nfD03o/T`0
ojY70?nXB@3o/U<0okUI0?nlG03o_5/@0?nkF`090?njF@3o_5`0ol5W0?nmGP3o_5`0okiS0?nlG03o
^e/0ok]J00P0ok]K00<0okeM0?nmH03o^e/01P3o^e/20?nkFP030?nnHP3o`FL0ok]H0080okaM0P3o
^eX=0?nkF`070?nkFP3o^e/0okYI0?nnH`3o^UX0okeQ0?nmG@020?nkFP/0ok]K00D0ok]H0?noI03o
_F40okeM0?nkG0020?nkFPT0ok]K00H0okYI0?noH`3o_5d0okeN0?nlF@3o^eX80?nkF`040?nmGP3o
_5`0okaL0?nmG@P0ok]K00@0okaN0?nkF`3o_Eh0ok]J0`3o^e/02P3o_5/0okiL0<U[<`1;:1@00`41
00000021BB40oiQ10?o6EP3oeEh30?o=F@030?o>G03ocUX0oliL00H0oleI00/0olmQ0?o<F03ocE`0
oleI0?o:EP3o_DP0okU50?o7D`3ocUd0oleG0?o=FP040?o=F@030?o>F`3ocEL0oleI00D0oleI00<0
oliM0?o=F@3ocET00P3ocET00`3oc5P0olmN0?o=G0040?o=F@030?o=FP3oc5P0oleI0080oleI00<0
oleG0?o=F@3oc5P00`3ocET03@3ocEL0oleI0?o=F@3ocET0om=L08mO:P000000NddN0?oLEP3ojU`0
onEH0?oUEP3oiUX00`3oiEP03@3oiEL0onIJ0?oUE`3oiEH0onEK0?oWGP3oiU`0onIK0?oUF03oiEL0
onIN0?oVH@3oiEL00P3oiEP00`3oi5X0onMX0?oUF0020?oUF0030?oUE`3oiV40onEH0080onEH0P3o
iEL30?oUF080onEF0`3oiEP00`3oiEL0onIH0?oUF0020?oUF0030?oUE`3oiU/0onEH0080onEH0P3o
iUT01P3oiEL0onEH0?oUF03oiEP0onAJ0?oUF`@0onEH00<0onMJ0?oUF03oiEP00P3oiEP00`3oiUT0
onIJ0?oUF0030?oUF0030?oUF@3oiUX0onEH00@0onEH00<0onIM0?oUF03oiEP00P3oiEP00`3oiEL0
onIJ0?oUE`040?oUF0030?oUE`3oi5X0onIK00D0onEH00<0onEG0?oWFP3oiUT01`3oiEP00`3oiU/0
onEG0?oUF0040?oUF0050?oUE`3oiUT0onEI0?oWG03oiEL00`3oiEP02P3olE`0ommE0=b;=@0g8`h0
000000h<1@1XDQh0ikQ30?olG@3oleX40?o`F@050?o`FP3olE/0oo5K0?oaG@3ol5P01`3ol5T01P3o
l5P0oo1I0?oaG03olE`0oo1K0?o`F0X0oo1I00P0oo1K0?o`FP3olE/0oo5L0?o`F@3ol5P0oo1L0?oa
F`T0oo1I00H0oo1H0?oaG@3ol5T0oo9S0?oaF@3ol5P=0?o`F@070?o`F03ol5T0oo1K0?oaF`3ol5L0
oo5Q0?oaG`020?o`F0X0oo1I00T0oo5I0?ofF`3oo5d0oomP0?oWE@3g`dP0eJPn095d:P0Y7`/00`00
0000200K40L0DC0D08M<8@3HOCH0ol=B0?oNG@3ofU/0omMH303oe5L01P3oeEP0om5G0?o@C`3obdX0
olU60?o9B080olM700@0olU90?noA03o/d00oki30P3oaDL?0?o6A`0I0?o8B03oaTL0olI70?o6A`3o
aDL0olI70?o9B@3oaDL0olQ70?o5AP3oa4L0olQ80?o5A`3oaTL0olQ80?o5AP3oa4L0olQ80?o8B@3o
`TD0olA50?o6B@3oaTL0olE70?o8B0020?o6A`060?o7B03oaTL0olI70?o6A`3oadP0olU83`3oaTL0
1@3ob4P0olI70?o6A`3oaTL0olA50080ol941P3oa4L03`3oaDL0olA70?o4A`3oa4L0ol560?o3A@3o
`dL0olI70?o5B@3o_TD0okm50?o6AP3oe4d0omIQ0?ognP3o0?oook`0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool50?ooo`050?n]V`1l?aT0Q4DN0?nE
@@3o_5<00P3o]Dh00`3o]E00okE>0?neCP060?neCQ80okI@00@0okE?0?neD@3o]Dh0okE>803o]U08
0?neCP030?nfD03o]Dh0okA>00X0okE>00L0okI@0?nbC@3oZDP0oja:0?niD@3o^UL0ok]J00h0ok]K
00T0okYI0?nlG@3o`6H0ok]J0?nkF`3o_Eh0okaL0?nkF`3o^eX0303o^e/00`3o_E`0okeM0?nkF`03
0?nkF`070?nkFP3o^e/0ol5W0?nmG`3o_5d0okaN0?nkFP0@0?nkF`070?nlFP3o`6H0okiP0?njF@3o
_Ed0ok]K0?nkFP0<0?nkF`030?njF@3o`680okYI0080okaL2`3o^e/0103o_5`0okiR0?nkF`3o_Ed:
0?nkF`030?nlG03o_V80okaL00T0ok]K00<0okaL0?nnGP3o^e`0103o^e/01@3o_5/0ol1M0?nfF@24
AR8020@20080000000@0_g<b0?o7E`3oeEd0om5L0P3ocET01@3oc5P0oliM0?o>F`3ocEX0olaH00D0
oleI00<0oliJ0?o=G03ocET00P3ocET0103o`Th0okU40?nlA`3ocEX60?o=F@030?o<F03ocU`0oleI
00@0oleI00<0oleG0?o>H03ocEX0103ocET00`3oceh0oleJ0?o=F@030?o=F@030?o>G@3ocET0oleI
00<0oleI00<0oliL0?o=FP3ocET00P3ocET03P3oc5P0oleI0?o=F@3ocET0om1J0?o5EP0e7`h0>B<?
0?nmB03om5`0onEI0?oUE`3oiUl0onEF0`3oiEP0103oiUT0onIK0?oWHP3oiE@20?oUF@070?oUE`3o
iEP0onEH0?oUF03oiU`0onIN0?oUE`020?oUF0030?oUF@3oj600onEH0080onEH00<0onEG0?oVG03o
iEP00P3oiEP00`3oiUP0onEI0?oUF0020?oUF0030?oVFP3oiUh0onEG00<0onEH00<0onQT0?oUF03o
iEP00P3oiEP00`3oiEX0onEH0?oUF0020?oUF0030?oVF@3oiET0onEH0080onEH00<0onEI0?oUF`3o
iEP0103oiEP01`3oiEL0onEH0?oUF03oiEP0onEG0?oUF`3oiEH0103oiEP00`3oiU/0onEH0?oUF003
0?oUF0030?oUF@3oiUd0onEH00@0onEH00<0onIJ0?oUF`3oiEP01@3oiEP00`3oieh0onEI0?oUF005
0?oUF0030?oWGP3oiEL0onEH00D0onEH00<0onAG0?oUF`3oiEL01@3oiEP0103oiET0onAJ0?oUF`3o
iET30?oUF00;0?o[FP3ojEX0omEA0>6?=`0J40H0000001LB1P1OBQ/0n=YA0?ocFP3olET00`3ol5T0
103ol5P0oo1I0?oaF`3olEl90?o`F@050?o`F03ol5X0oo1F0?obHP3olEX02`3ol5T01`3ol5X0oo1I
0?oaG`3olEl0oo1H0?oaG03ol5P02@3ol5T01`3ol5P0oo1I0?o`G03ol5L0oo1J0?oaGP3ol5P0403o
l5T01@3ol5/0oo1J0?oaG@3olF00oo1H00d0oo1I00P0ooAK0?ojG03oned0oneH0?oHD03N/440Sg8Z
04Lh50<0000000H02`D302hK2`22Bb40gH<f0?neBP3oeeP20?oDF0030?oFE`3oeEL0omAG00H0omAG
00@0om1B0?o;BP3obDP0olQ60P3obDP20?o8B0060?o9B03oaDD0oka30?o2A03oaDL0okm40P3ob4P:
0?o6A`030?o8B03oaTL0olM800<0olI700L0olQ80?o3A03oaDD0olI70?o8B03oaTL0olE700P0olI7
0P3oaDL01P3oadP0olQ70?o8B03o`D@0olI60?o9B@D0olI700<0olM80?o9B03oaTL0403oaTL00`3o
bDP0olM80?o4A@020?o2A0P0olA700D0olI80?o4A`3oa4L0ol=60?o6A`020?o4A`050?o2A`3o`dL0
olY90?oIBP3ohk80o`3ooonm0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWiol0oooo1@3oool01P3onol0ojN@07/o6@2WEbL0oj=60?njD@X0okE>3P3o]U001@3o
]Dh0okI@0?nfD03o]U00okE>0280okI@1@3o]Dh0103o]U00okE>0?neCP3o]4h=0?neCP080?nfD03o
/Td0ojU80?n^BP3o^U00okU?0?nhD03o^eP80?nkF`80okaL00H0ok]J0?nnH@3o`FL0okUF0?nkF`3o
_5dB0?nkF`080?nkFP3o_5d0okaP0?nkF`3o^eX0ol1S0?nlF`3o^eX20?nlG0l0ok]K00D0okaL0?nk
F`3o^e/0ol1T0?nkG0020?nlG0d0ok]K00D0okaL0?nlF@3o`FL0okaK0?nlG00;0?nkF`050?nlG03o
^eX0okiR0?nmG03o_5`02P3o^e/0103o_5`0okeQ0?nkFP3o_5`80?nkF`030?nlG03o_F80okeP00@0
ok]K00/0okaK0?nnG03o/UP0fW@j02lG3@0200002@D207E36`3oXDH0oliJ0?o@FP030?o=F@030?o=
FP3oceh0oliJ00H0oleI00<0olaH0?o>G@3ocE/00`3ocET0103obeL0okY50?niA03oaE@60?o=F@03
0?o<EP3ocET0oleJ00@0oleI00<0oliM0?o>G03ocEX0103ocET00`3ocU/0oleJ0?o=F@030?o=F@03
0?o=E`3ocUX0oleI00<0oleI00<0oliK0?o=G03ocET00P3ocET00`3oc5P0oliM0?o>G@020?o=F@0<
0?o>FP3HO3H00`810=R9=03omUd0onIH0?oUF03oiE/0onIJ0?oUF03oiET0onEG0P3oie`01P3oiEP0
onEI0?oUF03oiEL0onML0?oUE`<0onEH00<0onEF0?oUE`3oiEP00`3oiEP00`3oi5D0onEH0?oUF002
0?oUF0070?oUE`3oiEP0onEH0?oUF03oie`0onQP0?oUE`020?oUF0030?oWG03oif@0onEF00<0onEH
00<0onEK0?oUF03oiEP00P3oiEP00`3oiEL0onEH0?oUF0020?oUF0030?oUF`3oi5X0onEH0080onEH
00<0onEG0?oWG03oiUX00`3oiEP00`3oiET0onMM0?oUE`040?oUF0030?oUF`3oiEP0onEH00<0onEH
00<0onML0?oUF03oiEP0103oiEP00`3oiUX0onEH0?oUF0030?oUF0030?oUE`3oiET0onEH00D0onEH
00<0onML0?oUE`3oiEP0103oiEP00`3oi5X0onEK0?oUEP060?oUF0030?oTFP3oiUX0onEH00L0onEH
00<0onEK0?oUF@3oiEP00P3oiEP01@3oiUP0onaJ0?oVF03//TD0<b0<0080000000D0=BX?0?70A`3o
kEP0ooAJ0?obFP040?o`F@030?o`FP3ol5L0oo9T00X0oo1I00D0oo1J0?o`F03olEh0oo1H0?o`FP0:
0?o`F@060?o`FP3ol5T0oo1H0?obH03olE/0oo1H3P3ol5T0103olEh0oo9S0?o`F03ol5X?0?o`F@80
oo1J00<0oo1F0?obH@3olE/00P3ol5X<0?o`F@0J0?obFP3omU/0ooAJ0?o]F03oiE@0l/U;09Yj;P1<
?1P03P`400<10@0000000P0000l80`1N=QP0iXPh0?nhC@3ocUD0om9G0?oJFP3of5X0omMH0?oEF03o
e5L0om5E0?o=CP3obTT80?o9B00<0?o8AP3o`T@0ol940?o5A`3oa4L0olI70?o8A`3oa4D0ol=60?o7
B@3oaTL0olM81@3oaTL01P3ob4P0olI70?o7B03oaTL0olU80?o3A080olM81P3oaTL00`3oadP0olI7
0?o6A`090?o6A`0:0?o6B03oaTL0ol]80?o<B@3o`D@0olM60?o6B@3oaTL0olQ90?o9B0D0olI700<0
olM90?o8B03oaTL01P3oaTL02@3oadP0olI70?o6A`3oaTL0olM80?o6AP3o`D@0ol940?o3AP060?o4
A`060?o5A`3oaTP0olA70?o4A`3oaDL0olE60`3oa4L0103ocd/0om=90?o>G03onO?o0?oookd0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool60?ooo`06
0?oloP3FUG/0Od8L0:1D9@3eU440okQ@2@3o]Dh50?nfD080okI?0P3o]U000`3o]U40okI@0?nfD003
0?nfD0030?nfC`3o]U00okI@0280okI@00@0okI?0?neCP3o]Tl0okI?0P3o]Dl40?neCP80okI?2`3o
]Dh01@3o]U00ok9=0?nYB03o[TX0okY@00<0okU?00/0okYB0?njE03o_5L0okaK0?nkF`3o_f80okmQ
0?nlF`3o_V40okiP0?nkFP0D0?nkF`070?nlG@3o^eX0ok]K0?noI03o_5`0okaO0?nmH0020?nlG0l0
ok]K00H0okaM0?nkF`3o_V80okaL0?nmG@3o_5h>0?nkF`050?nlG03o_Eh0okiQ0?nkF@3o_Ul02`3o
^e/01P3o_5d0ok]K0?nmG`3o_El0okeM0?nkFPT0ok]K00D0okaL0?nmG@3o_5`0okeL0?nlG@070?nk
F`050?nlG03o_5X0okmQ0?nkF`3o_Eh00`3o^e/0303o_U`0ol1M0?nbE`3[V4X0QU0X01P<1`0B2P@0
?B<?0:=a<@3o^4l0oliI0?o>FP80oleI00@0oliK0?o<F03ocU`0oliK1P3ocET0103ocU/0oliL0?o>
F`3ocEP40?o=F@040?o2C`3o^TH0olEA0?o<F@@0oleI00<0oliK0?o>G03ocET01@3ocET00`3ocU/0
olaH0?o=F@040?o=F@030?o=F03ocUX0oleI00@0oleI00<0oliJ0?o=FP3ocET00P3ocET00`3ocU/0
oliL0?o=F@030?o=F@0C0?o<F03ocEP0oleI0?o=F@3oceX0]GHc00T60P1VAa/0oniK0?oWF03oiEP0
onIJ0?oUF03oiU`0onMM0?oVF`3oiUT0onIL0?oVFP040?oUF0060?oVF@3oiEP0onEH0?oUF03oiUX0
onIO103oiEP00`3oiEH0onEG0?oUF0030?oUF0070?oUE`3oiEP0onEH0?oUF03oied0onQP0?oUE`02
0?oUF0030?oVFP3oiU`0onEG00@0onEH00D0onIJ0?oUF03oiEP0onEH0?oUFP040?oUF0030?oUE`3o
iU/0onEI00<0onEH00<0onEG0?oVFP3oiEP00`3oiEP00`3oiET0onIJ0?oUF@030?oUF0030?oUF@3o
ie/0onEH00@0onEH00<0onIJ0?oVF`3oiEP00`3oiEP00`3oiUX0onIH0?oUF0050?oUF0030?oVF`3o
iUT0onEH00@0onEH00<0onII0?oVF`3oiEP01@3oiEP00`3oiEL0onIK0?oUF0060?oUF0<0onIJ1P3o
iEP0103oiU/0onEG0?oVF`3oiET30?oUF00<0?oWF@3oheL0jK]809f4<`18;Q800P4103<X3`1fGR<0
dkU50?o]E`3ome`0oo=J103ol5T00`3olE/0oo1J0?oaG@020?o`FPP0oo1I00D0oo1J0?oaG@3ol5T0
oo5K0?oaFP0;0?o`F@040?oaF`3olET0oo1H0?oaF`80oo1J3@3ol5T01@3olE`0oo1I0?oaH03olE/0
oo5J0100oo1I00P0oo5L0?oaGP3ol5P0oo5N0?o`F@3ol5P0oo5K0?o`FPT0oo1I01P0oo5I0?oaFP3o
lEX0oo5I0?obFP3ojeL0gLE:0:BL>P2AORl0M5`S03X_4P0J5@P030T301X>1`1P>1P0P5XU09Q^;P31
RSP0m;940?o0AP3oaTL0oli:0?o=BP3obTT70?o9B0030?o8AP3o`T@0ol5400H0olI700T0olQ80?o6
A`3oaDL0olM90?o6B03oa4H0olI70?o7B03o`TH00P3oaTL00`3oaDH0olI80?o6A`080?o6A`030?o7
B03oaTL0olI700T0olI700@0olM80?o6A`3ob4P0olQ80P3oaTL02P3ob4P0olM80?o4A`3oadT0olQ8
0?o7A`3oa4H0olI70?o6B03oadP40?o6A`040?o8B@3oaTL0olM80?o7B0H0olI700<0ol=40?o2A03o
`dH01P3oa4L20?o6B00:0?o4A`3oaDL0olE70?o4A`3o`dH0olA70?o<B03odD/0omn?0?oij_l0oooo
_P3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooo`L0
oooo00H0oo;b0<=aC@1i?AH0MchK0?jQAP3o]U070?neCP80okI@0P3o]Dh60?nfD0030?nfD@3o]U00
okE@02D0okI@0P3o]E020?nfD1H0okE>00D0okI@0?nbC@3oZDP0oji:0?njD0020?niC`090?njC`3o
^Dl0okU?0?nkC`3o^e40okYF0?njF@3o^e/0ok]L0140ok]K0P3o^eX0203o^e`0okiR0?nlG03o^EL0
okiR0?njF@3o^e/0ok]J0`3o^e/00`3o^eX0okeO0?nkFP090?nkF`030?nkFP3o_5/0okiS0080ok]K
00<0okiR0?nkFP3o^eX0303o^e/01P3o^eX0okaJ0?nnHP3o_5`0ok]J0?nnH080ok]J2P3o^e/01@3o
^eX0okaL0?nmGP3o_El0ok]K0080ok]J203o^e/01@3o_5`0okeN0?nlF@3o_F00ok]J00P0ok]K00D0
ok]J0?nlG@3o_5`0okeM0?njF@040?nkF`0:0?o3GP3o]UX0bf/d04<S4P0000004@X408E<8@3oVd<0
omMN0?oAF`<0oleI00@0oleJ0?o=F@3oceh0oleL1@3ocET0103oc5P0oliM0?o=E`3ocU`50?o=F@80
olaH00<0okQ50?o3C`3ocET0103ocET00`3ocUd0oliJ0?o=F@030?o=F@80olaH00<0oliM0?o=FP3o
cET00`3ocET00`3oc5P0oleH0?o=FP050?o=F@030?o>FP3ocET0oleI0080oleI00<0olaH0?o=F03o
cET00`3ocET03P3ocU/0oliM0?o=F@3ocET0om9L0=Ik=P02000000000>NoB@3oiEh0onEI0?oVE`3o
iUh0onEH0P3oiEL0103oiEX0onEH0?oTE@3oiEL30?oUF0030?oUG03oiU/0onEH0080onEH00<0onII
0?oWG03oiEL00`3oiEP00`3oj600onEH0?oUF0030?oUF0070?oUE`3oiEP0onEH0?oUF03oiUd0onIO
0?oUE`020?oUF0030?oUE`3oiEH0onEF00<0onEH00<0onEI0?oVF`3oiEP00`3oiEP00`3oieh0onEH
0?oUF0020?oUF0030?oUE`3oiET0onEI00<0onEH00<0onIH0?oUF03oiEP00P3oiEP00`3oiEL0onMJ
0?oUF`050?oUF0030?oVFP3oiEL0onEH00<0onEH00<0onEG0?oVF@3oiEP00`3oiEP00`3oiET0onII
0?oUEP040?oUF0030?oVF@3oie`0onMG00H0onEH00<0onEK0?oUF@3oiEP0103oiEP00`3oiEL0onEI
0?oVG0060?oUF0040?oUE`3oiUd0onEF0?oVFPH0onEH00D0onEG0?oVG03oiET0onEH0?oUE`030?oU
F0040?oWF@3ok5X0d8@c05Ti5@80000000@0KUTP0=R[?`3ok5P0oo]N1@3ol5T0103ol5P0oo5J0?oa
F`3olEl20?o`F0P0oo1I00H0oo1G0?oaH@3ol5T0oo1K0?o`FP3ol5P90?o`F@060?oaF`3ol5P0oo5N
0?oaF`3ol5T0oo1L0P3ol5P;0?o`F@80oo1H00H0oo5N0?o`E`3ol5P0oo5O0?o`F@3ol5P>0?o`F@80
oo1H00D0oo1G0?oaH`3olEX0oo5O0?o`F`020?o`F0d0oo1I00P0oo=J0?oiG03ooel0omQ@0=>X?`2G
Mbd0CSlF01@>10<0000000P0>B<<081:6P3:M2X0o9hh0?o5AP3ofTl0omE<0?o<BP@0olU800@0olQ6
0?o2A03o`T@0olA71P3oaTL02P3oaDL0olM80?o5B03oaTH0olU90?o4AP3obDP0ol=50?o4A`3oadT2
0?o4AP80olI700<0olQ80?o6A`3oaTL01@3oaTL00`3obTP0olI70?o6A`060?o6A`030?o8B03oaTL0
olI70080olI700<0olU80?o6A`3oaTL00P3oaTL04@3oadP0olI70?o6A`3oaTL0olE70?o6A`3oaTT0
olI60?o4A@3oaDL0olQ70?o6AP3oaDP0olQ70?o6A`3oaDL0olM800<0olI700D0olQ90?o6A`3o`TD0
ol940?o3AP070?o4A`80olE70`3oa4L20?o6A`030?oCB`3oj/l0oooo0?l0oooo_`3oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooo`P0oooo00/0omSD0:iR
?@1b>140_68[0?nkDP3o]Dh0okE@0?neCP3o]U00okE>0?neD0030?neCPH0okI@00<0okE>0?nfD03o
]U00803o]U000`3o]Dh0okI@0?nfD0020?neCPH0okI@5P3o]Dh02P3o]U00ok5<0?nXA`3o[d/0oke@
0?nhC`3o^Dl0ok]?0?niC`3o^4l30?niC`030?niDP3o^EH0ok]J00l0ok]K0P3o^eX01@3o_F40ol1T
0?nkF`3o`6@0okeM0080ok]J1`3o^e/00`3o_5h0okaL0?nlF`060?nkF`060?nkFP3o_5`0okmU0?nm
F`3o`6@0okaL0P3o^eX<0?nkF`060?nkFP3o^UT0okiP0?nlG@3o_V<0okeM303o^e/01P3o^eX0okaN
0?nmFP3o_5`0okeQ0?nkF@P0ok]K0P3o^eX01@3o_El0okaI0?nnH03o_5d0okaJ00P0ok]K00@0okeN
0?nlF`3o_Ed0okaK103o^e/0103o`5h0olYT0?nXDP23AB<20000000401`@1P39N3@0omEM0?oIG`D0
oleI00<0olmN0?o>G03ocEL01@3ocET0103ocUX0oliM0?o>G`3oc5P60?o=F@050?o>G`3o`Tl0oke7
0?o;E`3ocUX00`3ocET00`3oceh0oliM0?o=F@040?o=F@80oliJ1@3ocET00`3ocUX0oleI0?o=F@04
0?o=F@030?o=E`3ocUX0oleI00<0oleI00<0olaH0?o>F03oc5P0103ocET03@3ocUd0oleI0?o=F@3o
cET0ol1D028C20000000ID0K0?oWFP3oj600onEK0?oTE@3oiUT0103oiEP20?oUF`<0onEH00<0onEG
0?oTFP3oiEX00`3oiEP00`3oiED0onEF0?oUF0030?oUF0030?oXJ03oiEP0onEH00<0onEH00L0onEG
0?oUF03oiEP0onEH0?oWGP3oiV40onEG00<0onEH0P3oiUX40?oUF0030?oUE@3oiEP0onEH0080onEH
00<0onML0?oUE`3oiEP00P3oiEP00`3oiEL0onIM0?oUF0040?oUF0030?oUF`3oiET0onEH0080onEH
00<0onEG0?oVFP3oiEP0103oiEP00`3oiUX0onII0?oUE`030?oUF0030?oUE`3oiUP0onII00D0onEH
00<0onII0?oVE`3oiEP0103oiEP00`3oiUL0onEH0?oVF0050?oUF0030?oVF@3oie`0onEI00@0onEH
00<0onEG0?oUF`3oiUX01P3oiEP00`3oiEL0onEH0?oVF`080?oUF0030?oWG03oiET0onII00@0onEH
00/0onMI0?okH03oee80fh/e034N300000001@8106QC7P3L_4H0oomO0?odFP050?o`F@050?o`F03o
lF40oo1H0?oaG@3ol5P0203ol5T20?o`F0050?oaG@3olE/0oo5O0?o`EP3ol5P0203ol5T0203olEP0
oo5J0?o`F03ol5X0oo5K0?oaGP3olEd0oo1H3P3ol5T0103ol5P0oo5Q0?oaF@3olElA0?o`F@060?o`
F03ol5T0oo5Q0?oaG03ol5<0oo5O0`3ol5P<0?o`F@090?oaFP3ome`0ooaM0?ooFP3lgDX0b:0c09Yl
:01eGah0:b8;00<0000000X08A@707Y86@2aIbD0k8X`0?nnA03og4l0om=<0?o>BP3obTP0olQ60P3o
`T@50?o6A`090?o5A`3obDP0olA50?o7B@3oaDP0olI60?o6A`3ob4T0olI70080olE700L0olM80?o4
A@3oa4D0olE70?o6B03o`DD0olI70080olE7103oaTL00`3ob4T0olI70?o6A`040?o6A`030?o7B03o
bTT0olI700@0olI700<0olY90?o6A`3oaTL02P3oaTL04@3oadT0olI70?o7B@3oaDH0olA70?o6B@3o
adT0olA60?o3AP3oaTT0olI70?o5A`3oadP0olI70?o2A@3o`T@0ol=600L0olA700<0olE70?o4A`3o
a4L00P3oa4L00`3oaDH0om970?oNS`3o0?oool40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool90?ooo`060?oSh@2WGCL0O3lI0?^5>P3o_e@0okA>1P3o
]Dh50?nfD0030?neCP3o]U00okI@01h0okI@00<0okE?0?ndCP3o]U00303o]U0F0?neCP050?nhD@3o
[4`0ojE60?n`BP3o_5002P3o^Dl0103o^U<0ok]H0?nlG03o^e`90?nkF`<0ok]J00H0okmT0?nkFP3o
_600okiR0?nkF`3o^eX;0?nkF`030?nlG03o_5d0okaM0080ok]K0P3o^eX01P3o_V00okaM0?nkFP3o
_V80okaK0?nkFPd0ok]K00L0ok]J0?nmGP3o_V<0okUF0?nmGP3o_5h0ok]J00/0ok]K00D0ok]J0?nm
H03o_V00okaN0?nlG0020?nkFPP0ok]K00H0ok]J0?nnH03o_Eh0okaN0?nlF@3o^eX70?nkF`80ok]J
0P3o_Ed00`3o^e`0ok]K0?nkF`030?nkF`0;0?o3G`3oZe@0[5/]04HT4`00000050/409iJ9`3oWT@0
omAM0?o>FP3oc5T00`3ocET20?o>FP030?o>F`3ocET0oleI00@0oleI00<0olaH0?o>G@3ocE`01P3o
cET01P3ocU/0oleG0?o9E`3o^D@0ol5=0?o?G080oleI00@0oleK0?o>FP3ocE`0olaH103ocET00`3o
cU`0oleI0?o=FP060?o=F@030?o<F03ocET0oleI00<0oleI00<0oliO0?o=F@3ocET00`3ocET00`3o
cUl0oleJ0?o=F@030?o=F@030?o=E`3ocE/0oleI0080oleI00D0_8hl000000061040olQ>0?oXFP02
0?oUE`030?oUF`3oiEX0onEH0080onEH00@0onIH0?oVF@3oiEP0onEK0`3oiEP00`3oiEH0onEG0?oU
F0020?oUF0030?oXG@3oiEP0onEH00<0onEH00<0onQX0?oUF03oiEP00`3oiEP01P3oiEL0onEH0?oU
F03oiEP0onIK0?oVG@<0onEH00<0onEG0?oVGP3oif80103oiEP00`3oiU/0onEG0?oUF0020?oUF003
0?oUEP3oie`0onEH00<0onEH00<0onEF0?oVF`3oiEP0103oiEP00`3oiEH0onEH0?oUF0020?oUF003
0?oUF@3oie/0onEH00<0onEH00<0onEI0?oVG@3oiUT0103oiEP20?oVF@030?oUE`3oiEP0onEH00<0
onEH00<0onIH0?oUE`3oiEP00`3oiEP00`3oi5L0onEG0?oUFP050?oUF0030?oUE`3oieX0onIK00D0
onEH00@0onEG0?oUF@3oiUX0onEG1`3oiEP00`3oiE/0onML0?oUEP050?oUF0050?oUE`3oiEP0onEH
0?oUF`3oiEL00`3oiEP01@3oi5P0onaJ0?ogGP3f]4D0G3XF0080000000D09Qh;0:j;<`3ojUL0ooaM
0?oaFP040?o`F@060?o`F03ol5X0oo5K0?oaF`3ol5T0oo1H203ol5T01@3ol5P0oo1I0?oaG@3ol5T0
oo5N00X0oo1I00L0oo5L0?o`F03ol5P0oo1M0?o`G03olEX0oo5M00h0oo1I00H0oo1H0?o`FP3olEh0
oo1G0?oaG@3olE`20?o`F0h0oo1I00L0oo1H0?o`F@3ol5L0oo5N0?o`E`3olF00oo5Q0080oo1H2@3o
l5T03P3ol5X0oo1H0?oYD03oiTd0on980?oXBP3olTd0ooM?0?oXB`3^_Sd0]I4_081V8@13=Q400`81
0P0000002`0?20<0ES4B0:1M8P3XR300ok0o0?oBC03ocd/0olA60?o2A03oa4H0olI70080olE700H0
olE60?o6AP3oadT0olA60?o7B03oaDL20?o6A`050?o8B@3oaTL0olI70?o6A`3oadP00P3oaDL20?o6
A`080?o2AP3oaTL0olU90?o4A`3ob4T0olM90?o6A`3oadP50?o6A`040?o8B03oaTL0olI70?o:BAD0
olI700@0olE70?o7B03oaTL0olQ70P3oa4H0203ob4L0olM90?o4A@3o`TH0olU90?o3A@3oa4@0olA6
1P3oa4L00`3oaDL0olA70?o4A`030?o4A`030?o=B@3oc4d0ooKX0?l0oooo`@3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooo`X0oooo00H0on[T0:MYBP1o
@Qd0cg@c0?n]C03o]dl40?neCP030?nfC`3o]U00okI?01d0okI@0P3o]TlD0?nfD100okE>00<0okI?
0?neCP3o]Dh00`3o]Dh01@3o]U00ok1<0?nWA`3o[TX0okY@00X0okU?00D0okU@0?njD03o^U40okUD
0?nkE`040?nkF`080?nkFP3o_5h0okiP0?nlF`3o_f<0okaL0?nkFP3o_5dA0?nkF`050?nkFP3o_F40
okeN0?nlF`3o_f800`3o_5`>0?nkF`060?nmGP3o_5`0okaK0?noHP3o_5/0okeM3@3o^e/01@3o_V40
okeM0?nlG@3o^e`0okaL00X0ok]K00<0okaN0?nmGP3o_5/00P3o_5`80?nkF`030?nlG@3o^e/0okiP
0080okaL0`3o^e/20?nlG00;0?neF03GT4D0M4LS01d@20071080CRdD0:Yf=03o_5<0oliI0?oBG03o
cUX00P3ocET01@3ocEP0oliL0?o>G03ocET0oleJ00H0oleI00<0oliL0?o>FP3ocEX01@3ocET0103o
cU/0oleH0?o>G03oae<20?nlA`060?o9E@3ocET0oleI0?o=F`3ocU`0oleJ1@3ocET00`3ocU/0oliL
0?o=F@040?o=F@030?o>F`3ocU`0oleI00@0oleI00<0oliK0?o>G03ocE/0103ocET00`3ocU`0oleK
0?o=F@030?o=F@<0oliM00L0oliH0?oBGP3oaU/0CbdC03LS3@3:VCX0onYJ0080onEH00<0onII0?oU
FP3oiET00`3oiEP0203oiUT0onIK0?oUE`3oiEP0onIK0?oUE`3oiUX0onEL103oiEP00`3oiU`0onEH
0?oUF0030?oUF0030?oVFP3oiEP0onEH0080onEH00<0onEF0?oUF03oiEP0203oiEP00`3oiU/0onMN
0?oUF0030?oUF0030?oVFP3oiEP0onEH00<0onEH00<0onIK0?oUE`3oiEP00`3oiEP00`3oiUX0onEH
0?oUF0020?oUF0030?oUE`3oiUX0onEH00@0onEH00<0onIJ0?oUF03oiEP0103oiEP00`3oiUX0onEJ
0?oUF0020?oUF0040?oUF@3oiUT0onII0?oUE`H0onEH00<0onII0?oUF03oiEP00`3oiEP20?oVFPH0
onEH00<0onII0?oUE`3oiEX01@3oiEP0103oiUT0onEJ0?oVF@3oiEX50?oUF0040?oUF@3oiEL0onEJ
0?oVF@L0onEH00@0onEI0?oVG03oiUL0onIK103oiEP03@3ojeX0on5F0?g5B`2ZR3D0E3HE00<30@0O
60T0G4TK0;VW?P3okEP0oo9J0?oaFP3olET00`3ol5T01@3ol5X0oo5J0?oaG03ol5P0oo5K00T0oo1I
0P3ol5X0103olE/0oo1H0?oaG03olE/60?o`F@030?o`FP3olE`0oo5J0080oo1I00H0oo1J0?oaFP3o
lE/0oo5K0?o`F@3olE/>0?o`F@80oo1J00@0oo5N0?oaG@3ol5T0oo5L4@3ol5T01`3ol5/0oo5J0?oa
F@3olF40oo5J0?oaF@3olEd0103ol5T0103okeH0on]C0?oYD03oiD/60?oSB@0H0?oTBP3ojD/0on]<
0?oTBP3ofdH0jLY10;nR=02MPRX0Nf8P05105@0I50H02`H201X@1P0g80/0Ld8G08mN8@2dPRh0oZln
0?o1AP3oaDH0olI70?o9B03ob4T0olM81@3oaTL01@3ob4T0olI70?o6A`3oaTL0olM800@0olI700d0
olM80?o6A`3oadP0olI70?o:B@3ob4P0olI70?o4AP3ob4P0olU80?o3AP3oadL0olM800<0olI700<0
olY90?o6A`3oaTL0103oaTL00`3ob4P0olI70?o6A`090?o6A`030?o8B03oadP0olI700T0olI700X0
olI80?o9B03oaTH0okU20?noA@3oadP0olA70?o1AP3o`TL0olI70P3oa4L01`3oaDP0olA70?o4A`3o
a4L0olY?0?oQW03om^T0o`3oooo20?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0oooo2`3oool01@3od/L0QDHS07Hk602aG2T0ojm=0080okE>00<0okI@0?ne
C`3o]Dh06`3o]U000`3o]E00okE>0?nfD00G0?nfD0T0okE>00D0okI?0?neCP3o]Dh0okE>0?neC`08
0?neCP050?nfD03o/D`0ojM70?n^BP3o^U002P3o^Dl00`3o^E00okU?0?niC`020?niC`070?nhD03o
^E80okaK0?o0H`3o^UP0ok]L0?nlG00B0?nkF`090?nkG03o_5`0okaJ0?o1I`3o_5/0ok]J0?nkF`3o
_F40okaL00d0ok]K00D0okaL0?nkFP3o_V80okmT0?nkFP0>0?nkF`050?nlG03o_5h0okiR0?nkFP3o
_5`02`3o^e/00`3o_5`0okeP0?nlG00:0?nkF`040?nlG03o^e/0okiR0?nlG@D0ok]K00/0okeL0?o0
G@3o]5P0^F<_01/>1`0000003@L309EE9@3o/4d0oliJ0?o?FP050?o=F@030?o>G@3ocE`0oleI00L0
oleI00<0oliL0?o<F03ocET01P3ocET02P3ocEX0oliO0?o<F03oc5P0oka70?nkAP3o`Th0oliJ0?o=
G03ocU`60?o=F@030?o<E`3ocUX0oleJ00D0oleI00<0oliO0?o=F@3ocET0103ocET00`3ocU`0oleJ
0?o=F@040?o=F@030?o>G@3ocET0oleI0080oleI00D0oleJ0?o<EP3od640oleG0?o=FP020?oAG004
099C8`0:1`<0okU70?oZF`<0onEH00<0onIJ0?oUF@3oiEP00P3oiEP00`3oiEL0onIL0?oUE`030?oU
F0030?oUF@3oiEP0onEH00@0onEH00<0onEG0?oUF03oiEP00P3oiEP00`3oi5D0onEG0?oUF0030?oU
F0030?oUEP3oiEP0onEH0080onEH0P3oiEL40?oUF0030?oUE`3oiUD0onEH00@0onEH00<0onEF0?oU
F03oiEP00P3oiEP00`3oiET0onMN0?oUF0030?oUF0030?oUE`3oiEP0onEH00@0onEH00<0onMN0?oU
F03oiEP00`3oiEP00`3oieh0onEI0?oUF0040?oUF0030?oVF@3oiEP0onEH00@0onEH00<0onEK0?oU
F@3oiEP0103oiEP00`3oiEH0onIJ0?oUF0050?oUF0030?oUF`3oiEH0onEH00D0onEH00<0onEI0?oW
G03oiEP01P3oiEP00`3oiET0onEJ0?oUF0070?oUF0030?oWG@3oiEL0onEH00L0onEH00<0onAG0?oW
F`3oiEP01@3oiEP02`3ojUT0onEH0?ndA@1bB1/03PP30000000X8Pd0_iTi0?oRD`3om5/0oo5I00H0
oo1I00@0oo1J0?obH03ol5H0oo1J2P3ol5T01@3ol5X0oo1H0?oaG`3ol5H0oo1J00@0oo1I00<0oo1H
0?oaG@3ol5P01`3ol5T0103olEh0oo5O0?o`F03ol5X@0?o`F@040?oaG03olVH0oo1H0?o`FQ<0oo1I
00D0oo1J0?o`F03olF80oo1L0?oVC00<0?oSB@050?oTBP3ohdT0on=90?oTB@3oiDX00P3oidX01P3o
hdT0omi70?_:@02iU300FDLG00h:0`80000000X00@4000T40P0m8@d0TU8N0?BL>03o_T@0olA60?o9
B@3obdX0olI90P3oaTL01@3ob4T0olI70?o6A`3oaTL0olM800P0olI700<0olY90?o6A`3oaTL00`3o
aTL01@3oadP0olI80?o8AP3o`D@0ol=400<0olM84@3oaTL00`3oadP0olI70?o6A`0;0?o6A`030?o5
A@3o`T@0ol=600@0olA700P0olI70?o5AP3o_DD0ol570?o5B03oaTL0om1:0?oOZ?l0ooooa03oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooo``0oooo00D0
ojnO08a;:01`>180jI0o0?njDP040?neCQL0okI@00<0okE@0?neCP3o]Dh06`3o]U090?neCP030?nf
C`3o]Dh0okE>00X0okE>00D0okI@0?naC03oYdL0ojm;0?njD00>0?niC`80okY?0P3o^Dl0103o^U@0
ok]J0?nkF`3o^e`>0?nkF`80ok]J00D0okeM0?nkFP3o_F00ol5W0?nkFP040?nkF`040?nkFP3o_F00
ok]K0?nlG0T0ok]K00@0okaN0?nkFP3o_V80okYH3@3o^e/01@3o^eX0okaK0?nlG03o_Ed0okmT00`0
ok]K0`3o_5`00`3o_F80ok]K0?nkF`080?nkF`040?nkFP3o_5`0okeR0?nmG@D0ok]K00D0okaL0?o3
GP3o_E`0oj=@06`h70020000000402DD2@38PCT0om=L0?o>FPD0oleI00<0oliK0?o>G@3ocEL01P3o
cET0103oc5P0oleJ0?o?GP3ocU/70?o=F@0;0?o>G03oc5H0oleI0?o=F@3oaU80okY60?nmB03oc5P0
oleJ0?o>G03oc5P01@3ocET00`3ocU/0olaH0?o<F0050?o=F@030?o>G03ocE`0oleI00D0oleI00<0
oliL0?o=F@3ocET00`3ocET02@3ocUX0oleG0?o=F@3ocE`0oleI0?o=FP3ocel0oleI0?o=FP020?o=
F@060?oFGP3aRS`02`H306<n603oiEP0onMI0P3oiEP00`3oiE/0onIM0?oUE`040?oUF0030?oUEP3o
iEP0onEH0080onEH00@0onEI0?oVGP3oiUX0onEI0P3oiEP00`3oiET0onMN0?oUF0030?oUF0030?oU
E`3oiEP0onEH00<0onEH00<0onEF0?oUF03oiEP00`3oiEP00`3oiEH0onEG0?oUF0030?oUF0030?oU
E`3oiEP0onEH0080onEH00<0onIJ0?oWHP3oiEL0103oiEP00`3oiUT0onEH0?oUF0020?oUF0030?oU
F@3oiUl0onEG00@0onEH00<0onEG0?oVF@3oiEP00`3oiEP00`3oiEL0onEK0?oUE`040?oUF0030?oV
F`3oiET0onEH00D0onEH00<0onIJ0?oUE`3oiEP0103oiEP00`3oiEH0onII0?oUF0050?oUF0030?oV
F@3oiEL0onEH00D0onEH00<0onEI0?oUE`3oiEP01P3oiEP00`3oiUX0onII0?oUF@070?oUF0030?oU
EP3oie`0onEH00L0onEH00@0onII0?oWG03oi5X0onEI103oiEP01@3oiUP0onMI0?oXF@3o/D@0BBhA
0080000000D0:b<>0=nhA03omU/0ooQL0?oaF@060?o`F@030?o`FP3olEd0oo5I00`0oo1I00@0oo1L
0?oaG`3ol5T0oo1J0`3ol5T00`3olEX0oo1L0?o`F0080?o`F@050?o`E`3olUl0oo1J0?o`F`3ol5P0
3`3ol5T01@3ol5P0oo9P0?o`E@3ol5X0oo1L00l0oo1I00T0oo5J0?o`F03okED0onM=0?oTB@3oh4P0
omi70?oTB@3ohDP00P3ohdT00`3oi4T0on=90?oSB@040?oSB@030?oTBP3ohdT0onA:0080on=900`0
onA90?oSB@3ohTT0on=90?oWBP3ogDP0onI:0?;1?P25Jb40FDDE034X300>30@30000000804@V3P2I
Fb00l8Tb0?n`?`3o`TD0ole;0?o?B`3obdX30?o6A`030?o8B03oaTL0olI700H0olI700<0olY90?o6
A`3oaTL00P3oaTL20?o8B0@0olI700H0olU90?o0A03o`dD0olU90?o8A`3oaTH70?o6A`030?o8B03o
aTL0olI70080olI70P3ob4P=0?o6A`040?o8B03o`dH0ol940?o3A@L0olA700D0olI80?o7AP3ocd/0
ole]0?ojm03o0?oool@0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3oool=0?ooo`050?o1]@2>Cb/0_VDY0?nkDP3o^E000`3o]DhD0?nfD0030?neD03o]Dh0
okI@01h0okI@1@3o]Dh0103o]Tl0okI@0?neD03o]4h=0?neCP050?nfD03o/D/0ojM70?n_B`3o^U00
303o^Dl00`3o^dh0okU?0?niC`040?niC`040?niD03o^U@0ok]H0?nlG0X0ok]K00L0ok]J0?nkF`3o
_5`0okeQ0?njF@3o_f80ok]K0080ok]J1`3o^e/20?nmG@D0ok]K00L0ok]J0?nkF`3o_Eh0okaI0?o0
IP3o_5`0ok]J00h0ok]K00D0okiN0?nlG03o_f80okYH0?nkFP0;0?nkF`040?nmGP3o_5d0okiN0?nk
FPT0ok]K00D0ok]J0?nlG@3o^e/0okeN0?nkFP050?nkF`0:0?nlF`3o`Ul0oi]:0;YS<00K3PL00000
034M302HEbD0oja<0?oDG0D0oleI0P3ocEX00`3oce`0oleI0?o=F@060?o=F@030?o<F03ocU`0oleI
00H0oleI00<0oleJ0?o=E`3ocE`00P3ocET01`3ocUX0ol5=0?nkAP3oae<0oleI0?o>GP3oc5P01P3o
cET00`3ocUd0olaH0?o=F@050?o=F@030?o>G@3ocET0oleI0080oleI00@0olaH0?o=F@3oceh0oleJ
1@3ocET0203oc5H0oliM0?o=FP3ocf00olmN0?o<F03ocU`0oleJ0P3ocET01P3odE/0okE@048V4@00
0000ZX@c0?o]F`80onEH0P3oiET00`3oiEH0onEH0?oUF0020?oUF0030?oTFP3oiUX0onEH00<0onEH
00@0onEF0?oUE03oieX0onIK0P3oiEP00`3oiET0onIM0?oUF0030?oUF0030?oXIP3oiET0onEH00<0
onEH00<0onEF0?oUF03oiEP00`3oiEP00`3oiEH0onEG0?oUF0020?oUF0030?oUE`3oiel0onIK00<0
onEH00<0onII0?oVFP3oiEL01@3oiEP00`3oiUT0onEH0?oUF0020?oUF0030?oTE@3oiET0onEH00@0
onEH00<0onEI0?oUF03oiEP00`3oiEP00`3oi5D0onII0?oUF0040?oUF0030?oWG@3oi5X0onEH00@0
onEH00<0onIJ0?oVF@3oiEP01@3oiEP00`3oiUT0onEI0?oUF0050?oUF0030?oVF@3oiET0onEG00D0
onEH00<0onIH0?oVF`3oiEP01P3oiEP00`3oiET0onEK0?oWFP080?oUF0030?oVF@3oiET0onEG00H0
onEH00@0onEG0?oUF`3oiUX0onII1P3oiEP02P3okE/0om1?07e?7P0S5PP0000001XF202fTCL0om9>
0?olG@3omE/70?o`F@030?oaG03ol5T0oo5L00`0oo1I00@0oo1G0?oaG@3ol5`0oo1K0P3ol5P00`3o
lE`0oo1J0?o`E`090?o`F@050?obH03olEh0oo1G0?o`F`3ol5P03`3ol5T01`3ol5L0oo5L0?obHP3o
lEX0oo1K0?o`F@3ol5P0203ol5T20?oaFP040?o_F03okED0onI>0?oRB080on=900T0onA90?oSB@3o
i4T0oma70?oRB@3ohDP0omm80?oRB@3oi4T0103ohdT20?oTBP0B0?oSB@3oi4T0onA90?oOB03ohTT0
omm80?oQB@3oi4X0onA90?oSB@3oiTX0ona;0?oZBP3nfTD0^iPa081W801<?A<07QT80`0000002@0W
5`P0W5/P0>B5;`3oVcT0ok]50?oGC@3odd`0ola:0?o8B0080?o6A`040?o8B03oaTL0olI70?o7B080
olI700<0olQ80?o6A`3oaTL00`3oaTL30?o5A`040?o5AP3o`DD0olI70?o;B080olI700@0olE70?o6
A`3oadP0olY9103oaTL0103ob4P0olI70?o6A`3obTT;0?o6A`040?o8B03oaTH0ol940?o2A@80olA7
00<0olE70?o4A`3oa4L00P3oa4L0103oaTL0oli:0?o:K@3olnGo0?ooolD0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool>0?ooo`070?oXhP2VKDh0aVl]
0?n_C@3o^540okE>0?nfC`0=0?nfD0050?neD03o]Tl0okI@0?nfD03o]Tl08@3o]U000`3o]Dl0okI@
0?nfD0020?neCP030?nfC`3o]Dh0okE>0080okE>00@0okI@0?neCP3o]Dh0okI@2P3o]Dh01@3o]U00
ok5<0?nWA`3o[d/0okY@00@0okU?00L0ok]?0?niC`3o^E00ok]>0?nhC`3o^E00okY?00/0okU?00D0
okYC0?njEP3o^eP0ok]J0?nkG0030?nkF`080?nlG03o_F00ok]K0?nnG`3o_5h0okaM0?nmH03o_5/<
0?nkF`0:0?nlG@3o_Eh0ok]J0?nkF`3o_Ed0okaM0?nnH`3o^eT0okeN0?nkFP/0ok]K00P0ok]J0?nk
F`3o_5h0okeM0?nnGP3o^e/0okeN0?nlG0X0ok]K00H0ok]J0?nlG@3o_Eh0okaL0?nmG@3o_5`90?nk
F`80okeM0P3o_5`00`3o_5d0ok]K0?nkF`020?nkF`0<0?nmG03o`f00ojmF0=2>AP1iA2805@/501P>
1P1H<aH0]H0h0?o1E03ode`0om5K0`3ocET01@3ocEP0oliJ0?o>G03ocUX0oliK00L0oleI0`3ocU/6
0?o=F@030?o=FP3ocUd0oliK0080oleI0P3ocUX01P3oae<0ok]60?o6E03oceh0oleJ0?o>FP@0oleI
00@0oliK0?o=F@3ocUd0oliJ1P3ocET00`3ocU/0oliJ0?o=F@020?o=F@030?o=FP3ocU`0oliL00<0
oleI0`3ocU/0103ocUX0olaG0?o>G@3ocUX20?o=F@030?o<F03ocEX0oleI0080oleI00D0olAF05Xd
5`000000GCXG0?oKE0030?oUF0030?oVFP3oiUT0onEH00<0onEH00<0onEI0?oWG03oiET00`3oiEP0
203oiET0onMO0?oUF03oiEP0onIK0?oVF@3oiEL0onIG1@3oiEP00`3oj6H0onEI0?oUF0030?oUF003
0?oUE@3oiEP0onEH00<0onEH00<0onII0?oUF@3oiEP00`3oiEP00`3oiel0onIL0?oUF0030?oUF003
0?oVFP3oiU/0onEH00<0onEH00<0onII0?oVFP3oiEP00`3oiEP00`3oiET0onEJ0?oVF@040?oUF003
0?oUF@3oiUX0onEH00@0onEH00<0onIJ0?oVF@3oiEP0103oiEP00`3oiUT0onIJ0?oUF0040?oUF003
0?oVFP3oiU/0onII00D0onEH00<0onIJ0?oVF`3oiUP01@3oiEP00`3oiU/0onIJ0?oUF0050?oUF004
0?oUFP3oiU/0onEG0?oUF@H0onEH0`3oiUX60?oUF0040?oVF@3oiEX0onEI0?oVFPP0onEH00@0onII
0?oUFP3oiEP0onIJ103oiEP0303ojEX0onaJ0?oBD035Xch0KdTL00d80`0O6@T0ETDJ0;NR?03ojEH0
ooQL0?ocFPD0oo1I00H0oo1H0?oaF`3ol5T0oo5J0?oaF`3olET:0?o`F@030?oaF`3olEX0oo5K0080
oo5K00<0oo5J0?oaF@3olET02P3ol5T01P3olET0oo5J0?oaG03olE`0oo1H0?oaFPl0oo1I00l0oo5J
0?oaF`3ol5T0oo5M0?oaF`3olE`0oo1J0?o`F03ol5T0oo5J0?o`F03okeH0on]C0?oVC@3oiD/01@3o
hdT00`3oi4X0on=90?oSB@020?oTB@0@0?oRB@3oh4P0onA90?oPB03oi4T0onA:0?oPB03ohdT0on9:
0?oTBP3ohdP0on590?oTBP3oh4T0on990?oTB@@0on=901T0onA90?oRB@3ogDH0on580?oYB`3okD`0
onY;0>_?@P33/ST0[YPb08md9@1GAQL0<RT=01PC1P070`80?B<=06Pl5P24C1/0Y6`W0<fF=P3i[d00
okm50?o<BP3ocDX0olU800D0olI700<0olQ80?o6A`3oaTL00P3oaTL00`3oadP0olI70?o6A`070?o6
A`0;0?o7B03oaTP0olA70?o5A`3obDT0olM80?o4AP3obTT0olI70?o4AP3oadP01@3oaTL0103oadP0
olI70?o7B03oadP80?o6A`030?o6B03o`dD0ol=40080olE71@3oa4L00`3oce40onFS0?oil@3o0?oo
olH0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool?
0?ooo`050?o[iP2@DBh0XE4N0?nXB@3o]dl01`3o]U000`3o]Dl0okI@0?nfD00V0?nfD0030?neD03o
]4h0okA>00<0okI@2`3o]Dh00`3o]U00okE>0?neCP070?neCP060?neC`3o]Dh0ojm:0?nWB03o[d/0
okY@103o^Dl00`3o^dl0okU?0?niC`0B0?niC`090?nhD03o^U@0ok]H0?nnH`3o`FD0ok]J0?nnHP3o
_5`0ok]J00l0ok]K00H0ok]J0?nkF`3o_V<0okeN0?nmFP3o_El20?nkFP`0ok]K00L0ok]J0?nkF`3o
_fD0okaK0?nnGP3o_5/0ok]J00/0ok]K00@0okeM0?nmH@3o^eX0okaN2P3o^e/0103o_5X0okiR0?nm
G@3o_Ed70?nkF`0:0?o0G@3o/eP0TTdV03DL3P00000050/50;UZ;P3oZTX0omAM0?oCG0@0oleI00D0
olaH0?o>G@3ocU`0oleK0?o<F0070?o=F@030?o?H@3ocEL0oliM00H0oleI00@0olaH0?o=G03ocU/0
olaH0`3ocET01@3ocUX0olQD0?nlA`3o`4`0olmN00H0oleI00<0oliK0?o=F@3ocEX01P3ocET00`3o
cUX0oleJ0?o=F@040?o=F@0:0?o>G03ocET0olaH0?o=E`3ocel0olaH0?o=G03ocUd0oliK0?o<F0@0
oleI00<0oleJ0?o>GP3ocET00P3ocET01P3ocUX0ZWXe0000000n:100om5?0?o[FP<0onEH00<0onIH
0?oUF03oiEP00`3oiEP00`3oiEL0onEK0?oUF0030?oUF0030?oVF03oiEH0onEH0080onEH00<0onEI
0?oUEP3oied01@3oiEP00`3oiET0onEH0?oUF0020?oUF0030?oUE`3oj600onII00<0onEH00@0onEG
0?oWIP3oiUl0onEG0`3oiEP00`3oiEH0onEG0?oUF0030?oUF0030?oUG03oiUd0onEH00@0onEH00<0
onML0?oUE`3oiEP00`3oiEP00`3oiET0onEK0?oUF0030?oUF0030?oUF@3oiUT0onEF00H0onEH00<0
onEG0?oUF03oiEP00`3oiEP00`3oieX0onEI0?oUF0030?oUF0030?oUE`3oiEP0onAJ00D0onEH00@0
onEG0?oUF03oie`0onEI103oiEP00`3oiEL0onEI0?oUF@070?oUF0030?oUE`3oiUX0onEG00L0onEH
00<0onIM0?oUF03oiEH01P3oiEP0103oiEL0onIK0?oVF`3oiEL70?oUF0040?oTE`3oiET0onML0?oV
F`H0onEH00X0onMI0?o]F`3o/D@0WfDV00h80`000000?C0A09Mg;03oge80ooQL203ol5T00`3ol5/0
oo1J0?oaG00<0?o`F@060?o`FP3ol5`0oo1G0?oaHP3ol5P0oo5J303ol5T01@3ol5P0oo1I0?o`FP3o
lEh0oo5P0100oo1I00X0oo1H0?o`F@3ol5d0oo1I0?oaG03olE/0onQ?0?oWC03ohdT0on=81`3ohdT0
0`3oi4X0on=90?oSB@050?oSB@090?oTB@3ohdT0on990?oEAP3ohdT0omM60?oPB@3oiDX0onA900T0
on=900<0on580?oMAP3ogdL00P3ohdT02`3oi4T0on=90?oSB@3oiTX0one<0?ocCP3ofTH0kL0m0<jV
=@24Jb<09al:00<0000000P06Ph504@X3P1]?QL0d7T/0?ni@`3oeD`0om1<0?o:B@L0olI700<0olQ8
0?o6A`3oaTL00`3oaTL00`3ob4P0olI70?o6A`040?o6A`0A0?o7B@3oaTL0olI70?o7B03obdP0olM8
0?o4AP3ob4L0olI70?o2A03oa4H0olI80?o5A`3ob4L0olI70?o8B03oadT0203oaTL00`3obTP0olA4
0?o2A0060?o4A`030?o<A`3oi[00oooo0?l0ooooa`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`00
1`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooa00oooo00@0omO>09IB<02WER80ok9>0`3o]U000`3o
]Dl0okI@0?nfD00W0?nfD0040?neD03o]Dh0okI@0?neD0D0okI@2`3o]Dh00`3o]U00okE>0?neCP09
0?neCP040?n]BP3oZ4P0ok5:0?nkCaL0okU?00T0okU@0?niC`3o^4l0okY>0?nhD03o^UD0okaK0?nk
F`3o^eX0403o^e/01`3o^eX0okiR0?nlG@3o_Ed0okaL0?nkFP3o_5h03@3o^e/01P3o^eX0okeR0?nl
GP3o_F00ok]K0?nkFP/0ok]K00D0okYI0?nnH@3o^UT0okeM0?nkG00:0?nkF`040?njF03o_V40okaL
0?nlG0H0ok]K00@0okaL0?o0G@3oXe00FS0G0P0000001@0R4`P0ghdn0?o=F@3oeUh0oliJ00D0oleI
00<0oliL0?o<F03ocEX0203ocET00`3ocUX0oliL0?o=F@060?o=F@040?o=FP3ocU`0oleG0?o=FP<0
oleI00D0oliJ0?o;E`3o`D`0okA20?o4D@060?o=F@030?o<F03ocU`0olaH00H0oleI00<0oliJ0?o=
FP3ocET0103ocET01P3ocEX0oliK0?o=FP3od680oleJ0?o>G080oleI00<0oliJ0?o=F@3ocET00`3o
cET00`3ocEX0olmN0?o=FP030?o=F@050?o>FP1M=AL06@l50>ZE>@3omEd00`3oiEP00`3oiET0onIK
0?oUF0030?oUF0030?oUF@3oiel0onEF00@0onEH00<0onMN0?oUF03oiEP0103oiEP00`3oiUh0onIJ
0?oUF0030?oUF0030?oUE03oiEP0onEH0080onEH00<0onEF0?oWI`3oiUX00`3oiEP0103oiEL0onQU
0?oVGP3oiEL40?oUF0030?oUE`3oiEP0onEH00<0onEH00<0onEF0?oUE`3oiEP02`3oiEP00`3oiUT0
onEH0?oUF0020?oUF0030?oUF@3oiE/0onEG00@0onEH00<0onIJ0?oWG03oiEL0103oiEP00`3oiET0
onIL0?oUE`050?oUF0030?oUE`3oiUT0onEH00H0onEH00<0onIK0?oUF03oiEP01@3oiEP00`3oiUX0
onEH0?oUF0050?oUF0030?oVF@3oiE/0onEF00L0onEH00<0onEG0?oWG03oiUT01`3oiEP00`3oiUT0
onEI0?oVFP090?oUF0030?oUFP3oiUX0onEH00D0onEH00D0onMI0?oaG03oheL0okY805@f50020000
000402lU3P39Zd00ooIK0?oaF@P0oo1I00<0oo1J0?oaF`3ol5T0303ol5T0103ol5P0oo5L0?oaF`3o
lEX?0?o`F@040?o`F`3olE/0oo5I0?oaGQ40oo1I00H0oo1H0?o]D`3oidd0omi70?oJA`3oiDX80?oS
B@030?oTBP3ohdT0on=900@0on=900/0onE90?oMB03oi4T0on990?oQB03ohdT0on580?oRB@3oiTX0
ome80?oUBP080?oSB@030?oQB03ogDH0omm700L0on=900T0onA90?oWBP3ok4`0oo5=0?oQB03gacl0
gK8j0;2?;@1@@1@00`000000200=1`<0=1l<05hg502YHB<0o:Pm0?o=B`3obTT0olI92P3oaTL00`3o
bTT0olI70?o6A`040?o6A`040?o9B03oaTL0olI70?o7B080olI700<0olE70?o6A`3oaTL00P3oaTH0
1P3obDL0ol=50?o3A@3oaTT0olM80?o7B@P0olI700<0olQ80?o4A03o`T@01@3oa4L00`3ocDP0omVA
0?omn`3o0?ooolP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWK`3oool02@3od=P0bH^@09MXK00o:bd00000038S901UADP0bH^@0?oco01b0?ooo`090>B^]02G
J6`0IDE801TA4P0I4Q80IDE80;1iOP3RW:80ooWn01d0oooo00@0omS=09UE<@3ORCX0okUB:P3o]U00
0`3o]Dl0okI@0?nfD0080?nfD0L0okE>00D0okI@0?neCP3o]Dh0okE>0?neD0090?neCP050?nfC`3o
]4h0ojQ80?nUAP3o/T`02@3o^Dl00`3o^E00okU?0?niC`0;0?niC`030?niD03o^dl0ok]>00D0okU?
00<0okUC0?njF@3o^e/03@3o^e/00`3o_E`0okmT0?nkFP020?nlG0<0ok]K00<0okaN0?nkFP3o^e/0
2@3o^e/01@3o_5/0okiR0?nkF`3o_5/0okaL00/0ok]K00H0ok]L0?nkF`3o_V80okeM0?nlG03o^eX;
0?nkF`040?nnH@3o_640ok]L0?nkFPD0ok]K00/0okeL0?nlF`3oXU00S4XU01P<1P00000081880;a[
;P3o]Tl0om1K0?o>FP060?o=F@030?o>F`3ocET0olaH00L0oleI00<0oleG0?o?H03ocEX0203ocET0
0`3ocf00oleI0?o<F0050?o=F@040?o6DP3o^D@0okI40?o;E`D0oleI00<0olaH0?o>G@3ocE/01P3o
cET00`3ocU`0oleI0?o=F@030?o=F@060?o=FP3ocET0oleJ0?o?G`3oc5P0oleJ0`3ocET00`3ocUX0
oleG0?o=F@040?o=F@030?o<E`3ocET0oleI0080oleI00H0om1L0?nZBP091@80PE8P0?oeG@3oieT3
0?oUF0030?oUEP3oiEP0onEH00<0onEH00<0onEG0?oTE`3oiEP0103oiEP00`3oiEL0onEH0?oUF003
0?oUF0040?oUE`3oiEH0onIK0?oUE`80onEH0P3oiEL40?oUF0030?oUEP3oj6H0onIJ00<0onEH00@0
onEG0?oWH`3oiUd0onEG0`3oiEP00`3oiEL0onIM0?oUE`030?oUF0030?oUE`3oie`0onIK00@0onEH
00<0onII0?oUF`3oiEP0103oiEP00`3oi5X0onEJ0?oUF0040?oUF080onEI1@3oiEP00`3oiEH0onAG
0?oUF0040?oUF0030?oVF@3oiE/0onEH00D0onEH00<0onIH0?oUF@3oiEP01@3oiEP00`3oiU/0onEI
0?oUF0060?oUF0030?oUF@3oiEP0onEH00H0onEH00<0onEF0?oUF@3oiEP01P3oiEP00`3oiET0onIJ
0?oUE`070?oUF0040?oUE`3oiUX0onMN0?oUE`P0onEH00<0onEG0?oUF`3oie`01P3oiEP02`3oj5T0
oneJ0?oDDP2JHBD03`T40000000>30D0VWX^0?oND`3olUX0oo=J00L0oo1I00@0oo1J0?o`F03olV00
oo1F303ol5T01@3ol5X0oo1G0?o`F03olE`0oo1H00l0oo1I00@0oo1J0?oaH03olEh0oo1G303ol5T0
1@3okeL0onM>0?oSB@3oi4T0on=90080on9900<0on=90?oNB03oiTX01P3ohdT20?oTBP80on=900D0
onA90?oRB@3ofDL0on980?oRB@070?oSB@050?oRB@3oi4T0oma80?oJAP3oi4T01@3ohdT00`3ohDP0
ome60?oOA`030?oSB@030?oTB@3ohdT0on=900D0on=900T0onI:0?oYB`3ojT/0onE:0?oHAP3fad00
/Xl^06eG6`0B3@@00`0000001`0G2`D0Ec0C0:iS903oVCL0ol560?o6A`3oaTT00P3obDT50?o6A`03
0?o:B@3oaTL0olI700L0olI700<0olM80?o6A`3oaTL01P3oaTL20?o4A`050?o5A`3oaTP0ol=70?o6
A`3oaTT01@3oaTL20?o8B0030?o4A03o`T@0olA70080olA700@0olA60?o>BP3oh:H0ookoo`3oooo9
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWifh0oooo00<0
;AlP0000000000001P000000100=2@T0F3do08b2Q`3om?I]0?ooo`0304`d=P0=2@T0000000L00000
00<0<b<T08b2Q`3oj>`0703oool01@3ok>L0_GYG0=f:>P3o]e00okUA02@0okI@0P3o]Tl=0?nfD0/0
okE>00<0okE@0?neCP3o]Dh01@3o]Dh01`3o]Tl0okE?0?neC`3o]Dh0oje;0?nWA`3o/Td04`3o^Dl0
0`3o^Tl0ok]?0?niC`020?njC`030?niD03o^Dl0okU?00H0okU?00P0okU@0?njD`3o^eL0ok]J0?nl
FP3o^e/0ok]L0?nkF`80okaL0P3o_5h00`3o^e/0okiP0?nlG0080?nkF`030?nkFP3o_5`0okaO00<0
ok]K0P3o_5`0103o_El0ok]K0?nlG03o_5d;0?nkF`80okaL00@0okaK0?nmG`3o_Eh0ok]J2P3o^e/0
1@3o_5`0ok]K0?nlG@3o_5`0okeM00H0ok]K00`0okmM0?nlG03o[E@0d8M206Ll7P050`406a0705Tc
5P2gQCX0olEF0?o?F`3oceX50?o=F@030?o>G@3ocU/0oleK00P0oleI00<0oliJ0?o>F`3ocU/01P3o
cET0103ocEX0oleH0?o>G@3ocUX70?o=F@040?o8E@3o_4L0oke70?o5DP@0oleI00@0oleJ0?o=F03o
cEP0oleJ1@3ocET02P3ocU`0oliJ0?o=F03ocEX0oleK0?o=F@3oceh0oliJ0?o?H03ocE`60?o=F@03
0?o=FP3ocU/0oleI00@0oleI00<0oliK0?o>FP3ocET00P3ocET01P3oe5`0gie4038L3013:a40omeE
0?oYF@<0onEH00<0onEJ0?oVF`3oiEP0103oiEP00`3oie`0onEH0?oUF0040?oUF0030?oVF`3oiEP0
onEH00<0onEH00P0onIO0?oUF@3oiET0onIK0?oVE`3oiEP0onIM0?oVFP@0onEH00<0onEF0?oXIP3o
iUX00`3oiEP0103oiEL0onQV0?oVGP3oiEL30?oUF0030?oUE`3oj600onEG00@0onEH00<0onMK0?oV
FP3oiEP00`3oiEP00`3oiUT0onEJ0?oUF0040?oUF0030?oUE`3oiUX0onEH00D0onEH00<0onMK0?oV
F@3oiEP0103oiEP00`3oiEX0onII0?oUF0040?oUF0030?oVFP3oiUT0onEH00D0onEH00<0onIH0?oU
F03oiEP01@3oiEP00`3oiUX0onIK0?oUF0060?oUF080onIK1`3oiEP00`3oiET0onIK0?oUF0070?oU
F0040?oUFP3oiU`0onEG0?oUF@L0onEH00<0onIK0?oVFP3oiUT0203oiEP01@3oiET0onIJ0?oVF`3o
iEP0onEI00@0onEH0P3oieT02`3oeU80bJDo06a=7@0F3PH02`T30592602ZU3L0n=]A0?o`F@3omU/0
oo5J00L0oo1I0P3olE/00`3ol5X0oo5J0?o`F@0;0?o`F@050?oaG@3ol5L0oo5P0?o`F03ol5X03P3o
l5T01P3ol5X0oo5K0?oaF`3olE/0oo1H0?oaF`80oo5J00H0oo1I0?o^E`3oje<0onU@0?oVC@3oi4X9
0?oSB@090?oNB03ohDP0on990?oSB@3oi4T0on990?oSB@3ogTP0onA90080on9900<0onA90?oSB@3o
hdT0303ohdT02@3ohdX0omi80?oSB@3ohdT0on190?oTB@3oh4P0ome60?oOA`030?oSB@030?oTBP3o
hdT0on=900D0on=90P3oi4X06P3ohdT0onA90?oUBP3oiDX0onA90?oSB@3mg4L0eKTk0;:N<`2AQ2X0
JUDK038X3@0L5PL03``401hB1`1K=A<0P4hL08YO8`38Rc80nZ`o0?nlA03o`4H0olY:0?o<B@3ocDX0
olI81@3oaTL00`3oadP0olQ80?o7B00;0?o6A`060?o8B03oaTL0olI70?o6A`3oadP0olA60P3ob4P0
103oaTL0olA70?o7B03oaTL20?o1A0<0olA700<0om=^0?ohj@3oool0o`3oooo:0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWifh0oooo00P06A8B000000000000
<R<T0:AaM@39Ri00UfQ/04/d=P@0000000<0S75e0?ooo`3oool0J`3oool0200b8b@000000000000b
8b@0OUMJ0<V;T02`NWh0Bc@f100000000`0I4A80om3H0?ooo`0K0?ooo`050?o[j024AbP0^EdR0?nb
C@3o^E006P3o]U001@3o]U40okI@0?nfD03o]Dh0okA>0180okI@303o]Dh00`3o]E00okE>0?neCP09
0?neCP030?n/BP3oYdL0ok==0140okU?00<0ok]?0?niC`3o^Dl04@3o^Dl01`3o^U00okUD0?nlFP3o
^e/0okeP0?nnHP3o^eX03P3o^e/01`3o_5`0okeL0?nmH03o^e`0okeN0?nlGP3o^eX02`3o^e/01`3o
^eX0ok]K0?nlG03o_5d0okiR0?nkF`3o^eX02P3o^e/01@3o^eX0okaL0?nmGP3o_5/0ok]J00H0ok]K
00/0okeL0?o5H@3oYe40XUDZ00P40P0000008A<80;=V;03o^U40omUO0?o>FP040?o=F@050?o<F03o
cEX0oleL0?o>G03oc5P01`3ocET0103oc5P0oleL0?o<F03ocU`80?o=F@030?o>G`3ocET0olaH00L0
oleI00D0oleG0?o1CP3o^TD0ol9>0?o>FP040?o=F@030?o>G@3oc5P0oleI00D0oleI00H0oliK0?o=
F@3ocEX0olmN0?o>G03ocUl20?o<F0030?o>FP3oc5P0oleI00@0oleI00<0olaH0?o>GP3ocEX01@3o
cET00`3oc5P0oleH0?o=F@020?o=F@050?oAG03o[Dd0:aP;0000002eV3X01@3oiEP00`3oiUX0onEH
0?oUF0030?oUF0030?oWF`3oiEL0onEH00@0onEH00<0onEF0?oVF03oiEP00`3oiEP00`3oiEL0onIQ
0?oUF@020?oUF0040?oUEP3oiUL0onIP0?oVF`@0onEH00<0onEF0?oXIP3oiUX0103oiEP00`3oiel0
onML0?oUE`040?oUF0030?oVE@3oiEP0onEH00X0onEH00<0onIM0?oWG03oiEL01@3oiEP00`3oiET0
onEH0?oUF0030?oUF0030?oUEP3oiET0onEH00@0onEH00<0onEG0?oUF`3oiEP0103oiEP00`3oiEL0
onML0?oWF`060?oUF0030?oVFP3oiEL0onEH00H0onEH00<0onML0?oUF03oiEP01@3oiEP00`3oieX0
onIJ0?oUF0060?oUF0040?oVF@3oiUX0onAJ0?oUE`H0onEH00@0onEG0?oTE`3oiU/0onEG1`3oiEP0
103oiEL0onML0?oUE`3oiET80?oUF0040?oUEP3oiE/0onIK0?oUF@L0onEH00/0onmK0?o0B@2IHBD0
<b0<0000000;20<0PFPW0>VjA03ome/0oo=J0?o_F@070?o`F@040?o`E`3olUh0oo5K0?o`F0X0oo1I
00P0oo5J0?o`G03ol5L0oo1I0?oaG03ol5X0oo1L0?o`E`l0oo1I00D0oo5G0?obG`3ok5H0onMB0?oY
CP0>0?oSB@090?oTB@3ohdT0on180?oVB@3oi4T0ome70?oSB@3ohDP0on=90080onA9203ohdT20?oT
BP80on=900<0onA:0?oSB@3ohdT0103ohdT01`3oi4T0on=80?oJAP3ogDD0oma60?oPB03ohdT00P3o
i4T70?oSB@80onA:0`3ohdT20?oTB@030?oTBP3ohdT0on=90080on=900L0on];0?ofC`3ojD`0gk<i
08I/8`13=a408Q`900<0000000/03PL205lg503:MBX0oihi0?nf@P3ocDX0om9=0?o:BP3oaDL0olI7
0?o7B00H0?o6A`080?o6B@3oaDD0okQ10?o0A03oaDH0olA70?o=J03on^go0?oool`0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWKP3oool00`1<=3H0bH^@0?oQ
jP050?ooo`060>BoaP00000000000000000I4Q80oo?lK03oool00`1UADP0<R<T0>Bf_@050?ooo`03
0?oco039Ri0000000080000000<0<R<T0?oioP3oool06`3oool0103o_;80Se4b0;5H703o^50G0?nf
D0040?neC`3o]U00okE>0?nfDAH0okI@1`3o]Dh01@3o]U00okE>0?nfD03o]Dh0okI@0080okE@2@3o
]Dh0103o/dd0oj]90?nWA`3o]Th80?niC`030?niD03o^Dl0okU?00<0okU?00<0okQ?0?njC`3o^4l0
1P3o^Dl00`3o^E00okU?0?niC`0<0?niC`060?nhC@3o^E<0okYF0?niEP3o_5T0okaL303o^e/20?nk
FP050?nkF`3o_El0okmU0?nmGP3o^UT0303o^e/01P3o^eX0okeP0?nlG@3o_5`0okaM0?nkFP/0ok]K
00@0okeM0?nlG@3o_5`0okaL1P3o^e/01@3o_5/0olEO0?o1GP3oS4@0DbdF0080000000@0BRXB0=nB
@03og600om9L1P3ocET20?o>G0030?o?GP3ocEP0oleI00H0oleI00@0oliJ0?o>G03ocUd0oleG1`3o
cET0103ocEX0oliJ0?o=G03oc5P60?o=F@070?o>G@3ocUX0olaF0?nlB03o_TX0ol]G0?o>FP020?o=
F@030?o<F03ocUl0oleJ00D0oleI0P3oc5P0103od600oleG0?o>G@3ocf020?o<F0040?o=F@3ocEX0
oleI0?o<F0@0oleI00<0olaH0?o>G03ocU`01@3ocET00`3oc5P0oliJ0?o=F@030?o=F@050?oBG01f
@a`00000018;103of5<0103oiEP00`3oiE/0onEH0?oUF0040?oUF0030?oVF@3oiET0onEH00<0onEH
00<0onEG0?oVG@3oiEP0103oiEP00`3oiEH0onED0?oUF0030?oUF0030?oUE`3oiel0onEI00@0onEH
00<0onEG0?oWI03oiUX0103oiEP00`3oiE@0onEF0?oUF0040?oUF080onEG103oiEP00`3oiEL0onQS
0?oVF`040?oUF0030?oVF03oiEH0onEG00@0onEH00<0onIJ0?oUF03oiEH01@3oiEP00`3oiET0onEG
0?oUF0050?oUF0030?oUFP3oiEP0onEH00<0onEH00<0onEG0?oUF`3oiEX01P3oiEP00`3oiET0onII
0?oUF0060?oUF0030?oVF`3oiEL0onEH00D0onEH00<0onIH0?oUF03oiEP01P3oiEP00`3oiEL0onEK
0?oWG0070?oUF0030?oUE`3oiUX0onEF00P0onEH00@0onEG0?oUEP3oiU/0onEF2@3oiEP0103oiUP0
onEK0?oVF@3oiEL60?oUF0040?o`F`3omUd0oki806e56P80000000D04@d50:n;<`3omU/0oomO0?oa
F@070?o`F@050?o`F03olE/0oo1G0?oaG03olEX02@3ol5T02@3olE`0oo5M0?o`F03ol5P0oo5L0?oa
G@3olET0oo5K0?o`F00;0?o`F@080?oaFP3olET0oniF0?oYC`3ohD/0omi80?oSB03oh4T20?oTB@@0
on=900<0onA:0?oSB@3ohdT00P3ohdT03@3oi4X0on580?oOB03oi4T0omi80?oUBP3ohdT0onA90?oS
B@3ogTP0onA:0?oPB03ohTT00P3oi4T60?oSB@80onA:2`3ohdT02@3ohdP0omm60?oIAP3ogdP0onE9
0?oPB03ohTT0on=90?oTB@050?oSB@80onA:00<0on=90?oTB@3ohdT02@3ohdT0203oiTX0ona<0?og
C`3og4L0gK0i0:V9:`1SD1T08AT70`0000002`0O40H0GSPC09mN8@3[Rc80oka30?oGC@3oeTh0ola:
0?o6A`3obDP0olM900`0olI700<0olQ80?o6A`3oaTL00P3oaTL20?o8B0@0olI700D0ol=50?o4A03o
cDd0olic0?odhP3o0?ooold0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWKP3oool00`3ogn<0oooo0?ooo`060?ooo`050>:LXP000000000000000039Ri00K03o
ool00`3o_lH0oooo0?ooo`070?ooo`05075>D@00000000000000003TaLP07@3oool0103oem<0Xf57
0=J2<`3o^U4B0?nfD0050?neCP3o]4h0okI@0?nfD03o]Dl06@3o]U060?neCP040?nfD03o]4h0okA>
0?nfD0/0okE>00H0okE@0?neCP3o/dd0oj]90?nWA`3o]Th:0?niC`030?njD03o^E00okU?01H0okU?
00<0okY?0?nhC`3o^U00103o^Dl0103o^U80okYG0?nkF`3o_5`90?nkF`070?nkFP3o_F40okeP0?nk
F`3o_El0ok]K0?nmH@0=0?nkF`040?nmG`3o_Eh0okaM0?nkFPX0ok]K0P3o^eX0103o_Ul0okaL0?nm
GP3o^eX70?nkF`090?o5H03oS4@0PdDR01l@1`000000ARPA0<ee=03o]4l0omQN00L0oleI00@0oliJ
0?o>G@3ocET0olaH1`3ocET00`3oc5P0oliN0?o>G0090?o=F@030?o?GP3ocET0oleI00H0oleI00L0
oleH0?o>G@3ocEX0olA@0?nkAP3ob5@0olmL0080oleI00<0oleG0?o>FP3ocUd01@3ocET01@3ocU`0
olmP0?o=E`3ocUd0oleJ0080olaH0P3ocET00`3ocEX0oliJ0?o=F@060?o=F@030?o>G03oc5P0oleI
00<0oleI00@0olaH0?o>G@3ocUd0oleJ0P3ocET01P3oc5T0l:m=018:10000000bh0b0?oYF@<0onEH
00<0onII0?oVF`3oiET0103oiEP00`3oiEL0onIK0?oUF0050?oUF0030?oWH03oiET0onEH00<0onEH
00<0onMJ0?oUF03oiEP0103oiEP00`3oiEL0onEK0?oUF0030?oUF0030?oUE`3oif@0onIJ00@0onEH
00<0onEF0?oUE`3oiEP0103oiEP00`3oiUX0onII0?oUF0040?oUF0030?oTFP3oiUT0onEH00<0onEH
00<0onEG0?oVGP3oiE/01@3oiEP00`3oiUh0onIJ0?oUE`040?oUF0030?oUF@3oiEP0onEH00@0onEH
00<0onEG0?oVFP3oiEP01@3oiEP00`3oiEL0onIJ0?oUF0060?oUF0030?oUF`3oiEL0onEH00D0onEH
00<0onIK0?oVFP3oiEL01P3oiEP00`3oiUL0onEK0?oUF0070?oUF0030?oWG03oiUX0onEH00H0onEH
0P3oiEL00`3oie`0onIH0?oUF0070?oUF0040?oVF@3oiEP0onEK0?oUE`P0onEH0P3oiUT00`3oie`0
onEF0?oUF0050?oUF00;0?oVF03oled0omQB0;Ab:`18;A80000000d:101`FB40h;910?okG@3ome`0
2@3ol5T0103olE`0oo5J0?oaF`3ol5P80?o`F@0:0?oaG@3olEX0oo1I0?o`F@3ol5P0oo5K0?oaFP3o
lF80oo1G0?o`F0L0oo1I00`0oo5J0?o`F@3ojU80onM>0?oUB`3ohTP0on=90?oTB@3ohDP0on590?oQ
B03ogTP20?oTB@0<0?oSB@3oi4X0onA:0?oSB@3oi4T0on=90?oPB03ohDT0on980?oOB03ohdT0onA9
103ohdT0203oi4T0on=90?oPB03ohTT0oma70?oOB03oiDX0onA9103ohdT20?oTBP/0on=900/0on99
0?oNAP3ogTL0on990?oTB@3oh4P0on990?oQB@3og4L0on980?oTB@040?oSB@030?oTB@3ohdT0onA9
00@0on=900<0onA90?oSB@3ohdT00`3ohdT02`3oi4X0on=90?oSB@3oidX0onm<0?ofC`3oi4T0g;4i
0;ZG<02CMRH0@S@A00<0000000/050`405/e4`2<Da`0bW@Z0?n_?`3ofDh0om=<0?o=B`3oadL0olI7
0?o:B@090?o6A`030?o7B03oaTL0olI70080olI700<0olQ80?o6A`3oaTL00`3oaTL0103oa4D0ol94
0?nhK03ooNgo0?ooolh0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWN03oool0103;W:8000000000000V6Q]f0?ooo`050>G>d@00000000000000002CSHd07P3o
ool01@3on_/0bHY^0=j8?03o/dd0okM@00/0okI@00@0okE?0?nfD03o]Tl0okI?7`3o]U001P3o]Dh0
okI?0?neCP3o]Dh0okI?0?neCa00okE>00D0okM?0?ndC`3oZdT0ojM70?nfCP050?niC`040?njC`3o
^Dl0okU@0?nkC`80okU?00<0okU@0?niC`3o^Dl0203o^Dl00`3o^E00okU?0?niC`060?niC`030?nj
C`3o^Dl0okY?00T0okU?00D0okU@0?njD@3o^E80okUE0?nkF0040?nkF`060?nlGP3o_Eh0okaL0?nm
GP3o_5d0okaL0`3o^e/00`3o_5`0okaM0?nlG@070?nkF`050?nmGP3o^e/0okeN0?nkF`3o_5`02`3o
^e/20?nlG0030?nlGP3o_Ed0okaL00H0ok]K00X0okaK0?nmG03oZU<0]Glo06Dh6`0B2@D07A4706lo
7036Rcd0olEG0P3odU`50?o=F@040?o>G03ocEX0oliK0?o=FPP0oleI00@0olaH0?o>G03ocET0oleJ
1`3ocET0103ocU/0oliL0?o<F03ocE/60?o=F@080?o=F`3ocUd0oliJ0?o=FP3oaE40oka70?o2C@3o
cUX20?o=F@0;0?o>F`3ocEP0oleJ0?o=F@3ocUX0oliN0?o=F@3ocU/0oliM0?o>F`3oceh01P3ocET0
0`3ocUX0oliI0?o=F@050?o=F@030?o=F`3ocUX0oleI00H0oleI00/0oleJ0?o=F@3ocET0oleI0?o?
FP3odU`0MT/R00P50P2bNRl0onEH0?oVF@030?oUF0030?oUFP3oiEP0onEH00@0onEH00<0onEI0?oU
F03oiEP0103oiEP00`3oiE/0onII0?oUF0040?oUF0030?oWHP3oiUX0onEH00@0onEH00T0onEG0?oU
F@3oiET0onEI0?oVF@3oiEP0onEF0?oXIP3oiUX01@3oiEP00`3oiEL0onEH0?oUF0030?oUF0030?oV
GP3oied0onEG00@0onEH00<0onEG0?oVFP3oiEP0103oiEP00`3oiET0onII0?oUF0040?oUF0030?oU
F@3oiU/0onEI00@0onEH00<0onEI0?oVFP3oiEP01@3oiEP00`3oiET0onIJ0?oUF0050?oUF0030?oU
F@3oiUX0onEH00D0onEH00<0onEI0?oVF`3oiET01@3oiEP0103oiET0onII0?oVF@3oiEL70?oUF003
0?oVF`3oiUT0onEH00H0onEH00<0onEI0?oVF`3oiUT01`3oiEP00`3oiET0onEJ0?oVFP080?oUF004
0?oUF@3oiUX0onII0?oVFPT0onEH00@0onII0?oUF03oiUX0onIJ1P3oiEP03@3ojEX0onQJ0?oKE03_
_4T0S6@W01hC1`0=2`@0<bT?09J3<03cee00oo9J0?oaFP3olET0203ol5T00`3olE`0oo5J0?oaG007
0?o`F@030?o`FP3olET0oo5J00<0oo1I00D0oo5K0?o`F@3olEd0oo5K0?oaG0020?o`F@050?o_F03o
k5@0onYB0?oWCP3oiD/01`3ohdT03@3oi4T0on990?oRB@3oi4T0on990?oSB@3ohTX0on590?oSB@3o
gDP0onE:0?oRB@3ohdT00P3oi4T80?oSB@0<0?oTBP3oi4T0on990?oSB@3oi4T0on190?oSB@3ogdP0
on=90?oTB@3ohdT0onA:2`3ohdT0103oi4T0on180?oMAP3ohTP20?oSB@090?oTB@3oi4X0on990?oT
B@3oh4T0onA:0?oUBP3oh4T0onA:00L0on=900<0onA90?oSB@3ohdT02@3ohdT04`3oiDX0onY;0?o]
C03ojD/0n]Y60>K;@P3<[cP0[Hl_07]S801>?Q@0:b<<00L50P0N4PH0?b@=06Tl5P2@FB00Zh0_0>FP
>P3o^D@00P3ob4P00`3oaTP0olM80?o6A`040?o6A`050?o8B03obDP0olU90?o6A`3oadP0103oaTL2
0?o5AP030?nf@01]A1/0YVm_0?l0ooooc`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0
103YjNT0dM7A0=7Ad@3WinMi0?ooo`0401TA4P00000000000?noaWH0oooo00@06A4B000000000000
P61S7`3oool01@3ooOl0fXEX0;eU;`3oZTP0okQA00H0okI@00<0okE>0?nfC`3o]U008P3o]U000`3o
]Tl0okE>0?neCP0E0?neCP050?ngC`3o]4l0oj]90?nWA`3o]Th00P3o^Dl00`3o^4l0oka?0?nhC`06
0?niC`030?niD03o^Dl0okU?00h0okU?00<0okY?0?nkCP3o^Dl04@3o^Dl01P3o^E00okUB0?niEP3o
_Uh0ok]K0?nlG0T0ok]K00T0ok]L0?nmGP3o^UT0ok]K0?nlG03o^eX0okiN0?nnHP3o_5/03@3o^e/0
0`3o^eX0okaL0?nmGP080?nkF`0;0?nmG03o_e`0okQI0;IW<`0>1P<0000001`@1`3KOCH0okmD0?o?
F@3oce/01P3ocET0103oc5P0oliN0?o<F03ocEX90?o=F@030?o>G03oc5P0oleI00P0oleI00<0oliJ
0?o=F03ocET01`3ocET04@3oc5L0oliJ0?o=F@3ocUX0olIB0?nlA`3o^dH0olYF0?o=F@3oc5P0oliM
0?o=F`3ocET0oleG0?o@IP3ocE/0oleJ0080oleI00<0oliI0?o=F@3ocET01@3ocET00`3ocEP0olaG
0?o=F@050?o=F@030?o=FP3ocUd0oleI00D0oleI00<0oleJ0?o>G03ocET00`3ocET01P3oeEd0lHXl
00<20@2mMbl0onMI0?oXF@<0onEH00<0onEG0?oVFP3oiEP0103oiEP00`3oiEL0onIM0?oVF@040?oU
F0030?oUE`3oiE/0onEI00D0onEH00<0onEG0?oUF03oiEP00`3oiEP00`3oiEL0onML0?oUF0020?oU
F0050?oVF`3oiEL0onEF0?oXIP3oiUX01@3oiEP00`3oiEH0onEG0?oUF0030?oUF0030?oUE`3oiEP0
onEH00@0onEH00<0onEG0?oWGP3oiEP0103oiEP00`3oiEL0onMN0?oUF@050?oUF0030?oTE`3oiEP0
onEH00D0onEH00<0onMO0?oUF03oiEP01@3oiEP00`3oiET0onEH0?oUF0040?oUF0030?oVF`3oied0
onEG00D0onEH00<0onEG0?oUF`3oiE/01`3oiEP00`3oiUX0onEH0?oUF0060?oUF0030?oUFP3oiEH0
onEH00L0onEH00<0onEI0?oUF`3oiET01`3oiEP00`3oiET0onEK0?oUF@0:0?oUF0030?oWG`3oiEP0
onEH00T0onEH00<0onIJ0?oWG03oiEP01`3oiEP02`3oiUP0onYJ0?oIDP3ZUCT0=R8>0040000<2@<0
GDTK0>VjA03ol5T0oo=J00T0oo1I00@0oo1J0?oaF`3olEX0oo1H1P3ol5T00`3ol5P0oo5J0?o`F@05
0?o`F@040?o_E`3ok5<0on9>0?oTBPd0on=900T0on990?oSB@3ogDL0on=90?oTBP3ohTT0omm90?oS
B@3ohTT04`3ohdT01P3ohTT0onA90?oMB03oi4T0onA:0?oRB@X0on=900@0onA90?oPB03ogDH0on98
1`3ohdT01`3oi4T0on=90?oRB@3ohdT0omU60?oPB@3oiTX0103ohdT00`3oi4T0on=90?oSB@0>0?oS
B@0J0?oTB@3oiDT0onI:0?oYB`3ohTT0om]60?oEA@2iU300CShC014=10050P4000000080000>1P<0
:1P809=D7P3oXcX0ol160?o3A@3obDP0ol]90?o9B@3ob4P0olM80?o6A`3ob4P50?o6A`060?o7A`3o
bdH0ni4a02hK2`2MRi40oogoo`3oooo?0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWigT0oooo00@0IDE8000000000000oko6MP3oool0101UADP0000000000020
H6<Q0?ooo`030?nUSP30IS80ok1;00<0okI@00<0okE?0?nfD03o]U00903o]U000`3o]4h0okI@0?nf
D00D0?neCP080?neD03o]Dh0okI?0?ndC`3oZTT0ojI60?nfCP3o^dl:0?niC`050?niD03o^Dl0okU?
0?niC`3o^E002@3o^Dl00`3o^4l0okU?0?njC`080?niC`030?niD03o^Dl0okU?00T0okU?0P3o^Th0
1@3o^Dl0okUA0?njE`3o_5T0ok]J00T0ok]K00<0ok]J0?njFP3o_Ed00P3o_Eh00`3o_5T0ok]K0?nk
F`0;0?nkF`040?nlG03o_Ed0okiN0?nkFPP0ok]K00X0ol1N0?ndF03oTTP0MChN000000081@80?2<?
0>ZPAP3odEX0oliJ1P3ocET0103ocEX0oleI0?o>G@3ocEP80?o=F@040?o<F03ocEX0oliM0?o>F`T0
oleI00<0oliN0?o=G03ocET01`3ocET02P3ocU`0oleG0?o=F@3ocET0olaH0?nnBP3o^TD0okm;0?o=
F@3oc5P20?o>G@030?o?G`3ocUd0olaH00@0oleI00<0olaF0?o>FP3ocET01P3ocET00`3ocEX0oleI
0?o=F@050?o=F@030?o>G03oc5P0oleI00D0oleI00<0oliM0?o<F03ocET00P3ocET01P3odU`0okQ?
05Ha5@0a7``0om5?0?o]F`<0onEH00<0onEG0?oVG@3oiUX01@3oiEP00`3oiUX0onEI0?oUF0040?oU
F0030?oTE`3oiEL0onEH00@0onEH00<0onII0?oUF@3oiEP0103oiEP00`3oiEH0onMR0?oUE`020?oU
F0050?oVF@3oie`0onEF0?oXIP3oiUX01@3oiEP00`3oi5L0onEG0?oUF0040?oUF0030?oUEP3oiEP0
onEH00@0onEH00<0onEG0?oUF03oiEP0103oiEP00`3oiEH0onEH0?oUF0050?oUF0030?oWH03oiEP0
onEH00@0onEH00<0onEF0?oUF03oiEP01@3oiEP00`3oiE/0onEH0?oUF0050?oUF0030?oUF@3oie`0
onEI00D0onEH00<0onEG0?oWG03oiUT01`3oiEP00`3oiUT0onEG0?oUF0060?oUF080onIJ203oiEP0
0`3oiEH0onML0?oUF0080?oUF0030?oVF@3oie`0onEH00T0onEH00<0onEI0?oVFP3oiET02P3oiEP0
0`3oiET0onIJ0?oUF0060?oUF0060?oVF03oieT0onYI0?oRE`2?Fb<02@D20P000000102VQ300onUG
0?ogG03omE/:0?o`F@040?oaG03olE/0oo1J0?o`F0<0oo1I00P0oo1H0?oaF03ol5/0oo1J0?o`F@3o
keP0onmG0?oYD0<0on=900D0on180?oQB03ohTT0on990?oTBP060?oSB@050?oRB@3ohdT0on170?oL
A`3oiDX00P3ohdT01`3oi4X0on=90?oSB@3ogTL0ome70?oUBP3ohTT02`3ohdT00`3oi4X0on=90?oS
B@060?oSB@070?oVBP3oh4X0om]70?oSB@3ohTT0on=90?oTBP070?oSB@030?oQB03ogDH0on9800@0
on=900<0onA90?oSB@3oi4T01P3ohdT01P3oiTX0ome70?oUBP3ohTT0on580?oTBPl0on=900D0onA9
0?oSB@3ohdT0onA:0?oSB@020?oTB@80onE:00L0onA:0?oLA`3DZSL0K5HK01lH1`0@30@00P000080
000000T05@X407105`3RS380ok910?nlA03ob4L0olm;0?o<BP3obDT0103oaTL01P3oadP0olI60>f6
;@0_6`h0KdM>0?ojo_l0ooood03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinM`0?ooo`030?oco039Ri00<b<T0080000000D0OUMJ0?7>d@3oool0oooo06E5B002
000000030?noaP3oool0oooo0240oooo00<0on7Z0<V;T00c8b@00P000000100I4A80RemS0?b]]03o
lo`90?ooo`090>Bf_@1UADP000000000000=2@T0IDE80;1iOP3l[K@0ooWn02l0oooo00<0ooWn0<V;
T01UADP00P0000001@1nEeX0hYbR0?ooo`3oool0IDE80080000000<0P61S0?ooo`3oool0803oool0
0`3o/9T0iXU00?nlD`0V0?nfD0030?neCP3o]U00okI@00<0okI@5P3o]Dh01@3o]Tl0okA?0?nXA`3o
X4D0okI>00/0okU?00<0okU@0?niC`3o^Dl02P3o^Dl00`3o^Tl0okY>0?niC`0D0?niC`030?njC`3o
^Dl0okU?0080okU?0P3o^4l01P3o^E80ok]G0?nkFP3o^e/0okaL0?nkG0@0ok]K00D0okeP0?nkF`3o
_640okaK0?nkFP0;0?nkF`050?nkFP3o_5d0okaL0?nmGP3o^eX0203o^e/0103o_ed0olIQ0?nQC`1o
@b420000000402TH2P3BMc@0olUG0?oBG0L0oleI00<0oleK0?o>G@3ocU`02@3ocET00`3ocEX0oleG
0?o>G0090?o=F@030?o=F`3ocU`0oleJ00L0oleI00<0oleJ0?o=F@3ocE`00`3ocET02@3ob5@0ok]6
0?nkAP3ob5@0oleK0?o=F@3od6@0olmN0?o=F0050?o=F@030?o>G03oc5P0oleI00D0oleI0P3oc5P0
0`3ocU/0oleI0?o=F@040?o=F@030?o>G@3ocU`0oleI00H0oleI00X0oleJ0?o=F@3ocET0oleI0?o>
F@3od5X0/6D/00000029F240oo9L103oiEP00`3oi5X0onEH0?oUF0040?oUF0030?oUE`3oie`0onEK
00@0onEH00@0onEG0?oWHP3oiUh0onEG103oiEP20?oVG@030?oUE`3oiEP0onEH0080onEH00<0onEF
0?oWH03oiEL00`3oiEP0103oiE/0onEI0?oXH`3oiUX40?oUF0030?oUE`3oiV<0onMJ00`0onEH00<0
onIK0?oUF@3oiEP01@3oiEP00`3oiU/0onEH0?oUF0040?oUF0030?oVF@3oiEP0onEH00@0onEH00<0
onEI0?oWG`3oiET01@3oiEP00`3oiET0onML0?oUF@050?oUF0030?oUE`3oiET0onII00H0onEH00<0
onEG0?oVF@3oiEP01P3oiEP00`3oiUT0onEH0?oUF@060?oUF080onEG00<0onEK0?oUF@3oiEP01P3o
iEP00`3oiUX0onEI0?oUF@090?oUF0030?oVF`3oiET0onEG00P0onEH00@0onEI0?oVFP3oiET0onEG
2@3oiEP0103oiUX0onEK0?oVFP3oiEL80?oUF0090?oXF@3HRC@0BRlC00T50P000000Ie<N0>6a@@3o
ieH0ooUL00X0oo1I00@0oo1F0?oaG03olE/0oo1H0P3ol5T01P3ol5X0oo5I0?oaG03okUP0onaB0?oW
C@L0on=900<0on180?oOA`3ohdX00P3ohdT01`3oi4T0on990?oPB03oidX0omm80?oNB03oi4T0103o
hdT00`3oi4X0on=90?oSB@030?oSB@050?oOB03ohdT0on980?oSB@3oi4T04@3ohdT0203oi4X0on=9
0?oRB03ogTL0onA90?oPB03ohdT0onA91@3ohdT00`3ohDP0ome60?oRB0040?oSB@030?oTB@3ohdT0
on=900P0on=900D0onA90?oPA`3og4L0onA90?oPB0020?oSB@030?oTB@3ohdT0on=900L0on=90P3o
i4T30?oSB@030?oTBP3ohdT0on=900D0on=900P0onI:0?o_C03of4H0cZDf08a`8`0o<a005a<60081
0080000000l08a<707Q56038MBT0oj<k0?nnA03ocT`0om9<0?o<BP3oaTL0olA70?o8B@3FUC403@P<
0;AhP03om_l0o`3ooooA0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWidT0oooo3@0000001@20P800oooo0?ooo`3oool0P82000<0000000<0omoS0?ooo`3oool0
103oool0103o_lH000000000000000050?ooo`030?odmP2<LGD06A8B00D0000000@06Q8B0:FDV@3o
nOh0IDE80P0000000`3o_lH0oooo0?ooo`020?ooo`040?noaP0000000000000000D0oooo0`000000
0`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000H0oooo00<0d/[=05Pm?`0000002000
00000`2GJ6`0oooo0?ooo`030?ooo`030?oioP2UVY/0F3do00P0000000<0C3@f0?ooo`3oool00`3o
ool3000000030?noaP3oool0oooo00H0oooo00@0oko600000000000000001@3oool3000000030?no
aP3oool0oooo00@0oooo00@0oko600000000000000001P3oool00`3oj>`0Dd940000000500000003
03<S903Bal`0IDE80080000000<0P61S0?ooo`3oool08@3oool01@3cbK/0iXI40?nX@`3o^e80okM@
01X0okI@0P3o]Tl01@3o]U00okIA0?nfC`3o]U00okI?00P0okI@1P3o]Dh00`3o]Tl0okE>0?neCP0:
0?neCP080?neD03o]Dh0okE>0?nfD03o/dh0ojY80?nWA`3o]dh70?niC`050?niD03o^Dl0okU?0?ni
C`3o^E001P3o^Dl00`3o^Tl0okU?0?niD0020?niC`030?njC`3o^Dl0okU?00T0okU?00<0okU@0?ni
C`3o^Dl00P3o^Dl01P3o^Tl0okU?0?niC`3o^Tl0okU?0?njC`D0okU?00<0okU@0?nhC`3o^4l00P3o
^4l03P3o^E00okUA0?niDP3o^eH0ok]J0?nlFP3o_5`0okaN0?nmH03o^eX0ok]K0?nlG03o^e/0okaM
203o^e/01@3o_5`0okeM0?nmG`3o_5`0okeM00L0ok]K00`0okaL0?o0G@3hY500_Wdm07i38@0Q4PT0
<A`<06`n6`2[NSD0m;]A0?oDG@3ocUX50?o=F@040?o=F`3ocUT0oliL0?o>F`X0oleI0`3ocU/80?o=
F@030?o=F`3ocEX0oliL00P0oleI00<0oliN0?o>F`3ocEX00`3ocET01`3ocEX0ol1<0?niA`3oaeD0
oleK0?o>G03ocEP01P3ocET20?o>F`030?o=F03ocET0oleI00@0oleI00<0oleH0?o=F@3ocUX01`3o
cET00`3ocU/0oleI0?o=F@040?o=F@030?o>F`3ocUd0oleJ00<0oleI00H0olaI0:UX;@0:1P807Q<8
0>O5B`3oieT30?oUF0030?oVF@3oiUX0onII00D0onEH00<0onEK0?oVF`3oiEL0103oiEP00`3oiET0
onII0?oVF@050?oUF0030?oVF03oiUT0onEH00D0onEH00<0onIL0?oUF03oiEP00`3oiEP00`3oiUT0
onEH0?oUFP040?oUF0030?oUE`3oifH0onIK00D0onEH00<0onMV0?oUF`3oiEP0103oiEP00`3oie/0
onEI0?oUF0050?oUF0030?oVFP3oiEP0onEH00D0onEH00<0onIJ0?oUF03oiEP0103oiEP00`3oiET0
onIJ0?oUF0060?oUF0030?oUF@3oiEP0onEH00D0onEH00<0onIJ0?oUF03oiEP01@3oiEP00`3oiUP0
onEJ0?oUF0060?oUF0040?oUFP3oiUP0onII0?oUF@H0onEH00<0onII0?oWF`3oiEP01`3oiEP20?oV
F@030?oVG03oiUT0onEH00H0onEH00@0onEI0?oVF@3oiUX0onIJ2@3oiEP00`3oiEX0onEK0?oVFP09
0?oUF0050?oVF@3oiUX0onEJ0?oVFP3oiET01P3oiEP03@3oiUT0onaJ0?oVF03[`4T0SfTY03DQ3@00
0000=2X?08mi;@3Vd4d0oo5I0?ohG03olEX01`3ol5T02P3olET0oo5L0?o`F03ol5/0oniG0?oZDP3o
j4l0onI<0?oRBP3ohDP70?oSB@<0onA900T0on5:0?oTB@3ohTP0omm80?oQB@3oh4T0onE:0?oSB@3o
i4T01@3ohdT00`3oi4X0on=90?oTBP030?oSB@050?oTB@3ohTT0on990?oUBP3ohDT00P3ohTT20?oT
BPl0on=90`3oi4T00`3ohDP0on=:0?oOB0020?oSB@080?oRB@3oi4T0onA90?oQB03ogDH0on980?oT
BP3oi4T40?oTBP/0on=900T0onA90?oTBP3oh4P0onA90?oSB@3ohDT0onA90?oPB@3ohdT00P3oi4T2
0?oSB@<0onA9103ohdT00`3oi4X0on=90?oSB@060?oSB@80onA:01D0onQ:0?o[B`3oi4X0i/Y10<bj
?02cXcD0S78U05935P0k;a0091d9018;100m8`d0I3TE07e86P2/M2X0eihj0>nX?@2nPRh0NeA;0?;;
d@3onol0o`3ooooB0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWidT0oooo3@0000001@20P800oooo0?ooo`3oool0P82000<0000000<0omoS0?ooo`3oool0103o
ool0103o_lH000000000000000050?ooo`0509V;T000000000000000000V6Q/00`39Ri00100V6Q/0
00000;1iOP1UADP2000000030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool3
000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000001P3oool01@0o;2d000000000
00000000LDiA00<0oko600@0RV1S000000000000IDE81@3oool01P1nEeX00000000000000000<R<T
0;1iOP80oko600@0bH^@04/d=P000000<b<T1@3oool3000000030?noaP3oool0oooo00H0oooo00@0
oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko6000000000000
00001@3oool00`3olo`0<R<T000000020000000704/d=P39Ri00bH^@04/d=P000000F3do06E5B002
00000003081PH`3oool0oooo0280oooo00@0oncb0<UeD@3oRSH0okUA603o]U000`3o]Dh0okI@0?nf
D00>0?nfD0l0okE>00<0okA>0?neCP3o]Dh0103o]Dh01@3o]Tl0ok==0?nYB03oYdL0okM>00/0okU?
00H0okU@0?niC`3o^Dl0okU?0?njC`3o^dl70?niC`030?niD03o^Dl0okU?00`0okU?00<0okY>0?ni
C`3o^Dl02P3o^Dl70?nhC`070?niCP3o^4l0okYB0?niD`3o^UL0ok]K0?nlG0030?nkF`030?nlGP3o
_F40ok]K00@0ok]K00D0okaL0?nmH03o_5`0okaM0?nkFP070?nkF`050?nlF`3oaEl0ol1M0:YK;00>
1P<00P000000102TGRP0okiC0?oJH03odU`70?o=F@040?o>G03oc5P0oleL0?o<F0T0oleI00<0oliO
0?o<F03ocUd0203ocET0103ocUX0oliL0?o>G@3oc5P80?o=F@0<0?o>G@3ocET0olaH0?o<F03ocEX0
olmS0?o=F@3oaE40okU50?o8DP3ocUT0oleL203ocET00`3ocUd0olaH0?o=F@050?o=F@030?o=F03o
cEX0oleI00D0oleI00<0oleH0?o=F@3ocEL01P3ocET00`3ocUX0oleL0?o<F0040?o=F@050=nQA`00
00004@/40>ZE>@3oke`0103oiEP00`3oiEH0onIK0?oUF0040?oUF0030?oVF@3oiE/0onEG00D0onEH
00<0onIJ0?oVG@3oiEL0103oiEP00`3oiEL0onIK0?oUE`050?oUF0030?oTE`3oiEL0onEH00D0onEH
00@0onEF0?oUF03oiE/0onEG0P3oiEP00`3oiEH0onQV0?oVF`050?oUF0030?oUF`3oiET0onEH00D0
onEH00<0onIJ0?oUF03oiEP0103oiEP00`3oiU/0onEH0?oUF0050?oUF0030?oVG03oiEP0onEH00D0
onEH00<0onII0?oUE`3oiEP01@3oiEP00`3oie/0onIJ0?oUF0060?oUF0030?oUF@3oiEP0onEH00D0
onEH00<0onEI0?oVF03oiEH01`3oiEP00`3oiEL0onII0?oUF0060?oUF0030?oUF@3oiUX0onEG00T0
onEH00<0onIJ0?oUEP3oiEP01`3oiEP0103oiEL0onAJ0?oVF03oiEL80?oUF0030?oUE`3oi5X0onIL
00`0onEH00<0onIJ0?oUF`3oiEP0203oiEP02P3olU`0omQB0>nH>P1/@aX0000000`90`1LB1X0b9hk
0?oiG03olET40?o`F@80oo5J00H0onmG0?oYD03oidd0onE;0?oRB03ohTT20?oPB0040?oTB@3ohDP0
on180?oTB@<0on=90P3oi4T0103ogTP0ome80?oUBP3oh4T20?oSB@040?oUB@3ohDT0on180?oOB080
onA9203ohdT00`3oi4X0on=90?oSB@040?oSB@070?oTB@3ohDP0omm80?oSB@3oh4P0onE90?oTB@0B
0?oSB@090?oTB@3ohdT0on990?oQB@3ogdP0ome80?oSB@3ogTH0on=800/0on=900<0onA:0?oSB@3o
hdT0203ohdT01P3oi4T0on990?oNB03ohdX0on990?oMB0<0onA90P3ohdT01@3oi4X0on=90?oSB@3o
hdT0onA:00P0on=900<0onA:0?oSB@3ohdT0103ohdT02@3oi4T0one<0?ofCP3ojT`0ole10<JP=021
Ib40ASPB00T60@020000000300P40P0[7Ql0on;V0?l0ooooe03oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinM90?ooo`<0000000<0<R<T06E5B01UADP01`1UADP0
1@2bXZ@0oooo0?ooo`3oool0P82000<0000000<0omoS0?ooo`3oool0103oool0103o_lH000000000
000000050?ooo`0506E6B000000000000000003TaLP00`3oool0103TaLP000000000000I4A820000
00030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0
oooo00@0oooo00@0oko600000000000000001@3oool01P3l[K@00000000000000000UfQ/0?oioP@0
oooo00<0oko606E5B01UADP0103oool01P3ne]X00000000000000000C3@f0?oco0D0oooo00<0oko6
06E5B03oool0103oool3000000030?noaP3oool0oooo00H0oooo00@0oko600000000000000001@3o
ool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000001@3oool01@39Ri000000
000000000000bH^@00@0oooo00<0bH^@0000000I4A800P0000000`20H6<0oooo0?ooo`0S0?ooo`03
0?oTi`2gK4h0oj1701D0okI@00<0okE>0?ndCP3o]U004@3o]U050?neCP030?nfD03o]Dh0okE>00<0
okE>00<0okI@0?neCP3o]Dh0203o]Dh01@3o]Tl0ok==0?nYB03oYdL0okM>00/0okU?00<0okU@0?nh
C`3o^dh01P3o^Dl00`3o^E00okU?0?niC`0=0?niC`030?nhC`3o^dh0okU?00d0okU?1@3o^4l0103o
^Th0okQ=0?nhC`3o^4l20?nhC@050?niD03o^E80okYD0?njF@3o^e`00P3o^e/02@3o_Ed0okeN0?nk
F`3o^e/0ok]J0?nmGP3o^e/0okaM0?nkFP080?nkF`0:0?noG03o`5h0lX0o05db5`0:1P<0000005`d
5P3dS3d0ol]I0?oDG@L0oleI00@0olaH0?o?GP3ocUd0olaH2P3ocET00`3ocU/0oliM0?o<F0080?o=
F@030?o<F03ocUd0oleJ00P0oleI00`0oleJ0?o?GP3ocET0olaH0?o>G@3od6H0oleI0?o?GP3obUH0
oki:0?nmB@3oc5H90?o=F@030?o>G`3ocET0oleI00D0oleI00<0olaH0?o>F@3ocET01P3ocET00`3o
cU/0oleL0?o=F@050?o=F@030?o=F03ocUd0olaH00@0oleI00H0om1J08eN:@000000N4dN0?o_F`3o
iUT30?oUF0030?oUF@3oied0onEG00D0onEH00<0onIJ0?oWG03oiEP01@3oiEP00`3oiEL0onEI0?oU
F0040?oUF0030?oUE`3oif40onEG00D0onEH00<0onAE0?oUE`3oiEP01@3oiEP02@3oiEH0onEG0?oT
FP3oiE/0onEF0?oUF03oiEH0onMW0?oVF`050?oUF0030?oUE03oiEL0onEH00D0onEH00<0onQT0?oU
F03oiEP01@3oiEP00`3oi5D0onEH0?oUF0040?oUF080onII1P3oiEP00`3oiEX0onIM0?oUE`060?oU
F0030?oUEP3oiEL0onEH00D0onEH00<0onEG0?oTE@3oiEP01P3oiEP00`3oiET0onIH0?oUE`070?oU
F0030?oVF03oiET0onEH00H0onEH00<0onEI0?oUF`3oiUX02@3oiEP20?oUF@X0onEH00<0onMM0?oU
E`3oiEP0203oiEP00`3oiET0onEK0?oUEP0;0?oUF0030?oUF@3oiE/0onII00P0onEH00@0oneJ0?oe
G@3oeU40[fhZ0P0000002`0@30@0SW0Z0?oeFP3onU`0oo5I0?oaFP3okeL0onYA0?oWCP3oiD/0on=9
0080on9800P0on=90?oTB@3ohTT0on=80?oQB03oi4T0on980?oSB080onA900L0onE:0?oMB03ohDT0
on580?oPB03oi4T0onE:00<0on=900D0onA90?oRB@3ohdT0on170?oQB00A0?oSB@050?oTB@3ohTT0
on9:0?oQB@3ogDL02`3ohdT00`3oi4X0on=90?oSB@070?oSB@070?oTB@3ohDP0on180?oVB@3oeT@0
on980?oTB@0:0?oSB@030?oTBP3ohdT0on=900D0on=900<0onA90?oSB@3ohdT00P3ohdT02@3oi4T0
onA:0?oRB@3ohDP0onE90?oNA`3ohTT0on=90?oTB@0=0?oSB@030?oTB@3ohdT0on=900<0on=90P3o
i4T20?oSB@0:0?oUBP3ojT/0oo5=0?oSB@3ocD40iKTl09Ag:00510409AHJ0?oIh_l0ooooe@3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinM90?ooo`<0000000<0
bH^@0?ooo`3oool02`3oool01@20P8000000000000000000omoS00H0oooo00@0oko6000000000000
00001@3oool0100=2@T000000000002`NGh50?ooo`030;1iOP00000000000080000000<0oko60?oo
o`3oool00P3oool0103o_lH000000000000000050?ooo`<0000000<0oko60?ooo`3oool0103oool0
103o_lH000000000000000050?ooo`04038S90000000000007iGFPP0oooo00<0oko60?ooo`3oool0
0P3oool01@2ITI800000000000000000_j^]00L0oooo00<0omoS0?ooo`3oool00`3oool300000003
0?noaP3oool0oooo00H0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo
00@0oooo00@0oko600000000000000001@3oool0100I4A8000000000002`NGh60?ooo`0505Pm?`00
0000000000000020H6<09P3oool00`3om?X0jhUG0?nbB`0A0?nfD0030?neD03o]Tl0okI@01@0okI@
2P3o]Dh20?neD0030?nhC`3o]Dh0okE>00L0okE>00D0okI?0?nbC@3oYdL0ojQ80?ngCP0:0?niC`03
0?nhC`3o^Tl0okU?00X0okU?00<0okU@0?niC`3o^Dl02@3o^Dl00`3o^e00okU?0?niC`0<0?niC`03
0?nhD03o^Dl0okQ?0080okQ?00<0okU?0?nfC`3o^4l01P3o^4l0203o^4d0okQ?0?nhC`3o^E40okYG
0?nkFP3o^e/0okaL0`3o_Eh00`3o_5/0ok]K0?nkF`070?nkF`0;0?nlG03o_e`0oZ5>04lY5@0B2@@0
000002/I2`3jSch0ol9E0?oBG03od5/01`3ocET0103ocU`0oliJ0?o=FP3ocEX90?o=F@030?o=E`3o
cf40oleJ00X0oleI00<0oliL0?o>F`3ocET01`3ocET01`3oc5P0olmP0?o<F03oceh0oleL0?o=F@3o
cUd00P3ocET00`3oa500okU40?o0C@080?o=F@030?o<F03oceh0oleJ00H0oleI00<0olaH0?o=FP3o
cE/01P3ocET00`3oc5P0oliM0?o=F@060?o=F@030?o=G03ocEX0oleI00@0oleI00D0oliJ02dJ2`0a
8@d0ola>0?o/F`040?oUF0030?oUE`3oiET0onEH00D0onEH00<0onEG0?oUF03oiEP0103oiEP00`3o
iEL0onML0?oUE`060?oUF0030?oUFP3oiEP0onEH00<0onEH00<0onEG0?oWGP3oiUX01P3oiEP02@3o
iEH0onEH0?oUF03oi5X0onEK0?oVF@3oiEH0onMW0?oVF`060?oUF0030?oTE@3oiEP0onEH00@0onEH
00<0onML0?oUF03oiEP0103oiEP00`3oiET0onMR0?oUE`050?oUF0030?oUF@3oie`0onEH00H0onEH
00<0onAG0?oUE`3oiEP01@3oiEP00`3oiE/0onEI0?oUE`060?oUF0030?oVF@3oiEL0onEH00H0onEH
00<0onAJ0?oVFP3oiEP0403oiEP00`3oiET0onEG0?oUF@090?oUF0030?oVG@3oiUT0onEH00P0onEH
00<0onIK0?oUF@3oiEH02@3oiEP00`3oiET0onEG0?oWG00;0?oUF0030?oUF@3oiU/0onAE00T0onEH
00d0onaJ0?oSEP3oYCl0FCTE000000071@80<2P>0:V8<P3oiE80onY?0?oUB`3ohdT0on=800L0on=9
00X0onA90?oSB@3oh4P0on580?oSB@3ohDT0om]70?oTB@3ohDT0on990`3ohdT00`3oi4X0on=90?oS
B@030?oSB@040?oTB@3ohTT0on990?oMAa<0on=90P3ohTT00`3oi4T0on180?oUBP080?oSB@030?oT
BP3ohdT0on=900<0on=900<0onA:0?oSB@3ohdT00`3ohdT01`3oi4X0on980?oKAP3ohdP0omY60?oN
A`3oi4T00P3ohdT00`3oi4X0on=90?oSB@030?oSB@030?oTBP3ohdT0on=900D0on=900<0onA:0?oS
B@3ohdT00`3ohdT02P3oi4X0on=90?oTB@3ohdT0on990?oSBP3ohDT0omY60?oSB@3oi4T>0?oSB@04
0?oTBP3ohdT0on=90?oTB@H0on=900H0onI:0?oYBP3okdP0omjU0?oOi`3oio7o0?ooomH0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWB@3oool3000000030<V;
T03oool0oooo00/0oooo00D0P82000000000000000000?oOh`060?ooo`040?noaP00000000000000
00@0oooo00D0eY>I000000000000?b`]0?oioP050?ooo`030?oioP0o;2d000000080000000<0oko6
0?ooo`3oool00P3oool0103o_lH000000000000000050?ooo`<0000000<0oko60?ooo`3oool0103o
ool0103o_lH000000000000000040?ooo`050<Z;T0000000000003l/;@3ol?D03@3oool01@1UATP0
00000000000o;2d0ooSj00d0oooo0`0000000`3o_lH0oooo0?ooo`060?ooo`040?noaP0000000000
000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00D0
eY>I00000000000081HG0?oioP060?ooo`0509nCUP000000000000000020H6<09`3oool01@3ojND0
lJ^=0?FIC03o]4l0okM@00P0okI@0P3o]Tl20?nfD0030?nfC`3o]U00okI@01H0okI@103o]Dh00`3o
]Tl0okE>0?nfC`040?neCP030?nfD03o]Dh0okE>00P0okE>00D0okI?0?nbC@3oYdL0ojU80?ngCP05
0?niC`070?njD03o^Dl0okY?0?niC`3o^Tl0okU?0?niD00;0?niC`030?niD03o^Dl0okU?00@0okU?
00@0okU@0?njC`3o^Dl0okY?0`3o^Dl00`3o^E00okU?0?niC`0<0?niC`80okQ?00<0okU?0?nhC`3o
^4l02@3o^4l30?nhC@070?ngCP3o^4l0okYB0?nkFP3o^eP0ok]I0?nlF`020?nkF`0@0?nkG03o^e/0
ok]K0?nkF`3o_U`0ok]K0?jSC`2[L3L0P4DR01X>1`0Z60/0OTTO0:Qm=P3n_E<0oliJ0?o?FPL0oleI
00<0oliK0?o?G03ocET02P3ocET00`3ocEX0oliL0?o=FP090?o=F@030?o=FP3ocUd0oliL00H0oleI
00P0oleK0?o=FP3ocEP0oliL0?o=F@3oceh0oliL0?o=FP@0oleI00@0olIB0?njAP3o^4L0olYF1`3o
cET00`3ocUX0oliL0?o=F@060?o=F@030?o=FP3ocU`0oliL00H0oleI00<0oleJ0?o>G@3ocEX01P3o
cET00`3ocE/0oliK0?o=F@030?o=F@060?oBG03o`UD0PT/P01lC1`3X]TH0onYJ1@3oiEP00`3oiU/0
onEH0?oUF0050?oUF0030?oVF`3oiEP0onEH00D0onEH00<0onIJ0?oUF03oiEP0103oiEP20?oUF@D0
onEH00<0onEG0?oXH`3oiU/01P3oiEP00`3oiEH0onEH0?oUF0020?oUF0030?oVF`3oiUX0onEH00L0
onEH00<0onQT0?oUF@3oiEP01@3oiEP00`3oied0onEH0?oUF0050?oUF0030?oVF`3oiEP0onEH00@0
onEH00<0onEJ0?oVG03oiEL01@3oiEP00`3oiUX0onIL0?oUF@060?oUF0030?oVFP3oiUP0onEH00H0
onEH00<0onIJ0?oVF@3oiEP01P3oiEP00`3oiUX0onEI0?oUF0070?oUF0030?oVFP3oiU/0onEI00L0
onEH0P3oiUX90?oUF0030?oUF@3oiEP0onEI00P0onEH00<0onEG0?oUF@3oiUX02P3oiEP00`3oiET0
onIJ0?oUF@0;0?oUF0040?oVF@3oiEP0onIJ0?oVF@@0onEH00h0onEI0?oVF@3oiEP0onIH0?oVEP3o
ge80ol=509A[9@0X6@T02`H201<@1@1cGal0eKLk0?oMAP80onI:0`3ohdT01`3oi4T0on990?oSBP3o
i4T0on590?oUBP3ogTP00P3ohTT30?oSB@030?oTB@3ohdT0on=900<0on=900<0onA:0?oSB@3ohdT0
1@3ohdT0103oi4T0omm80?oSB@3ohTT40?oSB@030?oTBP3ohdT0on=900/0on=900L0onA90?oRB@3o
gdP0on=90?oQB@3ohdT0on9900<0on=900<0onA:0?oSB@3ohdT02P3ohdT00`3ohTP0omi60?oNA`02
0?oSB@060?oRB@3ohdT0on980?oOB03ohdT0on990`3ohdT00`3oi4X0on=90?oSB@0:0?oSB@80onA9
1`3ohdT01`3oi4T0on590?oTBP3oi4T0ome80?oSB@3ohTT01`3ohdT00`3oi4X0on=90?oTBP020?oT
B@H0on=900D0onA90?oLAP3oiX<0oo;E0?ono03o0?ooomP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWB@3oool3000000030<V;T03oool0oooo00/0oooo00D0
P82000000000000000000?oOh`060?ooo`040?noaP0000000000000000@0oooo00@0IDE800000000
0000bH^@1`3oool01@39Ri000000000000000000oko600@0oooo00@0oko600000000000000001@3o
ool3000000030?noaP3oool0oooo00@0oooo00@0oko60000000000000000103oool0100b8b@00000
0000003RW:8>0?ooo`0401TB4P00000000000>:LXPh0oooo0`0000000`3o_lH0oooo0?ooo`060?oo
o`040?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP000000
0000000000@0oooo00@0IDE8000000000000IDI81`3oool01@3TaLP00000000000000000P61S02T0
oooo00@0oo[o0?:<H03o/D`0okU@1@3o]U000`3o]E00okI@0?nfD00L0?nfD080okE>00<0okI?0?nd
CP3o]U001P3o]Dh00`3o]E00okE>0?neCP080?neCP050?nfC`3o/T`0ojM70?nWA`3o]dh01@3o^Dl0
0`3o^U00okU?0?niC`0;0?niC`050?niD03o^Dl0okU?0?niC`3o^E00103o^Dl00`3o^4l0okY?0?nk
CP060?niC`030?niD03o^Dl0okU?00T0okU?00<0okQ?0?njCP3o^Tl03P3o^4l0103o^4d0okM>0?nh
CP3o^Dh50?nhC@090?niC`3o^5D0okYG0?nkF03o^e/0ol5N0?o7H@3o[UD0Z5P/0080000000@050/4
0:UQ:P3odE`0omEN2@3ocET00`3ocE/0olmN0?o<F0090?o=F@040?o<F03ocEX0oleI0?o>F`X0oleI
00<0oleJ0?o=G03ocET00`3ocET0203oc5P0oleI0?o=G03ocU/0olmP0?o?H@3ocUh0oleJ1`3ocET0
1@3obUH0oka50?niA@3oaU80oliK00H0oleI00<0olaH0?o>FP3ocET01`3ocET00`3oceh0oleI0?o=
F@050?o=F@030?o=FP3ocU`0olaH00D0oleI00@0olaH0?o=F@3ocE`0oleJ0`3ocET01P3oceX0omAM
07Q47@000000S6HW0?oVF@H0onEH00<0onEJ0?oUF03oiEP01@3oiEP00`3oiU/0onEH0?oUF0040?oU
F080onIK1@3oiEP00`3oiEL0onIO0?oVG0050?oUF0030?oUEP3oiel0onIJ00D0onEH00<0onEG0?oU
EP3oiEP0103oiEP00`3oied0onEG0?oUEP050?oUF0030?oUE`3oif80onEI00D0onEH00<0onEI0?oW
G`3oiEP01@3oiEP00`3oiET0onML0?oUEP050?oUF0030?oUE`3oiEP0onEI00H0onEH00<0onIJ0?oT
FP3oiEP01P3oiEP00`3oiE/0onEI0?oUF0070?oUF0030?oUE`3oiEP0onEH00D0onEH00<0onIJ0?oW
G03oiEP01`3oiEP00`3oiEL0onIK0?oUF0070?oUF0030?oVF`3oie`0onEG00T0onEH00<0onMM0?oU
E`3oiEL0203oiEP0103oiEL0onEK0?oVF`3oiEL90?oUF0030?oUEP3oie`0onII00`0onEH01d0onMK
0?oUF@3oiUT0onII0?oUF03oheD0on9D0?oOD03ofdX0omM70?oIA`3ofTP0oma90?oPBP3/UC80GS/C
014;100000009b0;0:Z9;03mfdH0ona<0?oTB@3oh4P0on=90?oMA`3ohDP0onA:0?oTB@040?oSB@04
0?oTB@3ohDT0on=90?oQB@h0on=900P0onA:0?oSB@3oiDT0omm70?oOB03ohTT0on=90?oTB@l0on=9
00P0onA:0?oSB@3oi4T0omm70?oMA`3oiDX0on590?oTB@80onA:303ohdT00`3ogTL0omi60?oRB@04
0?oSB@070?oTB@3ohdP0ome70?oUBP3oh4P0on990?oTB@080?oSB@030?oTBP3ohdT0onA900h0on=9
0P3oi4T01`3og4L0omi70?oUB@3ohDP0onA90?oSB@3oi4T00`3ohdT00`3oi4T0on=90?oSB@050?oS
B@030?oTAP3og5T0ong80?l0oooof`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinM90?ooo`<0000000<0bH^@0?ooo`3oool02`3oool01@20P800000000000000
0000omoS00H0oooo00@0oko60000000000000000103oool3000000030?noaP3oool0oooo00D0oooo
00D0oko600000000000000000?noaP040?ooo`040?noaP0000000000000000D0oooo0`0000000`3o
_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000<0oooo00D0oo?l00000000000000000?no
aP0=0?ooo`050?oco000000000000000003o_lH03P3oool3000000030?noaP3oool0oooo00H0oooo
00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000
00000000103oool300000003081PH`3oool0oooo00D0oooo00D0omoS0000000000000000081PH`0Z
0?ooo`070?oen`3oXV80okI70?nfD@3o]U00okI?0?ndCP0P0?nfD0/0okE>00<0okE@0?neCP3o]Dh0
103o]Dh02P3o]E00okE>0?neCP3o]Dh0okI?0?nbC03oYdL0ojU80?ngCP3o^dl20?niC`030?njC`3o
^Dl0okU?0140okU?00D0okU@0?niC`3o^Dl0okU?0?niCP060?niC`80okU@00<0okU?0?niD03o^Dl0
2@3o^Dl0103o^Th0okQ?0?niC`3o^Dl<0?nhC`040?nfD03o^4l0okQ=0?ngCPL0okQ=00d0okQ>0?ni
C`3o^4d0okI?0?o3F03o/580hgPl06Pf6`0000003PL306ho6`3_RCX0omAM00P0oleI00@0olaH0?o=
G03ocEX0oliK2P3ocET0103ocEX0oleL0?o>G@3ocEL90?o=F@030?o=G03ocUX0oliM00<0oleI00T0
olaH0?o>F`3ocUd0olaH0?o?H03ocU`0oleL0?o>G03ocEX0203ocET01@3oa540ok]60?o0C03ocET0
oliJ00D0oleI00<0olaH0?o>F03ocEX01P3ocET00`3oc5P0oliM0?o=F@060?o=F@030?o=F03ocEX0
oliL00H0oleI00<0oleJ0?o?GP3ocEX0103ocET01P3oeEd0hh4i018:10000000ikI60?oVF0@0onEH
00<0onEG0?oUF`3oiEP01P3oiEP00`3oieX0onII0?oUF0050?oUF0030?oUE`3oiET0onEH00@0onEH
00<0onEG0?oVF@3oiEP01P3oiEP00`3oiE@0onIG0?oUF0040?oUF080onEF1@3oiEP20?oUE`030?oU
E03oiET0onEH00@0onEH00<0onED0?oUF03oiEP01@3oiEP00`3oiE80onAE0?oUF0050?oUF0030?oU
E`3oi5X0onEH00@0onEH00@0onEG0?oWG03oiE/0onEG1P3oiEP00`3oie`0onEH0?oUF0060?oUF003
0?oUFP3oiEP0onEH00H0onEH0P3oiEL60?oUF0040?oUE`3oiUX0onIK0?oUF@L0onEH00<0onEJ0?oT
FP3oiEL01`3oiEP00`3oiUP0onEG0?oUF0080?oUF0030?oUE`3oiEP0onEF00T0onEH00@0onEG0?oV
G@3oiEH0onEI2P3oiEP00`3oiET0onMK0?oUE`090?oUF080onII00D0onAH0?oSEP3oge80ome>0?oI
B@020?oGA`<0omQ800L0omY80?oHB03ofTP0on=<0?oNBP32NbT081@60080000000H0JUHK0?oCA@3o
n4l0onM:0?oRB@3oi4T80?oSB@060?oTBP3oiDT0omm80?oPB03ohdT0onA90`3ohdT00`3oi4X0on=9
0?oSB@090?oSB@040?oUBP3oh4T0on=90?oOB1<0on=900L0onA90?oSB@3oh4P0on990?oPB@3oi4X0
onA900X0on=900@0onA90?oNA`3ogTH0on991@3ohdT01`3oi4X0onA90?oSB@3ogDP0on990?oOB03o
hTT00P3oi4T60?oSB@030?oTB@3ohdT0on=900X0on=900<0onA90?oSB@3ohdT00P3ohdT20?oTB@09
0?oUBP3ogTP0onI:0?oQB03ogdP0onA90?oUB@3ohdT0onA:00H0on=900<0onE60?oK@03oiK@0o`3o
oooL0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWidT0oooo
0`0000000`39Ri00oooo0?ooo`0;0?ooo`050820P000000000000000003ogn<01P3oool0103o_lH0
00000000000000040?ooo`<0000000<0oo?l0?ooo`3oool01@3oool01@3ohNX00000000000000000
oko600@0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0
oko600000000000000000`3oool0103o_lH0000000000000000>0?ooo`040?noaP00000000000000
00l0oooo0`0000000`3o_lH0oooo0?ooo`060?ooo`040?noaP0000000000000000D0oooo0`000000
0`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo0`0000000`20NWh0oooo0?oo
o`050?ooo`050?o`m@000000000000000020H6<0:`3oool0103og]<0okY]0?naB@3o^50N0?nfD004
0?neCP3o]U00okE?0?nfD0/0okE>00<0okE@0?neCP3o]Dh0203o]Dh01P3o]Tl0ok9<0?nWA`3oY4L0
okI>0?njD0<0okU?0P3o^E0A0?niC`040?njD03o^Dl0okY>0?njCQ80okU?00<0okY>0?niC`3o^Tl0
103o^Dl<0?nhC`030?niC`3o^4l0okQ>00X0okQ=00@0ok]@0?o7E03VSC`0HS@E0P0000001@0n8`h0
lX/k0?o:F03off40oliK00P0oleI0P3ocUd00`3ocUX0oleI0?o=F@080?o=F@030?o<F03ocUd0oliM
00X0oleI00<0oliJ0?o>G@3ocET00P3ocET02P3oc5P0oleJ0?o?H03ocU`0olmN0?o=F@3ocEL0oliK
0?o>G03oc5P70?o=F@060?o<F03oceh0okm;0?nlA`3obUH0oliJ103ocET0103ocEX0oliJ0?o=F03o
c5P60?o=F@030?o<F03ocU`0oliL00L0oleI00<0oleK0?o>FP3ocET01P3ocET00`3oceh0oleJ0?o<
F0030?o=F@060?o<F@3ob5P0?B<?0000001N?1L0on9G1@3oiEP00`3oiUX0onIK0?oUF0060?oUF003
0?oWGP3oiEP0onEH00@0onEH00<0onII0?oWG03oiEL01@3oiEP00`3oiEL0onEB0?oUF0050?oUF003
0?oTE`3oiEH0onEH00D0onEH00<0onEF0?oUE`3oiEP01P3oiEP00`3oi5D0onIJ0?oUE`040?oUF003
0?oUE`3oi5D0onEH00D0onEH00<0onEI0?oVG@3oiEP01@3oiEP00`3oiU/0onIO0?oUF0050?oUF003
0?oUE`3oie`0onIJ00H0onEH00<0onEI0?oUG03oiEP01P3oiEP00`3oiUT0onEG0?oUF0050?oUF004
0?oUF@3oiE/0onII0?oUE`H0onEH00<0onEG0?oVF@3oiUT0203oiEP00`3oiE/0onIJ0?oUE`070?oU
F0030?oTE`3oieX0onEH00P0onEH0P3oiEL00`3oiUX0onEG0?oUF0070?oUF0040?oUE`3oi5L0onIK
0?oUE`X0onEH00@0onIJ0?oUEP3oiUX0onEG103oiEP20?oVF@080?oUF03oi5@0on1?0?oLC03ofDT0
omM70?oFAP3ofDP90?oHB00;0?oKB03oi4`0ojHf08MG7@091@40000004Tj4P2FN2L0m/Ho0?o`C@3o
hTT00P3oi4X80?oSB@040?oQB03oh4P0on980?oOB0l0on=900H0onA:0?oTB@3oi4T0omi80?oSBP3o
h4P20?oTBA40on=900L0onA90?oQB03oh4P0onI:0?oOB@3ohdT0onA900P0on=900@0onA90?oOA`3o
gDH0on99203ohdT20?oTB@040?oNA`3ohDP0onI:0?oPB080onA900<0on=90?oTB@3ohdT04P3ohdT0
3@3oi4X0on=90?oSB@3ohdT0onA90?oSB@3oh4P0omi70?oSB@3ogDL0onE:0?oSB@3oi4T0103ohdT0
103oiTH0omE?0?oV[`3oo?_o0?ooom`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWB@3oool3000000030<V;T03oool0oooo00/0oooo00D0P820000000000000
00000?oOh`060?ooo`040?noaP0000000000000000<0oooo00@0olS?00000000000000002@3oool3
000000030?noaP3oool0oooo0080oooo00@0oko600000000000000001@3oool3000000030?noaP3o
ool0oooo00@0oooo00@0oko600000000000000000`3oool0103SW:80000000000000000;0?oOh`04
0?o/l@3oool0oooo0>>LXP<000002`3ogn<0103onOh0oooo0?ooo`3oool3000000030?noaP3oool0
oooo00H0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0
oko600000000000000000`3oool01@3oi>L00000000000000000P82000P0oooo0`0000000`20H6<0
oooo0?ooo`0Z0?ooo`040?ogl`3ocJD0ojaN0?neD1P0okI@00<0okI?0?nfD03o]Tl01@3o]U050?ne
CP030?nfC`3o]Dh0okE>00@0okE>00<0okE?0?neCP3o]Dh0103o]Dh00`3o]Dl0okE>0?neCP020?ne
CP040?n_B`3oZ4P0oj]90?nhCa<0okU?00D0okY@0?niC`3o^Dl0okY?0?njD0090?niC`050?niD03o
^Dl0okU?0?niC`3o^E000`3o^Dl00`3o^Tl0okU?0?niC`040?niC`040?niD03o^Dl0okU?0?niC`P0
okQ?0P3o^Dl0103o^4l0okU?0?niC`3o^4l90?nhC@0B0?niC`3UUd00XF/]05`a5@0E2`D0>b4<081;
7@2nQ340oka80?o?D03obTh0olU>0?o:DP3obe@0olaF0?o<E`3ocEX0oleI0`3ocU/<0?o=F@030?o>
G@3ocET0oleI00X0oleI00h0oliL0?o>F`3ocET0oliO0?o<F03ocUd0oliI0?o=F@3ocE/0oleJ0?o<
F03ocU`0oliJ0?o>F`P0oleI00H0oleH0?o?GP3oaU<0oka70?o8E03ocUX50?o=F@030?o>F`3oc5P0
oleI00H0oleI00<0oleK0?o>G@3ocU/01`3ocET20?o>G0L0oleI00<0oliK0?o=F@3ocET0103ocET0
1P3ode`0ZG0a0000001W@QT0oli?0?oYF@@0onEH00<0onEI0?oVFP3oiEP01P3oiEP00`3oiUT0onEH
0?oUF0050?oUF0030?oUF@3oiUd0onEH00@0onEH00<0onEG0?oWG@3oj6801P3oiEP20?oUFPH0onEH
00<0onEF0?oUE`3oiEP01P3oiEP01@3oiED0onEI0?oWG03oiUT0onEG00<0onEH00<0onQR0?oUF03o
iEP0103oiEP00`3oiET0onMN0?oUF0060?oUF0030?oVFP3oiEX0onEH00D0onEH00<0onII0?oVFP3o
iEP01P3oiEP00`3oiUX0onEI0?oUF0050?oUF0030?oUF@3oie/0onII00L0onEH0P3oiUX80?oUF003
0?oVF03oiUT0onEH00L0onEH0P3oiU/00`3oiUT0onEH0?oUF0050?oUF0030?oVF@3oiU/0onIJ00T0
onEH00<0onIJ0?oUE`3oiEP02@3oiEP0103oiET0onII0?oUFP3oiUT:0?oUF00;0?oUF@3oiUX0onEI
0?oSE@3ohU<0on1A0?oNCP3og4X0omY:0?oIB@3ofDP00P3of4P20?oIB0030?oHB03ofDP0omQ800<0
omQ80180omY90?oIB@3oeTL0omI70?oIB@3oedL0on1;0?oKB@3oa440WG0V04ha4@060`406QD706aG
7031/3T0oma70?oYB`3oi4T80?oSB@070?oPB03ohTP0on990?oQB@3ohdT0on180?oTB@0;0?oSB@06
0?oTBP3ohdT0on=90?oTB@3ohdT0onA90P3oh4P00`3ohdT0on990?oSB@030?oSB@030?oTBP3ohdT0
on=900/0on=900L0onE:0?oSB@3ohTT0omi80?oTB@3ohDT0onA:00D0on=900@0onA90?oOA`3ogDH0
on991@3ohdT00`3oi4X0on=90?oSB@020?oSB@090?oTB@3ohdT0onA90?oSB@3oi4T0omi80?oTB@3o
hTT0on=90080onA93@3ohdT0103oi4X0on=90?oSB@3oi4X40?oSB@0>0?oTB@3ohdT0onA90?oSB@3o
hTT0onA90?oUBP3oh4P0onA90?oPB03ohdT0on1B0?oLUP3om^Go0?ooomh0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWB@3oool3000000030<V;T03oool0oooo
00/0oooo00D0P82000000000000000000?oOh`060?ooo`040?noaP0000000000000000<0oooo00@0
oko600000000000000002@3oool3000000030?noaP3oool0oooo0080oooo00@0oko6000000000000
00001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000000`3oool00`39
Ri0000000000000<00000004081PH`3oool0oooo0<V;T0h0000000@0oko60?ooo`3oool0oooo0`00
00000`3o_lH0oooo0?ooo`060?ooo`040?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo
0?ooo`040?ooo`040?noaP0000000000000000<0oooo00D0omoS00000000000000000820P0080?oo
o`<0000000<0P61S0?ooo`3oool0;03oool00`3onoh0oja]0?nfD00D0?nfD080okE>2@3o]U0H0?ne
CP040?n^B`3oYdL0oje:0?nhC`H0okU?00<0okU@0?niC`3o^Dl02@3o^Dl00`3o^dh0okU?0?niC`02
0?niC`030?niD03o^Dl0okU?00/0okU?00<0okQ@0?niC`3o^Tl0303o^Dl70?nhC`030?njC`3o^4l0
okQ?00@0okQ?1@3o^4d0303o^Dh0okY@0?njD03o/D/0Q4@N00H30@0000000`8009]H8@3oaT/0ola>
0?o;C@L0olM<00@0olQ=0?o8CP3obE<0ol]D303ocET00`3ocU`0olaH0?o=F@0:0?o=F@060?o>G`3o
c5P0oleL0?o?GP3ocEL0oleL1@3ocET00`3ocEP0oliM0?o=G00;0?o=F@030?o5D@3o^dH0ol5=00H0
oleI00<0oliM0?o=F@3ocET01P3ocET00`3ocU/0oliM0?o<F0070?o=F@030?o>G03ocEX0oleI00H0
oleI00<0oleJ0?o>G03ocET0103ocET01P3odU`0okUA02DE2P1C<a@0ola>0?o_F`D0onEH00<0onIJ
0?oUF@3oiEP01@3oiEP00`3oiEL0onEH0?oUF0050?oUF0030?oUF@3oied0onEG00L0onEH00<0onEF
0?oUF03oiEP00`3oiEP00`3oiEL0onQP0?oVH@060?oUF0030?oUEP3oiEL0onEH00D0onEH00L0onEG
0?oXIP3oiET0onEH0?oUF@3oiUX0onEI0080onEH00<0onQX0?oUF03oiEP01@3oiEP00`3oiEL0onII
0?oUF0050?oUF0030?oTFP3oiUT0onEH00H0onEH00<0onEG0?oUF03oiEP01@3oiEP00`3oiET0onIJ
0?oUF0060?oUF0030?oUF@3oiUT0onEG00L0onEH0P3oiEL80?oUF080onEF203oiEP00`3oiEL0onIK
0?oUE`080?oUF0030?oTFP3oiE/0onEG00T0onEH00<0onEG0?oWG@3oiEP02@3oiEP00`3oiET0onEK
0?oVF@080?oUF0080?oSE03oh500oma;0?oJBP3oedL0omQ80?oJB03ofDP90?oHB0060?oJB03of4P0
omI70?oHB03ofdP0omA8203of4P02`3ogdX0omE70?ni?@2FGal020D20000000K5PH0Q6TR0?oLA`3o
iTX0onE900L0on=900L0on990?oQBP3ohdT0onA90?oQB@3oi4T0omi700X0on=900<0onA:0?oSB@3o
hdT01`3ohdT01@3ofdH0on980?oSB@3ohdT0onA:00X0on=900<0onA:0?oSB@3ohdT01P3ohdT00`3o
hDP0ome80?oSB@030?oSB@040?oTB@3ogdL0ome60?oRB@d0on=900<0onA90?oSB@3oi4T00P3ohdT0
103oiDT0omm70?oKAP3oi4X20?oSB@030?oTB@3ohdT0on=900X0on=900D0onA:0?oSB@3ohdT0on=9
0?oTB@060?oSB@060?oTB@3ohdT0on=80?oTB03ofD40onFlo`3ooooP0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWidT0oooo0`0000000`39Ri00oooo0?ooo`0;
0?ooo`050820P000000000000000003ogn<01P3oool0103o_lH000000000000000030?ooo`040?no
aP0000000000000000T0oooo0`0000000`3o_lH0oooo0?ooo`020?ooo`040?noaP00000000000000
00D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000<0oooo00<0bH^@
000000000000300000001020H6<0oooo0?ooo`39Ri0>000000040?noaP3oool0oooo0?ooo`<00000
00<0oko60?ooo`3oool01P3oool0103o_lH000000000000000050?ooo`<0000000<0oko60?ooo`3o
ool0103oool0103o_lH000000000000000030?ooo`050?oOh`000000000000000020P800203oool3
00000003081PH`3oool0oooo02d0oooo00@0oncW0?nQC`3o/dd0okQ>403o]U000`3o]Dl0okI@0?nf
D00:0?nfD1P0okE>00@0oji;0?nWA`3o[DX0okQ?103o^Dl00`3o^E00okU?0?niC`080?niC`030?nj
C`3o^Dl0okU?00D0okU?00<0okU@0?niC`3o^Dl02`3o^Dl00`3o^500okY>0?njC`0<0?niC`H0okQ?
00<0okU>0?ngC`3o^4l0103o^4l00`3o]Tl0okQ=0?nhC@020?nhC@0;0?niC`3o_540oj]80=ad<@0`
60T0000000l90`1Z>aH0oiPj0?o7C03obTd03P3oad`0103obE00ol]D0?o<F03oc5P50?o=F@030?o=
FP3oceh0oliK00T0oleI00H0olaH0?o=F@3ocE/0om1R0?o?H@3ocEL90?o=F@030?o<F03ocET0oleI
00L0oleI00H0oleL0?o=F`3obeL0oki:0?njA@3ob5@50?o=F@030?o?GP3ocET0oleI00L0oleI00<0
oliM0?o<F03ocET01P3ocET00`3ocUd0oleI0?o<F0070?o=F@030?o<E`3ocEP0oleI00@0oleI00D0
olaH0;EW;@081@80nYhl0?odG@050?oUF0030?oVFP3oiE/0onEG00H0onEH00<0onMP0?oUF@3oiEP0
1@3oiEP00`3oiET0onMN0?oUF0060?oUF0030?oUEP3oiEL0onEH00@0onEH00<0onEG0?oVH@3oiV40
1P3oiEP00`3oiEH0onEG0?oUF0050?oUF0030?oUE`3oifP0onEI0080onEH00D0onEG0?oUF@3oiEP0
onEH0?oTE@060?oUF0030?oUE`3oiU`0onIM00H0onEH00<0onEG0?oVFP3oiEP01P3oiEP00`3oiUX0
onAJ0?oUF0060?oUF0030?oWG03oiEP0onEH00H0onEH00<0onMJ0?oWG03oiEP01`3oiEP00`3oiUT0
onEH0?oUF0070?oUF0030?oVF@3oiEH0onEH00L0onEH00<0onIJ0?oUF@3oiEP02@3oiEP00`3oiU/0
onEH0?oUF0090?oUF0030?oUF@3oiEP0onEH00T0onEH00<0onIJ0?oUF@3oiUT00P3oiEP0103oi5L0
on9B0?oOC`3ofdX40?oJB0040?oKB03oedL0om]90?oIB0/0omQ800D0omM70?oEA`3ofTL0omU90?oJ
B@080?oHB0050?oKB@3og4T0omQ80<J;;P0G3P@00P0000001@1@@1@0o/]10?oNA`3ojD/0onE:00<0
on=900D0onA:0?oSB@3ohdT0on990?oTB@040?oSB@030?oMB03oh4P0on=900L0on=900<0onA:0?oS
B@3ohdT02@3ohdT00`3ogdL0on990?oSBP050?oSB@030?oTBP3ohdT0on=900`0on=900T0on=:0?oU
B@3oh4P0onA90?oRB@3oi4T0omm70?oMAP3ohTT01P3ohdT00`3oi4T0on=90?oSB@020?oSB@030?oT
BP3oi4T0onA900L0on=900@0on580?oOB03oiDX0on99303ohdT0103oi4X0on=90?oSB@3oi4T80?oS
B@040?oTB03oiDD0omQV0?oY_?l0ooooh@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0
103YjNT0dM7A0=7Ad@3WinM90?ooo`<0000000<0bH^@0?ooo`3oool02`3oool01@20P80000000000
00000000omoS00H0oooo00@0oko600000000000000000`3oool0103od=P000000000000000090?oo
o`<0000000<0oko60?ooo`3oool00P3oool0103o_lH000000000000000050?ooo`<0000000<0oko6
0?ooo`3oool0103oool0103o_lH000000000000000030?ooo`030<V;T0000000000000`0000000@0
P61S0?ooo`3oool0bH^@3P000000103o_lH0oooo0?ooo`3oool3000000030?noaP3oool0oooo00H0
oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000
0000000000000`3oool01@3oj>`00000000000000000P82000P0oooo0`0000000`20H6<0oooo0?oo
o`0^0?ooo`040?odl@3oX680ok5?0?nhC`d0okI@00<0okE>0?nfD03o]U00303o]U040?neCP030?nf
D03o]Dh0okE>0140okE>00@0oji;0?nWA`3o[DX0okQ?3P3o^Dl00`3o^dl0okU?0?niC`060?niC`03
0?niD03o^Dl0okU?00X0okU?00<0ok]>0?nhC`3o^Dl03@3o^Dl40?nhC`030?njCP3o^4l0okQ?00H0
okQ?00P0okQ@0?nhC@3o^4d0okU?0?noD@3o_E40kH`k03@L2P80000000D0ABL?0?nG>@3obdh0olY=
0?o8C@0B0?o7C0070?o8C@3obU<0olaF0?o;E`3ocET0oleG0?o?GP080?o=F@060?o<F03ocE/0oliM
0?o<EP3ocUX0oliL2P3ocET00`3ocUh0oleJ0?o=F@080?o=F@070?o=FP3oceh0oleI0?o2CP3o^TD0
oka70?o<F0040?o=F@030?o?GP3ocEX0oleI00L0oleI00<0oleL0?o=F`3ocET01`3ocET00`3ocUX0
oleJ0?o=F@060?o=F@030?o=FP3ocUX0oleI00@0oleI00H0om5L0?nPA@0>1`<0B2hB0?oYFP3oj5T5
0?oUF0030?oTF@3oiEL0onEH00H0onEH00<0onII0?oUF03oiEP01P3oiEP00`3oiEH0onEH0?oUF004
0?oUF0030?oVF`3oj600onEG00D0onEH00<0onEG0?oWG03oie`01P3oiEP00`3oi5L0onEH0?oUF005
0?oUF0030?oUE`3oifL0onEI00<0onEH00D0onEI0?oVF`3oiEP0onEF0?oUE`060?oUF0030?oTFP3o
ieT0onEH00D0onEH00<0onEG0?oVGP3oiEL01P3oiEP00`3oiUT0onEI0?oUF0070?oUF0030?oWG03o
iEL0onEH00L0onEH00<0onEI0?oUF03oiEP01@3oiEP00`3oiUX0onEI0?oUF0070?oUF0030?oUF@3o
iUT0onEH00P0onEH00<0onML0?oUF@3oiEL0203oiEP00`3oiUP0onIJ0?oUF0090?oUF0040?oUE`3o
iUX0onEI0?oUE`D0onEH00P0onEI0?oVF@3oiUT0onEH0?oSE`3oi5P0omm@0?oMC0X0omY800<0om]9
0?oFA`3of4P01`3of4P0103ofdP0om560?oDAP3ofDP20?oHB0030?oGB03ofDT0omY800X0omQ800X0
omi90?nm?P2;FAd0:1T8000000050P40MEdM0>Be>`3oidX0onI:1`3ohdT0103oi4T0on=90?oSB@3o
i4X20?oSB@040?oNA`3ohDP0on=90?oTB@T0on=900<0onA:0?oSB@3ohdT01@3ohdT0103ohTP0on19
0?oSB@3ohDPD0?oSB@070?oTB@3ohTT0omY60?oSB@3ogDH0omi60?oRB@060?oSB@040?oTB@3ohdT0
on=90?oSB@80onA92P3ohdT01@3oi4T0on980?oLB03oi4X0on180080on=900<0onA90?oSB@3ohdT0
0`3ohdT00`3oi4T0on=90?oTBP020?oTB@T0on=900<0on990?oRS03ok]l0o`3ooooR0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWidT0oooo0`0000000`1nEeX0
/Z:T0;:RY0060;:RY0030=Rl_`3oool0oooo0080oooo00D0P82000000000000000000?oOh`060?oo
o`040?noaP0000000000000000@0oooo0`0000000`3ofN40oooo0?ooo`050?ooo`050?o@f0000000
00000000003o_lH0103oool0103o_lH000000000000000050?ooo`<0000000<0oko60?ooo`3oool0
103oool0103o_lH000000000000000030?ooo`040?noaP0000000000000000P0oooo0`0000001020
L780oooo0?ooo`3o_lH3000000P0oooo0`000000103ogn<0oooo0?ooo`3oool3000000030>>LXP3o
ool0oooo00H0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo
00@0oko60000000000000000103oool300000003081]L@3oool0oooo00D0oooo00D0onS/00000000
00000000081PH`0a0?ooo`050?oin@3ock`0ok9W0?neC@3o]e000`3o]U001P3o]U40okI@0?nfD03o
]Tl0okI@0?nfCa40okI@1`3o]Dh00`3o]Tl0okE>0?neD0030?nfC`D0okE>00<0okE?0?neCP3o]Dh0
0`3o]Dh0103o[DX0ojM70?n_BP3o^E030?niC`030?niD03o^Dl0okU?0080okU?00@0okY?0?niC`3o
^Tl0okY@1P3o^Dl00`3o^E00okU?0?niC`0:0?niC`070?njC`3o^U00okU@0?nhCP3o^Tl0okU?0?nh
D00=0?niC`040?niD03o^Dl0okY?0?niC`80okQ?00<0okQ@0?nhC`3o^4l00`3o^4l03P3o^500okQ?
0?nhD03o_500okQ?0>6D?`2THbX0J3LH01L=1@129Pl0Se8O0;b9=@3o`4X0ol]>2P3oad`00`3oadd0
olM<0?o7C0040?o7C080olQ=1@3oad`04@3ob4d0olU@0?o9D03obE40olYC0?o<EP3oc5L0oleH0?o=
F@3ocU`0oleI0?o>G@3ocf40oliL0?o?GP3ocET0oleJ00P0oleI00@0oleJ0?o=F@3ocET0oliK203o
cET01@3ocU/0oliJ0?o>F`3ocUX0olQD0080ok]600H0olUE0?o>FP3ocET0oleI0?o=F03ocUd80?o=
F@030?o>F`3ocUd0oleK00P0oleI00<0oliL0?o=F@3ocET01P3ocET00`3ocU/0oleL0?o=F@040?o=
F@060?o@F`3VWdD0:QP;00<20@38X3d0onYJ1@3oiEP00`3oiUT0onIJ0?oUF0060?oUF0030?oVFP3o
iEX0onEH00H0onEH00<0onMN0?oUF03oiEP01@3oiEP00`3oiU/0onMO0?oUE`060?oUF0030?oUEP3o
iEL0onEH00@0onEH00<0onEG0?oXH`3oiUd01P3oiEP00`3oiEL0onQW0?oUF@040?oUF0040?oVFP3o
iE/0onII0?oVF`L0onEH00<0onIL0?oUE`3oiEP01@3oiEP00`3oiET0onIK0?oUF0060?oUF0030?oW
F`3oiEP0onEH00H0onEH00<0onII0?oVF`3oiEP01`3oiEP00`3oiU/0onEH0?oUF0060?oUF080onEI
00<0onEG0?oUF03oiEP01@3oiEP00`3oiET0onMK0?oUF0080?oUF080onII00<0onIH0?oUF03oiEP0
1P3oiEP00`3oiUT0onIK0?oUFP0:0?oUF00?0?oVG03oie/0onIH0?oUF03oi5H0on=E0?oRE03ohE40
omm?0?oMC@3og4/0omY90?oJB03of4L0omU800/0omY800/0om]90?oHB03of4P0omQ90?oJB@3oe4L0
omI70?oJB03oedP0omU90?oIB0030?oHB0050?oJB03ofdT0omU90?oFA`3of4P00P3ofDP80?oHB00<
0?oKB@3ohD/0oli40;66;@1@<Q409AP800810@1GAQL0^Ilc0>S=@P3oidX0onQ:0`3ohdT01P3ohdX0
onA:0?oSB@3ohdT0onA90?oTBP<0on=900D0onA90?oOB03ohTT0on990?oTB@0?0?oSB@050?oTBP3o
hdT0on580?oRB@3ohdT00P3ohTT00`3oi4X0on=90?oSB@040?oSB@030?oTBP3ohdT0on=900D0on=9
00<0onA:0?oSB@3ohdT00P3oi4T01P3ogTL0omY40?oKA`3oi4X0on990?oTB@@0on=90`3oi4T00`3o
hdT0onA:0?oSB@080?oSB@0@0?oTBP3ohdT0on=90?oUBP3oi4X0on180?oTBP3ohTT0on590?oSB@3o
hTT0on=90?oTB@3ohdT0onA90?oSB@80onA91`3ohdT0103oiDT0on110?oSG@3ojK7o0?ooon@0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWB@3oool<00000003
06E5B03oool0oooo0080oooo00D0P82000000000000000000?7>d@060?ooo`040?noaP0000000000
000000@0oooo00@0IDE8000000000000bH^@1`3oool01@39Ri000000000000000000oko600@0oooo
00@0oko600000000000000001@3oool3000000030>:LXP3oool0oooo00@0oooo00@0oko600000000
00000000103oool3000000030?o@f03oool0oooo00@0oooo00D0onS/00000000000000000820P003
0?ooo`<0000000<0om3H0?ooo`3oool0103oool0103od=P000000000000000040?ooo`<0000000<0
OUMJ0?ooo`3oool01P3oool0103o_lH000000000000000050?ooo`<0000000<0hYbR0?ooo`3oool0
103oool0103o_lH000000000000000040?ooo`0406E5B0000000000006E6B0L0oooo00D0i<G80000
000000000000081PH`0c0?ooo`070?o^j@3oUdd0ojm:0?nhCP3o]Dl0okE@0?nfD@0F0?nfD0<0okE>
00L0okI?0?neCP3o]U00okE>0?nfC`3o]Dh0okEA00h0okE>00@0oja90?nWA`3o/4/0okY@0`3o^Dl0
0`3o^E00okU?0?niC`020?niC`030?nkC`3o^Dl0okU?00L0okU?00<0okU@0?niC`3o^Dl01`3o^Dl0
103o^4l0okY>0?niC`3o^Th?0?niC`060?niD03o^Dl0okQ?0?njCP3o^Dl0okQ=103o^4l00`3o^500
okQ?0?nhD0040?nhC`040?nmDP3oaUH0ojE607e27@80000000D04@T30<Qc;03obTd0omEA0?o9C00C
0?o7C080olQ=2@3oad`20?o7B`080?o6B`3oadd0olQ>0?o:E@3obU<0olaF0?o=FP3ocU/:0?o=F@03
0?o<F03ocUd0olaH00P0oleI00<0olaH0?o>G03ocE/00`3ocET00`3o_d/0okY50?o6DP020?o=F@80
olaH00<0oliL0?o=F@3ocET01P3ocET20?o>FP030?o<F03ocET0oleI00D0oleI00<0oleJ0?o?GP3o
cET0203ocET00`3oc5P0oleI0?o=F@040?o=F@050?nnD`0J3`H00000081A7`3ojUT01@3oiEP20?oU
E`030?oVF@3oiEP0onEH00@0onEH00<0onEG0?oVFP3oiEL01P3oiEP00`3oiEX0onEG0?oUF0060?oU
F0030?oUE03oiEH0onEH00D0onEH00<0onEG0?oVE`3oiEP01@3oiEP00`3oiEH0onQU0?oVGP060?oU
F0030?oUE`3oifT0onEI00H0onEH00<0onIJ0?oWG@3oiEP01@3oiEP00`3oiEL0onMM0?oUE`060?oU
F0030?oUF@3oiEL0onEH00L0onEH00<0onML0?oUF03oiEP01`3oiEP00`3oiET0onEH0?oUF0060?oU
F0030?oUE`3oiEP0onEH00H0onEH00<0onEG0?oUF03oiEP0203oiEP00`3oiUd0onIH0?oUF0080?oU
F0030?oVF@3oiEL0onEH00L0onEH00<0onEG0?oUF`3oiUP0103oiEP02P3oiET0onII0?oVF@3oiUT0
on=F0?oQD`3oh500omi>0?oLB`3ofTT20?oHA`040?oIA`3ofDP0omU80?oKB@@0omY800<0omU70?oL
B@3ofdP01P3ofTP0203ofdP0omY80?oFA`3oedL0om]90?oFA`3ofDP0omY82@3of4P01P3ofdP0omQ8
0?oJB03of4P0omM70?oHA`L0omQ801H0omU80?oJB03of4P0omU90?oNBP3oiTd0ol0o0<Un:@0S5PP0
000001<>101WDa/0i/Q00?o^C03oi4T0on=90?oTBP3ohdT0onA:0?oTB@3ohDT0onA:103ohdT00`3o
i4T0on=90?oPB0020?oPB0030?oUB@3ohdT0on=900h0on=900L0onA90?oSB@3oh4P0on980?oPB03o
hdT0onA900@0on=900<0onA:0?oSB@3ohdT02P3ohdT02`3oh4P0omi60?oOA`3ohdT0on580?oRB03o
h4P0on=90?oTB@3ohdT0onA900<0on=900<0onA90?oSB@3ohdT02P3ohdT00`3oi4T0on=90?oSB@02
0?oSB@050?oTBP3ohDP0omm80?oVBP3ogdP00P3oi4T00`3oi4X0on=90?oSB@060?oSB@040?oVA`3o
edX0on>M0?ofl_l0ooooi@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinM90?ooo``0000000<0IDE80?ooo`3oool00P3oool01@20P8000000000000000000f;bo
00H0oooo00@0hYbR0000000000000000103oool0102`NGh000000000001nEeX70?ooo`0507iGFP00
000000000000003o_lH0103oool0103o_lH000000000000000050?ooo`<0000000<0/7Un0?ooo`3o
ool0103oool0103RW:8000000000000000040?ooo`0406E5B000000000000>:LXPH0oooo00D0o]KJ
00000000000000000;:RY0030?ooo`0403<S9000000000000>:LXPH0oooo00@0o:fd000000000000
IDE8103oool4000000030?oco03oool0oooo00D0oooo00@0oko600000000000000001@3oool30000
00030;1iOP3oool0oooo00@0oooo00@0hYbR0000000000000000103oool0102`NGh000000000000o
;2d70?ooo`050;n[[@000000000000000020H6<0=03oool0103oin80oj9Y0?nX@P3o]TlH0?nfD0<0
okE>00<0okI?0?neCP3o]Dh02`3o]Dh00`3o]E00okE>0?neCP040?neCP040?n/B@3oYdL0ok1;0?nj
D0@0okU?00<0okY?0?nhC`3o^Dl00`3o^Dl00`3o^E00okU?0?niC`0>0?niC`030?njC`3o^Dl0okU?
0080okU?00<0okU@0?niC`3o^Dl03@3o^Dl0103o^Th0okU?0?niC`3o^5090?nhC`0<0?nhD03o^4l0
okiB0?nYB@2ZFRL0@R<?000000081040UEDP0?nI>P3oc4h0olY=5@3oad`20?o8C@T0olM<00<0olQ=
0?o6C03oad`00P3oad`00`3oaTX0olM<0?o7CP020?o9D0030?o;E03oc5L0olaH0080oleJ103ocET0
0`3ocUd0oleG0?o=F`080?o=F@030?o<F03ocE`0oliM0080oleI00@0oliJ0?o:EP3o^dH0ol9>0`3o
cET00`3ocUd0oleI0?o=FP080?o=F@030?o>F`3oc5P0oleI00L0oleI00<0oliL0?o=FP3ocET01P3o
cET00`3oc5P0oliM0?o=FP060?o=F@050;F8?00000006@l60?o<CP3ojUT01@3oiEP00`3oiUX0onIL
0?oUF0060?oUF0030?oUE`3oiET0onEH00H0onEH00<0onML0?oUF@3oiEP01@3oiEP00`3oiET0onMO
0?oUE`060?oUF0030?oVG@3oj600onEG00D0onEH00<0onEF0?oXI@3oiUh01`3oiEP00`3oieh0onEI
0?oUF0060?oUF0030?oUF@3oiE/0onEG00D0onEH0P3oiEL70?oUF0030?oUF`3oiUT0onEH00H0onEH
00<0onEI0?oVF@3oiEP01P3oiEP20?oUF@L0onEH00<0onEG0?oXF`3oiET0203oiEP00`3oi5X0onEI
0?oUF0070?oUF0030?oUF@3oiUd0onEH00P0onEH00<0onEI0?oVF03oiEL02@3oiEP20?oVFP0=0?oU
F@3oiUT0onEI0?oRE@3ohE<0on1@0?oMC@3ofd/0omY90?oJA`3of4L0omI70?oKB0050?oIB0030?oL
B@3ofTP0omY800<0omY800<0oma90?oGA`3ofTP00`3ofTP0103ofdP0omM70?oAAP3og4T20?oHB004
0?oJB03of4P0omQ80?oFAP/0omQ800H0omY80?oHB03of4P0omQ80?oEA`3oedL30?oHB0030?oKB@3o
f4P0omQ800@0omQ800D0om]90?oQB`3oiD`0jZ@f03hV3@020000000503X^403?YC@0one<0?oYB`3o
i4X00P3ohdT00`3oi4T0on580?oSB@070?oSB@030?oQB03oi4T0oma701<0on=900@0onA90?oRB03o
hDP0omi70P3oi4T20?oSB@030?oTBP3ohdT0on=900H0on=900l0onA:0?oSB@3ohdT0on=90?oRB03o
gDH0omi60?oSB@3oi4T0on990?oQB03oiTX0omm70?oSB@3oi4T03P3ohdT00`3oi4T0on=90?oSB@06
0?oSB@80onA900D0on990?oTB@3ogTL0on590?oUBP060?oSB@030?oUBP3oge80onBe0?l0ooooi`3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinM90?ooo``00000
00<0IDE80?ooo`3oool00P3oool01@20P8000000000000000000S8:700H0oooo00@0/7Un00000000
0000Bc@f103oool01@3l[K@00000000000000000oo?l00D0oooo00<0oo?l0000000000000P000000
0`3o_lH0oooo0?ooo`020?ooo`040?noaP0000000000000000D0oooo0`0000000`0I4A80ooWn0?oo
o`040?ooo`040;1iOP000000000004/d=P@0oooo00@0bH^@000000000000OUMJ1P3oool01@3H_;l0
0000000000000000i<G800<0oooo00@0IDI8000000000000OUMJ1P3oool0102`NGh0000000000039
Ri040?ooo`@0000000<0/7Un0?ooo`3oool01@3oool0103o_lH000000000000000050?ooo`<00000
00<06A4B0?oco03oool0103oool0102`NGh000000000000V6Q/40?ooo`050?b]]000000000000000
003olo`01P3oool01@20NWh00000000000000000P61S03D0oooo00<0oo?f0?oNbP3oZdd0603o]U00
0`3o]Dh0okI@0?neCP0E0?neCP040?n/B@3oYdL0ok1;0?njD080okU?00<0oka?0?niC`3o^Dl01@3o
^Dl00`3o^E00okU?0?niC`0=0?niC`030?njCP3o^Dl0okU?0180okU?00D0okY?0?niC`3o^Dl0okU?
0?nhD0090?nhC`040?nhD03o_580eH<g034I2P80000000D0CBdA0?nQ?P3oa4/0olm?0?o9C@0@0?o7
C0030?o8C@3oad`0olM<0080olM<00D0olQ=0?o7C03ob4d0olM<0?o6C0050?o7C0030?o6C03oad`0
olM<00<0olM<00@0olQ=0?o7C03oad`0olM<0P3oaT/02P3oad`0olQ=0?o7CP3obDl0olYB0?o;E@3o
c5P0oleI0?o?GP3ocE`:0?o=F@030?o=F03ocE`0oleJ00<0oleI00L0ol5=0?nlA`3obUH0oliJ0?o=
F@3ocU/0olaH00T0oleI00<0oliL0?o=F@3ocET01`3ocET00`3oc5H0oleG0?o<F0070?o=F@80oliJ
1P3ocET01@3ofV00JC/J0000003KRSD0oniK00H0onEH00<0onEF0?oTFP3oiEP01@3oiEP00`3oiEL0
onIM0?oUF@0?0?oUF0030?oUF@3oj6<0onEG00H0onEH00<0onIO0?oWH`3oiEL01@3oiEP00`3oiEH0
onQU0?oVGP070?oUF0030?oTE@3oiEP0onEH00H0onEH00@0onIF0?oVF`3oiUX0onEG103oiEP00`3o
iUX0onMM0?oUE`060?oUF0030?oWGP3oieX0onEH00L0onEH00<0onML0?oUF03oiEP01`3oiEP00`3o
iEL0onEH0?oUF0050?oUF0030?oVF@3oie`0onEI00P0onEH00<0onIK0?oUE`3oiEP01P3oiEP0103o
iEL0onEH0?oWG03oiET80?oUF0030?oTFP3oiE/0onEI00P0onEH00D0onII0?oSD`3ohU80on1>0?oM
B`020?oJB@030?oIB03ofDL0omY700<0omU80`3of4P40?oIB0030?oKB@3ofTP0omY800@0omY800/0
omQ80?oJB03ofTP0om]90?oHB03oedL0omY80?oGA`3ofdP0om]90?oJB0040?oHB0030?oKB@3oedL0
omU800P0omQ800<0omY80?oHB03of4P00P3of4P20?oEA`030?oJB@3of4P0omY800P0omQ800X0omY8
0?oQB`3obD<0gh`]03PS30000000514505525@3FZcL0onQ;103ohdT00`3oh4L0onA90?oSB@060?oS
B@040?oTB@3ohDT0on180?oQB180on=900D0onA90?oSB@3ohDT0on=80?oOB0020?oSB@80onA:2`3o
hdT00`3ohTP0ome60?oNAP030?oSB@80onA900@0on990?oRB03ofdH0onI:3@3ohdT00`3oi4T0on=9
0?oSB@070?oSB@80onA900H0on=90?oQB@3ohdT0on180?oQB@3oi4X30?oSB@030?oUB@3og3l0onF_
0?l0ooooj03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinM9
0?ooo`<0000000<0bH^@0?ooo`3oool02`3oool01P20P8000000000000000000<b<T0>C5b0<0oooo
00<0ooWn0<^^]00=2@T00P0000000`2`NWh0oooo0?ooo`030?ooo`0503l/;@000000000005Pm?`3b
h^@00`3oool00`3bh^@0F3do00000003000000030?noaP3oool0oooo0080oooo00@0oko600000000
000000001@3oool4000000070:F6R03oool0oooo0?ooo`3oo?l0bjjd00d92@02000000030;1jOP3o
ool0oooo0080oooo00H0ooWn06E6B000000000000:EjOP3onOh40?ooo`0506IGFP000000000003l/
;@3on?X00`3oool01@2bX:<00000000000000000d[Zn00@0oooo00D0_jF[00d92@00000081HG0?o`
m@040?ooo`<0000000@03@T90000001aCU40l]_O0P3oool0103onOh0oooo0?ooo`3o_lH3000000D0
oooo100000000`1UATP0l^;T0?ooo`020?ooo`050>GDf@0=2@T000000000001H?Cl01@3oool01@1n
EeX000000000001H?Cl0i<G800@0oooo00<0i<G802`O800000000P0000000`20H6<0oooo0?ooo`0e
0?ooo`040?oUe@3o_W`0oje<0?ndCQ<0okI@00<0okI?0?nfD@3o]Dl00P3o]Dh00`3o]Tl0okE>0?ne
CP050?neCP80okI?2`3o]Dh01@3oZdT0ojM70?n`B`3o^e00okY?0080okU?00<0okU@0?niC`3o^Dl0
103o^Dl00`3o^E00okU?0?niC`040?niC`030?niD03o^Dl0okU?00/0okU?00<0okU@0?niC`3o^Dl0
2@3o^Dl00`3o^Tl0okU?0?njC`020?niD0<0okU?00<0okQ@0?nhC`3o^4l00`3o^4l03@3o^E00ok]A
0?nfCP3NScd0S5`W05P^500?20@0A2H?08QI8P37SSH0ol590?o:C@3obDh01`3oad`0103ob4d0olM<
0?o8C@3oadd=0?o7C080olQ=1@3oad`00`3oaT`0olQ<0?o7C0050?o7C0030?o8C@3oad`0olM<00P0
olM<0P3oadd02@3ob4h0olU@0?o9D03obE80olYB0?o;E03obeD0olaF0?o<F0020?o=F@030?o=FP3o
cU/0oliK00@0oleI00L0ol9=0?njA@3oa4l0oliJ0?o=F@3ocUd0oleJ00P0oleI00<0oleJ0?o>FP3o
cET0203ocET00`3ocU/0oliJ0?o=F@070?o=F@80oleJ1@3ocET01@3oceX0omAM0<9l=P0C30D0]H0a
00L0onEH00<0onIJ0?oVF`3oiEP01P3oiEP00`3oiUT0onMK0?oUF0070?oUF0030?oWG03oiEP0onEH
00H0onEH00<0onEG0?oUF03oiEP01@3oiEP00`3oiU`0onMN0?oUE`050?oUF0030?oUEP3oj6D0onIN
00L0onEH00<0onAE0?oUF03oiEP01P3oiEP01@3oiU/0onEH0?oUF@3oiET0onII00<0onEH00<0onIJ
0?oWF`3oiEL01P3oiEP00`3oiEL0onMM0?oUF@070?oUF0030?oUF@3oiUT0onEH00H0onEH00<0onIH
0?oUF@3oiET01`3oiEP00`3oiEL0onIK0?oUF00C0?oUF0030?oVF@3oiEP0onEH00D0onEH0140onEI
0?oUF03oiEP0onEG0?oUF03oi5D0on=D0?oSD`3ohE40omm?0?oNC03ogD/0ome:0?oLB@3ofdT0omQ8
0?oKB@0:0?oIB0030?oIB@3ofDP0omU80080omU800<0omY80?oKB@3ofTP00P3ofTP01`3ofdT0omU8
0?oGA`3ofTT0omM70?oIB03og4T0103ofTP00`3ofTT0omQ80?oIB0050?oHB0030?oIB03oedP0omQ8
00L0omQ800@0omU80?oJB@3of4P0omY9303of4P04P3ofdT0omQ80?oIB03og4T0om]90?oFA`34Uc80
JD<F01hC1P091`80Bc`D0:VC;`3[bT40omi80?oVBP3ohdT0on590?oRB@X0on=900@0on590?oQB03o
hdT0onA:4`3ohdT0103ohDP0on=90?oQB@3ohdX;0?oSB@030?oRB03ogDH0omi60080onA91P3ohdT0
103oi4T0on590?oSB@3oh4P;0?oSB@030?oTB@3ohdT0on=900@0on=90P3oi4T50?oSB@080?oTBP3o
i4T0on990?oPB03ohdT0omaG0?oIP`3okLWo0?ooonT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWB@3oool3000000030<V;T03oool0oooo00/0oooo00X0P820
000000000000000005Pm?`0000006A4B09MXK02`NWh0<R<T0`0000000`0I4A80oo?l0?ooo`040?oo
o`050:FJV`00000000000000000V6Q/00`39Ri00100V6Q/0000006E5B01UADP2000000030?noaP3o
ool0oooo0080oooo00@0oko600000000000000001@3oool3000000060;1iOP0000006A4B09MXK039
Ri00IDI80`0000000`0=2@T0oo?l0?ooo`040?ooo`090?oco00V6Q/000000000000I4A80i:F[0?no
aP3RW:80<R<T0080000000<06A4B0?oQjP3oool00`3oool01P3onOh0Bc@f0000000000003@T90<V;
T080oko600D0RV1S000000000000000008aiOP050?ooo`<0000000<0bH^@0000000000000`000000
103o_lH0oooo0?ooo`3o_lH3000000D0oooo0`0000001`2`NGh0000000d92@2GJ6`0bH^@09MXK00I
4Q800`0000000`2<PXL0oooo0?ooo`040?ooo`0504/d=P00000000000000001;=3H00P39Ri00101;
=3H0000003<S901UADP200000003081PH`3oool0oooo03L0oooo00@0on7>0?ndM`3o/TX0okQA3P3o
]U000`3o]Tl0okE>0?nfD0020?nfD0/0okE>00<0okI?0?nfD03o]Dh00P3o]Dh00`3o]E00okE>0?ne
D0040?neCP050?ndCP3oXTH0ojM70?naB`3o^U002P3o^Dl00`3o^E00okU?0?niC`070?niC`030?nj
C`3o^Dl0okU?0180okU?00<0okQ?0?njCP3o^Dl01`3o^Dl02@3o^500okQ?0?nhC`3o^4l0okU@0?o1
D`3o_E40oie306/h60020000000402PF2035NBl0olm@0?o:C`D0olM<00<0olQ=0?o7C03oad`00`3o
ad`00`3ob4d0olM<0?o7C00;0?o7C0050?o8C@3oad`0olM<0?o7C@3ob4d00P3oaT`;0?o7C0030?o8
C@3oad`0olM<00T0olM<00<0olI<0?o7C03oad`01@3oad`0203oadd0olM<0?o8C@3ob4h0olUD0?o;
E03oc5H0oleG0P3oc5P01P3o`Th0okY50?nmB03oc5P0oleI0?o?GPT0oleI00<0oleJ0?o=F@3ocEL0
1`3ocET00`3oc5P0oleJ0?o>G0080?o=F@030?o=G03ocUh0olaH00D0oleI00H0omYP0>V5>P0D2`@0
I3lI0?oTF03oiUP60?oUF0030?oUF`3oiEP0onEH00D0onEH00<0onEG0?oUF03oiUX0203oiEP00`3o
iEH0onEH0?oUF0050?oUF0030?oWGP3oiEP0onEH00H0onEH00<0onEG0?oUEP3oiEP01@3oiEP00`3o
iEH0onMR0?oVGP070?oUF080onEG1`3oiEP01`3oif80onEG0?oUF03oiEP0onEI0?oTFP3oiEL02`3o
iEP00`3oiUT0onEH0?oUF00@0?oUF0030?oWG03oiET0onEH00P0onEH00<0onIJ0?oUF03oiEP01P3o
iEP20?oVF@030?oUE`3oiEP0onEH00H0onEH00T0onEI0?oVF@3oiEP0onII0?oUF03oi5L0onAF0?oS
EP3oheD00P3ogdl00`3ogT`0om]90?oJA`0:0?oKB0030?oIB@3ofdP0omU800T0omU800/0omY80?oI
A`3ofDL0omQ80?oJB03of4P0omM70?oKB03oeDL0omU70?oKB0030?oJB0040?oKB03of4P0omU80?oK
B080omY800<0omY90?oHB03ofTP01`3of4P02@3oeTL0omI80?oHB03of4P0omY80?oHB03ofDP0omQ8
0?oKB@070?oHB0030?oGA`3oeTH0omQ800`0omQ800@0on1:0?oHB03<ObX0:1T80P0000001@0n<Q00
gk<j0?o^C03ojT/0on5900P0on=900P0onA:0?oSB@3ohdT0on=90?oTBP3ogdL0on990?oQB1D0on=9
00<0omi70?oTB@3oh4P0203ohdT00`3ohTP0ome60?oNAP090?oSB@070?oTB@3ohdT0on=90?oUB@3o
gdP0onA90?oPB0020?oTB@D0on=900<0onA:0?oSB@3ohdT00`3ohdT00`3oi4T0on=90?oSB@050?oS
B@060?oTBP3ohdT0onI80?oO?@3og780ooWko`3oooo[0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWidT0oooo0`0000000`39Ri00oooo0?ooo`0;0?ooo`050820
P000000000000000002UU9T0200000000`3l[K@0oooo0?ooo`040?ooo`030?oXk00I4A80000000H0
000000<06A4B0?oco01UADP00P0000000`3o_lH0oooo0?ooo`020?ooo`040?noaP00000000000000
00D0oooo0`0000000`3olo`09QXK000000060000000307iGFP3oool0oooo00D0oooo00<0S75e0000
000000001`0000000`3RW:80oooo0?ooo`040?ooo`030?o@f00I4A80000000P0000000<0lLkA0?oo
o`3oool00`3oool3000000030?ooo`1;=3H0000000<0000000@0oko60?ooo`3oool0oko60`000005
0?ooo`<0000000<0oo?l04/d=P0000001`0000000`3ne]X0oooo0?ooo`040?ooo`030?o@f00=2@T0
000000H0000000D0S8:706E5B00000000000081PH`0j0?ooo`030?o]jP3o_X00ok5900`0okI@0P3o
]Dh50?nfD0/0okE>00<0okI?0?nfD03o]Dh01P3o]Dh0203o]E00okE>0?neCP3o]Dl0ojY80?nWA`3o
/D/0okY@2P3o^Dl00`3o^E00okU?0?niC`060?niC`030?njC`3o^Dl0okU?0180okU?00<0okY>0?ni
C`3o^Dl0203o^Dl03`3o^500okQ?0?nhC`3o^Dl0ol5D0?nG@@2cGbP08a870000000^6`T0TU<Q0?nR
?`3od500olQ=0?o9CP080?o7C080olQ=0`3oad`00`3ob4h0olM<0?o7C00:0?o7C0040?o7CP3oad`0
olM>0?o7C@`0olM<0P3ob4d>0?o7C0030?o8C@3oad`0olM<0080olM<00@0olM=0?o7C03oad`0olI<
0P3oaT/20?o7C00:0?o8C`3oaDh0okY50?njA@3o`4`0oleI0?o?GP3ocEX0oleI0?o=FPL0oleI00<0
oleJ0?o=E`3ocET01P3ocET00`3oc5P0oleJ0?o>GP090?o=F@030?o>G03oc5P0oleI00@0oleI00H0
om5L0?neCP16:14000000:V7=03ok5X60?oUF0030?oUF@3oiEL0onEH00H0onEH00<0onAJ0?oVF`3o
iEL01P3oiEP00`3oiEL0onMN0?oVFP070?oUF0030?oVG@3oiEP0onEH00H0onEH00<0onAE0?oUF03o
iEP01@3oiEP00`3oiEH0onQU0?oVGP080?oUF0030?oUE`3oiEP0onEH00D0onEH00<0onQM0?oUE`3o
iEP00P3oiEP01`3oie`0onEI0?oUE`3oiEP0onQR0?oVG`3oiEL01P3oiEP00`3oiEL0onMO0?oUF@07
0?oUF0030?oVG03oiEH0onEH00H0onEH00<0onEG0?oUF03oiEP0203oiEP20?oUE`L0onEH00<0onEG
0?oVFP3oiU/00`3oiEP01`3oiET0onII0?oVF@3oiUT0onEH0?oTE`3ohe400P3ohU801@3oh4l0ome=
0?oMBP3ofdX0om]80080omY700<0om]70?oLB@3ofdP02`3ofdP00`3ofTT0om]80?oJB0090?oIB008
0?oLB@3of4P0omM70?oJB@3ofDL0om=60?oJB03ofdP60?oJB0030?oKB03ofDP0omQ80080omY800<0
omY90?oHB03of4P01`3of4P01@3ofTP0omQ80?oIB03ofTP0om]900d0omQ800<0omI70?oHB03ofDT0
103of4P00`3ofTP0omQ80?oHB0040?oHB0040?oJB03ojDd0iZdj05Pg4P80000000H08a`90;>?;P3o
d480ooE?0?oVBP3oi4T60?oSB@030?oTBP3ohdT0onA:00<0on=900D0onE90?oMA`3ohdT0on=90?oT
B@0A0?oSB@070?oTBP3oi4T0on980?oLA`3ohTT0on590?oTB@050?oSB@030?oRB03ogDH0ome600T0
on=900/0onA:0?oSB@3ohdT0on=90?oTB@3ohdT0oma80?oVBP3oh4T0onA:0?oTB@070?oSB@030?oT
B@3ohdT0on=900L0on=900D0onA:0?oU@P3ogDT0ommj0?odj@3o0?ooon`0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWB@3oool3000000030<V;T03oool0oooo
00/0oooo00H0P61S0000000000006A4B0?oioP1;=3H60000000307iGFP3oool0oooo00H0oooo00<0
om3H04/d=P00000010000000100V6Q/0om3H0?ooo`1nEeX2000000030<V;T03oool0oooo0080oooo
00@0oko60000000000000000103oool01P3o_lH000000000000I4A80oooo0:FDV@H0000000<06A4B
0?7>d@3oool01P3oool00`3onOh0IDE8000000050000000300d92@3o_lH0oooo00L0oooo00<0oo?l
06E5B00000001@0000000`0I4A80oko60?ooo`040?ooo`070?noaP000000000000d92@3oool0oo?l
06E5B003000000040?noaP3oool0oooo0?noaP<00000103oool01`3o_lH000000000000I4A80oooo
0?oco00V6Q/01@0000000`0I4A80hYbR0?ooo`070?ooo`030:F2Q`000000000000@0000000<0Bc@f
0?oXk01nEeX00P0000000`1UATP0oooo0?ooo`0i0?ooo`040?o/h@3oXUH0ojY30?neCPH0okI@00<0
okE>0?ndCP3o]U00203o]U020?neCP030?nfD03o]Dh0okE>00H0okE>00D0okI?0?nfD03o]Dh0okE>
0?neC`020?neCP030?nfD03o]Dh0okE@0080okE>00D0okE?0?nYB03oYdL0ok5;0?njD0020?niC`03
0?niD03o^Dl0okU?00D0okU?00<0okU@0?niC`3o^Dl00P3o^Dl0103o^Tl0okU?0?njCP3o^4lB0?ni
C`030?njCP3o^Dl0ok]?00H0okU?00<0okQ@0?niC`3o^Dl00P3o^Dl01P3o^500okQ?0?o1D`3oaED0
dgPd02lH2P80000000@0IcXF0?nQ?P3ode40om1@0P3ob4d00`3obDh0olM<0?o7C00;0?o7C0030?o8
CP3oad`0olM<00T0olM<00D0olQ<0?o7C@3oad`0olM=0?o8C@0=0?o7C0030?o8C@3oad`0olM<00H0
olM<00<0olI<0?o7C03oad`00P3oad`20?o8C@@0olM<00<0olM=0?o7C03oad`01@3oad`0303oaT/0
olA:0?nkAP3o^dH0ol9;0?o9D@3obE80olYB0?o:D`3oc5H0ol]G0?o=F@@0oleJ00<0olaH0?o>F`3o
cET0203ocET00`3ocU`0oleI0?o=F@070?o=F@030?o>F`3ocU`0oleI00D0oleI00D0om1J0:5L:@00
00007a<70?o?D0070?oUF0030?oVFP3oiEP0onEH00H0onEH00<0onEI0?oVGP3oiEL01P3oiEP00`3o
iEL0onIM0?oVF@070?oUF0030?oUE`3oiEP0onEH00H0onEH00<0onEI0?oUF03oiEP01@3oiEP00`3o
iEH0onQU0?oVGP080?oUF0030?oUEP3oiEP0onEH00D0onEH00<0onEF0?oUF03oiEP00`3oiEP01P3o
iE/0onIH0?oUE`3oiUX0onEI0?oUE`H0onEH00<0onEG0?oVGP3oiEP0203oiEP00`3oie`0onEG0?oU
F0050?oUF0030?oUE`3oiE/0onMJ00P0onEH00<0onIK0?oUF`3oiEL01P3oiEP04@3oiET0onEH0?oW
G03oiUX0onIH0?oTE`3oi5D0on=C0?oPD03ogdl0omm=0?oNC03og4T0omY90?oJA`3ofdL0omY70080
om]800<0oma90?oKB03ofdP00P3ofdP00`3og4T0omU90?oIA`080?oKB0040?oJB03og4T0om]90?oG
A`L0omU800H0om]80?oIB03oe4H0omU90?oKB03of4P20?oKB0T0omY800H0om]90?oHB03oeDL0om]9
0?oJB@3of4P20?oIB@@0omQ800D0omY90?oHB03of4P0om]90?oGB0020?oIA`@0omQ800<0omU90?oH
B03of4P02P3of4P0103ofDP0omQ80?oHB03ofTP80?oHB00;0?oTC03od4D0eHD/064n500610400000
04/k4`2WQR/0onA:0?oZB`3ohTP0303ohdT01P3oi4T0on990?oRB03ohTP0on580?oTB@T0on=900<0
onA:0?oSB@3ohdT00`3ohdT02@3oi4X0on=90?oSB@3oi4T0on590?oRB03oh4P0on580?oTB@030?oS
B@030?oRB03ogDH0ome600`0on=900X0onA90?oSB@3ohdT0onA90?oSB@3oh4P0on990?oNB03ohdX0
onA90P3ohdT00`3ohdX0onA90?oSB@0:0?oSB@040?oS@@3ogV40ombK0?okn_l0ooook@3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinM90?ooo`<0000000<0bH^@
0?ooo`3oool04@3oool01`3ac]40_j^]08f9R@2ITI80/Z:T0>C5b03oo?l02P3oool01P3ac]40YYZK
0820P020P800YIZK0?;Ri1P0oooo00L0lLkA0;n[[@2ITI80SHV90;:RY03TaLP0ooWn00X0oooo00L0
omoS0<^d]P2CSHh0P82008b8R@2bXZ@0l]oS00/0oooo00L0iL[=0:FJV`20P800P82009nEU`3TaLP0
ooWn00d0oooo00@0iLG80:FJV`20P800omoS403oool01`3hinP0_j^]09VATP20P800YYZK0>C5b03o
nOh02P3oool01P3ac]40_j^]08b8R@20P800YIZK0>C5b480oooo00@0oo3/0?oOb@3o`8@0ojm>0P3o
]Dl00`3o]U00okI?0?nfD00;0?nfD0/0okE>00<0okI?0?nfD03o]Dh02@3o]Dh01@3o]4h0ojU80?nW
A`3o/D/0okY@00X0okU?00@0okU@0?niC`3o^Dl0okY?503o^Dl00`3o^U00okY?0?niC`0=0?niC`0;
0?njD03o]Tl0aHPj09QJ9P1<:A405@/505Xc4`2BGB<0eiHj0?o3C03ocU00103ob4d00`3obDh0olM<
0?o7C0030?o7C080olQ=1P3oad`01P3ob4h0olM<0?o7C03ob4d0olM<0?o8C@<0olM=0`3oad`00`3o
b4d0olM<0?o7C0020?o8C@/0olM<00<0olQ=0?o7C03oad`03P3oad`00`3ob4d0olM<0?o7C0020?o7
C0030?o7CP3oadd0olM<00H0olM<00D0olE:0?nkAP3o_DL0ol9:0?o7C0030?o8C080olQ=0P3obDh0
103obDl0olU@0?o:D@3obe<20?o;E@050?o;EP3oc5L0oleH0?o=F03ocET00P3ocEX00`3ocU/0oliJ
0?o=F@070?o=F@030?o>FP3ocU/0oleI00D0oleI00H0olmK0=6F@P0<1`<0:QX:0=FN?03ojeX60?oU
F080onEI1`3oiEP00`3oiET0onIL0?oUE`070?oUF0030?oWG03oiUX0onEH00L0onEH00<0onIK0?oU
F03oiEP01@3oiEP00`3oiUX0onQT0?oUE`060?oUF0030?oUEP3oj6D0onIN00P0onEH00<0onMM0?oU
F03oiEP01@3oiEP00`3oiUP0onEI0?oUF0050?oUF0040?oVF@3oiUP0onMK0?oVFPL0onEH00<0onEG
0?oVF`3oiEP01P3oiEP00`3oiET0onIJ0?oVFP080?oUF0030?oUF@3oiUT0onEH00@0onEH0P3oiET0
3P3oiUT0onEI0?oUF@3oiEH0onAF0?oSE03ohe<0on9C0?oQD@3oh4l0on1>0?oOC@3ogT`0ome:0`3o
g4T;0?oKB080oma91@3ofdP20?oJB0L0om]800<0omY80?oIB03ofTP00`3ofTP02@3ofDP0om]90?oH
B03ofTT0omQ80?oFA`3ofdT0omQ80?oIB0020?oJB0030?oFA`3of4P0om]800T0omY800<0om]80?oI
B03of4P00P3ofDP20?oJB@050?oIB03ofdT0omQ80?oHB03ofDP00`3of4P0203ofDP0omQ80?oHB03o
edP0omU90?oIB03of4P0omU82@3of4P0203ofDP0omQ80?oJB@3oedP0omM70?oIB03of4P0omY9203o
f4P0303ofdT0on5;0?oEA`3NZSP0PE<K044Z3@000000>Bh?09f4:`3>^3/0on990?oTBP<0on=900<0
onA:0?oSB@3ohdT01`3ohdT01P3ohTT0onA90?oSB@3ohDP0onA:0?oTBA00on=90P3oi4T01`3ohTT0
on=90?oQB@3oi4T0on180?oSB@3ohTT00P3ogDH90?oSB@040?oTBP3ohdT0on=90?oTBP@0on=900T0
onA90?oRB@3ohTT0onA90?oQB03oi4T0on580?oTB@3oi4X01`3ohdT20?oTB@040?oSAP3oh5@0onJM
0?ohl?l0ooook`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inM90?ooo`<0000000<0bH^@0?ooo`3oool0i`3oool0103o`j00ojY50?naB`3o]Dh<0?nfD0030?nf
C`3o]Dh0okE>00T0okE>00<0okI?0?neD03o]Dh02@3o]Dh01`3o]Dl0ojM70?nXB03o/d`0okY@0?ni
C`3o^E001`3o^Dl00`3o^E00ok]A0?niC`030?niC`030?niD03o^Dl0okU?01/0okU?00<0okQ@0?ni
C`3o^U000P3o^e402@3oXD@0EbhC0000000000006Pl50=Z9=03ob4d0olm@0?o9CP060?o8C@050?o9
CP3oad`0olM<0?o7C03ob4d01@3oad`01@3ob4d0olM<0?o7C03oad`0olQ>0080olM<00H0olQ=0?o7
C03oad`0olQ=0?o7C@3ob4d60?o7C080olQ=00<0olI<0?o7C03oad`0403oad`00`3oaT`0olM<0?o7
C0040?o7C0030?o8C@3oad`0olQ=00<0olM<00<0olI<0?o7C@3oad`01`3oad`01@3oaDX0oki70?nj
A@3o`TX0olQ<00X0olM<0`3ob4/0103oad`0olI<0?o7C@3oadd20?o7CP050?o9D@3obU80olYC0?o;
E@3obeL01@3ocET00`3ocEL0oliM0?o=F@060?o=F@050?o<F01N=QP05`h50?FK>`3omUd01P3oiEP0
0`3oiEL0onIJ0?oUF0070?oUF0030?oVF@3oiEP0onEH00L0onEH00<0onEG0?oUF03oiEP01`3oiEP0
0`3oieh0onEH0?oUF0050?oUF0030?oVFP3oj6H0onEF00H0onEH00<0onEF0?oXI@3oiUh0203oiEP0
0`3oif00onEH0?oUF0050?oUF0030?oVFP3oif80onEG00H0onEH00<0onEK0?oVH@3oi5X0203oiEP0
0`3oiEL0onEH0?oUF0060?oUF0030?oTF03oi5L0onEH00P0onEH00X0onEG0?oUF03oiEP0on=F0?oS
D`3ohe40omm?0?oPCP3ogT/0ome;0P3ofdT0103ogDX0oma90?oKB03ofdP50?oLB@030?oGA`3ofdP0
om]800P0om]800D0omY80?oIB03ofdP0om]80?oLB@070?oKB0030?oJB03ofDL0om]800H0om]800L0
omU80?oKB03ofDP0omY80?oIA`3oeDL0om]800P0omU80P3ofTP00`3of4P0om]90?oKB@0;0?oJB005
0?oIB03oedL0omU70?oKB@3ofDP02P3of4P00`3ofTP0omU90?oGA`020?oHB0030?oIB03of4P0omQ8
00L0omQ800@0omU90?oJB03of4P0omQ80P3oedL<0?oHB00:0?oKB@3ohD/0omA70?n[>@0o:@d00000
00D40@0]90`0e[Tk0?oUB@80on=900<0onA:0?oSB@3ohdT02@3ohdT0103oi4T0on590?oUBP3oh4P7
0?oSB@030?oTBP3ohdT0on=900X0on=900P0onA90?oSB@3ohTT0on=90?oOA`3ogdH0ome60?oOA`/0
on=900<0onA:0?oSB@3ohdT01P3ohdT01P3oi4T0on=90?oRB03oiTX0on5:0?oTB@D0on=900D0onA9
0?oSB@3ohTX0omAg0?omm@3o0?oooo40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWB@3oool3000000030<V;T03oool0oooo0>L0oooo00D0ooOg0?o@]P3oXdd0
ojm<0?neCP0;0?nfD0030?nfC`3o]Dh0okI@00P0okE>00<0okI@0?neC`3o]E000P3o]Dh00`3o]Dl0
okE>0?neCP050?neCP050?neC`3oYdL0ojQ80?ncC03o^U00203o^Dl00`3o^dl0okQ?0?niD00C0?ni
C`030?nhD03o^Tl0okU?00H0okU?00<0okU@0?niC`3o^Dl0103o^Dl02`3o^e40okYA0?nPA02@Bb00
4@P30000000O4@H0[f<U0?ncA@3obTh0olU>0080olQ=0P3obDh40?o8C@030?o9CP3oad`0olQ=00/0
olM<00@0olU>0?o6C03oad`0olQ<2`3oad`20?o8C@@0olM<00<0olI<0?o7C03oad`05@3oad`00`3o
b4d0olM<0?o7C0020?o7C0030?o7C@3oad`0olM<00H0olM<00D0olI<0?njA@3o^dH0ol9:0?o8C00<
0?o7C0030?o8C@3oad`0olI<00P0olI<0P3oaTd01`3oadh0olQ?0?o:D@3obU80olaJ0?o;E`3ocEP0
0`3oc5P20?o=F@060?o@FP3oXTH020@208iK8`3olE`0onMI1@3oiEP00`3oiEL0onIN0?oUF`080?oU
F0030?oVFP3oiEP0onEH00H0onEH00<0onIJ0?oVF@3oiEP01`3oiEP20?oUE`P0onEH00<0onEF0?oU
F03oiEP01@3oiEP00`3oiEH0onQU0?oVGP080?oUF0030?oWH03oiEP0onEH00D0onEH00<0onIK0?oX
H`3oiEH01`3oiEP00`3oiUX0onAE0?oUF0070?oUF0030?oVG03oiEL0onEH00L0onEH00/0onIJ0?oT
FP3oiEL0onEG0?oTE`3oheH0on=D0?oQD@3ohU00on1=0?oNC0020?oMBP030?oKBP3ogDX0oma900@0
oma900<0ome90?oKB03og4T01`3og4T00`3ogDX0oma90?oGA`0:0?oKB0060?oIA`3ofDP0om]80?oK
B03ofdT0oma91@3ofdP00`3ofdT0omQ80?oIA`060?oKB0070?oHB03og4T0omM70?oHA`3ofTP0omQ8
0?oIA`080?oIB0<0omY800<0om]80?oIB03ofTP01P3ofTP01P3ofTT0omY80?oJB03ofTP0omU80?oJ
B080omM700<0omU80?oHB03of4P0203of4P01P3ofTP0omU90?oIB03oddH0omQ80?oIB0T0omQ800<0
omU90?oJB03of4P00`3of4P00`3oedL0omQ80?oHB00:0?oHB00:0?oJB03ogDX0ome90?o4@@1gBQP0
30L20000000^90`0omU50?oWBP80onI:3@3ohdT01@3oi4X0on=90?oRB@3ohDP0onA900T0on=900<0
onA:0?oSB@3ohdT02P3ohdT00`3oeD80omY40?oOA`080?oSB@80onA900<0on=90?oTBP3ohdT02P3o
hdT01@3oi4T0onA:0?oSB03ofDH0onE:0080on=900@0onA90?oSAP3ofe40ong@o`3ooooc0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWidT0oooo0`0000000`39
Ri00oooo0?ooo`3Y0?ooo`040?oLc@3o_8L0oja:0?neCPX0okI@00<0okI?0?neCP3o]Dh01@3o]Dh0
1P3o]Tl0okE>0?ndCP3o]Dh0okE?0?neD0X0okE>00D0okE?0?nWA`3oZ4P0ok=<0?njD00M0?niC`03
0?njCP3o^Dl0okU?00P0okU?00T0okQ@0?niC`3o^Dl0okU?0?nmD@3o`E<0okI=0<ih<`080P400P00
0000101Y>aH0okE60?o<C`3obDh:0?o8C@030?o9CP3oad`0olM<00T0olM<00<0olQ=0?o7C03ob4d0
3P3oad`20?o8CA40olM<00<0olI<0?o7C03oad`0203oad`00`3ob4d0olM<0?o7C0020?o7C0030?o7
C@3oad`0olM<00H0olM<00D0olI<0?nkAP3o^dH0ol9:0?o8C00=0?o7C0D0olI<00<0olI;0?o6C03o
aT`0203oaT`0103oaD`0olI<0?o6C03oaT`20?o7CP0@0?o8C`3obU40olIB04/[4`0N4`L0olM:0?o]
F@3oi5H0onAG0?oUE`3oi5L0onEG0?oUF03oiET0onEF0?oUE`H0onEI2`3oiEP20?oWG`030?oUE`3o
iEP0onEH00D0onEH00<0onEG0?oUF03oiEP01`3oiEP00`3oiEH0onEH0?oUF0050?oUF0030?oUE`3o
ieh0onEK00P0onEH00<0onMN0?oUF03oiEP01@3oiEP00`3oiET0onIH0?oUF0080?oUF0030?oWG03o
iUT0onEH00@0onEI0P3oiEP00`3oiU/0onEG0?oTE`050?oTEP80on5A0P3oh5000`3ogd`0omi:0?oL
B@050?oLB@80ome90P3og4T00`3ogDX0oma90?oLB@0=0?oLB@80ome:00<0oma90?oKB03ofdP0203o
fdP00`3og4T0omU70?oIB0090?oKB0050?oJB@3of4P0om]90?oLB03ofdP00`3ofTP00`3oddH0omU8
0?oIB0020?oIB0030?oKB03ofdT0omU800L0omU8103ofTP00`3ofDP0omM70?oKB0020?oJB0030?oK
B@3ofDP0omY800@0omY800D0omU80?oHB03of4P0omU70?oGB00:0?oHB0060?oJB03ofDT0omQ80?oH
B03ofTT0omM72@3of4P00`3ofDT0omY80?oHB0030?oHB0030?oIB03oeDL0omU900H0omQ800@0omY8
0?oHB03of4P0omU80`3of4P02`3ofdT0oma90?n]>@1eBAP03@P303X`3P36X380e:/g0?WC@`3ok4`0
onE:00/0on=900@0onA:0?oSB@3ohdT0onE:0P3oh4PD0?oSB@060?oRB@3ogDH0omi60?oMAP3ohDP0
on981P3ohdT20?oTB@030?oSB@3oi4T0on=900@0on=900<0onA90?oSB@3ohdT0203ohdT01@3ogdP0
onI70?oPA@3oh5@0onS10?l0oooom03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinM90?ooo`<0000000<0OUMJ0;:RY02bXZ@01`2bXZ@00`3om?H0oooo0?ooo`0X
0?ooo`040>C5b020P800P8200820P4L0oooo00@0i<G80820P020P800P820JP3oool0103ofl00okQ_
0?n_D@3o/TP80?nfD0070?nfC`3o]Dh0okE>0?neCP3o]Dl0okE>0?nfC`050?neCP030?neC`3o]E00
okE>00T0okE>00H0okE?0?nWA`3oZ4P0ok=<0?njD03o^E020?niC`<0okY?2@3o^Dl00`3o^E00okU?
0?niC`050?niC`030?niD03o^Dl0okU?0080okY?203o^Dl00`3o^E00okU?0?niC`020?niC`0;0?nj
D03o_U80ok==0<j6>P26C280DB/B018:101G<A<0W6PX0=BJ>`3oaT`03@3ob4d00`3oad`0olQ=0?o7
C0040?o7C0040?o8C03ob4d0olM<0?o8C@<0olM<00@0olQ>0?o7C03oad`0olQ=203oad`00`3ob4d0
olM<0?o7C0040?o7C0040?o7C@3oad`0olM=0?o7C@@0olM<00<0olQ=0?o7C03oad`03@3oad`00`3o
b4d0olM<0?o7CP040?o7C0030?o7C@3oad`0olM<00H0olM<00D0olE:0?nkAP3o^dH0ol9:0?o8C00=
0?o7C0050?o6C@3oadd0olI<0?o6C03oad`02@3oaT`00`3oad`0olM=0?o7C0050?o6C00A0?o8C@3o
_DP0KShG0000002CKb@0onM<0?oOBP3ogd/0on1;0?oQC03oh4/0on5<0?oQC@3ohTl0on5?0?oQC@3o
hU000P3ohDl01`3ohU00on9A0?oRD@3ohe40on9A0?oSE@3oi5@00P3ohe@00`3oi5D0onAF0?oTEP02
0?oTEP030?oSE03oiEL0onAG00<0onAG00H0onEG0?oUF03oiEP0onEF0?oXH@3oiET70?oUF0030?oV
F03oiEP0onEH00L0onEH00<0onEF0?oUE`3oiEP01`3oiEP00`3oiUl0onAG0?oTE`020?oUE`070?oT
E`3oiEL0onAF0?oTEP3ohe@0onAD0?oTE@040?oSE0070?oSDP3ohU80on=B0?oSEP3ohU40ommA0?oP
C`020?oPCP060?oOCP3ogdd0omm=0?oOC03ofTX0omm;0P3ogTX40?oMB@80oma900<0om]90?oLB@3o
g4T02P3og4T00`3ogDX0ome90?oLB@050?oLB@030?oKB@3ogDT0oma900D0oma900D0ome:0?oLB@3o
fdP0oma90?oKB@090?oKB0030?oLB@3ofTT0omY800H0om]80P3og4P01@3ofTP0om]80?oLBP3ofDP0
oma90080omU700@0oma90?oJB03ofDP0om]90`3ofDP0103ofTT0omU80?oIB03ofTP40?oIB0050?oJ
B03ofTT0omY80?oJB03ofdT00P3ofTT00`3og4T0omY80?oJB0080?oJB0<0omQ800<0omU80?oHB03o
f4P0203of4P00`3ofTP0omY90?oHB0020?oHB0040?oIB03oedL0omM70?oIB0H0omQ800<0omU90?oJ
B03of4P0103of4P01@3ofDP0omM80?oIB@3oedP0omQ80080omU800<0omU90?oJB@3ofTP01@3of4P0
3P3ofDP0omQ80?oKB@3ogDT0gk0j08aK7@0/6PT0000002XR2`21Ib40`ZLf0?7BA03ojT/0onA9203o
hdT00`3oi4X0on=90?oSB@020?oSB@040?oTB@3ohTT0on590?oRB@D0on=900<0onA:0?oSB@3ohdT0
203ohdT02@3oi4X0onA90?oNA`3ogDH0omi60?oTB@3ohDP0onA90?oPB0030?oSB@030?oTB@3ohdT0
onA900D0on=90P3oi4T70?oSB@080?oTB@3ohdT0onA90?oUB03ohTd0omik0?oUX`3olnCo0?ooooD0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWB@3oool=0000
00030?oOh`3oool0oooo02P0oooo00@0bH^@0000000000000000A`3oool01039Ri00000000000000
001/0?ooo`040?oB^P3o_7T0oji60?ndC@P0okI@00<0okA>0?nfD03o]Dl02P3o]Dh00`3o]E00okE>
0?neCP060?neCP080?ncC@3oYdL0ojY90?neC@3o_500okQ?0?njC`3o^4lD0?niC`030?njD03o^Dl0
okU?00<0okU?00<0okU@0?niC`3o^Dl0103o^Dl0203o^E00okU?0?niC`3o^Dl0ol9D0?o2D`3oRC/0
Db/C0P00000010119@d0gH`f0?oEDP3oce090?o8C@060?o9CP3ob4d0olQ=0?o7C03ob4`0olQ=0P3o
ad`0103ob4d0olM<0?o7C03ob4d80?o7C0030?o8C@3oad`0olM<01D0olM<0P3ob4d20?o7C0030?o8
C@3oad`0olM<00h0olM<00<0olQ=0?o7C03oad`00P3oad`00`3oadd0olM<0?o7C0030?o7C080olI<
00H0olM<0?o5C03o^dH0ok]60?o2BP3ob4`;0?o7C0050?o8C@3oad`0olI<0?o6C03oad`02P3oaT`0
103oaD`0olI;0?o7C@3oaTd50?o6C0050?o9CP1b@1P0000001`B1@3odTD0203ogdX0103ogTT0omm:
0?oOBP3oh4/60?oOBP050?oLB@3ogdX0omm90?oOB@3ogTX01@3ogDT00`3ofdL0omi:0?oOBP030?oO
BP050?oOB`3oh4`0on1<0?oPC03oh4T01@3oh4`01@3ohDd0on5>0?oQCP3oh540on5=00D0on5>00D0
on1=0?oQCP3ohDh0on5>0?oPC@080?oPC0040?oOC03ogTX0omi:0?oNB@80omi:00H0ome90?oLB03o
g4P0omY70?oHA`3ogDP40?oLB0@0ome800D0ome90?oLB@3ofDP0oma80?oNB@050?oMB@030?oMB03o
gDT0ome900@0ome90P3og4T00`3ogDT0om]90?oLB@080?oLB@030?oKB03ofTP0oma900P0oma900<0
om]80?oLB@3og4T0103og4T01P3ogDX0om]80?oLB@3ofdP0omY80?oJA`X0om]800<0oma90?oJB03o
fdP00P3ofdP02@3og4P0om]90?oGA`3ofTP0omU70?oGA`3og4X0omY80?oHA`020?oKB0030?oLB@3o
fdT0omU800H0omU800@0omM70?oJB03ofdT0om]90P3ofDP00`3ofTT0om]90?oJB0020?oJB0060?oK
B@3ofTP0omY80?oIB03of4L0om]91`3ofTP50?oHB0030?oJB03oedL0omY900H0omQ800<0omY80?oJ
B@3of4P01@3of4P00`3oedL0omQ80?oJB00:0?oHB080omU900T0omQ80?oIB@3ofDP0omM90?oHB03o
edL0omQ80?oKB@3ofTP01@3of4P02@3ofDT0omQ80?oHB03of4P0omU80?o/CP3oa400agdY02dL2P02
0000000601hH202]Rbd0oo1=0?o`C@3ohdT0onA:3P3ohdT01P3ohDP0on990?oPB03oi4T0on=90?oT
BP/0on=900@0onA90?oNA`3ogDH0omi60`3ohdT01`3oi4T0on980?oRB03ohTP0omm80?oTB@3ohdX0
0`3ohdT20?oTB@X0on=900@0onA90?oT@03ofeD0onVgo`3ooooh0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWidT0oooo3@0000000`3ogn<0oooo0?ooo`0X0?oo
o`040<V;T00000000000000004L0oooo00@0bH^@0000000000000000K@3oool01@3ol>`0okId0?n/
A03o/Td0okE>00@0okI@603o]Dh01@3o/Td0ojQ80?nZB@3o]4`0okY@01L0okU?00<0okU@0?niC`3o
^Dl02P3o^Dl0303o^E00okU?0?niC`3o`U@0oh`l07a06`0R40L0000003`S303;LR/0oji30?oBD@<0
olQ=00<0olU>0?o8C@3ob4d01`3ob4d01P3oad`0olQ=0?o8C@3ob4d0olM<0?o8C@L0olM<0P3ob4d0
103oad`0olQ=0?o7C03ob4h:0?o7C0030?o8C@3oad`0olM<00d0olM<00D0olQ=0?o7C03oad`0olM<
0?o8C@0=0?o7C0030?o8C@3oad`0olM<0080olM<00<0olM=0?o7C03oad`01P3oad`0103oa4X0ok]6
0?nlA`3oa4/>0?o7C0030?o6C03oad`0olI<00X0olI<00<0olM<0?o6C03oadd01@3oaT`01P3oaD`0
ijM000D20@000000ehH]0?oTC0L0omm:00D0omi:0?oOBP3ogdX0omm:0?oPB`050?oOBP030?oNB@3o
gdX0omm:00<0omm:103ogTX00`3oh4X0omi:0?oNBP050?oNBP80omi900<0omi:0?oNB03ogTP0103o
gTP30?oMB0030?oKA`3ogDP0ome800@0ome800@0omm90?oMB03ogDP0on182@3ogTP0103ogdT0omi9
0?oNB@3ogTT50?oMB@030?oIB@3of4P0omi900P0ome900D0om]:0?oMB@3ogDT0om]90?oNB@040?oM
B@030?oLB03of4P0omi900H0ome93`3og4T00`3ogDX0oma90?oLB@050?oLB@030?oKB03ofTT0oma9
00@0oma900H0ome:0?oKB03ofdP0om]80?oKB@3ofTL;0?oKB0080?oIB@3ofTP0om]80?oJB03oeDL0
oma90?oGA`3ofTP20?oKB0070?oLBP3ofdP0omQ80?oIA`3ofdP0oma90?oKB@020?oIB0060?oJB@3o
fDP0omU80?oIB03ofdT0omU80P3of4P01@3ofTT0omU80?oIB03ofDP0omY900L0omY800<0omU80?oL
B@3ofTP01P3ofTP30?oHB0070?oJB@3ofTP0omQ80?oHB03ofDP0omM70?oJB0050?oHB0030?oIB03o
f4P0omQ80080omQ800D0omU90?oHB03ofTP0omU80?oFA`0:0?oHB0040?oIB03of4P0omQ80?oJB0<0
omQ800@0omM70?oHB@3ofdT0omY82`3of4P02`3ogdX0oo5?0?V^>P1aB1P0:ad80000000A3P@0KEXM
0>6e>@3ol4`0onM;0100on=900@0on980?oOB03ohDT0onA:2P3ohdT20?oTBP030?oOA`3ogDH0omi6
00@0on=90P3oi4T00`3ohTT0on580?oPB0020?oSB@030?oTB@3ohdT0on=900T0on=900H0onA90?oU
B@3ofc/0omUh0?oadP3oo_oo0?ooooP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWB@3oool=000000030?oOh`3oool0oooo02P0oooo00@0bH^@000000000000
0000A`3oool01039Ri00000000000000001^0?ooo`090?o^j03o]7T0ojE30?n`B`3o]4l0okI@0?ne
CP3o]U00okI?01L0okE>00D0ok9<0?nRAP3o[TX0ok==0?njD00>0?niC`030?niD03o^Dl0okU?0080
okU?00D0okY?0?niC`3o^Dl0okU?0?niD00<0?niC`050?niD03o_580ol1C0;QV;00R40L00P000000
1@23BQ`0ok130?o>C`3od500olU=0100olQ=303oad`0103ob4d0olM<0?o7C03ob4hH0?o7C0030?o6
C03oad`0olM<00L0olM<00<0olQ=0?o7C03oad`01@3oad`00`3ob4d0olM<0?o8C@040?o7C0030?o7
C@3oad`0olM<00H0olM<00<0ol=:0?nkAP3o_4L03`3oad`00`3oaT`0olI=0?o6C@090?o6C0060?o7
C03oaT`0olI<0?o7C@3oaT`0olM<0`3oaT`01@3ocTl0VfHV0000001Q?A@0omU900L0omm:00<0on1;
0?oOBP3ogdX00P3ogdX00`3oh4/0omm:0?oOBP030?oOBP030?oMB@3ogdX0omm:0080omm:1@3ogTX0
0`3og4T0omi:0?oNBP070?oNBP030?oKB`3ogd/0omi900L0omi900<0oma90?oNB@3ogTT0103ogTT0
103oh4/0omi90?oNB@3ogdT90?oNB@050?oOBP3ogTT0omi90?oOBP3ogTX0103ogDT20?oLB@T0ome9
00D0omm:0?oMB@3ogDT0ome90?oNB@040?oMB@80oma900<0omi90?oMB@3ogDT00`3ogDT0103ogDX0
oma90?oLB@3ofdT;0?oLB@030?oKB@3ogDT0oma900L0oma90P3ogDT40?oLB@030?oMBP3ofdP0om]8
0080om]80P3og4T:0?oKB0050?oMB@3oedL0omQ80?oLB@3ofDL01@3ofdP01`3og4X0om]80?oKB03o
f4P0omU80?oLB@3ofdT00P3ofDP01@3og4X0om]80?oIB03ofDP0omY80080omU80P3of4P30?oIB003
0?oJB@3ofTP0omY800H0omY800@0om]80?oIA`3oedL0om]8103ofTP30?oHB0030?oIB03of4P0omQ8
0080omQ800<0omE70?oHB03ofTP02@3of4P0103ofTP0omQ80?oHB03of4P30?oGA`H0omQ80P3ofTP0
0`3of4P0omY80?oHB0050?oHB0030?oFB03of4P0omY800H0omQ800<0om]90?oHB03of4P0103of4P0
2P3ohd/0ola40?nk?P33NRP050`40000000O60L0Ie@J0?;B@`3oiT/?0?oSB@040?oTB@3ohDP0on=9
0?oQB@`0on=900<0omm70?oMAP3ogTH01`3ohdT01@3oi4T0on990?oSB03oh4T0on9900/0on=900@0
onE90?oLBP3ojK`0ooOao`3ooooj0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWih40oooo00@0i<G80820P020P800P820A`3oool0103TaLP0P8200820P020P81_
0?ooo`080?omoP3of<40olBB0?n]E@3o/4`0ok=>0?neC`3o]U0=0?neCP030?neC`3o]Dh0okE>00L0
okE>00D0ok=>0?nWA`3o[4T0okI=0?njD00=0?niC`030?niD03o^Dl0okU?00L0okU?00<0okU@0?ni
C`3o^Dl00P3o^Dl00`3o^E00okU?0?niC`020?niC`0=0?nkD03o_540ok1;0;Qi=@23Bb40=A`<01<;
101W>QH0V6dY0>VQ?@3oaD`0ol]>0?o9C@0:0?o8C@040?o9CP3ob4d0olU>0?o8CPD0olQ=2P3oad`0
1@3ob4d0olM<0?o7C03oad`0olQ>01T0olM<00<0olI=0?o7C@3oad`02P3oad`01`3ob4d0olM<0?o7
C03oad`0olQ=0?o7C03ob4d0103oad`00`3oadd0olM<0?o7C0050?o7C0050?o7C@3o`dX0ok]60?nl
A`3obD`0303oad`0103ob4d0olM<0?o6C03oad`=0?o6C00;0?o7C@3oaT`0olI=0?o6C03oad`0oli?
0?BV@00T50P0JD8F0?o:@`3ohD/01`3ogdX00`3ogTX0omm:0?oOBP020?oOBP030?oPB`3ogdX0omm:
0080omm:00<0omi90?oOBP3ogdX00`3ogdX00`3ogd/0omm:0?oNBP020?oNBP030?oOBP3ogTX0omi:
00L0omi:00<0omm;0?oNBP3ogTT01`3ogTT00`3ogdX0omi90?oNB@040?oNB@040?oPB`3ogdX0omi9
0?oOB@T0omi900<0omm:0?oNB@3ogTT00P3ogdX40?oMB@030?oNB@3ogTX0ome900P0ome900L0omi:
0?oMB@3ogDT0ome90?oNB@3og4T0om]900<0ome900<0oma90?oKB03ogDT0103ogDT30?oLB@030?oM
B@3og4P0oma900P0oma900@0ome90?oKB@3og4T0ome:203og4T00`3ofTP0oma90?oLB@020?oLB@04
0?oMBP3ofdP0om]80?oLB@<0om]800<0omY80?oKB03ofdP00P3ofdP01`3og4T0omY80?oIB03og4T0
omU80?oLB@3ofdP00P3ofdT60?oKB0<0oma90P3ofdP01@3og4T0om]90?oIB03ofDP0omY800L0omU8
00D0omY80?oHA`3ofTP0omY80?oKB@040?oJB0030?oIB03ofTP0omY800<0omY80P3ofDP30?oJB003
0?oKB@3of4P0omQ80080omQ800<0omY90?oHB03of4P00P3of4P00`3ofTP0omM70?oHB@080?oHB003
0?oIB03ofTT0omQ800D0omQ800@0omM80?oJB@3of4P0omU8103of4P00`3ofDP0omQ80?oHB0050?oH
B0030?oJB@3oeTL0omY800`0omQ800`0omY90?oKB@3og4T0oma90?6m?`2@LBD0HCdD01@<100O6@P0
N64O0;>M<`3dd4<20?oUBP/0on=900P0onA:0?oSB@3ohdT0onA:0?oRB@3ohTP0on=90?oRB@P0on=9
00<0omm70?oMAP3ogTH01P3ohdT00`3oi4T0on=90?oTB@020?oSB@050?oTB@3ohTT0on990?oQB03o
i4T00`3ohdT01P3oi4T0onA80?oSBP3oh5h0on220?ocg?l0ooooo03oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oood<0oooo00D0onSN0?n_I03o[Dl0oj]4
0?ncC@0G0?neCP050?ncCP3oYdL0oja90?nfC@3o^U003`3o^Dl00`3o^dl0okU?0?niC`050?niC`03
0?niD03o^Dl0okU?00D0okU?00/0ok]A0?o2D`3o/D/0oi4m03dP3@0000001P@103`R3@3TVS/0ole@
0?o9C@0?0?o8C@80olM<1P3ob4d80?o7C0030?o9CP3ob4d0olM<00<0olM<00<0olQ>0?o7C03oad`0
1`3oad`00`3oadh0olM<0?o7C00=0?o7C0030?o8C@3oad`0olM<0180olM<00@0olM=0?o7C03oad`0
olM=203oad`0103o`dX0ok]60?nlA`3obD`?0?o7C0T0olI<0P3oad`30?o6C00:0?o7C@3oaT`0olI<
0?o6C03ocdl0oje104LX400Z6`T0ola40?oUC0P0omm:00<0ome90?oOBP3ogdX00P3ogdX00`3oh4/0
omm:0?oOBP020?oOBP030?oPBP3ogdX0omm:00@0omm:0`3ogTX00`3ogDX0ome90?oNBP070?oNBP03
0?oOBP3oh4/0omi900P0omi900<0omm:0?oNB@3ogTT0103ogTT0103oh4/0omi90?oOBP3ogdX90?oN
B@050?oOB@3ogTT0omi90?oOBP3ogTX01@3ogDT00`3ofTT0oma90?oMB@0>0?oMB@050?oJB03ogTT0
ome90?oMB@3ogTT0103ogDT00`3ogDX0ome90?oMBP020?oLB@030?oMB@3og4P0oma900T0oma900<0
om]90?oLB@3og4T0203og4T01@3ogDT0oma90?oLB@3og4T0ome:00H0om]800H0oma90?oIB03ofDP0
oma90?oGA`3ofTP70?oKB0050?oIB@3ofdP0om]80?oKB03og4X00P3ofdP00`3og4X0om]80?oKB002
0?oKB0050?oKB@3og4T0omY80?oIB03ofTP02@3ofDP00`3oedL0omU80?oLB@0;0?oJB0050?oKB03o
edL0omQ80?oJB03ofdT02`3of4P00`3ofTP0omE70?oHB00<0?oHB0050?oKB@3ofDP0omQ80?oGA`3o
edP01P3of4P00`3ofTP0omQ80?oHB0080?oHB0030?oFAP3of4P0omQ80080omQ800<0omY80?oHB03o
f4P00`3of4P0403ofTT0omQ80?oHB03of4P0omU80?oGA`3ogDX0olm507E:60030P00000000D2002Y
Qb/0omi70?o^C03oidX@0?oSB@040?oRB03ohDP0onA:0?oRB@D0on=900<0omm70?oMAP3ogDH0103o
hdT00`3oi4T0on=90?oSB@040?oSB@80onA:00X0on=90?oTB@3ohDP0on180?oRB@3ohdT0onE70?oO
D`3ogjh0ooWjo`3oooon0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0ooooA03oool01`3onOT0olNT0?nfJP3oZdD0ok5=0?ndC@3o]U003@3o]Dh00`3o]U00
okE>0?neCP040?neCP050?n`C@3oYdL0oji:0?njD03o^E003@3o^Dl00`3o^E40okU?0?niC`070?ni
C`030?niD03o^Dl0okU?00@0okU?00X0okeB0?nkD@3oR3X0P4<M000000010@00Bb/@0<Qa:P3o`DX0
oli?0`3ob4d00`3obDh0olQ=0?o8C@080?o8C@80olM<1`3ob4d00`3obDh0olQ=0?o7C0050?o7C003
0?o8C@3oad`0olM<00D0olM<00<0olQ=0?o7C03oad`05@3oad`00`3oaT`0olM<0?o7C00;0?o7C005
0?o6C03oad`0olM<0?o7C03ob4d00P3oad`00`3ob4d0olM<0?o7C0020?o7C080olM=1`3oad`0103o
`dX0ok]60?nlA`3obD`>0?o7C080olI<00<0olM=0?o6C03oaT`02P3oaT`02@3oadd0olI<0?o6C03o
bDd0olY=0:]Q9@000000R5XN0?oZCP080?oOBP030?oPB`3ogdX0on1;00<0omm:00@0on1;0?oOBP3o
gdX0omm:0P3ogTX50?oOBP@0omi:00<0omm:0?oNBP3ogTX01`3ogTX0103ofdT0ome:0?oOB@3ogdX>
0?oNB@040?oPB`3ogdX0omi90?oOBPT0omi900H0omm90?oNB@3ogTT0omm:0?oNBP3ogTT30?oMB@03
0?oNB@3of4P0omU900P0ome900<0omm:0?oPBP3ogDT0203ogDT00`3ofdP0oma90?oMB@020?oMB@03
0?oMBP3og4T0oma90080oma900<0omY90?oGA`3ogDT02@3og4T00`3ofTP0oma90?oLB@080?oLB@05
0?oIB03ofdT0oma90?oLB@3ogDX00P3ofdP20?oLB@060?oLB03of4P0omQ80?oKB@3of4P0oma9103o
fdP20?oLB@<0om]800<0omY80?oHB03ofdP0103ofdP00`3og4X0om]80?oKB0020?oKB0040?oLB@3o
fDT0omU90?oKB0/0omU800<0omQ80?oKB@3ofTP0303ofTP00`3oeTH0omY80?oKB@050?oHB0030?oJ
B03of4P0omQ800D0omQ800<0omE70?oKB@3of4P01@3of4P0103ofTP0omQ80?oJB@3ofTP40?oHB003
0?oJB03oe4H0omQ800D0omQ800<0omU90?oJB03of4P02@3of4P01@3oeTL0omM70?oIB@3of4P0omY8
00D0omQ80140omY90?oHB03of4P0omQ80?oIB03oedL0omI60?oJB03of4P0]G<U04H/3P0000000@00
06mK7@3G[3P0omm80?o/C00@0?oSB@060?oTB@3oh4P0on580?oRB@3ohdT0onA90P3ohdT00`3ogdL0
ome60?oMAP030?oSB@030?oTB@3ohdT0on=900H0on=900T0onA:0?oSB@3ohdT0on=90?oTB@3ohDH0
omll0?oJD03oiKH0o`3ooooo0?ooo`40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooom50?ooo`070?omo`3oj^@0ok=/0?nZ@`3o[d/0ok5=0?neC`080?ne
CP030?nfD03o]Dh0okE>00P0okE>00@0ok1=0?nWA`3o[TX0ok]A303o^Dl00`3o^Dh0okU?0?nhC`08
0?niC`030?niD03o^Dl0okU?00<0okU?00@0ok]A0?o4E@3o^Dl0^V4Z0`000000102?DAl0oke80?oE
DP3obdh=0?o8C@80olM<103ob4d00`3obDh0olQ=0?o8C@060?o8C@030?o7C03ob4d0olQ=0100olM<
00<0olQ=0?o7C03oad`03`3oad`00`3ob4d0olM<0?o7C0090?o7C0030?o6C03oad`0olM<00D0olM<
00<0olQ=0?o7C03oad`01`3oad`0203oadd0olI=0?o7C03oad`0ol=:0?nkAP3o_4L0olU<2`3oad`0
0`3oadd0olM<0?o7C0020?o6C0030?o7C03oaT`0olI<00@0olI<00<0olI;0?o6C03oaT`00`3oaT`0
2@3oadd0olI<0?o6C03obDh0oi<h00`60P000000cZ8f0?oRB`070?oOBP030?oOB@3oh4/0omm:00@0
omm:00<0on1;0?oOBP3ogdX0203ogdX00`3ogTX0omm;0?oNBP0;0?oNBP030?oMB@3ogDX0omi900P0
omi900<0oma90?oNB@3ogTT0103ogTT0103oh4/0omi90?oOBP3ogdX90?oNB@050?oMB@3ogTT0omi9
0?oOBP3ogTX01@3ogDT00`3ofDP0om]90?oMB@070?oMB@030?oNBP3ofdP0ome900D0ome900D0omi9
0?oLB@3og4P0oma80?oNBP030?oMB@030?oMBP3og4T0oma900<0oma900<0ome90?oIB03og4T01`3o
g4T00`3ogDT0omY80?oLB@0:0?oLB@040?oKB03ogDT0oma90?oLBP<0om]800@0omQ80?oNB@3oedL0
omM71@3og4T20?oKB080oma90`3ofdP00`3og4T0omM70?oHA`040?oKB0030?oLB@3ofdP0om]80080
om]800H0oma90?oJB@3of4P0omU90?oIB03og4T:0?oIB0030?oKB@3oedL0omY80080omY800<0om]9
0?oJB03ofTP01`3ofTP00`3ofDL0omU90?oHB0040?oHB0030?oKB@3of4P0omQ800D0omQ80P3ofTP0
203oedL0omU90?oHB03ofTP0omU90?oJB03ofDT0omY81`3of4P0103ofDT0omU80?oGA`3oedL?0?oH
B0050?oJB03oeTL0omQ80?oHB03ofTP01@3of4P00`3ofTT0omQ80?oHB0020?oHB00?0?oJB03oeTL0
omM70?oKB@3ojDd0olY30;Ud9P0X6PT0000000/70P1_FA`0i/@o0?odCP3oiDX0on990100on=900H0
on980?oTB@3ogdP0onA90?oSB@3oh4P20?oMAP030?oRB03ohdT0onA900T0on=90P3oi4T01P3ohdT0
onA90?oT@@3ofD/0onF:0?oM[_l0ooooo`3oool20?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooA`3oool0203omO00om2^0?o0O`3o[5D0ojm:0?nbC@3o
]4h0okI?0P3o]Dh00`3o]Tl0okE>0?nfC`0;0?neCP040?n`C@3oYdL0oji:0?nkD@P0okU?00<0okY?
0?niC`3o^E000P3o^Dl00`3o^E00okU?0?niC`070?niC`80okU@0P3o^Dl02`3o_E40nji;0;5h=01o
@a`0>Ql=01P=1@1c@AT0[7H]0>ZV@03obDh0ol]?00D0olQ=00<0olU>0?o8C@3ob4d0503ob4d20?o7
C0040?o8C@3oadd0olQ=0?o7C0@0olQ=203oad`0103ob4d0olM<0?o7C03ob4dA0?o7C0030?o8C@3o
ad`0olM<00d0olM<00D0olQ=0?o7C03oad`0olM<0?o8C@040?o7C0030?o7C@3oad`0olM<00H0olM<
00<0olE:0?nkAP3o^dH00`3oad`20?o8C@@0olM<00<0olQ=0?o7C03oad`00`3oad`20?o6C0030?o7
C@3oaT`0olI<0080olI<0`3oad`50?o6C0080?o7C@3oaT`0olM<0>n^@`0X5`T02`H209UP803ohT/7
0?oOBP050?oPBP3ogdX0on5;0?oOBP3oh4/00`3ogdX00`3oh4/0omm:0?oOBP080?oOBP050?oNBP3o
gd/0omi:0?oOBP3ogDX0203ogTX20?oOBP030?oNBP3ogTT0omm:00L0omi900<0oma90?oNB@3ogTT0
103ogTT0103ogdX0omi90?oOBP3ogdX90?oNB@040?oKB@3ogTT0omi90?oOBP80omi:103ogDT20?oN
B@P0ome900<0omi:0?oJB03ogdX01`3ogDT00`3ofdT0oma90?oKB@030?oMB@030?oMBP3og4T0ome9
00<0oma900<0om]90?oLB03og4T0203og4T00`3ogDT0omY80?oKB@080?oLB@050?oMB@3ofdT0oma9
0?oJB@3ogDT00P3ofDP0103og4T0om]90?oMBP3og4T20?oKB0<0omY800@0oma90?oKB03ofdP0om]8
0P3og4T20?oKB0040?oLB@3ofdP0omY80?oIB0P0om]800H0oma90?oKB@3ofDP0omU80?oKB@3ofDT:
0?oIB0070?oJB03of4P0omM70?oIB03ofdP0omY80?oKB@090?oJB0030?oKB@3of4P0omU800@0omQ8
00<0omU80?oHB03of4P0103of4P01`3ofTT0omQ80?oIB03ofdT0omM70?oIB03ofDT00P3of4P20?oI
B0H0omQ800D0omU90?oIB03of4P0omQ80?oFA`030?oHB0030?oJB@3of4P0omQ800X0omQ800@0omU8
0?oJB@3oe4L0omU8103of4P05@3ofTT0omQ80?oHB03ofDP0omU90?oIB03of4P0omM80?oIB03ofTP0
oma90?oQB`3b`d40ZG/X06a55P0U60P07QP8071J702/VC80iL]10?oXB`070?oSB@030?oTBP3ohdT0
on=900D0on=900T0onA90?oSB@3ohdT0on580?oSBP3ogdP0omi60?oMAP3ohTP02P3ohdT20?oTB@06
0?oTB03ohD<0on5M0?oXXP3olMT0ookoo`3ooooo0?ooo`<0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooom:0?ooo`070?o/i@3o]7<0oje90?n^B`3o[d`0
okE>0?ndCP020?neCP030?neC`3o]E00okE>00T0okE>00@0ok1=0?nWA`3o[TX0ok]A1`3o^Dl0103o
^dl0okU?0?niC`3o^E0=0?niC`050?niD03o_E80okeA0?=o=`0e70`00P000000101@;A40mj4m0?o?
D03oce020?o8C@030?o9CP3ob4d0olQ=00D0olQ=00D0olM<0?o8C@3ob4d0olQ=0?o8C00@0?o8C@03
0?o7C03ob4d0olM<00P0olM<00<0olQ>0?o7C03oad`08P3oad`00`3oaT`0olM<0?o7C0080?o7C003
0?o8C@3oad`0olM<0080olM<00<0olM=0?o7C03oad`00`3oad`20?o7C@050?o7C03oaDX0okI40?nk
AP3obD`02P3oad`01`3obD`0olM<0?o8C@3ob4d0olM<0?o6C03oad`0103oaT`00`3oaT/0olI<0?o6
C0050?o6C0080?o7C@3oaT`0olM<08QD80000000SETM0?oYC@3oh4/90?oOBP030?oQB`3ogdX0omm:
00<0omm:00D0on1;0?oOBP3ogdX0ome90?oNBP060?oOBP040?oNBP3ogdX0omi:0?oMB@T0omi:00D0
ome:0?oLB@3ogTX0omi90?oOBP0@0?oNB@80omm:2@3ogTT01@3og4P0omi90?oNB@3ogdX0omi:00l0
ome900<0omi:0?oMB@3og4P03@3ogDT00`3ogDX0oma90?oLB@040?oLB@030?oJB@3ofdT0oma900P0
oma900<0ome90?oHB03ogDX0103og4T30?oNBP030?oIB03ofdP0ome90080oma900<0oma80?oKB03o
fdP01`3ofdP00`3ofdT0om]80?oKB0020?oKB080oma91P3ofdP00`3ofTT0om]80?oKB0050?oKB005
0?oLB@3ofdT0omU80?oIB03ofTP00P3ofdT:0?oIB080omY800@0omQ80?oKB@3ofTP0om]82@3ofTP0
103ofdT0omQ80?oJB03oeDL30?oHB00;0?oJB03of4P0omQ80?oHB03ofdT0omU80?oHB03ofTP0omQ8
0?oJB@3of4P00P3oedL30?oHB080omU91P3of4P00`3ofDT0omU80?oHB0020?oHB0030?oHA`3of4P0
omU90140omQ80P3oedL30?oHB080omY81P3of4P0103of4L0om]80?oHB03of4P20?oPBP060?o5@P2B
G1l000000000000D40D0SW<U0P3oiTX30?oSB@030?oTBP3ohdT0onA:00d0on=900<0omM30?oHA03o
hTP0203ohdT20?oTB@050?oSB@3ohdL0omMR0?oW]`3on_D0o`3ooooo0?ooo`H0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooom;0?ooo`060?o`j@3o]H80
ojQ70?nXA`3o[TX0okA=0P3o]Dh00`3o]Tl0okE>0?neCP090?neCP040?n`C03oYdL0ojm:0?nkD@H0
okU?00D0okQ?0?niC`3o^Dl0okU?0?niD00<0?niC`0;0?nkD@3o^E00o8Hi04hY4P0<1@80000004/Z
3`3`R3<0oki:0?o<C`3obDd00`3ob4d00`3obDh0olQ=0?o8C@020?o8C@80olM<5P3ob4d@0?o7C003
0?o8C@3oad`0olM<00<0olM<00<0olQ=0?o7C03oad`03@3oad`00`3ob4d0olM<0?o7C0060?o7C003
0?o6C03oad`0olM<00T0olM<00<0olQ=0?o7C03oad`00P3oad`00`3oadd0olM<0?o7C0060?o7C004
0?o3BP3o^TH0oka70?o9C0h0olM<1@3oaT`20?o7C@030?o6C@3oaT`0olI<00D0olI<00L0olM=0?o7
C03oad`0;Q/:03<P2`3o`d00onM=00P0omm:00<0omi:0?oOBP3ohD/01@3ogdX00`3oh4/0omm:0?oO
BP080?oOBP040?oNBP3ogd/0omi:0?oLB@X0omi:00<0omi90?oNBP3ogTT01`3ogTT00`3ogdX0omm9
0?oNB@070?oNB@80omm:2@3ogTT01@3og4T0omi90?oNB@3ogdX0omi:00D0ome900<0omi90?oHB03o
g4T01`3ogDT0103ogTX0oma90?oGA`3ogTT80?oMB@80oma90P3ogDT01@3ogDX0oma90?oLB@3ogDX0
ome900<0oma900<0om]90?oLB@3og4T0203og4T30?oMBP<0oma900<0om]80?oEA`3ofdP01@3og4T:
0?oKB0030?oLB03og4T0om]80080om]80P3og4T30?oKB0050?oLBP3ofdP0om]80?oKB@3ofTP01`3o
fdP40?oIB0030?oKB03ofdT0omQ800T0omU80`3ofTP00`3ofDP0omU70?oJB0090?oJB0050?oKB@3o
f4P0omQ80?oHB03oedP00`3of4P00`3ofdT0omQ80?oHB0050?oHB0060?oJB@3of4P0omQ80?oHB03o
f4L0omY82@3of4P00`3ofDT0omU80?oHB0030?oHB0040?oJB03oeTL0omM70?oIB0D0omQ800<0omY8
0?oHB03of4P01`3of4P01@3ofdT0omQ80?oEA`3of4P0omU800T0omQ80100omM70?oLB@3ofDT0omQ8
0?oJB03oh4/0omE70>JA<00i9@`0000000H50P1>?a@0dJTf0?oPB03oiDX0onA90P3ohdT00`3oi4X0
on=90?oSB@0;0?oSB@040?oMAP3og4H0ome60?oTB@H0on=900H0onA90?oTB03ohdP0onA;0?oIO@3o
oogo0?ooool0oooo203oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOo0?oood`0oooo00P0ooKi0?o@^@3oY5D0oje=0?n_BP3o/D`0okA>0?nfC`/0okE>00@0ojm<
0?nWA`3o[dX0ok]A0`3o^Dl00`3o^4l0okY?0?niC`040?niC`030?niD03o^Dl0okU@00P0okU?0P3o
_E802P3o[TX0YeTV0000000000002`H209]H8@3o`d/0olY=0?o;CP3obDd40?o8C@030?o9CP3ob4d0
olQ=00L0olQ=00<0olM<0?o8C@3ob4d03`3ob4d80?o7C0030?o8CP3oad`0olM<02@0olM<00<0olI<
0?o7C03oad`01@3oad`00`3ob4d0olM<0?o7C0020?o7C0030?o8C@3oaT`0olM<0080olM<00<0olM=
0?o7C03oad`01P3oad`0103oaD/0ok]60?nlA`3obD`>0?o7C0H0olI<0P3oad`30?o6C00:0?o7C03o
add0olM=0?o7C@3oad`0olm?0<=^:@060`80gX`^0?oYC@T0omm:00<0on1:0?oOBP3ohD/01@3ogdX0
103oh4/0omm:0?oNBP3ogDT70?oOBP80omi:0P3ogdX90?oNBP030?oOBP3ogTX0omi:0080omi900<0
on1;0?oNB@3ogTT00`3ogTT00`3ogdX0omi90?oNB@070?oNB@030?oLBP3ogDX0omi900P0omi900L0
oma90?oNB@3ogTT0omm:0?oNBP3ogDT0omi900<0ome900<0omi90?oJB03og4T01`3ogDT0103ogTX0
ome90?oMB@3ogdX80?oMB@80omi900<0omY80?oLB@3ogDX01`3og4T0103ofdT0oma90?oLB@3og4T3
0?oNBP030?oMB@3ogDX0ome900<0oma900D0om]90?oMB@3ofTP0omU80?oMB@060?oLB@@0om]80P3o
g4T:0?oKB080oma91P3ofdP00`3og4T0om]90?oJB0060?oKB0D0omU800<0om]80?oKB@3ofDP0203o
fDP30?oJB080om]900<0omY80?oIB03ofTP0203ofTP40?oHB0040?oLB@3of4P0omQ80?oIB0L0omQ8
00<0omY90?oHB03of4P00P3of4P20?oGA`P0omQ800<0omU90?oIB03of4P01@3of4P00`3oedL0omU8
0?oHB0040?oHB0030?oKB@3of4P0omQ800T0omQ800<0om]80?oCAP3of4P02@3of4P20?oJB0<0omQ8
00d0omY80?oJB@3og4T0omA70=n<;@0R5PL000000080001;?A<0gKPk0?oVBP3ojT/0onA90080onA:
303ohdT01P3ogTH0ome60?oRB03oh4P0omi80?oUBP<0on=900H0onA90?oTB03ohdh0oma@0?oP[03o
o_[o0?ooool0oooo2@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOo0?ooodh0oooo00P0ooOd0?oM`P3o^g`0ok5H0?n[B`3o/4/0okA=0?ndCPT0okE>00L0oji;
0?nXB03o/4/0ok]A0?njC`3o^Dl0okY?00L0okU?00<0okU@0?niC`3o^Dl01@3o^Dl02`3o_540ol1B
0?Z[B@2aKc00Nd8L02hH2`0L40H0NdDJ0:Um<03cZd40olY>00P0olQ=00<0olU>0?o8C@3ob4d00P3o
b4d00`3obDd0olQ=0?o8C@0<0?o8C@030?o9CP3ob4d0olQ=00H0olQ=3@3oad`20?o8C@@0olM<00@0
olQ=0?o7C03oad`0olQ=703oad`00`3oaT`0olM<0?o7C0050?o7C0030?o8CP3oad`0olM<0080olM<
00<0olM=0?o7C03oad`00`3oad`01`3oadd0olM<0?o7C03oaDX0ok]60?nlA`3obD`03P3oad`30?o6
C0030?o7C@3oaT`0olI<00P0olI<00H0olM=0?o>D02fMB/05P`406155`3oiD`30?oPB`@0omm:0P3o
h4X01@3ogdX0on1;0?oPB`3oh4/0omm:0080on1;0P3ogdX00`3oh4/0omm:0?oOBP080?oOBP030?oN
BP3ogdX0omi:00d0omi:203ogTT00`3ofdT0omi90?oNB@060?oNB@040?oOB@3ofTT0omY90?oOB@P0
omi900L0ome90?oNB@3ogTT0omm:0?oNBP3ogDT0omi900<0ome900<0omi90?oMBP3ogDT01P3ogDT0
1P3ogTT0omm:0?oNB@3ogDT0om]90?oNB@H0ome90P3ogTX0103ofdT0omm:0?oLB@3ogDX30?oLB@@0
ome:00<0om]90?oJB03og4T00`3og4T02P3ogDT0oma90?oLBP3ogTT0om]80?oIB03ogDX0omQ80?oL
B@3ogDT90?oLB@`0om]800<0omY80?oKB03ofdP00P3og4T40?oKB0070?oLB@3ofdP0om]80?oKB03o
fTT0om]90?oLB@040?oKB0H0omU800<0om]90?oJB03ofDP01`3ofDP40?oJB0040?oKB03ofDP0omM7
0?oKB@L0omY800T0om]90?oHB03ofDT0omY90?oHB03ofTP0omQ80?oFA`3ofDP01`3of4P00`3ofTT0
omQ80?oHB0020?oHB0040?oIB03of4P0omM80?oIB0H0omQ800<0omU90?oIB03of4P01P3of4P00`3o
fDP0om]90?oFA`030?oHB0030?oKB@3of4P0omQ800@0omQ800@0omY90?oHB03of4P0om]9103of4P0
103ofDT0omI70?oHB03ofDP60?oHB0030?oIB@3ofTT0omM800D0omQ800/0oma90?G8@P2SPb`0KdLG
02`L2@0?30@0GT/H09f0:@3H_Sh0onE:0?oYB`0<0?oSB@0=0?oOAP3ogDH0on580?oSB@3oi4T0on99
0?oRB03ohdH0on920?oOD03oi7d0onk<0?oll@3o0?ooool0oooo2`3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooe40oooo00L0onCL0?o5V03o/E/0oje7
0?n^C03o/Td0okE?00L0okE>00@0ojm;0?nTAP3o/T`0okY@2P3o^Dl00`3o^E00okU?0?niD0030?ni
C`0;0?nkD03oaeD0ok1:0=]d<@0d6`/0000000<1001[?1L0lZ@n0?oFD`3obTd01P3ob4d00`3oad`0
olQ=0?o8C@030?o8C@80olU>00<0olQ=0?o7C03ob4d01`3ob4d00`3obDh0olQ=0?o8C@070?o8C@05
0?o7C03ob4d0olQ=0?o8C@3obDh01P3oad`01`3ob4d0olM<0?o7C03oad`0olQ=0?o7C03ob4d02@3o
ad`01P3ob4d0olM<0?o7C03oad`0olQ=0?o7C080olM=1`3oad`00`3ob4d0olM<0?o7C00=0?o7C003
0?o7C@3oad`0olM<00<0olM<00<0olQ=0?o7C03oad`02`3oad`0103oaDX0ok]60?nlA`3obD`>0?o7
C0@0olI<00<0olM<0?o5C03oaT`01`3oaT`01@3oce00fWX_00h70`000000iK8k00T0omm:00D0omm9
0?oNBP3ogdX0omm:0?oQB`040?oOBP80on1;00@0on5;0?oNB`3oh4/0on1;1P3ogdX20?oNBP030?oO
BP3ogTX0omm;00P0omm;00<0omi:0?oOB`3ogTX0203ogTT00`3ofDL0omi90?oNB@060?oNB@030?oO
B@3ofdP0om]900P0omi91P3ogdX40?oNBP<0ome900<0omi:0?oMB@3ogDT0103ogDT01`3ogTX0omm:
0?oNBP3ogTX0oma:0?oNBP3ogTT0203ogDT0103ofdP0ome90?oNBP3ogDT20?oLB@070?oMB@3og4T0
oma90?oLB@3ogDT0oma80?oJB@020?oLB@090?oKB03ofDL0ome90?oKB@3og4X0oma90?oMB@3ofdT0
omQ800/0oma900D0omY80?oJB@3ofdP0om]80?oLB@070?oKB0D0oma92@3ofdP20?oJB0@0om]81`3o
fDP00`3ofTP0omU70?oGA`060?oIB0P0omY800@0om]80?oKB@3ofTP0omY9103ofTP70?oHB0030?oJ
B@3of4P0omQ800D0omQ800<0omY90?oHB03of4P01@3of4P00`3ofDP0omM70?oGA`040?oHB0030?oI
B@3ofDP0omQ800H0omQ800L0omU90?oHB03of4P0omQ80?oGA`3ofDT0om]90080omQ800@0omU90?oH
B03ofDT0omU82P3of4P20?oGA`L0omQ800<0omU80?oGA`3oeTL01P3of4P0103ofdT0onI<0?oDAP2N
I2430000000407AM7P3ocD40ooQ?0?oXB`X0on=900<0omm60?oMAP3ohTP00P3oi4T01@3oi4X0on=0
0?oIG03ohX`0on320?l0ooooo`3oool>0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWiol0ooooD`3oool01`3oe[P0ojmS0?nZA03o[TT0ok1<0?ncC@3o]U00103o
]Dh01@3o]U00ojm<0?nTAP3o/4/0ok]A00X0okU?00<0okU@0?niC`3o^Dl00P3o^Dl0103o^e40oka@
0<i];`1M<QD20000000507=16@3`R3<0ol5:0?o@D03ob4d00P3obDh00`3ob4d0olQ<0?o8C@0<0?o8
C@030?o9CP3ob4d0olQ=00D0olQ=00<0olU>0?o8C@3ob4d00P3ob4d0103obDh0olQ=0?o8C@3oad`5
0?o8C@030?o9CP3oad`0olM<00@0olM<00D0olQ=0?o7C03oad`0olM<0?o8C@0B0?o7C0040?o8C@3o
ad`0olM<0?o8CA@0olM<00<0olM=0?o6C03oad`04@3oad`0103oaDX0ok]60?nlA`3obD`80?o7C003
0?o8C@3oad`0olM<00<0olM<0`3oaT`00`3oad`0olI=0?o5C0080?o6C0050?nmB00a70X0000005/i
4`3og4T0203ogdX00`3ogTX0omi90?oOBP020?oOBP030?oQB`3ogdX0omm:00<0omm:00<0omm;0?oM
B@3ogdX02@3ogdX00`3og4X0omi:0?oNBP080?oOBP80on1;0P3ogTX80?oNB@030?oKB03ogTT0omi9
00H0omi900@0omm90?oHB03ofTP0omm9203ogTT00`3ogdX0omi90?oNB@060?oNB@<0ome900<0oma9
0?oMB@3ogDT01@3ogDT00`3ogTX0ome90?oMB@020?oNB@T0ome900H0om]80?oMB@3ogDX0ome90?oK
B03ofdT50?oLB@090?oMB@3og4T0om]80?oKB@3ofdP0omU70?oLB@3ogDX0ome90080oma900<0ome9
0?oLB@3ofTP02`3og4T00`3ofDP0oma80?oKB0090?oKB0040?oLB03ofdP0oma90?oLB@X0om]800<0
omQ70?oKB03ofdP00P3ofdP60?oIB0050?oKB03ofDP0om]80?oIA`3oedL01@3ofDP50?oJB0040?oK
B@3ofdP0omY80?oLB@P0omY81P3of4P0103ofDP0omI70?oGA`3ofTP40?oHB0030?oKB@3of4P0omQ8
00D0omQ800D0omY80?oHB03ofDL0omE70?oIB00>0?oHB0070?oJB03of4P0omI80?oJB03ofdT0omQ8
0?oJB0070?oHB0030?oJB03of4P0omQ800D0omQ800<0omM70?oHB03ofTP01@3of4P0103ofTP0omM7
0?oEA`3ofDP60?oHB00;0?oMB@3og4T0kYDb08QE7@030P000000040c402JO2P0om=30?o_C@3ohTT0
203ohdT02@3ogTH0ome60?oPA`3oi4T0onE80?oR>P3ogg/0onc?0?omo`1X0?ooo`070?oOh`2GJ6`0
<R<T0000000I4Q80OUMJ0>:LXP0Q0?ooo`090?oXk039Ri00IDE8038S90000000IDE807iGFP39Ri00
oo3e00L0oooo00T0i;Jm06E5B0000000000000d92@1UADP0/7Un0?b]]03onOh00`3oool00`0I4Q80
000004/d=P0P0?ooo`030?o@f02GJ6`0<R<T0080000000<0LTiA0<V;T03ohNX01P3oool0203ohNX0
bH^@06E5B00=2@T0000001TA4P1UADP0i;Jm7`3oool0203T][d0IDE801TA4P0000003@T906E5B039
Ri00on7Z<@3oool0203od=P0bH^@06E5B00I4Q80000006E5B01nEeX0i;Jm103oool0103od=P0bH^@
06E5B00I4Q8200000003038S902`NWh0oooo0;/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomC0?ooo`090?ono`3okN<0okf60?nYC`3o[4P0oje;0?n`
C03o/dd0okI?00<0okE>00@0oji;0?nXB03o[d/0okY@2P3o^Dl0203o^E00okU?0?niC`3o^Dl0ol1C
0?nfCP2<BR001P<10P000000102jJBP0okm:0?oCD@3oc4h20?o8C@030?o8CP3oadh0olQ=00X0olQ=
00<0olM<0?o8C@3ob4d00`3ob4d00`3obDh0olQ=0?o8C@030?o8C@030?o9CP3ob4d0olQ=00<0olQ=
0P3oad`60?o8C@030?o9CP3oad`0olM<00L0olM<00<0olM=0?o7C03oad`04@3oad`00`3ob4d0olM<
0?o7C0030?o7C080olQ=903oad`0103oaDX0ok]60?nlA`3obD`>0?o7C0<0olI<00<0olI;0?o6C@3o
aT`01`3oaT`0203ob4d0bHlg0000000J40D0ok8l0?oRB`3oh4X0on5;1P3ogdX00`3oh4X0omi:0?oO
BP020?oOBP030?oQB`3ogdX0omm:00<0omm:00<0on1;0?oNB@3ogdX0203ogdX0103ogTX0omm:0?oN
BP3oh4/80?oNBP040?oMB@3ogTX0omi:0?oNBPP0omi900<0omm90?oNB@3ogTT01P3ogTT00`3ogdT0
omY80?oKB@0:0?oNB@030?oOB@3ogTT0omi900L0ome900<0omi90?oJB03ogDT01P3ogDT01@3ogTX0
ome90?oMB@3ofTT0oma900T0ome900<0omi:0?oLB03ogDT00P3og4T00`3ofTP0ome:0?oLB@030?oL
B@030?oHB03ofTL0omU900@0oma900<0ome:0?oMB@3og4T00`3og4T20?oJB0X0oma900D0omU80?oI
A`3ofdP0om]80?oLB@090?oKB0030?oJB03og4T0om]800X0om]800<0omU70?oKB03ofdP00P3ofdP8
0?oIB0030?oKB03of4P0omQ800@0omU80P3ofTP00`3ofdP0om]90?oJB0030?oJB0030?oKB03ofTP0
omM700H0omY8203of4P00`3oedL0omQ80?oIB0030?oHB0030?oKB@3of4P0omQ800L0omQ800<0omY8
0?oGA`3ofDP0303of4P01`3ofdT0omQ80?oHB03ofTT0omQ80?oFB03oedP02@3of4P00`3ofTP0omQ8
0?oHB0040?oHB0050?oIB03of4P0omY80?oDAP3ofDP00`3of4P01@3ofDP0omQ80?oJB03oedL0omQ7
00L0omQ800D0om]90?oWC@3oe4H0ojPh04D/3P020000000403L/3P39Z3H0oo==0?oTB@H0on=900P0
omm60?oMAP3ogDH0on580?oR?P3oe4T0onJ[0?ofiSl0oooo0`0000000`39Ri00oooo0?ooo`080?oo
o`040?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP000000
0000000000H0oooo00<0C3@f000000000000100000000`1;=3H0onS/09MXK00200000003081XK03o
ool0oooo0080oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000000000L0oooo
00<0om3H03<S900000001P0000000`20J6`0oooo0?ooo`040?ooo`030;1iOP000000000000H00000
00D0IDI80?ooo`3oool0oooo04`d=P02000000030?oco03oool0oooo00L0oooo3P0000060?ooo`03
0?o@f01UADP0000000L0000000<0om3H0?ooo`3oool00P3oool00`3H_;l000000000000600000003
0;1iOP3oool0oooo00D0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`00000000000000
00L0oooo00<0/7Un0000000000001P0000000`3H_;l0oooo0?ooo`050?ooo`<0000000<0oko60?oo
o`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0
omoS00000000000000000820P0070?ooo`030;:;T0000000000000H0000000@0om3H0?ooo`3oool0
VH:7200000000`0b8b@0om3H0?ooo`2i0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWiol0ooooE@3oool03P3ooOl0oo;]0?o>Y@3oZE@0oje=0?nZB@3o[d`0ok9>
0?ndCP3o]Dh0oji;0?nXB03o/4/0okY@2@3o^Dl02`3o^U00ok]A0?njD03gZ4P0VVP/06`h600O4@P0
7a47081<7P2eP340ok540080olY>4P3ob4d00`3obDh0olQ=0?o8C@040?o8C@80olU>0P3ob4d00`3o
bDh0olQ=0?o8C@0;0?o8C@030?o9CP3oad`0olM<00@0olM<00<0olQ=0?o7C03ob4d03@3oad`00`3o
b4d0olM<0?o7C0040?o7C0030?o8C@3oad`0olM<00H0olM<00D0olQ=0?o7C@3oad`0olM<0?o8C@0:
0?o7C0030?o8C@3oad`0olM<0140olM<00@0olE:0?nkAP3o_4L0olU<3P3oad`20?o6C0030?o7C03o
aT`0olI<00L0olI<00L0olY=0?nnB@1B;Q80;ah:0=fP=P3ohd`0on1:00d0omm:00L0on5;0?oOBP3o
gdX0omm:0?oPB`3ogdX0omm;00/0omm:00<0ome:0?oNBP3ogdX0303ogTX30?oNB@80omm:0P3ogTT0
0`3ogdX0omm90?oNB@070?oNB@040?oOB@3ofdP0om]90?oOBPT0omi900<0omm90?oNB@3ogTT0103o
gDT00`3ogTT0ome90?oMB@090?oMB@050?oNBP3ogDT0ome90?oLB@3ogDX02P3ogDT02@3ofdT0omi9
0?oLB@3og4T0ome90?oJB@3ogDT0oma90?oHB0030?oLB@030?oLB03og4T0oma90080oma900<0ome:
0?oMB@3og4T00P3og4T20?oMB@030?oJB03og4T0oma900P0oma9103ofdP00`3og4T0om]80?oKB007
0?oKB0030?oJB@3ogDX0om]800T0om]800@0oma90?oJB03of4P0omU80P3ofdP60?oIB0080?oJB@3o
fDP0omU80?oIB03ofDT0omU80?oJB03ofTT20?oKB@H0omY800<0om]90?oJB03ofdP00P3ofDP00`3o
fdP0omY80?oJB0020?oJB0H0omQ800@0omU80?oJB@3of4P0omY90P3ofDP20?oHB0030?oKB@3of4P0
omQ800H0omQ800L0omY80?oHB03of4P0omU80?oFA`3ofDP0omU900P0omQ800@0omU90?oHB03ofDP0
omY9103of4P00`3ofDP0omM70?oHB0060?oHB080omU80P3of4P00`3ofdT0omQ80?oHB0050?oHB003
0?oJB03oedL0omU800D0omQ800<0omQ70?oJB03of4P0103of4P05`3ofDT0omU80?oJB@3ogDX0oli5
0<6C<@21FAh0?BH<00h;101:>a<0T7/X0<bb>P3oh4P0onI:0?oTB@3ohTT0on180?oMAP3ogDP0om]=
0?oQP03okm00ooOW0440oooo0`0000000`39Ri00oooo0?ooo`080?ooo`040?noaP00000000000000
00D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00`0omoS
04`d=P000000000000d92@1UATP0P61S075>D@0c8b@0000005U6B01H?Cl2000000030820P03oool0
oooo0080oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000000000D0oooo00<0
lLkA075>D@0000000P0000001`0=2@T0?b`]06E6B00c8b@03@T900000020P800103oool01P2oYJ/0
9QXK0000000000006A8B05Pm?`80P61S00@0IDI802HJ6`000000<b<T0`3oool0101iH6<000000000
003FTiT90?ooo`h000001@3oool01P2aSY4000000000000000001`D503l/;@80IDI800<081HG0000
00000000103oool02@2bW:804`d>0000000000003@T905m2A01UATP0F3do00d92@020000000302HJ
6`2bW:80oooo00@0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000000000D0
oooo00T0/YbR02HJ6`000000000000d92@1H?Cl0IDI805m2A00=2@T00P0000000`0C3@h0/YbR0?oo
o`050?ooo`<0000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081P
H`0000000000000000@0oooo00D0omoS00000000000000000820P0050?ooo`030?7>d@1aCU400000
0080000000H03@T9058i>`1UATP0<b<T00d92@0000030?ooo`04081TJ0000000000002HJ6`80IDI8
00H0F3do01TB4P000000000000d92@2INWji0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooF03oool02`3omoP0olNb0?nYH03o/540oja70?n]B`3o/D`0
oje:0?nXB03o/4/0okY@00P0okU?0P3o_E402`3oZDP0hWLc01X>1@0000005@/406Lj5@3o[d@0olY=
0?o9C@3ob4d0olU=00D0olQ=00<0olU>0?o8C@3ob4d01@3ob4d00`3oad`0olQ<0?o8C@0?0?o8C@05
0?o9CP3ob4d0olQ<0?o7C03obDh0203ob4d00`3obDh0olM<0?o7C0040?o7C0030?o8C@3oad`0olM<
01@0olM<00<0olQ=0?o7C03oad`03@3oad`00`3ob4d0olM<0?o7C0050?o7C0030?o7C@3oad`0olM<
0140olM<00@0olE:0?nkAP3o_4L0olU<0`3oad`00`3oaT`0olM<0?o7C0020?o7C0030?o8C@3oad`0
olM<00<0olM<00<0olI<0?o7C03oaT`00P3oaT`00`3oad`0olI<0?o6C0030?o6C0070?o9C03ob4d0
[V8U00H40@3iWC@0onU=0?oPBP0>0?oOBP030?oQB`3ogdX0omm:0100omm:2P3ogTX20?oOBP80omi:
1`3ogTT00`3og4T0omi90?oNB@070?oNB@030?oOB@3ofTP0om]900d0omi9203ogDT00`3ogTT0ome9
0?oMB@090?oMB@030?oMBP3ogDT0ome900P0ome90P3og4T01@3ofdT0omI70?oKB03ogDT0omi900D0
oma900<0omi90?oLB@3og4T00P3og4T00`3ogDX0ome90?oLB@050?oLB@030?oMB@3og4T0oma900L0
oma90P3ofdP00`3ofTP0om]80?oKB0090?oKB0030?oLB03ogDT0oma900D0om]800D0oma90?oKB03o
fdP0om]80?oLB@020?oKB0030?oHB03ofDP0om]800D0omU80P3ofdP40?oIB0050?oGA`3ofDL0om]8
0?oIB03ofdT02P3ofTP00`3ofDP0omY80?oKB0030?oJB0/0omQ800<0omM70?oKB@3of4P03P3of4P0
0`3ofdP0omM70?oGB0050?oHB0050?oKB@3ofTP0omQ80?oHB03ofdT01`3of4P00`3oeTP0omU90?oH
B0040?oHB080omU90P3of4P00`3ofdT0omQ80?oHB0070?oHB0030?oGA`3of4P0om]90080omQ800D0
omY90?oHB03ofDL0omY80?oIB0020?oJB0H0omQ800D0omY80?oJB@3og4T0^WhZ01XA1@0200000007
061=6@3od480on=80?oXB@3ofT@0oleA0?oGV@150?ooo`<0000000<0bH^@0?ooo`3oool0203oool0
103o_lH000000000000000050?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000
000000040?ooo`0507iGFP000000000001TA4P3od=P0103oool00`3RW:8000000000000200000003
0820P03oool0oooo0080oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`00000000000000
00@0oooo00<0onS/0000000000000P0000000`39Ri00oo?l0?ooo`030?ooo`030?b]]02bXZ@0oooo
0080oooo00H0o]KJ000000000000000004`d=P3olo`50?ooo`030?noaP1UADP0oooo0080oooo00@0
VI6B000000000000Bc@f2@3oool30000000301TB4P1UADP0IDE800P0IDE8103oool00`3od=P00000
00000002000000030>BoaP3oool0oooo0080oooo00<0o:fd06E5B03oool00P3oool01P3RW:800000
000000000000UfQ/0?oco0<0oooo00<0oo?l04`d=P0000000P0000000`3ac]40oooo0?ooo`020?oo
o`<0000000<0P61S0?ooo`3oool01@3oool01020H6<000000000000000040?ooo`060?7>d@000000
00000000001<=3H0oo?l0`3oool00`3olo`0UfQ/00000002000000030>:LXP3oool0oooo00<0oooo
0`0000000`3o_lH0oooo0?ooo`030?ooo`040?noaP0000000000000000L0oooo00@0P61S00000000
00000000103oool01@3ogn<00000000000000000P82000@0oooo00<0om3H0000000000000P000000
0`39Ri00oo?l0?ooo`030?ooo`070;5iOP3oool0oooo0?ooo`20P800/7Un0?oQjP050?ooo`05075>
D@00000000000000003ac]40^03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOo0?oooeX0oooo00T0oo?_0?o6V`3o/f40ojM20?n/AP3oZdT0ojQ80?n/B@3o]Dd0
1`3o^Dl02`3o`5<0ok9=0=]d<@0m80h0000000h80`1]?QH0oi<h0?o=C`3obTh0olM<00l0olQ=00<0
olM<0?o8C@3ob4d03`3ob4d0103obDh0olQ=0?o8C@3obDh:0?o8C@030?o9CP3oad`0olM<00<0olM<
00<0olI=0?o7C03oad`03P3oad`00`3ob4d0olM<0?o7C0040?o7C0030?o8C@3oad`0olM<0140olM<
00@0olQ=0?o7C03oad`0olI<1P3oad`00`3oaD`0olI<0?o7C0070?o7C0080?o7C@3oad`0olM<0?o7
C03oaDX0ok]60?nlA`3obD`20?o7C0030?o6B`3oad`0olM<00T0olM<00<0olI<0?o6B`3oaT`00P3o
aT`00`3oadd0olI<0?o6C0030?o6C0060?o;CP3oV3X02@D2054d4@3oiD`0on9;0`3ogdX00`3oh4X0
on1;0?oOBP090?oOBP030?oQB`3ogdX0omm:00<0omm:00<0omi:0?oOBP3ogdX0203ogdX01@3ogDT0
ome:0?oNBP3ogTX0on1;00L0omi:00@0ome90?oNBP3ogTX0omi:1`3ogTT00`3ofTP0ome90?oNB@07
0?oNB@030?oOB@3ofTP0om]900X0omi900<0omQ80?oOB@3ogTT0103ogDT01@3ogTT0ome90?oMB@3o
gDT0ome:00X0ome900<0omi90?oIA`3ogTT01`3ogDT0103ofdP0omi90?oKB03ogDT40?oLB@030?oM
B@3og4T0om]800@0oma900H0om]80?oLB@3og4T0oma90?oMBP3ogDT50?oLB@030?oMB@3ofTP0oma9
00L0oma900@0omi:0?oKB03ofdP0oma90P3ofdP00`3ogDX0om]80?oKB0070?oKB0030?oIB03ofTP0
om]800P0om]800H0oma90?oKB03ofdP0oma80?oKB@3ofdP20?oIB0050?oLB@3ofdP0omU80?oIB03o
fTT01@3ofDP0103oedL0omQ80?oJB03ofdT70?oJB0060?oIB03ofTP0omY80?oJB03of4P0oma90`3o
fTP70?oHB080om]90`3of4P00`3ofdT0omM70?oHB0090?oHB0030?oJB03of4P0omQ80080omQ800H0
omY80?oGA`3of4P0omY80?oHB03ofTP50?oHB0030?oJB03of4P0omQ800D0omQ800<0omY80?oFA`3o
f4P0203of4P00`3ofdT0omQ80?oHB0070?oHB00:0?oJB03oedP0omM70?oHB03ofTP0omY90?oHB03o
edL0omU80?oJB@/0omQ800X0on1;0?n_>@1lCaT09AL70000000O6@P0XX0Y0>>i=03BXTh0oo[eAP3o
ool3000000030<V;T03oool0oooo00P0oooo00@0oko600000000000000001@3oool3000000030?no
aP3oool0oooo00@0oooo00@0oko60000000000000000103oool0100I4A80000000000039Ri060?oo
o`0506E6B0000000000000000020P800103oool300000003081PH`3oool0oooo00D0oooo00@0P61S
0000000000000000103oool01@2bXZ@00000000000000000LDiA00/0oooo00D0VI6B000000000000
00000;n[[@070?ooo`050?oOh`3oool0oooo0?ooo`3;];H00`0000000`3onOh0oooo0?ooo`060?oo
o`<0000000<0IDI80?ooo`3oool0303oool01@1UADP00000000000000000hYbR00X0oooo00@06A4B
000000000000IDE81P3oool01@2bXZ@00000000000000000S8R900@0oooo0`0000000`20H6<0oooo
0?ooo`050?ooo`04081PH`0000000000000000@0oooo00D0S8R900000000000000000;:RY0060?oo
o`0406E5B0000000000001TA4PD0oooo0`0000000`3o_lH0oooo0?ooo`030?ooo`040?noaP000000
0000000000L0oooo00@0P61S0000000000000000103oool01@3ogn<00000000000000000P82000@0
oooo00D0IDE800000000000000000>:LXP0:0?ooo`030?oZl`3oool0oooo00D0oooo00D0i<G80000
0000000000000;n[[@2h0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0ooooF`3oool02P3onOL0om_=0?o0Q03o[f40ojY30?n/B@3oZ4P0ojU90?nfCP3o^U03
0?niC`040?o0D`3oaUD0oj9608a97`80000000@070l50;i/:@3od500om9@903ob4d00`3obDh0olM<
0?o8C@0;0?o8C@070?o9CP3oad`0olM<0?o7C03ob4d0olM<0?o8C@0?0?o7C0030?o8C@3oad`0olM<
00D0olM<00<0olQ=0?o7C03oad`0103oad`20?o7C@l0olM<00<0olQ=0?o7C03oad`0103oad`00`3o
aT`0olM<0?o7C00:0?o7C0040?o5BP3o^dH0oka70?o9C0h0olM<00<0olE<0?o7C03oaT`01`3oaT`0
1`3oadd0oke805D`4P000000WgPX0?oZCP3oh4X03`3ogdX00`3ohD/0omm:0?oOBP0>0?oOBP050?oN
B@3ogTX0omi:0?oNBP3ogdX01P3ogTX00`3ogDX0omY80?oNBP020?oNBPL0omi900<0omY80?oMB@3o
gTT01`3ogTT00`3ogdT0omY80?oKB@0:0?oNB@030?oHB03ogdT0omi900@0ome900H0omi:0?oMB@3o
gDT0ome90?oJB03og4T:0?oMB@030?oLB@3ogDT0ome900<0ome900@0om]90?oKB03ogDT0omQ80P3o
gDT70?oLB@030?oJB@3og4T0ome90080oma900H0ome90?oLB@3og4T0oma90?oMBP3ogDT?0?oLB@07
0?oNBP3ofdP0om]80?oLB@3og4P0om]80?oLB@0:0?oKB0030?oIA`3oedL0om]800L0om]800H0oma9
0?oKB@3ofdP0om]80?oMB@3ofTP60?oIB0030?oKB@3ofDP0omU800@0omU800<0omU70?oIB03ofdT0
1`3ofTP00`3ofDP0omY80?oJB0020?oJB0040?oKB@3ofTP0omY80?oKB@L0omQ800<0omY80?oHB03o
f4P00P3of4P0103ofTP0omU70?oGB03ofDT80?oHB0030?oIB@3of4P0omQ80080omQ800D0omY80?oJ
B@3ofDT0omM70?oJB00@0?oHB0040?oHA`3oeTL0omQ80?oJB0D0omQ800<0om]90?oHB03of4P0203o
f4P01@3ofDP0omA70?oIB03oedL0om]90080omQ800<0omU90?oJB03of4P01`3of4P0203ofTP0omQ8
0?oHB03of4P0on1:0?oVC@3oZCL0FST>0P0000000`0[81<0gKNm0?ooo`160?ooo`<0000000<0bH^@
0?ooo`3oool0203oool0103o_lH000000000000000050?ooo`<0000000<0oko60?ooo`3oool0103o
ool0103o_lH000000000000000030?ooo`050?oQjP00000000000000003ohNX01P3oool01@2ITI80
0000000000000000P82000@0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000
000000@0oooo00D0P61S00000000000000000<^d]P0;0?ooo`0507iGFP00000000000000003ol?D0
2`3oool01@3ac]400000000000000000o]KJ00P0oooo0`0000000`1UATP0oooo0?ooo`0;0?ooo`05
0?noaP00000000000000002GJ6`02P3oool01@3RW:800000000000000000on7Z00H0oooo00D0oo3e
0000000000000000075>D@040?ooo`<0000000<0P61S0?ooo`3oool01@3oool01020H6<000000000
000000040?ooo`05075>D@00000000000000003ol?D01P3oool01@3ohNX00000000000000000hYbR
00@0oooo0`0000000`3o_lH0oooo0?ooo`030?ooo`040?noaP0000000000000000L0oooo00@0P61S
0000000000000000103oool01@3ogn<00000000000000000P82000<0oooo00D0omoS000000000000
000004`d=P0C0?ooo`050?oioP00000000000000002ITI80^03oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooed0oooo01@0oogo0?o_iP3oe:l0okaa0?nY
C`3oZDH0oj]90?naB`3o]dh0okiA0>bTAP2TIR`0H3<E02HD2@0P4PL0RDlN0;n6=03o]4D0oli@0?o9
C@T0olQ=00<0olU>0?o8C@3obDh03P3ob4d00`3obDh0olQ=0?o8C@080?o8C@050?o9CP3ob4d0olQ=
0?o8C@3obDh00`3ob4d30?o9CP<0olQ=00@0olU>0?o7C03ob4`0olQ=3`3oad`00`3ob4d0olM<0?o7
C0080?o7C0030?o8C@3oad`0olM<00@0olM<00<0olQ=0?o7C03oad`0103oad`00`3ob4d0olM<0?o7
C0060?o7C0030?o8C@3oad`0olM<0080olM<00D0olQ=0?o7C03oad`0olM<0?o7C@030?o7C080olM=
1P3oad`0103oaDX0ok]60?nlA`3obD`80?o7C0030?o8C@3oad`0olM<00<0olM<1P3oaT`02`3oadd0
olI<0?o6C03oaT`0ol5:06<h5@000000Abd?0?[EA`3ohD/0on1:00@0omm:0P3oh4/00`3ogdX0on1:
0?oOBP060?oOBP030?oQB`3ogdX0omm:0080omm:00<0omm;0?oOBP3ogdX0203ogdX00`3ogTX0ome:
0?oNBP030?oNBP030?oOB`3ogTX0omi:00<0omi:00<0on1:0?oOBP3ogTX00P3ogTX70?oNB@030?oO
BP3ogTT0omi900L0omi900<0omm90?oJB03ofdT02P3ogTT00`3of4P0omm90?oNB@050?oMB@040?oN
B@3ogDT0ome90?oLB@`0ome90P3og4T00`3ogTT0oma90?oNBP020?oLB@040?oMB@3ogTT0ome90?oM
B@H0oma900<0omi:0?oLB@3og4T00`3og4T20?oKB@80oma900<0ome:0?oMB@3og4T01P3og4T00`3o
fdT0ome90?oLB@050?oLB@030?oNBP3ofdP0om]80080om]800<0omU80?oKB@3og4T02P3ofdP00`3o
fTT0oma90?oKB0020?oKB0060?oLB@3ofdT0om]80?oKB03og4X0oma90P3ofdP30?oKB@030?oJB@3o
fDP0omU800<0omU800<0omY80?oIB03ofDP0103ofDP00`3of4P0oma90?oKB@070?oJB0030?oKB@3o
fTP0omY80080omY800@0om]80?oHB03ofTT0omU81`3of4P00`3ofDP0omQ80?oHB0040?oHB0030?oI
B03oedP0omQ800D0omQ80`3ofDP00`3ofDT0omU80?oHB0020?oIB@050?oIB03oedP0omY90?oHB03o
fDP01@3of4P00`3ofDP0omQ80?oHB0060?oHB00:0?oIB03oedP0omU90?oEA`3ofDP0omQ80?oIB@3o
fDP0omQ80?oKB@X0omQ8103ofDP01`3of4P0omU80?oHB03ofDP0omY90?oIB03oedP01@3of4P20?oI
B00;0?oHB03ofDP0om]90?oG@@3oddP0on5]0?oJX@2aSiD0Me9F0=2Z/`3oo?h0A`3oool300000003
0<V;T03oool0oooo00P0oooo00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo
00@0oooo00@0oko600000000000000000`3oool0103o_lH000000000000000070?ooo`050?;Be@00
0000000000000020P800103oool300000003081PH`3oool0oooo00D0oooo00@0P61S000000000000
0000103oool01@0c8b@000000000000o;2d0ooco00/0oooo00@0<b<T000000000000/7Yn303oool0
1@3on?X06A8B000000000000_j^]00P0oooo0`0000000`1UATP0oooo0?ooo`0;0?ooo`0506E6B000
0000000003l/;@3onOh02P3oool0101<=3H0000000000015<3880?ooo`0408YPH`000000000002HJ
6`@0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000000000@0oooo00@09QXK
000000000000RV1S203oool01015<38000000000001<=3H40?ooo`<0000000<0oko60?ooo`3oool0
0`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0omoS0000
0000000000000820P0030?ooo`050;:SY000000000000000002OTiH04`3oool01@3om?H000000000
00000000P8200;P0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooomQ0?ooo`070?o]h`3o[X40oii30?n[BP3oX4D0Z5TV01lA1`0200000004064f503oZd40
om5A0?o;CP`0olQ=00D0olU>0?o8C@3ob4d0olQ=0?o9C00G0?o8C@030?o9CP3ob4d0olQ=00`0olQ=
00D0olM>0?o7C03oad`0olM<0?o8CP0H0?o7C0030?o8C@3oad`0olM<00/0olM<00<0olQ=0?o7C03o
ad`04@3oad`00`3oaT`0olM<0?o7C0040?o7C0060?o7C@3oad`0olM<0?o3BP3o^dH0oka73`3oad`6
0?o6C00;0?o7C03oaT`0olI<0?o6C02^Oc400000034O2`3o`d00onA<0?oQB`3oh4X01P3ogdX00`3o
h4X0omi:0?oOBP060?oOBP050?oQB`3ogdX0omm:0?oOBP3ogTX0303ogdX50?oNBP030?oOBP3ogTX0
omi:00<0omi:00<0oma90?oNBP3ogTX00P3ogTX50?oNB@80omm:2P3ogTT01@3ogdT0omY80?oKB@3o
gTT0omm:00P0omi900<0omU80?oOB@3ogTT01@3ogDT00`3ogTT0ome90?oMB@020?oNB@P0ome900<0
omi90?oJB03ofdP00P3og4T90?oMB@030?oLB@3of4P0ome900P0oma900<0omQ80?oLB@3ofDT00P3o
g4T00`3ogDX0ome90?oLB@040?oLB@040?oMBP3ogDT0ome90?oIA`H0oma900<0omi:0?oKB03ofdP0
0P3ofdP20?oLB0H0om]800<0oma90?oMBP3ogDX00`3ofdP20?oLB0H0om]800<0oma90?oKB03ofdP0
0P3ofdP0103og4X0om]90?oJB03ofdT40?oIB0030?oKB03ofDP0omU800D0omU800<0oma90?oKB03o
g4T03P3ofTP00`3of4P0omU90?oHB00=0?oHB0030?oGA`3oeTH0omQ80080omQ80P3ofDT20?oHB003
0?oJB03of4P0omQ80080omQ800H0omY90?oHB03of4P0omQ80?oGB03oedL90?oHB0030?oJB03of4P0
omQ800D0omQ800D0omY80?oGB03oeDH0om]90?oJB00<0?oHB0080?oIB03of4P0omQ80?oJB03ofDP0
omM70?oHB03oedL20?oHB0030?oIA`3oeTH0omQ80080omQ800T0omY80?oHB03of4P0omQ80?oJA`3o
cdX0onBc0?oYbP3ooOh0C03oool3000000030<V;T03oool0oooo00P0oooo00@0oko6000000000000
00001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000000`3oool01@3o
lo`00000000000000000on7Z00L0oooo0`0000000`20P800oooo0?ooo`020?ooo`<0000000<0P61S
0?ooo`3oool01@3oool01020H6<000000000000000030?ooo`050?oQjP00000000000000003RW:80
2`3oool01@3olo`00000000000000000oko600d0oooo00@0UfQ/000000000000P7Yn203oool30000
000306E6B03oool0oooo00X0oooo00D0on7Z00000000000000000>:LXP0:0?ooo`050?o`m@000000
000000000020H6<0203oool01@3o_lH00000000000000000on7Z00<0oooo0`0000000`20H6<0oooo
0?ooo`050?ooo`04081PH`0000000000000000<0oooo00D0on7Z00000000000000000?noaP080?oo
o`05081PH`00000000000000003ol?D00`3oool3000000030?noaP3oool0oooo00<0oooo00@0oko6
00000000000000001`3oool01020H6<000000000000000040?ooo`050?oOh`000000000000000020
P8000`3oool01@20LGD00000000000000000lLkA01<0oooo00D0/Z:T00000000000000000:FJV`2h
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooHP3o
ool0303oo?l0eXEb0?n:=`0i7`d00`000000001;:a00oi4g0?o1BP3ocDl0olQ=0?o9CP`0olQ=00@0
olU>0?o8C@3ob4d0olM<2@3ob4d01@3obDh0olQ=0?o8C@3ob4d0olU>00D0olQ=00<0olM<0?o8C@3o
b4d00P3ob4d00`3obDh0olQ=0?o8C@0<0?o8C@80olM<0P3ob4d;0?o7C0030?o8C@3oadd0olM<00/0
olM<00<0olQ=0?o7C03oad`02`3oad`00`3ob4d0olM<0?o7C0050?o7C0030?o8C@3oad`0olM<00P0
olM<00<0olI<0?o7C03oad`0203oad`0103oa4X0ok]60?nlA`3ob4h>0?o7C0T0olI<00P0olm?06@i
5P081040bWhY0?o]CP3oh4X0on5;0?oPBPH0omm:00<0ome90?oOBP3ogdX01P3ogdX0103ohD/0omm:
0?oOBP3ogTT20?oOBP030?oPB`3ogdX0omm:00H0omm:00<0omi:0?oNB@3ogdX02P3ogTX00`3ofdP0
omi:0?oNBP020?oNBPH0omi900<0omm:0?oNB@3ogTT02@3ogTT00`3ofdP0oma90?oNB@090?oNB@03
0?oIB03ogdT0omi900T0ome900<0omi90?oMB@3ogDT01@3ogDT01@3ofDL0omi90?oLB@3ogDT0omi9
00`0ome91@3og4T02`3ogTX0oma90?oLB@3og4T0omY90?oLB@3ogDT0om]80?oLB@3ogDX0ome900T0
oma900<0omi90?oLB@3og4T00`3og4T00`3ogTX0om]80?oKB0040?oKB0040?oIB03ofdP0ome:0?oM
BPT0om]800<0omM70?oKB03ofdP0103ofdP00`3og4T0om]80?oKB0020?oKB0030?oLBP3ofdT0omU8
00d0omU800@0oma90?oJB03ofTP0om]9303ofTP00`3ofdT0omM70?oGA`070?oHB0030?oJB03of4P0
omQ800L0omQ800<0omY80?oHB03of4P0203of4P00`3ofTT0omQ80?oHB0030?oHB0030?oEA`3oedL0
omQ80080omQ800D0omY80?oIB@3of4P0omQ80?oKB@090?oHB0040?oJB03oedL0omM70?oIB0P0omQ8
00<0om]90?oHB03of4P00`3of4P01P3ofTP0omQ80?oHB03of4P0omY80?oFA`<0omQ800T0omQ70?oH
B03ofTP0omQ80?oIB03of4P0omI60?o:H@3ok/d0C`3oool3000000030<V;T03oool0oooo00P0oooo
00@0oko600000000000000001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000
00000000103oool0100b8b@0000000000039Ri070?ooo`<0000000<0P8200?ooo`3oool00P3oool3
00000003081PH`3oool0oooo00D0oooo00@0P61S00000000000000000`3oool01@3o_lH000000000
00000000om3H00/0oooo00@0oko600000000000000003P3oool0103RW:8000000000001nEeX80?oo
o`<0000000<0IDI80?ooo`3oool02P3oool01@3o_lH00000000000000000om3H00X0oooo00D0omoS
0000000000000000081aM@080?ooo`050?oQjP00000000000000003o_lH00`3oool300000003081P
H`3oool0oooo00D0oooo00@0P61S00000000000000000`3oool01@3o_lH00000000000000000on7Z
00P0oooo00D0P75e00000000000000000?oOh`030?ooo`<0000000<0oko60?ooo`3oool00`3oool0
103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0omoS000000000000
00000820P0030?ooo`05081PH`00000000000000003oj>`04P3oool00`3ohNX0<b<T000000020000
00030=Rl_`3oool0oooo0;H0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooomS0?ooo`090?oSj00l9bD02@<000H51P2IF2D0ol550?o3B`3oa4/0olI<00l0
olQ=00<0olQ>0?o8C@3ob4d02@3ob4d00`3obDh0olQ=0?o8C@060?o8C@030?o8C03ob4d0olQ=00<0
olQ=00@0olU>0?o8C@3ob4d0olU>2P3ob4d00`3obDh0olM<0?o7C00K0?o7C0030?o8C@3oad`0olM<
00/0olM<00<0olQ=0?o7C03oad`05@3oad`00`3oadd0olM<0?o7C0030?o7C0040?o5BP3o^TH0okU5
0?o9C080olM<0`3ob4d90?o7C0P0olI<00T0oli?0?nY@00G3@D0IT4E0?oTB`3ohTX0on1:0?oQB`3o
h4X01@3ogdX20?oPBPP0omm:00D0on5;0?oOBP3ogdX0ome90?oNBP0:0?oOBP030?oNB@3og4T0omm:
00@0omi:00<0omm:0?oNBP3ogTX00`3ogTX00`3ogdX0omi:0?oNBP020?oNBPH0omi900<0om]80?oM
B@3ogTT02@3ogTT20?oOB@X0omi900<0oma80?oNB@3ogTT02@3ogDT01`3ofDL0ome90?oMB@3ogDT0
omi90?oJB03ofDP01@3ogDT00`3ofTP0omi:0?oMB@090?oMB@80omY8103og4T00`3ogDT0oma90?oL
B@030?oLB@050?oMB@3ofDP0oma90?oMBP3ogDT02@3og4T00`3of4P0oma90?oLB@030?oLB@040?oN
BP3ofdP0om]80?oLB@80ome:00<0om]80?oKBP3ofdP0303ofdP00`3oedL0om]80?oKB0030?oKB003
0?oLB@3ofdP0om]80080om]800D0oma:0?oKB@3ofDP0omQ80?oKB0040?oIB0030?oKB03ofDP0omU8
00@0omU800@0om]80?oJB03ofTP0om]91P3ofTP00`3ofdT0omY80?oJB0030?oJB0040?oKB@3of4P0
omY80?oIB0H0omQ800<0omY80?oHB03of4P00`3of4P01P3ofTP0om]90?oHB03ofDP0omA60?oJB0D0
omQ800D0omU80?oHB03of4P0omQ80?oJB@060?oHB0030?oGA`3of4P0omQ800D0omQ800<0om]90?oH
B03of4P02@3of4P00`3oeDL0omM80?oHB0050?oHB0030?oJB03ofDP0omQ800X0omQ800D0omU80?oB
A@3ofDT0omQ80?oFA`020?oJB0040?oH@`3of4d0ola^0?oR]e40oooo0`0000000`39Ri00oooo0?oo
o`080?ooo`040?noaP0000000000000000D0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?no
aP0000000000000000@0oooo00D0UfQ/0000000000006A4B0?oco0060?ooo`<0000000<0P8200?oo
o`3oool00P3oool300000003081PH`3oool0oooo00D0oooo00@0P61S00000000000000000`3oool0
103RW:80000000000000000<0?ooo`040?b]]00000000000000000h0oooo00@0on7Z000000000000
F3do203oool30000000306E6B03oool0oooo00X0oooo00@0hYbR00000000000000002`3oool01@3a
c]400000000000000000P82000T0oooo0`000000103RW:80oooo0?ooo`3oool300000003081PH`3o
ool0oooo00D0oooo00@0P61S00000000000000000`3oool0103RW:8000000000000000090?ooo`05
0820P000000000000000003ac]400`3oool3000000030?noaP3oool0oooo00<0oooo00@0oko60000
0000000000001`3oool01020H6<000000000000000040?ooo`050?oOh`000000000000000020P800
0`3oool0101aCU40000000000000000A0?ooo`030?oQjP2GJ6`0000000<0000000<06A4B0?o`m@3o
ool0]`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
of@0oooo00/0k/c?0::GV03@]kT0onS?0?oIY03o`fX0ol1B0?o0BP3o`DT0ol=;0?o5B`020?o8C@03
0?o9C@3ob4d0olQ=00H0olQ=00D0olU?0?o8C@3ob4d0olQ=0?o9CP080?o8C@030?o9CP3ob4d0olQ=
00`0olQ=00<0olU>0?o8C@3ob4d02`3ob4d01@3obDh0olM<0?o7C03oad`0olQ=00<0olM<0P3ob4d4
0?o7C080olQ=103oad`00`3ob4d0olM<0?o7C0070?o7C0030?o8C@3oad`0olM<00<0olM<00<0olQ=
0?o7C03oad`01@3oad`00`3ob4d0olM<0?o7C00D0?o7C080olI<1@3oad`0103oaD/0oka60?nnB03o
bD`80?o7C0030?o8C@3oad`0olM<0080olM<00<0olQ=0?o7C03oaTd0103oaT`01`3oadd0oli?0>jW
?`159Ph0=b<<0?oAA@3ohT/00P3oh4X00`3ohD/0on1:0?oOBP040?oOBP030?oPB`3ogdX0omm:00L0
omm:00@0on5;0?oOBP3ogdX0omi:2`3ogdX00`3ogTT0on1:0?oOBP040?oNBP030?oOB`3ogTX0omi:
0080omi:00<0ome:0?oNBP3ogTX00`3ogTX50?oNB@030?oOBP3ofdT0ome900X0omi90P3ogdT20?oN
B@030?oOBP3ogTT0omi900D0omi900<0omm:0?oNB@3ogTT01@3ogDT02@3ogTT0ome:0?oLB@3ogTT0
omU80?oMB@3ogTT0oma90?oNB@060?oMB@030?oNB@3og4T0ome900X0ome90P3og4T00`3ofdT0oma9
0?oLB@020?oLB@030?oMB@3og4T0oma90080oma90P3ogDT0103ogDX0oma90?oLB@3og4T20?oMB@<0
oma900D0omi:0?oMBP3ogDX0ome:0?oKB@020?oLB@80ome:00<0omi:0?oKB03ofdP01@3ofdP00`3o
fDP0om]80?oKB00:0?oKB0070?oKB@3og4T0oma90?oLB@3ofdT0om]80?oLB@040?oKB0030?oLBP3o
fdT0omU80080omU800D0omQ80?oIB03ofDP0omU80?oKB@070?oIB080omY800<0omU90?oKB@3ofTP0
2P3ofTP02@3ofdT0omQ80?oHB03ofDP0omM80?oHB03ofDP0omQ80?oIB0020?oHB0050?oKB@3of4P0
omQ80?oIB03ofDT0103of4P00`3ofDP0omM70?oHB0040?oHB0050?oIB03of4P0omQ80?oHB03ofTT0
203of4P0103ofDP0omQ80?oHB03ofTT20?oHB0030?oKB@3of4P0omQ800X0omQ800H0omU80?oIB@3o
edL0omQ80?oIB@3ofDP:0?oHB00=0?oIB03of4P0omQ80?oHB03ofDP0omQ80?oIB@3oedH0omQ70?oG
D@3ocV00onFV0?o_d`1C0?ooo`<0000000<0bH^@0?ooo`3oool0203oool0103o_lH0000000000000
00050?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000040?ooo`080?o`
m@1aCU4000000000000V6Q/0P6Q/0>G5b03onOh30?ooo`<0000000<0P8200?ooo`3oool00P3oool3
00000003081PH`3oool0oooo00D0oooo00@0P61S00000000000000000`3oool01039Ri0000000000
0000000<0?ooo`040<V;T00000000000000000/0P61S00P0omWQ0?ooo`3oool0oooo06E6B0000000
4`d>0?oioPL0oooo0`0000000`1UATP0oooo0?ooo`0:0?ooo`040<V;T00000000000000000/0oooo
00D0i<G800000000000000000820P0090?ooo`<0000000@0bH^@0?ooo`3oool0oooo0`0000000`20
H6<0oooo0?ooo`050?ooo`04081PH`0000000000000000<0oooo00@0bH^@00000000000000002@3o
ool01@20P8000000000000000000i<G800<0oooo0`0000000`3o_lH0oooo0?ooo`030?ooo`040?no
aP0000000000000000L0oooo00@0P61S0000000000000000103oool01@3ogn<00000000000000000
P82000<0oooo00@0IDI800000000000000003P3oool00`3ol?D0/Z:T0616B0040000000300d92@1a
CU40lLkA0;T0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooomZ0?ooo`0:0?oZfP3ocH`0okYA0?nl?03o`TP0ol1:0?o3B`3oaD`0olM=0?o9C@80olQ=00@0
olU<0?o9C@3ob4d0olQ=0P3obDh40?o8C@030?o9CP3ob4d0olQ=00@0olQ=00H0olU>0?o8C@3ob4d0
olQ=0?o7C03ob4`B0?o8C@030?o7C03ob4d0olQ=0080olQ=2`3oad`00`3ob4d0olM<0?o7C0040?o8
CAX0olM<00<0olQ=0?o7C@3oad`0103oad`00`3ob4d0olM<0?o7C0060?o7C0030?o5C03oad`0olM<
00@0olM<00@0olI=0?o7C03oad`0olI<0`3oad`0103oa4/0ok]60?nlA`3obD`60?o7C0030?o8C@3o
ad`0olM<00D0olM<1P3oaT`01`3obdl0ok5403LP30000000/8X^0?oSB`3oh4X00P3ohD/00`3oh4X0
omm:0?oOBP030?oOBP030?oPBP3ogdX0omm:00P0omm:00@0on5;0?oOBP3ogdX0on1:2`3ogdX00`3o
gDT0on1:0?oOBP090?oNBP030?oJB03ogTX0omi:00<0omi:1P3ogTT00`3ogDP0ome90?oNB@090?oN
B@80omm92P3ogTT00`3ogdX0omi90?oNB@040?oMB@070?oLB@3og4P0ome90?oHB03ogTT0omm:0?oN
B@0;0?oMB@030?oKB03ogTX0ome900P0ome900<0oma90?oHB03ofTP00`3og4T01@3ogDT0ome:0?oL
B@3og4T0ome900<0ome:00@0om]80?oKB@3og4T0oma90P3ogDX70?oLB@030?oKB03ogDT0oma90080
oma900<0omi:0?oKB03ofdP01@3ofdP00`3og4T0om]90?oLB00<0?oKB0030?oJB03ofdP0om]800H0
om]800L0oma:0?oKB@3ofDP0omU80?oKB03ofTP0omM700<0omU800<0omY90?oIB03ofDP0103ofDP3
0?oJB0030?oIA`3ofDT0omY800X0omY8103of4P00`3oeDL0om]90?oIB@020?oIB@030?oHB03ofTT0
omQ80080omQ800<0omU80?oHB03of4P0103of4P00`3ofTP0omM70?oGA`020?oHB0050?oJB@3of4P0
omQ80?oHB03ofTT02@3of4P00`3ofDL0omE70?oHA`020?oHB0030?oKB@3of4P0omQ800T0omQ800L0
omU90?oHB03ofTP0omQ80?oGA`3ofDP0omY800/0omQ800X0omY80?oKB@3ofdT0omQ80?oKA@3oecX0
om9A0?oLO@3ok^00ooclE@3oool3000000030<V;T03oool0oooo00P0oooo00@0oko6000000000000
00001@3oool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000001P3oool00`1a
CU40000000000009000000030820P03oool0oooo0080oooo0`0000000`20H6<0oooo0?ooo`050?oo
o`04081PH`0000000000000000<0oooo00@0bH^@0000000000000000303oool00`39Ri0000000000
000<000000050?noaP3oool0oooo0?ooo`3RW:800P0000000`3l[K@0oooo0?ooo`050?ooo`<00000
00<0IDI80?ooo`3oool02P3oool01039Ri00000000000000000;0?ooo`050>C5b000000000000000
0020P8002@3oool3000000040<V;T03oool0oooo0?ooo`<0000000<0P61S0?ooo`3oool01@3oool0
1020H6<000000000000000030?ooo`040<V;T00000000000000000T0oooo00D0P820000000000000
00000>C5b0030?ooo`<0000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?oo
o`04081PH`0000000000000000@0oooo00D0omoS00000000000000000820P0030?ooo`0406E6B000
00000000000000d0oooo00<0oko601TA4P000000100000000`1<=3H0oo?l0?ooo`2j0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooJ`3oool01@3on?@0
om^h0?oAT@3o/dT0okm10080ol1:00<0ol9;0?o5C03ob4d01@3ob4d20?o9CP/0olQ=00D0olU>0?o8
C@3ob4d0olM<0?o8C00A0?o8C@030?o7C03ob4d0olQ=00@0olQ=2`3oad`0103ob4d0olM<0?o7C03o
ad`30?o8C@80olM<00<0olQ=0?o7C03oad`0303oad`00`3ob4d0olM<0?o7C0060?o7C0030?o8C@3o
add0olM<00`0olM<00<0olI<0?o7C03oad`01@3oad`02`3oadd0olM<0?o7C03oad`0olE<0?o7C03o
aT`0olE:0?nkAP3o_4L0olU<00T0olM<00<0olI<0?o7C03oad`00P3oad`60?o6C0050?o9C@2GER40
000000h90P3oc4@00P3oh4X20?oQB`030?oPBP3ogdX0omm:0080omm:00<0on1;0?oOB`3oh4/02@3o
gdX00`3ohD/0omm:0?oOBP0<0?oOBP030?oPBP3ogdX0omm;00@0omi:00D0omm:0?oOB`3ogTX0omi:
0?oOBP060?oNBPD0omi900<0omi:0?oPB@3ogTT02P3ogTT20?oOB@/0omi900X0omm90?oNB@3ogTT0
omi:0?oJB03og4T0ome90?oKB03ogdT0omi90P3ogDT00`3ogdT0ome90?oMB@090?oMB@030?oFA`3o
g4X0ome900P0ome90P3og4T01@3ogTX0ome:0?oMBP3ogDX0ome900<0oma900@0ome90?oMBP3ogDX0
ome:0P3ofdP00`3ogDT0oma90?oLB@040?oLB@060?oMBP3og4T0oma90?oLB@3ogDT0om]80`3og4T0
0`3ogTX0om]80?oKB0060?oKB0030?oJB03ofTL0om]800D0om]800<0oma90?oKB03ofdP00`3ofdP0
103ofDP0omY70?oLB@3ofdT50?oKB0030?oLBP3ofdT0omU80080omU800<0om]80?oJB03ofDP00P3o
fDP00`3ofTT0omU80?oIB0040?oIB0@0omY80P3ofdT00`3ofDP0omY80?oJB0070?oJB080omQ800D0
omY90?oHB03of4P0omY80?oIB0070?oHB0030?oIB@3ofTP0omQ800D0omQ800D0omU80?oGA`3ofDT0
omQ80?oIB@0?0?oHB0040?oGA`3of4P0omQ80?oKB@T0omQ800@0omY80?oHB03ofDT0omY90P3of4P0
0`3ofTP0omM70?oGA`090?oHB0030?oIB@3of4P0omY80080omY800D0omU40?o>F03oghl0onFn0?oi
l@1G0?ooo`<0000000<0bH^@0?ooo`3oool0203oool0103o_lH000000000000000050?ooo`<00000
00<0oko60?ooo`3oool0103oool0103o_lH000000000000000060?ooo`030?oXk01nEeX0000000T0
000000<0P8200?ooo`3oool00P3oool300000003081PH`3oool0oooo00D0oooo00@0P61S00000000
000000000`3oool0103l[K@0000000000000000<0?ooo`030<V;T0000000000000`0000000D0oko6
0?ooo`3oool0oooo0?oQjP02000000030;1iOP3oool0oooo00D0oooo0`0000000`1UATP0oooo0?oo
o`0:0?ooo`040?b]]00000000000000000/0oooo00D0lLkA00000000000000000820P0090?ooo`<0
000000@0hYbR0?ooo`3oool0oooo0`0000000`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000
000000<0oooo00@0hYbR00000000000000002@3oool01@20P8000000000000000000lLkA00<0oooo
0`0000000`3o_lH0oooo0?ooo`030?ooo`040?noaP0000000000000000L0oooo00@0P61S00000000
00000000103oool01@3ogn<00000000000000000P82000<0oooo00@0OUMJ0000000000000000303o
ool00`3oj>`06A4B0000000300000003038S9039Ri00ooWn0;`0oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooom]0?ooo`0;0?oin`3og;d0olR10?nm@P3o
`TL0ol1:0?noB@3o`d/0olA;0?o8C@3obDd03P3ob4d20?o9CQ@0olQ=00<0olM<0?o8C@3ob4d01@3o
b4d30?o7C080olQ=2P3oad`00`3ob4d0olM<0?o7C0050?o7C0050?o8C@3oad`0olM<0?o7C03ob4d0
0P3oad`00`3ob4d0olM<0?o7C00;0?o7C0030?o8C@3oad`0olM<00<0olM<0P3ob4d60?o7C0030?o6
C03oad`0olM<00`0olM<00D0olI<0?o4BP3o^dH0oka70?o9C00>0?o7C0H0olI<00D0nJa2014:1000
0000/g4U0?oTB`040?oPBP030?oQB`3oh4X0omm:0080omm:00<0on1:0?oPB`3oh4/01P3ogdX30?oP
B`030?oQB`3oh4/0omm:00/0omm:00@0ome90?oOBP3oh4X0omm;203ogTX20?oOBPD0omi:1@3ogTT0
0`3ogdX0on1:0?oNB@0:0?oNB@80omm92`3ogTT01@3ogdT0ome90?oKB@3ogdT0om]800L0ome900<0
om]80?oMB@3ogDT02@3ogDT0103og4X0oma90?oMB@3ogTT30?oNBP@0ome900@0oma90?oMB@3of4P0
oma90P3ogDT00`3og4T0ome:0?oLB@060?oLB@030?oJB03ogDT0oma900D0oma900<0ome90?oLB@3o
g4T00P3og4T01@3ofdP0om]90?oLB@3og4T0omi:00P0om]800<0om]90?oJB03ofdP0103ofdP20?oL
B@D0om]80P3ofTP00`3og4T0om]80?oKB0040?oKB0030?oLBP3ofdT0omU800<0omU800<0omY90?oK
B@3ofDP0203ofDP50?oJB0030?oKB03ofTT0omY800L0omY800@0omU80?oJB03of4P0omY80`3of4P0
1@3ofDP0omE70?oJB03of4P0omY900<0omQ800<0omU90?oJB03of4P01`3of4P00`3ofdP0omM70?oH
B00?0?oHB0040?oJB03oeTL0omU90?oKB@L0omQ800<0omY80?oIB03of4P00P3of4P00`3ofDP0omQ8
0?oHB0030?oHB0030?oEA`3of4P0omU800<0omQ800/0omU90?oJB03of4P0omY80?oHB03ofTP0omY1
0?oB?`3ogI00onoF0?oloP1I0?ooo`<0000000<0bH^@0?ooo`3oool0203oool0103o_lH000000000
000000050?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000080?ooo`04
0?oQjP39Ri00OUMJ01TA4PH0000000<0P8200?ooo`3oool00P3oool300000003081PH`3oool0oooo
00D0oooo00@0P61S00000000000000000`3oool01@3o_lH00000000000000000oko600/0oooo00@0
oko60000000000000000203oool3000000030?noaP3oool0oooo0080oooo00<0<R<T0000001;=3H0
1`3oool30000000306E6B03oool0oooo00X0oooo00D0oko600000000000000000?noaP0:0?ooo`05
0?oOh`000000000000000020LGD0203oool01@3ohNX00000000000000000oko600<0oooo0`000000
0`20H6<0oooo0?ooo`050?ooo`04081PH`0000000000000000<0oooo00D0oko60000000000000000
0?oQjP080?ooo`05081aM@00000000000000003ogn<00`3oool3000000030?noaP3oool0oooo00<0
oooo00@0oko600000000000000001`3oool01020H6<000000000000000040?ooo`050?oOh`000000
000000000020P8000`3oool01@20H6<00000000000000000omoS00/0oooo00H0_j^]000000000000
000000d92@3RW::o0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWiol0ooooK`3oool02`3oo?T0onS<0?oG[@3oaW/0okeA0?o0B`3o`4T0ol990?o4B`3oaD`0olI<
00d0olQ=00<0olU>0?o8C@3ob4d03P3ob4d00`3obDh0olQ=0?o8C@090?o8C@T0olM<00<0olQ=0?o7
C03oad`00`3oad`00`3ob4d0olM<0?o7C0080?o7C0030?o8C@3oad`0olM<0080olQ=3@3oad`00`3o
b4d0olM<0?o7C00C0?o7C0030?o7C@3oad`0olM<00@0olM<00D0olI<0?o3BP3o^dH0oki70?o9C005
0?o7C0030?o8C@3oad`0olM<00H0olM<103oaT`01`3oadd0olU=07mA7`081@80Z6XT0?oLB@3ohT/0
103oh4X00`3ohD/0on1:0?oOBP0<0?oOBP80on1:00<0on5;0?oOBP3ogdX01P3ogdX50?oPB`80omm:
00<0on1:0?oOB`3ogTX01@3ogTX00`3ogdX0omm;0?oNB`060?oOB`030?oNB@3ogdX0omi900l0omi9
00<0omm:0?oOB@3ogTT00`3ogdX01P3ogTT0omm:0?oOBP3ogdX0ome:0?oOBP80ome:00<0omm:0?oN
BP3ogTX00P3ogTX30?oMB@040?oNBP3ogTT0ome90?oGB080ome9203ogTX01@3ogDT0omi90?oKB@3o
gTX0ome900<0omi9103ogDT@0?oLB@040?oKB@3og4T0om]90?oKB@@0oma900@0ome:0?oLB@3og4T0
oma90P3ofdT30?oLB@P0om]800<0oma90?oLB03ofdP0103ofdP20?oLB@H0om]800<0om]90?oLB@3o
g4P01P3ofdP60?oIB0050?oKB@3ofDP0om]90?oIB03ofTT01@3ofDP60?oJB0070?oKB@3ofTT0om]9
0?oKB@3ofTT0omY80?oKB@030?oJB0030?oIB03of4P0omQ800<0omQ800<0omU80?oGB03of4L00P3o
fDP30?oHB0030?oJB@3ofTP0omQ800T0omQ800<0omU80?oIB@3of4P03P3of4P0103ofDP0omY80?oF
A`3ofDT20?oHB0<0omU81`3of4P00`3ofTT0om]90?oHB0030?oHB0040?oJB03oedP0omU90?oHB080
omU800P0omU70?oIB03of4T0omIR0?oMRP3ojLD0oo?J0?omne/0oooo0`0000000`0I4Q80<b<T03<S
900603<S9080oooo00@0oko600000000000000001@3oool3000000030?6^]03oool0oooo00@0oooo
00@0oko600000000000000003`3oool3000000030820P03oool0oooo0080oooo0`0000000`1iEeX0
oooo0?ooo`050?ooo`04081PH`0000000000000000@0oooo00@04`d>000000000000_H:72`3oool0
1@3ogn<00000000000000000onS/00H0oooo00@0onS/00000000000000001@3oool0102mPXL00000
0000003nd=P60?ooo`<0000000<03@T903<S900c8b@01P0c8b@00`2;Gf<0oooo0?ooo`020?ooo`04
02HJ6`00000000000;f2Q`X0oooo00D0ooSj00d92@0000000000079CEP080?ooo`050>BUZ`000000
000000L51@3ol?D00`3oool30000000307UGFP3oool0oooo00D0oooo00@0P61S0000000000000000
0`3oool01@3ol?D01`D5000000000000i:F[00P0oooo00D0LU=F0000000000003@T90?ohnP030?oo
o`<0000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`000000
0000000000@0oooo00D0omoS00000000000000000820P0030?ooo`0509>=S@00000000000000003N
`L<02`3oool01@20L7800000000000000000bk6e0<00oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomc0?ooo`060?ohm03oa8h0ok]H0?o3E@3o_TD0ol58
0P3o`4X00`3oa4/0olQ=0?o8C@070?o8C@030?o7C03ob4d0olU>01`0olQ=3`3oad`01@3ob4d0olM<
0?o7C03oad`0olQ=00X0olM<0`3ob4d20?o7C0030?o8C@3oad`0olM<00H0olM<00<0olQ=0?o7C03o
ad`02@3oad`00`3oaT`0olM<0?o7C00<0?o7C0070?o5C03oad`0olM<0?o4BP3o/T80oki70?o9C00>
0?o7C0@0olI<00H0olY=0?nL>`081040Vf4P0?oWC@3ohT/50?oPBP030?oQB`3oh4X0omm:0080omm:
00@0omi90?oOBP3ogdX0on5;203ogdX00`3oh4/0ome90?oOBP0;0?oOBP040?oNB@3ogdX0on1:0?oO
B`D0omi:0P3ogd/00`3ogTX0omm:0?oNBP050?oNBPD0omi900<0ome90?oLB03ogTT02P3ogTT00`3o
gdX0omi90?oNB@020?oNB@050?oMB@3ogdX0oma90?oMB@3ogdT00P3ogTT00`3og4T0omQ80?oOB@07
0?oMB@040?oNB@3ogDT0ome90?oOBP`0ome900<0omQ70?oMB@3ogDT0203ogDT20?oLB@040?oJB03o
g4T0oma90?oLB@80ome91P3og4T20?oMB@80oma900<0om]90?oMB@3og4T01`3og4T0103ofdP0om]9
0?oLB@3og4T:0?oKB0030?oJB@3ofDP0om]80080om]80P3og4T80?oKB0030?oHBP3ofdP0om]800@0
om]8203ofDP00`3of4P0oma90?oIB0050?oIB0D0omY80P3ofdT00`3ofdP0omY80?oGA`070?oJB0T0
omQ800H0omY90?oJB03of4P0omQ80?oJB@3ofTP:0?oHB080omU800<0omM70?oHB03of4P0303of4P0
1@3ofdT0omY80?oHB03ofDP0omA700`0omQ800<0om]90?oHB03of4P00P3of4P02@3ofdT0omQ80?oG
A`3oe4L0om]60?oFB03ogEP0ola/0?oM]@1P0?ooo``000000P3oool0103o_lH00000000000000005
0?ooo`<0000000<0/7Un0?ooo`3oool0103oool0103RW:80000000000000000?0?ooo`<0000000<0
P8200?ooo`3oool00P3oool30000000305Pm?`3oool0oooo00D0oooo00@0LDiA0000000000000000
103oool01@1H?Cl000000000000I4A80ooWn00/0oooo00@0<b<T000000000000hYbR1P3oool0103l
[K@000000000001UADP50?ooo`040?oQjP00000000000;1iOPH0oooo300000000`1UADP0oooo0?oo
o`020?ooo`050;1iOP000000000001TA4P3olo`02P3oool0101nEeX000000000000V6Q/80?ooo`04
04/d=P000000000003l/;@@0oooo0`0000000`1H?Cl0oooo0?ooo`050?ooo`04075>D@0000000000
000000@0oooo00@0?b`]000000000000Bc@f203oool0100V6Q/000000000001nEeX40?ooo`<00000
00<0bH^@0?ooo`3oool00`3oool01@3o_lH00000000000000000oko600H0oooo00@0P61S00000000
00000000103oool01@3ogn<00000000000000000P82000<0oooo00D0f;bo000000000000000008b2
Q`0;0?ooo`04081PH`000000000000000<40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooome0?ooo`0:0?ofk@3oekl0ol5U0?nmC@3o_T80ol570?o0BP3o
`DX0olA;0?o7C0P0olQ=0P3obDh60?o8C@030?o9CP3ob4d0olQ=00H0olQ=00<0olM<0?o8C@3ob4d0
2@3ob4d30?o7C0040?o8C@3oad`0olM<0?o8C@P0olM<00<0olQ=0?o7C03oad`0303oad`00`3ob4d0
olM<0?o7C0020?o7C0030?o8C@3oad`0olM<00H0olM<00<0olQ=0?o7C03oad`00`3oad`00`3ob4d0
olM<0?o7C0020?o7C0030?o6C03oad`0olM<0100olM<00<0ol=:0?njAP3o]D<01`3oad`00`3oaT`0
olM<0?o7C0050?o7C0<0olI<00H0olM<0?nlA`1O=Q@08QH70?o2?`3oj4`60?oPBP030?oQB`3oh4X0
omm:00h0omm:00<0on5;0?oPBP3ogdX02P3ogdX20?oPBP030?oOBP3oh4X0omm;00P0omi:00<0omm:
0?oNBP3ogTX0103ogTX50?oNB@030?oMB@3og4T0omi900X0omi900P0omm:0?oNB@3ogDT0ome90?oN
BP3of4P0ome:0?oOB@@0omi900@0oma90?oHB03ogTT0omm:2@3ogDT20?oNB@/0ome90P3ogTT80?oM
B@040?oMBP3og4T0oma90?oMB@<0oma90P3ogDT70?oLB@060?oJB03ofdT0oma90?oLB@3ofdP0oma8
1`3og4T0103ogDT0omM70?oLB@3og4T80?oKB0<0oma900@0omY90?oKB03ofdP0om]80P3og4T90?oK
B0030?oIB03ofdP0om]800<0om]82@3ofDP00`3of4P0om]90?oIB0020?oIB0050?oKB@3ofDP0omY8
0?oJB03ofdT01@3ofTP00`3ofdP0omY80?oIB0060?oJB0T0omQ800H0omM70?oKB@3of4P0omQ80?oJ
B@3ofTP;0?oHB0040?oKB@3oedL0omM70?oIB0/0omQ800P0omU80?oHB03ofTP0omQ80?oIB03oedL0
omI70?oIB@X0omQ800<0omY80?oHB03ofDP00P3ofTP01`3of4P0omY80?oI@@3oeCl0omIE0?oBK`3o
lo80HP3oool<00000080oooo00@0oko600000000000000001@3oool30000000301TA4P3onOh0oooo
00@0oooo00@0/7Un000000000000Bc@f3P3oool01@3ogn<00000000000000000YIZK00@0oooo0`00
00000`0=2@T0oo?l0?ooo`050?ooo`0405Pm?`000000000004/d=P@0oooo00D0P75e000000000000
00000>C5b00;0?ooo`0406E6B0000000000007iGFPH0oooo00@0/7Un000000000000bH^@1P3oool0
0`0I4Q80000004/d=P060?ooo``0000000<0IDE80?ooo`3oool00P3oool01@3ohNX0000000000000
0000bH^@00X0oooo00D0hYbR00000000000000000?oQjP060?ooo`050?o`m@00000000000000001a
CU40103oool30000000300d92@3olo`0oooo00D0oooo00@0F3do000000000000Bc@f103oool01@1a
CU400000000000000000oo3e00H0oooo00D0on7Z00000000000000000>:LXP040?ooo`<0000000<0
OUMJ0?ooo`3oool00`3oool01@39Ri000000000000000000bH^@00H0oooo00@0IDI8000000000000
Bc@f103oool01@3ogn<00000000000000000P82000<0oooo00D0oo3e000000000000000006E6B00;
0?ooo`04081aM@000000000000000<40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooomg0?ooo`060?o`k03obi40olAX0?nlD`3o_T00ol5:0P3o`4X01@3o
a4/0olM=0?o8C@3ob4d0olU=00<0olQ=00<0olU>0?o8C@3ob4d01`3ob4d00`3obDh0olQ=0?o8C@03
0?o8C@030?o8CP3ob4d0olQ=00X0olQ=3`3oad`00`3ob4d0olM<0?o7C0050?o7C0030?o8C@3oad`0
olM<00@0olM<00<0olQ=0?o7C03oad`01@3oad`20?o7C@@0olM<00<0olQ=0?o7C03oad`06`3oad`0
0`3o`dX0ok]60?nnA`050?o7C0030?o8C@3oad`0olI;00L0olM<0`3oaT`01P3ocTl0_VdZ0000001f
BaT0ooAA0?oOBPH0on1:00D0on5;0?oPBP3ogdX0omm:0?oNB@0<0?oOBP030?oOB`3ogdX0omm:00D0
omm:00<0on1;0?oOBP3ogdX00P3ogdX01@3ogTT0omm:0?oOBP3oh4X0omm;00P0omi:00<0oma90?oN
BP3ogTX0103ogTX60?oNB@030?oMB@3ogTT0omi900T0omi900@0ome90?oNB@3ogDP0oma9203ogTT0
103og4T0omQ80?oNB@3ogdX70?oMB@040?oNB@3ogDT0ome90?oLB0@0ome900<0omi90?oMB@3ogDT0
3P3ogDT0103ogDX0oma90?oLB@3ofdP<0?oLB@070?oKB03ofdT0oma90?oLB@3ogDT0om]80?oJB007
0?oLB@030?oMB@3og4T0oma900/0om]800@0omQ70?oJB03ofdP0om]80P3og4T90?oKB0030?oJB@3o
fTP0om]800<0om]82@3ofDP20?oHB0050?oKB03ofDP0omU80?oLBP3ofdP02@3ofTP00`3ofdP0omQ8
0?oJB0050?oJB0T0omQ800<0omY80?oGA`3oedL03`3of4P00`3ofTP0omM70?oIB0090?oHB0050?oJ
B03of4P0omY90?oHB03ofTP00`3of4P0103ofDT0omM70?oGA`3ofTP80?oHB00;0?oJB03of4P0omU8
0?oIB@3ofdT0oma60?oFA03of6P0omAa0?oH/P3ono80H`3oool3000000030<V;T03oool0oooo00P0
oooo00@0oko600000000000000001@3oool4000000030>C5b03oool0oooo0080oooo00D0oo?l01TA
4P000000000007iGFP060?ooo`030>B^]03oool0oooo00D0oooo00D0bkBf00000000000000000<^d
]P040?ooo`@0000000<0bH^@0?ooo`3oool00`3oool01@3olo`03@T9000000000000OUMJ00@0oooo
00D0bkBf0000000000000000075>D@0;0?ooo`05081jOP00000000000000003ogn<0103oool01@3o
lo`06A4B000000000000on7Z00H0oooo00@0C3@f000000000000oo?l1@3oool30000000306E6B03o
ool0oooo00`0oooo00D0UfQ/00000000000000000>:LXP0:0?ooo`0401TA4P000000000006E5B0H0
oooo00D0/Z:T000000000000000008b8R@040?ooo`@0000000<0bH^@0?ooo`3oool00`3oool01@3o
lo`03@T9000000000000OUMJ00@0oooo00D0S8R900000000000000000;:RY0060?ooo`0406E5B000
0000000001TA4PD0oooo100000000`3oj>`0oooo0?ooo`020?ooo`0606E5B000000000000000000I
4A80oo?l1@3oool0100c8b@000000000001nEeX40?ooo`050?oOh`000000000000000020P800103o
ool01@2GJ6`00000000000000000hYbR00X0oooo00D0S8R900000000000000000?kFfP300?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooN@3oool0203o
mo@0on[I0?oM/@3ob740ol=P0?nlA@3o`4L0oki90P3o`T/01@3oaT`0olQ<0?o8C@3obDd0olU>00/0
olQ=00<0olU>0?o8C@3obD`03P3ob4d20?o7C080olQ=2`3oad`00`3ob4d0olM<0?o7C00@0?o7C003
0?o8C@3oad`0olM<00D0olM<00<0olQ=0?o7C03oad`00P3ob4d30?o7C0030?o8C@3oad`0olM<00d0
olM<00<0olM=0?o7C03oaT`01@3oad`01P3o`dX0ok]60?nnA`3obD`0olM<0?o7B``0olM<0P3oaT`0
1`3obDd0[VhY00d70`0E3@@0g[Pn0?oRB`3ohD/01P3oh4X0103ohD/0on1:0?oOBP3oh4X50?oOBP03
0?oPB`3ogdX0omm:00@0omm:00<0omi:0?oQC03ogdX02P3ogdX01P3oh4X0omi:0?oOBP3ogdX0on1:
0?oOB`H0omi:0P3ogd/70?oNBP030?oPB`3ogTT0omi90080omi900@0omm:0?oNB@3ogTT0omm:0`3o
gTT01@3ogdX0omi90?oNBP3ogDT0om]80080omi:00<0omi90?oOB@3ogdT00`3ogTT00`3ogdX0omi9
0?oNB@020?oNB@040?oMB@3ofDP0omi90?oOBPL0ome900@0omi:0?oMB@3og4T0omM7103ogDT00`3o
gTX0ome90?oMB@050?oMB@030?oLB@3ogTX0ome900H0ome900D0ome:0?oLB@3og4T0ome90?oKB@03
0?oLB@030?oMBP3ogDT0oma900H0oma900<0omY90?oLB@3og4T02`3og4T00`3ofdT0oma90?oKB008
0?oKB080oma900@0om]80?oKB@3og4T0om]80P3og4T90?oKB0030?oLB@3ofTP0omY900<0om]800P0
omY80?oIB03ofTP0omY90?oJB03ofDP0om]90?oKB080omU800<0omU90?oJB@3ofTP00`3ofDP00`3o
g4T0omY80?oJB0070?oJB0030?oKB03ofDP0omU800<0omY800<0om]90?oHB03of4P0203of4P20?oI
B0030?oFA`3ofDP0omQ800`0omQ800P0omU80?oHB03ofTT0omM70?oHB03ofDT0omQ80?oIB080omQ8
00<0omU90?oHB03ofDT00`3of4P00`3ofDT0omQ80?oHB0020?oHB0040?oIB03of4T0omM70?oGB080
omU800<0omU90?oHB03ofTP00P3ofDP02@3of4P0omY70?oF@`3of5d0omaa0?oKT03ok/T0ooG^0?om
o01U0?ooo`<0000000<0bH^@0?ooo`3oool0203oool0103o_lH000000000000000050?ooo`<00000
00L0F3do03<S902<R8T0bkBf0>C5b02bX:<0C3@f0080000000<01`D50?78c`3oool01@3oool0100i
9bT0IDI8081jOP2bXZ@20>C5b0030=Rl_`2ITI80<b<T0080000000<0<b<T0?o_l@3oool00`3oool3
0000000802`O80000000IDI808b8R@3H_Kl0bkBf09V;T01<=3H20000000300d92@3ab<l0oooo00<0
oooo00<0ooSj08]OH`0000000P000000201UATP0S8R90;:RY03TaLP0bkBf0:FJV`20J6`0bkBf0`3o
ool01P3bgn<09QXK000000000000FDiA0>C5b080omoS00D0aK2b03l/;@000000000006ICEP070?oo
o`0407UPH`00000000000=JCV@D0oooo0`0000000`1UATP0oooo0?ooo`0<0?ooo`030?o`m@16<380
00000080000000L0NFMY0;:RY03TaLP0i<G80;RWZ@20J6`0UfQ/00<0oooo00/0lLkA03<S90000000
000004`d=P2<PXL0g/740>C5b03H_;l0S8:702HJ6`020000000303<S903hinP0oooo00<0oooo0`00
0000200/7b00000006E6B02<R8T0f;fo0<^d]P2IRi00C3@f0P0000000`0=2@T0lLS?0?ooo`030?oo
o`0;0?SWj00c8b@000000000000V6Q/0S8:70=Rl_`3TaLP0g/7408b2Q`1<=3H00P0000000`0c8b@0
lLkA0?ooo`040?ooo`<0000000<0F3do05=6B02oZjd00P3TaLP0302;M7H00000000000000000<b<T
0000000V6Q/0S8:70=:h^`3H_;l0VI6B06E6B080000000<03@T90?78c`3oool00`3oool01@3ogn<0
0000000000000000P82000@0oooo00<0oo3e08]OH`0000000P0000001`1UATP0S8R90<^d]P3TaLP0
bkBf0:FJV`2<J6`00`3oool01P3Ud]D03@T9000000000000AcTk0;n[[@80i<G800@0f;fo09VATP20
J6`0i;Jm^@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?ooogd0oooo00D0oo?^0?oH/P3o^6`0oka00?o1A`040?o1B`030?o4B`3oad`0olQ=00h0olQ=00<0
olU>0?o8C@3ob4d02P3ob4d00`3oad`0olQ=0?o7C00<0?o7C0030?o8C@3oad`0olM<01X0olM<00<0
olQ=0?o7C03oad`01`3oad`00`3ob4d0olM<0?o7C00A0?o7C0040?o3BP3o^dH0oki70?o9C0@0olM<
00<0olM=0?o7C03oad`01`3oad`01`3oaT`0olE<0>RU?`0000000P000=B5;03oiD`0203oh4X00`3o
hD/0omm:0?oPBP0<0?oOBP030?oPBP3ogTX0on5;00P0omm:00D0on1;0?oOBP3ogdX0oma80?oNBP02
0?oOBP030?oPBP3ogd/0omi:00H0omi:00<0omm90?oNBP3ogTX01@3ogTX00`3oh4/0omi90?oNB@08
0?oNB@030?oKB03ogTT0ome900<0omi90P3ogdX;0?oNB@040?oMB@3ofdP0omi90?oOBPL0ome900@0
omi:0?oMB@3ogDT0ome:103ogDT00`3ogTX0ome90?oMB@050?oMB@80omi91`3ogDT01@3ogDX0oma9
0?oLB@3og4T0omU800d0oma900<0omQ80?oLB@3og4T00`3og4T00`3ogTT0om]80?oNBP050?oLB@03
0?oJB03og4T0om]800/0om]80P3ofTP20?oLB@/0om]80P3ofDL00`3og4T0oma:0?oKB0020?oIB003
0?oKB@3ofDP0omU800@0omU80P3ofTP01@3oedL0omQ80?oIB03ofDP0om]900X0omY800H0omU80?oJ
B03oedL0om]80?oJB03ofdT=0?oHB0030?oIB03ofDT0omQ800d0omQ800D0omY90?oHB03oedL0omQ8
0?oIB@0:0?oHB0030?oIB@3ofDP0omQ800<0omQ800@0omY80?oGA`3of4P0omU80`3of4P01P3ofTP0
omY50?oE?P3obUH0on:[0?odjfX0oooo0`0000000`39Ri00oooo0?ooo`080?ooo`040?noaP000000
0000000000D0oooo0`0000000`3olo`09QXK000000060000000307iGFP3oool0oooo00D0oooo2P00
00000`1;=3H0oo?l0?ooo`040?ooo`<0000000<0P7Yn04/d=P0000001`0000000`3l[K@0oooo0?oo
o`050?ooo`030?b]]00I4A80000000L0000000<0S8R90?ooo`3oool00P3oool00`3od=P06A4B0000
0008000000030?7>d@3oool0oooo00D0oooo00@0VI6B000000000000Bc@f1@3oool30000000306E6
B03oool0oooo00d0oooo00<0o]KJ01TA4P0000001`0000000`0I4A80oooo0?ooo`020?ooo`030?oc
o00V6Q/0000000P0000000<0Bc@f0?oco03oool0103oool300000003081jOP1;=3H0000000L00000
00<0o:fd0?ooo`3oool0103oool00`3olo`0Bc@f000000080000000302HJ6`3olo`0oooo00D0oooo
0`0000000`3olo`09QXK00000006000000030?kFfP1UADP0000000L0000000<0o:fd0?ooo`3oool0
0`3oool01@3ogn<00000000000000000P82000H0oooo00<0o:fd00d92@0000001P0000000`0=2@T0
oooo0?ooo`020?ooo`030?b]]0000000000000L0000000<0bH^@0?ooo`3oool0]`3oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooogl0oooo00D0ooKc0?oN
^@3o^W40okY:0?o0B@030?o0BP040?o1BP3oa4`0olM<0?o8C0L0olQ=00<0olM<0?o8C@3ob4d01`3o
b4d00`3obDh0olQ=0?o8C@060?o8C@h0olM<00@0olQ=0?o7C03ob4d0olQ=6@3oad`00`3ob4d0olM<
0?o7C00;0?o7C0030?o8C@3oad`0olM<00d0olM<00@0ol=:0?nkAP3o_TL0olU<0`3oad`00`3oaT`0
olM<0?o7C0080?o7C0070?o6C03ocTl0UUhT0000001S?a<0omi:0?oQBP080?oPBP030?oQB`3oh4X0
omi900`0omm:00<0omi:0?oOBP3ohD/02`3ogdX01P3ogDX0omm:0?oOBP3ogdX0on1:0?oOB`L0omi:
00<0om];0?oNBP3ogTX01@3ogTX00`3oh4/0omi90?oNB@020?oNB@070?oLB@3ogTT0omi:0?oMB@3o
g4X0omi90?oMB@050?oNB@030?oNBP3ogDP0omi900D0omi900<0omm:0?oNB@3ogTT00`3ogTT00`3o
gdX0omi90?oOBP070?oMB@050?oNB@3ogDT0ome90?oOB@3ogTT00`3ogDT00`3ogTX0ome90?oMB@05
0?oMB@030?oJB03ogDT0ome900H0ome900H0ome:0?oLB@3og4T0oma90?oMB@3ogTX30?oLB@030?oM
B@3og4T0oma900H0oma900<0omY90?oLB@3og4T01@3og4T00`3of4P0oma90?oLB@030?oLB@030?oJ
B03ogDT0om]800P0om]800L0oma90?oKB03ofdP0om]80?oKB@3og4P0oma900X0om]80P3og4X0103o
f4P0omU80?oKB03ofdP;0?oIB0050?oKB03oeTL0omQ80?oIB03ofdT02`3ofTP01@3ofDP0omQ80?oI
B03ofTP0om]900`0omQ800<0omY80?oHB03oedL03@3of4P00`3ofTP0omU80?oJB0020?oHB0030?oG
A`3ofTP0omQ800P0omQ800<0omY80?oJB@3of4P00P3of4P03@3ofTT0omQ80?oHB03of4P0omM70?oJ
B03of4P0omY80?oEA`3oc780onFi0?ohk03oo_l0J`3oool3000000030<V;T03oool0oooo00P0oooo
00@0oko60000000000000000103oool01P3o_lH000000000000I4A80oooo0:FDV@H0000000<06A4B
0?7>d@3oool01P3oool00`2bTiT0000000000006000000030;1iOP3olo`0oooo00@0oooo00L0omoS
000000000000000008b8R@3olo`0Bc@f00D0000000<03@T90>:LXP3oool0203oool00`3ohNX0C3@f
00000006000000030820P03oool0oooo00<0oooo00<0oo?l06E5B00000001@0000000`0I4A80oko6
0?ooo`070?ooo`050<^d]P00000000000000003onOh0103oool30000000306E6B03oool0oooo00h0
oooo00<0on7Z09MXK00000001`0000050?ooo`030=Rl_`000000000000H0000000<0/7Un0?ooo`3o
ool0103oool01`3ogn<00000000000000000S8R90?oco01;=3H01@0000000`0=2@T0hYbR0?ooo`08
0?ooo`030;1iOP000000000000H0000000<0f;bo0?ooo`3oool0103oool01P3o_lH000000000000I
4A80oooo0:FDV@H0000000@0hYbR0?ooo`3olo`0OUMJ1@0000000`0=2@T0hYbR0?ooo`050?ooo`05
0?oOh`000000000000000020P8001`3oool00`3;YJ/0000000000006000000D0oooo00<0om3H038S
900000001P0000000`39Ri00oooo0?ooo`2g0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooP@3oool00`3oo_l0ooCV0?o3PP020?o0C0060?noAP3o`4T0
ol5:0?o0BP3o`D/0olI<1@3ob4d00`3ob4`0olQ=0?o8C@0;0?o8C@030?o9CP3ob4d0olQ=0080olQ=
00<0olM<0?o8C@3ob4d0303oad`00`3ob4d0olM<0?o7C00?0?o7C0030?o8C@3oad`0olM<00P0olM<
00<0olQ=0?o7C03oad`03`3oad`00`3oadd0olM<0?o7C0090?o7C0040?o3BP3o^dH0oki70?o9C0h0
olM<00H0olU<0?o?C`0o8`d050d40?nh?03oi4/30?oPBP030?oQB`3oh4X0on1:00<0on1:00<0on5;
0?oPBP3oh4X01`3ogdX00`3ohD/0omm:0?oOBP020?oOBP030?oPBP3ogdX0on5;00X0omm:00<0on1:
0?oOBP3ogdX00P3ogdX00`3oh4X0omm;0?oNBP060?oNBP030?oLBP3ogTX0omi:00D0omi:00<0on1;
0?oNB@3ogTT00P3ogTT01@3og4T0omY80?oNBP3ogTT0omm:00L0omi900<0ome:0?oJB03ogdT02`3o
gTT00`3ogdX0omi90?oOBP0;0?oMB@050?oNB@3ogDT0ome90?oMB@3ogTX0403ogDT01P3ogDX0oma9
0?oLB@3og4T0omY90?oFA`<0oma900<0ome90?oLB@3og4T0103og4T0103ogTX0oma90?oLB@3ofTT6
0?oLB@030?oKB@3ofdP0oma900<0oma900<0om]90?oFAP3ofdP0203ofdP00`3og4T0om]80?oKB009
0?oKB0030?oLB@3og4X0om]900@0om]800@0oma90?oKB03ofdP0om]82P3ofDP01P3ofTT0om]90?oK
B@3ofTP0omU80?oKB@/0omY800D0omU80?oJB03of4P0oma80?oKB@0<0?oHB0040?oJB03of4P0omY8
0?oFAP/0omQ800<0om]90?oJB03ofTT00`3of4P00`3oedP0omI70?oIB@090?oHB0040?oIB03of4P0
omY80?oIB@<0omQ800H0omY80?oHAP3oeTP0omQ;0?o:EP3oj<M_0?ooo`<0000000<0bH^@0?ooo`3o
ool05P3oool01`3RW:80OUMJ038S900I4Q80IDE80<V;T03olo`02@3oool0203ohNX0bH^@07iGFP0=
2@T0000001TA4P1UADP0i;Jm3P3oool01P3RW:80F3do0000000b8b@0IDE80>BoaP/0oooo00T0oo3e
0<V;T01UADP0<R<T0000001;=3H0IDE80<V;T03oj>`01`3oool01`3;U9T0Bc@f000000000000?b/]
0<V;T03olo`02@3oool01@3ac]400000000000000000o]KJ00@0oooo0`0000000`1UATP0oooo0?oo
o`0@0?ooo`030?oQjP2GJ6`0<R<T0080000000<0F3do0<V;T03od=P01P3oool0203ohNX0bH^@06E5
B00=2@T0000001TA4P1UADP0i;Jm3P3oool01P3RW:80F3do0000000b8b@0IDE80>BoaP/0oooo00P0
i;Jm06E5B00I4A80000000d92@1UADP0bH^@0?oQjPd0oooo00H0hYbR07iGFP0I4A809QXK0;1iOP3o
hNX40?ooo`060?noaP1H?Cl00000038S901UADP0i;o6503oool0203ohNX0bH^@06E5B00I4Q800000
04/d=P1UADP0i:jd1`3oool0202`NWh06A4B0000000000009QXK07iGFP39Ri00oo?l^@3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooh@0oooo00d0oo?T
0?oPa03ofZH0olMf0?o2E03o`4`0ol180?o1B@3o`D/0ol9:0?o4B`3oaT`0olM<00@0olQ=00<0olU>
0?o8C@3ob4d0303ob4d?0?o7C0030?o8C@3oad`0olM<01X0olM<00<0olQ=0?o7C03oad`00P3oad`0
0`3ob4d0olM<0?o7C00=0?o7C0030?o6C@3oadd0olM<0080olM<0P3oadd20?o7C0040?o3BP3o^dH0
oki70?o9C0d0olM<00H0ol]>0?o3BP2BDb006Q060>2Y>03ohT/40?oPBP030?oQB`3oh4X0on1:00<0
on1:00<0on5;0?oOBP3ogdX03P3ogdX00`3ohD/0omm:0?oOBP070?oOBP030?oPB`3ogDT0omm:00<0
omm:00<0on1:0?oOB`3ogTX01@3ogTX30?oOBPH0omi:00D0on1;0?oMB@3ogTT0omi90?oMB@040?oN
B@030?oOBP3ogTT0omi900D0omi900<0ome:0?oJB03ogdT02`3ogTT00`3ogdX0omm90?oOBP080?oM
B@040?oOBP3ogDT0oma90?oKB0<0ome900<0omi:0?oMB@3ogDT01P3ogDT00`3ofdT0omi:0?oMB@05
0?oMB@030?oMBP3og4T0oma90080oma900<0ome90?oKB@3og4T00P3og4T00`3ogDT0oma90?oLB@03
0?oLB@050?oNBP3og4T0oma90?oKB@3ogDT01@3og4T0103ogDT0om]90?oMB@3ogDT40?oLB@030?oJ
B03ofdP0om]800D0om]80P3og4T20?oKB080oma90`3ofdP00`3og4T0om]80?oKB0050?oKB080oma9
0P3ofdP00`3ofTP0omU80?oLB@0=0?oIB0030?oKB@3ofDP0oma900h0omY800<0omU80?oJB@3ofDP0
303of4P30?oIB0030?oHA`3of4P0omU80080omQ80P3ofDP20?oHB0050?oIB@3of4P0omQ80?oHB03o
fTT01@3of4P00`3ofDP0omI70?oHB0040?oHB0030?oIB03ofTT0omQ80080omU800X0omY90?oKB03o
f4H0omQ?0?oLF03oe6P0on>J0?oO]@3ol^X0oo_eL03oool3000000030<V;T03oool0oooo06d0oooo
00D0ooSj01TB4P00000000000;n[[@040?ooo`<0000000<0IDI80?ooo`3oool0o`3ooom?0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooR03oool01P3o
j>40olnO0?o>O@3o_580okdm0?nnAP<0ol1:00D0ol5:0?o3BP3oaT`0olQ=0?o9CP0>0?o8C@040?o7
C03ob4d0olQ=0?o8C@/0olM<0`3ob4dJ0?o7C0030?o8C@3oad`0olM<0100olM<00<0olI<0?o7C03o
ad`0203oad`0103o`dX0ok]60?nnA`3obD`80?o7C00:0?o8C03oad`0olM<0?o7C03obDd0olQ=09ED
8@000000S5dN0?oUC0/0on1:00<0on1<0?oOB`3ogdX0203ogdX0103oh4X0omm:0?oOBP3ogTX20?oO
BP030?oQB`3ogdX0omm:00P0omm:00<0omi:0?oOBP3ogdX00P3ogdX00`3oh4X0omm;0?oNBP050?oN
BP030?oIB@3og4T0omm;00@0omi:00<0omi90?oLB@3ogdX0103ogTT01@3ogdT0omi90?oNB@3ogTT0
omm:00L0omi900<0ome:0?oJB03ogdT01@3ogTT00`3ogdX0omi90?oNB@040?oNB@030?oOB@3ogdX0
ome900T0ome900<0oma90?oMB@3ogDT00P3ogDT00`3ogTX0ome90?oMB@060?oMB@030?oHB03ogTT0
ome900D0ome900<0ome:0?oLB@3og4T00P3og4T00`3ofTT0omY80?oMB@020?oLB@030?oMBP3og4T0
oma900<0oma900D0omi:0?oLB@3og4T0oma90?oJB0070?oLB@80ome900<0om]90?oLB@3og4T00P3o
g4T00`3ofdP0oma90?oLB@030?oKB0<0oma9103ofdP00`3ofTP0omU70?oJB0080?oKB0030?oLB@3o
fdP0om]80080om]800<0omQ80?oIB@3ofdP02P3ofDP01P3ofTT0om]90?oIB03of4P0oma90?oKB0/0
omY800D0om]90?oJB03ofdP0omY80?oFA`0;0?oHB0040?oJB03ofDT0omU90?oJB080omQ800<0omY8
0?oKB03ofDT0203of4P00`3ofDT0omQ80?oHB0040?oHB00@0?oJB03oedP0omQ80?oJB03of4P0omU8
0?oHB03ofTP0omQ80?oJA`3of3d0om<m0?oAEP3ogHD0ombh0?ojogD0oooo0`0000000`39Ri00oooo
0?ooo`1^0?ooo`0409MXK00000000000081jOP@0oooo0`0000000`1UATP0oooo0?ooo`3o0?ooodl0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooon;0?oo
o`050?oD[`3ocX@0okQE0?nj>`3o`4@00`3o`4X0103o`T/0olA;0?o5B`3oaT`80?o8C@030?o9C@3o
ad`0olQ=0080olQ=00<0olM<0?o8C@3oad`0103oad`00`3ob4d0olM<0?o7C0050?o7C0030?o8C@3o
ad`0olM<01X0olM<00D0olQ=0?o7C03oad`0olM<0?o7C@0I0?o7C0030?o3BP3o^dH0oki700<0olM<
0P3ob4d40?o7C00:0?o8C@3oaT/0olM<0?o7C03oc4h0oi4g01@;10000000fJ/h0?oRB`H0on1:00<0
on5;0?oPBP3oh4X0103oh4X90?oOBP040?oPB`3ogdX0on1:0?oNB@80omm:00<0on5;0?oOBP3ogdX0
1`3ogdX00`3ogTX0omi90?oOBP030?oOBP030?oPBP3ogd/0omi:00D0omi:0P3ogDX0203ogTX0oma9
0?oOBP3ogdX0ome90?oOBP3ogTX0on1;103ogTT00`3ogdX0omi90?oNB@090?oNB@030?oMBP3ofTP0
omm900`0omi90P3ogdX90?oMB@030?oNBP3ogDT0omi:00<0ome900<0omi:0?oMB@3ogDT01P3ogDT0
0`3ogTX0omi90?oNBP050?oMB@030?oMBP3og4T0oma900<0oma900<0ome90?oLB@3og4T01`3og4T0
1P3ogTX0oma90?oLB@3og4T0omY80?oNB@P0oma900H0om]80?oLBP3og4X0oma90?oKB03ofTP30?oL
B@X0om]800<0omQ80?oJB03ofdP01`3ofdP00`3og4T0om]80?oLB@020?oKB0030?oJB@3ofTX0omQ7
00X0omU800@0om]80?oIB03ofDP0omU80P3ofdT00`3ofdP0omY80?oJB00;0?oJB0030?oKB@3oedL0
omQ800/0omQ800P0omU90?oKB03of4P0omQ80?oIB@3ofDL0om]90?oGA`l0omQ800D0omU90?oHB03o
fTP0omI70?oJB0020?oHB0070?oIB03ofd40om550?oJO`3ogi80omng0?omo`1g0?ooo`<0000000<0
bH^@0?ooo`3oool0KP3oool0103RW:8000000000001nEeX40?ooo`<0000000<0IDI80?ooo`3oool0
o`3ooom?0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0
ooooR`3oool0203oo_l0ooGg0?oQb@3ofJD0okaX0?nnAP3o`480ol980`3o`4X00`3o`TX0olA<0?o6
C@0:0?o8C@030?o9CP3oad`0olM<00D0olM<00<0olQ=0?o7C03oad`00P3ob4d30?o7C0030?o8C@3o
ad`0olM<01X0olM<00<0olQ=0?o7C03oad`06`3oad`00`3o`dX0ok]60?nnA`090?o7C0090?o7C@3o
ad`0olM<0?o7C03oaD/0CB/@0000001:<100om]900`0on1:00<0on1;0?oPBP3ogdX02P3ogdX01@3o
gTT0omi:0?oOBP3ogdX0on5;00T0omm:00<0on1:0?oOBP3ogdX00`3ogdX00`3oh4X0omm;0?oNBP04
0?oNBP050?oOBP3ogdT0oma90?oOBP3ogDT01@3ogTX01@3oh4/0omi90?oNB@3ogTT0ome900`0omi9
00<0ome:0?oJB03ogdT02`3ogTT00`3ogDT0om]90?oOBP090?oMB@030?oOB@3ogDT0omi900<0ome9
00<0omi:0?oMB@3ogDT01P3ogDT00`3og4P0om]80?oNB@050?oMB@030?oMBP3og4T0oma900<0oma9
0P3ofdT30?oLB@030?oMB@3og4T0oma90080oma900L0omi:0?oLB@3og4T0oma90?oKB03of4P0ome9
0080oma90`3ogDX30?oLB@050?oKB@3ogTX0ome:0?oKB03ofdT0203ofdP00`3og4T0om]80?oKB002
0?oKB0030?oJB@3ofTP0om]900L0om]800<0oma90?oKB03ofdT00`3ofdP00`3ogDX0omY80?oKB@0:
0?oIB0050?oKB03ofDP0omU80?oLB@3of4P0303ofTP00`3ofdT0omY80?oKB@020?oHB0030?oKB@3o
f4P0omQ800H0omQ800D0om]90?oHB03ofTP0omU90?oJB0020?oHB080omY800<0omI70?oIB03of4P0
1P3of4P0103ofDP0omQ80?oHB03of4P20?oIB@0<0?oHB03ofTP0omQ80?oHB03oedH0omM70?oLA`3o
fS/0ole70?oAL`3oj;T0ooKcNP3oool3000000030<V;T03oool0oooo06h0oooo00@0on7Z00000000
0000F3do103oool30000000306E6B03oool0oooo0?l0ooooC`3oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooohl0oooo00L0ooWd0?obgP3og[l0omNO0?o5
K03o_D/0ol190080ol1:0P3o`DX0103o`T/0olA<0?o6C03oaT`50?o8C@030?o9CP3ob4d0olM<00P0
olM<0P3ob4d00`3oad`0olQ=0?o7C0020?o8C@h0olM<00<0olQ=0?o7C03oad`02P3oad`0103ob4d0
olM<0?o7C03ob4dJ0?o7C0040?o3BP3o^dH0oke70?o8C0/0olM<00H0olU=0:a^:P000000D3<A0?Ro
?`3oiD`30?oPBP80on5;1@3oh4X0103ohD/0on1;0?oQB`3oh4X90?oOBP030?oPB`3ogdX0omm:00<0
omm:00<0on5;0?oOBP3ogdX03@3ogdX02`3oh4X0omm;0?oOBP3ogTX0oma90?oOBP3ogDX0oma90?oL
BP3ogTX0omm;00H0omi:00H0on1;0?oNB@3ogTT0omi90?oLB@3ogDT30?oNB@80omm:1P3ogTT00`3o
gDX0omY80?oOB@0;0?oNB@030?oKB@3ofTP0omm:00/0ome900D0om]80?oNB@3ogDT0ome90?oNBP09
0?oMB@030?oJB@3ogTX0omi900@0ome900<0ome:0?oLB@3og4T01`3og4T20?oMB@80ome:00<0ome9
0?oLB@3ogTX00P3og4T01P3ogDX0ome90?oKB@3ofdT0ome90?oLB@<0ome900<0ome:0?oLB@3og4T0
0P3og4T01@3ogDX0omY80?oKB@3ofTT0oma800H0om]800<0oma90?oKB03ofdP0103ofdP00`3of4P0
om]80?oKB0050?oKB0040?oLB@3ofdP0om]90?oLB@80om]800<0oma:0?oJB03ofDP02P3ofDP00`3o
fTP0omU80?oIB0020?oJB0030?oHB03ofDP0omY800/0omY800D0om]90?oHB03of4P0omQ80?oJB002
0?oJB@80omQ800P0omY90?oIB03of4P0omU80?oHB03ofDP0om]90?oJB0D0omQ800<0omM80?oJB03o
f4P01@3of4P0103ofDT0omQ80?oIB03ofDP20?oHB00:0?oIB03of4P0omQ80?oEB03od540omej0?oP
U@3olML0ooKS0?ojmW`0oooo0`0000000`0I4Q80<b<T03<S900603<S90030>_:c03oool0bH^@00<0
0000H`3oool0101UATP0000001<=3P3onOh30?ooo`<0000000<03@T903<S900c8b@01`0c8b@00`3o
b<l0oooo0?ooo`1W0?ooo`050>C5b0000000000000000020P800f03oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooiD0oooo00H0om6W0?nhK03o`E80okm;
0?o0B03o`DP40?o0BP050?o3C03oaT`0olQ=0?o8C@3obDh04`3oad`00`3ob4d0olM<0?o7C00F0?o7
C0030?o8C@3oadd0olM<00d0olM<00<0olI<0?o7C03oad`02`3oad`01P3o`dX0oka70?njAP3obD`0
olM<0?o8C@P0olM<00H0olU<0?o0BP0L40H0?RH=0?o5@03ojDd80?oPBP070?oQB`3oh4X0on1:0?oO
BP3oh4X0on5;0?oPBP030?oOBP<0on5;103ogdX00`3ogTX0omi90?oOBP020?oOBP030?oQB`3ogdX0
omm:00L0omm:00<0on1:0?oOBP3ogdX00`3ogdX00`3oh4X0omi:0?oMBP040?oNBP80ome9203ogTX0
1P3oh4/0omi90?oNB@3ogTT0oma90?oMB@/0omi900<0ome:0?oJB03ogdT02`3ogTT00`3og4P0omY8
0?oOBP0:0?oMB@030?oOBP3ofTT0omi90080ome900<0omi:0?oMB@3ogDT01`3ogDT00`3ogTT0omi:
0?oMB@040?oMB@030?oMBP3og4T0oma900@0omi:00D0om]80?oLB@3og4T0oma90?oMB@040?oLB@03
0?oNBP3og4T0oma90080oma900<0ome90?oLB@3og4T02@3og4T01@3ogTX0omY70?oJB@3ofTL0omU8
00L0om]800<0oma90?oKB03ofdP00`3ofdP00`3og4T0omY90?oKB0050?oKB0030?oLB@3ofdP0om]8
00<0om]800@0oma:0?oIB03ofTP0omM73@3ofDP0103ofTP0om]80?oGA`3of4P<0?oJB080omQ800@0
om]90?oJB03ofDL0omY9203of4P00`3ofdT0omY80?oHB0060?oHB0030?oKB@3of4P0omQ80080omY8
103of4P01P3ofTP0omU50?oGB@3ofDl0om=C0?oAQH<0oooo300000000`3TaLP0oooo0<V;T0030000
06<0oooo00@0hYbR000000000000o:fd0`3oool=000000030?noaP3oool0oooo06L0oooo00D0i<G8
00000000000000000820P03H0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWiol0ooooU`3oool01`3ohm00oki]0?o2E`3o^e00oki70?o0AP3o`DP00`3o`4X00`3o
`D/0olA;0?o6C@0F0?o7C0030?o8C@3oad`0olM<01<0olM<00<0olQ=0?o7C03oad`0303oad`01@3o
aD`0olM<0?o7C03oad`0olM=00X0olM<00@0ol=:0?nc@`3o_TL0olU<2P3oad`01P3oc4h0cW@/00<2
0@2^KBD0ooA@0?oOBP/0on1:00@0omm:0?oPBP3ohD/0on1:2`3ogdX0103oh4X0on5;0?oQB`3ohD/9
0?oOBP030?oNBP3ogd/0omm:0080omm:00@0omi:0?oLB03ogd/0omm;1@3ogTX01@3ogdX0omi:0?oN
BP3ogTX0omm:00D0omi:00<0on1;0?oNB@3ogTT00P3ogTT00`3ogdX0omi90?oNB@090?oNB@030?oM
BP3ofTP0omm900L0omi900L0omm:0?oNB@3ogTT0omi90?oKB@3ofTP0omm:00/0ome900D0omi:0?oM
B@3ogDT0ome90?oNBP080?oMB@040?oNB@3og4X0omY:0?oNBP80omm:0`3ogDT60?oLB@050?oMB@3o
g4T0oma90?oLB@3ogDX0103og4T00`3ogTX0oma90?oLB@030?oLB@030?oJB03og4T0oma900P0oma9
00D0omi:0?oKB03ofDP0oma90?oKB@070?oKB0030?oLB@3ofdP0om]800@0om]800<0omM70?oIB03o
fdP0103ofdP00`3og4T0om]80?oKB0030?oKB0050?oLBP3ofDP0omY80?oKB03oedL02@3ofDP00`3o
fdT0omU80?oIB0020?oJB0030?oKB03oedL0omQ800X0omY80P3ofdT40?oHB0030?oJB@3of4P0omQ8
00H0omQ800<0om]90?oJB03of4P01P3of4P00`3oedL0omU90?oHB0030?oHB0080?oIB03ofD@0omLo
0?oEB`3of5T0olac0?oPa`3on^j40?ooo``0000000<0i<G80?ooo`39Ri000`00001S0?ooo`040?oQ
jP00000000000;1iOP<0oooo3@0000000`3o_lH0oooo0?ooo`1W0?ooo`050>C5b000000000000000
0020P800f03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?oooiT0oooo00L0on[G0?o4X@3oa7@0ol1L0?nlC@3o`4L0ol5600<0ol5;00D0ol5:0?o2B`3oa4/0
olI;0?o7C0020?o8C0030?o7C03ob4d0olM<00l0olM<00<0olQ=0?o7C03oad`0103oad`00`3ob4d0
olM<0?o7C00:0?o7C0030?o8C@3oad`0olM<01/0olM<00@0ol590?nkAP3o_TL0olU<2@3oad`01`3o
cDh0ojU0018:0`0i90`0onQ=0?oRBP3ogdT02`3oh4X0103ogTT0on1:0?oQB`3oh4X?0?oOBP030?oQ
B`3ogdX0omm:00D0omm:0P3oh4/01@3ogTX0on1:0?oOB`3ogD/0on1:00<0omm:103ogTX50?oOBP03
0?oPB`3ogdX0omm:00<0omm:00@0on1;0?oOBP3ogdX0omm:0P3ogdT;0?oNB@030?oMB@3ofTP0omm9
00/0omi900<0om]90?oIB@3ogdX00P3ogTT90?oMB@030?oNB@3ogdX0omm:00D0omm:00<0omi:0?oM
B@3ogDT00`3ogDT20?oKB0030?oOBP3ogDT0ome90080ome900<0ome:0?oLB@3og4T0103og4T00`3o
fdP0omU70?oMB@060?oLB@030?oNBP3og4T0oma900<0oma900<0om]80?oLB@3og4T00`3og4T20?oM
BP<0oma900H0omi:0?oKB03ofdT0oma90?oLB03ofTP>0?oKB0030?oHB03og4P0om]800<0om]800<0
oma90?oKB03ofdP00`3ofdP00`3og4X0omU80?oIB0020?oHB0030?oIB@3ofTP0omU800T0omU80`3o
fTP00`3ofdP0omM70?oIB0060?oJB080om]90P3ofTP50?oHB0030?oKB03oedL0omQ800H0omQ800<0
om]90?oJB03of4P0103of4P03@3ofTT0omQ80?oHB03ofdP0omM70?oJB03ofDP0omTo0?oFB@3oeV00
omeb0?oAR`3okMT0U@3oool01039Ri00000000000000001T0?ooo`03038S90000000Bc@f07X0oooo
00D0i<G800000000000000000820P03H0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWiol0ooooV`3oool02P3ooO`0ongR0?oXd03oj/@0olnC0?o7IP3o`eh0oke=
0?noA03o`DT20?o0BP80ol9;00<0ol=<0?o6C03oaT`00P3oad`20?o8C0/0olM<00D0olM=0?o7C03o
ad`0olM<0?o8C@060?o7C0030?o8C@3oad`0olM<00L0olM<00<0olQ=0?o7C03ob4d0303oad`0103o
b4d0olM<0?o7C03oadd;0?o7C0040?o4BP3o^dH0oki70?o9C080olM=1P3oad`01P3ocDh0jJ4m03DN
2`000000^Xl_0?oTB`80on1:00<0on5:0?oPBP3oh4X01P3oh4X01P3oh4/0on1:0?oPBP3oh4X0on5;
0?oPBPX0omm:00<0on1;0?oOBP3ogdX00P3ogdX02@3ohD/0omm:0?oOBP3ogdX0on1:0?oOBP3oh4X0
omi:0?oMB@020?oOBP030?oPB`3ogdX0omm:0080omm:00<0on1:0?oOB`3ogTX00`3ogTX20?oMBP<0
omm;00<0omm:0?oOB`3ogd/00`3ogd/00`3oh4/0omm:0?oOBP030?oOBPD0omi90P3ogdX40?oNB@03
0?oMBP3ofTP0omm900<0omi9103ogdX01`3ogTT0omm:0?oOBP3ogdX0omi:0?oNB`3oh4X00P3ogTX0
0`3ogTT0ome90?oMB@070?oMB@040?oKB@3ogTT0ome90?oNBPT0ome900<0omi90?oLB03ogDT0103o
gDT00`3ogDX0oma90?oLB@040?oLB@030?oMB@3ofdT0oma90080oma900D0omi:0?oLB@3og4T0oma9
0?oNBP0@0?oLB@030?oNBP3ofdP0om]80080oma900<0omU80?oLB@3ofdP01@3ofdP0103og4X0om]8
0?oKB03og4T30?oKB0030?oLB@3ofDP0om]800T0om]800<0oma90?oIB03ofDP02`3ofDP00`3ofTT0
omU80?oIB0020?oJB0050?oKB@3ofTP0om]90?oKB@3ofDP00P3ofTP00`3ofdT0omY80?oJB0020?oJ
B0030?oKB@3ofTP0omQ800@0omQ80`3ofDP50?oHB0@0omU800l0omQ80?oIB03ofDP0omQ80?oIB03o
fTL0omQ30?oGB03oeUD0omUT0?oJOP3ohj`0oo3:0?obj@3oo_l0o`3ooooo0?oooe/0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooonP0?ooo`090?omo03o
lNh0onG>0?oBV@3o]ED0oki50?nn@03o`TT0oke800<0ol1:00@0ol5;0?o2BP3o`d/0olE;0P3ob4`9
0?o7C0030?o8C@3oad`0olM<00@0olM<0P3ob4d50?o7C080olQ=1@3oad`00`3ob4d0olM<0?o7C00:
0?o7C0030?o6C03oad`0olQ=00`0olM<0P3oaT`0103o`dX0ok]60?nnA`3obD`80?o7C0050?noB@0c
7@X0000005Pg4P3ogdX01@3oh4X00`3ogdX0omm90?oPBP040?oPBP060?oNB@3oh4X0on1:0?oPBP3o
hD/0on1:2@3ogdX00`3oh4X0omm:0?oOBP030?oOBP060?oQB`3ogdX0omi:0?oMB@3ogdX0omi:0P3o
gdX00`3oh4X0omm:0?oOBP050?oOBP030?oPBP3ogd/0omi:00<0omi:00<0on1:0?oOBP3ogTX00`3o
gTX00`3oh4X0omi:0?oNBP020?oNBP050?oPB`3ogTT0omi90?oLB@3ofdT0303ogTT00`3ogdX0omi9
0?oNB@0<0?oNB@80omm:2`3ogDT01@3og4T0omY80?oNB@3ogDT0omi900X0ome900<0omY70?oMB@3o
gDT0103ogDT80?oLB@030?oMB@3og4T0oma900/0oma90P3ofdT40?oLB@050?oMBP3ogDT0oma90?oL
B@3ogTX01@3ofdP20?oLB@P0om]800<0oma90?oKB@3ofdP00`3ofdP00`3ofTP0om]80?oKB0050?oK
B0030?oLB@3ofdP0om]800@0omU800<0om]80?oIB03ofDP01`3ofDP00`3ofdP0omY90?oJB0050?oJ
B0030?oHB03ofdT0omY800L0omY8203of4P00`3ofTP0omU80?oIB@030?oJB0D0omQ800P0omU80?oJ
A03oe3h0ol]O0?oHS03olLD0oo7R0?oooOl0ooooo`3ooomP0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooX`3oool01`3oo?`0oo7U0?oWa@3ocZ00okA;
0?nn@P3o`DP01@3o`4X0103o`DX0ol=:0?o3BP3oa4/70?o7C0030?o8C@3oad`0olM<0100olM<00H0
olQ=0?o7C03oad`0olQ=0?o7C03ob4d90?o7C0040?o6C03oad`0olM<0?o8C@/0olM<00L0olI<0?o7
C03oad`0ol=:0?nkAP3o_TL0olU<00L0olM<00H0olQ=0<>>=`0200003`X30?nb>`3ohT/60?oPBP03
0?oOBP3oh4X0on1:0080on1:00<0omm:0?oPBP3oh4X00P3oh4X00`3ohD/0on1:0?oOBP080?oOBP03
0?oNBP3oh4X0on1;0080omm:00D0on1:0?oOB`3ogDP0omm:0?oNBP040?oOBP030?oNB@3ogdX0omm:
00D0omm:00<0on1:0?oOB`3ogTX03P3ogTX01P3oh4/0omi90?oNB@3og4T0omY80?oOB@/0omi900<0
omm:0?oOB@3ogTT0303ogTT20?oOBP/0ome900<0omi:0?oMB@3ogDT0303ogDT20?oNB@D0ome91`3o
g4T00`3ogDT0omY70?oKB0020?oLB@030?oMB@3og4T0oma900L0oma900<0om]90?oKB03og4T01`3o
g4T00`3ogTX0om]80?oKB0030?oKB0030?oJB03og4P0ome900D0om]800@0oma90?oKB03og4T0om]9
3`3ofdP50?oIB0030?oJB03ofTT0omU80080omU800H0om]90?oLBP3ofdT0omU80?oKB03ofdT70?oJ
B0030?oKB03og4T0omY800D0omY800<0om]90?oHB03of4P01@3of4P0103ofDT0omY80?oIB03ofTP2
0?oHB00;0?oIB03of4P0omQ80?oHB03ofTH0omI10?o;B`3ob6`0on_30?oei`3onOX0o`3ooooo0?oo
of<0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooonV
0?ooo`090?ono`3olN40omVm0?ndI`3o^4h0ol1<0?o0BP3o`4P0okm800@0ol1:00@0ol9:0?o4B`3o
aD`0olI<6P3oad`00`3ob4d0olM<0?o7C00;0?o7C0030?o8C@3oad`0olM<00`0olM<00D0ol=:0?nk
AP3o_TL0olU<0?o8C@060?o7C0060?oED@1mAQX000000;Ib9P3oh4X0on5:203oh4X01P3ogdT0on1:
0?oPBP3ohDX0on1:0?oQB`80on1:00<0on5;0?oPBP3ogdX01`3ogdX00`3oh4X0omm:0?oOBP020?oP
BP030?oMBP3ogdX0on1;00H0omm:00<0omi:0?oMB@3ogdX01P3ogdX00`3oh4X0omm;0?oNBP030?oN
BP030?oLB@3ogTX0omi:00P0omi:00D0on1;0?oNB@3ogTT0ome90?oKB00<0?oNB@030?oOBP3ogdT0
omi900d0omi900<0omm:0?oMB@3ogDT02P3ogDT00`3ogTT0ome90?oMB@0B0?oMB@P0oma900D0omU8
0?oJB@3og4T0oma90?oMB@0:0?oLB@030?oHB03og4T0oma900H0oma900<0omi:0?oKB03ofdP00`3o
fdP00`3og4T0omY90?oLB@070?oKB0030?oLB@3ofdT0om]800<0om]800<0omY80?oIA`3ofdP0203o
fdP60?oIB0030?oHB03og4X0oma:00D0omU800<0om]80?oIB03ofTP0203ofTP00`3ofdP0omY80?oJ
B0040?oJB0D0omQ800H0om]90?oHB03of4P0omQ80?oKB03oe4H20?oHB0080?oJA`3of4P0omU90?oI
BP3oc780onc40?olm@3oo?co0?ooool0ooooIP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?oooj/0oooo00X0on[J0?oM/03ofYd0olj>0?o2HP3o`U40ol1=
0?noB@3o`4L0ol5:0P3o`4X0103o`DX0ol=;0?o4B`3oa4`20?o6C080olM<00@0olQ<0?o7C03oad`0
olQ=4@3oad`20?o8C@80olM<0P3ob4d50?o7C0040?o8C@3oad`0olM<0?o7C@/0olM<00@0ol=:0?nk
AP3o_TL0olU<1@3oad`01`3obDd0oli?0=N8<`0E3@D0YV`T0?oJB03ohT/02P3oh4X00`3ohDX0on1:
0?oPBP040?oPBP030?oQB`3oh4X0omm:00D0omm:0P3oh4X01@3ogDT0omm:0?oNBP3ogdX0on1:0080
omm:00<0on5;0?oOBP3ogdX0103ogdX00`3ogTX0on1:0?oOBP020?oOBP060?oPB`3ogdX0omm:0?oO
BP3oh4X0omm;2`3ogTX01@3oh4/0omi:0?oNBP3ogTX0on1;0080omi900<0omi:0?oOB@3ogTT01P3o
gTT20?oOBP<0omi900<0omm:0?oOB@3ogTT03@3ogTT00`3ogdX0ome90?oMB@090?oMB@030?oNB@3o
g4T0oma900`0ome900<0omi90?oLB@3ogTX0103ogDT80?oLB@030?oMB@3ofdP0oma900`0oma900<0
ome90?oJB03ogDT00`3og4T0103ogDX0oma90?oLB@3ogTX70?oKB0040?oIB03ofdP0omU80?oLB080
om]800@0oma90?oKB03og4T0om]9103ofdP0103og4T0om]90?oJB03ofTP30?oKB0040?oKB@3og4T0
om]90?oKB080omY800<0omU80?oJB@3ofdT00`3ofDP00`3of4P0omU80?oIB0040?oIB0030?oJB@3o
fdT0omY800H0omY80P3ofDP00`3ofdP0omY80?oJB0030?oJB0030?oHB03ofDT0omU80080omQ800`0
omU80?oIA`3ofT@0omQ70?oHC03ofU80omAI0?oAI03oiI`0on>c0?o/f03oo_Oo0?ooool0ooooJP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oook00oooo
00P0onKE0?o=X`3obX<0olM]0?nlC@3o_d<0ol120?o0B@D0ol1:00@0ol5;0?o3B`3oaD/0olI;0P3o
ad`00`3ob4`0olM<0?o7C00;0?o7C0030?o8C@3oad`0olM<00P0olM<0P3ob4d00`3oad`0olQ=0?o7
C00=0?o7C0040?o3BP3o^dH0oki70?o9C0D0olM<00H0olm?0?nD>00>2080Cc4A0?oMB@3oi4/<0?oP
BP030?oOB@3ogdX0on1:00<0on1:00<0on5;0?oPBP3ogdX00P3ogdX01@3ogTX0on1:0?oOBP3ogdX0
ome900<0omm:00D0on1;0?oPBP3ogdX0omm:0?oQB`060?oOBP030?oMB@3ogdX0omm:00H0omm:00<0
on1:0?oOB`3ogTX00`3ogTX00`3ogdX0omi:0?oNBP080?oNBP040?oPB`3ogTT0omi90?oOBPd0omi9
00<0omm:0?oOB@3ogTT0303ogTT00`3og4T0omi:0?oMB@0:0?oMB@030?oNBP3of4P0omY800d0ome9
00<0omi90?oMB@3ogDT00`3ogDT:0?oLB@040?oMBP3og4T0ome90?oMBPX0oma900<0ome90?oKB03o
g4T01P3og4T60?oKB00;0?oLB03og4T0omQ80?oKB03og4T0oma80?oKB03og4T0om]80?oLB@3ofdT0
1P3ofdP01P3of4P0omU90?oKB03ofdP0oma90?oLBP@0om]81`3ofDP00`3og4T0omY80?oIB0040?oI
B0030?oJBP3ofdT0omY800L0omY800L0omQ80?oHA`3ofdT0omY80?oIB03of4P0omY80080omQ800T0
omY80?oKAP3ofT00omE40?oBE@3ogG80omek0?oIY@3om>`0o`3ooooo0?ooog00oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooonc0?ooo`080?o/h`3odZ40
olan0?nnK03o]dh0ok`l0?o0@`3o`TP60?o0BP030?o2BP3oa4/0olE<0080olM<0P3ob4`A0?o7C003
0?o6C03oad`0olM<00@0olM<0P3oadd70?o7C0030?o6C03oad`0olM<0080olM<00@0ol9:0?nkAP3o
_dP0olU<103oad`01P3obDd0ok]805he50000000WGLW0?o/CP`0on1:00P0omm90?oPBP3oh4X0on9:
0?oOBP3ohD/0on1:0?oQB`80on1:00@0omi:0?oOBP3ogDT0omm90P3oh4X80?oOBP030?oQB`3ogdX0
omm:00@0omm:00<0on1:0?oOBP3ogdX00`3ogdX01@3oh4/0omm:0?oOBP3oh4X0omm;00@0omi:00<0
oma90?oNBP3ogTX0103ogTX01@3ogdX0omm;0?oNBP3ogTX0on1;0080omi900<0oma90?oNB@3ogTT0
1`3ogTT01P3ogdX0omi90?oNB@3ogTT0omm:0?oOB@X0omi900D0omm:0?oNB@3ogdT0omY80?oLB@0<
0?oMB@030?oKB@3og4T0ome900`0ome900<0omY80?oKB@3ogTX00`3ogDT90?oLB@030?oMB@3ofdT0
oma900`0oma900<0om]90?oHB03ogDT00`3og4T00`3ogDX0oma90?oLB@070?oKB080omQ80P3ofdP0
103ogDT0om]80?oKB03ofdP20?oLB@030?oKB03og4T0oma900<0om]800<0oma90?oKB@3ofdT0103o
fdP00`3og4T0om]90?oKB0070?oIB0030?oJB03ofDP0om]800D0omU800<0om]90?oJB03ofTP00P3o
fTP01@3ofdT0omY80?oJB03ofdT0omY80080omM70P3of4P02P3ofTP0omQ80?oKA`3ofCl0omA60?o?
DP3oeg00on2?0?oN^03oloCo0?ooool0ooooL`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?oookD0oooo00T0ooWg0?oUg`3ogK`0omFF0?noKP3o^5<0ok`o
0?o0A03o`TP01@3o`4X0103o`DX0ol9:0?o3B`3o`d/20?o5C0030?o7C03ob4`0olM<00/0olM<0P3o
aT`60?o7C0030?o8C@3oad`0olM=00<0olM<00H0olM=0?o7C03oad`0olI<0?o6C@3oadd30?o7C004
0?o2BP3o^dH0okm80?o9C0@0olM<00D0olY=0<ac:`0000004``40?6n?P0=0?oPBP0;0?oOB@3ogdX0
on1:0?oQBP3ogdX0omm90?oPBP3ogd/0omi;0?oPBP3ogTX0103ogdX00`3ogTT0omm:0?oOBP060?oO
BP030?oQB`3ogdX0omm:00<0omm:00<0omi:0?oOBP3ogdX0103ogdX01@3oh4/0omm:0?oOBP3oh4X0
omm;00/0omi:00T0omm:0?oOB`3ogTX0omi:0?oPB`3ogTT0ome90?oIA`3ogdT0203ogTT01@3ogdX0
omi90?oNB@3ogTT0on1;00d0omi900<0omm90?oJB03og4T0303ogDT00`3ogTX0omm90?oMB@0=0?oM
B@030?oLB@3ogTX0ome90080ome92P3og4T01@3ofdP0oma90?oLB@3og4T0ome900/0oma900D0om]9
0?oLB@3og4T0oma90?oLBP020?oLB@`0om]800@0oma80?oJB03og4T0ome:0P3ofdP20?oLB@@0om]8
0P3ofTP40?oKB080om]900<0om]80?oIB03ofDP01P3ofDP00`3of4P0omQ70?oJB0040?oIB0030?oK
B03ofdT0omQ80080omQ80140omU90?oHB03of4P0omU90?oHB03ofTP0omM70?oEA`3og4L0omPk0?oD
?03ocdd0omMo0?oX[P3oiL80onoT0?ono03o0?ooool0ooooM@3oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oookP0oooo01<0oogo0?ogl`3om>X0oo3K0?oH
[`3oe9`0om210?o1HP3o_4X0ol170?o0B@3o`DX0ol1:0?o0B@3o`4X0ol5;0?o1BP3o`D/0ol=;0080
olA;00<0olE;0?o6C03oad`03`3oad`00`3ob4d0olM<0?o7C0030?o7C0030?o7C@3oad`0olM<00H0
olM<00D0ol9:0?nkAP3o_TL0olU<0?o7C0020?o8C@060?o7C03IW3/040P301T@1P2jPb/0onE<303o
h4X02P3ogdX0on1:0?oPBP3oh4X0omm:0?oPBP3ogdX0on5:0?oPB`3oh4X<0?oOBP040?oPB`3oh4X0
omm:0?oQB`l0omm:00<0on1:0?oOB`3ogTX00P3ogTX00`3ogTT0omm:0?oNBP060?oNBP070?oOBP3o
gTX0omi:0?oPB`3ogTT0ome90?oJB@0=0?oNB@030?oPB`3ogTT0omi900X0omi900<0omm:0?oNB@3o
fdP03@3ogDT00`3ogTT0oma90?oLB@0<0?oMB@040?oNBP3og4P0ome90?oNBP80ome93P3og4T00`3o
gDT0oma90?oLB@0:0?oLB@040?oMB@3og4T0oma90?oMBP80oma90`3ofdP30?oLB@<0om]800P0om]:
0?oLB@3ofdP0om]80?oIB03ofdT0ome:0?oLB@P0om]800<0omY80?oLB@3ofdP00`3ofdP00`3og4T0
om]80?oIB0070?oIB0050?oJB03ofDP0omQ80?oHB03ofTT0103ofDP20?oHB00>0?oJB@3ofDP0omY8
0?oIA`3ofDH0omA90?oAE@3ofF`0on>30?oOWP3ok]40ooKH0?ogj03onoSo0?ooool0ooooN@3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oookl0oooo00/0
ooko0?obi03oknD0olNF0?nhFP3o`4X0ol1<0?noB`3o`4X0ol170?o1B0060?o1B`040?o1BP3o`D/0
olE<0?o5C0/0olM<00<0olQ=0?o7C@3oad`00`3oad`00`3oadd0olM<0?o7C0060?o7C0040?o2BP3o
^dH0oki70?o9C0<0olM<00D0ol]=06/l5`091@80aWdY0?o_D00=0?oPBP030?oOBP3ogDT0omm:00D0
on1:0P3oh4/50?oOBP030?oPBP3ogdX0omm:00L0omm:00<0on5;0?oOBP3ogdX00`3ogdX00`3ogDT0
omm:0?oOBP050?oOBP040?oPB`3ogdX0on1:0?oOB`<0omi:00<0omY80?oNBP3ogTX01P3ogTX0103o
gd/0omi:0?oNBP3oh4/20?oNB@030?oOB@3ogTT0omi900/0omi900<0on1;0?oNB@3ogTT02`3ogTT0
0`3ogdT0omY80?oLB@0=0?oMB@030?oIB@3ofTT0ome900`0ome900<0omU80?oLB@3ogDT00P3ogDT:
0?oLB@80ome90P3og4T00`3ogDT0oma90?oLB@090?oLB@030?oMB@3og4T0oma90080oma900@0omi:
0?oLB@3ogDX0oma91`3ofdP00`3ofDL0omQ70?oKB0030?oKB0030?oMB@3og4P0om]800P0om]800<0
omQ:0?oKB03ofdP0103ofdP40?oIB0030?oJB03ofdT0omY80080omQ800D0omY80?oHB03ofDT0omU8
0?oJB0020?oHB00:0?oIA`3ofTP0omM90?oHBP3oedh0olMK0?o:P03ohL80ooST0?onool0ooooo`3o
oon00?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo
a03oool02P3oeK00ok^=0?njM@3o`f00ol5F0?nnC`3o_d/0okm50?o0AP3o`DP70?o0BP050?o1BP3o
`d`0olE<0?o5C03oaT`01@3oad`00`3ob4d0olM<0?o7C0030?o7C0030?o7C@3oaT`0olM<00H0olM<
00@0ol9:0?nkAP3o_TL0olU<0P3oad`01P3oc4h0oji201D<101K>1<0on=<0?oQBP@0on1:00<0on5;
0?oPBP3oh4X00P3oh4X0103ogdX0on1:0?oPBP3ogdX80?oPBP030?oQB`3ogTX0omm:00h0omm:00<0
on5;0?oOBP3ogdX00`3ogdX00`3oh4X0omm:0?oOBP070?oOBP030?oPBP3ogd/0omi:0080omi:00<0
omi90?oNBP3ogTX02@3ogTX0103oh4/0omi90?oOBP3ogdT=0?oNB@030?oPB`3ogTT0omi900`0omi9
00<0om]80?oMB@3ogDT0303ogDT00`3ofTX0omY90?oMB@0<0?oMB@030?oOBP3ogTT0ome90080ome9
2`3og4T0103ofDL0oma90?oLB@3ogDX:0?oLB@030?oNBP3ogDX0om]900D0oma92@3ofdP00`3og4T0
omY90?oKB0030?oKB0030?oLB@3ofdP0om]800P0om]800<0oma:0?oGA`3og4P0103ofdP20?oJB003
0?oKB@3of4P0omQ800<0omQ800d0omU80?oHB03of4P0omM70?oJAP3of440omI80?oGB`3ofeD0omIN
0?o;LP3odIL0oo;T0?l0ooooo`3ooon50?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWiol0ooooa`3oool02`3ooO/0om[90?o6U@3oaWL0olAM0?o0F03o_4l0okm9
0?no@P3o`DL0ol980080ol1:00<0okm80?nmA`3o`4X00P3o`4X01@3o`D/0ol=;0?o4B`3oaD/0olE<
00L0olM<00<0olM=0?o7C03oad`01P3oad`02`3o`TX0ok]60?nnA`3obD`0olM<0?o9C03ocdl0O4DI
00/70P3o/S/0onE<00P0on1:00@0omm:0?oPBP3ogTX0on1;0P3ohD/80?oPBP030?oQB`3ogdX0on1:
00@0omm:00<0omi:0?oOBP3ogdX01@3ogdX00`3oh4/0omm:0?oQB`040?oOBP030?oMB@3ogdX0omm:
00P0omm:00@0on1:0?oOB`3ogTX0omi:0P3ogdX;0?oNBP030?oPB`3ogTT0omi:00/0omi900@0omm:
0?oNB@3ogTT0on1;3@3ogTT00`3ogdX0omi90?oNBP0=0?oMB@030?oNBP3ogTT0ome900l0ome900<0
omi90?oMB@3og4T02@3og4T00`3ogDT0om]90?oMB@020?oMB@@0oma90P3ogTX00`3ogDT0oma90?oL
B@030?oLB@030?oKB03og4T0oma900@0oma92@3ofdP00`3oedL0omU80?oKB0040?oKB0030?oIB03o
fdP0om]800H0om]800@0oma:0?oJB@3ofdT0om]80`3ofTP60?oHB00;0?oKB@3ofTP0omY60?oG?@3o
eT<0omA;0?oBDP3ogf/0omIe0?o?R`3oj<X0o`3ooooo0?ooohT0oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oooo;0?ooo`0?0?oek@3ojmh0onK?0?oX``3o
eJP0olZ90?o8O03obFP0ok]@0?nkB`3o_T/0ol160?o0A`3o`DT0ol5:00@0ol5;0`3o`T/01P3o`d/0
olA<0?o4B`3oa4`0olI=0?o6C0L0olM<00X0ol9:0?nkAP3o_TL0olU<0?o9C@3oad/0UeHQ00T50P1l
G1h0onE<103oh4X01P3ogdX0on1:0?oPBP3oh4X0on5:0?oOBPP0on1:103ohD/00`3oh4X0on5;0?oP
BP020?oOBP040?oPB`3ohDX0on1;0?oOB`<0omm:00<0on1:0?oPB`3oh4/00P3oh4/00`3ogdX0on5;
0?oOBP0<0?oOBP040?oPB`3ogdX0on1:0?oOB`80omi:00<0oma90?oNBP3ogTX01`3ogTX20?oOB`04
0?oNBP3oh4/0omi90?oKB@/0omi900@0omm:0?oNB@3ogTT0omi:3P3ogTT00`3ogdX0omi:0?oMB@0<
0?oMB@80omi92@3ogDT00`3ogTT0omi:0?oNBP020?oNBP040?oIB03ogDT0omi:0?oMB@80oma91@3o
gDX30?oLB@030?oMBP3og4X0omY80080ome:00<0ome90?oNBP3og4T02@3og4T00`3ofdP0omU90?oL
B@040?oLB@T0om]800<0oma90?oJB03ofTP00P3ofdP01P3og4T0om]80?oKB@3ofTP0om]90?oJB080
oma900L0omY80?oIB03ofTP0omQ80?oJB@3oedL0omQ80080omU800l0omQ80?oJB03ofD@0omU40?oH
B@3oeDh0omQL0?oRL`3ogGL0omZ90?o]_`3ok[`0onc70?o/e`3ooOh0o`3ooooo0?oooh`0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooB0?ooo`0;0?oi
mP3oh=40omk40?oP_P3oeih0oki`0?neEP3o^D`0okm50?o0A03o`DL0103o`4X00`3o`DX0ol1:0?o1
B`020?o0BP050?o1BP3o`D/0ol9:0?o1B`3o`d/00P3oaD`02P3oaT/0ol190?nkAP3o_TL0olU<0?o;
CP2JF2800P0000T50P3ob4820?oPBP80omm:00<0on9:0?oOBP3oh4X01`3oh4X00`3ogTX0on1:0?oP
BP070?oPBP030?oQB`3oh4X0omm:00<0omm:00<0ome90?oPBP3ogdX00`3ogdX30?oPBP030?oPB`3o
gdX0on1;00<0omm:00@0oma90?oNB@3oh4/0omm:103oh4/40?oOBP050?oPBP3ogd/0omi:0?oNBP3o
gDT0303ogTX00`3ogdX0omi90?oJB00=0?oNB@030?oOB@3ofdT0omm900d0omi900<0omm:0?oOB@3o
gDT0303ogDT0103ogTX0omY:0?oNBP3ogDT30?oNBPD0ome9103ogTT0103ogTX0ome90?oMB@3ogDT<
0?oLB@050?oMB@3ogDX0oma90?oLB@3ogTX02`3og4T01P3ofDP0om]90?oLB@3og4T0ome:0?oLB@X0
om]800<0omY90?oJB03ofdT00P3ofTP0103of4P0omY80?oJB03oedL30?oHB080omY80`3of4P02`3o
fTP0om]70?oLA@3ofSd0omU60?o>DP3odgX0on:>0?o`^`3oj/`0oo?/0?l0ooooo`3ooonD0?ooo`04
0>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooeP3oool0303o
o?l0oo7/0?o]g`3ok]T0omne0?nkLP3o]5`0okU>0?no@P3o`4D0ol580?o1BPT0ol1:00`0ol5;0?o2
B`3o`T/0oki80?nkAP3o_DH0olA;0?nbA00?2@<000000:5U8@3ohd/20?oOB@030?oQBP3oh4X0on1:
00P0on1:00<0omi90?oPBP3oh4X0203oh4X00`3ohD/0on1:0?oOBP030?oOBP030?oMBP3ogdX0omm:
00H0omm:00<0on1:0?oOBP3ohD/00`3ogdX20?oNBP`0omm:00<0omi:0?oPBP3ogdX0303oh4/00`3o
gTX0omi90?oLB@0>0?oNB@030?oJB03ogdT0omi900T0omi90`3ogdX00`3ogTT0omm:0?oOBP030?oO
BP030?oNBP3ogDT0ome900H0ome900@0omi90?oGB03ogTT0ome90P3ogTT;0?oMB@030?oHAP3ogDT0
ome900`0oma900D0om]80?oHB03ogDT0ome90?oNBP0;0?oLB@060?oJB@3ofdP0oma90?oLB@3ogDT0
oma91@3ofdP0103ofDP0om]90?oKB@3ofDP20?oHB0030?oJB03oedP0omQ800D0omQ800<0omY80?oG
B03of4P00P3ofTP02`3ofTH0omU10?oI@`3oeTT0olY>0?o2H`3ofil0ooG:0?ocg@3om_40ooom0?l0
ooooo`3ooonG0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
iol0oooofP3oool02`3oo_l0ooSg0?oflP3om^`0on?30?noO`3o/EL0okA=0?nnB03o`4P0ol1:0080
ol5;0P3o`DX50?o0BP0<0?noB03o^dH0ok]60?o3BP2/L2X0000004T_3`3o^cl0on1:0?oMB@3ogTT0
on19503oh4X20?oQB`@0omm:00<0omi90?oOBP3oh4X02@3ogdX0103ohD/0omm:0?oOBP3oh4X<0?oO
BP040?oPBP3ogd/0omi:0?oLB0/0omi:00D0omm:0?oNBP3ogTX0omi90?oOB@0>0?oNB@030?oKB@3o
gdT0omi900d0omi900<0omm90?oMB@3ogDT0303ogDT20?oNBPh0ome900@0omQ80?oMB@3ogTX0ome:
3P3og4T00`3ogDX0omi:0?oLB@0;0?oLB@050?oGA`3og4T0oma90?oLB@3ofTT00P3ofdT0103ofTP0
omQ80?oHB03of4P20?oJB00G0?oIB03ofTP0omQ80?oHB03ofDT0omQ80?oJB03of4P0omU80?oIA`3o
fdT0omQ80?oIA`3oedD0om]70?o;C@3oaf40omJJ0?oRYP3ooN`0ooW_0?ohm03ooOl0o`3ooooo0?oo
oi/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooR
0?ooo`0E0?ocj@3ohLL0ombh0?oJ[@3ofYd0ol^80?o2KP3o_Ul0ol=G0?o2DP3o`4d0oki;0?o0B`3o
_D@0okY40?nY@00n8`h09AL80>:K=03ogDX0omU800<0omQ800X0omU90?oJB@3ogDX0oma90?oMB@3o
g4T0ome90?oNBP3ogdX0ome90P3ogdX90?oPBP030?oQB`3oh4X0omm:0080omm:00L0omi:0?oOBP3o
gdX0omm:0?oNBP3ogdX0on1:00@0omm:00H0on1;0?oQB`3ogdX0omm:0?oMBP3ogTX;0?oOBP040?oP
BP3ogd/0omi:0?oMB@h0omi:00<0omm:0?oNB@3ogTT03@3ogTT00`3ofdT0omm90?oNB@0<0?oNB@03
0?oOBP3ofdT0ome900d0ome90P3ogTT00`3ogTX0ome90?oMB@0;0?oMB@80omi900<0omm:0?oMBP3o
g4T02`3og4T0103ofdT0oma90?oLB@3ogTX80?oLB@050?oKB@3ofTT0omY80?oJB03og4T00`3ofDP5
0?oHB0050?oIB03ofTP0omU70?oJAP3ofDH00P3oedT0303of4/0omM>0?oJC`3oeeL0om1M0?oGMP3o
iIT0onbZ0?oT[P3oi[l0oo7W0?okj_l0ooooo`3ooonS0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooojP3oool0403oo?P0onCO0?o>Z`3o`8L0ol]n0?o>
LP3o[580EC0?01X@1P3o]C`0onA=0?oI@03ofT80oma60?oKB03ofTP60?oHB0030?oJB03of4P0omQ7
00@0omQ80P3ofdT01@3ogDT0oma90?oLB@3ogTT0omm90080omm:00@0omi:0?oOBP3ogdX0omi9203o
gdX01@3oh4X0omm:0?oOBP3ogdX0on1;00l0omm:00@0on1;0?oOB`3ogdX0omm:303ogTX00`3oh4/0
omm:0?oLB@0?0?oNB@030?oKB@3ogdT0omi900`0omi900<0omm90?oKB@3ogDT03P3ogDT00`3ofdP0
omm:0?oMB@0<0?oMB@040?oLB@3ofTP0omi:0?oMBP/0oma90P3ofTT01@3og4T0omY80?oJB03ofdT0
omY900L0omQ801H0omU80?oIB@3of4P0omQ80?oIB03of4P0omY80?oHB03ofdL0omY40?oJ@03of3/0
omE90?oCC03oe5D0omIL0?oOL03ofG/0omB10?oDW@3oh<H0oo;Io`3ooooo0?oooj`0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oooo_0?ooo`0@0?omo`3o
_kD020L=05Hh8P3oiI@0onVA0?oKL03oefT0om5G0?o@C03oe4X0omU50?oI?03ofT<0omY40?oKB0<0
omQ800<0omM80?oHB03of4P01@3of4P20?oJB080omQ80`3ofDT00`3og4T0omY90?oMB@020?oMB@80
omi:0`3ogdX0103ogTT0omm:0?oPBP3oh4X30?oOBP030?oNBP3og4T0omm:00/0omm:00<0on1:0?oO
B`3ogDX03@3ogTX00`3ogdX0omi:0?oLB@0?0?oNB@030?oKB03ogdT0omi900`0omi900<0omm90?oI
B@3ogDT03P3ogDT00`3ofTP0omm:0?oMB@0=0?oMB@040?oNB@3ogDT0oma90?oKBP80oma90`3ofdT0
0`3ofTP0om]90?oKB@020?oKB@80omQ800<0omI80?oHB03of4P01`3of4P20?oJB00A0?oHB03ofTL0
om]70?oJA@3oed40omXo0?oG>P3oeDX0om1>0?oCH03oefd0on>90?oQUP3ofil0ombe0?oRb@3on_X0
o`3ooooo0?oook40oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooa0?ooo`0F0=jIX03P/k@0oooo0?ooo`3omnh0on_M0?oS``3oh[<0onN`0?oXU03ofXD0
om1U0?o>G@3od4`0omQ10?oG=`3ofd00omY40?oKAP3ofdL0oma80?oIB@<0omQ80P3ofDT00`3ofTP0
omQ80?oHB0030?oHB0040?oFB03of4P0omQ80?oHB080omY80`3ofdT00`3ofDP0omQ80?oIB0030?oM
B@030?oNBP3ogdX0omi:0080omi:00<0omm:0?oPBP3oh4X00P3oh4X50?oOBP040?oPBP3ogdX0oma9
0?oMBPh0omi:00<0oma90?oNB@3ogTT03@3ogTT00`3ofdT0omm90?oNB@0=0?oNB@030?oJBP3ogDT0
ome900h0ome900<0omi:0?oMB@3ogDT00`3ogDT00`3og4P0ome:0?oMBP020?oMB@080?oLB@3ofdP0
om]80?oKB03ofdT0om]80?oKB@3ofDT20?oJB0D0omQ800@0omY80?oHB03of4P0omY80P3of4P05`3o
fDT0omQ80?oHB03of4P0omY80?oIB@3ofdP0om]60?oJ@`3of3d0omPk0?oG@P3ocd/0ole=0?o>F`3o
dfT0omIe0?oWTP3ojZX0on:g0?oWc`3ok^80ooko0?l0ooooo`3ooonf0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooonP3oool0503oood0oo[k0?ogkP3o
m^/0ooOT0?ohf03om=T0on>h0?oMY03oh9`0on6H0?oTU@3oj8T0omae0?oHJP3oe5/0om9C0?oBB`3o
eDT0omU80P3ofDH01`3ofDL0omY80?oIB03ofDP0omQ80?oIB03ofTT00`3of4P20?oIB@030?oHB03o
fDP0omM70080omQ800@0omY80?oEB03ofTT0omU80P3ofTP40?oJB@040?oKB@3og4T0oma90?oLB@80
om]900<0oma90?oMBP3og4T02@3og4T00`3ogDT0omi:0?oMB@020?oMB@l0omi:00<0ome90?oJB@3o
gdX02@3ogTT40?oLB@030?oMB@3ofDP0oma900H0oma900L0om]90?oKBP3ofdX0oma90?oKBP3og4T0
om]90080oma900<0om]80?oIB03ofDP0103ofDP20?oIB@030?oJB03ofTT0omU800<0omQ800<0omE8
0?oIB03of4P00`3of4P0703ofTT0omQ80?oJB03ofDP0omU70?oJA`3ofDH0omQ60?oIB03oedP0om=:
0?o>C03ocU80omIP0?oKK`3ojY<0onJE0?oPUP3ohJ40on:^0?oY``3okLd0ooSK0?ogi03om^D0ooOZ
0?ohl03on?Go0?ooool0oooo_03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinOo0?ooool0oooo2@3oool03@3oo_l0oo_l0?oln03onoD0oocd0?onl`3oj<00omNO
0?o:NP3o`f40olA?0?o8C03oddX00`3ofDT60?oHB0040?oHA`3oeTH0omI60?oJA`80omY8103of4P0
0`3ofTP0om]90?oIB@060?oHB0030?oJB03oe4L0omQ800T0omQ800<0omY80?oJB@3of4P00P3of4P0
0`3ofdT0omQ80?oHB0060?oHB0090?oJB03of4P0omQ80?oKB@3ofTP0omQ80?oJB03odTL0omY800X0
omQ800D0omY90?oHB03of4P0omQ80?oJB@090?oHB0030?oJB03ofdT0omQ800<0omQ800<0omA70?oH
B03of4P01@3of4P01@3ofDP0omU70?oIA`3ofDL0omU800<0omQ800@0omY80?oKB@3of4P0omY80`3o
fDT03@3oeTT0olQ>0?o8H`3obG<0olM^0?oJY`3oiK@0ookc0?onm03oo?D0oo[f0?ojn03ooOh0o`3o
oooo0?ooolX0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?oooaL0oooo00T0onc@0?oM]`3oe9d0olb20?o:M03obf00ol]O0?oFFP3og5H00P3ofE80
1P3od4`0omA90?oHC03of4/0omQ:0?oGB@<0omQ800D0omU70?oHA03ofDD0omU50?oJAP020?oHA`03
0?oLA`3oe4L0om]80080omY800D0omU80?oHB03of4P0omU90?oJB@070?oHB0030?oJB@3of4P0omQ8
00D0omQ800<0omU80?oKB@3of4P0103of4P00`3ofTP0om970?oJB0060?oHB0030?oIB@3ofTP0omQ8
00D0omQ800<0omY90?oHB03of4P00P3of4P20?oJB0030?oIB03ofdT0omY80080omY70P3of4L20?oI
A@0F0?oEA03ofD@0omQ40?oHB03ofDT0omQ90?oFB@3oedX0omM<0?oHC03of500omYA0?oJE@3ogEP0
omeI0?oAG03oc640olES0?o0M`3ocH<0omfe0?o^eOl0ooooo`3ooooH0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooolO0?ooo`0I0?omm@3oi=40
on;60?oFX`3o`7X0olnA0?o?P@3ocg80om1b0?oEK@3oh6/0omm[0?oNI03ofUl0omQK0?oIF`3oeeD0
omA@0?oFD03oeDd0omA90?oEB@3oeTX0omE:0?oGBP050?oHB0070?oH@03ofT80omU20?oJ@P3of440
omU40?oEA@040?oJAP030?oKAP3og4H0omY600L0omY600<0om]60?oEAP3ofdH00`3ofTH01@3ofdH0
oma60?oKA@3ofD80omQ10080omY200D0omU20?oJ@P3ofT80omY20?oJA0030?oHB0030?oIB03oedX0
omI:00<0omI:0`3oe500403oeDl0omMH0?oIG03oeEP0omUL0?oNH03oh6T0oma]0?o?L`3od780olim
0?o@T03odYX0omo10?oRaP3ol^?o0?ooool0ooooh@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`00
1`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo:`3oool02P3oo_T0ooKd0?obj@3olnX0onoM
0?o[dP3ojm<0onW=0?o[``3oj/<20?o[a@030?o/a03oll00oo;10080oo;100<0oo:l0?oNV03ofhh0
0P3ofhh00`3ofi00omAn0?o7G`0>0?o?J@040?o?JP3obV00olQQ0?o?J0<0olmY00<0oliX0?o?K03o
fXX01`3ofhh00`3oi9d0oo?00?oc`@020?ob`@050?o/``3oj/D0on_50?o[a@3oj/L00`3ojm801P3o
j]00oo3R0?odj`3olNH0oo?]0?onnOl0ooooo`3oooo[0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?ooool0ooooo`3ooomR0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooooo0?ooool0
ooooo`3ooomR0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OW
iol0ooooG`3oool02@3onOh0hYbR07iGFP1;=3H00000038S901UADP0bH^@0?oXk00=0?ooo`070<V;
T01UADP000000000001;=3H0/7Un0?o`m@0H0?ooo`030?oQjP39Ri00IDE80080000000@06A4B06E5
B03FTiT0oo?lo`3ooooo0?ooool0ooooa03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0
103YjNT0dM7A0=7Ad@3WinOo0?oooed0oooo00<0oo3e0:FDV@0i:2T01`0000000`0J4Q80P61S0>C5
b0090?ooo`030?;Oh`0V6Q/0000000D0000000<0omoS0?ooo`3oool00`0000000`3o_lH0oooo0?oo
o`040?ooo`040?noaP0000000000000000H0oooo00<0ooWn07m/K@000000200000000`2GJ6`0oooo
0?ooo`030?ooo`<0000000<0oko60?ooo`3oool0o`3ooooo0?ooool0oooo^03oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooe`0oooo00<0on7Z01TA4P00
00000`000000101UADP0bH^@07iGFP0I4A840000000309MXK03oool0oooo00H0oooo00D0VI6B0000
00000000000004`d=P020<V;T00404/d=P3ogn<0oooo0?ooo`<0000000<0oko60?ooo`3oool0103o
ool0103o_lH000000000000000060?ooo`0607iGFP00000000000000000b8b@0f9bR0P3o_lH01039
Ri009QXK0000001UADP50?ooo`<0000000<0oko60?ooo`3oool0o`3ooooo0?ooool0oooo^03oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooe/0oooo00<0
ooWn04/d=P0000000P0000000`1nEeX0on7Z0?ooo`020?ooo`030?oco039Ri003@T900<0000000<0
i<G80?ooo`3oool01@3oool01@20LGD00000000000000000i<G800H0oooo0`0000000`3o_lH0oooo
0?ooo`040?ooo`040?noaP0000000000000000D0oooo00H0o:fd000000000000000009MXK03olo`4
0?ooo`030?oOh`1UADP0IDE800D0oooo0`0000000`3o_lH0oooo0?ooo`3o0?ooool0ooooo`3ooonh
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooF`3o
ool01@3TaLP00000000000000000F3do00L0oooo00D0S75e000000000000000008aiOP070?ooo`05
081PH`00000000000000003ol?D01P3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000
0000000000001@3oool0100b8b@000000000001nEeX80?ooo`030?noaP3oool0oooo00<0oooo0`00
00000`3o_lH0oooo0?ooo`3o0?ooool0ooooo`3ooonh0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooF`3oool01@1VDeH00000000000000000glkA00L0
oooo00H0on_]03l/;@000000000002HJ6`3ol?D60?ooo`04081PH`0000000000000000L0oooo0`00
00000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo00D0bX^@000000000000
81HG0?o`m@0>0?ooo`<0000000<0oko60?ooo`3oool0o`3ooooo0?ooool0oooo^03oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooeX0oooo00D0oo?l00d9
2@000000000009MXK0090?ooo`050?o@f0000000000000000039Ri001P3oool01020H6<000000000
000000070?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000040?ooo`04
038S900000000000075>D@l0oooo0`0000000`3o_lH0oooo0?ooo`3o0?ooool0ooooo`3ooonh0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooFP3oool0
1@3l[K@00000000000000000om3H00X0oooo00@0Bc@f000000000000Bc@f1P3oool01020H6<00000
0000000000070?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000030?oo
o`050?oioP000000000000000020H6<03`3oool3000000030?noaP3oool0oooo0?l0ooooo`3ooooo
0?oookP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oomJ0?ooo`0409MXK0000000000001TA4P/0oooo00D0bH^@00000000000000000?oQjP050?ooo`04
081PH`0000000000000000L0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP0000000000
000000<0oooo00D0omoS00000000000000000820P00?0?ooo`<0000000<0oko60?ooo`3oool0o`3o
oooo0?ooool0oooo^03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOo0?oooeX0oooo00@09QXK000000000000Y75e2`3oool01@3ogn<00000000000000000hibR
00D0oooo00@0P61S00000000000000001`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko6
00000000000000000`3oool01@3ac]400000000000000000P71b00/0omoS00@0ooco0?ooo`3oool0
oooo0`0000000`3o_lH0oooo0?ooo`3o0?ooool0ooooo`3ooonh0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooF@3oool01@3od=P00000000000000000
oko600`0oooo00@0Bc@f000000000000UfQ/1@3oool01020H6<000000000000000070?ooo`<00000
00<0oko60?ooo`3oool0103oool0103o_lH000000000000000030?ooo`030>C5b0000000000000d0
000000@0omoS0?ooo`3oool0oooo0`0000000`3o_lH0oooo0?ooo`3o0?ooool0ooooo`3ooonh0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooF@3oool0
1@3o_lH00000000000000000oko600`0oooo00@0IDE8000000000000IDE81@3oool01020H6<00000
0000000000070?ooo`<0000000<0oko60?ooo`3oool0103oool0103o_lH000000000000000030?oo
o`030>C5b0000000000000d0000000@0omoS0?ooo`3oool0oooo0`0000000`3o_lH0oooo0?ooo`3o
0?ooool0ooooo`3ooonh0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0ooooF@3oool0103RW:80000000000000000=0?ooo`0409MXK0000000000004/d=PD0
oooo00@0P61S00000000000000001`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000
0000000000000`3oool00`3TaLP000000000000=000000040?oOh`3oool0oooo0?ooo`<0000000<0
oko60?ooo`3oool0o`3ooooo0?ooool0oooo^03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?oooeT0oooo00@0bH^@00000000000000003@3oool01039Ri00
00000000000000050?ooo`04081PH`0000000000000000L0oooo0`0000000`3o_lH0oooo0?ooo`04
0?ooo`040?noaP0000000000000000<0oooo00D0omoS00000000000000000820P0070?ooo`050820
P000000000000000003oko400`3oool3000000030>>LXP3oool0oooo0?l0ooooo`3ooooo0?oookP0
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomI0?oo
o`040<V;T00000000000000000d0oooo00@0bH^@00000000000000001@3oool01020H6<000000000
000000070?ooo`<0000000<0hYbR0?ooo`3oool0103oool0103o_lH000000000000000040?ooo`<0
000000<0P6Q/0?ooo`3oool01@3oool01020J6`000000000000000040?ooo`<0000000<0OUMJ0?oo
o`3oool0o`3ooooo0?ooool0oooo^03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?oooeT0oooo00@0bH^@00000000000000003@3oool01039Ri0000000000
000000050?ooo`04081PH`0000000000000000L0oooo0`0000000`2`NGh0oooo0?ooo`040?ooo`04
0>:LXP0000000000000000@0oooo00@0IDE8000000000000LDiA1`3oool0101nEeX000000000001U
ADP40?ooo`@0000000<0ooWn0?ooo`3oool0o`3ooooo0?ooool0oooo]`3oool0103YjNT0dM7A0=7A
d@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oooeT0oooo00@0bH^@000000000000
00003@3oool01039Ri0000000000000000050?ooo`04081PH`0000000000000000L0oooo0`000000
0`0I4A80oo?l0?ooo`040?ooo`040;1iOP000000000002HJ6`@0oooo00@0bH^@000000000000?b`]
1`3oool0101H?Cl0000000000039Ri040?ooo`@0000000<0f;bo0?ooo`3oool0o`3ooooo0?ooool0
oooo]`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
oeT0oooo00D0o[Jm00000000000000000?o@f00<0?ooo`0609MXK0000000000004`d=P3oool0ooSj
0`3TaLP0101VBTd000000000000000040>C5b0030?ohnP3oool0oooo00@0000000<0IDI80?;Ri03o
ool00P3oool01@3Ue=T03@T9000000000000F3do00@0oooo00H0ooWn06E6B000000000000:EjOP3o
nOh40?ooo`050;nUZ`071@D0000003l/;@3ol?D0103oool30000000600d92@0i9bT0i<G80?o`m@3o
ool0oocoo`3ooooo0?ooool0oooo]@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?oooeT0oooo00D0om3H00000000000000000?b]]00<0?ooo`0606E5B000
0000000007iGFP3oool0omoS2`0000000`3ogn<0oooo0?ooo`030000000706E5B00000003@T909MX
K039Ri00UfQ/01TB4P030000000308b2Q`3oool0oooo00<0oooo00T0oo?l04/d=P000000000001TA
4P39Ri00oko60>:LXP0b8b@00P0000000`0I4A80on7Z0?ooo`040?ooo`<0000000<0bH^@00000000
00000P0000000`20H6<0oooo0?ooo`3o0?ooool0ooooo`3ooonc0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooFP3oool3000000030<V;T03oool0oooo
00X0oooo0`0000000`39Ri00oooo0?oOh`0;000000030?oOh`3oool0oooo00<0000000<0oko604/d
=P0000001`0000000`3ne]X0oooo0?ooo`040?ooo`030?o@f00=2@T0000000L0000000<0hYbR0?oo
o`3oool0103oool3000000030?ooo`0V6Q/000000080000000<0P61S0?ooo`3oool0o`3ooooo0?oo
ool0oooo/`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?oooeX0oooo00@0Bc@f000000000000IDE82`3oool01`3od=P00000000000000000o:fd0?ooo`3o
gn<02`0000000`3ogn<0oooo0?ooo`03000000030?noaP3olo`0?b`]00D0000000<06A4B0>:LXP3o
ool01`3oool00`2bW:800000000000050000000308aXK03oool0oooo00@0oooo00H0oko600000000
00006A4B0?ooo`2bW:8300000003081PH`3oool0oooo0?l0ooooo`3ooooo0?oook<0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomJ0?ooo`050<Z;T000
0000000000d92@3ne]X02P3oool01@2TLGD000000000000V6Q/0oo3e00D0oooo00@0P61S00000000
000000001`3oool3000000090?noaP3oool0onoa0<^d]P2ITI80P8200:JJV`3TaLP0ooWn00X0oooo
00P0omoS0<^d]P2UVY/0P82008b8R@2bXZ@0i<G80?olo``0oooo00@0o]KJ0<^d]P2UVY/0`;2bo`3o
oooo0?ooool0oooo]@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinOo0?oooeX0oooo00D0oo?l00d92@000000000007iGFP090?ooo`050?oQjP00000000000000
0039Ri001P3oool01020H6<000000000000000070?ooo`<0000000<0oko60?ooo`3oool0o`3ooooo
0?ooool0oooog@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?oooe/0oooo00D0C3@f00000000000000000?oXk0080?ooo`0509MXK000000000000000003o
hNX01P3oool01020H6<000000000000000070?ooo`<0000000<0oko60?ooo`3oool0o`3ooooo0?oo
ool0oooog@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?oooe/0oooo00D0P75e00000000000000000:FJV`070?ooo`050?oOh`00000000000000001<=3H0
1`3oool01020H6<000000000000000070?ooo`<0000000<0oko60?ooo`3oool0o`3ooooo0?ooool0
oooog@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
oe/0oooo00L0k=_N01TB4P000000000002HJ6`2bXZ@0onS/00@0oooo00<0lLkA04dm?`0000000P00
00000`2oZ:`0oooo0?ooo`050?ooo`040?STj02oZjd0P82007iGFPL0oooo0`0000000`3o_lH0oooo
0?ooo`3o0?ooool0ooooo`3ooooM0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0ooooG03oool00`3od=P06A4B000000030000000404/d=P2mPXL0UfQ/038S
90@0000000<0/7Un0?ooo`3oool04@3oool3000000030?noaP3oool0oooo0?l0ooooo`3ooooo0?oo
omd0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooomM
0?ooo`030?o@f01;=3H0000000T0000000<0bH^@0?ooo`3oool04P3oool3000000030?noaP3oool0
oooo0?@0oooo00L0oko609MXK00I4Q800000038S901nEeX0lLkA00d0oooo00L0bH^@06E5B0000000
000004/d=P2`NGh0oo3e01P0oooo00<0on7Z0<V;T01UADP00P000000100I4A80IDE80=JCV@3olo`T
0?ooo`070?noaP2GJ6`06A8B0000000b8b@0OUMJ0?7>d@0=0?ooo`070<V;T01UADP000000000001;
=3H0/7Un0?o`m@0>0?ooo`030?o@f02GJ6`0<R<T0080000000<0LTiA0<V;T03ohNX0103oool00`3o
d=P0UfQ/038S90020000000301TB4P1nEeX0hYbR0?l0ooooo`3ooom;0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooGP3oool00`3olo`0LDiA00000006
0000000303<S903o_lH0oooo01@0oooo0`0000000`3o_lH0oooo0?ooo`3C0?ooo`040?noaP000000
0000000000L0oooo00@0f;bo0000000000006A4B1`3oool0103o_lH000000000000000060?ooo`03
09MXK0000000000000@0000000@09QXK0?o@f03oool0UfQ/0P0000000`3od=P0oooo0?ooo`030?oo
o`030?oioP1;=3H0000000D0000000<0omoS0?ooo`3oool00`0000000`3o_lH0oooo0?ooo`040?oo
o`040?noaP0000000000000000L0oooo00<0f;bo0000000000001`0000000`39Ri00oooo0?ooo`03
0?ooo`<0000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`00
00000000000000D0oooo00<0UfQ/00000000000010000000100V6Q/0om3H0?ooo`2GJ6`200000003
0?o@f03oool0oooo00<0oooo00<0ooWn04/d=P0000001@0000000`3ogn<0oooo0?noaP03000000L0
oooo00<0om3H06E5B00000001`000000103od=P0oooo0?oQjP0b8b@800000003038S903oj>`0oooo
0?l0ooooo`3ooom80?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWiol0ooooG`3oool02@3oo?l0lLkA0<^d]P2bXZ@0P82008b8R@2bXZ@0f;bo0?odmP0F0?ooo`<0
000000<0oko60?ooo`3oool0d`3oool0103o_lH000000000000000070?ooo`0508amO`0000000000
0000003UaLP01P3oool0103o_lH000000000000000050?ooo`050:J:S@00000000000000000i:2T0
0P20H6<01@1aCU406Q8B00d92@2UPXL0F3do008000001P3oool01@2oZjd000000000000000009QXK
0080IDI800@09QXK0?oOh`3oool0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP000000
0000000000H0oooo00H0_jF[01<=3P000000000001TB4P1/Ce42081PH`0406E6B00C3@h0000006E5
B0D0oooo0`0000000`3o_lH0oooo0?ooo`030?ooo`040?noaP0000000000000000L0oooo00@0P61S
0000000000000000103oool01@2VRXd00000000000000000>BPY0080P61S00D0LDiA01XB4P0=2@T0
YH:705Pm?`02000000H0oooo00D0_j^]000000000000000002HJ6`0206E6B00402HJ6`3ogn<0oooo
0?noaP<000001P3oool01P2aSY4000000000000000001`D503l/;@80IDI800<081HG000000000000
0P3oool0103ob<l000000000000C3@h306E6B00503TX:@00000000000000001C@T@0o`3ooooo0?oo
odT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?oooeP0oooo00@0oko600000000000000001`3oool01@1H?Cl00000000000000000S8R900H0oooo
00@0oko600000000000000001@3oool01@0o;2d000000000000I4A80onS/00<0oooo00<0lLkA0000
000000000`0000060?ooo`05081aM@00000000000000003TaLP01P3oool3000000030?noaP3oool0
oooo00@0oooo00@0oko600000000000000001@3oool01P3l[K@00000000000000000UfQ/0?oco0@0
oooo00<0omoS06E5B01UADP01@3oool3000000030?noaP3oool0oooo00<0oooo00@0oko600000000
000000001`3oool01020H6<000000000000000040?ooo`0503l/;@000000000001TA4P3oj>`00`3o
ool00`3ac]40000000000003000000H0oooo00D0P75e00000000000000000>C5b0050?ooo`040?no
aP0000000000000000D0oooo00<0om3H0000000000000P0000000`3T_lH0oooo0?ooo`020?ooo`03
0?b]]01UADP0oooo0080oooo00<000000;1iOP3ol?D0103oool01@3RW:800000000000000000hYbR
0?l0ooooo`3ooom80?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWiol0ooooo`3ooomH0?ooo`040?noaP0000000000000000L0oooo00D06A8B0000000000000000
081XK0060?ooo`040?noaP0000000000000000D0oooo00@03@T9000000000000bH^@1@3oool00`39
Ri00000000000002000000H0oooo00D0P61S00000000000000000?o`m@060?ooo`<0000000<0oko6
0?ooo`3oool0103oool0103o_lH000000000000000050?ooo`04038S90000000000007iGFPP0oooo
00<0oko60?ooo`3oool00`3oool3000000030?noaP3oool0oooo00<0oooo00@0oko6000000000000
00001`3oool01020H6<000000000000000040?ooo`0400d92@00000000000<V;T0D0oooo00<0bH^@
0000000000000P0000060?ooo`05081PH`00000000000000003ol?D01@3oool0103o_lH000000000
000000050?ooo`0506E5B000000000000000003RW:802@3oool00`3olo`0on7Z0?ooo`060?ooo`04
0<V;T0000000000007iGF_l0ooooo`3ooom80?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooomH0?ooo`040?noaP0000000000000000H0oooo00<0
on7Z0000000000000P0000000`1H?Cl0oooo0?ooo`040?ooo`040?noaP0000000000000000@0oooo
00D0on7Z00000000000000000?oQjP060?ooo`04038S900000000000000000H0oooo00@0P61S0000
0000000000001`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000000000000000103o
ool01@3l[K@00000000000000000on7Z00h0oooo0`0000000`3o_lH0oooo0?ooo`030?ooo`040?no
aP0000000000000000L0oooo00@0P61S00000000000000000`3oool01@3ohNX00000000000000000
on7Z00H0oooo00@0<R<T00000000000000001P3oool01020H6<000000000000000060?ooo`040?no
aP0000000000000000@0oooo00D0oko6000000000000000009MXK00C0?ooo`040?oco00000000000
038S9?l0ooooo`3ooom80?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0ooooo`3ooomH0?ooo`040?noaP0000000000000000H0oooo00L0RV1S000000000000
?b`]0000000=2@T0onS/00D0oooo00@0oko60000000000000000103oool0103o_lH0000000000000
00070?ooo`040>BUZ`0000000000000000H0oooo00@0P61S00000000000000001`3oool300000003
0?noaP3oool0oooo00@0oooo00@0oko60000000000000000103oool0101UATP000000000001H?Cl?
0?ooo`<0000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`00
00000000000000<0oooo00@0oko600000000000000001`3oool0103TYJ/000000000000000060?oo
o`04081PH`0000000000000000H0oooo00@0oko60000000000000000103oool01@1UATP000000000
000o;2d0ooWn01<0oooo00@0onS/0000000000000000o`3ooooo0?ooodP0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oooeP0oooo00@0oko60000
0000000000001@3oool01@3ohNX000000000000b8b@0on7Z0080000000<0/7Un0?ooo`3oool00`3o
ool0103o_lH000000000000000040?ooo`050?oco000000000000000003ohNX01`3oool3000000H0
oooo00@0P61S00000000000000001`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko60000
0000000000000`3oool01@3onOh00000000000000000P61S00l0oooo0`0000000`3o_lH0oooo0?oo
o`030?ooo`040?noaP0000000000000000L0oooo00@0P61S00000000000000000`3oool01@3olo`0
0000000000000000on7Z00L0oooo0`0000060?ooo`04081PH`0000000000000000H0oooo00@0oko6
00000000000000000`3oool01@3ohNX00000000000000000hYbR01@0oooo00@0IDE8000000000000
Bc@fo`3ooooo0?ooodP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?oooeP0oooo00@0oko600000000000000001@3oool0203RW:8000000000002G
J6`0oooo04/d=P000000<R<T1@3oool0103o_lH000000000000000050?ooo`0401TB4P0000000000
0<V;T0L0oooo0`0000060?ooo`04081PH`0000000000000000L0oooo0`0000000`3o_lH0oooo0?oo
o`040?ooo`040?noaP0000000000000000<0oooo00D0omoS00000000000000000820P00?0?ooo`<0
000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000
000000@0oooo00@06A8B000000000000bH^@1`3oool3000000H0oooo00@0P61S0000000000000000
1P3oool0103o_lH000000000000000030?ooo`050?noaP00000000000000003od=P04P3oool00`3o
l?D0IDE800000002000000030;1iOP3oool0oooo0?l0ooooo`3ooom60?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooomH0?ooo`040?noaP000000
0000000000D0oooo00H0OUMJ000000000000o:fd0?ooo`2`NGh2000000030?o@f03oool0oooo0080
oooo00@0oko600000000000000001@3oool01@1<=3H000000000000I4A80ooWn00H0oooo0`000006
0?ooo`04081PH`0000000000000000L0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP00
00000000000000<0oooo00D0o]KJ00000000000000000820P00?0?ooo`<0000000<0oko60?ooo`3o
ool00`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0oooo00D0C3@f
0000000000006A4B0?oioP060?ooo`<000001P3oool01020H6<000000000000000060?ooo`040?no
aP0000000000000000<0oooo00@0hYbR00000000000000004P3oool00`3ohNX0C3@f000000020000
000300d92@3ohNX0oooo0?l0ooooo`3ooom70?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooomH0?ooo`040?noaP0000000000000000@0oooo00@0
lLS?000000000000;1lP0P3oool0103oj>`03@T90000001aCU440?ooo`040?noaP00000000000000
00D0oooo00P0^9nS000000000000000005=1A03;];H0o]KJ0?oioP<0oooo0`0000060?ooo`04081P
H`0000000000000000L0oooo0`0000000`3o_lH0oooo0?ooo`040?ooo`040?noaP00000000000000
00<0oooo00D0i<G80000000000000000040`<P0;081PH`040?o/l03oool0oooo0?ooo`<0000000<0
oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000@0
oooo00P0^9nS000000000000000005=1A03;];H0o]KJ0?oioP<0oooo0`0000060?ooo`04081PH`00
00000000000000H0oooo00@0oko600000000000000000`3oool01039Ri00000000000000000?0?oo
o`030=W9c@20H6<0?b`]00@0000000<03@T90;6>T@3oool0o`3ooooo0?ooodP0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oooeP0oooo00@0oko6
0000000000000000103oool0101nEeX000000000001aCU430?ooo`0405Pm?`00000000000?o@f0<0
oooo00@0oko600000000000000001P3oool00`3RW:8000000000000:000000H0oooo00@0P61S0000
0000000000001`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko600000000000000000`3o
ool00`3TaLP000000000000=000000040?oOh`3oool0oooo0?ooo`<0000000<0oko60?ooo`3oool0
0`3oool0103o_lH000000000000000070?ooo`04081PH`0000000000000000D0oooo00<0hYbR0000
000000002P0000060?ooo`04081PH`0000000000000000H0oooo00@0oko600000000000000000`3o
ool01039Ri00000000000000000>0?ooo`030?noaP0=2@T0000000@0000000<0UfQ/0?oco03oool0
o`3ooooo0?ooodT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?oooeP0oooo00@0oko60000000000000000103oool0100I4A80000000000020NWh3
0?ooo`04081XK000000000000;1iOP<0oooo00@0oko600000000000000001`3oool00`3od=P0OUMJ
00000009000000H0oooo00@0P61S00000000000000001`3oool3000000030?noaP3oool0oooo00@0
oooo00@0oko600000000000000000`3oool00`3TaLP000000000000=000000040?oOh`3oool0oooo
0?ooo`<0000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`00
00000000000000H0oooo00<0om3H07iGFP0000002@0000060?ooo`04081PH`0000000000000000H0
oooo00@0oko600000000000000000`3oool0103l[K@0000000000000000=0?ooo`030?o@f00I4A80
000000<0000000<0OUMJ0?oco03oool0o`3ooooo0?oood/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oooeP0oooo00@0oko60000000000000000
0`3oool01@3UaLP00000000000000000f;fo00<0oooo00D0^:NX0000000000006A8B0?odmP020?oo
o`040?noaP0000000000000000T0oooo00@0l]_O0<^d]P2bXZ@0S8R90`20P803000000H0oooo00@0
P61S00000000000000001`3oool3000000030?noaP3oool0oooo00@0oooo00@0oko6000000000000
00000`3oool01@3ogn<00000000000000000P82000L0oooo00D0P82000000000000000000?o_l@03
0?ooo`<0000000<0oko60?ooo`3oool00`3oool0103o_lH000000000000000070?ooo`04081PH`00
00000000000000P0oooo00@0l]_O0<^d]P2bXZ@0S8R90`20P803000000H0oooo00@0P61S00000000
000000001P3oool0103o_lH000000000000000030?ooo`050?oOh`00000000000000003a[[@0303o
ool01P0o;2d000000000000I4Q80S8:70?7>dOl0ooooo`3ooom>0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooomH0?ooo`040?noaP0000000000
000000<0oooo00D0S8R900000000000000000?oioP030?ooo`050?oOh`00000000000000003H_;l0
0P3oool0103o_lH0000000000000000@0?ooo`<000001P3oool01020H6<000000000000000070?oo
o`<0000000<0hYbR0?ooo`3oool0103oool0103o_lH000000000000000040?ooo`<0000000<0P6Q/
0?ooo`3oool01@3oool01020J6`000000000000000040?ooo`<0000000<0oko60?ooo`3oool00`3o
ool0103o_lH000000000000000070?ooo`04081PH`0000000000000000l0oooo0`0000060?ooo`04
081PH`0000000000000000H0oooo00@0oko60000000000000000103oool0101;=3H000000000002G
J6`;0?ooo`050?noaP00000000000000003l[K@0o`3ooooo0?oooe00oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oooeP0oooo00@0oko600000000
000000000`3oool01020J6`000000000001;=3H50?ooo`0401TA4P00000000000:FJV`80oooo00@0
oko60000000000000000403oool3000000H0oooo00@0P61S00000000000000001`3oool300000003
0;1iOP3oool0oooo00@0oooo00@0hYbR0000000000000000103oool0101UADP000000000001aCU47
0?ooo`0407iGFP000000000006E5B0@0oooo0`0000000`39Ri00oooo0?ooo`030?ooo`050?noaP00
000000000000003o_lH01P3oool01020H6<0000000000000000?0?ooo`<000001P3oool01020H6<0
00000000000000060?ooo`040?noaP0000000000000000@0oooo00D0/7Un0000000000006A4B0?oc
o00:0?ooo`040?noaP000000000000000?l0ooooo`3ooomA0?ooo`040>WYj@3AdM40dM7A0=cLg0d0
oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooomH0?ooo`040?noaP00000000000000
00<0oooo00@0F3do000000000000bH^@1@3oool0102GJ6`0000000000020LGD20?ooo`040?noaP00
00000000000000l0oooo00@0oko6000000000000Bc@f1P3oool01020H6<000000000000000070?oo
o`<0000000<06A4B0?oco03oool0103oool0102`NGh000000000000V6Q/40?ooo`040<V;T0000000
000003l/;@L0oooo00@0F3do000000000000bH^@103oool30000000307iGFP3oool0oooo00<0oooo
00D0bH^@00000000000000000<V;T0060?ooo`0406E6B0000000000004/d=Ph0oooo00@0oko60000
00000000Bc@f1P3oool01020H6<000000000000000060?ooo`040?noaP0000000000000000@0oooo
00D0on7Z00000000000000000<V;T00:0?ooo`040?oQjP000000000000000?l0ooooo`3ooomA0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooomH
0?ooo`040?noaP000000000000000080oooo00D0onS/00d92@0000009QXK0?o`m@050?ooo`040?kF
fP0=2@T0000004D`<P80oooo00@0oko600000000000000001P3oool0102GJ6`0S75e0>C5b03oo?l4
0?ooo`050>C5b01<=3H000000000003;U9T00P3oool01@3on?X0i<G80>C5b03TaLP0ITY=00<00000
103TaLP00`3on?X0oooo0?ooo`040000000306E6B03bh^@0oooo0080oooo00D0iMCI00d92@000000
000005Pm?`040?ooo`060?oioP1UATP000000000002UNWh0ooWn103oool01@2oYJ/01`D50000000o
;2d0oo3e00@0oooo100000001P3B^Kh0oooo0?ooo`3oool0n>OX03<S90<0000000<03@T90:FDV@3o
nOh00`3oool01@3TaLP06Q8B000000000000/7Yn00D0oooo00@0UfQ/08aaM@3TaLP0ooco103oool0
1@3TaLP0C3@f000000000000biBI0080oooo00D0ooSj0>C5b03TaLP0i<G806I:C@03000000@0i<G8
00<0ooSj0?ooo`3o_lH00`0000050?ooo`060<^UZ`071@D000000000001aCU40l^;T103oool00`3o
j>`0i<G80?ooo`020?ooo`0505Pm?`000000000008]OH`3oj>`01@3oool00`3ok?40oooo0?ooo`3o
0?ooool0ooooA`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooF03oool0103o_lH000000000000000020?ooo`040<V;T000000000000<V;T0L0
oooo00H0UfQ/000000000000on7Z0?ooo`3o_lH3000000H0oooo00@0IDE8000000000000<b<T0`39
Ri001@1aCU400000000000000000<b<T00<0oooo00<0omoS0000000000002@0000000`3ogn<0oooo
0?ooo`030000000706E5B00000003@T909MXK039Ri00UfQ/01TB4P030000000308b2Q`3oool0oooo
00<0oooo00T0oo?l04/d=P000000000001TA4P39Ri00oko60>:LXP0b8b@00P0000000`0I4A80on7Z
0?ooo`040?ooo`<0000000<0/7Un0000001nEeX00P39Ri001@0V6Q/00000000000000000IDE80080
000000@06A4B0:AaM@2`NGh0<R<T0`0000000`0I4A80oo?l0?ooo`040?ooo`0406E5B00000000000
03<S90<0bH^@00D0LDiA000000000000000003<S90030?ooo`030?oOh`000000000000T0000000<0
omoS0?ooo`3o_lH00`0000060?ooo`0607iGFP00000000000000000=2@T0IDE80P39Ri000`1aCU40
000006E5B0030?ooo`030?oQjP0I4A8000000080000000H0OUMJ0<V;T039Ri00UfQ/038S901UATSo
0?ooool0ooooB@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooF03oool0103o_lH000000000000000020?ooo`0404/d=P00000000000?o@f0L0
oooo00H0o:fd000000000000bH^@0?ooo`3o_lH3000000H0oooo2`0000001@2UU9T0oooo0?ooo`3o
ool0omoS00/0000000<0omoS0?ooo`3oool00`0000000`3o_lH0Bc@f00000007000000030?kFfP3o
ool0oooo00@0oooo00<0om3H00d92@0000001`0000000`3RW:80oooo0?ooo`040?ooo`<0000000<0
oo?l02HJ6`0000001P0000000`3ne]X0IDE800000007000000030?b]]03oool0oooo00@0oooo2`00
00001@2UU9T0oooo0?ooo`3oool0omoS00/0000000<0omoS0?ooo`3o_lH00`0000060?ooo`030?kF
fP0I4A80000000L0000000<06A4B0?ooo`3oool00P3oool00`3l[K@00000000000060000000306E6
B03oool0oooo0?l0ooooo`3ooom70?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WY
j@3AdM40dM7A0>OWiol0ooooo`3ooomH0?ooo`060?noaP00000000000000003oool0on7Z0P000000
0`0b8b@0oooo0?ooo`070?ooo`0501TA4P000000Bc@f0?ooo`3o_lH00`0000060?ooo`030?oQjP1U
ADP0000000L0000000<0/7Un0?oioP3oool00P3oool00`3ogn<0000000000009000000030?oOh`3o
ool0oooo00<0000000<0oko60?oco00o;2d01@0000000`0I4A80hYbR0?ooo`070?ooo`030;:LXP00
0000000000D0000000<0S6Q/0?ooo`3oool0103oool01P3o_lH000000000000I4A80oooo0:FDV@H0
000000@0hYbR0?ooo`3olo`0OUMJ1@0000000`0=2@T0hYbR0?ooo`060?ooo`030?oQjP1UADP00000
00L0000000<0/7Un0?oioP3oool00P3oool00`3ogn<0000000000009000000030?oOh`3oool0oko6
00<000001`3oool00`3ohNX0UfQ/00000007000000D0oooo00<0VGYn0000000000001@0000000`1U
ATP0oooo0?ooo`3o0?ooool0ooooA`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooF03oool01P3o_lH00000000000000000oooo09MXK0800000
00<0f:F[0?ooo`3oool01`3oool01@2`NWh000000000003T][d0oko600<00000203oool00`3ol?D0
d[Rk08b8R@020820P00309nEU`3TaLP0oo3e00T0oooo00@0P61S00000000000000001`3oool30000
00090?noaP3oool0onoa0<^d]P2ITI80P8200:JJV`3TaLP0ooWn00X0oooo00P0omoS0<^d]P2UVY/0
P82008b8R@2bXZ@0i<G80?olo``0oooo00H0lLkA0;n[[@2<R8T0Thf>0=Rl_`3ol?D40?ooo`060?oO
h`2/WZ00P82009VATP2bXZ@0l]oS2P3oool00`3ol?D0d[Rk08b8R@020820P00309nEU`3TaLP0oo3e
00T0oooo00@0P61S00000000000000004`3oool00`3ol?D0bkBf09VATP020820P0030:bNX03TaLP0
onS/00H0oooo00<0lLkA0;n[[@2<R8T00P20P8000`2UVY/0_j^]0?;Oh`3o0?ooool0ooooB@3oool0
103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooF03o
ool01@3o_lH00000000000000000oo?l0080000000<03@T90?ooo`3oool0203oool01@3olo`00000
0000001;=3H0oko600<000006@3oool01020H6<000000000000000070?ooo`<0000000<0oko60?oo
o`3oool0C`3oool01020H6<0000000000000003o0?ooool0ooooLP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooF03oool01@3o_lH000000000
00000000hYbR0080000000<0C3@f0?ooo`3oool02@3oool0100o;2d000000000003RW:83000001T0
oooo00@0P61S00000000000000001`3oool3000000030?noaP3oool0oooo04l0oooo00@0P61S0000
000000000000o`3ooooo0?ooog80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?oooeP0oooo00D0oko6000000000000000007iGFP020000000307iG
FP3oool0oooo00T0oooo00@0LDiA000000000000OUMJ0`00000I0?ooo`04081PH`00000000000000
00L0oooo0`0000000`3o_lH0oooo0?ooo`1?0?ooo`04081PH`000000000000000?l0ooooo`3ooomb
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3o
oomH0?ooo`030?noaP000000000000@0000000<0[9jO0?ooo`3oool02@3oool00`2OTiH000000000
0004000001T0oooo00@0n>CX0;n[[@20P800OUMJ1`3oool3000000030?noaP3oool0oooo04l0oooo
00@0n>CX0;n[[@20P800OUMJ1P3oool0103TaLP0P8200820P020P83o0?ooool0ooooJ03oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooF03oool0
0`3o_lH0000000000004000000030?7>d@3oool0oooo00T0oooo00<0lLkA0000000000001000000T
0?ooo`<0000000<0oko60?ooo`3oool0F@3oool01039Ri00000000000000003o0?ooool0ooooJ03o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
F03oool00`3o_lH0000000000004000000030?oioP3oool0oooo00T0oooo00<0oo3e000000000000
1000000T0?ooo`<0000000<0oko60?ooo`3oool0F@3oool01039Ri00000000000000003o0?ooool0
ooooJ03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooF03oool00`3o_lH00000000000030000000307iGFP3oool0oooo00/0oooo00<0Bc@f0000
000000000`00000T0?ooo`<0000000<0oko60?ooo`3oool0F@3oool01039Ri00000000000000003o
0?ooool0ooooJ03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooUP3oool3000000030?noaP3oool0oooo05T0oooo00@0i<G80820P020P800P820
o`3ooooo0?ooofP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80
oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?oo
ool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo
0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3o
oooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooonk0?ooo`0608R8R00A4A4000000000001NGUh0gMgMo`3ooooo0?oo
ool0ooooX03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?oook/0oooo00<0GUiN0000000000000`0000000`1gMgL0oooo0?ooo`3o0?ooonh0oooo00D0P820
00000000000000000::RXP3o0?ooojT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOWo`3ooonk0?ooo`0306m_K`000000000000@0000000<0IVIV0?ooo`3oool0
o`3oooo]0?ooo`050820P000000000000000002RXZ80o`3ooonY0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo^`3oool01@2k^k/0XZ:R0::RXP28R8P0
8R8R00<0000000<0WYjN0?ooo`3oool0o`3oooo/0?ooo`050820P000000000000000002RXZ80o`3o
oonY0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0oooo
_`3oool01@3<c<`00000000000000000<c<c0?l0ooookP3oool01@20P8000000000000000000XZ:R
0?l0ooooZ@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?oool00oooo00D0MgMg00000000000000000=gMg@3o0?ooond0oooo00D0P8200000000000000000
0::RXP3o0?ooojT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOWo`3oooo00?ooo`050>k^kP0A4A4000000000001gMgL0o`3oooo]0?ooo`050820P00000000000
0000002RXZ80o`3ooonY0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiol0oooo`@3oool01@28R8P00000000000092@T0eMGE0?l0ooook03oool01@20P8000000
000000000000XZ:R0?l0ooooZ@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinLZ0?ooo`090>KViP28R8P0A4A4028R8P0000008R8R04A4A028R8P0i^KV02D0oooo
00<0gMgM08R8R01=CDd00`0000000`14A4@0R8R80>k^kP0<0?ooo`030<c<c01VIVH08R8R00800000
00@0:b/[06IVIP28R8P0k^k^4`3oool0103^k^h0P82004A4A00A4A4200000080A4A400<0R8R80>KV
iP3oool09@3oool00`3<c<`0IVIV028R8P020000000402/[:`1VIVH0R8R80>k^kPP0oooo00@0a<C4
06IVIP14A4@04A4A0P00000204A4A0030:ZZZP3oool0oooo01@0oooo00<0gMgM06m_K`14A4@00P00
00000`0[:b/0R8R80<c<c00X0?ooo`030>k^kP1gMgL0<c<c0080000000<0<c<c08R8R03<c<`0?`3o
ool00`3^k^h0VIVI04A4A00200000003028R8P1VIVH0c<c<0180oooo00L0TI6A04A4A00000000000
028R8P1gMgL0^k^k00`0oooo00<0gMgM06m_K`14A4@00P000000100J6QX0EEEE08R8R03^k^h<0?oo
o`070;>c/`14A4@08R8R0000000R8R80IVIV0:ZZZP0G0?ooo`0509VIV@00000000000000001EEED0
6P3oool00`3MgMd0R8R803<c<`020000000304A4A028R8P0oooo00T0oooo00<0c<c<06IVIP0R8R80
0P0000000`0c<c<0R8R80<c<c01P0?ooo`030<c<c01VIVH08R8R0080000000@0:b/[06IVIP28R8P0
k^k^C`3oool00`3^k^h0P82004A4A0020000000302/[:`1gMgL0c<c<0140oooo00L0^k^k04A4A00R
8R800000028R8P1VIVH0VIVI0240oooo00@0eMGE07MgM`14A4@08R8R0P000000100c<c<0A4A408R8
R03^k^h]0?ooo`030>k^kP20P800A4A40080000000<0:b/[07MgM`3<c<`04@3oool01`2k^k/0A4A4
028R8P0000008R8R06IVIP2IVIT0503oool00`2k^k/0GUiN014A4@020000000403<c<`1VIVH0VIVI
0>k^kPH0oooo00<0k^k^09VIV@1EEED00P0000000`0A4A40GUiN0<c<c00R0?ooo`030;>c/`1EEED0
A4A40080000000<0<c<c05EEE@2k^k/04`3oool01@20P8000000000000000000XZ:R0080oooo00<0
gMgM06IVIP0R8R800P0000000`0c<c<0R8R80>k^kP0=0?ooo`030=GEe@1gMgL0A4A40080000000<0
A4A407MgM`2k^k/04@3oool0203MgMd0R8R804A4A00A4A40000004A4A01VIVH0eMGEo`3oooma0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWibT0oooo00<0^k^k
028R8P0000001P0000000`0R8R80^k^k0?ooo`0<0?ooo`<0000000<0A4A40?ooo`3oool0403oool0
0`1VIVH00000000000070000000308R8R03gmoL0oooo00L0oooo00<0^k^k04A4A00000001`000000
0`0c<c<0oooo0?ooo`020?ooo`050::RXP000000000000000020P800203oool00`3MgMd0IVIV0000
000800000003014A4@1gMgL0oooo00H0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0
A4A40?ooo`3oool01`3oool00`2k^k/0A4A4000000070000000303<c<`3oool0oooo00@0oooo00<0
gMgM06IVIP000000200000000`0R8R80MgMg0?ooo`0A0?ooo`030>k^kP1gMgL0000000L0000000<0
A4A40>k^kP28R8P00P0000000`0A4A40oooo0?ooo`050?ooo`<0000000<0A4A40?ooo`3oool0203o
ool30000000304A4A03oool0oooo00H0oooo00<0R8R8014A4@0000001P0000001014A4@0gMgM0?oo
o`14A4@20000000304A4A03oool0oooo0100oooo00@08R8R00000000000000001P3oool300000003
04A4A03oool0oooo00P0oooo00D0P82000000000000000000::RXP080?ooo`0308R8R00A4A400000
00H0000000@0A4A40;^k^`3oool0A4A40P0000000`0R8R80oooo0?ooo`070?ooo`030<c<c00c<c<0
000000H0000000@0<c<c0=gMg@3oool0A4A40P0000000`14A4@0oooo0?ooo`020?ooo`0306IVIP00
0000000000L0000000<0^k^k0?ooo`3oool0203oool00`28R8P00000000000040000000304A4A03o
ool0oooo0080oooo0`0000000`14A4@0oooo0?ooo`0=0?ooo`0305EEE@00000000000080000000<0
k^k^0?ooo`3oool05P3oool00`28R8P000000000000400000003028R8P3oool0oooo00H0oooo00<0
^k^k04A4A00000001`0000000`14A4@0gMgM0?ooo`0F0?ooo`030<c<c000000000000080000000<0
VIVI0?ooo`3oool0203oool01@0R8R800000000000000000MgMg00X0oooo0`0000000`14A4@0oooo
0?ooo`080?ooo`<0000000<08R8R0?ooo`3oool0103oool01014A4@0000000000000000:0?ooo`03
0;^k^`14A4@0000000L0000000<0<c<c0?ooo`3oool00P3oool01@20P8000000000000000000XZ:R
00X0oooo0`0000000`14A4@0oooo0?ooo`0?0?ooo`0504A4A000000000000000002k^k/0203oool0
1@0A4A400000000000000000ZZZZ00P0oooo00D0^k^k000000000000000004A4A0070?ooo`0309VI
V@0A4A40000000H0000000<0A4A40=gMg@2k^k/00`00000:0?ooo`030:ZZZP092@T0000000D00000
103oool0100A4A40000000000014A4@90?ooo`050?Ogm`00000000000000000c<c<02P3oool00`2I
VIT04A4A000000080000000305EEE@2ZZZX0oooo00D0oooo0`0000000`14A4@0oooo0?ooo`070?oo
o`<0000000<0EEEE0?ooo`3oool01P3oool01@3^k^h00000000000000000IVIV00H0oooo00<0VIVI
014A4@0000001P0000000`14A4@0gMgM0;^k^`03000000X0oooo00<0ZZZZ00T92@0000001@000004
0?ooo`050:ZZZP00000000000000002IVIT02@3oool00`2k^k/08R8R000000070000000303<c<`3o
ool0oooo00<0oooo00<0VIVI014A4@0000001P0000000`14A4@0^k^k0=gMg@03000000030820P03o
ool0oooo00h0oooo00@0A4A400000000000000001P3oool00`1VIVH00000000000060000000308R8
R03^k^h0oooo0100oooo00L0P82000000000000000000::RXP3^k^h0MgMg00L0000000<04A4A08R8
R03oool02P3oool00`3<c<`06QXJ000000060000000407MgM`3oool0oooo04A4A080000000<0A4A4
0?ooo`3oool01`3oool00`34a<@0000000000005000000050::RXP3oool0oooo0?ooo`20P8000`00
00000`14A4@0oooo0?ooo`3o0?ooofL0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOW9`3oool00`3^k^h0IVIV0000000:0000000306IVIP3^k^h0oooo00X0oooo
0`0000000`14A4@0oooo0?ooo`0@0?ooo`0304A4A0000000000000P0000000<0TI6A0?ooo`3oool0
1@3oool00`2RXZ800000000000080000000304A4A03oool0oooo0080oooo00D0XZ:R000000000000
00000820P0070?ooo`030<c<c00A4A40000000/000001`3oool300000003028R8P3oool0oooo00T0
oooo0`0000000`14A4@0oooo0?ooo`060?ooo`030::RXP000000000000P0000000<0A4A40?ooo`3o
ool00`3oool00`2IVIT04A4A0000000;00000140oooo00<0moOg03<c<`0000002@0000001@1_Kfl0
R8R80000000000008R8R00L0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?oo
o`3oool0103oool00`3gmoL0EEEE000000090000000303`l?03oool0A4A40080000000<0A4A40?oo
o`3oool0403oool0100R8R8000000000000000060?ooo`<0000000<0A4A40?ooo`3oool0203oool0
1@20P8000000000000000000XZ:R00L0oooo00<0XZ:R0000000000002@0000001@2k^k/0A4A40000
000000008R8R00P0oooo00<0VIVI000000000000200000000`1=CDd0oooo04A4A0020000000304A4
A03oool0oooo0080oooo00<0A4A40000000000001`0000000`0J6QX0k^k^0?ooo`070?ooo`0308R8
R0000000000000D0000000<0A4A40?ooo`3oool00P3oool30000000304A4A03oool0oooo00`0oooo
00<0gMgM0000000000000`0000000`2IVIT0oooo0?ooo`0E0?ooo`030<C4a0000000000000D00000
00<08R8R0?ooo`3oool01@3oool00`2ZZZX00000000000090000000303<c<`3^k^h0oooo01D0oooo
00<0ZZZZ0000000000000P0000000`1EEED0oooo0?ooo`070?ooo`030>k^kP000000000000800000
00<0EEEE0?ooo`3oool0203oool30000000304A4A03oool0oooo00P0oooo0`0000000`0R8R80oooo
0?ooo`040?ooo`0404A4A00000000000000000T0oooo00<0XZ:R000000000000200000000`14A4@0
oooo0?ooo`020?ooo`050820P000000000000000002RXZ802P3oool30000000304A4A03oool0oooo
00l0oooo00D0GUiN00000000000000000::RXP070?ooo`030>KViP00000000000080000000<08R8R
0?ooo`3oool01`3oool4000000H0oooo00<0VIVI000000000000200000000`0l?3`0k^k^00000002
000000030;^k^`3oool0oooo00H0oooo00<0c<c<0000000000001P0000001@2k^k/0oooo0?ooo`3o
ool0A4A400<000002P3oool0100R8R8000000000000J6QX80?ooo`030>k^kP1EEED0000000/00000
00<0<c<c0?ooo`3oool0103oool01014A4@000000000000A4A490?ooo`0403<c<`0000000000028R
8PT0oooo00@04A4A000000000000<c<c1@3oool00`2IVIT00000000000080000000303`l?03^k^h0
00000080000000<0^k^k0?ooo`3oool01P3oool00`3<c<`0000000000006000000050;^k^`3oool0
oooo0?ooo`3MgMd00`0000000`1gMgL0oooo0?ooo`060?ooo`030;^k^`000000000000T00000103o
ool00`3<c<`0000000000009000000050;>c/`00000000000000001NGUh0403oool01014A4@00000
0000000000060?ooo`0304A4A0000000000000L0000000<0<c<c0>k^kP3oool03`3oool01P20P800
0000000000000000VIVI03<c<`X0000000<0TI6A0?ooo`3oool01`3oool00`2IVIT0000000000008
0000000309VIV@3oool0A4A40080000000<0A4A40?ooo`3oool01`3oool00`14A4@0000000000005
000000050::RXP3oool0oooo0?ooo`20P8000`0000000`14A4@0oooo0?ooo`3o0?ooofL0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW9P3oool00`34a<@06QXJ
000000020000000703<c<`1VIVH0R8R80::RXP28R8P0Kfm_03<c<`030000000301XJ6P34a<@0oooo
00T0oooo0`0000000`14A4@0oooo0?ooo`0@0?ooo`0404A4A0092@T0?3`l06m_K`80XZ:R00<0TI6A
04e=C@0000000P0000000`0F5QH0gMgM0?ooo`030?ooo`030?Ogm`2ATI403@d=00<0000000P0@410
0820P02RXZ80XZ:R08f=S@1EEED0:b/[05iNGP@0oooo00D0XZ:R00000000000000000820P0060?oo
o`030=GEe@0W9bL000000080000000X04A4A05iNGP20P800XZ:R09jNWP20P800GUiN03`l?0051@D0
00001`3oool300000003028R8P3oool0oooo00T0oooo0`0000000`14A4@0oooo0?ooo`040?ooo`03
0?Ogm`2ATI403@d=00<0000000P0@4100820P02RXZ80XZ:R08f=S@1EEED0:b/[05iNGP@0oooo00<0
TI6A0000000000000P000000200R8R80GUiN0820P02RXZ80VIVI0820P01NGUh08b<S0P00000A0?oo
o`0>0820P00000000000000000092@T0EEEE08R8R02RXZ80UIFE06IVIP0c<c<0000000D51@0[:b/2
00000003028R8P3oool0oooo00D0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A4
0?ooo`3oool0103oool02`1lO7`000000000000000001@D504e=C@1gMgL0XZ:R09ZJVP1_Kfl0A4A4
0080000000D0<c<c02/[:`000000000004A4A00B0?ooo`04028R8P0000000000000000H0oooo0`00
00000`14A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ801P3oool00`34a<@06QXJ
000000020000000602/[:`1gMgL0XZ:R0::RXP20P800A4A40P0000001@0J6QX0:b/[000000000000
8R8R00L0oooo00<0b<S800T92@0000000P0000002P14A4@0Kfm_096AT@2JVYX0MgMg04A4A0092@T0
000005EEE@0c<c<20000000304A4A03oool0oooo0080oooo00@0A4A400T92@1=CDd0P8200P2RXZ80
0`20P800:b/[000000020000000302/[:`3MgMd0oooo00D0oooo00<0ZZZZ0000000000000P000000
1@14A4@0R8R809jNWP1gMgL0Kfm_00@0oooo0`0000000`14A4@0oooo0?ooo`0<0?ooo`0305EEE@00
0000000000<0000000<06QXJ0?Ogm`3oool05@3oool02@1EEED000000000000000008R8R08R8R02R
XZ80VIVI07=cL`050?ooo`030?Ogm`2ATI403@d=00<0000000H0CDe=08R8R02RXZ80XZ:R07alO00c
<c<30000000301XJ6P2ATI40moOg01@0oooo00<0HV9R0000000000000`0000000`3<c<`0oooo0?oo
o`060?ooo`0307MgM`00000000000080000000<07QhN0?ooo`3oool0203oool30000000304A4A03o
ool0oooo00P0oooo0`0000000`0R8R80oooo0?ooo`040?ooo`0404A4A00000000000000000L0oooo
00<0moOg096AT@0=3@d00`0000002010@400P8200::RXP2RXZ80SHf=05EEE@0[:b/0GUiN103oool0
1@20P8000000000000000000XZ:R00X0oooo0`0000000`14A4@0oooo0?ooo`0?0?ooo`0508B4Q000
000000000000001lO7`01`3oool00`34a<@00000000000030000000304e=C@3gmoL0oooo00H0oooo
00D0?3`l00000000000000000<C4a0040?ooo`030>;RhP092@T000000080000000T06QXJ05iNGP2A
TI40XZ:R0820P01NGUh0<c<c0000000c<c<00`0000000`2IVIT0oooo0?ooo`060?ooo`0:04A4A000
00000000000000092@T0GUiN09jNWP2ATI40Kfm_0::RXP<0oooo00D0R8R800000000000000000<C4
a0090?ooo`0506IVIP00000000000000003Vi^H01P3oool00`3Vi^H0:b/[0000000300000008028R
8P1NGUh0TI6A0::RXP2IVIT0P82004e=C@0A4A42000000030??cl`3oool0oooo00<0oooo00D0MgMg
00000000000000000=GEe@080?ooo`0506m_K`00000000000000003MgMd0203oool01@0c<c<00000
000000000000lo?c00<0oooo00<0h^;R00T92@0000000P0000002@0J6QX0GUiN096AT@2RXZ80P820
05iNGP0c<c<0000003<c<`030000000309VIV@3oool0oooo00H0oooo00X0A4A40000000000000000
00T92@1NGUh0WYjN096AT@1_Kfl0XZ:R103oool0100A4A4000000000000[:b/70?ooo`030=GEe@0J
6QX000000080000000T09bLW06m_K`2ATI40XZ:R09FEU@1_Kfl0A4A4014A4@3gmoL00`3oool03@1W
IfL000000000000000003@d=05iNGP2ATI40XZ:R096AT@1NGUh0<c<c0000000J6QX00`0000000`1=
CDd0oooo0?ooo`0>0?ooo`0404A4A00000000000000000H0oooo00P0A4A402<S8`1NGUh0P8200::R
XP2JVYX0Kfm_02/[:`<0000000<0:b/[0>k^kP3oool03P3oool01@20P80000000000000000008R8R
0080000000H06QXJ06][J`2RXZ80XZ:R08R8R00c<c<30000000300d=3@34a<@0oooo00H0oooo00<0
TI6A00T92@0000000P0000002P14A4@0Kfm_09ZJVP2ATI40MgMg04A4A0051@D0000005EEE@0c<c<2
0000000304A4A03oool0oooo00H0oooo00<0ZZZZ0000000000000P0000001@1VIVH0XZ:R09VIV@1g
MgL0]kNg00<0oooo00D0P820000000000000000004A4A03o0?ooofT0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW9P3oool01@0l?3`00000000000000000IVIV
00L0oooo00D0Kfm_000000000000000003`l?00:0?ooo`<0000000<0A4A40?ooo`3oool0403oool0
0`3<c<`0k^k^0?ooo`050?ooo`0506IVIP00000000000000001VIVH0103oool00`1gMgL000000000
00020000000309VIV@3oool0oooo00D0oooo00<0k^k^0?ooo`3oool00P3oool01@2RXZ8000000000
00000000P82000D0oooo00<0k^k^014A4@0000000P0000000`0A4A40c<c<0?ooo`060?ooo`030<c<
c00A4A40oooo00H0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool0
103oool00`1gMgL00000000000020000000309VIV@3oool0oooo00D0oooo00H0k^k^0?ooo`3oool0
oooo0>k^kP092@T30000000305EEE@3oool0oooo00H0oooo00<0VIVI014A4@3oool0403oool01@0c
<c<00000000000000000R8R800H0oooo00<0c<c<00T92@0000000P0000000`0R8R80oooo0?ooo`05
0?ooo`<0000000<0A4A40?ooo`3oool0203oool30000000304A4A03oool0oooo00<0oooo00<0gMgM
00T92@0000000P0000000`2ATI40oooo0?ooo`040?ooo`030<c<c0092@T0000000<0000000<0A4A4
0?ooo`3oool0403oool0100R8R8000000000000000060?ooo`<0000000<0A4A40?ooo`3oool0203o
ool01@20P8000000000000000000XZ:R00D0oooo00<0gMgM014A4@0000000P0000000`0c<c<0moOg
0?ooo`040?ooo`030<c<c00A4A40000000<0000000<08R8R0?ooo`3oool01@3oool01@1_Kfl00000
000000000000CDe=00H0oooo00<0k^k^01XJ6P0000000`0000000`14A4@0oooo0?ooo`020?ooo`03
0<c<c03^k^h0oooo00D0oooo00D0IVIV000000000000000006IVIP060?ooo`0504A4A00000000000
00000028R8P02@3oool30000000304A4A03oool0oooo00/0oooo00D0i^KV0000000000000000028R
8P03000000030<C4a03oool0oooo01@0oooo00D08R8R00000000000000000<C4a0090?ooo`0607Mg
M`00000000000000000A4A40^k^k1P3oool00`3<c<`04A4A000000020000000307MgM`3oool0oooo
0180oooo00@0:b/[0000000000008R8R0P0000000`1VIVH0oooo0?ooo`050?ooo`050>k^kP000000
00000000000c<c<00P0000000`2ZZZX0oooo0?ooo`070?ooo`<0000000<0A4A40?ooo`3oool0203o
ool300000003028R8P3oool0oooo00@0oooo00@0A4A400000000000000001`3oool00`1gMgL00000
000000020000000309VIV@3oool0oooo00D0oooo00<0k^k^0?ooo`3oool00P3oool01@20P8000000
000000000000XZ:R00X0oooo0`0000000`14A4@0oooo0?ooo`0?0?ooo`050::RXP00000000000000
001NGUh01`3oool00`2RXZ800000000000040000000308R8R03oool0oooo00D0oooo00D0R8R80000
00000000000008R8R0040?ooo`060<C4a00000000000000000092@T0k^k^1P3oool00`1VIVH00000
000000020000000306IVIP3oool0oooo00H0oooo100000000`2IVIT0oooo0?ooo`060?ooo`050;^k
^`000000000000000028R8P02@3oool01@2IVIT00000000000000000ZZZZ00H0oooo00<0TI6A0000
000000000P0000000`2IVIT0oooo0?ooo`060?ooo`030:ZZZP14A4@0eMGE00D0oooo00D0^k^k0000
00000000000008R8R0080?ooo`050;^k^`00000000000000002IVIT0203oool01@1=CDd000000000
00000000eMGE00<0oooo00H0a<C4000000000000000000T92@3^k^h60?ooo`0306IVIP0000000000
0080000000<0IVIV0?ooo`3oool01P3oool40000000309VIV@3oool0oooo00L0oooo00D0<c<c0000
0000000000000?Ogm`060?ooo`06028R8P00000000000000000R8R80i^KV1`3oool01@3gmoL0oooo
0?ooo`3oool0A4A400<0000000<0P8200?ooo`3oool0103oool00`2k^k/02@T90000000200000003
03<c<`3oool0oooo00h0oooo00@0A4A400000000000000001P3oool00`3<c<`0moOg0?ooo`050?oo
o`0503<c<`00000000000000002c/k<03`3oool00`20P8000000000000030000000306IVIP3oool0
oooo00<0oooo00<0moOg03<c<`0000000`0000000`3MgMd0oooo0?ooo`030?ooo`030>k^kP000000
00000080000000<0VIVI0?ooo`3oool0103oool00`2ATI400000000000030000000304A4A03oool0
oooo00H0oooo00D0A4A4000000000000000008R8R0080?ooo`050820P0000000000000000014A4@0
o`3ooomY0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWibD0
oooo00<0^k^k0000000000000P0000000`3MgMd0oooo0?ooo`050?ooo`030=gMg@00000000000080
000000<0^k^k0?ooo`3oool01`3oool30000000304A4A03oool0oooo01P0oooo00D0gMgM00000000
00000000028R8P030?ooo`030;^k^`00000000000080000000<0VIVI0?ooo`3oool02`3oool01@2R
XZ800000000000000000P82000D0oooo00<0R8R80000000000000P0000000`3<c<`0oooo0?ooo`07
0?ooo`80k^k^1P3oool300000003028R8P3oool0oooo00T0oooo0`0000000`14A4@0oooo0?ooo`03
0?ooo`030;^k^`00000000000080000000<0VIVI0?ooo`3oool02P3oool00`28R8P0000000000002
000000030>KViP3oool0oooo00L0oooo0P3^k^h@0?ooo`0501XJ6P00000000000000003EeMD01`3o
ool01@1NGUh000000000000000008R8R00L0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<00000
00<0A4A40?ooo`3oool00`3oool01P28R8P000000000000000004A4A0>KViPL0oooo00<0IVIV0000
000000000P0000000`14A4@0oooo0?ooo`0@0?ooo`04028R8P0000000000000000H0oooo0`000000
0`14A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ801@3oool01P28R8P000000000
000000004A4A0<c<c0L0oooo00<0c<c<0000000000000P0000000`0R8R80oooo0?ooo`050?ooo`05
04A4A000000000000000002RXZ801`3oool00`20P8000000000000020000000304A4A03oool0oooo
00X0oooo00D0gMgM0000000000000000028R8P060?ooo`@0000000<0k^k^0?ooo`3oool01`3oool3
0000000304A4A03oool0oooo00/0oooo00D0^k^k000000000000000006m_K`0300000003096AT@3o
ool0oooo01@0oooo100000000`3gmoL0oooo0?ooo`060?ooo`030;^k^`00000000000080000000<0
^k^k0?ooo`3oool01P3oool00`2k^k/0000000000002000000030=gMg@3oool0oooo0100oooo00P0
k^k^00000000000000000:ZZZP092@T00000014A4@L0oooo00D0ZZZZ000000000000<c<c08R8R002
0000000306IVIP3oool0oooo00L0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<08R8R
0?ooo`3oool0103oool01014A4@000000000000000060?ooo`030;^k^`00000000000080000000<0
VIVI0?ooo`3oool02`3oool01@20P8000000000000000000XZ:R00X0oooo0`0000000`14A4@0oooo
0?ooo`0?0?ooo`050<C4a0000000000000000014A4@01`3oool00`20P80000000000000500000003
0>k^kP3oool0oooo00@0oooo00D0ZZZZ000000000000000005EEE@040?ooo`050<C4a00000000000
0000000l?3`01`3oool00`3Vi^H04A4A000000020000000303<c<`3oool0oooo00H0oooo00@04A4A
00000000000000002P3oool30000000305EEE@3oool0oooo00L0oooo00D0c<c<0000000000000000
08R8R0060?ooo`0505iNGP000000000000000014A4@02`3oool00`3Vi^H0oooo0?ooo`030?ooo`05
0>k^kP00000000000000001VIVH0203oool01@3MgMd00000000000000000MgMg00P0oooo00D0IVIV
00000000000000000<C4a0030?ooo`050<C4a000000000000000000l?3`01`3oool00`3Vi^H04A4A
000000020000000303<c<`3oool0oooo00H0oooo00@04A4A00000000000000002P3oool01@14A4@0
0000000000000000gMgM00D0oooo00<0VIVI0000000000000P0000000`3<c<`0oooo0?ooo`0:0?oo
o`0504A4A000000000000000002k^k/01`3oool01@1_Kfl000000000000000006QXJ0100oooo00@0
A4A400000000000000003P3oool01@1_Kfl00000000000000000TI6A00l0oooo00<0P82000000000
00000P0000000`0c<c<0oooo0?ooo`050?ooo`030>k^kP0A4A4000000080000000<0IVIV0?ooo`3o
ool00`3oool01@34a<@000000000000000008R8R00L0oooo00<0moOg014A4@0000000`0000000`14
A4@0oooo0?ooo`060?ooo`@0000000<0k^k^0?ooo`3oool01P3oool01@34a<@0R8R808R8R028R8P0
XZ:R0?l0ooooJ@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inLU0?ooo`0504A4A000000000000000001gMgL02@3oool01@1gMgL00000000000000000EEEE00T0
oooo0`0000000`14A4@0oooo0?ooo`0I0?ooo`@000000`3oool01@14A4@00000000000000000IVIV
00h0oooo00D0XZ:R00000000000000000820P0050?ooo`05014A4@000000000000000028R8P04P3o
ool300000003028R8P3oool0oooo00T0oooo0`0000000`14A4@0oooo0?ooo`030?ooo`0504A4A000
000000000000001VIVH03@3oool01@0A4A400000000000000000R8R801`0oooo100000080?ooo`05
0;>c/`00000000000000000R8R801`3oool30000000304A4A03oool0oooo00P0oooo0`0000000`14
A4@0oooo0?ooo`030?ooo`05014A4@000000000000000028R8P0203oool00`34a<@0000000000002
0000000304A4A03oool0oooo0100oooo00@08R8R00000000000000001P3oool30000000304A4A03o
ool0oooo00P0oooo00D0P82000000000000000000::RXP050?ooo`05014A4@000000000000000028
R8P02@3oool01@14A4@000000000000000008R8R00L0oooo00D0<c<c00000000000000000<c<c007
0?ooo`030<C4a000000000000080000000<0A4A40?ooo`3oool02`3oool4000000H0oooo0`000000
0`0R8R80oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool02`3oool01P28R8P0000000000000
0000a<C4014A4@80000000<0IVIV0?ooo`3oool0503oool30000000304A4A03oool0oooo00L0oooo
00D0A4A4000000000000000007MgM`0:0?ooo`0503`l?000000000000000002ZZZX04P3oool01P2I
VIT00000000000000000oooo03<c<`80000000<0^k^k0?ooo`3oool0103oool01@1VIVH000000000
0028R8P0gMgM0080000000<04A4A0?ooo`3oool01`3oool30000000304A4A03oool0oooo00P0oooo
0`0000000`0R8R80oooo0?ooo`040?ooo`0404A4A00000000000000000H0oooo00D0A4A400000000
0000000006IVIP0>0?ooo`050820P000000000000000002RXZ802P3oool30000000304A4A03oool0
oooo00l0oooo00D0c<c<000000000000000003<c<`070?ooo`0506IVIP00000000000000000l?3`0
0`0000000`2ZZZX0oooo0?ooo`040?ooo`050<c<c000000000000000000c<c<0103oool01@34a<@0
0000000000000000A4A400P0oooo00<0R8R80000000000000P0000080?ooo`0404A4A00000000000
000000X0oooo00@04A4A000000000000<c<c2P3oool30000000304A4A03oool0oooo00@0oooo00D0
A4A4000000000000000008R8R00B0?ooo`04014A4@000000000004A4A0T0oooo0`0000000`14A4@0
oooo0?ooo`060?ooo`050820P000000000000000002RXZ800`3oool01@34a<@00000000000000000
A4A400P0oooo00<0R8R80000000000000P0000080?ooo`0404A4A00000000000000000X0oooo00D0
GUiN00000000000000000<C4a0050?ooo`0505EEE@00000000000000001VIVH03@3oool01@14A4@0
0000000000000000a<C400L0oooo00<0a<C40000000000000P00000@0?ooo`0404A4A00000000000
000000h0oooo00D0P82000000000000000000820P00?0?ooo`030820P000000000000080000000<0
c<c<0?ooo`3oool01P3oool01@2IVIT000000000000000004A4A00D0oooo00D0/k>c000000000000
000004e=C@080?ooo`0308R8R000000000000080000000<0A4A40?ooo`3oool01P3oool300000003
04A4A03oool0oooo0?l0ooooM@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinLT0?ooo`060;>c/`00000000000000000l?3`0moOg2@3oool00`3gmoL0?3`l0000
0002000000030;>c/`3oool0oooo00H0oooo0`0000000`14A4@0oooo0?ooo`0G0?ooo`030?_kn`1g
MgL000000080000000@06QXJ0?ooo`3oool0fMWI0`0000000`0J6QX0moOg0?ooo`0=0?ooo`050::R
XP000000000000000020P800103oool01@2RXZ800000000000000000EEEE01<0oooo0`0000000`0R
8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool00P3oool01P3IfMT00000000000000000
6QXJ0?Ogm``0oooo00D0XZ:R000000000000000005EEE@0M0?ooo`0500T92@00000000000000003Z
j^X01`3oool01@3Vi^H000000000000000008R8R00L0oooo0`0000000`14A4@0oooo0?ooo`080?oo
o`<0000000<0A4A40?ooo`3oool00P3oool01P2RXZ800000000000000000?3`l0?Ogm`P0oooo00<0
no_k03`l?00000000P0000000`14A4@0oooo0?ooo`0@0?ooo`04028R8P0000000000000000H0oooo
0`0000000`14A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ80103oool01P2RXZ80
0000000000000000?3`l0?Ogm`T0oooo00D0VYZJ0000000000000000028R8P070?ooo`0501HF5P00
000000000000003gmoL0203oool01@0l?3`00000000000000000A4A400/0oooo00<0moOg07MgM`00
00000P0000000`0J6QX0oooo0?ooo`040?ooo`<0000000<08R8R0?ooo`3oool0203oool300000003
04A4A03oool0oooo00/0oooo00H0A4A40000000000006QXJ0?Ogm`28R8P20000000301hN7P3oool0
oooo01@0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`060=WIf@00000000000000000N7Qh0moOg
2P3oool01@2JVYX00000000000000000FUYJ0180oooo00H0?3`l000000000000Kfm_0?ooo`1VIVH2
0000000304e=C@3oool0oooo00<0oooo00L0eMGE00T92@0000002@T90>KViP3oool0EEEE00800000
00<0R8R80?ooo`3oool01P3oool30000000304A4A03oool0oooo00P0oooo0`0000000`0R8R80oooo
0?ooo`040?ooo`0404A4A00000000000000000D0oooo00H0fMWI000000000000000001XJ6P3gmoL>
0?ooo`050820P000000000000000002RXZ802P3oool30000000304A4A03oool0oooo00l0oooo00D0
lo?c000000000000000000d=3@070?ooo`0604A4A000000000000000002g]kL04A4A0P0000000`10
@400oooo0?ooo`050?ooo`05014A4@00000000000000003^k^h00`3oool01P3MgMd0000000000000
00005QHF0>k^kPP0oooo00D0EEEE00000000000000000;^k^`070?ooo`050820P000000000000000
003<c<`02@3oool01@0h>3P00000000000000000k^k^00T0oooo00@0A4A40000000000004A4A1P3o
ool01@0W9bL00000000000000000c<c<0180oooo00D0IVIV00000000000000000>KViP080?ooo`05
02l_;`000000000000T92@3kno/01`3oool01@2RXZ800000000000000000R8R800<0oooo00H0gMgM
000000000000000001HF5P3^k^h80?ooo`0505EEE@00000000000000002k^k/01`3oool01@20P800
0000000000000000c<c<00T0oooo00D0P82000000000000000000:ZZZP050?ooo`0500T92@000000
00000000003<c<`03@3oool01@1NGUh00000000000000000SHf=00P0oooo00D0EEEE000000000000
00000;^k^`0?0?ooo`0404A4A00000000000000000d0oooo00<0moOg03`l?00000000P0000000`2=
SHd0oooo0?ooo`0=0?ooo`050820P000000000000000000l?3`02P3oool01@1=CDd0000000000000
0000VIVI00@0oooo00D0UIFE000000000000000007MgM`090?ooo`0503`l?0000000000000000014
A4@0203oool30000000304A4A03oool0oooo0?l0ooooM@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinLT0?ooo`0505EEE@00000000000000002IVIT02`3oool0
1@2IVIT00000000000000000EEEE00P0oooo0`0000000`14A4@0oooo0?ooo`0G0?ooo`0307MgM`00
000000000080000000@0MgMg0?ooo`3oool0ZZZZ0`0000000`1=CDd0oooo0?ooo`0=0?ooo`050::R
XP000000000000000020P800103oool01@14A4@00000000000000000^k^k01<0oooo0`0000000`0R
8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool00P3oool01@2ZZZX00000000000000000
CDe=00d0oooo00D0A4A400000000000000000;^k^`0M0?ooo`0503<c<`00000000000000002ATI40
203oool300000003028R8P3oool0oooo00D0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<00000
00<0A4A40?ooo`3oool00P3oool01@14A4@00000000000000000ZZZZ00X0oooo00D0ZZZZ00000000
0000000004A4A00B0?ooo`04028R8P0000000000000000H0oooo0`0000000`14A4@0oooo0?ooo`08
0?ooo`050820P000000000000000002RXZ80103oool01@14A4@00000000000000000ZZZZ00X0oooo
00D0eMGE0000000000000000028R8P070?ooo`<0000000<0A4A40?ooo`3oool01`3oool01@2IVIT0
0000000000000000A4A400X0oooo00<0gMgM03<c<`0000000`0000000`1gMgL0oooo0?ooo`040?oo
o`<0000000<08R8R0?ooo`3oool0203oool30000000304A4A03oool0oooo00X0oooo00D0k^k^0000
00000000000008R8R0020?ooo`04014A4@00000000000:ZZZQD0oooo0`0000000`14A4@0oooo0?oo
o`060?ooo`050:ZZZP00000000000000001=CDd02`3oool01@3<c<`00000000000000000:b/[0140
oooo00L0ZZZZ00000000000000000=gMg@3oool0ZZZZ00<0000000<0i^KV0?ooo`3oool00P3oool0
101VIVH000000000000l?3`20?ooo`040<c<c00000000000014A4@P0oooo0`0000000`14A4@0oooo
0?ooo`080?ooo`<0000000<08R8R0?ooo`3oool0103oool01014A4@000000000000000050?ooo`05
0:ZZZP00000000000000001=CDd03`3oool01@20P8000000000000000000XZ:R00X0oooo0`000000
0`14A4@0oooo0?ooo`0@0?ooo`0503<c<`00000000000000003<c<`01P3oool01P0R8R8000000000
00000000oooo0;^k^`<0000000<0VIVI0?ooo`3oool0103oool01@0c<c<00000000000000000c<c<
00@0oooo00H0IVIV000000000000000003<c<`3^k^h70?ooo`050<c<c0000000000000000028R8P0
1`3oool01@2k^k/00000000000000000R8R800T0oooo00D0EEEE00000000000000000<c<c0090?oo
o`0508R8R000000000000000002k^k/01@3oool01@0R8R800000000000000000gMgM0180oooo00D0
VIVI00000000000000000:ZZZP080?ooo`0504A4A000000000000000003MgMd01`3oool01@34a<@0
0000000000000000GUiN00@0oooo00H0IVIV000000000000000003<c<`3^k^h70?ooo`050<c<c000
0000000000000028R8P01`3oool01@2k^k/00000000000000000R8R800T0oooo00D0XZ:R00000000
000000000820P0040?ooo`030=gMg@0000000000008000003P3oool01P2c/k<00000000000000000
6QXJ0>k^kPL0oooo00D0c<c<000000000000000008R8R00?0?ooo`0404A4A00000000000000000`0
oooo00<0^k^k03<c<`0000000`0000000`2k^k/0oooo0?ooo`0=0?ooo`050820P000000000000000
001gMgL02P3oool01@2ZZZX00000000000000000A4A400@0oooo00D0P82000000000000000000::R
XP090?ooo`0509VIV@000000000000000014A4@0203oool30000000304A4A03oool0oooo0?l0oooo
M@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinLT0?ooo`05
03<c<`00000000000000003MgMd02`3oool01@3<c<`00000000000000000<c<c00P0oooo0`000000
0`14A4@0oooo0?ooo`0E0?ooo`030=gMg@1VIVH0000000<0000000D02@T90=gMg@3oool0oooo09VI
V@030000000306IVIP3oool0oooo00d0oooo00D0XZ:R00000000000000000820P0040?ooo`0403<c
<`0000000000000001@0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3o
ool00P3oool01@2IVIT00000000000000000IVIV00d0oooo00@0<c<c00000000000000007P3oool0
1P1NGUh000000000000000006QXJ0;^k^`L0oooo0`0000000`0R8R80oooo0?ooo`050?ooo`<00000
00<0A4A40?ooo`3oool0203oool30000000304A4A03oool0oooo0080oooo00D0A4A4000000000000
00000=gMg@0:0?ooo`050=gMg@000000000000000014A4@04P3oool0100R8R800000000000000006
0?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000000000000000XZ:R00@0oooo00D0
A4A400000000000000000=gMg@0:0?ooo`050>k^kP00000000000000000R8R801`3oool300000003
04A4A03oool0oooo00L0oooo00D0^k^k000000000000000004A4A0090?ooo`030=gMg@0c<c<00000
00<0000000<04A4A0=gMg@3oool01@3oool300000003028R8P3oool0oooo00P0oooo0`0000000`14
A4@0oooo0?ooo`0:0?ooo`0509VIV@00000000000000003MgMd00P3oool0101VIVH000000000001E
EEDE0?ooo`<0000000<0A4A40?ooo`3oool01P3oool01@2IVIT00000000000000000Kfm_00/0oooo
00D0i^KV000000000000000001XJ6P0A0?ooo`0406IVIP0000000000028R8P80oooo00D0c<c<0000
0000000000000<C4a0040?ooo`04028R8P000000000005iNGP<0oooo00@02@T9000000000000ZZZZ
1`3oool30000000304A4A03oool0oooo00P0oooo0`0000000`0R8R80oooo0?ooo`040?ooo`0404A4
A00000000000000000D0oooo00D0VIVI000000000000000006IVIP0?0?ooo`050820P00000000000
0000002RXZ802P3oool30000000304A4A03oool0oooo0100oooo00D0EEEE00000000000000000:ZZ
ZP060?ooo`<0000000@0<c<c0?ooo`3oool0A4A40P0000000`0R8R80oooo0?ooo`040?ooo`0504A4
A0000000000000000034a<@0103oool00`3MgMd04A4A0000000200000003028R8P2ZZZX0oooo00H0
oooo0`0000000`14A4@0oooo0?ooo`060?ooo`<0000000<0EEEE0?ooo`3oool01`3oool01@1VIVH0
0000000000000000a<C400T0oooo00D0^k^k000000000000000008R8R0050?ooo`05028R8P000000
00000000003MgMd04P3oool01@2k^k/00000000000000000R8R800P0oooo00D0GUiN000000000000
00000<C4a0070?ooo`050=gMg@000000000000000014A4@0103oool00`3MgMd04A4A000000020000
0003028R8P2ZZZX0oooo00H0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`<0000000<0EEEE0?oo
o`3oool01`3oool01@34a<@00000000000000000IVIV00@0oooo00<0k^k^0000000000000P00000>
0?ooo`030>k^kP0A4A4000000080000000<08R8R0:ZZZP3oool01P3oool30000000304A4A03oool0
oooo00d0oooo00@0A4A400000000000000002`3oool00`2RXZ8000000000000300000003014A4@3^
k^h0oooo00h0oooo00D0P8200000000000000000096AT@0:0?ooo`050=gMg@00000000000000000c
<c<0103oool01@20P8000000000000000000XZ:R00T0oooo00D0^k^k000000000000000004A4A008
0?ooo`<0000000<0A4A40?ooo`3oool0o`3ooome0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWib@0oooo1000000=0?ooo`@00000203oool30000000304A4A03o
ool0oooo01<0oooo00<0k^k^06IVIP0000001@0000001@1=CDd0oooo0?ooo`3oool0P82000<00000
00<0P8200?ooo`3oool03@3oool01@2RXZ800000000000000000P82000@0oooo1000000?08R8R0D0
oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool00P3oool01@20P800
0000000000000000P82000d0oooo1000000>08R8R0030<C4a03oool0oooo00d0oooo00<0^k^k0000
000000000`0000000`0c<c<0R8R80<c<c0040?ooo`<0000000<08R8R0?ooo`3oool01@3oool30000
000304A4A03oool0oooo00P0oooo0`0000000`14A4@0oooo0?ooo`020?ooo`@00000303oool30000
000304A4A03oool0oooo0100oooo00@08R8R00000000000000001P3oool30000000304A4A03oool0
oooo00P0oooo00D0P82000000000000000000::RXP040?ooo`@00000303oool300000003028R8P3o
ool0oooo00D0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool01@3o
ool00`3MgMd0IVIV000000050000000309VIV@3oool0oooo00D0oooo0`0000000`0R8R80oooo0?oo
o`080?ooo`<0000000<0A4A40?ooo`3oool02P3oool0100c<c<000000000000c<c<30?ooo`050:ZZ
ZP00000000000000003^k^h0503oool30000000304A4A03oool0oooo00H0oooo00D0P82000000000
000000000820P00<0?ooo`@000004@3oool0100A4A4000000000001gMgL20?ooo`050?Ogm`000000
00000000002IVIT00`3oool01@3Vi^H00000000000000000R8R800<0oooo00@0<c<c000000000000
IVIV1`3oool30000000304A4A03oool0oooo00P0oooo0`0000000`0R8R80oooo0?ooo`040?ooo`04
04A4A00000000000000000D0oooo00D0P82000000000000000000820P00?0?ooo`050820P0000000
00000000002RXZ802P3oool30000000304A4A03oool0oooo0100oooo00D0R8R80000000000000000
08R8R0050?ooo`050;^k^`00000000000000001VIVH00P3oool01@2k^k/00000000000000000R8R8
00D0oooo00D0GUiN00000000000000000::RXP050?ooo`030<c<c0000000000000<0000000<0CDe=
0:ZZZP3<c<`0103oool0100c<c<000000000000R8R880?ooo`04028R8P000000000003<c<`T0oooo
00D0P82000000000000000000::RXP090?ooo`050=gMg@00000000000000001gMgL01@3oool01@0c
<c<00000000000000000MgMg00d0R8R800<0^k^k0?ooo`3oool00`3oool30000000305EEE@3oool0
oooo00H0oooo00D0MgMg00000000000000000;>c/`070?ooo`050>k^kP00000000000000000l?3`0
1@3oool00`3<c<`00000000000030000000304e=C@2ZZZX0c<c<00@0oooo00@0<c<c000000000000
8R8R203oool0100R8R8000000000000c<c<90?ooo`050<c<c000000000000000001EEED01@3oool4
000000l0oooo00<0c<c<0000000000000`0000000`0R8R80TI6A0<c<c0040?ooo`0403<c<`000000
0000028R8Pl0oooo00@0A4A400000000000000002@3oool00`3MgMd0IVIV000000050000000309VI
V@3oool0oooo00h0oooo00D0P82000000000000000000::RXP0;0?ooo`@00000103oool01@20P800
0000000000000000XZ:R00X0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`<0000000<0A4A40?oo
o`3oool0o`3ooome0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A
0>OWib@0oooo1000000=0?ooo`@00000203oool30000000304A4A03oool0oooo0140oooo00<0moOg
09VIV@0R8R801@0000000`0c<c<0MgMg0>KViP030?ooo`050820P0000000000000000020P8003`3o
ool01@2RXZ800000000000000000P82000@0oooo4`0000050?ooo`<0000000<08R8R0?ooo`3oool0
2@3oool30000000304A4A03oool0oooo0080oooo00D0P82000000000000000000820P00=0?oooa80
000000<0P8200?ooo`3oool03P3oool00`2c/k<0EEEE014A4@0<00000003028R8P3oool0oooo00D0
oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool00P3oool4000000`0
oooo0`0000000`14A4@0oooo0?ooo`0@0?ooo`04028R8P0000000000000000H0oooo0`0000000`14
A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ80103oool4000000`0oooo0`000000
0`0R8R80oooo0?ooo`050?ooo`<0000000<0A4A40?ooo`3oool0203oool30000000304A4A03oool0
oooo00<0oooo00<0moOg06m_K`0000001@0000000`0c<c<0XZ:R0?ooo`070?ooo`<0000000<08R8R
0?ooo`3oool0203oool30000000303`l?03oool0oooo00T0oooo00D0/k>c00000000000000000;>c
/`040?ooo`0403`l?0000000000005iNGQ@0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`050820
P0000000000000000020P800303oool400000100oooo00D0R8R800000000000000000=GEe@030?oo
o`0406IVIP000000000005iNGP<0oooo00D0YZJV00000000000000000<C4a0030?ooo`05069RHP00
00000000014A4@3clo<01P3oool30000000304A4A03oool0oooo00P0oooo0`0000000`0R8R80oooo
0?ooo`040?ooo`0404A4A00000000000000000D0oooo00D0P82000000000000000000820P00?0?oo
o`050820P000000000000000002RXZ802P3oool30000000304A4A03oool0oooo0100oooo00D0c<c<
000000000000000003<c<`050?ooo`0507MgM`00000000000000002RXZ800`3oool01@2RXZ800000
000000092@T0/k>c00@0oooo00D0P82000000000000000000820P0060?ooo`030>KViP1VIVH02@T9
00d0000000<0gMgM0?ooo`3oool01@3oool01@1VIVH00000000000000000i^KV00P0oooo00D0ZZZZ
000000000000000007QhN00:0?ooo`04028R8P000000000002/[:`D0oooo00<0CDe=000000000000
3`0000000`1=CDd0oooo0?ooo`030?ooo`05028R8P0000000000014A4@3kno/01`3oool01@2IVIT0
0000000000000000TI6A00P0oooo00@08R8R0000000000005QHF1P3oool00`3Vi^H0IVIV00T92@0=
000000030=gMg@3oool0oooo00D0oooo00D0IVIV00000000000000000>KViP080?ooo`050>k^kP00
000000000000000h>3P01@3oool01@0l?3`00000000000000000^k^k00l0oooo00<0i^KV08R8R00W
9bL03@0000000`3MgMd0oooo0?ooo`0<0?ooo`0404A4A00000000000000000L0oooo00<0b<S804A4
A0000000100000000`0J6QX0MgMg0<c<c00A0?ooo`050820P000000000000000002RXZ802`3oool4
000000@0oooo00D0P82000000000000000000::RXP0:0?ooo`<0000000<0A4A40?ooo`3oool01P3o
ool30000000304A4A03oool0oooo0?l0ooooM@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinLT0?ooo`0503<c<`00000000000000003<c<`02`3oool01@3<c<`0
0000000000000000<c<c00P0oooo0`0000000`14A4@0oooo0?ooo`0A0?ooo`0303<c<`0000000000
00<0000000<0<c<c0=gMg@3oool01@3oool01@2IVIT00000000000000000IVIV00l0oooo00D0XZ:R
00000000000000000820P0040?ooo`03014A4@000000000000l0000000<0A4A40?ooo`3oool00`3o
ool4000000/0oooo0`0000000`14A4@0oooo0?ooo`020?ooo`0509VIV@00000000000000001VIVH0
3@3oool00`0A4A4000000000000?000000030::RXP3oool0oooo0140oooo00<0P820014A4@000000
2@0000000`0R8R80oooo0?ooo`050?ooo`@000002P3oool30000000304A4A03oool0oooo0080oooo
100000000`3^k^h0oooo0?ooo`080?ooo`050=gMg@000000000000000014A4@04P3oool0100R8R80
00000000000000060?ooo`@000002P3oool01@20P8000000000000000000XZ:R00@0oooo10000000
0`3^k^h0oooo0?ooo`080?ooo`050>k^kP00000000000000000R8R801`3oool30000000304A4A03o
ool0oooo00P0oooo0`0000000`14A4@0oooo0?ooo`030?ooo`0303<c<`000000000000<0000000<0
IVIV0=gMg@3oool02@3oool300000003028R8P3oool0oooo00P0oooo1000000;0?ooo`04028R8P00
0000000003<c<`D0oooo00D0ZZZZ00000000000000000>k^kP0C0?ooo`<0000000<0A4A40?ooo`3o
ool01P3oool01@2IVIT00000000000000000IVIV00/0oooo00D0i^KV000000000000000001XJ6P0@
0?ooo`04014A4@000000000002/[:`@0oooo00@0gMgM000000000000:b/[0`3oool01@1_Kfl00000
000000000000moOg00<0oooo00D0XZ:R00000000000000000;^k^`060?ooo`<0000000<04A4A0?oo
o`3oool0203oool300000003028R8P3oool0oooo00@0oooo00@0A4A400000000000000001@3oool0
1@2IVIT00000000000000000IVIV00l0oooo00D0P820000000000000000008R8R00:0?ooo`<00000
00<0A4A40?ooo`3oool04@3oool4000000D0oooo00@0<c<c00000000000000001@3oool01@0l?3`0
0000000000000000k^k^00<0oooo00D0XZ:R000000000000000005iNGP080?ooo`040>k^kP2IVIT0
EEEE00T92@X0000000<0R8R80?ooo`3oool01@3oool01@2ZZZX00000000000000000VIVI00P0oooo
00D0a<C4000000000000000004A4A00:0?ooo`0506IVIP00000000000000003MgMd0103oool00`1g
MgL000000000000@000000D0oooo00D0A4A400000000000000000=GEe@070?ooo`050<C4a0000000
00000000001NGUh0203oool01@1gMgL00000000000000000gMgM00L0oooo00@0k^k^09VIV@1EEED0
2@T92P0000000`28R8P0oooo0?ooo`050?ooo`050:ZZZP00000000000000002IVIT02@3oool0100c
<c<000000000000A4A450?ooo`0508R8R000000000000000001VIVH04@3oool0103gmoL0VIVI05EE
E@0A4A4:0000000308R8R03oool0oooo00`0oooo00@0A4A400000000000000001`3oool00`0J6QX0
0000000000030000000306IVIP3^k^h0oooo0180oooo00D0P8200000000000000000096AT@0:0?oo
o`030>k^kP000000000000800000103oool01@20P8000000000000000000XZ:R00X0oooo0`000000
0`14A4@0oooo0?ooo`060?ooo`<0000000<0A4A40?ooo`3oool0o`3ooome0?ooo`040>WYj@3AdM40
dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib@0oooo00D0A4A40000000000000000
09VIV@0;0?ooo`0509VIV@000000000000000014A4@0203oool30000000304A4A03oool0oooo0100
oooo00<0VIVI0000000000000`0000000`1VIVH0k^k^0?ooo`060?ooo`050::RXP00000000000000
001=CDd03`3oool01@2RXZ800000000000000000P82000@0oooo00D0A4A400000000000000000>k^
kP0:0?ooo`<0000000<0A4A40?ooo`3oool00`3oool4000000030=gMg@3oool0oooo00P0oooo0`00
00000`14A4@0oooo0?ooo`020?ooo`050::RXP00000000000000001=CDd03@3oool01@14A4@00000
000000000000k^k^00T0oooo00D0P82000000000000000000::RXP0E0?ooo`030<c<c02k^k/0R8R8
00@0R8R80`0000000`0R8R80oooo0?ooo`050?ooo`@0000000<0k^k^0?ooo`3oool01`3oool30000
000304A4A03oool0oooo0080oooo00D0A4A400000000000000000;^k^`0:0?ooo`050:ZZZP000000
000000000014A4@04P3oool0100R8R8000000000000000060?ooo`@0000000<0gMgM0?ooo`3oool0
1`3oool01@20P8000000000000000000XZ:R00@0oooo00D0A4A400000000000000000;^k^`0:0?oo
o`050=GEe@00000000000000000R8R801`3oool30000000304A4A03oool0oooo00P0oooo0`000000
0`14A4@0oooo0?ooo`020?ooo`0309VIV@000000000000<0000000<0XZ:R0?ooo`3oool02P3oool3
00000003028R8P3oool0oooo00P0oooo100000000`3<c<`0oooo0?ooo`070?ooo`050;^k^`000000
00000000001gMgL01P3oool010092@T000000000002k^k/C0?ooo`<0000000<0A4A40?ooo`3oool0
1P3oool01@2RXZ800000000000000000CDe=00/0oooo00D0c<c<0000000000000000028R8P0?0?oo
o`050=GEe@000000000000000014A4@01@3oool0100c<c<000000000003^k^h20?ooo`0404A4A000
0000000005EEE@@0oooo00D0a<C40000000000000000096AT@060?ooo`@0000000<0k^k^0?ooo`3o
ool01`3oool300000003028R8P3oool0oooo00@0oooo00@0A4A400000000000000001@3oool01@2R
XZ800000000000000000CDe=00l0oooo00D0P820000000000000000007MgM`0:0?ooo`<0000000<0
A4A40?ooo`3oool04@3oool01@14A4@00000000000000000^k^k00@0oooo0`0000000`0c<c<0oooo
0?ooo`030?ooo`050820P000000000000000002ZZZX00`3oool01@2k^k/00000000000000000A4A4
00/0oooo00<0i^KV0;^k^`28R8P01@28R8P30000000307MgM`3oool0oooo00D0oooo00D0c<c<0000
00000000000008R8R0080?ooo`050=gMg@00000000000000000J6QX02P3oool01@28R8P000000000
00000000^k^k00@0oooo00D0VIVI000000000000000006m_K`0:0?ooo`0404A4A000000000000000
00D0oooo00D0EEEE00000000000000000;>c/`070?ooo`050<c<c000000000000000000l?3`0203o
ool01@28R8P00000000000000000^k^k00X0oooo00<0i^KV0;^k^`28R8P01@28R8P30000000307Mg
M`3oool0oooo00D0oooo00D0c<c<000000000000000008R8R0090?ooo`0405EEE@00000000000000
00D0oooo00<0gMgM0000000000000P0000000`3^k^h0oooo0?ooo`0B0?ooo`030<C4a028R8P0R8R8
00@0R8R80`0000000`1gMgL0oooo0?ooo`0<0?ooo`0404A4A00000000000000000H0oooo00<0VIVI
0000000000000P0000000`0c<c<0gMgM0?ooo`0D0?ooo`050820P000000000000000001gMgL02P3o
ool01@2k^k/00000000000000000A4A400@0oooo00D0P82000000000000000000::RXP0:0?ooo`<0
000000<0A4A40?ooo`3oool01P3oool30000000304A4A03oool0oooo0?l0ooooM@3oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinLT0?ooo`0508R8R00000000000
0000001EEED02`3oool01@1EEED00000000000000000R8R800P0oooo0`0000000`14A4@0oooo0?oo
o`0@0?ooo`0604A4A000000000000000000A4A40ZZZZ2@3oool01@34a<@00000000000000000:b/[
00l0oooo00D0XZ:R00000000000000000820P0040?ooo`0506IVIP00000000000000002k^k/02@3o
ool01@3MgMd00000000000000000MgMg00D0oooo100000000`2IVIT0oooo0?ooo`070?ooo`050;^k
^`00000000000000001EEED0103oool01@34a<@00000000000000000:b/[00d0oooo00D0IVIV0000
0000000000000;^k^`090?ooo`0506m_K`00000000000000002k^k/0703oool300000003028R8P3o
ool0oooo00D0oooo100000000`3<c<`0oooo0?ooo`060?ooo`050;^k^`00000000000000001EEED0
103oool01@1EEED00000000000000000R8R800X0oooo00D0IVIV000000000000000004A4A00B0?oo
o`04028R8P0000000000000000H0oooo100000000`2IVIT0oooo0?ooo`070?ooo`0505iNGP000000
00000000002ZZZX0103oool01@1EEED00000000000000000R8R800X0oooo00D0/k>c000000000000
0000028R8P070?ooo`<0000000<0A4A40?ooo`3oool0203oool30000000304A4A03oool0oooo0080
oooo00H0A4A40000000000000000014A4@2ZZZX=0?ooo`<0000000<08R8R0?ooo`3oool0203oool4
0000000308R8R03oool0oooo00L0oooo00D0IVIV00000000000000000<c<c0060?ooo`0403<c<`00
00000000096ATA<0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`050<C4a000000000000000000[
:b/02`3oool01@2ZZZX00000000000000000A4A400l0oooo00D0/k>c000000000000000006IVIP05
0?ooo`0408R8R000000000000:ZZZP80oooo00@06QXJ000000000000VIVI103oool01@3^k^h00000
000000000000IVIV00H0oooo100000000`2IVIT0oooo0?ooo`060?ooo`050=gMg@00000000000000
000[:b/01P3oool01014A4@000000000000000050?ooo`050<C4a000000000000000000[:b/03`3o
ool01@20P8000000000000000000CDe=00T0oooo00D0^k^k000000000000000005EEE@0C0?ooo`05
07MgM`000000000000000028R8P00`3oool01@2k^k/00000000000000000IVIV00D0oooo00D0a<C4
000000000000000005iNGP030?ooo`050<c<c000000000000000000c<c<04`3oool30000000304A4
A03oool0oooo00H0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`030?Ogm`000000000000800000
00<0^k^k0?ooo`3oool01`3oool01@28R8P00000000000000000R8R800@0oooo00D0c<c<00000000
0000000004A4A00:0?ooo`0404A4A00000000000000000D0oooo00D0Kfm_00000000000000000820
P0070?ooo`050=gMg@0000000000000000092@T0203oool01@2k^k/00000000000000000R8R80180
oooo0`0000000`14A4@0oooo0?ooo`060?ooo`<0000000<0A4A40?ooo`3oool01`3oool01@28R8P0
0000000000000000^k^k00D0oooo00D0EEEE000000000000000008R8R00K0?ooo`<0000000<0A4A4
0?ooo`3oool0303oool01014A4@000000000000000060?ooo`0604A4A000000000000000000A4A40
eMGE5P3oool01@20P8000000000000000000CDe=00X0oooo00D0R8R8000000000000000005EEE@04
0?ooo`050820P000000000000000002RXZ802P3oool30000000304A4A03oool0oooo00H0oooo0`00
00000`14A4@0oooo0?ooo`3o0?ooogD0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOW903oool00`3Vi^H06QXJ000000020000000309VIV@3oool0oooo00L0oooo
00H0VIVI000000000000000001XJ6P3Vi^H80?ooo`<0000000<0A4A40?ooo`3oool0403oool40000
00030<C4a03oool0oooo00P0oooo00<0lo?c01XJ6P0000000P0000000`2IVIT0oooo0?ooo`0<0?oo
o`050::RXP000000000000000020P800103oool01P34a<@00000000000000000A4A40?Ogm`P0oooo
00D0P82000000000000000000;^k^`050?ooo`@0000000<0:b/[0>KViP3oool01`3oool01@20P800
0000000000000000TI6A00@0oooo00<0lo?c01XJ6P0000000P0000000`2IVIT0oooo0?ooo`0:0?oo
o`060<C4a0000000000000000014A4@0moOg203oool01@10@4000000000000000000gMgM01/0oooo
00D0h^;R000000000000000003`l?0070?ooo`@0000000<0RHV90?ooo`3oool01P3oool01@20P800
0000000000000000TI6A00@0oooo00H0/k>c000000000000000001XJ6P3MgMd80?ooo`030=gMg@09
2@T000000080000000<0A4A40?ooo`3oool0403oool0100R8R8000000000000000060?ooo`@00000
00<0:b/[0>KViP3oool01`3oool01@10@4000000000000000000b<S800@0oooo00H0/k>c00000000
0000000001XJ6P3MgMd90?ooo`05069RHP00000000000000000R8R801`3oool30000000304A4A03o
ool0oooo00P0oooo0`0000000`14A4@0oooo0?ooo`020?ooo`@0000000<0a<C40?ooo`3oool0303o
ool300000003028R8P3oool0oooo00P0oooo100000000`0J6QX0k^k^0?ooo`060?ooo`050>KViP09
2@T000000000000W9bL01`3oool0101_Kfl0000000000019BDTC0?ooo`<0000000<0A4A40?ooo`3o
ool01P3oool00`3clo<06QXJ000000020000000309VIV@3oool0oooo00P0oooo00D0CDe=00000000
000000000820P00?0?ooo`0506m_K`00000000000000002RXZ801@3oool01P3Vi^H04A4A0000000l
?3`0oooo0;>c/`80000000<06QXJ0?Ogm`3oool0103oool0101=CDd000000000000W9bL60?ooo`@0
000000<0:b/[0?Ogm`3oool01P3oool01@30`<000000000000000000BDU900H0oooo00@0A4A40000
0000000000001@3oool00`3clo<06QXJ000000020000000309VIV@3oool0oooo00`0oooo00H0P820
000000000000000001HF5P3^k^h80?ooo`050820P000000000000000002ATI404`3oool01@2RXZ80
0000000000000000GUiN00<0oooo00D0MgMg00000000000000000::RXP050?ooo`060?_kn`1NGUh0
00000000000A4A40c<c<0P3oool01@3^k^h000000000000000004A4A01<0oooo0`0000000`0R8R80
oooo0?ooo`060?ooo`0502LW9`0000000000014A4@3kno/0203oool01P0[:b/00000000000000000
8R8R0<c<c0P0oooo00D0R8R8000000000000000008R8R0040?ooo`060?_kn`1=CDd0000000000005
1@D0/k>c2@3oool0100[:b/000000000000A4A450?ooo`06096AT@00000000000000000W9bL0k^k^
1P3oool00`3MgMd00000000000020000000305EEE@3gmoL0oooo00D0oooo00D0^k^k000000000000
000006IVIP0B0?ooo`<0000000<08R8R0?ooo`3oool01P3oool01@0W9bL000000000000A4A40no_k
00P0oooo00D0a<C4000000000000000008R8R0050?ooo`060=gMg@0F5QH00000000000092@T0`<30
6P3oool300000003028R8P3oool0oooo00`0oooo00@0A4A400000000000000001P3oool400000003
0<C4a03oool0oooo01D0oooo00H0P820000000000000000001HF5P3MgMd80?ooo`030>k^kP0R8R80
00000080000000<0/k>c0?ooo`3oool00P3oool01@20P8000000000000000000XZ:R00X0oooo0`00
00000`14A4@0oooo0?ooo`060?ooo`<0000000<0A4A40?ooo`3oool0o`3ooome0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWibD0oooo00<0VIVI000000000000
0P0000000`3<c<`0oooo0?ooo`050?ooo`030<c<c000000000000080000000<0VIVI0?ooo`3oool0
1`3oool30000000304A4A03oool0oooo0100oooo00@08R8R0000000000000000303oool00`2IVIT0
0000000000020000000309VIV@3oool0oooo00/0oooo00D0XZ:R00000000000000000820P0050?oo
o`0506IVIP00000000000000001gMgL01`3oool01@2k^k/00000000000000000A4A400H0oooo1@00
00000`14A4@0oooo0?ooo`050?ooo`030>k^kP0A4A4000000080000000<0c<c<0?ooo`3oool00`3o
ool00`2IVIT00000000000020000000309VIV@3oool0oooo00X0oooo00D0IVIV0000000000000000
07MgM`070?ooo`050;^k^`000000000000000014A4@0703oool01@2c/k<00000000000000000EEEE
00L0oooo100000000`0R8R80oooo0?ooo`050?ooo`030?Ogm`0A4A4000000080000000<0c<c<0?oo
o`3oool00`3oool01P14A4@00000000000000000<c<c0?Ogm`L0oooo00<0IVIV0000000000000P00
00000`14A4@0oooo0?ooo`0@0?ooo`04028R8P0000000000000000H0oooo1@0000000`14A4@0oooo
0?ooo`050?ooo`030>k^kP092@T000000080000000<0i^KV0?ooo`3oool00`3oool01P14A4@00000
000000000000<c<c0>k^kPL0oooo00<0c<c<0000000000000P0000000`0R8R80oooo0?ooo`050?oo
o`<0000000<0A4A40?ooo`3oool0203oool30000000304A4A03oool0oooo0080oooo00@08R8R0000
0000000000003`3oool300000003028R8P3oool0oooo00P0oooo1@0000000`2ATI40oooo0?ooo`05
0?ooo`050:ZZZP00000000000000001VIVH01`3oool0102k^k/00000000000092@TC0?ooo`<00000
00<0A4A40?ooo`3oool01`3oool00`2IVIT00000000000020000000309VIV@3oool0oooo00H0oooo
00<0VIVI0000000000000P0000000`3<c<`0oooo0?ooo`0=0?ooo`0503<c<`00000000000000003E
eMD01P3oool01@1gMgL000000000002k^k/0EEEE0080000000<0R8R80?ooo`3oool0103oool01@2k
^k/00000000000000000c<c<00D0oooo1@0000000`2RXZ80oooo0?ooo`050?ooo`050820P0000000
00000000001VIVH01P3oool01014A4@000000000000000060?ooo`0309VIV@000000000000800000
00<0VIVI0?ooo`3oool02`3oool00`20P8000000000000020000000304A4A03oool0oooo00D0oooo
00<0k^k^014A4@0000000P0000000`3<c<`0oooo0?ooo`0A0?ooo`050>k^kP00000000000000000A
4A400`3oool0100c<c<000000000000000080?ooo`05028R8P0000000000028R8P3^k^h00P3oool0
1@0R8R800000000000000000gMgM0140oooo00D0k^k^000000000000000003<c<`080?ooo`0504A4
A000000000000000003MgMd0203oool00`1gMgL000000000000200000003014A4@3<c<`0oooo00H0
oooo00D0A4A4000000000000000008R8R0060?ooo`05028R8P00000000000000002IVIT01`3oool0
1@2IVIT00000000000000000EEEE00D0oooo00<0/k>c0000000000000P0000000`0c<c<0k^k^0?oo
o`040?ooo`030<c<c0000000000000<0000000<0EEEE0?ooo`3oool0103oool01@28R8P000000000
00000000A4A40140oooo00D0k^k^000000000000000003<c<`080?ooo`0504A4A000000000000000
003MgMd02@3oool30000000304A4A03oool0oooo00@0oooo00H0P820000000000000000003<c<`3^
k^hH0?ooo`050>k^kP00000000000000000c<c<03P3oool01014A4@000000000000000060?ooo`04
028R8P0000000000000001P0oooo00<0P8200000000000000P0000000`0c<c<0k^k^0?ooo`060?oo
o`0504A4A0000000000000000014A4@01@3oool01@20P8000000000000000000XZ:R00X0oooo0`00
00000`14A4@0oooo0?ooo`060?ooo`<0000000<0A4A40?ooo`3oool01`3oool01@34a<@0R8R808R8
R028R8P0XZ:R0?l0ooooJ@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinLV0?ooo`05028R8P00000000000000001=CDd01`3oool01@1=CDd00000000000000000
8R8R00X0oooo0`0000000`14A4@0oooo0?ooo`0@0?ooo`0505EEE@000000000000000028R8P0303o
ool00`14A4@00000000000020000000309VIV@3oool0oooo00X0oooo00D0XZ:R0000000000000000
0820P0050?ooo`030=gMg@0A4A4000000080000000<0VIVI0?ooo`3oool00`3oool00`3<c<`04A4A
00000002000000030:ZZZP3oool0oooo00@0oooo1P0000000`1VIVH0oooo0?ooo`040?ooo`0506IV
IP00000000000000000R8R801`3oool00`14A4@00000000000020000000309VIV@3oool0oooo00T0
oooo00<0gMgM00T92@0000000P0000000`3<c<`0oooo0?ooo`030?ooo`030<c<c00A4A4000000080
000000<0ZZZZ0?ooo`3oool0403oool00`14A4@0c<c<0?ooo`070?ooo`0505EEE@00000000000000
0020P8001`3oool50000000306IVIP3oool0oooo00@0oooo00D0/k>c0000000000000000014A4@06
0?ooo`030;^k^`00000000000080000000<0/k>c0?ooo`3oool0103oool00`3<c<`02@T900000003
0000000304A4A03oool0oooo0100oooo00@08R8R00000000000000001P3oool6000000030;>c/`3o
ool0oooo00@0oooo00D0IVIV0000000000000000028R8P060?ooo`030;^k^`000000000000800000
00<0IVIV0?ooo`3oool0103oool00`3<c<`04A4A0000000300000003028R8P3oool0oooo00D0oooo
0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool00P3oool01@1EEED00000
000000000000R8R800h0oooo0`0000000`0R8R80oooo0?ooo`080?ooo`D0000000<06QXJ0>k^kP3o
ool01@3oool01@1_Kfl00000000000000000TI6A00L0oooo00D0i^KV000000000000000009VIV@0B
0?ooo`<0000000<0A4A40?ooo`3oool0203oool00`14A4@00000000000020000000309VIV@3oool0
oooo00@0oooo00<0VIVI0000000000000P0000000`14A4@0oooo0?ooo`0>0?ooo`0500T92@000000
00000000003gmoL01P3oool0103<c<`000000000001VIVH3000000030=gMg@3oool0oooo00D0oooo
00@04A4A000000000000MgMg1@3oool50000000303<c<`3oool0oooo00D0oooo00D0<c<c00000000
00000000096AT@060?ooo`0404A4A00000000000000000L0oooo00<0A4A40000000000000P000000
0`2IVIT0oooo0?ooo`0:0?ooo`030820P0000000000000<0000000<0IVIV0?ooo`3oool0103oool0
1@1VIVH000000000000000008R8R01D0oooo00D08R8R00000000000000000=gMg@020?ooo`<00000
00<0<c<c0?ooo`3oool01P3oool01@2k^k/00000000000000000R8R80080oooo00D0EEEE00000000
000000000:ZZZP070?ooo`0304A4A03<c<`0oooo00L0oooo00D0R8R8000000000000000004A4A008
0?ooo`0505iNGP000000000000000034a<@0203oool00`2IVIT000000000000300000003014A4@3M
gMd0oooo00@0oooo00<0c<c<0000000000000P0000000`2ZZZX0oooo0?ooo`040?ooo`030<c<c00A
4A4000000080000000<0VIVI0?ooo`3oool00`3oool00`3^k^h08R8R000000020000000308R8R03o
ool0oooo00<0oooo00<0a<C40000000000000`0000000`1EEED0k^k^0?ooo`030?ooo`030::RXP00
0000000000@0000000<0IVIV0?Ogm`3oool00`3oool01@14A4@00000000000000000MgMg00L0oooo
00<0A4A40<c<c03oool01`3oool01@28R8P00000000000000000A4A400P0oooo00D0GUiN00000000
000000000<C4a0090?ooo`0404A4A00000000000014A4@H0oooo00<0gMgM0000000000000P000000
0`0c<c<0gMgM0?ooo`0<0?ooo`030::RXP3<c<`0oooo00L0oooo00D0R8R8000000000000000004A4
A00>0?ooo`0404A4A00000000000000000H0oooo00D0EEEE000000000000000008R8R00G0?ooo`03
0820P0000000000000<0000000<0IVIV0?ooo`3oool0103oool00`1VIVH000000000000200000003
0;^k^`3oool0oooo00<0oooo00D0P82000000000000000000::RXP0:0?ooo`<0000000<0A4A40?oo
o`3oool01P3oool30000000304A4A03oool0oooo00L0oooo00D0P820000000000000000004A4A03o
0?ooofT0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW9P3o
ool00`20P8000000000000020000000305EEE@3<c<`0oooo0080oooo00<0c<c<05EEE@0000000`00
00000`20P800oooo0?ooo`030?ooo`D0A4A40`0000000`0A4A40A4A404A4A00304A4A0030<c<c03o
ool0oooo00X0oooo00<0ZZZZ0000000000000P0000001`28R8P0k^k^0?ooo`3oool0k^k^09VIV@1g
MgL01@3oool00`3MgMd04A4A000000030000000308R8R03oool0oooo0080oooo00<0^k^k06IVIP2k
^k/0103oool01@2RXZ800000000000000000P82000H0oooo00<0VIVI0000000000000P0000001P2I
VIT0oooo0?ooo`3oool0a<C4014A4@<0000000<0A4A40?ooo`3oool01@3oool30000000501XJ6P00
000000000000001NGUh00`3oool00`3Vi^H0EEEE000000030000000308R8R03oool0oooo00D0oooo
00<0gMgM014A4@0000000`0000000`28R8P0oooo0?ooo`020?ooo`030;^k^`1VIVH0^k^k00@0oooo
00H0CDe=000000000000000002/[:`3MgMd20?ooo`030?Ogm`2IVIT04A4A00<0000000<0A4A40?oo
o`3oool04@3oool20000000306IVIP3<c<`0oooo00<0oooo00<0gMgM08R8R00000000`0000000`2c
/k<0oooo0?ooo`050?ooo`<0000000D0<c<c0000000000008R8R09VIV@030?ooo`030<c<c00[:b/0
00000080000000<0A4A40?ooo`3oool01@3oool01P0[:b/000000000000000006QXJ0:ZZZP<0oooo
00<0gMgM08R8R00000001@0000000`14A4@0oooo0?ooo`0@0?ooo`04028R8P0000000000000000H0
oooo0`0000001@0c<c<000000000000A4A40VIVI00<0oooo00<0c<c<05EEE@0000000`0000000`28
R8P0oooo0?ooo`050?ooo`0305EEE@00000000000080000000H0Kfm_0?ooo`3oool0oooo0>k^kP28
R8P600000003028R8P3oool0oooo00D0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0
A4A40?ooo`3oool00P3oool00`2ZZZX00000000000020000000708R8R03gmoL0oooo0?ooo`3^k^h0
P82008R8R0020?ooo`030;^k^`14A4@0A4A40080A4A40`0000000`092@T0A4A404A4A00304A4A003
09VIV@3oool0oooo0080oooo0`0000002`0A4A4000000000000A4A40R8R80<c<c03oool0^k^k0=gM
g@3oool0A4A400<0000000<0^k^k0?ooo`3oool01P3oool0100R8R8000000000001EEED=0?ooo`03
07MgM`14A4@0A4A40080A4A40`0000000`0A4A40A4A404A4A00204A4A00306m_K`3oool0oooo00<0
oooo00<0k^k^014A4@0000000`0000001P2ATI40oooo0?ooo`3oool0i^KV05EEE@@0000000<04A4A
0>k^kP3oool03P3oool01@2ZZZX00000000000000000A4A400P0oooo00<04A4A0000000000000P00
00000`0c<c<0oooo0?ooo`060?ooo`0405EEE@0000000000028R8PD0oooo0`0000001@0A4A400000
0000000R8R80VIVI00<0oooo00<0c<c<05EEE@0000000`0000000`34a<@0oooo0?ooo`040?ooo`04
04A4A00000000000000000L0oooo00<0gMgM014A4@0000000`0000000`28R8P0oooo0?ooo`020?oo
o`030;^k^`1VIVH0^k^k00@0oooo00D0P820000000000000000000T92@0200000003028R8P3<c<`0
oooo0080oooo00<0TI6A0000000000000P0000000`28R8P0oooo0?ooo`0C0?ooo`0704A4A0000000
00000000002k^k/0oooo0;^k^`030000000306IVIP3oool0oooo00L0oooo00L0A4A4000000000000
4A4A0>k^kP3oool0R8R800<0000000<0R8R80?ooo`3oool01@3oool0100R8R80000003<c<`2ZZZX4
0?ooo`030=gMg@28R8P0000000<0000000<0R8R80?ooo`3oool00P3oool01@1EEED0A4A404A4A014
A4@06QXJ00<0000000<0<c<c04A4A014A4@00P14A4@01@2k^k/0oooo0?ooo`3oool0^k^k00<00000
00D04A4A000000000000<c<c0;^k^`030?ooo`030:ZZZP0A4A40000000<0000000<0k^k^0?ooo`3o
ool01@3oool00`2IVIT00000000000020000000608R8R03oool0oooo0?ooo`3EeMD08R8R10000000
0`3^k^h0oooo0?ooo`030?ooo`050=gMg@0000000000000000092@T00P0000000`0R8R80c<c<0?oo
o`020?ooo`0604A4A000000000000000000l?3`04A4A0P0000001@1NGUh0oooo0?ooo`3oool0/k>c
00@0000000<0VIVI0?ooo`3oool01@3oool0100R8R80000003<c<`2ZZZX40?ooo`030=gMg@28R8P0
000000<0000000<0R8R80?ooo`3oool00P3oool01@1EEED0A4A404A4A014A4@06QXJ00<0000000<0
<c<c04A4A014A4@00P14A4@00`2k^k/0oooo0?ooo`020?ooo`0506IVIP00000000000000003^k^h0
1P3oool00`2IVIT000000000000200000003014A4@1gMgL0k^k^00<0oooo00<0c<c<04A4A03^k^h0
1@3oool01@2ATI40000003<c<`28R8P0i^KV00<0oooo00<0k^k^08R8R00000000`0000000`28R8P0
oooo0?ooo`0<0?ooo`0404A4A00000000000000000H0oooo00<0ZZZZ0000000000000P0000001`2k
^k/0oooo0?ooo`3gmoL0VIVI06IVIP28R8P0403oool01@20P80000000000000000002@T900800000
00<0<c<c0=GEe@3oool00P3oool00`28R8P00000000000020000000305EEE@3oool0oooo00@0oooo
00D0P82000000000000000000::RXP0:0?ooo`<0000000D0A4A40?ooo`3oool0oooo07MgM`0404A4
A0<0000000<04A4A04A4A014A4@00`14A4@01@3<c<`0oooo0?ooo`3oool0P82000<0000000<0A4A4
0?ooo`3oool0o`3ooomW0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWibH0oooo00<0lo?c07MgM`0J6QX0100000000`092@T08R8R00T92@040000000301XJ6P1g
MgL0lo?c00D0oooo3P0000000`34a<@0oooo0?ooo`0;0?ooo`0309VIV@0J6QX0000000<0000000D0
7QhN014A4@000000000003Ph>0060?ooo`030>KViP19BDT0000000@000000P0R8R80100=3@d00000
00000028R8P40?ooo`050::RXP000000000000000020P8001`3oool00`1lO7`00000000000020000
0003014A4@0R8R808R8R00@0000000<0?3`l0>k^kP3oool01P3oool30000000304A4A02c/k<0<c<c
00<0000000<06QXJ028R8P051@D00`0000000`051@D0P8200?ooo`080?ooo`030>KViP19BDT00000
00@000000P0R8R80100=3@d0000000000028R8P40?ooo`030=WIf@14A4@0000000<0000000<04A4A
028R8P0A4A400`0000000`051@D0Kfm_0>k^kP0C0?ooo`03014A4@0000000000008000000P0R8R80
0`092@T00000000000020000000300T92@1_Kfl0no_k00L0oooo0`0000000`28R8P0Lg=c00000002
0000000300d=3@0R8R802@T900@0000000<02@T90<30`03oool01P3oool00`34a<@06QXJ00000004
00000003028R8P0J6QX000000080000000<06QXJ0<C4a00000000P0000000`14A4@0oooo0?ooo`0@
0?ooo`04028R8P0000000000000000H0oooo0`0000000`28R8P0/k>c03<c<`030000000301XJ6P0F
5QH0000000<0000000<02@T90820P03oool01`3oool00`3gmoL0EUIF00000004000000808R8R00D0
2@T9000000000000000007alO00300000003028R8P3oool0oooo00D0oooo0`0000000`14A4@0oooo
0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool00`3oool00`2IVIT03@d=000000020000000300d=
3@0R8R804A4A0080000000@0Kfm_0?ooo`3oool0XZ:R3@0000000`28R8P0oooo0?ooo`020?ooo`<0
00000P20P8000`051@D0000000000003000000030;^k^`3Vi^H03@d=0080000000<04A4A0??cl`3o
ool01`3oool01@2RXZ800000000000000000^k^k00`0oooo00<0A4A40000000000002P0000000`14
A4@0oooo0?ooo`040?ooo`030>KViP19BDT0000000<0000000@02@T9028R8P0R8R801@D50`000000
0`0=3@d0MgMg0>KViP0@0?ooo`0504A4A000000000000000002ZZZX0203oool00`19BDT000000000
0002000000030::RXP3oool0oooo00H0oooo00D0a<C400000000000000000:ZZZP040?ooo`<00000
00<0A4A40;>c/`0J6QX00`0000000`0N7Qh02@T9000000030000000300T92@20P800oooo00H0oooo
00@0A4A40000000000000000203oool00`3Vi^H0BDU900000004000000808R8R00@03@d=00000000
0000R8R8103oool01P20P8000000000000000000O7al03<c<`<0000000<06QXJ028R8P092@T01000
00000`15ADD0oooo0?ooo`0D0?ooo`07096AT@00000000000000001gMgL0oooo06m_K`0300000003
0::RXP3oool0oooo00L0oooo00L0gMgM01XJ6P000000000003<c<`3gmoL0^k^k00<0000000<0A4A4
0?ooo`3oool01@3oool00`1VIVH0000000000002000000808R8R00<06QXJ0000000000000`000000
0`1EEED0k^k^0?ooo`030?ooo`0303Ph>0000000000000X0000000<0IVIV0?ooo`3oool00P3oool0
1P0A4A40000000000014A4@0/k>c03`l?0<0000000<08R8R01HF5P0000000`0000000`092@T0ZZZZ
0?ooo`080?ooo`0309jNWP0J6QX000000080000000@02@T9028R8P0R8R801@D50`0000000`0F5QH0
a<C40?ooo`050?ooo`070?_kn`092@T0000000000014A4@0Kfm_014A4@02000000808R8R00<02@T9
0000000000000P000000102RXZ80c<c<05EEE@092@T2000000808R8R00H01@D50000000000000000
02LW9`3gmoL70?ooo`0306IVIP0000000000008000000P0R8R800`0J6QX000000000000300000003
05EEE@3^k^h0oooo00<0oooo00<0>3Ph0000000000002P0000000`1VIVH0oooo0?ooo`020?ooo`05
0::RXP00000000000000002RXZ801`3oool00`3EeMD0MgMg014A4@030000000400D51@0R8R808R8R
014A4@80000000<0TI6A0?ooo`3oool00`3oool00`2c/k<0000000000002000000<08R8R00<02@T9
0000000000000P0000000`1EEED0k^k^0?ooo`0=0?ooo`0404A4A00000000000000000L0oooo00<0
FUYJ0000000000000P0000000`0J6QX08R8R00T92@020000000306m_K`3oool0oooo00h0oooo00H0
P820000000000000000008V9R@0J6QX3000000808R8R00<02@T90000000000000P0000000`1FEUH0
moOg0?ooo`050?ooo`050820P000000000000000002RXZ802P3oool30000000504A4A03oool0oooo
0?ooo`14A4@03@0000001@34a<@0oooo0?ooo`3oool0P82000<0000000<0A4A40?ooo`3oool0o`3o
oomW0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWibT0oooo
00<0VIVI014A4@0000001P0000000`0A4A40VIVI0?ooo`070?ooo`h0000000<0a<C40?ooo`3oool0
303oool00`3^k^h0?3`l0000000600000003028R8P3oool0oooo00H0oooo00<0VIVI028R8P000000
1`0000000`1VIVH0oooo0?ooo`020?ooo`050::RXP000000000000000020P800203oool00`2k^k/0
A4A4000000070000000306IVIP3gmoL0oooo00L0oooo0`0000001@14A4@0oooo0?ooo`2IVIT02@T9
00L0000000<0XZ:R0?ooo`3oool02P3oool00`2IVIT08R8R000000070000000306IVIP3oool0oooo
00@0oooo00<0^k^k04A4A00000001`0000000`2ZZZX0oooo0?ooo`0D0?ooo`0309VIV@0A4A400000
00L0000000<0A4A40=gMg@3oool0203oool30000000408R8R03oool0VIVI014A4@L0000000<0EEEE
0>k^kP3oool02@3oool00`28R8P04A4A0000000600000003028R8P3EeMD0oooo00<0000000<0A4A4
0?ooo`3oool0403oool0100R8R8000000000000000060?ooo`<0000000@0R8R80?ooo`3oool0EEEE
1`0000000`0[:b/0k^k^0?ooo`0:0?ooo`0308R8R00A4A40000000H0000000<08R8R0:ZZZP3oool0
0`0000000`0R8R80oooo0?ooo`050?ooo`<0000000<0A4A40?ooo`3oool0203oool30000000304A4
A03oool0oooo00@0oooo00<0/k>c0000000000001P0000001014A4@0oooo0?ooo`2RXZ8=00000003
08R8R03oool0oooo0080oooo0`0000000`28R8P0oooo08R8R005000000030;^k^`1gMgL000000080
000000<0MgMg0?ooo`3oool0203oool0100R8R8000000000000c<c<<0?ooo`0304A4A00000000000
00X0000000<0A4A40?ooo`3oool01P3oool00`2IVIT08R8R0000000700000003028R8P3<c<`0oooo
0100oooo00D0^k^k0000000000000000028R8P090?ooo`0508R8R000000000000000000A4A402P3o
ool0100c<c<000000000000c<c<40?ooo`<0000000@0A4A40?ooo`34a<@04A4A1`0000000`1EEED0
k^k^0?ooo`070?ooo`0404A4A00000000000000000X0oooo00<0VIVI028R8P0000001`0000000`1V
IVH0oooo0?ooo`020?ooo`080820P000000000000000002RXZ80oooo08R8R00A4A470000000305EE
E@3gmoL0oooo01D0oooo00L0c<c<000000000000000003<c<`3oool08R8R00<000002`3oool01P1_
Kfl00000000000000000XZ:R0?ooo`@00000203oool00`3MgMd0IVIV00T92@070000000300T92@2Z
ZZX0oooo00D0oooo00<0EEEE0000000000002P0000000`0R8R80oooo0?ooo`020?ooo`0405EEE@00
0000000000000080oooo00<0MgMg0000000000001@0000000`0J6QX0c<c<0?ooo`0;0?ooo`0309VI
V@0R8R80000000L0000000<0a<C40?ooo`3oool01P3oool01`14A4@000000000000[:b/0oooo0>k^
kP1gMgL01`0000001P28R8P0oooo0?ooo`3oool0gMgM03<c<`L0000000<0a<C40?ooo`3oool01`3o
ool00`3MgMd0IVIV00T92@070000000300T92@2ZZZX0oooo00D0oooo00<0EEEE0000000000002P00
00000`0R8R80oooo0?ooo`020?ooo`050>k^kP00000000000000001VIVH02@3oool00`3MgMd0A4A4
0000000700000003028R8P3oool0oooo00@0oooo00<0gMgM06IVIP0A4A40200000000`1NGUh0oooo
0?ooo`0>0?ooo`0404A4A00000000000000000L0oooo00<0moOg07MgM`0000001`0000000`14A4@0
oooo0?ooo`0>0?ooo`080820P0000000000000000034a<@0oooo08R8R00A4A470000000307MgM`3g
moL0oooo00H0oooo00D0P82000000000000000000::RXP0:0?ooo`<0000000D0A4A40?ooo`3oool0
oooo04A4A00=000000050<C4a03oool0oooo0?ooo`20P8000`0000000`14A4@0oooo0?ooo`3o0?oo
ofL0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW:P3oool0
2@3MgMd0R8R804A4A00R8R800000028R8P14A4@0MgMg0=GEe@0>0?ooo`<0000000<0A4A40?ooo`3o
ool04`3oool02@3^k^h0R8R804A4A00c<c<00000028R8P14A4@0MgMg0<c<c00:0?ooo`030:ZZZP1N
GUh08R8R0080000000@0<c<c07MgM`2IVIT0k^k^4`3oool00`3<c<`0IVIV028R8P020000000303<c
<`28R8P0gMgM0140oooo00P0c<c<06IVIP0c<c<00000014A4@14A4@0R8R80<c<c0l0oooo00<0ZZZZ
05iNGP0R8R800P000000100c<c<0MgMg09VIV@3^k^h80?ooo`080:ZZZP14A4@08R8R0000000A4A40
A4A408R8R03MgMdH0?ooo`040>KViP28R8P0EEEE03<c<`80000000<0<c<c05EEE@2c/k<04P3oool0
1`2IVIT0CDe=0000000000008R8R06IVIP3<c<`03@3oool00`3^k^h0MgMg03<c<`020000000302/[
:`1VIVH0ZZZZ00<0oooo0`0000000`14A4@0oooo0?ooo`0Q0?ooo`0809VIV@1VIVH0<c<c0000000R
8R80A4A408R8R03Vi^H=0?ooo`030>k^kP2IVIT0A4A40080000000<04A4A05EEE@2ZZZX00`3oool3
00000003028R8P3oool0oooo01h0oooo00T0gMgM08R8R014A4@06QXJ0000000R8R80A4A4096AT@3^
k^h01`3oool300000003028R8P3oool0oooo00h0oooo00H0VIVI05EEE@0R8R804A4A04A4A03MgMdT
0?ooo`<0000000<0A4A40?ooo`3oool03@3oool00`2k^k/0IVIV028R8P020000000303<c<`1gMgL0
ZZZZ03P0oooo0`0000002`14A4@0oooo0?ooo`3^k^h0VIVI05EEE@0J6QX00000028R8P14A4@0ZZZZ
01X0oooo00<0ZZZZ05iNGP0R8R800P000000100c<c<0MgMg09VIV@3^k^h40?ooo`050820P0000000
00000000002RXZ800P3oool00`3^k^h0MgMg03<c<`020000000303<c<`28R8P0c<c<01T0oooo1000
00001@3gmoL000000000000000006QXJ00/0oooo00L0^k^k000000000000000005iNGP3oool0A4A4
00<0000000<0^k^k0?ooo`3oool01`3oool0103MgMd0R8R804A4A00R8R820000000304A4A01VIVH0
a<C400/0oooo00D0a<C4000000000000000005iNGP090?ooo`0508R8R000000000000000002k^k/0
0P3oool0203<c<`0MgMg04A4A0092@T0000004A4A01VIVH0eMGE3`3oool0202ATI40A4A4014A4@00
00004A4A04A4A028R8P0gMgM403oool01`2k^k/0EEEE028R8P0000006QXJ06IVIP3MgMd01@3oool0
203^k^h0R8R804A4A00A4A402@T904A4A028R8P0gMgM303oool0103MgMd0R8R804A4A00R8R820000
000304A4A01VIVH0a<C400/0oooo00D0a<C4000000000000000005iNGP0I0?ooo`030=gMg@28R8P0
CDe=00<0000000<0CDe=08R8R03<c<`02@3oool00`2RXZ80A4A4028R8P020000000404A4A01VIVH0
VIVI0?Ogmad0oooo00<0gMgM08R8R00l?3`00P000000100c<c<0MgMg0:ZZZP3^k^hG0?ooo`030>k^
kP1gMgL0<c<c0080000000<0<c<c08R8R03MgMd0903oool30000000304A4A03oool0oooo0?l0oooo
M@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinM10?ooo`<0
000000<0A4A40?ooo`3oool0g@3oool30000000304A4A03oool0oooo0440oooo0`0000000`0R8R80
oooo0?ooo`0^0?ooo`<0000000<08R8R0?ooo`3oool0>03oool30000000304A4A03oool0oooo04d0
oooo0`0000000`14A4@0oooo0?ooo`0_0?ooo`050820P000000000000000002RXZ808`3oool01@0J
6QX00000000000000000a<C400<0000000<0<c<c0?ooo`3oool02@3oool01`3gmoL04A4A00000000
00006QXJ0?ooo`1VIVH00`0000000`2IVIT0oooo0?ooo`0K0?ooo`050=gMg@000000000000000014
A4@02@3oool01@2ZZZX00000000000000000VIVI06D0oooo00D0gMgM000000000000000004A4A02M
0?ooo`<0000000<0A4A40?ooo`3oool0o`3ooome0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWid40oooo0`0000000`14A4@0oooo0?ooo`3M0?ooo`<0000000<0
A4A40?ooo`3oool0@@3oool300000003028R8P3oool0oooo02h0oooo0`0000000`0R8R80oooo0?oo
o`0h0?ooo`<0000000<0A4A40?ooo`3oool0C@3oool30000000304A4A03oool0oooo02l0oooo00D0
P82000000000000000000::RXP0S0?ooo`0503Ph>0000000000000000024Q8@00`0000000`1ADE40
oooo0?ooo`0:0?ooo`060;^k^`0A4A4000000000001NGUh0VIVI0`0000000`1VIVH0oooo0?ooo`0L
0?ooo`04014A4@0000000000028R8PT0oooo00D0i^KV000000000000000006IVIP1V0?ooo`04014A
4@0000000000028R8Yd0oooo0`0000000`14A4@0oooo0?ooo`3o0?ooogD0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW@@3oool30000000304A4A03oool0oooo
0=d0oooo0`0000000`14A4@0oooo0?ooo`110?ooo`<0000000<08R8R0?ooo`3oool0;P3oool30000
0003028R8P3oool0oooo03P0oooo0`0000000`14A4@0oooo0?ooo`1=0?ooo`<0000000<0A4A40?oo
o`3oool0;`3oool01@20P8000000000000000000XZ:R02<0oooo00D0GUiN000000000000000003<c
<`03000000030820P03oool0oooo00/0oooo00D0VIVI000000000000000007MgM`0300000003014A
4@3oool0oooo01`0oooo00@0A4A400000000000000002P3oool01014A4@000000000000A4A5V0?oo
o`0404A4A00000000000000009d0oooo0`0000000`14A4@0oooo0?ooo`3o0?ooogD0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW@@3oool01014A4@000000000
000R8R;O0?ooo`<0000000<0A4A40?ooo`3oool0@@3oool300000003028R8P3oool0oooo02h0oooo
0`0000000`0R8R80oooo0?ooo`0h0?ooo`<0000000<0A4A40?ooo`3oool0C@3oool30000000304A4
A03oool0oooo02l0oooo00D0P82000000000000000000::RXP0S0?ooo`0506m_K`00000000000000
00092@T00`0000000`2IVIT0oooo0?ooo`0<0?ooo`04028R8P0000000000014A4@@0000000<0k^k^
0?ooo`3oool06`3oool01@28R8P00000000000000000c<c<00T0oooo00D0IVIV0000000000000000
0>k^kP1U0?ooo`0508R8R000000000000000003<c<`0W03oool30000000304A4A03oool0oooo0?l0
ooooM@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinM10?oo
o`0505EEE@00000000000000003MgMd0=03oool01@20P8000000000000000000GUiN0:D0oooo0`00
00000`14A4@0oooo0?ooo`0@0?ooo`@0000000<0gMgM0?ooo`3oool0:P3oool300000003028R8P3o
ool0oooo02h0oooo00@0k^k^0:ZZZP1VIVH0:b/[>P3oool0103<c<`0IVIV014A4@14A4A?0?ooo`<0
000000<0A4A40?ooo`3oool04P3oool4000000030;^k^`3oool0oooo01H0oooo00D0P82000000000
000000000::RXP0S0?ooo`030820P0000000000000D0000000<0/k>c0?ooo`3oool0303oool00`2k
^k/0000000000005000000030;^k^`3oool0oooo01`0oooo00@0gMgM08R8R00R8R80VIVI2@3oool0
1@28R8P00000000000000000^k^k06H0oooo00@0gMgM08R8R00R8R80VIVI2@3oool00`3MgMd00000
00000002000000030>KViP3oool0oooo0380oooo100000000`2k^k/0oooo0?ooo`1B0?ooo`040>k^
kP28R8P04A4A04A4A?l0ooooM`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinM10?ooo`060;>c/`00000000000000000l?3`0g]kN<`3oool01@20P80000000000
00000000GUiN0:D0oooo0`0000000`14A4@0oooo0?ooo`0@0?ooo`@0000000<0gMgM0?ooo`3oool0
:P3oool300000003028R8P3oool0oooo0340oooo00<0lo?c0?ooo`3oool0>`3oool00`3Vi^H0oooo
0?ooo`1=0?ooo`<0000000<0A4A40?ooo`3oool04P3oool4000000030;^k^`3oool0oooo01H0oooo
00D0P82000000000000000000::RXP0S0?ooo`030:n_[`000000000000D0000000<0dM7A0?ooo`3o
ool03@3oool00`10@4000000000000040000000307MgM`3oool0oooo01h0oooo00<0no_k0>k^kP3o
ool0203oool01@3EeMD00000000000000000MgMg06P0oooo00<0no_k0>k^kP3oool02@3oool01@0A
4A400000000000000000c<c<03@0oooo100000000`2k^k/0oooo0?ooo`1E0?ooo`030>KViP3oool0
oooo0?l0ooooM@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inM20?ooo`03028R8P0000000000008000000P14A4@00`0c<c<0a<C40?ooo`0^0?ooo`050820P000
000000000000001NGUh0Y@3oool30000000304A4A03oool0oooo0100oooo100000000`3MgMd0oooo
0?ooo`0Z0?ooo`<0000000<08R8R0?ooo`3oool0_`3oool30000000304A4A03oool0oooo0180oooo
100000000`2k^k/0oooo0?ooo`0F0?ooo`050820P000000000000000002RXZ808`3oool00`34a<@0
00000000000500000100oooo00<0/k>c000000000000100000000`14A4@0oooo0?ooo`0Z0?ooo`04
00T92@000000000004A4A7@0oooo00D0<c<c00000000000000000:ZZZP0d0?ooo`@0000000<0^k^k
0?ooo`3oool0o`3oooo=0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWid80oooo00<0MgMg0000000000001@0000000`2k^k/0oooo0?ooo`0]0?ooo`050820P000
000000000000001NGUh0Y@3oool30000000304A4A03oool0oooo0100oooo100000000`3MgMd0oooo
0?ooo`0Z0?ooo`<0000000<08R8R0?ooo`3oool0_`3oool30000000304A4A03oool0oooo0180oooo
100000000`2k^k/0oooo0?ooo`0F0?ooo`050820P000000000000000002RXZ80K`3oool0100R8R80
000000000000001d0?ooo`0504A4A000000000000000002ATI40=03oool4000000030;^k^`3oool0
oooo0?l0ooooc@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inM20?ooo`030>KViP0c<c<0000000D0000000<0XZ:R0?ooo`3oool0;@3oool01@3MgMd0^k^k0;^k
^`2k^k/0eMGE0:D0oooo0`0000000`14A4@0oooo0?ooo`0@0?ooo`@0^k^k00<0moOg0?ooo`3oool0
:P3oool300000003028R8P3oool0oooo0;l0oooo0`0000000`14A4@0oooo0?ooo`0B0?ooo`@0^k^k
00<0k^k^0?ooo`3oool05P3oool01@20P8000000000000000000XZ:R06l0oooo00D0?3`l00000000
000000000>k^kP1c0?ooo`050=GEe@2k^k/0^k^k0;^k^`3MgMd0=03oool40;^k^`030>k^kP3oool0
oooo0?l0ooooc@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inM40?ooo`030=GEe@2c/k<0TI6A0080P82000<0XZ:R0=gMg@3oool0o`3ooooo0?ooool0ooooo`3o
oooo0?oooaH0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3o
oooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooob<0
oooo00@0XZ:R05EEE@14A4@04A4A0P000000100c<c<0A4A408R8R03MgMej0?ooo`050=gMg@28R8P0
EEEE04A4A0092@T00P000000100c<c<0GUiN09VIV@3MgMeH0?ooo`040;^k^`1_Kfl0A4A4014A4@80
000000@0<c<c04A4A01gMgL0^k^ko`3ooooo0?ooodd0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooob00oooo00<0R8R805EEE@0000002P000000
0`14A4@0^k^k0?ooo`1e0?ooo`0308R8R01EEED0000000X0000000<0A4A40=gMg@3oool0DP3oool0
0`34a<@0EEEE0000000:0000000304A4A02k^k/0oooo0?l0ooooo`3ooom:0?ooo`040>WYj@3AdM40
dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3ooolP0?ooo`0301XJ6P00
0000000000<0000000@04A4A028R8P0R8R804A4A1@0000000`1RHV80moOg0?ooo`1c0?ooo`0301XJ
6P000000000000<0000000@06QXJ028R8P0R8R804A4A100000000`0J6QX0TI6A0?Ogm`1A0?ooo`03
08f=S@000000000000<0000000@04A4A028R8P0R8R804A4A1@0000000`0c<c<0a<C40?ooo`3o0?oo
ool0ooooB03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo
0?ooool0oooo803oool01@14A4@000000000001NGUh0^k^k00D0oooo00<0gMgM04e=C@0000000`00
00000`1EEED0oooo0?ooo`1b0?ooo`0504A4A00000006QXJ08R8R02k^k/01@3oool00`2c/k<04A4A
000000030000000305EEE@3oool0oooo04l0oooo00D0XZ:R000000000000<c<c0::RXP050?ooo`03
0=gMg@28R8P02@T900<0000000<0:b/[0?ooo`3oool0o`3ooooo0?ooodL0oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooob00oooo00<0MgMg06IV
IP3<c<`0203oool00`3gmoL0<c<c00000003000000030;^k^`3oool0oooo0740oooo00<0MgMg06IV
IP3Vi^H0203oool00`3^k^h0<c<c00000003000000030;^k^`3oool0oooo04h0oooo00<0^k^k06IV
IP3<c<`02@3oool00`2ATI40000000000002000000030;^k^`3oool0oooo0?l0ooooo`3ooom60?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiol0ooooo`3oool]
0?ooo`0503<c<`000000000000000014A4@0P03oool01@0c<c<00000000000000000A4A405d0oooo
00D0<c<c000000000000000004A4A03o0?ooool0ooooB03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo;@3oool00`3Vi^H0:b/[000000020000
00030;^k^`3oool0oooo07d0oooo00<0i^KV01HF5P0000000P0000000`3MgMd0oooo0?ooo`1J0?oo
o`030>KViP0[:b/000000080000000<0^k^k0?ooo`3oool0o`3ooooo0?ooodD0oooo00@0jNWY0=7A
d@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooobh0oooo00D0VIVI
000000000000000008R8R0200?ooo`0504e=C@000000000000000034a<@0G@3oool01@2IVIT00000
000000000000R8R80?l0ooooo`3ooom70?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`04
0>WYj@3AdM40dM7A0>OWidL0oooo00T0c<c<08R8R014A4@04A4A0000000A4A40A4A407MgM`3^k^h0
6@3oool00`3<c<`0IVIV028R8P020000000303<c<`28R8P0c<c<00X0oooo00@0gMgM08R8R01EEED0
8R8R0P0000000`0c<c<0Kfm_0>k^kP070?ooo`040=gMg@28R8P0EEEE028R8P80000000<0<c<c06m_
K`3^k^h05P3oool0203^k^h0R8R804A4A00R8R80000004A4A01VIVH0ZZZZ803oool01@3gmoL0VIVI
06IVIP14A4@02@T90080000000<0A4A406IVIP3<c<`0>P3oool0202ZZZX0A4A4028R8P0000004A4A
04A4A028R8P0c<c<:@3oool0203^k^h0VIVI05EEE@0J6QX00000028R8P14A4@0ZZZZ7@3oool00`3M
gMd0R8R803<c<`020000000304A4A028R8P0oooo0200oooo00@0k^k^09VIV@1EEED04A4A0P000000
100R8R80A4A408R8R03<c<`L0?ooo`040<C4a01VIVH0A4A4014A4@8000000P14A4@00`2ZZZX0oooo
0?ooo`0L0?ooo`040>k^kP28R8P0EEEE04A4A080000000<0<c<c05EEE@2k^k/0503oool0203MgMd0
R8R805EEE@0R8R800000014A4@14A4@0ZZZZ9P3oool01@3MgMd00000000000000000EEEE01X0oooo
00<0c<c<08R8R00c<c<00P0000000`0R8R80IVIV0<c<c01N0?ooo`0506m_K`00000000000000002Z
ZZX08P3oool00`3MgMd0Kfm_04A4A0020000000302/[:`28R8P0c<c<03<0oooo00D0gMgM00000000
0000000005EEE@090?ooo`050?Ogm`2IVIT0IVIV04A4A0092@T00P0000000`14A4@0IVIV0<c<c00I
0?ooo`030<c<c01VIVH08R8R0080000000<0<c<c08R8R03<c<`0:P3oool00`2ZZZX0MgMg04A4A002
0000000304A4A01gMgL0gMgM00/0oooo00@0k^k^08R8R01EEED0A4A40P0000000`0c<c<0EEEE0;^k
^`0<0?ooo`040>k^kP2IVIT0EEEE014A4@80000000@08R8R04A4A028R8P0c<c<203oool00`2c/k<0
EEEE04A4A0020000000403<c<`1EEED0R8R80?Ogmd80oooo00<0gMgM06m_K`14A4@00P0000000`0[
:b/0R8R80<c<c01=0?ooo`040<C4a01VIVH0A4A4014A4@8000000P14A4@00`2ZZZX0oooo0?ooo`0E
0?ooo`090?Ogm`2IVIT0EEEE03<c<`0000008R8R04A4A028R8P0i^KV00/0oooo00@0k^k^08R8R01E
EED0A4A40P0000000`0c<c<0EEEE0;^k^`3@0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWib<0oooo00D0A4A4000000000000000008R8R00B0?ooo`050:ZZZP00
000000000000000R8R801`3oool00`20P8000000000000060000000303<c<`3oool0oooo0080oooo
0`0000000`14A4@0oooo0?ooo`0=0?ooo`030;^k^`14A4@0000000L0000000<0A4A40=gMg@3oool0
1P3oool00`2c/k<00000000000070000000308R8R03^k^h0oooo00<0oooo00<0/k>c000000000000
1`0000000`28R8P0k^k^0?ooo`0C0?ooo`0304A4A0000000000000@0000000<0A4A40?ooo`3oool0
0P3oool01@20P8000000000000000000XZ:R00X0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`03
0=gMg@0c<c<0000000P0000000<08R8R07MgM`3oool0503oool00`2IVIT000000000000200000003
09VIV@3oool0oooo00L0oooo00<0XZ:R0000000000000P0000000`3^k^h0oooo0?ooo`0:0?ooo`03
0;^k^`14A4@0000000L0000000<0P8200?ooo`3oool02@3oool30000000304A4A03oool0oooo00T0
oooo00@0A4A400000000000000002@3oool00`34a<@04A4A000000060000000404A4A02k^k/0oooo
0::RXP<0000000<0XZ:R0?ooo`3oool04P3oool00`28R8P000000000000400000003028R8P3oool0
oooo0080oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool01P3oool0
0`3^k^h0IVIV000000090000000304e=C@3oool0oooo00D0oooo00D0P82000000000000000000::R
XP0=0?ooo`030=gMg@1VIVH0000000P0000000<08R8R07MgM`3oool04@3oool01014A4@000000000
000000060?ooo`0303<c<`000000000000H0000000<0R8R80>k^kP3oool0403oool00`2c/k<00000
000000060000000404A4A03MgMd0oooo04A4A080000000<08R8R0?ooo`3oool04P3oool02@3gmoL0
R8R805EEE@0R8R800000028R8P14A4@0R8R80>KViP030?ooo`<0000000<0A4A40?ooo`3oool00`3o
ool300000003028R8P3oool0oooo00d0oooo00<0gMgM04A4A00000001`0000000`14A4@0^k^k0?oo
o`0;0?ooo`030<c<c000000000000080000000<0VIVI0?ooo`3oool0203oool01@0R8R8000000000
00000000MgMg00X0oooo00@0A4A400000000000000001`3oool30000000304A4A03oool0oooo00P0
oooo00D0P82000000000000000000::RXP080?ooo`080>k^kP28R8P0EEEE014A4@0000008R8R04A4
A02ZZZX30?ooo`050820P000000000000000002RXZ804@3oool30000000304A4A03oool0oooo00T0
oooo00<0k^k^07MgM`0000001`0000000`14A4@0k^k^08R8R00200000003014A4@3oool0oooo00D0
oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool0203oool0202k^k/0
EEEE028R8P0000004A4A04A4A028R8P0c<c<0`3oool30000000304A4A03oool0oooo00H0oooo00<0
gMgM03<c<`000000200000000`0R8R80MgMg0?ooo`0D0?ooo`030;^k^`14A4@0000000L0000000<0
A4A40=gMg@3oool02P3oool01@20P8000000000000000000XZ:R01L0oooo00<0P820000000000000
1@0000001@0J6QX0^k^k0?ooo`3oool08R8R0080000000<0A4A40?ooo`3oool00P3oool00`0c<c<0
0000000000060000000308R8R03^k^h0oooo00L0oooo00<0k^k^06IVIP0000002@0000000`1=CDd0
oooo0?ooo`040?ooo`0306IVIP000000000000H0000000<0A4A40>k^kP3oool0403oool01014A4@0
00000000000000070?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000000000000000
XZ:R0100oooo00<0k^k^07MgM`0000001`0000000`14A4@0k^k^08R8R00200000003014A4@3oool0
oooo00D0oooo00@08R8R00000000000000001`3oool01014A4@0000000000000000E0?ooo`<00000
00<0A4A40?ooo`3oool01P3oool01@2RXZ800000000000000000P82000T0oooo00<0gMgM06IVIP00
0000200000000`0R8R80MgMg0?ooo`060?ooo`0404A4A00000000000000000X0oooo00<0CDe=0000
000000001@0000001@0R8R80^k^k0?ooo`3oool08R8R0080000000<0A4A40?ooo`3oool00P3oool0
0`0c<c<00000000000060000000308R8R03^k^h0oooo0<d0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOW8`3oool01P3<c<`04A4A0000000000004A4A0=gMgA40
oooo00D0FUYJ000000000000000006m_K`040?ooo`030?Ogm`2ATI40:b/[00@0000000<04A4A028R
8P0J6QX00P0000000`14A4@0oooo0?ooo`020?ooo`<0000000<0A4A40?ooo`3oool02`3oool00`3g
moL0HV9R000000030000000400T92@0R8R808R8R00D51@<0000000<06QXJ096AT@3gmoL01@3oool0
1`2RXZ8000000000000000004A4A028R8P0A4A40100000000`0J6QX0dM7A0?ooo`020?ooo`070::R
XP00000000000000000A4A408R8R014A4@040000000301XJ6P3AdM40oooo0100oooo00<0k^k^04A4
A00000000`000000100F5QH06QXJ00000014A4@40?ooo`050820P000000000000000002RXZ802P3o
ool30000000304A4A03oool0oooo00@0oooo00<0c<c<04e=C@092@T0100000000`0A4A408R8R01XJ
6P05000001@0oooo00<0no_k02/[:`0000000`0000000`0[:b/0moOg0?ooo`070?ooo`03069RHP00
000000000080000000<0R8R80?ooo`3oool0203oool00`34a<@0<c<c000000030000000300T92@0R
8R805QHF00@0000000<0<c<c096AT@3gmoL0203oool30000000304A4A03oool0oooo00T0oooo00@0
A4A40000000000000000203oool00`2ZZZX05QHF00000003000000808R8R00H04A4A000000000000
000003`l?01lO7`3000000030::RXP3oool0oooo0140oooo00<0VIVI0000000000000P0000001009
2@T08R8R01XJ6P0R8R840?ooo`<0000000<08R8R0?ooo`3oool02@3oool30000000304A4A03oool0
oooo00D0oooo00<0c<c<02/[:`00000010000002028R8P0300d=3@0000000000008000001`3oool0
1@20P8000000000000000000XZ:R00/0oooo00<0i^KV04e=C@092@T01@0000000`0R8R806QXJ0000
000400000180oooo00@0A4A400000000000000001P3oool01P0R8R8000000000000000008R8R014A
4@@0000000<06QXJ0::RXP3oool03P3oool00`2IVIT03@d=000000020000000400D51@0R8R808R8R
00T92@80000000<02@T906m_K`0h>3P00P0000000`14A4@0oooo0?ooo`0@0?ooo`030>KViP2ATI40
7QhN00L0000000@04A4A06IVIP34a<@0oooo0`0000000`14A4@0oooo0?ooo`030?ooo`<0000000<0
8R8R0?ooo`3oool02`3oool00`3gmoL0TI6A01XJ6P030000000400D51@0R8R808R8R00T92@@00000
00<0HV9R0?Ogm`3oool02@3oool00`2ATI400000000000020000000302/[:`3gmoL0oooo00L0oooo
00<0a<C40000000000000P0000000`14A4@0oooo0?ooo`080?ooo`0404A4A00000000000000000L0
oooo0`0000000`14A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ801P3oool00`3V
i^H0IfMW0000000700000004028R8P1VIVH0a<C40820P0<0000000<0XZ:R0?ooo`3oool03`3oool3
0000000304A4A03oool0oooo00P0oooo00<0c<c<01XJ6P0000000`0000000`092@T08R8R01HF5P03
0000000503`l?01_Kfl000000000000R8R801`3oool30000000304A4A03oool0oooo00P0oooo0`00
00000`14A4@0oooo0?ooo`050?ooo`030>KViP2ATI40?3`l00P0000000<0A4A40<C4a03oool00`00
00000`14A4@0oooo0?ooo`040?ooo`030<c<c01=CDd02@T900@0000000<04A4A028R8P0J6QX01@00
000C0?ooo`030?Ogm`1RHV80000000<0000000@02@T9028R8P0R8R801@D50`0000000`0J6QX0TI6A
0?Ogm`090?ooo`050820P000000000000000002RXZ805@3oool00`3^k^h0EEEE0000000300000003
00T92@0R8R804A4A00<0000000<0CDe=0<c<c00R8R800P0000000`14A4@0oooo0?ooo`020?ooo`06
028R8P00000000000000000R8R804A4A100000000`0J6QX0XZ:R0?ooo`050?ooo`030<c<c00[:b/0
000000@000000P0R8R800`0=3@d0000000000002000000H0oooo00H0A4A40000000000000000028R
8P0J6QX40000000301XJ6P2RXZ80oooo00l0oooo00@0A4A400000000000000001`3oool300000003
04A4A03oool0oooo00P0oooo00D0P82000000000000000000::RXP0?0?ooo`030<c<c00J6QX00000
00<0000000<02@T9028R8P0F5QH00`0000001@0l?3`0Kfm_0000000000008R8R00L0oooo00@08R8R
00000000000000001`3oool01014A4@0000000000000000E0?ooo`<0000000<0A4A40?ooo`3oool0
1P3oool01@2RXZ800000000000000000P82000L0oooo00<0i^KV04e=C@092@T01@0000000`0R8R80
6QXJ00000004000000L0oooo00@0A4A40000000000000000203oool00`2ZZZX0:b/[000000030000
0003014A4@0R8R804A4A00<0000000<0?3`l0;>c/`0R8R800P0000000`14A4@0oooo0?ooo`020?oo
o`06028R8P00000000000000000R8R804A4A100000000`0J6QX0XZ:R0?ooo`3<0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib@0oooo00D0R8R8000000000000
000006IVIP0A0?ooo`05014A4@000000000000000034a<@00`3oool00`3gmoL0<c<c000000030000
000305EEE@2ZZZX0oooo00<0oooo00<0P82007MgM`3oool00`3oool30000000304A4A03oool0oooo
00X0oooo00<0k^k^03<c<`0000000`0000001P2IVIT0oooo0?ooo`3oool0k^k^06IVIP@0000000<0
<c<c0>k^kP3oool00`3oool0102RXZ804A4A07MgM`2k^k/30?ooo`030=gMg@0[:b/0000000800000
00P0GUiN0?ooo`3oool0oooo0::RXP0A4A40MgMg0;^k^`<0oooo00<0gMgM02/[:`0000000P000000
0`1NGUh0oooo0?ooo`0?0?ooo`0307MgM`00000000000080000000D0R8R80?ooo`3oool0k^k^09VI
V@040?ooo`050820P000000000000000002RXZ802P3oool30000000304A4A03oool0oooo00<0oooo
00<0eMGE0000000000000`0000000`14A4@0^k^k0?ooo`030?ooo`0409VIV@0A4A400000000001@0
oooo00<0c<c<000000000000100000000`2ZZZX0oooo0?ooo`060?ooo`0302/[:`00000000000080
000000<04A4A0?ooo`3oool01`3oool00`3^k^h06QXJ000000020000000303<c<`3<c<`0oooo0080
oooo00<0gMgM06IVIP0000000`0000000`0c<c<0moOg0?ooo`060?ooo`<0000000<0A4A40?ooo`3o
ool02@3oool01014A4@000000000000000070?ooo`0308R8R000000000000080000000<04A4A0<C4
a03oool00P3oool01@2c/k<000000000000000002@T900<0000000<0XZ:R0?ooo`3oool04@3oool0
1@0l?3`00000000000000000A4A400<0oooo00<0a<C40?ooo`3oool00P3oool300000003028R8P3o
ool0oooo00T0oooo0`0000000`14A4@0oooo0?ooo`040?ooo`030:ZZZP000000000000<0000000<0
P8200?ooo`3oool00P3oool0102k^k/0MgMg014A4@0000070?ooo`050820P000000000000000002R
XZ802`3oool00`1EEED00000000000020000000304A4A02k^k/0oooo00<0oooo00@0^k^k04A4A000
000000004P3oool01014A4@000000000000000060?ooo`0302/[:`1gMgL0^k^k00<0oooo00<0gMgM
05EEE@0000000`0000000`3MgMd0oooo0?ooo`0;0?ooo`030;^k^`00000000000080000000<08R8R
0=GEe@3oool00P3oool00`2IVIT00000000000040000000304A4A03oool0oooo00l0oooo00<0k^k^
014A4@000000100000000`0R8R80A4A4028R8P040000000506IVIP000000000000000014A4@01@3o
ool300000003028R8P3oool0oooo00X0oooo00<0k^k^03<c<`0000000`0000000`1VIVH0i^KV0?oo
o`020?ooo`030::RXP00000000000080000000<0<c<c0>k^kP3oool0203oool00`1=CDd000000000
0003000000030:ZZZP3oool0oooo00H0oooo00<0EEEE0000000000000P0000000`092@T0oooo0?oo
o`080?ooo`0404A4A00000000000000000L0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`050820
P000000000000000002RXZ801@3oool00`3^k^h04A4A0000000400000080A4A400<08R8R00000000
00000P0000001@0c<c<00000000000000000XZ:R0140oooo0`0000000`14A4@0oooo0?ooo`080?oo
o`0605iNGP00000000000000000A4A40ZZZZ0`3oool00`3<c<`0IVIV0000000400000003028R8P3o
ool0oooo00D0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool0103o
ool00`3gmoL04A4A000000050000000304A4A00R8R80000000<0000000D0IVIV0000000000000000
04A4A0050?ooo`030=GEe@000000000000<0000000<0A4A40;^k^`3oool00`3oool0102IVIT04A4A
00000000000B0?ooo`030>k^kP0c<c<0000000<0000000H0VIVI0?ooo`3oool0oooo0>k^kP1VIVH4
0000000303<c<`3^k^h0oooo00L0oooo00D0P82000000000000000000::RXP0E0?ooo`0304A4A000
000000000080000000H0R8R80>k^kP3oool0oooo0>k^kP1=CDd2000000804A4A0P0000000`14A4@0
oooo0?ooo`020?ooo`0302/[:`1gMgL0^k^k00<0oooo00<0gMgM05EEE@0000000`0000000`3MgMd0
oooo0?ooo`020?ooo`030:ZZZP000000000000<0000000<0P8200?ooo`3oool00P3oool0102k^k/0
MgMg014A4@0000060?ooo`80A4A400H0^k^k0?ooo`3oool0oooo0=gMg@1EEED4000000030;^k^`3o
ool0oooo00d0oooo00@0A4A400000000000000001`3oool30000000304A4A03oool0oooo00P0oooo
00D0P82000000000000000000::RXP0?0?ooo`0605iNGP00000000000000000A4A40ZZZZ0`3oool0
0`3<c<`0IVIV0000000400000003028R8P3oool0oooo00D0oooo00@08R8R00000000000000001`3o
ool01014A4@0000000000000000E0?ooo`<0000000<0A4A40?ooo`3oool01P3oool01@2RXZ800000
000000000000P82000L0oooo00<0EEEE0000000000000P0000000`14A4@0^k^k0?ooo`030?ooo`04
0;^k^`14A4@00000000000L0oooo00@0A4A400000000000000001`3oool00`28R8P0000000000002
00000003014A4@2IVIT0moOg0080oooo00<0gMgM04A4A00000000P00000010092@T0000000000014
A4@40?ooo`0302/[:`1gMgL0^k^k00<0oooo00<0gMgM05EEE@0000000`0000000`3MgMd0oooo0?oo
o`3:0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib@0oooo
00<0k^k^0000000000000P0000000`3^k^h0oooo0?ooo`0=0?ooo`030;^k^`000000000000800000
00D0moOg0?ooo`3oool0oooo0;^k^`040000000309VIV@3oool0oooo00D0oooo00<0k^k^0?ooo`3o
ool00P3oool30000000304A4A03oool0oooo00X0oooo00H0MgMg0000000000000000014A4@2k^k/6
0?ooo`030<c<c00A4A4000000080000000<0MgMg0?ooo`3oool00P3oool00`3Vi^H0k^k^0?ooo`05
0?ooo`050;>c/`00000000000000000c<c<00`3oool00`3Vi^H0k^k^0?ooo`050?ooo`050;>c/`00
000000000000000c<c<04@3oool01@14A4@00000000000000000R8R800T0oooo00D0P82000000000
000000000::RXP0:0?ooo`<0000000<0A4A40?ooo`3oool00`3oool01P20P8000000000000000000
2@T909VIV@P0oooo00<0VIVI014A4@3oool04`3oool01@2ZZZX000000000000000004A4A00800000
00<0IVIV0?ooo`3oool01@3oool01@3^k^h00000000000000000<c<c0080000000<0ZZZZ0?ooo`3o
ool01P3oool01P1gMgL000000000000000004A4A0=gMg@H0oooo00<0c<c<00T92@0000000P000000
0`2k^k/0oooo0?ooo`050?ooo`<0000000<0A4A40?ooo`3oool02@3oool01014A4@0000000000000
00060?ooo`030=gMg@0A4A4000000080000000<0<c<c0>k^kP3oool0103oool00`3<c<`04A4A0000
0004000000030::RXP3oool0oooo0140oooo00D08R8R00000000000000000<C4a0080?ooo`<00000
00<08R8R0?ooo`3oool02@3oool30000000304A4A03oool0oooo00<0oooo00<0k^k^014A4@000000
0P0000000`0A4A40VIVI0?ooo`070?ooo`0305EEE@3oool0oooo00D0oooo00D0P820000000000000
00000::RXP0:0?ooo`030>k^kP092@T000000080000000<0EEEE0?ooo`3oool01P3oool00`2IVIT0
4A4A0?ooo`0A0?ooo`0404A4A00000000000000000H0oooo00<0gMgM0?ooo`3oool01@3oool01@0c
<c<00000000000000000/k>c00d0oooo00H0IVIV0000000000000000028R8P3^k^h50?ooo`030<c<
c00A4A40000000<0000000<0A4A40?ooo`3oool03`3oool00`14A4@000000000000200000003014A
4@2IVIT0oooo0080oooo00<0k^k^04e=C@0000001@0000000`14A4@0oooo0?ooo`030?ooo`<00000
00<08R8R0?ooo`3oool02P3oool01P1gMgL000000000000000004A4A0;^k^`H0oooo00<0c<c<014A
4@0000000P0000000`1gMgL0oooo0?ooo`070?ooo`0402/[:`0000000000028R8P80000000<0IVIV
0?ooo`3oool01@3oool01@3^k^h00000000000000000<c<c0080000000<0ZZZZ0?ooo`3oool01`3o
ool01014A4@000000000000000070?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000
000000000000XZ:R00D0oooo00<0A4A40000000000000P0000000`0A4A40c<c<0?ooo`020?ooo`03
0;^k^`0A4A40000000D0000000<0XZ:R0?ooo`3oool03`3oool30000000304A4A03oool0oooo00P0
oooo00D0<c<c000000000000000008R8R0060?ooo`030<c<c0092@T000000080000000<08R8R0?oo
o`3oool01@3oool30000000304A4A03oool0oooo00P0oooo0`0000000`14A4@0oooo0?ooo`040?oo
o`030::RXP00000000000080000000<04A4A09VIV@3oool00P3oool00`3^k^h0R8R800T92@050000
000304A4A03oool0oooo00<0oooo00H0P820000000000000000000T92@2IVIT80?ooo`0309VIV@0A
4A40oooo0140oooo00H0MgMg0000000000000000014A4@2k^k/60?ooo`030<c<c00A4A4000000080
000000<0MgMg0?ooo`3oool01P3oool01@20P8000000000000000000XZ:R01@0oooo00<0gMgM0000
000000000P0000000`2IVIT0oooo0?ooo`030?ooo`030?Ogm`0c<c<0000000@0000000<0A4A40?oo
o`3oool00P3oool00`3MgMd0oooo0?ooo`050?ooo`0503<c<`00000000000000002c/k<00`3oool0
0`3gmoL04A4A0000000200000003014A4@2IVIT0oooo00L0oooo00<0EEEE0?ooo`3oool0103oool0
0`3<c<`0moOg0?ooo`050?ooo`0506IVIP00000000000000001VIVH03`3oool01014A4@000000000
000000070?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000000000000000XZ:R00l0
oooo00D0<c<c000000000000000008R8R0060?ooo`030<c<c0092@T000000080000000<08R8R0?oo
o`3oool01@3oool0100R8R8000000000000000070?ooo`0404A4A00000000000000001D0oooo0`00
00000`14A4@0oooo0?ooo`060?ooo`050::RXP000000000000000020P8001P3oool00`3^k^h02@T9
000000020000000305EEE@3oool0oooo00H0oooo00<0VIVI014A4@3oool01P3oool01014A4@00000
0000000000060?ooo`030>k^kP0A4A4000000080000000<0<c<c0>k^kP3oool0103oool00`3Vi^H0
4A4A000000040000000304A4A03oool0oooo0080oooo00<0gMgM0?ooo`3oool01@3oool01@0c<c<0
0000000000000000/k>c0<`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOW9@3oool01@1VIVH00000000000000000R8R800l0oooo00D0IVIV0000000000000000
06IVIP040?ooo`0505iNGP00000000000000001=CDd03@3oool30000000304A4A03oool0oooo00T0
oooo00<0^k^k0000000000000P0000000`2k^k/0oooo0?ooo`060?ooo`030;^k^`00000000000080
000000<0gMgM0?ooo`3oool02@3oool01@3^k^h000000000000000004A4A00/0oooo00D0k^k^0000
000000000000014A4@0A0?ooo`@0000000<0k^k^0?ooo`3oool01`3oool01@20P800000000000000
0000XZ:R00X0oooo0`0000000`14A4@0oooo0?ooo`030?ooo`0504A4A000000000000000001VIVH0
2P3oool00`3^k^h0moOg0?ooo`0B0?ooo`0507MgM`00000000000000001NGUh00P0000000`0A4A40
oooo0?ooo`050?ooo`050:ZZZP000000000003<c<`28R8P00P0000000`1VIVH0oooo0?ooo`050?oo
o`030;^k^`00000000000080000000<0^k^k0?ooo`3oool01P3oool01@1NGUh00000000000000000
GUiN00L0oooo0`0000000`14A4@0oooo0?ooo`090?ooo`0404A4A00000000000000000H0oooo00H0
R8R80000000000000000014A4@3<c<`70?ooo`030<c<c0000000000000<0000000<0XZ:R0?ooo`3o
ool04@3oool4000000030?Ogm`3oool0oooo00H0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0
000000<0A4A40?ooo`3oool00`3oool00`28R8P0000000000002000000030<c<c03oool0oooo00L0
oooo00<0moOg0>k^kP3oool01@3oool01@20P8000000000000000000XZ:R00X0oooo00<0R8R80000
000000000P0000000`3Vi^H0oooo0?ooo`070?ooo`80k^k^4@3oool01014A4@0000000000000000>
0?ooo`0506m_K`00000000000000002ATI403@3oool01@0c<c<00000000000000000ZZZZ00L0oooo
00<0^k^k0000000000000P0000000`14A4@0oooo0?ooo`0>0?ooo`030<c<c0000000000000800000
00<0<c<c0>k^kP3oool0103oool00`3^k^h0<c<c000000040000000304A4A03oool0oooo00<0oooo
0`0000000`0R8R80oooo0?ooo`090?ooo`030=gMg@00000000000080000000<0^k^k0?ooo`3oool0
1P3oool00`2k^k/0000000000002000000030;^k^`3oool0oooo00D0oooo00P0k^k^000000000000
00000:ZZZP092@T00000014A4@L0oooo00D0ZZZZ000000000000<c<c08R8R0020000000306IVIP3o
ool0oooo00L0oooo00@0A4A400000000000000001`3oool30000000304A4A03oool0oooo00P0oooo
00D0P82000000000000000000::RXP040?ooo`0309VIV@00000000000080000000<0<c<c0>k^kP3o
ool0103oool00`3MgMd0<c<c00000004000000030::RXP3oool0oooo00l0oooo0`0000000`14A4@0
oooo0?ooo`080?ooo`0501XJ6P00000000000000003EeMD01`3oool01@1NGUh00000000000000000
8R8R00L0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool0103oool0
1P1=CDd000000000000000006QXJ0>k^kPH0oooo00<0R8R80000000000000`0000000`14A4@0oooo
0?ooo`030?ooo`0504A4A000000000000000001VIVH02P3oool00`3^k^h0moOg0?ooo`0?0?ooo`03
0;^k^`00000000000080000000<0^k^k0?ooo`3oool01P3oool00`2k^k/000000000000200000003
0=gMg@3oool0oooo00D0oooo00D0P82000000000000000000::RXP0D0?ooo`0508R8R00000000000
00000014A4@01`3oool00`3^k^h04A4A000000030000000304A4A03oool0oooo00X0oooo00D0Kfm_
0000000000000000096AT@030?ooo`030<C4a000000000000080000000<0c<c<0?ooo`3oool01`3o
ool00`3gmoL0k^k^0?ooo`0<0?ooo`050=gMg@00000000000000000R8R803`3oool01014A4@00000
0000000000070?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000000000000000XZ:R
00l0oooo00D06QXJ00000000000000000=GEe@070?ooo`0505iNGP00000000000000000R8R801`3o
ool0100R8R8000000000000000070?ooo`0404A4A00000000000000001D0oooo0`0000000`14A4@0
oooo0?ooo`060?ooo`050::RXP000000000000000020P8001P3oool00`28R8P00000000000020000
00030>KViP3oool0oooo00L0oooo0P3^k^h60?ooo`0404A4A00000000000000000H0oooo00H0a<C4
000000000000000000T92@3<c<`70?ooo`030<c<c0000000000000<0000000<0A4A40?ooo`3oool0
2P3oool01@1_Kfl00000000000000000TI6A0<`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0
oooo00@0jNWY0=7Ad@3AdM40inOW9@3oool01P3Vi^H04A4A0000000000004A4A0>k^kPd0oooo00H0
^k^k000000000000000001XJ6P3MgMd30?ooo`030>k^kP0A4A4000000080000000<0eMGE0?ooo`3o
ool02`3oool30000000304A4A03oool0oooo00P0oooo00H0moOg028R8P000000000000D51@2c/k<:
0?ooo`0505iNGP00000000000000002=SHd02`3oool00`3^k^h0000000000002000000/0oooo00<0
k^k^0000000000000P00000A0?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P80000000000
00000000XZ:R00X0oooo0`0000000`14A4@0oooo0?ooo`020?ooo`060=gMg@051@D000000000000A
4A40h^;R7`3oool01@10@40000000000000[:b/0a<C400<0000000<0c<c<0?ooo`3oool0103oool0
2@0l?3`000000000002ZZZX0k^k^00d=3@0000002@T90=GEe@050?ooo`060>k^kP0R8R8000000000
00092@T0/k>c2@3oool01P3IfMT02@T90000000000005QHF0>k^kPH0oooo0`0000000`14A4@0oooo
0?ooo`090?ooo`0404A4A00000000000000000D0oooo00H0k^k^00T92@000000000000D51@2k^k/9
0?ooo`030;^k^`051@D000000080000000<0XZ:R0?ooo`3oool04@3oool30000000304A4A03oool0
oooo00L0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool00P3oool0
1P3^k^h02@T90000000000002@T90<C4a180oooo00D0P82000000000000000000::RXP090?ooo`06
0=gMg@092@T000000000000A4A40a<C47@3oool01014A4@0000000000000000>0?ooo`0506m_K`00
0000000000000020P8003@3oool4000000T0oooo00D0R8R8000000000000000004A4A00@0?ooo`06
07alO000000000000000000h>3P0moOg1`3oool00`3gmoL0IVIV000000030000000304A4A03oool0
oooo00<0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`0508R8R000000000000000001NGUh02P3o
ool01P2c/k<01@D5000000000000:b/[0?Ogm`H0oooo00H0P820000000000000:b/[0?ooo`14A4@2
0000000309VIV@3oool0oooo00@0oooo00T0?3`l000000000000ZZZZ0>k^kP0J6QX0000000T92@3E
eMD0203oool01014A4@000000000000000070?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20
P8000000000000000000XZ:R00<0oooo00<0lo?c014A4@0000000P0000000`1_Kfl0moOg0?ooo`06
0?ooo`030?Ogm`1VIVH0000000<0000000<0XZ:R0?ooo`3oool03`3oool30000000304A4A03oool0
oooo00P0oooo100000080?ooo`050<C4a000000000000000000R8R801`3oool30000000304A4A03o
ool0oooo00P0oooo0`0000000`14A4@0oooo0?ooo`030?ooo`030>KViP092@T000000080000000<0
/k>c0?ooo`3oool01@3oool00`3kno/0IVIV000000030000000304A4A03oool0oooo0080oooo00H0
gMgM00D51@0000000000014A4@3Rh^8K0?ooo`060?Ogm`0R8R800000000000051@D0/k>c2P3oool0
1@1NGUh00000000000000000SHf=00L0oooo00D0P82000000000000000000::RXP0D0?ooo`0505EE
E@00000000000000002k^k/0203oool00`34a<@02@T9000000020000000304A4A03oool0oooo00X0
oooo00D0Kfm_00000000000000000820P0030?ooo`0507=cL`000000000000T92@34a<@06@3oool0
0`3MgMd0000000000002000000l0oooo00@0A4A400000000000000001`3oool30000000304A4A03o
ool0oooo00P0oooo00D0P82000000000000000000::RXP0?0?ooo`@00000203oool01@34a<@00000
0000000000008R8R00L0oooo00@08R8R00000000000000001`3oool01014A4@0000000000000000E
0?ooo`<0000000<0A4A40?ooo`3oool01P3oool01@2RXZ800000000000000000P82000D0oooo00H0
gMgM00T92@0000000000014A4@34a<@B0?ooo`0404A4A00000000000000000H0oooo00D0Lg=c0000
000000000000069RHP090?ooo`030;^k^`092@T000000080000000<0A4A40?ooo`3oool02P3oool0
1@1_Kfl00000000000000000P8200<`0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0
jNWY0=7Ad@3AdM40inOW9P3oool01@1=CDd00000000000000000/k>c00d0oooo00D08R8R00000000
0000000009VIV@040?ooo`0508R8R000000000000000001VIVH03P3oool30000000304A4A03oool0
oooo00P0oooo00D0a<C4000000000000000003<c<`0;0?ooo`050;>c/`000000000000000014A4@0
2`3oool01@2ATI4000000000000000006QXJ00/0oooo00D0TI6A000000000000000001XJ6P0A0?oo
o`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000000000000000XZ:R00X0oooo0`000000
0`14A4@0oooo0?ooo`020?ooo`0508R8R0000000000000000028R8P0803oool01@092@T000000000
0028R8P0moOg00<0000000<0TI6A0?ooo`3oool00`3oool0102ZZZX000000000000R8R820?ooo`04
03`l?0000000000006IVIPD0oooo00D0R8R8000000000000000006IVIP0;0?ooo`0506IVIP000000
000000000028R8P01P3oool30000000304A4A03oool0oooo00T0oooo00@0A4A40000000000000000
1@3oool01@34a<@00000000000000000<c<c00/0oooo00D0<c<c00000000000000000::RXP0C0?oo
o`<0000000<0A4A40?ooo`3oool01`3oool300000003028R8P3oool0oooo00T0oooo0`0000000`14
A4@0oooo0?ooo`020?ooo`050<C4a0000000000000000014A4@04`3oool01@20P800000000000000
0000XZ:R00T0oooo00D0R8R8000000000000000008R8R00N0?ooo`0404A4A00000000000000000d0
oooo00<0k^k^01XJ6P0000000P0000000`2IVIT0oooo0?ooo`0;0?ooo`05028R8P00000000000000
002ZZZX0203oool01@3^k^h00000000000000000A4A40100oooo00D0A4A4000000000000000009VI
V@0:0?ooo`0504A4A0000000000000000014A4@01@3oool300000003028R8P3oool0oooo00T0oooo
00D0A4A400000000000000000;>c/`0;0?ooo`0503<c<`000000000000000034a<@01P3oool01P0A
4A40000000000028R8P0oooo07MgM`80000000<08R8R0?ooo`3oool00`3oool0102ZZZX000000000
000A4A420?ooo`0407MgM`000000000006IVIPP0oooo00@0A4A400000000000000001`3oool30000
000304A4A03oool0oooo00P0oooo00D0P82000000000000000000::RXP030?ooo`050<C4a0000000
00000000000J6QX02`3oool01@0R8R800000000000000000XZ:R0140oooo0`0000000`14A4@0oooo
0?ooo`080?ooo`05014A4@00000000000000003EeMD01`3oool01@3gmoL000000000000000008R8R
00L0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool00`3oool01@28
R8P00000000000000000<c<c00X0oooo00D0A4A4000000000000000004A4A0040?ooo`0508R8R000
0000000000000028R8P0703oool01@34a<@00000000000000000<c<c00/0oooo00D0/k>c00000000
0000000004A4A0070?ooo`050820P000000000000000002RXZ80503oool0100A4A40000000000000
000:0?ooo`0506IVIP000000000000000014A4@02`3oool00`3^k^h06QXJ000000020000000509VI
V@3oool0oooo0?ooo`14A4@00P0000000`14A4@0oooo0?ooo`0G0?ooo`030>k^kP0c<c<000000080
000000<0<c<c0?ooo`3oool03@3oool01014A4@000000000000000070?ooo`<0000000<0A4A40?oo
o`3oool0203oool01@20P8000000000000000000XZ:R00l0oooo00D04A4A00000000000000000=GE
e@070?ooo`050?Ogm`00000000000000000R8R801`3oool0100R8R8000000000000000070?ooo`04
04A4A00000000000000001D0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`050::RXP0000000000
00000020P8001@3oool01@28R8P00000000000000000R8R801<0oooo00@0A4A40000000000000000
1P3oool01@14A4@00000000000000000/k>c00X0oooo00D0IVIV000000000000000004A4A00;0?oo
o`030>k^kP0J6QX000000080000000<0VIVI0?ooo`3oool0bP3oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinLV0?ooo`03096AT@00000000000180000000<04A4A
0?ooo`3oool00`3oool01@1EEED00000000000000000VIVI00h0oooo0`0000000`14A4@0oooo0?oo
o`080?ooo`050:ZZZP00000000000000001=CDd02`3oool01@3<c<`00000000000000000:b/[00X0
oooo00<0^k^k01XJ6P0000000P0000000`0l?3`0oooo0?ooo`080?ooo`030;^k^`0J6QX000000080
000000<0?3`l0?ooo`3oool03`3oool30000000304A4A03oool0oooo00P0oooo00D0P82000000000
000000000::RXP0:0?ooo`<0000000<0A4A40?ooo`3oool00P3oool01@14A4@00000000000000000
^k^k01l0oooo00L0ZZZZ00000000000000000=gMg@3oool0EEEE0080000000<0IVIV0?ooo`3oool0
0`3oool0101VIVH000000000001gMgL20?ooo`0406IVIP0000000000014A4@D0oooo00D0EEEE0000
00000000000009VIV@0;0?ooo`0509VIV@00000000000000001EEED01P3oool30000000304A4A03o
ool0oooo00T0oooo00@0A4A400000000000000001@3oool01@2RXZ800000000000000000EEEE00/0
oooo00D0EEEE00000000000000000::RXP0C0?ooo`<0000000<0A4A40?ooo`3oool01`3oool30000
0003028R8P3oool0oooo00T0oooo0`0000000`14A4@0oooo0?ooo`020?ooo`050::RXP0000000000
0000001NGUh04`3oool01@20P8000000000000000000XZ:R00T0oooo00D0A4A40000000000000000
0;^k^`0N0?ooo`0404A4A00000000000000000`0oooo00<0^k^k03<c<`0000000`0000000`2k^k/0
oooo0?ooo`0;0?ooo`0606IVIP00000000000000000c<c<0k^k^203oool30000000304A4A03oool0
oooo00h0oooo00D08R8R00000000000000000<C4a00:0?ooo`0508R8R0000000000000000014A4@0
1@3oool300000003028R8P3oool0oooo00T0oooo00D0:b/[00000000000000000<c<c00;0?ooo`05
04e=C@00000000000000002ZZZX01@3oool01`2ZZZX00000000000000000gMgM0?ooo`2ZZZX00`00
00000`3Vi^H0oooo0?ooo`020?ooo`0406IVIP000000000003`l?080oooo00@0c<c<000000000000
4A4A203oool01014A4@000000000000000070?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20
P8000000000000000000XZ:R00<0oooo00D0XZ:R000000000000000004A4A00;0?ooo`0504A4A000
000000000000002RXZ804@3oool30000000304A4A03oool0oooo00P0oooo00D0<c<c000000000000
0000096AT@080?ooo`<0000000<08R8R0?ooo`3oool01@3oool30000000304A4A03oool0oooo00P0
oooo0`0000000`14A4@0oooo0?ooo`030?ooo`0504A4A0000000000000000028R8P02P3oool01@28
R8P00000000000000000A4A400@0oooo00D0A4A400000000000000000;^k^`0L0?ooo`050:ZZZP00
000000000000001=CDd02`3oool01@3<c<`00000000000000000:b/[00L0oooo00D0P82000000000
000000000::RXP0D0?ooo`<0000000<08R8R0?ooo`3oool0203oool01@2IVIT00000000000000000
A4A400X0oooo00<0^k^k03<c<`0000000`0000001@2k^k/0oooo0?ooo`3oool08R8R0080000000<0
GUiN0?ooo`3oool05P3oool00`2k^k/0<c<c000000030000000307MgM`3oool0oooo00d0oooo00@0
A4A400000000000000001`3oool30000000304A4A03oool0oooo00P0oooo00D0P820000000000000
00000::RXP0?0?ooo`0503<c<`00000000000000002ATI40203oool300000003028R8P3oool0oooo
00D0oooo00@08R8R00000000000000001`3oool01014A4@0000000000000000E0?ooo`<0000000<0
A4A40?ooo`3oool01P3oool01@2RXZ800000000000000000P82000D0oooo00D0A4A4000000000000
00000;^k^`0C0?ooo`0404A4A00000000000000000H0oooo00D08R8R00000000000000000=GEe@0:
0?ooo`050:ZZZP000000000000000014A4@02P3oool00`2k^k/0<c<c00000003000000030;^k^`3o
ool0oooo0<X0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
9P3oool00`34a<@000000000000B0000000307MgM`3oool0oooo00<0oooo00D0<c<c000000000000
00000<c<c00>0?ooo`<0000000<0A4A40?ooo`3oool0203oool01@2IVIT00000000000000000Kfm_
00/0oooo00D0i^KV000000000000000001XJ6P080?ooo`030=gMg@1VIVH0000000@0000000<0MgMg
0?ooo`3oool01P3oool00`3MgMd0IVIV000000040000000307MgM`3oool0oooo00l0oooo0`000000
0`14A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ802P3oool30000000304A4A03o
ool0oooo0080oooo00@0<c<c0000000000000000803oool0101VIVH000000000000R8R820?ooo`04
09VIV@000000000004A4A0D0oooo00@08R8R000000000000^k^k0P3oool01@28R8P0000000000000
0000eMGE00@0oooo00D0<c<c00000000000000000=gMg@0;0?ooo`050<c<c000000000000000000c
<c<01P3oool30000000304A4A03oool0oooo00T0oooo00@0A4A400000000000000001@3oool01@2R
XZ800000000000000000Kfm_00/0oooo00D0Kfm_00000000000000000::RXP0C0?ooo`<0000000<0
A4A40?ooo`3oool01`3oool300000003028R8P3oool0oooo00T0oooo0`0000000`14A4@0oooo0?oo
o`020?ooo`0509VIV@000000000000000020P8004`3oool01@20P8000000000000000000XZ:R00T0
oooo00@0<c<c00000000000000007`3oool01014A4@0000000000000000:0?ooo`030>k^kP1VIVH0
000000@0000000<04A4A0>k^kP3oool0303oool00`2k^k/00000000000020000000303<c<`3MgMd0
oooo00H0oooo0`0000000`14A4@0oooo0?ooo`0>0?ooo`05014A4@00000000000000003MgMd02P3o
ool01@3<c<`00000000000000000A4A400D0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`0501XJ
6P00000000000000003^k^h02`3oool01@1VIVH00000000000000000VIVI00D0oooo00@0IVIV0000
000000008R8R0P3oool01@3<c<`00000000000000000a<C400@0oooo00@08R8R000000000000GUiN
0`3oool010092@T000000000002ZZZX70?ooo`0404A4A00000000000000000L0oooo0`0000000`14
A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ800`3oool01@2ATI40000000000000
0000GUiN00/0oooo00D0IVIV00000000000000000::RXP0A0?ooo`<0000000<0A4A40?ooo`3oool0
203oool01P1NGUh000000000000000006QXJ0;^k^`L0oooo0`0000000`0R8R80oooo0?ooo`050?oo
o`<0000000<0A4A40?ooo`3oool0203oool30000000304A4A03oool0oooo00<0oooo00D08R8R0000
0000000000000;^k^`0:0?ooo`050<c<c0000000000000000014A4@0103oool0100c<c<000000000
0000000M0?ooo`0509VIV@00000000000000001_Kfl02`3oool01@3Vi^H000000000000000006QXJ
00L0oooo00D0P82000000000000000000::RXP0D0?ooo`<0000000<08R8R0?ooo`3oool0203oool0
1@2k^k/00000000000000000A4A400P0oooo00<0k^k^06IVIP000000100000000`0A4A40k^k^0?oo
o`020?ooo`0401XJ6P00000000000820P1L0oooo00<0XZ:R0000000000000`0000000`0A4A40gMgM
0?ooo`0>0?ooo`0404A4A00000000000000000L0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`05
0820P000000000000000002RXZ803`3oool01P1NGUh000000000000000006QXJ0;^k^`L0oooo0`00
00000`0R8R80oooo0?ooo`050?ooo`04028R8P0000000000000000L0oooo00@0A4A4000000000000
00005@3oool30000000304A4A03oool0oooo00H0oooo00D0XZ:R00000000000000000820P0050?oo
o`0403<c<`0000000000000001@0oooo00@0A4A400000000000000001P3oool01@0R8R8000000000
00000000k^k^00X0oooo00D0gMgM000000000000000004A4A0080?ooo`030>k^kP1VIVH0000000@0
000000<04A4A0>k^kP3oool0b`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinLV0?ooo`030?_kn`0c<c<000000140000000<05QHF0>k^kP3oool0103oool40000
00l0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`050820P0000000000000000020P800303oool4
000000H0oooo00<0a<C4055AD@000000100000000`092@T0CDe=0>KViP060?ooo`030<C4a01ADE40
000000@0000000<02@T904e=C@3Vi^H04@3oool30000000304A4A03oool0oooo00P0oooo00D0P820
00000000000000000::RXP0:0?ooo`<0000000<0A4A40?ooo`3oool00P3oool4000000h0A4A44@3o
ool01@3EeMD02@T9000000000000TI6A0080oooo00D0moOg028R8P0000003@d=0>k^kP030?ooo`04
0::RXP000000000001hN7P<0oooo00D0`<3000000000000000000::RXP040?ooo`@000003@3oool4
000000H0oooo0`0000000`14A4@0oooo0?ooo`090?ooo`0404A4A00000000000000000D0oooo00D0
P82000000000000000000820P00;0?ooo`050820P000000000000000002RXZ804`3oool300000003
04A4A03oool0oooo00L0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3o
ool00P3oool01@20P80000000000000000008R8R00h0A4A41@3oool01@20P8000000000000000000
XZ:R00T0oooo1000000>04A4A0030::RXP3oool0oooo00h0oooo00@0A4A40000000000000000203o
ool00`34a<@0Kfm_01XJ6P040000000300T92@1=CDd0c<c<00l0oooo00<0^k^k01XJ6P0000000P00
0000100=3@d0A4A405iNGP1_Kfl40820P0<0000000<0A4A40?ooo`3oool03P3oool4000000`0oooo
0`0000000`14A4@0oooo0?ooo`030?ooo`<0000000<08R8R0?ooo`3oool02@3oool4000000`0oooo
00D0P82000000000000000000820P0040?ooo`050=GEe@092@T000000000002ATI400P3oool01@3k
no/08R8R000000000000Q8B400<0oooo00D0dM7A000000000000000009jNWP030?ooo`040410@000
0000000004A4A0L0oooo00@0A4A400000000000000001`3oool30000000304A4A03oool0oooo00P0
oooo00D0P82000000000000000000::RXP030?ooo`050820P0000000000000000020P8002`3oool0
1@20P8000000000000000000XZ:R0140oooo0`0000000`14A4@0oooo0?ooo`080?ooo`030=gMg@0c
<c<0000000<0000000<06QXJ04A4A01WIfL01020P80300000003028R8P3oool0oooo00D0oooo0`00
00000`14A4@0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool00`3oool4000000`0oooo0`00
00000`14A4@0oooo0?ooo`020?ooo`@000003P14A4@?0?ooo`050820P0000000000000000020P800
303oool4000000L0oooo00D0P82000000000000000000::RXP0D0?ooo`<0000000<08R8R0?ooo`3o
ool02@3oool30000000304A4A03oool0oooo00@0oooo00<0a<C406m_K`0J6QX0100000000`092@T0
CDe=0<c<c0040?ooo`<0000000<08R8R04A4A014A4@03014A4@60?ooo`030<C4a01_Kfl0<c<c00@0
000000<01@D504e=C@3<c<`0403oool01014A4@000000000000000070?ooo`<0000000<0A4A40?oo
o`3oool0203oool01@20P8000000000000000000XZ:R00l0oooo00<0gMgM03<c<`0000000`000000
0`0J6QX0A4A406MWI`040820P0<0000000<08R8R0?ooo`3oool01@3oool0100R8R80000000000000
00070?ooo`0404A4A00000000000000001D0oooo0`0000000`14A4@0oooo0?ooo`060?ooo`050::R
XP000000000000000020P8001@3oool4000000h0A4A400<0XZ:R0?ooo`3oool00`3oool01014A4@0
00000000000000060?ooo`@00000303oool30000000304A4A03oool0oooo00@0oooo00<0a<C406m_
K`0J6QX0100000000`092@T0CDe=0<c<c03=0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWibL0oooo00D0c<c<000000000000000006IVIP0:0?ooo`05096AT@00
000000000000001NGUh01P3oool4000000l0oooo0`0000000`0c<c<0oooo0?ooo`080?ooo`050820
P0000000000000000020P800303oool4000000@0oooo00<0k^k^03<c<`0000001@0000000`1VIVH0
gMgM0?ooo`050?ooo`030>k^kP0c<c<0000000D0000000<0IVIV0=gMg@3oool04P3oool300000003
04A4A03oool0oooo00P0oooo00D0P82000000000000000000::RXP0:0?ooo`<0000000<0A4A40?oo
o`3oool00P3ooolB00000140oooo00@0IVIV0000000000000000103oool01028R8P000000000002I
VIT30?ooo`04028R8P000000000005EEE@<0oooo00D0moOg000000000000000006IVIP040?ooo`@0
00003@3oool4000000H0oooo0`0000000`0c<c<0oooo0?ooo`090?ooo`0404A4A000000000000000
00D0oooo00D0P82000000000000000000820P00;0?ooo`050820P000000000000000002RXZ804`3o
ool30000000304A4A03oool0oooo00L0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0
A4A40?ooo`3oool00P3oool00`20P80000000000000@000000D0oooo00D0P8200000000000000000
09VIV@090?oooa80000000<0P8200?ooo`3oool03P3oool01014A4@000000000000000060?ooo`03
0?Ogm`0c<c<0000000D0000000<0<c<c0=gMg@3oool04@3oool00`3EeMD08R8R0000000<00000003
04A4A03oool0oooo00h0oooo1000000<0?ooo`<0000000<0A4A40?ooo`3oool00`3oool300000003
01XJ6P3oool0oooo00T0oooo1000000<0?ooo`050820P0000000000000000020P800103oool0101V
IVH000000000000000040?ooo`0408R8R0000000000004e=C@<0oooo00D0TI6A0000000000000000
0=GEe@030?ooo`0507MgM`00000000000000003Vi^H01P3oool01014A4@000000000000000070?oo
o`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000000000000000XZ:R00<0oooo00D0P820
00000000000000000820P00;0?ooo`050820P000000000000000002RXZ804@3oool30000000303<c
<`3oool0oooo00X0oooo00<0ZZZZ028R8P0000002`0000000`0R8R80oooo0?ooo`050?ooo`<00000
00<0A4A40?ooo`3oool0203oool30000000304A4A03oool0oooo00<0oooo1000000<0?ooo`<00000
00<0A4A40?ooo`3oool00P3ooolB000000l0oooo00D0P82000000000000000000820P00<0?ooo`@0
00001`3oool01@20P8000000000000000000XZ:R01@0oooo0`0000000`0R8R80oooo0?ooo`090?oo
o`<0000000<0A4A40?ooo`3oool00P3oool00`3gmoL0<c<c000000050000000303<c<`3MgMd0oooo
00D0oooo4P0000050?ooo`03096AT@000000000000D0000000<0XZ:R0?ooo`3oool0403oool01014
A4@000000000000000070?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P800000000000000
0000XZ:R0140oooo00<0ZZZZ028R8P0000002`0000000`0R8R80oooo0?ooo`050?ooo`04028R8P00
00000000000000L0oooo00@0A4A400000000000000005@3oool30000000304A4A03oool0oooo00H0
oooo00D0XZ:R00000000000000000820P0050?oooa80000000<0P8200?ooo`3oool00`3oool01014
A4@000000000000000060?ooo`@00000303oool30000000304A4A03oool0oooo0080oooo00<0moOg
03<c<`0000001@0000000`0c<c<0gMgM0?ooo`3>0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo0007
0?ooo`040>WYj@3AdM40dM7A0>OWibP0oooo00D0<c<c0000000000004A4A0>k^kP090?ooo`0505EE
E@00000000000000002ATI401P3oool01@0c<c<00000000000000000c<c<00h0oooo1000000:0?oo
o`0509VIV@00000000000000001VIVH02`3oool01@3Vi^H000000000000000006QXJ00@0oooo00<0
<c<c000000000000100000000`2RXZ80oooo0?ooo`060?ooo`0303<c<`000000000000@0000000<0
XZ:R0?ooo`3oool04`3oool30000000304A4A03oool0oooo00P0oooo00D0P8200000000000000000
08R8R00:0?ooo`<0000000<0A4A40?ooo`3oool00P3oool00`0A4A4000000000000>00000003028R
8P3oool0oooo00l0oooo00@04A4A000000000000EEEE103oool0103MgMd000000000001EEED20?oo
o`050>k^kP00000000000000001gMgL0103oool01014A4@000000000000l?3`40?ooo`0503<c<`00
000000000000003<c<`02`3oool01@3<c<`00000000000000000<c<c00H0oooo1000000;0?ooo`04
04A4A00000000000000000D0oooo00D0P820000000000000000007MgM`0;0?ooo`0506m_K`000000
00000000002RXZ804`3oool30000000304A4A03oool0oooo00L0oooo0`0000000`092@T0oooo0?oo
o`090?ooo`<0000000<0A4A40?ooo`3oool00P3oool00`28R8P000000000000?0000000304A4A03o
ool0oooo00<0oooo00D0P82000000000000000000820P0090?ooo`03014A4@000000000000l00000
00<0XZ:R0?ooo`3oool03P3oool01014A4@000000000000000060?ooo`0309VIV@000000000000@0
000000<0IVIV0>k^kP3oool0503oool00`2ZZZX0EEEE00T92@0:0000000304A4A03oool0oooo00h0
oooo00D06QXJ00000000000000000>k^kP0:0?ooo`050=gMg@000000000000000014A4@01@3oool4
000000/0oooo00D06QXJ00000000000000000>KViP0;0?ooo`0506IVIP00000000000000002IVIT0
103oool0100A4A4000000000000[:b/40?ooo`040=gMg@000000000002/[:`<0oooo00D0Kfm_0000
0000000000000?Ogm`030?ooo`050::RXP00000000000000002k^k/01P3oool01014A4@000000000
000000070?ooo`@000002P3oool01@20P8000000000000000000XZ:R00<0oooo00D0VIVI00000000
0000000006m_K`0;0?ooo`0506m_K`00000000000000002RXZ804@3oool4000000h0oooo00<0P820
014A4@0000002@0000000`0R8R80oooo0?ooo`050?ooo`@000002P3oool30000000304A4A03oool0
oooo00<0oooo00D0<c<c00000000000000000=gMg@0:0?ooo`050=gMg@000000000000000014A4@0
103oool00`0A4A4000000000000>00000003028R8P3oool0oooo00d0oooo00D0VIVI000000000000
000006IVIP0;0?ooo`050>KViP00000000000000000J6QX01`3oool01@20P8000000000000000000
XZ:R01@0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool00P3oool0
0`2IVIT00000000000040000000306IVIP3^k^h0oooo00H0oooo00<02@T90000000000003P000000
0`14A4@0oooo0?ooo`030?ooo`0301XJ6P000000000000<0000000<0IVIV0=gMg@3oool04P3oool0
1014A4@000000000000000070?ooo`@000002P3oool01@20P8000000000000000000XZ:R01<0oooo
00<0P820014A4@0000002@0000000`0R8R80oooo0?ooo`050?ooo`04028R8P0000000000000000L0
oooo00@0A4A400000000000000005@3oool30000000304A4A03oool0oooo00H0oooo00D0XZ:R0000
0000000000000820P0050?ooo`03014A4@000000000000l0000000<0XZ:R0?ooo`3oool00`3oool0
1014A4@000000000000000060?ooo`@0000000<0moOg0?ooo`3oool0203oool01@3MgMd000000000
00000000A4A400@0oooo00<0VIVI000000000000100000000`1VIVH0k^k^0?ooo`3?0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWibP0oooo00D0VIVI00000000
0000000009VIV@090?ooo`05028R8P00000000000000003<c<`01P3oool01@14A4@0000000000000
0000VIVI00h0oooo100000000`3<c<`0oooo0?ooo`070?ooo`050::RXP00000000000000001=CDd0
2`3oool01@3<c<`000000000000000008R8R00<0oooo00<0c<c<0000000000000`0000000`1VIVH0
gMgM0?ooo`070?ooo`030<c<c0000000000000<0000000<0IVIV0=gMg@3oool05@3oool300000003
04A4A03oool0oooo00P0oooo00D0P820000000000000000007MgM`0:0?ooo`<0000000<0A4A40?oo
o`3oool00P3oool01@14A4@00000000000000000k^k^00T0oooo0`0000000`0R8R80oooo0?ooo`0>
0?ooo`050:ZZZP000000000000000028R8P01@3oool01P0c<c<000000000003^k^h0oooo0<C4a0<0
000000<0ZZZZ0?ooo`3oool00P3oool01028R8P000000000000A4A440?ooo`0504A4A00000000000
0000002IVIT02`3oool01@2IVIT00000000000000000A4A400H0oooo100000000`3Vi^H0oooo0?oo
o`080?ooo`0404A4A00000000000000000D0oooo00D0XZ:R000000000000000005iNGP0;0?ooo`05
05EEE@00000000000000002RXZ804`3oool30000000304A4A03oool0oooo00L0oooo100000000`3^
k^h0oooo0?ooo`080?ooo`<0000000<0A4A40?ooo`3oool00P3oool01@2RXZ800000000000000000
MgMg00X0oooo0`0000000`14A4@0oooo0?ooo`030?ooo`050820P000000000000000001VIVH02@3o
ool01@14A4@00000000000000000k^k^00T0oooo00D0P82000000000000000000::RXP0@0?ooo`04
04A4A00000000000000000H0oooo00<0CDe=0000000000000P0000000`1VIVH0gMgM0?ooo`0H0?oo
o`030>KViP2k^k/0R8R800D0R8R80`0000000`14A4@0oooo0?ooo`0>0?ooo`05028R8P0000000000
0000003EeMD02P3oool01@2ZZZX00000000000000000A4A400D0oooo100000000`3<c<`0oooo0?oo
o`080?ooo`05028R8P00000000000000003<c<`02`3oool01@1=CDd00000000000000000XZ:R00<0
oooo00D0eMGE000000000000000004A4A0050?ooo`0403<c<`00000000000>k^kP80oooo00@0A4A4
000000000000EEEE103oool01@34a<@00000000000000000TI6A00H0oooo00@0A4A4000000000000
00001`3oool4000000030=gMg@3oool0oooo00L0oooo00D0P82000000000000000000::RXP030?oo
o`050::RXP00000000000000001EEED02`3oool01@1EEED00000000000000000XZ:R0140oooo1000
00000`3<c<`0oooo0?ooo`0=0?ooo`030<c<c02k^k/0R8R800@0R8R80`0000000`0R8R80oooo0?oo
o`050?ooo`@0000000<0k^k^0?ooo`3oool01`3oool30000000304A4A03oool0oooo00<0oooo00D0
A4A400000000000000000:ZZZP0:0?ooo`050:ZZZP000000000000000014A4@0103oool01@14A4@0
0000000000000000k^k^00T0oooo0`0000000`0R8R80oooo0?ooo`0=0?ooo`050::RXP0000000000
0000001=CDd02`3oool01@3<c<`000000000000000008R8R00L0oooo00D0P8200000000000000000
0::RXP0D0?ooo`<0000000<08R8R0?ooo`3oool02@3oool30000000304A4A03oool0oooo0080oooo
00<0CDe=0000000000000P0000000`1VIVH0gMgM0?ooo`080?ooo`04028R8P000000000007MgM`X0
oooo0`0000000`14A4@0oooo0?ooo`020?ooo`0309VIV@00000000000080000000<0<c<c0=gMg@3o
ool0503oool01014A4@000000000000000070?ooo`@0000000<0gMgM0?ooo`3oool01`3oool01@20
P8000000000000000000XZ:R01D0oooo00<0c<c<0;^k^`28R8P01028R8P300000003028R8P3oool0
oooo00D0oooo00@08R8R00000000000000001`3oool01014A4@0000000000000000E0?ooo`<00000
00<0A4A40?ooo`3oool01P3oool01@2RXZ800000000000000000P82000D0oooo00D0A4A400000000
000000000>k^kP090?ooo`050820P000000000000000002RXZ801@3oool01014A4@0000000000000
00060?ooo`05028R8P00000000000000003MgMd02P3oool01@2ZZZX00000000000000000A4A400@0
oooo00<0CDe=0000000000000P0000000`1VIVH0gMgM0?ooo`3A0?ooo`040>WYj@3AdM40dM7A0=cL
g0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWibT0oooo00D0CDe=0000000000006QXJ0>k^kP07
0?ooo`060::RXP00000000000000000l?3`0no_k1P3oool01P2ZZZX00000000000000000:b/[0?Og
m`d0oooo100000000`1NGUh0oooo0?ooo`070?ooo`060=GEe@00000000000000000F5QH0k^k^2P3o
ool01@2=SHd00000000000000000EEEE00<0oooo00H0TI6A000000000000000002LW9`3EeMD:0?oo
o`06096AT@00000000000000000W9bL0eMGE603oool30000000304A4A03oool0oooo00P0oooo00D0
P820000000000000000003`l?0090?ooo`050:ZZZP00000000000000001_Kfl0103oool01@20P800
0000000000000000VIVI00P0oooo00D0h^;R000000000000000004A4A00@0?ooo`0503`l?0000000
000000T92@3Vi^H01@3oool01P2ZZZX0000000000028R8P0oooo08B4Q0<0000000<0h^;R0?ooo`3o
ool00P3oool01@3^k^h04A4A000000000000XZ:R00<0oooo00H0ZZZZ000000000000000002/[:`3^
k^h90?ooo`030?Ogm`0[:b/000000080000000<0ZZZZ0?ooo`3oool0103oool4000000030:n_[`3o
ool0oooo00P0oooo00@0A4A400000000000000001@3oool01@2g]kL00000000000000000;bl_00X0
oooo00<0moOg01hN7P0000000P0000000`2RXZ80oooo0?ooo`0A0?ooo`<0000000<0A4A40?ooo`3o
ool01`3oool40000000307MgM`3oool0oooo00L0oooo00D0ZZZZ000000000000000006m_K`040?oo
o`050<30`000000000000000001=CDd02@3oool01@34a<@00000000000000000R8R800D0oooo00D0
P820000000000000000002l_;`090?ooo`050820P000000000000000002IVIT02@3oool01@1RHV80
0000000000000000a<C40100oooo00@0A4A400000000000000001P3oool01@0A4A40000000000000
0000TI6A0280oooo00D0k^k^000000000000000005EEE@0@0?ooo`0505EEE@00000000000000002J
VYX02P3oool01@14A4@00000000000000000A4A400D0oooo100000000`1NGUh0oooo0?ooo`080?oo
o`0505EEE@00000000000000002=SHd02P3oool00`3^k^h05QHF00000002000000050=GEe@3oool0
oooo0?ooo`2NWYh00`0000000`1lO7`0oooo0?ooo`030?ooo`070:ZZZP000000000008R8R03oool0
k^k^00d=3@02000000030<C4a03oool0oooo0080oooo00D0moOg014A4@0000000000055AD@060?oo
o`0404A4A00000000000000000L0oooo100000000`1gMgL0oooo0?ooo`070?ooo`0505EEE@000000
00000000002g]kL00`3oool01P3EeMD000000000000000007QhN0?Ogm`X0oooo00D08R8R00000000
000000000::RXP0A0?ooo`@0000000<0GUiN0?ooo`3oool04`3oool01@3gmoL00000000000000000
:b/[00L0oooo100000000`2k^k/0oooo0?ooo`060?ooo`050:ZZZP00000000000000001_Kfl01@3o
ool01P2ZZZX00000000000000000?3`l0?_kn`T0oooo00D0A4A4000000000000000004A4A0040?oo
o`050820P000000000000000002IVIT0203oool01@3Rh^800000000000000000A4A400l0oooo00H0
eMGE000000000000000001HF5P3^k^h:0?ooo`0508f=S@00000000000000001EEED01`3oool01@20
P8000000000000000000XZ:R01@0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A4
0?ooo`3oool00P3oool01@0A4A400000000000000000TI6A00/0oooo00@0@410000000000000CDe=
2@3oool01@34a<@00000000000000000R8R800@0oooo00H08R8R000000000000000004e=C@3Zj^XF
0?ooo`0404A4A00000000000000000L0oooo100000000`1gMgL0oooo0?ooo`070?ooo`0505EEE@00
000000000000002g]kL06`3oool01@3gmoL00000000000000000:b/[00L0oooo00@08R8R00000000
000000001`3oool01014A4@0000000000000000E0?ooo`<0000000<0A4A40?ooo`3oool01P3oool0
1@2RXZ800000000000000000P82000D0oooo00D0P820000000000000000009VIV@090?ooo`05069R
HP000000000000000034a<@01@3oool01014A4@000000000000000060?ooo`0503Ph>00000000000
0000002_[jl02@3oool00`3gmoL0?3`l000000020000000304A4A03oool0oooo0080oooo00D04A4A
0000000000000000096AT@3D0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3A
dM40dM7A0>OWibT0oooo00D0gMgM000000000000000007MgM`060?ooo`030>k^kP0A4A4000000080
000000<0gMgM0?ooo`3oool01P3oool01@0J6QX00000000000000000ZZZZ00d0oooo1@0000000`2k
^k/0oooo0?ooo`070?ooo`0503<c<`00000000000000001EEED02P3oool01@0[:b/0000000000000
0000VIVI00<0oooo00D0P82000000000000000000820P00;0?ooo`050820P0000000000000000020
P8006@3oool30000000304A4A03oool0oooo00P0oooo00<0P8200000000000000P0000000`3MgMd0
oooo0?ooo`060?ooo`0506IVIP00000000000000002IVIT0103oool01P3^k^h00000000000000000
4A4A0?Ogm`L0oooo00D0ZZZZ000000000000000006m_K`0?0?ooo`050=GEe@00000000000000000c
<c<01`3oool01@0A4A400000014A4@3oool0A4A40080000000<0<c<c0?ooo`3oool0103oool0101g
MgL000000000000R8R840?ooo`0503<c<`00000000000000001EEED02@3oool01@2ZZZX000000000
000000006QXJ00L0oooo100000000`1NGUh0oooo0?ooo`080?ooo`0404A4A00000000000000000D0
oooo00<0k^k^0000000000000P0000000`2k^k/0oooo0?ooo`070?ooo`0308R8R000000000000080
000000<0XZ:R0?ooo`3oool04@3oool30000000304A4A03oool0oooo00L0oooo1@0000000`3MgMd0
oooo0?ooo`060?ooo`0506IVIP00000000000000002IVIT0103oool01P3gmoL00000000000000000
2@T90>k^kPP0oooo00D0EEEE00000000000000000=gMg@050?ooo`030820P0000000000000800000
00<0^k^k0?ooo`3oool01P3oool01P3^k^h000000000000000004A4A0>k^kPP0oooo00D0:b/[0000
0000000000000>k^kP0@0?ooo`0404A4A00000000000000000H0oooo1000000S0?ooo`050:ZZZP00
0000000000000028R8P0403oool01@2ATI400000000000000000A4A400T0oooo00<0R8R800000000
00000P0000000`14A4@0oooo0?ooo`030?ooo`D0000000<0^k^k0?ooo`3oool01`3oool01@2IVIT0
0000000000000000:b/[00X0oooo00D0EEEE000000000000000003<c<`040?ooo`0505EEE@000000
00000000002c/k<01P3oool01@0R8R800000014A4@3oool0R8R80080000000<0<c<c0?ooo`3oool0
103oool0101gMgL000000000000A4A460?ooo`0404A4A00000000000000000L0oooo1@0000000`3<
c<`0oooo0?ooo`060?ooo`0503<c<`00000000000000003<c<`0103oool01@0R8R80000000000000
0000R8R800T0oooo00<0R8R80000000000000P0000000`2RXZ80oooo0?ooo`0?0?ooo`D0000000<0
^k^k0?ooo`3oool04P3oool01@3EeMD00000000000000000A4A400L0oooo100000000`1VIVH0oooo
0?ooo`060?ooo`0506IVIP00000000000000002IVIT01P3oool01@0A4A400000000000000000a<C4
00P0oooo00<0R8R80000000000000P0000000`14A4@0oooo0?ooo`020?ooo`060>k^kP0000000000
0000000A4A40moOg1`3oool01@2ZZZX00000000000000000Kfm_0100oooo00D0<c<c000000000000
000005EEE@0:0?ooo`0502/[:`00000000000000002IVIT01`3oool01@20P8000000000000000000
XZ:R01@0oooo0`0000000`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool00P3oool4
000000`0oooo00D0MgMg0000000000002@T90>k^kP080?ooo`0505EEE@00000000000000003MgMd0
103oool4000001P0oooo00@0A4A400000000000000001`3oool5000000030<c<c03oool0oooo00H0
oooo00D0<c<c00000000000000000<c<c00K0?ooo`050=GEe@000000000000000014A4@01`3oool0
100R8R8000000000000000070?ooo`0404A4A00000000000000001D0oooo0`0000000`14A4@0oooo
0?ooo`060?ooo`050::RXP000000000000000020P8001@3oool01P3^k^h000000000000000004A4A
0>k^kPP0oooo00D0:b/[00000000000000000>k^kP050?ooo`0404A4A00000000000000000H0oooo
00D0Kfm_000000000000000005iNGP090?ooo`0308R8R000000000000080000000<0A4A40?ooo`3o
ool00P3oool400000=D0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOW:P3oool0100c<c<000000000000R8R860?ooo`0508R8R0000000000000000014A4@02@3o
ool01@1=CDd00000000000000000CDe=00d0oooo1@0000000`0c<c<0moOg0?ooo`070?ooo`0309VI
V@00000000000080000000<0VIVI0?ooo`3oool01P3oool00`2IVIT0000000000002000000050<c<
c03oool0oooo0?ooo`2ATI400`0000000`20P800oooo0?ooo`090?ooo`05096AT@00000000000000
0020P8006@3oool30000000304A4A03oool0oooo00P0oooo00<0P8200000000000000P0000000`14
A4@0oooo0?ooo`050?ooo`030>k^kP0A4A4000000080000000<0c<c<0?ooo`3oool00`3oool01@0c
<c<00000000000000000^k^k00L0oooo00D0GUiN00000000000000000::RXP0?0?ooo`050;>c/`00
000000000000001EEED01`3oool01@0l?3`000000000002k^k/0:b/[0080000000<0R8R80?ooo`3o
ool0103oool01@2k^k/00000000000000000c<c<00<0oooo00<0VIVI0000000000000P0000000`2I
VIT0oooo0?ooo`060?ooo`0504e=C@00000000000000001=CDd01`3oool40000000301XJ6P3^k^h0
oooo00P0oooo00@0A4A400000000000000001P3oool01P14A4@00000000000000000<c<c0>k^kPL0
oooo00<0c<c<0000000000000`0000000`2RXZ80oooo0?ooo`0A0?ooo`<0000000<0A4A40?ooo`3o
ool01`3oool50000000304A4A03oool0oooo00D0oooo00<0k^k^014A4@0000000P0000000`3<c<`0
oooo0?ooo`030?ooo`0506IVIP00000000000000001gMgL01`3oool01@2k^k/00000000000000000
A4A400H0oooo00<0P8200000000000000P0000000`0c<c<0k^k^0?ooo`070?ooo`0506IVIP000000
00000000001gMgL01`3oool01@2k^k/00000000000000000A4A40140oooo00@0A4A4000000000000
00001P3oool0100A4A40000000000000000S0?ooo`0506IVIP00000000000000002ZZZX0403oool0
1P34a<@000000000000000002@T90<c<c0L0oooo00<0c<c<014A4@0000000`0000000`14A4@0oooo
0?ooo`030?ooo`D0000000<0<c<c0>k^kP3oool01`3oool00`3<c<`00000000000020000000309VI
V@3oool0oooo00H0oooo00<0VIVI0000000000000P0000000`2IVIT0oooo0?ooo`020?ooo`0503<c
<`00000000000000003EeMD01P3oool01@1gMgL000000000002k^k/0EEEE0080000000<0R8R80?oo
o`3oool0103oool01@2k^k/00000000000000000c<c<00D0oooo00@0A4A400000000000000001`3o
ool50000000304A4A03oool0oooo00D0oooo00<0k^k^00T92@0000000P0000000`3Vi^H0oooo0?oo
o`020?ooo`0608R8R000000000000000000A4A40c<c<1`3oool00`3<c<`04A4A0000000300000003
0::RXP3oool0oooo00l0oooo1@0000000`0c<c<0moOg0?ooo`0B0?ooo`050;>c/`00000000000000
001EEED01`3oool400000003028R8P3oool0oooo00D0oooo00<0moOg014A4@0000000P0000000`3<
c<`0oooo0?ooo`040?ooo`0504A4A000000000000000001_Kfl01`3oool00`3Vi^H04A4A00000003
0000000304A4A03oool0oooo00<0oooo00D0<c<c00000000000000000;^k^`070?ooo`0505iNGP00
000000000000002RXZ80403oool00`2IVIT00000000000020000000309VIV@3oool0oooo00H0oooo
00<0VIVI0000000000000P0000000`3<c<`0oooo0?ooo`050?ooo`050820P000000000000000002R
XZ80503oool300000003028R8P3oool0oooo00T0oooo0`0000000`14A4@0oooo0?ooo`020?ooo`04
014A4@0000000000000000`0oooo00D0/k>c000000000000000007MgM`070?ooo`050;^k^`000000
000000000014A4@01@3oool0100R8R80000000000000000H0?ooo`0404A4A00000000000000000L0
oooo1@0000000`14A4@0oooo0?ooo`050?ooo`030>k^kP092@T000000080000000<0i^KV0?ooo`3o
ool06@3oool01@2c/k<00000000000000000EEEE00L0oooo00@08R8R00000000000000001`3oool0
1014A4@0000000000000000E0?ooo`<0000000<0A4A40?ooo`3oool01P3oool01@2RXZ8000000000
00000000P82000H0oooo00D0IVIV000000000000000007MgM`070?ooo`050;^k^`00000000000000
0014A4@01P3oool01014A4@000000000000000060?ooo`060::RXP00000000000000000J6QX0k^k^
1`3oool00`3<c<`00000000000030000000304A4A03oool0oooo0080oooo00@04A4A000000000000
0000e@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinLZ0?oo
o`0505iNGP00000000000000003EeMD01@3oool01@0R8R800000000000000000ZZZZ00T0oooo00<0
XZ:R0000000000000P0000000`2IVIT0oooo0?ooo`0:0?ooo`H0000000<0TI6A0?ooo`3oool01`3o
ool00`14A4@00000000000020000000309VIV@3oool0oooo00@0oooo00<0VIVI0000000000000P00
00000`14A4@0oooo0?ooo`020?ooo`050:ZZZP000000000000000014A4@02`3oool01@2ZZZX00000
000000000000A4A401T0oooo0`0000000`14A4@0oooo0?ooo`080?ooo`030820P0000000000000<0
000000<0IVIV0?ooo`3oool0103oool01@1VIVH000000000000000008R8R00H0oooo00D0MgMg0000
00000000000004e=C@060?ooo`030<c<c0092@T000000080000000<0eMGE0?ooo`3oool03@3oool0
1@28R8P00000000000000000MgMg00L0oooo00@0IVIV000000000000IVIV0`0000000`3MgMd0oooo
0?ooo`050?ooo`04014A4@000000000007MgM`@0oooo00<0A4A40000000000000P0000000`3<c<`0
oooo0?ooo`040?ooo`0309VIV@00000000000080000000<0XZ:R0?ooo`3oool01@3oool500000003
03<c<`3^k^h0oooo00L0oooo00@0A4A400000000000000001P3oool00`2k^k/00000000000020000
000306IVIP3oool0oooo00@0oooo00<0c<c<014A4@000000100000000`2RXZ80oooo0?ooo`0A0?oo
o`<0000000<0A4A40?ooo`3oool01`3oool60000000306IVIP3oool0oooo00@0oooo00D0IVIV0000
000000000000028R8P060?ooo`030=gMg@0A4A4000000080000000<0VIVI0?ooo`3oool00`3oool0
0`3Vi^H04A4A00000002000000030:ZZZP3oool0oooo00@0oooo00<0P8200000000000000`000000
0`0c<c<0k^k^0?ooo`060?ooo`030=gMg@092@T000000080000000<0c<c<0?ooo`3oool00`3oool0
0`3<c<`04A4A00000002000000030:ZZZP3oool0oooo00l0oooo00@0A4A400000000000000001P3o
ool01@0[:b/00000000000000000a<C401L0oooo00<0XZ:R0<c<c03oool01`3oool01P2ZZZX00000
0000000000004A4A0>k^kQ00oooo00<0moOg028R8P0000000P0000000`0R8R80gMgM0?ooo`040?oo
o`030>k^kP0c<c<0000000@0000000<0A4A40?ooo`3oool00`3oool60000000303<c<`3gmoL0oooo
00L0oooo00<0A4A40000000000000P0000000`2IVIT0oooo0?ooo`040?ooo`0309VIV@0000000000
0080000000<0A4A40?ooo`3oool00`3oool01@092@T00000000000000000moOg00H0oooo00@0c<c<
000000000000IVIV0`0000000`3MgMd0oooo0?ooo`050?ooo`04014A4@000000000007MgM`D0oooo
00@0A4A400000000000000001`3oool6000000030;>c/`3oool0oooo00@0oooo00D0IVIV00000000
00000000028R8P050?ooo`030>k^kP0R8R8000000080000000<08R8R0=gMg@3oool0103oool00`3M
gMd0<c<c00000004000000030::RXP3oool0oooo00l0oooo1P0000000`2ATI40oooo0?ooo`070?oo
o`0304A4A03<c<`0oooo00L0oooo00D0EEEE00000000000000000820P0070?ooo`D0000000<0IVIV
0?ooo`3oool0103oool01@2c/k<000000000000000004A4A00L0oooo00H0R8R80000000000000000
014A4@3MgMd60?ooo`0308R8R0000000000000<0000000<0A4A40?ooo`3oool00`3oool01@1gMgL0
0000000000000000CDe=00H0oooo00<0c<c<00T92@0000000P0000000`3EeMD0oooo0?ooo`0?0?oo
o`0304A4A000000000000080000000<0VIVI0?ooo`3oool0103oool00`2IVIT00000000000020000
000304A4A03oool0oooo00H0oooo00D0P82000000000000000000::RXP0D0?ooo`<0000000<08R8R
0?ooo`3oool02@3oool30000000304A4A03oool0oooo0080oooo00D0:b/[00000000000000000<C4
a00;0?ooo`030>k^kP0A4A4000000080000000<0VIVI0?ooo`3oool00`3oool00`3Vi^H04A4A0000
0002000000030:ZZZP3oool0oooo00<0oooo00D0EEEE000000000000000008R8R00G0?ooo`0404A4
A00000000000000000L0oooo1P0000000`2c/k<0oooo0?ooo`040?ooo`0506IVIP00000000000000
000R8R804P3oool00`14A4@0c<c<0?ooo`070?ooo`0505EEE@000000000000000020P8001`3oool0
100R8R8000000000000000070?ooo`0404A4A00000000000000001D0oooo0`0000000`14A4@0oooo
0?ooo`060?ooo`050::RXP000000000000000020P8001P3oool00`3MgMd02@T90000000200000003
0<c<c03oool0oooo00<0oooo00<0c<c<014A4@0000000P0000000`2ZZZX0oooo0?ooo`040?ooo`04
04A4A00000000000000000H0oooo00<0gMgM0000000000000P0000000`1VIVH0oooo0?ooo`040?oo
o`030>KViP0A4A40000000@0000000<0A4A40?ooo`3oool00P3oool01@0[:b/00000000000000000
a<C40=@0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW:P3o
ool01@2c/k<00000000000000000UIFE00@0oooo00D0MgMg000000000000000005EEE@0:0?ooo`03
0?Ogm`1_Kfl02@T900<0000000P0:b/[05iNGP2ATI40XZ:R09VIV@20P800BDU90::RXP@0oooo0`00
00002@14A4@06QXJ000000051@D0A4A406IVIP20P800Kfm_0<c<c0040?ooo`030?Ogm`1_Kfl01@D5
00<0000000H0BDU908R8R02RXZ80XZ:R07MgM`0[:b/30000000300T92@1_Kfl0moOg00@0oooo00<0
j^[Z028R8P0000000P0000002014A4@0MgMg09VIV@2JVYX0MgMg04e=C@0c<c<0a<C40`3oool00`3Z
j^X08R8R000000020000000804A4A01gMgL0VIVI09ZJVP1gMgL0CDe=03<c<`34a<@<0?ooo`0305iN
GP0R8R808R8R00808R8R0`0000000`092@T08R8R028R8P03028R8P03096AT@3oool0oooo0080oooo
00D0P820000000000000000002l_;`0200000006014A4@1WIfL0VIVI0::RXP28R8P0BDU90`000000
0`0=3@d0a<C40?ooo`050?ooo`030>KViP0c<c<000000080000000L0:b/[06m_K`2ATI40XZ:R07Mg
M`1=CDd02@T90080000000<02@T9096AT@3oool03`3oool01@14A4@00000000000000000/k>c00L0
oooo00<0YZJV0000000000000`0000000`1EEED0oooo0?ooo`060?ooo`0507MgM`0000000000014A
4@3Vi^H00`3oool00`3gmoL0?3`l000000020000000701HF5P1VIVH0R8R80::RXP2EUID0IVIV02/[
:`030000000300T92@1_Kfl0no_k00L0oooo0`0000002@14A4@03@d=000000092@T0A4A407=cL`20
P800GUiN0<c<c0030?ooo`0404A4A00000000000000000L0oooo00<0XZ:R01XJ6P0000000P000000
1P0J6QX0Jf][0::RXP2RXZ80TI6A05YJFP<0000000D08R8R00000000000000000::RXP0>0?ooo`03
05iNGP0R8R808R8R00808R8R0`0000000`092@T08R8R028R8P02028R8P0305YJFP3oool0oooo0080
oooo0`0000002P0F5QH0<c<c000000000000;bl_0820P02IVIT0XZ:R07MgM`0[:b/30000000301XJ
6P34a<@0oooo00H0oooo00<0c<c<03<c<`0000000P0000001P0[:b/0P8200::RXP2RXZ80MgMg02/[
:`<0000000<0CDe=0?ooo`3oool01@3oool01@20P8000000000000000000;bl_0080000000H02@T9
05EEE@20P800P82005iNGP3Vi^H30?ooo`0;0820P000000000000000000F5QH0Kfm_096AT@2RXZ80
SHf=04e=C@092@T00P0000000`092@T0TI6A0?ooo`0A0?ooo`0404A4A00000000000000000H0oooo
00`0O7al0000000000000000028R8P1gMgL0VIVI0::RXP24Q8@0CDe=03<c<`28R8P@0?ooo`050820
P00000006QXJ04e=C@1cLg<00`2RXZ800`1lO7`0A4A4000000020000000300T92@2ZZZX0oooo0140
oooo00<0gMgM04e=C@0000000P0000001`092@T0CDe=08R8R02RXZ80TI6A07MgM`0W9bL00P000000
1@0R8R809bLW000000000000A4A400D0oooo0`0000001P0R8R806QXJ0000000000009bLW06IVIP80
P82000<0UIFE0?ooo`3oool00P3oool00`3gmoL0Kfm_00T92@030000000602/[:`1gMgL0XZ:R0::R
XP28R8P0BDU90`0000000`051@D0Kfm_0?Ogm`040?ooo`0508R8R000000000000000001VIVH0203o
ool00`0W9bL00000000000020000000305EEE@3oool0oooo00H0oooo00D0MgMg0000000000004A4A
0>KViP040?ooo`0404A4A00000000000000000L0oooo0`0000002P1NGUh0<c<c000000092@T0CDe=
0820P02IVIT0UIFE06IVIP0[:b/30000000301XJ6P34a<@0oooo00D0oooo00<0gMgM04e=C@000000
0P0000001`092@T0HV9R09VIV@2RXZ80TI6A05iNGP092@T00P0000001@0h>3P00000000000000000
XZ:R0140oooo0`0000002@14A4@06QXJ000000051@D0A4A406IVIP20P800Kfm_0<c<c0040?ooo`80
000000<0=3@d06IVIP20P8000P2RXZ800`28R8P0Kfm_04A4A0030000000300T92@3EeMD0oooo00H0
oooo0`0000002P1NGUh06QXJ0000000A4A40CDe=08f=S@2RXZ80R8R806IVIP0F5QH30000000306m_
K`3oool0oooo00D0oooo00<0k^k^04e=C@0000000P0000002`092@T0CDe=07MgM`2NWYh0TI6A07Mg
M`14A4@01@D50000000R8R80CDe=0080000000<0A4A40?ooo`3oool00`3oool00`3Vi^H0<c<c0000
00020000000702/[:`1_Kfl0TI6A0::RXP1gMgL0CDe=00T92@020000000300T92@2ATI40oooo0140
oooo00<0moOg06m_K`051@D00`0000001P19BDT0R8R80::RXP2RXZ80MgMg02/[:`<0000000<02@T9
06m_K`3gmoL0103oool4028R8P05014A4@00000000000000000F5QH0100R8R800`2ATI40oooo0?oo
o`0=0?ooo`<0000000<08R8R0?ooo`3oool02@3oool30000000304A4A03oool0oooo0080oooo00`0
O7al0000000000000000028R8P1gMgL0VIVI0::RXP24Q8@0CDe=03<c<`28R8P50?ooo`030<c<c00c
<c<000000080000000H0:b/[0820P02RXZ80XZ:R07MgM`0[:b/30000000304e=C@3oool0oooo00@0
oooo00<0eMGE014A4@0000000P0000001`1NGUh0VIVI0::RXP2ATI40HV9R03<c<`28R8P0403oool0
1014A4@000000000000000070?ooo`<0000000X0GUiN03<c<`0000002@T904e=C@20P800VIVI09FE
U@1VIVH0:b/[0`0000000`0J6QX0a<C40?ooo`0A0?ooo`80000000<0=3@d06IVIP20P8000P2RXZ80
0`28R8P0Kfm_04A4A0030000000300T92@3EeMD0oooo00H0oooo00@08R8R00000000000000001`3o
ool01014A4@0000000000000000@0?ooo`D08R8R0`0000000`092@T08R8R028R8P02028R8P0505YJ
FP3oool0oooo0?ooo`2RXZ800`0000000`20P800oooo0?ooo`050?ooo`0;0820P000000000000000
000F5QH0Kfm_096AT@2RXZ80SHf=04e=C@092@T00P0000000`092@T0TI6A0?ooo`060?ooo`0404A4
A00000000000000000L0oooo00<0XZ:R01XJ6P0000000P0000001`0J6QX0EEEE096AT@2RXZ80TI6A
06m_K`0R8R800P0000001@14A4@00000000000000000A4A400@0oooo00`0O7al0000000000000000
028R8P1gMgL0VIVI0::RXP24Q8@0CDe=03<c<`28R8S=0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWib/0oooo00@04A4A000000000000CDe=0`3oool00`3^k^h0
000000000002000000030>k^kP3oool0oooo00X0oooo00<0gMgM03<c<`000000200000000`28R8P0
oooo0?ooo`020?ooo`<0000000<0R8R80<c<c00A4A401@0000000`2k^k/0oooo0?ooo`040?ooo`03
08R8R0000000000000T0000000<06QXJ0=gMg@3oool01P3oool00`3^k^h0<c<c0000000800000003
0:ZZZP3oool0oooo0080oooo00<0k^k^03<c<`000000200000000`2ZZZX0oooo0?ooo`0:0?ooo`03
04A4A0000000000000/0000000<0R8R80?ooo`3oool00P3oool01P20P8000000000000000000XZ:R
06IVIPX0000000<0Kfm_0?ooo`3oool01`3oool00`28R8P000000000000800000003014A4@3<c<`0
oooo0100oooo00D04A4A00000000000000000>KViP070?ooo`030=GEe@000000000000<0000000<0
c<c<0?ooo`3oool01P3oool01@3^k^h00000000000000000R8R800@0oooo00<0k^k^03<c<`000000
2P0000000`0c<c<0gMgM0?ooo`080?ooo`<0000000<0R8R806m_K`0000001@0000001@2k^k/0oooo
0?ooo`3oool0A4A400<00000203oool00`3^k^h06QXJ000000090000000306IVIP20P80000000080
000000<0XZ:R0?ooo`3oool0303oool00`14A4@000000000000:0000000304A4A03oool0oooo0080
oooo0`0000000`0R8R80oooo06IVIP090000000300T92@3<c<`0oooo00T0oooo00<0A4A400000000
0000200000000`0A4A40i^KV0?ooo`060?ooo`060820P000000000000000002ZZZX04A4A1P000000
0`3MgMd0oooo0?ooo`020?ooo`0308R8R0000000000000P0000000<02@T90<c<c03oool04P3oool0
1014A4@000000000000000060?ooo`030?Ogm`0c<c<0000000P0000000<0EEEE0?ooo`3oool03P3o
ool00`2ATI400000000000090000000300T92@3<c<`0oooo01@0oooo00<0VIVI0000000000002000
00000`0c<c<0k^k^04A4A0020000000304A4A03oool0oooo00<0oooo0`0000000`14A4@0c<c<014A
4@050000000305iNGP3oool0oooo00@0oooo00<0gMgM01XJ6P0000002P0000000`28R8P0oooo0?oo
o`040?ooo`05028R8P00000000000000003<c<`0203oool00`1EEED0000000000002000000030<c<
c03oool0oooo00H0oooo00D0k^k^000000000000000008R8R0040?ooo`0404A4A000000000000000
00L0oooo0`0000000`28R8P0oooo06IVIP0900000003014A4@3<c<`0oooo00P0oooo00<0CDe=0000
00000000200000000`0c<c<0^k^k00000002000000030::RXP3oool0oooo00l0oooo0`0000000`28
R8P0c<c<014A4@05000000030;^k^`3oool0oooo0080oooo00<08R8R0000000000002@0000000`0A
4A40c<c<0?ooo`070?ooo`<0000000<0R8R80;>c/`0000002@0000000`0A4A40i^KV0?ooo`080?oo
o`0309VIV@000000000000P0000000<0<c<c0>k^kP28R8P00P0000000`14A4@0oooo0?ooo`050?oo
o`0308R8R0000000000000P0000000<04A4A0<c<c03oool0503oool00`28R8P00000000000090000
000301XJ6P3MgMd0oooo00D0oooo3@0000000`28R8P0oooo0?ooo`0=0?ooo`<0000000<08R8R0?oo
o`3oool02@3oool30000000304A4A03oool0oooo0080oooo00<0moOg03<c<`000000200000000`1E
EED0oooo0?ooo`050?ooo`0304A4A0000000000000P0000000<04A4A0>KViP3oool01P3oool00`2A
TI400000000000070000000305EEE@3oool0oooo00h0oooo00@0A4A400000000000000001`3oool3
0000000308R8R03oool0IVIV00T0000000<04A4A0<c<c03oool04P3oool00`0R8R80000000000009
00000003014A4@3<c<`0oooo00L0oooo00@08R8R00000000000000001`3oool01014A4@000000000
0000000@0?ooo`d0000000D0A4A40?ooo`3oool0oooo0::RXP03000000030820P03oool0oooo00H0
oooo00<0R8R8000000000000200000000`092@T0c<c<0?ooo`070?ooo`0404A4A000000000000000
00P0oooo00<0k^k^03<c<`0000002@0000000`1VIVH0oooo000000020000000304A4A03oool0oooo
0080oooo00<0moOg03<c<`000000200000000`1EEED0oooo0?ooo`3;0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib/0oooo00@0R8R80000000000006QXJ0`3o
ool01@2k^k/00000000000000000<c<c00l0oooo00<0GUiN0000000000001P0000000`1VIVH0oooo
0?ooo`020?ooo`<0000000@0R8R80?ooo`3MgMd06QXJ100000000`2k^k/0oooo0?ooo`050?ooo`03
09VIV@0R8R80000000L0000000<08R8R0<c<c03oool0203oool00`3^k^h0MgMg0000000700000003
0::RXP3oool0oooo00<0oooo00<0k^k^07MgM`0000001`0000000`2RXZ80oooo0?ooo`0:0?ooo`03
04A4A0000000000000/0000000<0R8R80?ooo`3oool00P3oool02020P8000000000000000000XZ:R
0?ooo`28R8P04A4A1`0000000`1EEED0moOg0?ooo`090?ooo`030;^k^`0R8R80000000H0000000<0
<c<c0>k^kP3oool0403oool01@2k^k/000000000000000008R8R00T0oooo00D04A4A000000000000
0000028R8P0:0?ooo`0401XJ6P000000000003<c<`H0oooo00<0VIVI028R8P0000001`0000000`1N
GUh0oooo0?ooo`090?ooo`<0000000<0R8R80>k^kP0c<c<01@0000001@2k^k/0oooo0?ooo`3oool0
A4A400<000002@3oool00`34a<@04A4A0000000600000004028R8P2ZZZX0oooo0820P0<0000000<0
XZ:R0?ooo`3oool0303oool00`14A4@000000000000:0000000304A4A03oool0oooo0080oooo0`00
00001@0R8R80oooo0?ooo`28R8P02@T900L0000000<0XZ:R0?ooo`3oool02@3oool00`3MgMd0A4A4
000000070000000306IVIP3^k^h0oooo00L0oooo00L0P82000000000000000000<C4a03MgMd0<c<c
00D0000000<0gMgM0?ooo`3oool00`3oool00`2k^k/0A4A400000007000000030:ZZZP3oool0oooo
0180oooo00@0A4A400000000000000001`3oool00`3^k^h0MgMg000000070000000304A4A03oool0
oooo00l0oooo00<0VIVI028R8P000000200000000`2ATI40oooo0?ooo`0E0?ooo`030820P0000000
000000H0000000@0MgMg0>k^kP3oool0A4A40P0000000`14A4@0oooo0?ooo`030?ooo`<0000000@0
A4A40?ooo`3MgMd0<c<c100000000`1NGUh0oooo0?ooo`050?ooo`030<c<c00R8R80000000L00000
00<08R8R09VIV@3oool01@3oool01@2k^k/000000000000000008R8R00T0oooo00D0R8R800000000
00000000014A4@0:0?ooo`0403<c<`000000000003<c<`@0oooo00@0A4A400000000000000001`3o
ool30000000408R8R03oool0oooo05EEE@L0000000<0:b/[0>k^kP3oool02@3oool00`3MgMd0A4A4
000000070000000307MgM`3^k^h0a<C400<0000000<0XZ:R0?ooo`3oool03`3oool30000000408R8
R03oool0gMgM01XJ6P@0000000<0^k^k0?ooo`3oool00`3oool00`2IVIT04A4A0000000700000003
04A4A03MgMd0oooo00P0oooo0`0000001028R8P0oooo09VIV@0A4A470000000305EEE@3^k^h0oooo
00X0oooo00<0^k^k028R8P0000001P000000100l?3`0k^k^0?ooo`28R8P20000000304A4A03oool0
oooo00H0oooo00<0^k^k028R8P0000001P0000000`0c<c<0k^k^0?ooo`0F0?ooo`0309VIV@0R8R80
000000L0000000<08R8R0<c<c03oool01P3oool=0000000308R8R03oool0oooo00d0oooo0`000000
0`0R8R80oooo0?ooo`090?ooo`<0000000<0A4A40?ooo`3oool00`3oool00`3^k^h0MgMg00000007
0000000304A4A03oool0oooo00D0oooo00<0gMgM04A4A00000001`0000000`1VIVH0k^k^0?ooo`07
0?ooo`030?Ogm`1gMgL0000000L0000000<0A4A40?ooo`3oool03P3oool01014A4@0000000000000
00070?ooo`<0000000@0R8R80?ooo`3oool0EEEE1`0000000`0[:b/0k^k^0?ooo`0D0?ooo`0309VI
V@0A4A40000000L0000000<0A4A40=gMg@3oool0203oool0100R8R8000000000000000070?ooo`04
04A4A0000000000000000100oooo3@0000001@14A4@0oooo0?ooo`3oool0XZ:R00<0000000<0P820
0?ooo`3oool01`3oool00`2k^k/0A4A400000007000000030:ZZZP3oool0oooo00L0oooo00@0A4A4
00000000000000002P3oool00`1=CDd000000000000500000004014A4@2ZZZX0oooo0?ooo`<00000
00<0A4A40?ooo`3oool00`3oool00`3^k^h0MgMg000000070000000304A4A03oool0oooo0</0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW:`3oool01@3MgMd0
0000000000000000gMgM0080oooo00D0P820000000000000000006IVIP0@0?ooo`090:ZZZP1gMgL0
A4A4014A4@0000008R8R04A4A028R8P0k^k^00X0oooo00H0c<c<05EEE@0R8R80000003<c<`3MgMd9
0?ooo`030;^k^`1VIVH08R8R0080000000<0<c<c07MgM`2ZZZX03@3oool02@2c/k<0A4A403<c<`00
00004A4A04A4A01gMgL0ZZZZ0?Ogm`070?ooo`090;>c/`14A4@0<c<c0000000A4A40A4A407MgM`2Z
ZZX0moOg0140oooo0`0000000`14A4@0oooo0?ooo`080?ooo`050820P000000000000000002RXZ80
0P3oool00`3^k^h0MgMg03<c<`020000000303<c<`28R8P0c<c<00d0oooo00T0i^KV08R8R014A4@0
8R8R0000000R8R80A4A408R8R03^k^h0>`3oool0202RXZ80A4A4028R8P0000004A4A04A4A01gMgL0
ZZZZ4P3oool01P2IVIT0EEEE014A4@0R8R80A4A40=gMg@<0oooo00@0A4A400000000000000002P3o
ool0203^k^h0VIVI05EEE@0J6QX00000014A4@14A4@0R8R80`3oool01@20P8000000000000000000
XZ:R01<0oooo0`0000000`14A4@0oooo0?ooo`070?ooo`<0000000`08R8R0?ooo`3oool0oooo0<C4
a01EEED0<c<c0000000A4A40A4A408R8R03<c<`>0?ooo`030<c<c028R8P0<c<c0080000000<08R8R
06IVIP3MgMd04@3oool01P2IVIT0?3`l0000000R8R80A4A40>k^kPL0oooo00P0ZZZZ04A4A00R8R80
0000014A4@14A4@0R8R80=gMgB80oooo00<0gMgM06IVIP0c<c<00P000000100c<c<0MgMg0:ZZZP3^
k^hC0?ooo`030<c<c01_Kfl0<c<c0080000000@06QXJ05EEE@28R8P0gMgM6@3oool0203<c<`0MgMg
04A4A0092@T0000003<c<`1EEED0/k>c4`3oool01@1gMgL08R8R0000000R8R80TI6A00T0oooo00<0
^k^k08R8R00c<c<00P0000000`0R8R80GUiN0:ZZZP0o0?ooo`0809VIV@1VIVH0<c<c0000000R8R80
A4A408R8R03Vi^H=0?ooo`030<c<c01gMgL0:b/[0080000000<0<c<c06m_K`3MgMd07P3oool01P3<
c<`0EEEE028R8P000000<c<c0=gMg@H0oooo00@0i^KV08R8R01EEED0<c<c0P0000000`0c<c<0EEEE
0;>c/`0B0?ooo`0709VIV@1=CDd000000000000R8R80IVIV0<c<c00>0?ooo`090>KViP1gMgL0A4A4
014A4@000000<c<c05EEE@28R8P0k^k^00l0oooo00T0i^KV08R8R014A4@08R8R0000000R8R80A4A4
08R8R03^k^h06P3oool00`2k^k/0IVIV028R8P020000000303<c<`1gMgL0ZZZZ00d0oooo00D0P820
00000000000000000::RXP0^0?ooo`030=gMg@1VIVH0<c<c0080000000@0<c<c07MgM`2ZZZX0k^k^
2@3oool00`3<c<`0R8R803<c<`0200000003028R8P1VIVH0gMgM00`0oooo00<0gMgM08R8R00l?3`0
0P000000100R8R80GUiN0:ZZZP3^k^hR0?ooo`0809VIV@1VIVH0<c<c0000000R8R80A4A408R8R03V
i^HG0?ooo`040>KViP28R8P0EEEE03<c<`80000000<0<c<c05EEE@2c/k<02`3oool0100R8R800000
0000000000070?ooo`0404A4A00000000000000001D0oooo0`0000000`14A4@0oooo0?ooo`0F0?oo
o`080:ZZZP14A4@08R8R0000000A4A40A4A408R8R03MgMd:0?ooo`0404A4A00000000000000000X0
oooo00T0moOg09VIV@1EEED0<c<c0000000A4A40A4A406IVIP3EeMD00`3oool30000000304A4A03o
ool0oooo00D0oooo00<0gMgM06IVIP0c<c<00P000000100c<c<0MgMg0:ZZZP3^k^k=0?ooo`040>WY
j@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib`0oooo00@0TI6A00000000
0000CDe=0P3oool01@0_;bl00000000000000000]kNg0740oooo0`0000000`14A4@0oooo0?ooo`08
0?ooo`050820P000000000000000002RXZ80OP3oool01014A4@0000000000000000E0?ooo`050820
P000000000000000002RXZ804`3oool30000000304A4A03oool0oooo00L0oooo0`0000000`0R8R80
oooo0?ooo`3o0?ooomd0oooo00D0P82000000000000000000::RXP2b0?ooo`04028R8P0000000000
000000L0oooo00@0A4A400000000000000005@3oool30000000304A4A03oool0oooo02P0oooo00@0
A4A400000000000000005P3oool30000000304A4A03oool0oooo0=/0oooo00@0jNWY0=7Ad@3AdM40
g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW;@3oool01@0c<c<000000000002ZZZX0^k^k
00<0000000<04A4A0?ooo`3oool0L03oool30000000304A4A03oool0oooo00P0oooo00D0P8200000
0000000000000::RXP1n0?ooo`0404A4A00000000000000001D0oooo00D0P8200000000000000000
0::RXP0C0?ooo`<0000000<0A4A40?ooo`3oool01`3oool300000003028R8P3oool0oooo0?l0oooo
g@3oool01@20P8000000000000000000XZ:R0;80oooo00@08R8R00000000000000001`3oool01014
A4@0000000000000000E0?ooo`<0000000<0A4A40?ooo`3oool0:03oool01014A4@0000000000000
000F0?ooo`<0000000<0A4A40?ooo`3oool0f`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinL]0?ooo`0509VIV@000000000006IVIP1EEED00`0000000`28R8P0
oooo0?ooo`1`0?ooo`<0000000<0A4A40?ooo`3oool0203oool01@20P8000000000000000000XZ:R
07h0oooo00@0A4A400000000000000005@3oool01@20P8000000000000000000XZ:R01<0oooo0`00
00000`14A4@0oooo0?ooo`070?ooo`<0000000<08R8R0?ooo`3oool0o`3ooooM0?ooo`050820P000
000000000000002RXZ80/P3oool0100R8R8000000000000000070?ooo`0404A4A000000000000000
01D0oooo0`0000000`14A4@0oooo0?ooo`0X0?ooo`0404A4A00000000000000001H0oooo0`000000
0`14A4@0oooo0?ooo`3K0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWibh0oooo00<02@T9000000000000100000000`3MgMd0oooo0?ooo`1`0?ooo`<0000000<0
A4A40?ooo`3oool0203oool01@20P8000000000000000000XZ:R07h0oooo00@0A4A4000000000000
00005@3oool01@20P8000000000000000000XZ:R01<0oooo0`0000000`14A4@0oooo0?ooo`070?oo
o`<0000000<08R8R0?ooo`3oool0o`3ooooM0?ooo`050::RXP00000000000000002ATI40/P3oool0
100R8R8000000000000000070?ooo`0404A4A00000000000000001D0oooo00@08R8R000000000000
8R8R:P3oool01014A4@0000000000000000F0?ooo`<0000000<0A4A40?ooo`3oool0f`3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinL^0?ooo`0305EEE@000000
000000<0000000<0TI6A0?ooo`3oool0L@3oool0103gmoL0eMGE09jNWP28R8P:0?ooo`050820P000
000000000000002RXZ80OP3oool01014A4@0000000000000000E0?ooo`050820P000000000000000
002RXZ804`3oool0103Vi^H0/k>c08R8R028R8P90?ooo`<0000000<08R8R0?ooo`3oool0FP3oool4
000000030;^k^`3oool0oooo0:80oooo100000000`2k^k/0oooo0?ooo`3B0?ooo`050;Ng]`000000
00000000001EEED0K@3oool4000000030;^k^`3oool0oooo03h0oooo00@08R8R0000000000000000
1`3oool01014A4@0000000000000000E0?ooo`0503Ph>000000000000000003EeMD01`3oool01@20
P8000000000000000000GUiN01d0oooo00@0A4A400000000000000005P3oool30000000304A4A03o
ool0oooo0=/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
;P3oool00`2ZZZX000000000000200000003028R8P3oool0oooo0800oooo00D0P820000000000000
00000::RXP1n0?ooo`0404A4A00000000000000001D0oooo00D0P82000000000000000000::RXP0P
0?ooo`<0000000<08R8R0?ooo`3oool0FP3oool4000000030;^k^`3oool0oooo0:80oooo10000000
0`2k^k/0oooo0?ooo`3B0?ooo`030>k^kP00000000000080000000<0R8R80>k^kP3oool0JP3oool4
000000030;^k^`3oool0oooo03h0oooo00@08R8R00000000000000001`3oool01014A4@000000000
0000000E0?ooo`0606m_K`000000000000000014A4@0k^k^1P3oool01@20P8000000000000000000
GUiN01d0oooo00@0A4A400000000000000005P3oool30000000304A4A03oool0oooo0=/0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW;P3oool00`3MgMd00000
000000020000000309VIV@3oool0oooo0800oooo00D0P82000000000000000000::RXP1n0?ooo`04
04A4A00000000000000001D0oooo00D0P82000000000000000000::RXP0P0?ooo`<0000000<08R8R
0?ooo`3oool0FP3oool4000000030;^k^`3oool0oooo0:80oooo100000000`2k^k/0oooo0?ooo`3C
0?ooo`0304A4A0000000000000<0000000<0A4A403`l?028R8P0J03oool4000000030;^k^`3oool0
oooo03h0oooo00@08R8R00000000000000001`3oool01014A4@0000000000000000E0?ooo`030::R
XP000000000000<000000P14A4@01@1NGUh0oooo0?ooo`3oool0P82000<0000000<0GUiN0?ooo`3o
ool06`3oool01014A4@0000000000000000F0?ooo`<0000000<0A4A40?ooo`3oool0f`3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinNf0?ooo`050820P0000000
00000000002RXZ80OP3oool01014A4@0000000000000000E0?ooo`050820P000000000000000002R
XZ80803oool300000003028R8P3oool0oooo05X0oooo100000000`2k^k/0oooo0?ooo`2R0?ooo`@0
000000<0^k^k0?ooo`3oool0d`3oool00`3MgMd04A4A000000050000000307MgM`3oool0oooo06H0
oooo100000000`2k^k/0oooo0?ooo`0n0?ooo`04028R8P0000000000000000L0oooo00@0A4A40000
0000000000005@3oool00`3^k^h04A4A000000050000000503`l?03oool0oooo0?ooo`20P8000`00
00000`1NGUh0oooo0?ooo`0K0?ooo`0404A4A00000000000000001H0oooo0`0000000`14A4@0oooo
0?ooo`3K0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWikH0
oooo00D0`<300820P020P800P8200=7Ad@1n0?ooo`040::RXP20P800P8200820P1D0oooo00D0`<30
0820P020P800P8200=7Ad@0P0?ooo`<0P82000<0TI6A0?ooo`3oool0FP3oool40=gMg@030?Ogm`3o
ool0oooo0:80oooo103MgMd00`3gmoL0oooo0?ooo`3D0?ooo`040>KViP2IVIT0A4A4028R8P800000
00<04A4A05iNGP3oool0I`3oool40=gMg@030?Ogm`3oool0oooo03h0oooo00@0TI6A0820P020P800
P8201`3oool0102RXZ80P8200820P020P80F0?ooo`040>KViP2IVIT0EEEE02/[:`<0000000D0@410
0?ooo`3oool0oooo0>k^kP030=gMg@030>[ZjP3oool0oooo01/0oooo00@0XZ:R0820P020P800P820
5P3oool30820P0030::RXP3oool0oooo0=/0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3o
oooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3o
oooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3o
oooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3o
oooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40hn?So`3fm_Ko0?Kfm_l0m_Kfo`3fm_Ko0?KfmV80m_Kf00@0i>CT
0=7Ad@3AdM40g=cL3@3oool000L0oooo00<0jNWY0=7Ad@3AdM40o`3AdM7o0=7AdOl0dM7Ao`3AdM7o
0=7AdFH0dM7A00<0g=cL0?ooo`3oool02`3oool000L0oooo00<0jNWY0=7Ad@3AdM40o`3AdM7o0=7A
dOl0dM7Ao`3AdM7o0=7AdFH0dM7A00<0g=cL0?ooo`3oool02`3oool000L0oooo00<0jNWY0=7Ad@3A
dM40o`3AdM7o0=7AdOl0dM7Ao`3AdM7o0=7AdFH0dM7A00<0g=cL0?ooo`3oool02`3oool000L0oooo
00@0jNWY0=7Ad@3AdM40hN7Qo`3alO7o0?7alOl0lO7ao`3alO7o0?7alF80lO7a00@0h^;R0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3o
oooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3A
dM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?oo
of80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo
0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY
0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL
3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0
ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3A
dM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3ooooo0?ooool0ooooo`3o
oooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW
o`3ooooo0?ooool0ooooo`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOWo`3oool30?ooo`040>k^kP34a<@0XZ:R09VIV@@0P82000@0WYjN0;>c
/`34a<@0i^KV>P3oool00`3Vi^H0a<C40::RXP030820P00309ZJVP34a<@0eMGE03d0oooo00<0eMGE
0::RXP2ATI400`20P8000`2RXZ80/k>c0>;RhP0?0?ooo`050?_kn`3<c<`0^k^k0::RXP2=SHd00`20
P800102ATI40/k>c0<c<c03gmoM30?ooo`050?_kn`3<c<`0^k^k0::RXP2=SHd00`20P800102ATI40
/k>c0<c<c03gmoOo0?ooool0ooooo`3ooomO0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?oo
o`040>WYj@3AdM40dM7A0>OWib80oooo00<0R8R80000000000001@0000090?ooo`0304A4A0000000
000000@0000000<0GUiN0?ooo`3oool02P3oool00`28R8P0000000000004000000P0oooo00<0P820
000000000000200000000`14A4@0IVIV0:ZZZP0B0?oooa00000000<08R8R0?ooo`3oool05@3oool5
0000000308R8R03oool0oooo00H0oooo00<0R8R80000000000000`0000001@14A4@0oooo0?ooo`3o
ool0^k^k00D0000000<0<c<c0?ooo`3oool03@3oool00`0c<c<00000000000030000000309VIV@3o
ool0oooo00<0oooo00<0A4A40000000000000`0000090?ooo`030>k^kP0A4A40000000D000004@3o
ool00`2k^k/0IVIV00T92@0;0000000304e=C@3MgMd0oooo00P0oooo4@0000000`2RXZ80oooo0?oo
o`0I0?ooo`030<c<c00c<c<0000000P0000000<08R8R0;^k^`3oool03@3oool50000000304A4A03o
ool0oooo02<0oooo00<0VIVI03<c<`000000200000000`1VIVH0gMgM0?ooo`0;0?ooo`030=gMg@0[
:b/0000000X0000000<0XZ:R0?ooo`3oool02P3ooolA0000000304A4A03oool0oooo00H0oooo1@00
00000`28R8P0oooo0?ooo`060?ooo`0308R8R0000000000000<0000000<0A4A40?ooo`3oool0103o
ool00`3MgMd0:b/[0000000:000000030::RXP3oool0oooo0?l0ooooo`3ooooo0?oooe`0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW8P3oool00`1_Kfl00000
00000005000000030>KViP3oool0oooo00H0oooo00<04A4A000000000000100000000`14A4@0oooo
0?ooo`0:0?ooo`0308R8R0000000000000@00000203oool00`20P80000000000000<0000000305EE
E@3MgMd0oooo00h0oooo400000000`0R8R80oooo0?ooo`0E0?ooo`D0000000<0R8R80?ooo`3oool0
1P3oool00`1EEED00000000000030000000506m_K`3oool0oooo0?ooo`3Vi^H01P0000000`3MgMd0
oooo0?ooo`0;0?ooo`030=gMg@000000000000@0000000<0a<C40?ooo`3oool00`3oool00`14A4@0
000000000003000000T0oooo00<0R8R80000000000001@00000?0?ooo`030>k^kP14A4@0000000l0
00002@3ooolA000000030::RXP3oool0oooo01P0oooo00<0gMgM028R8P0000002P0000000`0A4A40
^k^k0?ooo`0<0?ooo`D0000000<0A4A40?ooo`3oool08@3oool00`3gmoL0A4A40000000;00000003
014A4@2IVIT0oooo00X0oooo00<0R8R80000000000002`0000000`28R8P0oooo0?ooo`090?oooa40
000000<0A4A40?ooo`3oool01P3oool50000000308R8R03oool0oooo00H0oooo00<0EEEE00000000
00000`0000000`1_Kfl0oooo0?ooo`040?ooo`0308R8R0000000000000/0000000<0R8R80?ooo`3o
ool0o`3ooooo0?ooool0ooooF`3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0
dM7A0=7Ad@3WinLR0?ooo`0304e=C@000000000000D0000000<0c<c<0?ooo`3oool01@3oool00`3^
k^h00000000000050000000302/[:`3oool0oooo00X0oooo00<0R8R8000000000000100000080?oo
o`030820P0000000000000d0000000<08R8R0;^k^`3oool03@3oool@00000003028R8P3oool0oooo
01D0oooo1@0000000`28R8P0oooo0?ooo`050?ooo`030>k^kP000000000000@0000000<0VIVI0?oo
o`3oool00P3oool00`0R8R800000000000030000000308R8R03oool0oooo00/0oooo00<0VIVI0000
00000000100000000`3^k^h0oooo0?ooo`030?ooo`0304A4A0000000000000<000002@3oool00`0R
8R80000000000005000000l0oooo00<0EEEE0000000000003`0000090?oooa40000000<0XZ:R0?oo
o`3oool05`3oool00`2ZZZX04A4A0000000=0000000308R8R03oool0oooo00X0oooo1@0000000`14
A4@0oooo0?ooo`0Q0?ooo`030820P0000000000000d0000000<0a<C40?ooo`3oool0203oool00`2k
^k/000000000000<0000000306IVIP3oool0oooo00P0oooo4@0000000`14A4@0oooo0?ooo`060?oo
o`D0000000<0R8R80?ooo`3oool01@3oool00`3^k^h00000000000040000000309VIV@3oool0oooo
00@0oooo00<0^k^k000000000000300000000`1VIVH0oooo0?ooo`3o0?ooool0ooooo`3ooomJ0?oo
o`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib80oooo00<0;bl_
0000000000001@0000000`2c/k<0oooo0?ooo`050?ooo`030=7Ad@000000000000D0000000<02@T9
0>k^kP3oool02P3oool00`28R8P0000000000004000000P0oooo00<0P8200000000000003`000000
0`0l?3`0VIVI0?_kn`0;0?oooa00000000<08R8R0?ooo`3oool05@3oool50000000308R8R03oool0
oooo00D0oooo00<0R8R8000000000000100000000`3IfMT0oooo0?ooo`020?ooo`030::RXP000000
000000<0000000<0:b/[0?ooo`3oool02`3oool00`0c<c<00000000000030000000305iNGP3oool0
oooo00@0oooo00<0A4A40000000000000`0000080?ooo`030<30`0000000000000H000003@3oool0
0`2c/k<0?3`l0000000A000000T0oooo4@0000000`2RXZ80oooo0?ooo`0E0?ooo`030??cl`1=CDd0
000000D0000000D01@D5028R8P0R8R808R8R00T92@060000000303<c<`3Rh^80oooo00T0oooo1@00
00000`14A4@0oooo0?ooo`0P0?ooo`030:ZZZP0=3@d0000000h0000000<09bLW0>k^kP3oool0203o
ool00`2k^k/000000000000=0000000303`l?03^k^h0oooo00L0oooo4@0000000`14A4@0oooo0?oo
o`060?ooo`D0000000<0R8R80?ooo`3oool01@3oool00`28R8P0000000000004000000030=WIf@3o
ool0oooo00@0oooo00<0^k^k0000000000003@0000000`0l?3`0k^k^0?ooo`3o0?ooool0ooooo`3o
oomI0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib80oooo
200000000`28R8P0oooo0?ooo`050?ooo`030:ZZZP000000000000H0000000<0ZZZZ0?ooo`3oool0
2@3oool00`28R8P0000000000004000000P0oooo00<0P8200000000000000`0000001@0R8R80A4A4
04A4A014A4@08R8R00T0000000<0TI6A0?ooo`3oool02@3oool@00000003028R8P3oool0oooo01D0
oooo1@0000000`28R8P0oooo0?ooo`050?ooo`03014A4@000000000000<0000000<0<c<c0?ooo`3o
ool0103oool00`0R8R80000000000003000000030=GEe@3oool0oooo00T0oooo00<0i^KV00000000
0000100000000`3<c<`0oooo0?ooo`040?ooo`0304A4A0000000000000<00000203oool00`1_Kfl0
000000000006000000`0oooo00<0R8R80000000000001@0000000`0R8R80R8R80<c<c0030?ooo`03
0;^k^`14A4@0000000@000002@3ooolA000000030::RXP3oool0oooo01D0oooo00<0R8R800000000
0000100000000`0R8R80c<c<0?ooo`020?ooo`030=gMg@14A4@0000000D0000000<0IVIV0?ooo`3o
ool0203oool50000000304A4A03oool0oooo01l0oooo00<0^k^k000000000000100000001`1VIVH0
c<c<0?ooo`3oool0k^k^09VIV@0R8R801@0000000`14A4@0oooo0?ooo`070?ooo`060;^k^`000000
000003<c<`28R8P0gMgM0`3oool00`2ATI40000000000005000000030::RXP3oool0oooo00H0oooo
4@0000000`14A4@0oooo0?ooo`060?ooo`D0000000<0R8R80?ooo`3oool01@3oool00`0A4A400000
000000030000000303<c<`3oool0oooo00D0oooo00H0^k^k000000000000<c<c08R8R03MgMd30?oo
o`03096AT@000000000000D0000000<0XZ:R0?ooo`3oool0o`3ooooo0?ooool0ooooF03oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinLQ0?ooo`030<c<c0000000
000000H0000000<0Kfm_0?ooo`3oool01@3oool00`2IVIT00000000000060000000308R8R03oool0
oooo00T0oooo00<0R8R8000000000000100000080?ooo`030820P0000000000000<0000000<0R8R8
0?ooo`3oool00P3oool00`3^k^h0Kfm_000000060000000302/[:`3oool0oooo00T0oooo1@000000
0`28R8P0oooo0?ooo`0P0?ooo`D0000000<0R8R80?ooo`3oool0103oool00`3Vi^H0000000000004
0000000309VIV@3oool0oooo00@0oooo00<0MgMg0000000000000`0000000`2k^k/0oooo0?ooo`09
0?ooo`030<C4a0000000000000<0000000<08R8R0?ooo`3oool01@3oool00`14A4@0000000000003
000000P0oooo00<0?3`l0000000000001P00000;0?ooo`030>KViP000000000000D0000000<0EEEE
0?ooo`3oool01@3oool00`20P800000000000003000000T0oooo1@0000000`14A4@0oooo0?ooo`0Q
0?ooo`0303`l?0000000000000<0000000<0<c<c0>k^kP3oool01@3oool00`1VIVH0000000000003
0000000301XJ6P3oool0oooo00P0oooo1@0000000`14A4@0oooo0?ooo`0O0?ooo`0306IVIP000000
000000<0000000<0CDe=0?ooo`3oool0103oool00`3^k^h06QXJ00000004000000030=gMg@3oool0
oooo00L0oooo00<0<c<c0=gMg@3oool01P3oool00`2IVIT00000000000040000000306IVIP3oool0
oooo00H0oooo1P0000000`28R8P0oooo0?ooo`0A0?ooo`D0000000<0R8R80?ooo`3oool0103oool0
0`3Vi^H00000000000040000000309VIV@3oool0oooo00H0oooo00<0<c<c0=gMg@3oool01P3oool0
0`2IVIT00000000000040000000306IVIP3oool0oooo0?l0ooooo`3ooooo0?oooeP0oooo00@0jNWY
0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW8@3oool00`2IVIT000000000
00060000000305EEE@3oool0oooo00D0oooo00<0P8200000000000001P0000000`14A4@0oooo0?oo
o`090?ooo`0308R8R0000000000000@00000203oool00`20P8000000000000030000000308R8R03o
ool0oooo00@0oooo00<0^k^k028R8P0000001@0000000`28R8P0oooo0?ooo`080?ooo`D0000000<0
R8R80?ooo`3oool0803oool50000000308R8R03oool0oooo00@0oooo00<0^k^k0000000000001000
00000`3^k^h0oooo0?ooo`040?ooo`030<c<c0000000000000<0000000<0TI6A0?ooo`3oool02@3o
ool00`2IVIT00000000000030000000307MgM`3oool0oooo00D0oooo00<0A4A40000000000000`00
00070?ooo`030>k^kP092@T0000000L000002`3oool00`2IVIT000000000000400000003014A4@3V
i^H0oooo00H0oooo00<0P8200000000000000`0000090?ooo`D0000000<0A4A40?ooo`3oool0803o
ool00`3MgMd000000000000300000003028R8P3^k^h0oooo00L0oooo00<0EEEE0000000000000`00
00000`2IVIT0oooo0?ooo`070?ooo`D0000000<0A4A40?ooo`3oool07P3oool00`3^k^h000000000
0004000000030;>c/`3oool0oooo00D0oooo00<0Kfm_0000000000000`0000000`1gMgL0oooo0?oo
o`070?ooo`030>KViP3oool0oooo00L0oooo00<0MgMg0000000000000`0000000`14A4@0oooo0?oo
o`060?ooo`H0000000<0R8R80?ooo`3oool04@3oool50000000308R8R03oool0oooo00@0oooo00<0
^k^k000000000000100000000`3^k^h0oooo0?ooo`060?ooo`030>KViP3oool0oooo00L0oooo00<0
MgMg0000000000000`0000000`14A4@0oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib40oooo00<0GUiN000000000000
0P0000001@0=3@d00000000000000000<c<c00L0oooo00D0DE5A000000000000000000d=3@040000
000300T92@3^k^h0oooo00T0oooo00<0R8R8000000000000100000080?ooo`030820P00000000000
00<0000000<0R8R80?ooo`3oool01@3oool00`3gmoL0TI6A00T92@040000000300T92@2ZZZX0oooo
00P0oooo1@0000000`28R8P0oooo0?ooo`0P0?ooo`D0000000<0R8R80?ooo`3oool0103oool00`24
Q8@00000000000030000000307MgM`3oool0oooo00H0oooo00<0EEEE0000000000000P0000000`1J
FUX0oooo0?ooo`090?ooo`03069RHP00000000000080000000<04A4A0>KViP3oool01P3oool00`14
A4@0000000000003000000L0oooo00H0IVIV000000000000000001XJ6P0F5QH4000000/0oooo00<0
;bl_0000000000000`0000000`1NGUh0i^KV0?ooo`070?ooo`030820P0000000000000<000002@3o
ool50000000304A4A03oool0oooo01l0oooo00<0moOg03`l?00000000`0000000`0A4A40gMgM0?oo
o`080?ooo`030?Ogm`0W9bL0000000<0000000<04A4A0=gMg@3oool01`3oool50000000304A4A03o
ool0oooo01h0oooo00<0TI6A0000000000000`0000000`0A4A40moOg0?ooo`060?ooo`030;^k^`00
0000000000<0000000<06QXJ0?Ogm`3oool04@3oool00`3^k^h06QXJ000000030000000301XJ6P3o
ool0oooo00H0oooo1P0000000`28R8P0oooo0?ooo`0A0?ooo`D0000000<0R8R80?ooo`3oool0103o
ool00`24Q8@00000000000030000000307MgM`3oool0oooo0140oooo00<0k^k^01XJ6P0000000`00
00000`0J6QX0oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWib40oooo1@0000001@1=CDd000000000000000002@T900L0
oooo00H0?3`l000000000000000004A4A00R8R840000000309VIV@3oool0oooo00P0oooo00<0R8R8
000000000000100000080?ooo`030820P0000000000000<0000000<0R8R80?ooo`3oool01`3oool0
0`1NGUh000000000000300000003014A4@3^k^h0oooo00L0oooo1@0000000`28R8P0oooo0?ooo`0P
0?ooo`D0000000<0R8R80?ooo`3oool0103oool00`14A4@0000000000003000000030>k^kP3oool0
oooo00H0oooo00<0gMgM0000000000004`0000000`1gMgL0oooo0?ooo`060?ooo`0304A4A0000000
000000<000001P3oool00`2k^k/00000000000020000000309VIV@0R8R80000000<000002P3oool0
0`2ZZZX00000000000030000000304A4A03oool0oooo00P0oooo00<0P8200000000000000`000009
0?ooo`D0000000<0A4A40?ooo`3oool07`3oool00`2IVIT00000000000030000000305EEE@3oool0
oooo00T0oooo00<0MgMg0000000000000`0000000`1VIVH0oooo0?ooo`060?ooo`D0000000<0A4A4
0?ooo`3oool07P3oool00`14A4@00000000000030000000304A4A03oool0oooo00H0oooo00<0gMgM
000000000000100000000`2k^k/0oooo0?ooo`0A0?ooo`0304A4A0000000000000<00000203oool6
0000000308R8R03oool0oooo0140oooo1@0000000`28R8P0oooo0?ooo`040?ooo`0304A4A0000000
000000<0000000<0k^k^0?ooo`3oool04P3oool00`14A4@000000000000300000?l0ooooo`3ooooo
0?oooeX0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW803o
ool00`3<c<`0000000000003000000030820P000000000000080000000<0k^k^0?ooo`3oool0103o
ool0100R8R80000000000000000205EEE@@0000000<0MgMg0?ooo`3oool0203oool00`28R8P00000
00000004000000P0oooo00<0P8200000000000000`0000000`28R8P0oooo0?ooo`070?ooo`030:ZZ
ZP000000000000@0000000<0VIVI0?ooo`3oool01P3oool50000000308R8R03oool0oooo0200oooo
1@0000000`28R8P0oooo0?ooo`040?ooo`0302/[:`00000000000080000000<0EEEE0?ooo`3oool0
203oool00`0J6QX000000000000B000000030<c<c03oool0oooo00H0oooo00<0A4A4000000000000
0`0000060?ooo`0706IVIP00000000000000000A4A40k^k^028R8P04000000X0oooo00<0IVIV0000
000000000`0000000`2ZZZX0oooo0?ooo`080?ooo`030820P0000000000000<000002@3oool50000
000304A4A03oool0oooo01l0oooo00<0IVIV0000000000000`0000000`20P800oooo0?ooo`090?oo
o`030::RXP000000000000<0000000<08R8R0?ooo`3oool01P3oool50000000304A4A03oool0oooo
01h0oooo00<0<c<c0000000000000`0000000`28R8P0oooo0?ooo`070?ooo`H0000000<0ZZZZ0?oo
o`3oool04@3oool00`14A4@0000000000003000000P0oooo1P0000000`28R8P0oooo0?ooo`0A0?oo
o`D0000000<0R8R80?ooo`3oool0103oool00`0[:b/00000000000020000000305EEE@3oool0oooo
01<0oooo00<0A4A40000000000000`00003o0?ooool0ooooo`3ooomJ0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib00oooo00<0VIVI0000000000000`000000
0`2c/k<0000000000002000000030;^k^`3oool0oooo00@0oooo100000000`1_Kfl0R8R800000003
0000000304A4A03oool0oooo00P0oooo00<0R8R8000000000000100000080?ooo`030820P0000000
000000<0000000<0R8R80?ooo`3oool01`3oool00`3MgMd00000000000040000000305EEE@3oool0
oooo00H0oooo1@0000000`28R8P0oooo0?ooo`0P0?ooo`D0000000<0R8R80?ooo`3oool00`3oool0
0`3^k^h00000000000030000000309VIV@3oool0oooo00P0oooo00<0A4A40000000000004@000000
0`0A4A40oooo0?ooo`070?ooo`0304A4A0000000000000<000001@3oool00`3MgMd0000000000002
0000000307MgM`3oool08R8R00@000002P3oool00`0A4A4000000000000200000003014A4@3oool0
oooo00T0oooo00<0P8200000000000000`0000090?ooo`D0000000<0A4A40?ooo`3oool07`3oool0
0`0A4A40000000000003000000030::RXP3oool0oooo00T0oooo00<0a<C400000000000010000000
0`3<c<`0oooo0?ooo`050?ooo`D0000000<0A4A40?ooo`3oool07P3oool60000000308R8R03oool0
oooo00L0oooo1P0000000`28R8P0oooo0?ooo`0A0?ooo`03014A4@00000000000080000000<02@T9
0?ooo`3oool01P3oool60000000308R8R03oool0oooo0140oooo1@0000000`28R8P0oooo0?ooo`03
0?ooo`030>k^kP000000000000<0000000<0VIVI0?ooo`3oool04`3oool00`0A4A40000000000002
0000000300T92@3oool0oooo0?l0ooooo`3ooooo0?oooeP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOW803oool00`1NGUh00000000000020000000304e=C@3A
dM40000000<0000000<0Kfm_0?ooo`3oool00`3oool00`34a<@000000000000200000003096AT@3E
eMD0000000@0000000<0i^KV0?ooo`3oool01`3oool00`28R8P0000000000004000000P0oooo00<0
P8200000000000000`0000000`28R8P0oooo0?ooo`080?ooo`0304A4A0000000000000@0000000<0
k^k^0?ooo`3oool01@3oool50000000308R8R03oool0oooo0200oooo1@0000000`28R8P0oooo0?oo
o`030?ooo`0306m_K`00000000000080000000<05QHF0?Ogm`3oool02@3oool00`24Q8@000000000
000A00000003055AD@3oool0oooo00L0oooo00<0A4A40000000000000`0000050?ooo`0805EEE@00
000000000000000[:b/0k^k^0?ooo`0R8R84000000T0oooo00<0ZZZZ0000000000000`0000000`14
A4@0oooo0?ooo`090?ooo`030820P0000000000000<000002@3oool50000000304A4A03oool0oooo
01h0oooo00<0c<c<000000000000100000000`3<c<`0oooo0?ooo`090?ooo`030>[ZjP0000000000
00@0000000<0TI6A0?ooo`3oool01@3oool50000000304A4A03oool0oooo01h0oooo1P0000000`28
R8P0oooo0?ooo`070?ooo`H0000000<0R8R80?ooo`3oool03`3oool00`3Vi^H0EEEE000000040000
000302/[:`3oool0oooo00H0oooo1P0000000`28R8P0oooo0?ooo`0A0?ooo`D0000000<0R8R80?oo
o`3oool00`3oool00`1_Kfl00000000000020000000301HF5P3gmoL0oooo0180oooo00<0i^KV05EE
E@000000100000000`0[:b/0oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`040>WYj@3AdM40dM7A
0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWib00oooo1@0000000`28R8P0oooo00000003
00000003028R8P3oool0oooo00<0oooo00<0R8R80000000000000P0000000`2k^k/0oooo014A4@04
0000000309VIV@3oool0oooo00L0oooo00<0R8R8000000000000100000080?ooo`030820P0000000
000000<0000000<0R8R80?ooo`3oool0203oool00`2IVIT0000000000004000000030<C4a03oool0
oooo00D0oooo1@0000000`28R8P0oooo0?ooo`0P0?ooo`D0000000<0R8R80?ooo`3oool00P3oool0
0`2IVIT00000000000030000000304e=C@3oool0oooo00T0oooo00<0a<C40000000000000`000000
0`0c<c<0A4A404A4A00604A4A0D0000000<0R8R80?ooo`3oool01`3oool00`14A4@0000000000003
000000@0oooo00<0c<c<0000000000000P000000102ZZZX0oooo0?ooo`0R8R84000000T0oooo00<0
IVIV0000000000000`0000000`1_Kfl0oooo0?ooo`090?ooo`030820P0000000000000<000002@3o
ool50000000304A4A03oool0oooo01h0oooo00<0R8R8000000000000100000000`3MgMd0oooo0?oo
o`0:0?ooo`H0000000<0A4A40?ooo`3oool01@3oool50000000304A4A03oool0oooo01h0oooo1P00
00000`28R8P0oooo0?ooo`070?ooo`H0000000<0R8R80?ooo`3oool03P3oool00`3EeMD04A4A0000
00050000000304e=C@3oool0oooo00H0oooo1P0000000`28R8P0oooo0?ooo`0A0?ooo`D0000000<0
R8R80?ooo`3oool00P3oool00`2IVIT00000000000030000000304e=C@3oool0oooo0140oooo00<0
eMGE014A4@0000001@0000000`1=CDd0oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWial0oooo00<0^k^k000000000000
0`0000000`2k^k/0oooo028R8P04000000030>k^kP3oool0oooo0080oooo00<0EEEE000000000000
0P0000000`3<c<`0oooo04A4A0040000000306IVIP3oool0oooo00L0oooo00<0R8R8000000000000
100000080?ooo`030820P0000000000000<0000000<0R8R80?ooo`3oool0203oool00`2k^k/00000
00000004000000030<C4a03oool0oooo00D0oooo1@0000000`28R8P0oooo0?ooo`0P0?ooo`D00000
00H0R8R80?ooo`3oool0oooo08R8R00A4A450000000308R8R03oool0oooo00T0oooo00<0k^k^0000
000000000`0000000`2IVIT0oooo0?ooo`050?ooo`030:ZZZP000000000000<0000000<0/k>c0?oo
o`3oool01`3oool00`14A4@0000000000003000000@0oooo00D0XZ:R0000000000000000014A4@03
0?ooo`03028R8P0000000000008000002@3oool00`14A4@0000000000003000000030820P03oool0
oooo00T0oooo00<0P8200000000000000`0000090?ooo`D0000000<0A4A40?ooo`3oool07P3oool0
0`28R8P0000000000004000000030?Ogm`3oool0oooo00X0oooo00<0<c<c0000000000000`000000
0`14A4@0oooo0?ooo`050?ooo`D0000000<0A4A40?ooo`3oool07P3oool60000000308R8R03oool0
oooo00L0oooo1P0000000`28R8P0oooo0?ooo`0=0?ooo`030=gMg@0[:b/0000000H0000000<0P820
0?ooo`3oool01P3oool60000000308R8R03oool0oooo0140oooo1@0000001P28R8P0oooo0?ooo`3o
ool0R8R8014A4@D0000000<0R8R80?ooo`3oool0403oool00`3MgMd0:b/[00000006000000030820
P03oool0oooo0?l0ooooo`3ooooo0?oooeP0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo
00@0jNWY0=7Ad@3AdM40inOW7`3oool00`28R8P0000000000003000000030>k^kP3oool0EEEE00@0
000000<0^k^k0?ooo`3oool00P3oool00`0R8R80000000000002000000030>KViP3oool0R8R800@0
000000<0<c<c0?ooo`3oool01`3oool00`28R8P0000000000004000000P0oooo00<0P82000000000
00000`0000000`28R8P0oooo0?ooo`080?ooo`030>k^kP000000000000@0000000<0/k>c0?ooo`3o
ool01@3oool50000000308R8R03oool0oooo0200oooo1@0000001014A4@0R8R808R8R01=CDd70000
00030<C4a03oool0oooo00X0oooo00<0<c<c0000000000000P0000000`1EEED0oooo0?ooo`050?oo
o`0307MgM`000000000000<0000000<0eMGE0?ooo`3oool01`3oool00`14A4@00000000000030000
00@0oooo00D0IVIV000000000000000004A4A0030?ooo`03028R8P0000000000008000002@3oool0
0`0c<c<000000000000300000003096AT@3oool0oooo00D0oooo00<08R8R0000000000001`000009
0?ooo`D0000000<0A4A40?ooo`3oool07P3oool00`1VIVH0000000000004000000d0oooo00<0A4A4
0000000000000`0000000`0R8R80oooo0?ooo`050?ooo`D0000000<0A4A40?ooo`3oool07P3oool6
0000000308R8R03oool0oooo00L0oooo1P0000000`28R8P0oooo0?ooo`0<0?ooo`0308R8R00A4A40
000000L0000000<0a<C40?ooo`3oool01P3oool60000000308R8R03oool0oooo0140oooo1@000000
1014A4@0R8R808R8R01=CDd7000000030<C4a03oool0oooo00l0oooo00<0R8R8014A4@0000001`00
00000`34a<@0oooo0?ooo`3o0?ooool0ooooo`3ooomH0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo
00070?ooo`040>WYj@3AdM40dM7A0>OWial0oooo00<0CDe=0000000000000P000000100c<c<0oooo
0?ooo`2RXZ840000000506m_K`3oool0oooo0?ooo`3MgMd010000000100R8R80oooo0?ooo`34a<@5
000000030>k^kP3oool0oooo00H0oooo00<0R8R8000000000000100000080?ooo`030820P0000000
000000<0000000<0R8R80?ooo`3oool02@3oool6000000030::RXP3oool0oooo00D0oooo40000000
0`34a<@0oooo0?ooo`0E0?ooo`h0000000<08R8R096AT@3oool0303oool00`2c/k<0000000000003
000000030=GEe@3oool0oooo00<0oooo00<0k^k^014A4@0000000`0000000`0l?3`0oooo0?ooo`08
0?ooo`0304A4A0000000000000<000000`3oool00`3gmoL07QhN000000020000000509FEU@3oool0
oooo0?ooo`0R8R80100000090?ooo`H0000000<0XZ:R0?ooo`3oool01@3oool00`0R8R8000000000
0007000000T0oooo400000000`28R8P0oooo0?ooo`0C0?ooo`0304A4A0000000000000@000003@3o
ool00`14A4@0000000000004000000L0oooo4000000F0?ooo`H0000000<0R8R80?ooo`3oool01`3o
ool60000000308R8R03oool0oooo00T0oooo00<0k^k^07alO00A4A40200000000`0J6QX0VIVI0?oo
o`080?oooa00000000<0R8R80?ooo`3oool01`3oool>00000003028R8P2ATI40oooo00h0oooo00<0
k^k^07alO00A4A40200000000`0J6QX0VIVI0?ooo`3o0?ooool0ooooo`3ooomJ0?ooo`040>WYj@3A
dM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWial0oooo1@0000001028R8P0oooo
0?ooo`3^k^h40000000503<c<`3oool0oooo0?ooo`28R8P0100000001@1gMgL0oooo0?ooo`3oool0
4A4A00@0000000<0a<C40?ooo`3oool01P3oool00`28R8P0000000000004000000P0oooo00<0P820
0000000000000`0000000`28R8P0oooo0?ooo`090?ooo`H0000000<0XZ:R0?ooo`3oool01@3oool@
000000030<C4a03oool0oooo01D0oooo300000000`092@T0MgMg0<c<c00?0?ooo`0303<c<`000000
00000080000000<0IVIV0?ooo`3oool00`3oool00`28R8P0000000000003000000030:ZZZP3oool0
oooo00P0oooo00<0A4A40000000000000`0000030?ooo`0308R8R000000000000080000000D0i^KV
0?ooo`3oool0oooo028R8P04000000T0oooo1P0000000`2RXZ80oooo0?ooo`050?ooo`03028R8P00
0000000000L000002@3oool@0000000308R8R03oool0oooo01<0oooo00<0A4A40000000000001000
000=0?ooo`0304A4A0000000000000@000001`3oool@000001H0oooo1P0000000`28R8P0oooo0?oo
o`070?ooo`H0000000<0R8R80?ooo`3oool0203oool00`2IVIT04A4A000000080000000306IVIP3^
k^h0oooo00T0oooo400000000`28R8P0oooo0?ooo`070?ooo``0000000<02@T907MgM`3<c<`03`3o
ool00`2IVIT04A4A000000080000000306IVIP3^k^h0oooo0?l0ooooo`3ooooo0?oooe/0oooo00@0
jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW7P3oool00`3MgMd00000
00000003000000050:ZZZP3oool0oooo0?ooo`0R8R80100000030?ooo`0307MgM`00000000000080
000000D0VIVI0?ooo`3oool0oooo04A4A004000000030;>c/`3oool0oooo00H0oooo00<0R8R80000
00000000100000080?ooo`030820P0000000000000<0000000<0R8R80?ooo`3oool02@3oool60000
00030::RXP3oool0oooo00D0oooo400000000`34a<@0oooo0?ooo`0E0?ooo`l0000000<0A4A40=gM
g@3oool0303oool00`28R8P000000000000200000003014A4@3oool0oooo00<0oooo00<0EEEE0000
000000000P0000000`0A4A40oooo0?ooo`090?ooo`0304A4A0000000000000<000000`3oool01@0R
8R800000000000000000A4A400@0oooo00<08R8R0000000000000P0000090?ooo`H0000000<0XZ:R
0?ooo`3oool01@3oool00`0R8R80000000000007000000T0oooo400000000`28R8P0oooo0?ooo`0C
0?ooo`0304A4A0000000000000@000003@3oool00`14A4@0000000000004000000L0oooo4000000F
0?ooo`H0000000<0R8R80?ooo`3oool01`3oool60000000308R8R03oool0oooo00L0oooo00<0IVIV
000000000000200000000`1VIVH0oooo0?ooo`0:0?oooa00000000<0R8R80?ooo`3oool01`3oool?
0000000304A4A03MgMd0oooo00/0oooo00<0IVIV000000000000200000000`1VIVH0oooo0?ooo`3o
0?ooool0ooooo`3ooomL0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWiah0oooo00<0a<C40000000000000`0000001@3<c<`0oooo0?ooo`3oool0EEEE00@00000
00@0^k^k0?ooo`3oool0A4A4100000001@3<c<`0oooo0?ooo`3oool0MgMg00@0000000<0VIVI0?oo
o`3oool01P3oool00`28R8P0000000000004000000P0oooo00<0P8200000000000000`0000000`28
R8P0oooo0?ooo`080?ooo`030>k^kP000000000000@0000000<0ZZZZ0?ooo`3oool01@3oool@0000
00030<C4a03oool0oooo01D0oooo400000000`0l?3`0oooo0?ooo`0;0?ooo`030=gMg@0000000000
00<0000000<0i^KV0?ooo`3oool00P3oool50000000306IVIP3oool0oooo00T0oooo00<0A4A40000
000000000`0000020?ooo`030:ZZZP00000000000080000000<0VIVI0?ooo`3oool00P3oool00`0R
8R80000000000002000000T0oooo00<04A4A0000000000000`0000000`2IVIT0oooo0?ooo`050?oo
o`0305iNGP14A4@0A4A400L0A4A42@3oool@0000000308R8R03oool0oooo01<0oooo00<0IVIV0000
000000001000000=0?ooo`0304A4A0000000000000<0000000<08R8R0?ooo`3oool01@3oool@0000
01H0oooo1P0000000`28R8P0oooo0?ooo`070?ooo`H0000000<0R8R80?ooo`3oool01P3oool00`34
a<@00000000000080000000308R8R03gmoL0oooo00/0oooo400000000`28R8P0oooo0?ooo`070?oo
oa00000000<0?3`l0?ooo`3oool02@3oool00`34a<@00000000000080000000308R8R03gmoL0oooo
0?l0ooooo`3ooooo0?oooed0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7A
d@3AdM40inOW7P3oool00`2VYZH000000000000200000003028R8P3oool0oooo0080oooo00<0XZ:R
0000000000000P0000000`1gMgL0oooo0>KViP040000000301XJ6P3oool0oooo0080oooo00<0/k>c
0000000000000P0000000`1[Jf/0oooo0?ooo`060?ooo`0308R8R0000000000000@00000203oool0
0`20P8000000000000030000000308R8R03oool0oooo00P0oooo00<0ZZZZ00000000000010000000
0`34a<@0oooo0?ooo`050?ooo`D0000000<0A4A40820P020P8002020P8000`3Rh^80oooo0?ooo`0E
0?ooo`D0000000P0R8R80?ooo`3oool0oooo0>KViP34a<@0R8R801XJ6P@0000000<0?3`l0=GEe@3o
ool02`3oool00`1NGUh0000000000002000000050:JVYP3oool0oooo0?ooo`3<c<`0100000000`09
2@T0eMGE0?ooo`0:0?ooo`0304A4A0000000000000<0000000<0oooo0>k^kP0[:b/00`0000000`1=
CDd0oooo0?ooo`030?ooo`03028R8P0000000000008000002@3oool00`1=CDd00000000000030000
000307MgM`3oool0oooo01P0oooo1@0000000`0R8R80P8200820P0080820P0030<C4a03oool0oooo
01<0oooo00<0R8R8000000000000100000000`3Zj^X0oooo0?ooo`0:0?ooo`0301XJ6P0000000000
00<0000000<0A4A40?ooo`3oool01@3oool500000003028R8P20P800P82000P0P8205P3oool60000
000308R8R03oool0oooo00L0oooo1P0000000`28R8P0oooo0?ooo`060?ooo`030410@00000000000
00D0000000<0<c<c0::RXP3^k^h03P3oool60000000304A4A020P800P82000L0P82000<0a<C40?oo
o`3oool01`3oool50000000808R8R03oool0oooo0?ooo`3Vi^H0a<C408R8R00J6QX40000000303`l
?03EeMD0oooo00P0oooo00<0@4100000000000001@0000000`0c<c<0XZ:R0>k^kP3o0?ooool0oooo
o`3ooomP0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiah0
oooo00<0P8200000000000000P0000000`1VIVH0oooo0?ooo`020?ooo`030>k^kP00000000000080
000000<0<c<c0?ooo`2ZZZX0100000000`1VIVH0oooo0?ooo`030?ooo`@0000000<0A4A40?ooo`3o
ool01P3oool00`28R8P0000000000004000000P0oooo00<0P8200000000000000`0000000`28R8P0
oooo0?ooo`080?ooo`0306IVIP000000000000@0000000<0gMgM0?ooo`3oool01@3oool500000003
08R8R03oool0oooo0200oooo1@0000000`28R8P0oooo0?ooo`040?ooo`03096AT@000000000000<0
000000<08R8R0?ooo`3oool02P3oool00`3^k^h00000000000020000000506m_K`3oool0oooo0?oo
o`2IVIT0100000000`1VIVH0oooo0?ooo`0:0?ooo`0304A4A0000000000000<0000000<0oooo07Mg
M`0000000`0000000`3MgMd0oooo0?ooo`030?ooo`03028R8P0000000000008000002@3oool00`28
R8P00000000000030000000305EEE@3oool0oooo01P0oooo1@0000000`14A4@0oooo0?ooo`0N0?oo
o`030;^k^`000000000000@0000000<0eMGE0?ooo`3oool02@3oool00`3gmoL00000000000040000
000308R8R03oool0oooo00D0oooo1@0000000`14A4@0oooo0?ooo`0N0?ooo`H0000000<0R8R80?oo
o`3oool01`3oool60000000308R8R03oool0oooo00D0oooo00<0c<c<0000000000001@0000000`1g
MgL0moOg0?ooo`0?0?ooo`H0000000<0R8R80?ooo`3oool04@3oool50000000308R8R03oool0oooo
00@0oooo00<0TI6A0000000000000`0000000`0R8R80oooo0?ooo`060?ooo`030<c<c00000000000
00D0000000<0MgMg0?Ogm`3oool0o`3ooooo0?ooool0ooooH@3oool0103YjNT0dM7A0=7Ad@3Lg=`=
0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinLN0?ooo`0305iNGP00000000000080000000<0R8R8
0?ooo`3oool00`3oool00`0R8R80000000000002000000030?ooo`28R8P0000000<0000000<0R8R8
0?ooo`3oool00`3oool01@0R8R800000000000000000:b/[00P0oooo00<0R8R80000000000001000
00080?ooo`030820P0000000000000<0000000<0R8R80?ooo`3oool0203oool00`0R8R8000000000
0004000000030?Ogm`3oool0oooo00D0oooo1@0000000`28R8P0oooo0?ooo`0P0?ooo`D0000000<0
R8R80?ooo`3oool0103oool00`3<c<`0000000000004000000030<c<c03oool0oooo00X0oooo00D0
:b/[000000000000000004A4A0030?ooo`0306m_K`00000000000080000000<0VIVI0?ooo`3oool0
2P3oool00`14A4@0000000000003000000030?Ogm`0A4A4000000080000000<0EEEE0?ooo`3oool0
103oool00`0R8R80000000000002000000T0oooo00<0ZZZZ0000000000000`0000000`0c<c<0oooo
0?ooo`0H0?ooo`D0000000<0A4A40?ooo`3oool07P3oool00`3MgMd0000000000004000000030<C4
a03oool0oooo00T0oooo00<0gMgM000000000000100000000`2IVIT0oooo0?ooo`050?ooo`D00000
00<0A4A40?ooo`3oool07P3oool60000000308R8R03oool0oooo00L0oooo1P0000000`28R8P0oooo
0?ooo`050?ooo`0308R8R0000000000000@0000000<0VIVI0?ooo`3oool0403oool60000000308R8
R03oool0oooo0140oooo1@0000000`28R8P0oooo0?ooo`040?ooo`030<c<c0000000000000@00000
00<0c<c<0?ooo`3oool01@3oool00`28R8P00000000000040000000309VIV@3oool0oooo0?l0oooo
o`3ooooo0?ooof80oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40
inOW7P3oool00`14A4@0000000000002000000030;^k^`3oool0oooo00<0oooo00<0EEEE00000000
00000P0000000`3MgMd0A4A400000003000000030;^k^`3oool0oooo00<0oooo00D0<c<c00000000
00000000014A4@080?ooo`0308R8R0000000000000@00000203oool00`20P8000000000000030000
000308R8R03oool0oooo00L0oooo00<0gMgM000000000000100000000`0c<c<0oooo0?ooo`060?oo
o`D0000000<0R8R80?ooo`3oool0803oool50000000308R8R03oool0oooo00@0oooo00<0moOg0000
00000000100000000`28R8P0oooo0?ooo`0:0?ooo`0504e=C@00000000000000000J6QX00`3oool0
0`1=CDd0000000000002000000030>k^kP3oool0oooo00X0oooo00<0A4A40000000000000`000000
0`3<c<`0000000000002000000030;^k^`3oool0oooo00@0oooo00<08R8R0000000000000P000009
0?ooo`030>k^kP000000000000<0000000<02@T90?ooo`3oool0603oool50000000304A4A03oool0
oooo01l0oooo00<04A4A0000000000000`0000000`2RXZ80oooo0?ooo`090?ooo`030<C4a0000000
000000@0000000<0c<c<0?ooo`3oool01@3oool50000000304A4A03oool0oooo01h0oooo1P000000
0`28R8P0oooo0?ooo`070?ooo`H0000000<0R8R80?ooo`3oool01@3oool00`14A4@0000000000003
0000000308R8R03oool0oooo0140oooo1P0000000`28R8P0oooo0?ooo`0A0?ooo`D0000000<0R8R8
0?ooo`3oool0103oool00`3gmoL00000000000040000000308R8R03oool0oooo00D0oooo00<0A4A4
0000000000000`0000000`28R8P0oooo0?ooo`3o0?ooool0ooooo`3ooomS0?ooo`040>WYj@3AdM40
dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiah0oooo00D09bLW0000000000000000
00T92@060?ooo`030::RXP00000000000080000000<0`<30014A4@0000000P0000000`0J6QX0oooo
0?ooo`040?ooo`03055AD@00000000000080000000<0c<c<0?ooo`3oool01@3oool00`28R8P00000
00000004000000P0oooo00<0P8200000000000000`0000000`28R8P0oooo0?ooo`070?ooo`0308B4
Q0000000000000@0000000<0XZ:R0?ooo`3oool01P3oool50000000308R8R03oool0oooo0200oooo
1@0000000`28R8P0oooo0?ooo`050?ooo`H0000000<0CDe=0?ooo`3oool02P3oool00`2ATI400000
00000002000000040<C4a03oool0oooo01XJ6P<0000000<0?3`l0?ooo`3oool02`3oool00`14A4@0
0000000000030000000507alO000000000000000000_;bl01`3oool00`0R8R800000000000020000
00X0oooo00<0MgMg0000000000000`0000000`1NGUh0oooo0?ooo`0G0?ooo`D0000000<0A4A40?oo
o`3oool07`3oool00`20P8000000000000030000000306][J`3oool0oooo00T0oooo00<0R8R80000
000000000`0000000`14A4@0oooo0?ooo`060?ooo`D0000000<0A4A40?ooo`3oool07P3oool60000
000308R8R03oool0oooo00L0oooo1P0000000`28R8P0oooo0?ooo`050?ooo`03014A4@0000000000
0080000000<04A4A0?Ogm`3oool04P3oool60000000308R8R03oool0oooo0140oooo1@0000000`28
R8P0oooo0?ooo`050?ooo`H0000000<0CDe=0?ooo`3oool01@3oool00`0A4A400000000000020000
0003014A4@3gmoL0oooo0?l0ooooo`3ooooo0?ooof@0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3oool0
00L0oooo00@0jNWY0=7Ad@3AdM40inOW7@3oool00`3^k^h00000000000020000000302/[:`3oool0
oooo00@0oooo00<0k^k^0000000000000P0000000`20P8000000000000020000000306IVIP3oool0
oooo00@0oooo00<0P8200000000000000P0000000`28R8P0oooo0?ooo`050?ooo`0308R8R0000000
000000@00000203oool00`20P8000000000000030000000308R8R03oool0oooo00H0oooo00<0k^k^
014A4@000000100000000`14A4@0oooo0?ooo`070?ooo`D0000000<0R8R80?ooo`3oool0803oool5
0000000308R8R03oool0oooo00@0oooo00<0k^k^000000000000100000000`14A4@0oooo0?ooo`0:
0?ooo`030<c<c000000000000080000000<0EEEE0?ooo`2k^k/0100000000`1gMgL0oooo0?ooo`0;
0?ooo`0304A4A0000000000000<0000000D0<c<c00000000000000000820P0070?ooo`03028R8P00
00000000008000002P3oool00`3^k^h02@T9000000040000000308R8R03oool0oooo01H0oooo1@00
00000`14A4@0oooo0?ooo`0O0?ooo`030>k^kP0A4A40000000<0000000<08R8R0?ooo`3oool02@3o
ool00`14A4@0000000000003000000030;^k^`3oool0oooo00H0oooo1@0000000`14A4@0oooo0?oo
o`0N0?ooo`H0000000<0R8R80?ooo`3oool01`3oool60000000308R8R03oool0oooo00D0oooo1@00
00000`0R8R80oooo0?ooo`0B0?ooo`H0000000<0R8R80?ooo`3oool04@3oool50000000308R8R03o
ool0oooo00@0oooo00<0k^k^000000000000100000000`14A4@0oooo0?ooo`050?ooo`D0000000<0
8R8R0?ooo`3oool0o`3ooooo0?ooool0ooooI03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinLM0?ooo`030;^k^`00000000000080000000<0A4A40?ooo`3oool0
1@3oool01@0A4A400000000000000000A4A400@0000000<0R8R80?ooo`3oool0103oool00`2IVIT0
0000000000020000000304A4A03oool0oooo00D0oooo00<0R8R8000000000000100000080?ooo`03
0820P0000000000000<0000000<0R8R80?ooo`3oool01@3oool00`3^k^h0<c<c0000000500000003
0;^k^`3oool0oooo00L0oooo1@0000000`28R8P0oooo0?ooo`0P0?ooo`D0000000<0R8R80?ooo`3o
ool0103oool00`3<c<`00000000000040000000308R8R03oool0oooo00X0oooo00<0moOg00000000
00000`0000000`3oool0R8R800000003000000030:ZZZP3oool0oooo00/0oooo00<0A4A400000000
00001`0000000`2c/k<0oooo0?ooo`050?ooo`03028R8P0000000000008000002`3oool00`14A4@0
000000000004000000030;^k^`3oool0oooo01D0oooo1@0000000`14A4@0oooo0?ooo`0P0?ooo`03
06IVIP000000000000<0000000<0^k^k0?ooo`3oool01`3oool00`3^k^h02@T90000000300000003
028R8P3oool0oooo00L0oooo1@0000000`14A4@0oooo0?ooo`0N0?ooo`H0000000<0R8R80?ooo`3o
ool01`3oool60000000308R8R03oool0oooo00D0oooo00<0<c<c0000000000000P0000000`0A4A40
oooo0?ooo`0B0?ooo`H0000000<0R8R80?ooo`3oool04@3oool50000000308R8R03oool0oooo00@0
oooo00<0c<c<000000000000100000000`28R8P0oooo0?ooo`050?ooo`0303<c<`00000000000080
000000<04A4A0?ooo`3oool0o`3ooooo0?ooool0ooooI03oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinLM0?ooo`0308R8R000000000000080000000<0EEEE0?oo
o`3oool01@3oool01@0R8R8000000000000000006QXJ00@0000000<0^k^k0?ooo`3oool0103oool0
0`2c/k<000000000000200000003014A4@3oool0oooo00D0oooo00<0R8R800000000000010000008
0?ooo`030820P0000000000000<0000000<0R8R80?ooo`3oool0103oool00`2k^k/04A4A00000005
0000000304A4A03oool0oooo00P0oooo1@0000000`28R8P0oooo0?ooo`0P0?ooo`D0000000<0R8R8
0?ooo`3oool0103oool00`20P8000000000000040000000309VIV@3oool0oooo00/0oooo00<0EEEE
0000000000000P0000000`2ZZZX0<c<c00000003000000030<c<c03oool0oooo00/0oooo00<0A4A4
0000000000001`0000000`3^k^h0oooo0?ooo`050?ooo`03028R8P0000000000008000002`3oool0
0`28R8P000000000000400000003014A4@3MgMd0oooo00X0oooo00<0i^KV0?ooo`3oool0203oool5
0000000304A4A03oool0oooo0200oooo00<0gMgM0000000000000`0000000`0R8R80k^k^0?ooo`07
0?ooo`0305EEE@000000000000<0000000<0VIVI0?ooo`3oool01`3oool50000000304A4A03oool0
oooo01h0oooo1P0000000`28R8P0oooo0?ooo`070?ooo`H0000000<0R8R80?ooo`3oool01@3oool0
0`1EEED0000000000003000000030;^k^`3oool0oooo0140oooo1P0000000`28R8P0oooo0?ooo`0A
0?ooo`D0000000<0R8R80?ooo`3oool0103oool00`20P8000000000000040000000309VIV@3oool0
oooo00D0oooo00<0EEEE0000000000000`0000000`2k^k/0oooo0?ooo`3o0?ooool0ooooo`3ooomS
0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40dM7A0>OWiad0oooo00<0
?3`l0000000000000P0000000`1gMgL0oooo0?ooo`050?ooo`0304e=C@000000000000D0000000<0
2@T90?ooo`3oool01@3oool00`3AdM40000000000003000000030<C4a03oool0oooo00@0oooo00<0
R8R8000000000000100000080?ooo`030820P0000000000000<0000000L0EEEE0::RXP2RXZ80XZ:R
096AT@1gMgL0>3Ph00L0000000<0<c<c0>k^kP3oool02@3oool50000000304A4A020P800P82000P0
P82000<0[jn_0?ooo`3oool05@3oool50000000305EEE@2RXZ80XZ:R0080XZ:R00<0P82004e=C@09
2@T01@0000000`0R8R80k^k^0?ooo`0<0?ooo`030<C4a000000000000080000000<0:b/[00000000
00000P0000000`0[:b/0no_k0?ooo`0<0?ooo`0304A4A0000000000000H0000000<0MgMg0?ooo`3o
ool01P3oool00`0R8R80000000000002000000/0oooo00<0j^[Z03`l?00000001@0000001@0R8R80
P8200;^k^`3MgMd0no_k00<0oooo00<0dM7A0:ZZZP1gMgL00P1=CDd:0?ooo`D0000000<08R8R0820
P020P8002@20P8000`3^k^h0oooo0?ooo`0E0?ooo`03069RHP000000000000<0000000<06QXJ08R8
R03Vi^H00`3oool00`3^k^h0XZ:R03<c<`05000000030410@03oool0oooo00P0oooo1@0000000`0R
8R80P8200820P0080820P0030<C4a03oool0oooo01<0oooo1P0000000`28R8P0oooo0?ooo`070?oo
o`H0000000<0R8R80?ooo`3oool01@3oool00`2k^k/01@D5000000030000000401XJ6P28R8P0c<c<
0?_kn`80oooo00D0k^k^0<C4a028R8P0EEEE09VIV@090?ooo`H0000000<0A4A40820P020P8002020
P8000`3MgMd0oooo0?ooo`060?ooo`D0000000<0EEEE0::RXP2RXZ800P2RXZ800`20P800CDe=00T9
2@0500000003028R8P3^k^h0oooo00H0oooo00<0^k^k00D51@0000000`000000100J6QX0R8R80<c<
c03kno/20?ooo`050>k^kP34a<@0R8R805EEE@2IVIT0o`3ooooo0?ooool0ooooF`3oool0103YjNT0
dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinLL0?ooo`030>k^kP0000000000
00<0000000<0XZ:R0?ooo`3oool01@3oool00`1_Kfl00000000000050000000302/[:`3oool0oooo
00D0oooo00<0moOg0000000000000`0000000`1gMgL0oooo0?ooo`040?ooo`0308R8R00000000000
00@00000203oool00`20P80000000000000@00000003014A4@3<c<`0oooo00X0oooo400000000`1N
GUh0oooo0?ooo`0E0?oooa80000000<0c<c<0?ooo`3oool03@3oool00`1EEED00000000000060000
000309VIV@3oool0oooo00`0oooo00<0A4A40000000000001@0000000`0R8R80oooo0?ooo`070?oo
o`03028R8P0000000000008000003@3oool00`1VIVH000000000000?0000000302/[:`3oool0oooo
00P0oooo4@0000000`3MgMd0oooo0?ooo`0E0?ooo`030>KViP000000000000D0000000D02@T904A4
A014A4@0A4A4014A4@07000000030<C4a03oool0oooo00P0oooo400000000`28R8P0oooo0?ooo`0C
0?ooo`H0000000<0R8R80?ooo`3oool01`3oool60000000308R8R03oool0oooo00H0oooo00<0A4A4
000000000000300000000`1EEED0oooo0?ooo`070?oooa40000000<0^k^k0?ooo`3oool01P3ooolB
000000030<c<c03oool0oooo00L0oooo00<0A4A4000000000000300000000`1EEED0oooo0?ooo`3o
0?ooool0ooooo`3ooomI0?ooo`040>WYj@3AdM40dM7A0=cLg0d0oooo00070?ooo`040>WYj@3AdM40
dM7A0>OWia`0oooo00<0^k^k0000000000000`0000000`2k^k/0oooo0?ooo`050?ooo`0308R8R000
0000000000D0000000<0A4A40?ooo`3oool01P3oool00`0R8R800000000000020000000304A4A03o
ool0oooo00@0oooo00<0R8R8000000000000100000080?ooo`030820P0000000000000l0000000<0
8R8R0<c<c03oool02`3oool@0000000305iNGP3oool0oooo01D0oooo4@0000000`2IVIT0oooo0?oo
o`0>0?ooo`0309VIV@000000000000H0000000<0k^k^0?ooo`3oool0303oool00`14A4@000000000
00050000000308R8R03oool0oooo00L0oooo00<08R8R0000000000000P00000>0?ooo`0306IVIP00
0000000000h0000000<08R8R0?ooo`3oool0203ooolA000000030=gMg@3oool0oooo01H0oooo00<0
VIVI0000000000003`0000000`1VIVH0oooo0?ooo`090?oooa00000000<0R8R80?ooo`3oool04`3o
ool60000000308R8R03oool0oooo00L0oooo1P0000000`28R8P0oooo0?ooo`060?ooo`0309VIV@00
0000000000`0000000<0A4A40?ooo`3oool01`3ooolA000000030;^k^`3oool0oooo00H0oooo4@00
00000`2IVIT0oooo0?ooo`080?ooo`0309VIV@000000000000`0000000<0A4A40?ooo`3oool0o`3o
oooo0?ooool0ooooF@3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7A
d@3WinLL0?ooo`0308R8R0000000000000<0000000<0a<C40?ooo`3oool01@3oool00`2RXZ800000
000000050000000305iNGP3oool0oooo00H0oooo00<0EEEE0000000000000`0000060?ooo`0308R8
R0000000000000@00000203oool00`20P80000000000000=0000000300T92@28R8P0k^k^00d0oooo
400000000`1NGUh0oooo0?ooo`0E0?oooa00000000<0EEEE0?ooo`3oool03`3oool00`3^k^h00000
000000050000000303<c<`3oool0oooo00d0oooo00<0A4A40000000000001@0000000`3^k^h0oooo
0?ooo`070?ooo`03028R8P0000000000008000003`3oool00`14A4@000000000000=00000003028R
8P3oool0oooo00P0oooo4@0000000`3MgMd0oooo0?ooo`0G0?ooo`030:ZZZP0A4A40000000d00000
00<0R8R80?ooo`3oool02P3oool@0000000308R8R03oool0oooo01<0oooo1P0000000`28R8P0oooo
0?ooo`070?ooo`H0000000<0R8R80?ooo`3oool01P3oool00`3gmoL0<c<c0000000<0000000304A4
A03oool0oooo00L0oooo4@0000000`2k^k/0oooo0?ooo`060?oooa00000000<0EEEE0?ooo`3oool0
2@3oool00`3gmoL0<c<c0000000<0000000304A4A03oool0oooo0?l0ooooo`3ooooo0?oooeT0oooo
00@0jNWY0=7Ad@3AdM40g=cL3@3oool000L0oooo00@0jNWY0=7Ad@3AdM40inOW703oool00`0l?3`0
000000000003000000030>k^kP3oool0oooo00D0oooo00<0c<c<0000000000001@0000000`24Q8@0
oooo0?ooo`060?ooo`0309VIV@000000000000<0000000<0/k>c0?ooo`3oool00`3oool00`28R8P0
000000000004000000P0oooo00<0P820000000000000200000001P0J6QX0;bl_04e=C@1_Kfl0TI6A
0=kNgPl0oooo400000000`1NGUh0oooo0?ooo`0E0?ooo``0000000D0:b/[04e=C@1gMgL0/k>c0?Og
m`0B0?ooo`0307MgM`000000000000@0000000<0/k>c0?ooo`3oool03@3oool00`14A4@000000000
000400000003096AT@3oool0oooo00P0oooo00<08R8R0000000000000P00000?0?ooo`050?Ogm`2R
XZ80GUiN03<c<`051@D02`0000000`19BDT0oooo0?ooo`080?oooa40000000<0gMgM0?ooo`3oool0
603oool00`3^k^h0N7Qh01XJ6P0900000003014A4@1VIVH0gMgM00d0oooo400000000`28R8P0oooo
0?ooo`0C0?ooo`H0000000<0R8R80?ooo`3oool01`3oool60000000308R8R03oool0oooo00L0oooo
00@0moOg0:ZZZP1NGUh04A4A2@0000000`092@T0GUiN0?ooo`080?oooa40000000<0^k^k0?ooo`3o
ool01P3oool<0000000502/[:`1=CDd0MgMg0;>c/`3gmoL0303oool0103gmoL0ZZZZ05iNGP0A4A49
0000000300T92@1NGUh0oooo0?l0ooooo`3ooooo0?oooeX0oooo00@0jNWY0=7Ad@3AdM40g=cL3@3o
ool000L0oooo00@0jNWY0=7Ad@3AdM40inOWo`3oool30?ooo`040<c<c028R8P0A4A403<c<`@00000
00@0A4A408R8R02ZZZX0k^k^>P3oool00`3<c<`0R8R804A4A0030000000303<c<`28R8P0c<c<05T0
oooo00@0i^KV08R8R014A4@08R8R0`0000000`14A4@0Kfm_0;^k^`150?ooo`040>KViP28R8P0A4A4
028R8P<0000000<0A4A406m_K`2k^k/0o`3ooooo0?ooool0ooooG@3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo
0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3o
ool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0oooo
o`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103Y
jNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo
0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
inOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?ooool0ooooo`3ooooo0?ooool0
ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3WinOo0?oo
ool0ooooo`3ooooo0?ooool0ooooHP3oool0103YjNT0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3Ng]ko0>g]kOl0kNg]o`3]kNgo0>g]kOl0kNg]HP3]kNd0103Ogml0dM7A0=7Ad@3L
g=`=0?ooo`001`3oool00`3YjNT0dM7A0=7Ad@3o0=7AdOl0dM7Ao`3AdM7o0=7AdOl0dM7AIP3AdM40
0`3Lg=`0oooo0?ooo`0;0?ooo`001`3oool00`3YjNT0dM7A0=7Ad@3o0=7AdOl0dM7Ao`3AdM7o0=7A
dOl0dM7AIP3AdM400`3Lg=`0oooo0?ooo`0;0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3FcKko0=[8
Yol0f/RWo`3Jb:Oo0=[8Yol0f/RWHP3Jb:L0103Fc;/0dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3o
XP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80
o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y
^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o
0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0
oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR
0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103Y
jNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3L
g=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3o
XP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80
o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A
0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?oo
o`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y
^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o
0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W
^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3o
ool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0oj80HP3oXP00103Y^680dM7A
0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3W^foo0?nR0?l0oj80o`3oXP3o0?nR0?l0
oj80HP3oXP00103Y^680dM7A0=7Ad@3Lg=`=0?ooo`001`3oool0103YjNT0dM7A0=7Ad@3HbkCo0=o3
Tol0gl>Co`3O`i?o0=o3Tol0gl>CHP3O`i<0103Hb[00dM7A0=7Ad@3Lg=`=0?ooo`001`3oool00`3Y
jNT0dM7A0=7Ad@3o0=7AdOl0dM7Ao`3AdM7o0=7AdOl0dM7AIP3AdM400`3Lg=`0oooo0?ooo`0;0?oo
o`001`3oool00`3YjNT0dM7A0=7Ad@3o0=7AdOl0dM7Ao`3AdM7o0=7AdOl0dM7AIP3AdM400`3Lg=`0
oooo0?ooo`0;0?ooo`001`3oool0103bl_80g]kN0=SHf03MgMgo0>?Shol0hn?So`3Shn?o0>?Shol0
hn?SHP3Shn<0103Ng]h0f=SH0=SHf03WinL=0?ooo`00o`3ooooo0?ooool0ooooo`3ooooo0?ooogh0
oooo003o0?ooool0ooooo`3ooooo0?ooool0ooooOP3oool00?l0ooooo`3ooooo0?ooool0ooooo`3o
oomn0?ooo`00o`3ooooo0?ooool0ooooo`3ooooo0?ooogh0oooo003o0?ooool0ooooo`3ooooo0?oo
ool0ooooOP3oool00?l0ooooo`3ooooo0?ooool0ooooo`3ooomn0?ooo`00o`3ooooo0?ooool0oooo
o`3ooooo0?ooogh0oooo003o0?ooool0ooooo`3ooooo0?ooool0ooooOP3oool00?l0ooooo`3ooooo
0?ooool0ooooo`3ooomn0?ooo`00o`3ooooo0?ooool0ooooo`3ooooo0?ooogh0oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{476.875, 354.938},
  ImageMargins->{{29.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users span a broad diversity of fields, with the largest user population \
coming from the engineering disciplines. "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users represent a broad cross section of the following:"
}], "Text"],

Cell["\<\
The vast majority of Fortune 500 corporations, including The Boeing \
Company, General Electric, and Intel Corporation\
\>", "BulletedList"],

Cell["\<\
Over a dozen key government agencies, including NASA, the CDC, and \
the U.S. Patent Office\
\>", "BulletedList"],

Cell["\<\
All major national and international research labs, such as SLAC, \
INRIA, and the German Fraunhoffer Institute\
\>", "BulletedList"],

Cell[TextData[{
  "Virtually all the top 50 U.S. universities as ranked in",
  StyleBox[" U.S. News and World Report",
    FontSlant->"Italic"]
}], "BulletedList"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(\(Key\)\(\ \)\(Technologies\)\(\ \)\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "The scope of capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is well beyond what is possible to even think of covering in a one hour \
lecture.  In fact, I'm sure that right now people are doing things with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that are well beyond the scope of my scientific knowledge and in some \
cases beyond the my knowledge of details of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " system.  Don't let the sheer size of possibilities daunt you, though: you \
do not need to know everything to effectively use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "; a tiny fraction of what is possible is often quite sufficient to do \
effective work in many cases."
}], "Text"],

Cell[TextData[{
  "I could spend the entire time showing you lots of slick polished demos, \
but I think that, technically,  the design of Mathematica from its most basic \
structures communicates the value of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " most eloquently, so I will start the talk with the basic ideas of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and follow with increasingly sophisticated examples."
}], "Text"],

Cell[TextData[{
  "The main focus will be on what I consider to be key technologies of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that make it particularly effective as an exploratory computational tool. \
 Keep in mind that what I consider to be key technologies are perhaps skewed \
by my background as a mathematician and focus as developer of numerical \
functionality.  "
}], "Text"],

Cell["\<\
\[Bullet] Symbolic Programming
  - Language based on symbolic expressions
  - Pattern matching provides a powerful programming paradigm\
\>", "Text"],

Cell["\<\
\[Bullet] Symbolic computation
  - Mathematical knowledge base in a usable form\
\>", "Text"],

Cell["\<\
\[Bullet] Numerical computation
  - Task based commands
  - Optimized libraries for optimal processor speed\
\>", "Text"],

Cell["\<\
\[Bullet] Automatic Algorithm Selection
  - Depth of algorithmic knowledge
  - Scalability\
\>", "Text"],

Cell["\<\
\[Bullet] Data capabilities
  - Import/Export of many different data formats
  - Symbolic XML
  - Database connections\
\>", "Text"],

Cell["\<\
\[Bullet] Notebook Document-Centered Interface
  - Combines computational commands, results, visualizations
  - Interactive mathematical typesetting
  - Publication quality technical documents\
\>", "Text"],

Cell["\<\
\[Bullet] Wide variety of deployment possibilities
  - Communication with notebooks
  - Electronic communication via webMathematica\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Language",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "An important aspect which has ensured the status of  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as a successful computing system for such a long time is the design of \
the language."
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language is extensible."
}], "BulletedList"],

Cell["\<\
The language is very general: tasks can be done procedurally, \
functionally, or in an object-oriented manner.\
\>", "BulletedList"],

Cell["\<\
Substitution rules with pattern matching provide an extremely \
powerful programming paradigm for both computational and scripting \
applications.\
\>", "BulletedList"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(\(\ \)\(Expressions\)\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "The basic unit of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is an expression.  An expression is a tree which at some level has atomic \
units which are typically strings, symbols, or numbers.  Symbolic expressions \
are a key unifying idea in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " since everything can be represented by them."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(\(\ \)\(Expressions\)\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
A simple example to demonstrate the idea of a symbolic expression \
is the quadratic formula.\
\>", "Text"],

Cell["This inputs the quadratic formula as a symbolic expression.", \
"MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qf\  = \ \(\(-b\)\  \[PlusMinus] \ \@\(b\^2 - \ 4\ a\ c\)\)\/\(2\ \
a\)\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \(\(\(-b\) \[PlusMinus] \@\(b\^2 - 4\ a\ c\)\)\/\(2\ a\)\)], "Output",
  CellLabel->"Out[158]="]
}, Open  ]],

Cell[TextData[{
  "Give a representation of the full format ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses to store the symbolic expression."
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[%]\)], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(Times[Rational[1, 2], Power[a, \(-1\)], 
          PlusMinus[Times[\(-1\), b], 
            Power[Plus[Power[b, 2], Times[\(-4\), a, c]], Rational[1, 2]]]]\),
        
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[159]//FullForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Expressions",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["Here is a matrix. with strings and numbers.", "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"tour", " ", "=", " ", 
      RowBox[{"(", GridBox[{
            {"\"\<Mumbai\>\"", "\"\<Monday\>\"", "7"},
            {"\"\<Pune\>\"", "\"\<Tuesday\>\"", "8"},
            {"\"\<Kharagpur\>\"", "\"\<Wednesday\>\"", "9"},
            {"\"\<Kolkata\>\"", "\"\<Thursday\>\"", "10"},
            {"\"\<Hyderabad\>\"", "\"\<Friday\>\"", "11"},
            {"\"\<Madurai\>\"", "\"\<Monday\>\"", "14"},
            {"\"\<Bangalore\>\"", "\"\<Tuesday\>\"", "15"},
            {"\"\<Roorkee\>\"", "\"\<Wednesday\>\"", "16"},
            {"\"\<Kanpur\>\"", "\"\<Friday\>\"", "18"}
            }], ")"}]}]], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \({{"Mumbai", "Monday", 7}, {"Pune", "Tuesday", 8}, {"Kharagpur", 
        "Wednesday", 9}, {"Kolkata", "Thursday", 10}, {"Hyderabad", "Friday", 
        11}, {"Madurai", "Monday", 14}, {"Bangalore", "Tuesday", 
        15}, {"Roorkee", "Wednesday", 16}, {"Kanpur", "Friday", 
        18}}\)], "Output",
  CellLabel->"Out[154]="]
}, Open  ]],

Cell[TextData[{
  "Give a representation of the full format ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses to store the symbolic expression."
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[tour]\)], "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(List[List["\<Mumbai\>", "\<Monday\>", 7], 
          List["\<Pune\>", "\<Tuesday\>", 8], 
          List["\<Kharagpur\>", "\<Wednesday\>", 9], 
          List["\<Kolkata\>", "\<Thursday\>", 10], 
          List["\<Hyderabad\>", "\<Friday\>", 11], 
          List["\<Madurai\>", "\<Monday\>", 14], 
          List["\<Bangalore\>", "\<Tuesday\>", 15], 
          List["\<Roorkee\>", "\<Wednesday\>", 16], 
          List["\<Kanpur\>", "\<Friday\>", 18]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[155]//FullForm="]
}, Open  ]],

Cell["Add the month to each row.", "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[
      Map[Insert[#, \ \ "\<February\>", \ 3] &, \ tour]]\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Mumbai\"\>", "\<\"Monday\"\>", "\<\"February\"\>", "7"},
            {"\<\"Pune\"\>", "\<\"Tuesday\"\>", "\<\"February\"\>", "8"},
            {"\<\"Kharagpur\"\>", "\<\"Wednesday\"\>", "\<\"February\"\>", 
              "9"},
            {"\<\"Kolkata\"\>", "\<\"Thursday\"\>", "\<\"February\"\>", 
              "10"},
            {"\<\"Hyderabad\"\>", "\<\"Friday\"\>", "\<\"February\"\>", 
              "11"},
            {"\<\"Madurai\"\>", "\<\"Monday\"\>", "\<\"February\"\>", "14"},
            {"\<\"Bangalore\"\>", "\<\"Tuesday\"\>", "\<\"February\"\>", 
              "15"},
            {"\<\"Roorkee\"\>", "\<\"Wednesday\"\>", "\<\"February\"\>", 
              "16"},
            {"\<\"Kanpur\"\>", "\<\"Friday\"\>", "\<\"February\"\>", "18"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[163]//MatrixForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Expressions",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["Here is a simple sum of terms", "MathCaption",
  CellTags->"M185A.1.2"],

Cell[BoxData[
    \(TraditionalForm\`2\  + \ a\  + \ 5\  + \ 2\ a\)], "Input",
  CellLabel->"In[40]:="],

Cell[TextData[{
  "Give a representation of the full format ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses to store the symbolic expression as it was input."
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FullForm[
      Unevaluated[2\  + \ a\  + \ 5\  + \ 2\ a]]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(Unevaluated[Plus[2, a, 5, Times[2, a]]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[164]//FullForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Evaluation",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " works by evaluating symbolic expressions.  When an expression is \
evaluated, it is transformed by built-in and/or user defined procedures."
}], "Text"],

Cell[TextData[{
  "Give a representation of the full format ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses to store the symbolic expression after evaluation."
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FullForm[2\  + \ a\  + \ 5\  + \ 2\ a]\)], "Input",
  CellLabel->"In[165]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(Plus[7, Times[3, a]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[165]//FullForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Rules",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["Transformations to expressions can be specified by rules", "Text"],

Cell[TextData[{
  "A rule defines a substitution for symbolic expressions.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", it has the notation lhs->rhs giving a substitution for something \
matching lhs into rhs."
}], "Text"],

Cell["This substitutes numbers into the quadratic formula", "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(-b\)\  \[PlusMinus] \ \@\(b\^2 - \ 4\ a\ c\)\)\/\(2\ a\)\  /. \ {a \
\[Rule] 1, \ b \[Rule] \(-4\), \ c \[Rule] 3}\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    \(\(4 \[PlusMinus] 2\)\/2\)], "Output",
  CellLabel->"Out[169]="]
}, Open  ]],

Cell["\<\
Rules can be given with patterns which can match particular \
arguments\
\>", "Text"],

Cell["\<\
The effect of this rule is to distribute a multiple though \
PlusMinus.  s_ is a pattern that matches any expression and can be \
represented by s on the right hand side of a rule.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ 
      c_\ PlusMinus[x1_, \ x2_] \[RuleDelayed] \ 
        PlusMinus[c\ x1, \ c\ x2]\)], "Input",
  CellLabel->"In[172]:="],

Cell[BoxData[
    \(2 \[PlusMinus] 1\)], "Output",
  CellLabel->"Out[172]="]
}, Open  ]],

Cell["\<\
Rule substitutions can be used to give particular values for \
parameters\
\>", "Text"],

Cell["\<\
This makes a density plot of the modulus of the formula as a \
function of (real) b and c for a = 1.  The DensityPlot command works by \
evaluating the argument with settings for b and c on a grid.\
\>", \
"MathCaption"],

Cell[BoxData[
    \(\(DensityPlot[
        Abs[\(\(-b\)\  \[PlusMinus] \ \@\(b\^2 - \ 4\ a\ c\)\)\/\(2\ a\) /. \ \
{a \[Rule] 1, \ PlusMinus \[Rule] Subtract}], {b, \(-1\), 1}, {c, \(-1\), 
          1}, \ PlotPoints \[Rule] 100, \ Mesh \[Rule] False];\)\)], "Input",
  CellLabel->"In[190]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Rules : Functions\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Functions that are specified by patterns are effectively \
rules\
\>", "Text"],

Cell["\<\
Define a function test which will substitute its argument into a \
generic quadratic.\
\>", "MathCaption"],

Cell[BoxData[
    \(test[x_]\  := \ a\ x^2\  + \ b\ x\  + \ c\)], "Input",
  CellLabel->"In[94]:="],

Cell["Substitute the quadratic formula into the generic quadratic.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(test[\(\(-b\)\  \[PlusMinus] \ \@\(b\^2 - \ 4\ a\ c\)\)\/\(2\ a\)]\)], \
"Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(c + \(b\ \((\(-b\) \[PlusMinus] \@\(b\^2 - 4\ a\ c\))\)\)\/\(2\ a\) + \
\((\(-b\) \[PlusMinus] \@\(b\^2 - 4\ a\ c\))\)\^2\/\(4\ a\)\)], "Output",
  CellLabel->"Out[95]="]
}, Open  ]],

Cell["You can give different sets of substitutions to be applied", "Text"],

Cell["\<\
Create an expression for each possible meaning of \[PlusMinus] \
PlusMinus\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ {{PlusMinus \[Rule] Plus}, {\ 
          PlusMinus \[Rule] Subtract}}\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \({c + \(b\ \((\(-b\) + \@\(b\^2 - 4\ a\ c\))\)\)\/\(2\ a\) + \((\(-b\) + \
\@\(b\^2 - 4\ a\ c\))\)\^2\/\(4\ a\), 
      c + \(b\ \((\(-b\) - \@\(b\^2 - 4\ a\ c\))\)\)\/\(2\ a\) + \((\(-b\) - \
\@\(b\^2 - 4\ a\ c\))\)\^2\/\(4\ a\)}\)], "Output",
  CellLabel->"Out[96]="]
}, Open  ]],

Cell["Simplify the expression.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \({0, 0}\)], "Output",
  CellLabel->"Out[97]="]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Expressions : \ Documents\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Yes, these have representations as symbolic expressions also and \
can be manipulated with symbolic programming.\
\>", "Text"],

Cell["\<\
This will go back up to the beginning of the notebook and page \
through the slides seen up to this point.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(FrontEndExecute[{FrontEndToken[
            FrontEnd`SelectedNotebook[], "\<ScrollPageFirst\>"]}];\)\), "\
\[IndentingNewLine]", 
    \(Pause[1. ]; 
    Do[FrontEndExecute[{FrontEndToken[
            FrontEnd`SelectedNotebook[], "\<ScrollPageNext\>"]}]; \ 
      Pause[2. /i], {i, 13}]\)}], "Input",
  CellLabel->"In[12]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Expressions : \ Graphics\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Graphics objects have representations as symbolic objects that can \
be transformed.\
\>", "Text"],

Cell["\<\
This loads a package that contains definitions for constructing \
polyhedra.  \
\>", "MathCaption"],

Cell[BoxData[
    \(Needs["\<Graphics`Polyhedra`\>"]\)], "Input",
  CellLabel->"In[191]:="],

Cell["\<\
This generates a symbolic expression for a graphical image of a \
stellated dodecahedron.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dodo\  = \ Stellate[Polyhedron[Dodecahedron]]\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[192]="]
}, Open  ]],

Cell["\<\
The complete form of it is not shown by default because most often \
you want to see the image, which can be generated with Show.\
\>", "Text"],

Cell["Show the graphic.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[dodo];\)\)], "Input",
  CellLabel->"In[193]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.1504 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0844264 1.2109 3.08998e-017 1.2109 [
[ 0 0 0 0 ]
[ 1 1.1504 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08676 .24213 m
0 .87494 L
s
0 .87494 m
.38254 1.1504 L
s
.38254 1.1504 m
.40225 .57033 L
s
.40225 .57033 m
.08676 .24213 L
s
.67488 0 m
.92568 .39615 L
s
.92568 .39615 m
1 1.00617 L
s
1 1.00617 m
.70966 .66123 L
s
.70966 .66123 m
.67488 0 L
s
.08676 .24213 m
0 .87494 L
s
0 .87494 m
.70966 .66123 L
s
.70966 .66123 m
.67488 0 L
s
.67488 0 m
.08676 .24213 L
s
.40225 .57033 m
.92568 .39615 L
s
.92568 .39615 m
1 1.00617 L
s
1 1.00617 m
.38254 1.1504 L
s
.38254 1.1504 m
.40225 .57033 L
s
0 0 m
1 0 L
1 1.1504 L
0 1.1504 L
closepath
clip
newpath
.5 Mabswid
.758 .388 .353 r
.57293 .65641 m .43057 .68495 L .55953 .76166 L closepath p F P
0 g
s
.875 .733 .703 r
.57293 .65641 m .46551 .53819 L .43057 .68495 L closepath p F P
0 g
s
.672 .716 .882 r
.57293 .65641 m .61508 .52127 L .46551 .53819 L closepath p F P
0 g
s
.317 .336 .722 r
.57293 .65641 m .67512 .6593 L .61508 .52127 L closepath p F P
0 g
s
.302 0 .271 r
.57293 .65641 m .55953 .76166 L .67512 .6593 L closepath p F P
0 g
s
.694 .747 .893 r
.25726 .56891 m .46551 .53819 L .38794 .45327 L closepath p F P
0 g
s
.692 .542 .679 r
.25726 .56891 m .43057 .68495 L .46551 .53819 L closepath p F P
0 g
s
.788 .408 .336 r
.25726 .56891 m .32774 .7012 L .43057 .68495 L closepath p F P
0 g
s
0 .021 .575 r
.25726 .56891 m .2981 .55333 L .32774 .7012 L closepath p F P
0 g
s
0 0 0 r
.25726 .56891 m .38794 .45327 L .2981 .55333 L closepath p F P
0 g
s
.676 .541 .692 r
.52102 .33433 m .46551 .53819 L .61508 .52127 L closepath p F P
0 g
s
.883 .763 .725 r
.52102 .33433 m .38794 .45327 L .46551 .53819 L closepath p F P
0 g
s
0 0 0 r
.52102 .33433 m .49579 .37754 L .38794 .45327 L closepath p F P
0 g
s
.292 .35 .751 r
.52102 .33433 m .61508 .52127 L .64079 .42328 L closepath p F P
0 g
s
.662 .132 0 r
.52102 .33433 m .64079 .42328 L .49579 .37754 L closepath p F P
0 g
s
.896 .736 .676 r
.38779 .89469 m .43057 .68495 L .32774 .7012 L closepath p F P
0 g
s
.682 .518 .658 r
.38779 .89469 m .55953 .76166 L .43057 .68495 L closepath p F P
0 g
s
.656 .516 .68 r
.8283 .50453 m .61508 .52127 L .67512 .6593 L closepath p F P
0 g
s
.641 .714 .9 r
.8283 .50453 m .64079 .42328 L .61508 .52127 L closepath p F P
0 g
s
.263 0 .17 r
.38779 .89469 m .5462 .83288 L .55953 .76166 L closepath p F P
0 g
s
.727 .319 .273 r
.74952 .86104 m .55953 .76166 L .5462 .83288 L closepath p F P
0 g
s
.66 .501 .659 r
.74952 .86104 m .67512 .6593 L .55953 .76166 L closepath p F P
0 g
s
.199 0 .22 r
.8283 .50453 m .67512 .6593 L .74421 .65764 L closepath p F P
0 g
s
.233 .257 .682 r
.74952 .86104 m .74421 .65764 L .67512 .6593 L closepath p F P
0 g
s
.601 .773 .962 r
.38779 .89469 m .39613 .79541 L .5462 .83288 L closepath p F P
0 g
s
0 .119 .654 r
.38779 .89469 m .32774 .7012 L .39613 .79541 L closepath p F P
0 g
s
.731 .226 .025 r
.8283 .50453 m .72365 .50508 L .64079 .42328 L closepath p F P
0 g
s
.955 .803 .654 r
.8283 .50453 m .74421 .65764 L .72365 .50508 L closepath p F P
0 g
s
.676 .768 .92 r
.27705 .33255 m .38794 .45327 L .49579 .37754 L closepath p F P
0 g
s
.91 .788 .713 r
.27705 .33255 m .2981 .55333 L .38794 .45327 L closepath p F P
0 g
s
.649 .802 .956 r
.74952 .86104 m .5462 .83288 L .66401 .76896 L closepath p F P
0 g
s
.944 .827 .698 r
.74952 .86104 m .66401 .76896 L .74421 .65764 L closepath p F P
0 g
s
.919 .77 .679 r
.18103 .71712 m .32774 .7012 L .2981 .55333 L closepath p F P
0 g
s
.776 .348 .232 r
.18103 .71712 m .39613 .79541 L .32774 .7012 L closepath p F P
0 g
s
.175 .273 .727 r
.66959 .28294 m .64079 .42328 L .72365 .50508 L closepath p F P
0 g
s
.639 .746 .926 r
.66959 .28294 m .49579 .37754 L .64079 .42328 L closepath p F P
0 g
s
.731 .281 .183 r
.52102 .92577 m .5462 .83288 L .39613 .79541 L closepath p F P
0 g
s
.102 0 .016 r
.52102 .92577 m .66401 .76896 L .5462 .83288 L closepath p F P
0 g
s
.04 .12 .62 r
.27705 .33255 m .34789 .54495 L .2981 .55333 L closepath p F P
0 g
s
0 0 0 r
.18103 .71712 m .2981 .55333 L .34789 .54495 L closepath p F P
0 g
s
.055 0 .052 r
.83414 .64883 m .74421 .65764 L .66401 .76896 L closepath p F P
0 g
s
.128 .204 .675 r
.83414 .64883 m .72365 .50508 L .74421 .65764 L closepath p F P
0 g
s
.032 0 0 r
.66959 .28294 m .47767 .42959 L .49579 .37754 L closepath p F P
0 g
s
.688 .206 .102 r
.27705 .33255 m .49579 .37754 L .47767 .42959 L closepath p F P
0 g
s
.612 .736 .934 r
.18103 .71712 m .41249 .70259 L .39613 .79541 L closepath p F P
0 g
s
.13 .25 .721 r
.52102 .92577 m .39613 .79541 L .41249 .70259 L closepath p F P
0 g
s
.928 .764 .657 r
.66959 .28294 m .72365 .50508 L .62575 .5134 L closepath p F P
0 g
s
.775 .331 .195 r
.83414 .64883 m .62575 .5134 L .72365 .50508 L closepath p F P
0 g
s
.651 .488 .65 r
.27705 .33255 m .47767 .42959 L .34789 .54495 L closepath p F P
0 g
s
.679 .778 .925 r
.83414 .64883 m .66401 .76896 L .58628 .68452 L closepath p F P
0 g
s
.913 .797 .719 r
.52102 .92577 m .58628 .68452 L .66401 .76896 L closepath p F P
0 g
s
.647 .505 .676 r
.18103 .71712 m .34789 .54495 L .41249 .70259 L closepath p F P
0 g
s
.677 .508 .649 r
.66959 .28294 m .62575 .5134 L .47767 .42959 L closepath p F P
0 g
s
.174 .241 .693 r
.45263 .5383 m .41249 .70259 L .34789 .54495 L closepath p F P
0 g
s
.111 0 .07 r
.45263 .5383 m .34789 .54495 L .47767 .42959 L closepath p F P
0 g
s
.744 .313 .227 r
.45263 .5383 m .47767 .42959 L .62575 .5134 L closepath p F P
0 g
s
.656 .74 .912 r
.45263 .5383 m .58628 .68452 L .41249 .70259 L closepath p F P
0 g
s
.671 .535 .69 r
.52102 .92577 m .41249 .70259 L .58628 .68452 L closepath p F P
0 g
s
.904 .761 .694 r
.45263 .5383 m .62575 .5134 L .58628 .68452 L closepath p F P
0 g
s
.689 .536 .674 r
.83414 .64883 m .58628 .68452 L .62575 .5134 L closepath p F P
0 g
s
.25 Mabswid
.67488 0 m
.92568 .39615 L
s
.92568 .39615 m
1 1.00617 L
s
1 1.00617 m
.70966 .66123 L
s
.70966 .66123 m
.67488 0 L
s
.08676 .24213 m
0 .87494 L
s
0 .87494 m
.70966 .66123 L
s
.70966 .66123 m
.67488 0 L
s
.67488 0 m
.08676 .24213 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[193]:=",
  ImageSize->{250.313, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003j00017b000`400?l00000o`00003oY`3oool2
00000540oooo002U0?ooo`80000000<0oooo000000000000D03oool00:80oooo0`0000030?ooo`80
0000D03oool00:00oooo0P0000060?ooo`030000003oool0000004l0oooo002M0?ooo`<00000203o
ool010000000oooo0?ooo`00001>0?ooo`00V`3oool2000000/0oooo00@000000?ooo`3oool00000
CP3oool009T0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000C@3oool009H0oooo0`00
000?0?ooo`050000003oool0oooo0?ooo`000000C@3oool009@0oooo0P00000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0BP3oool00940oooo0`00000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0B@3oool008l0oooo0P00000G0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0B@3oool008`0oooo0`00000J0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0B03oool008X0oooo0P00000M0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0A`3oool008L0oooo0`00000O0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0A`3oool008D0oooo0P00000R0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0AP3oool008<0oooo0P00000T0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0AP3oool00800oooo0`00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0A@3oool007h0oooo0P00000Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
A03oool007/0oooo0`00000[0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A03o
ool007T0oooo0P00000^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@`3oool0
07H0oooo0`00000`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool007@0
oooo0P00000c0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00740oooo
0`00000e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@@3oool006l0oooo0P00
000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@03oool006`0oooo0`00000j
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@03oool006X0oooo0P00000m0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0?`3oool006P0oooo0P00000o0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0?`3oool006D0oooo0`0000110?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0?P3oool006<0oooo0P0000140?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0?@3oool00600oooo0`0000160?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0?@3oool005h0oooo0P0000190?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?03oool005/0oooo0`00001<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0>`3oool005T0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0>`3oool005H0oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0>P3oool005@0oooo0P00001D0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0>@3oool00580oooo0P00001F0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0>@3oool004l0oooo0`00001H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0>03oool004d0oooo0P00001K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
>03oool004X0oooo0`00001M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=`3o
ool004P0oooo0P00001P0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0=P3oool0
04D0oooo0`00001R0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0=P3oool004<0
oooo0P00001U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=@3oool00400oooo
0`00001W0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=03oool003h0oooo0P00
001Z0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=03oool003/0oooo0`00001/
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<`3oool003T0oooo0P00001_0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<`3oool003L0oooo0P00001a0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0<P3oool003@0oooo0`00001c0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0<@3oool00380oooo0P00001f0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0<@3oool002l0oooo0`00001h0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0<03oool002d0oooo0P00001k0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0;`3oool002X0oooo0`00001m0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0;`3oool002P0oooo0P0000210?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0;P3oool002D0oooo0`0000230?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0;@3oool002<0oooo0P0000260?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0;@3oool00240oooo0P0000280?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0;03oool001h0oooo0`00002:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0;03oool001`0oooo0P00002=0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
:`3oool001T0oooo0`00002?0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:P3o
ool001L0oooo0P00002B0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:P3oool0
01D0oooo0P00002D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:@3oool001D0
oooo0P00002D0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:03oool001D0oooo
00<000000?ooo`000000T`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02P0oooo
000E0?ooo`040000003oool0oooo00000980oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0W0?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0W0?ooo`00503oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0V
0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0U0?ooo`00503oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`00
503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`00503oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo000D0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0P@3oool3000000@0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0R0?ooo`004`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0
oooo0`0000000`2]PZH000000?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool08@3oool001<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1k0?ooo`<00000
0P2]PZH00`000000kL>X000000040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
8@3oool001<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1i0?ooo`80000000<0
20000000002]PZH00P2]PZH00`000000kL>X000000040?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0803oool001<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1g
0?ooo`040000000800002000000000@0[H:V00<000000>g3Z0000000103oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0200oooo000C0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0M03oool20000000300P000000000000000D0[H:V00<000000>g3Z0000000103oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01l0oooo000C0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0L@3oool200000080200000<000000:f2YP2]PZH01@2]PZH01000
0000kL>X0>g3Z00000030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07P3oool0
01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1^0?ooo`8000000`0800000`00
0000[H:V0:f2YP060:f2YP040000003]`jP0kL>X000000<0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0N0?ooo`004P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
06/0oooo0P00000300P000800000202]PZH01@000000kL>X0>g3Z03]`jP0000000<0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`004P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo06T0oooo00<0000000P0000800000P0800000`000000[H:V0:f2YP080:f2
YP050000003]`jP0kL>X0>g3Z00000000`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo01`0oooo000B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0IP3oool20000
00@0200000<000000:f2YP2]PZH02@2]PZH00`000000kL>X0>g3Z0020>g3Z0040000003oool0oooo
000002h0oooo00<000000?ooo`3oool0703oool00180oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1S0?ooo`8000001@0800000`000000[H:V0:f2YP0:0:f2YP030000003]`jP0kL>X
0080kL>X00@000000?ooo`3oool00000;`3oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo0`00000i0?ooo`030000003oool0oooo
00X0oooo0P00000500P0008000003@2]PZH00`000000kL>X0>g3Z0020>g3Z0040000003oool0oooo
00000300oooo00<000000?ooo`3oool06P3oool00180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0F0?ooo`030000002VO:H0000000D00000<`3oool010000000ZB40000000000009
0?ooo`03000000080000200000@0200000<000000:f2YP2]PZH03@2]PZH00`000000kL>X0>g3Z002
0>g3Z0040000003oool0oooo00000300oooo00<000000?ooo`3oool06P3oool00180oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`8000000P2VO:H200000080/3@J1@00000]
0?ooo`8000000`2Y8@000`000000oooo0?ooo`040?ooo`8000001P0800000`000000[H:V0:f2YP0=
0:f2YP030000003]`jP0kL>X00@0kL>X00<000000?ooo`000000<@3oool00`000000oooo0?ooo`0I
0?ooo`004P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01@0oooo0P0000040:Il
YP8000001@2`=1X5000002L0oooo0P0000050:TQ00040000003oool0oooo0?ooo`8000001`080000
0`000000[H:V0:f2YP0>0:f2YP030000003]`jP0kL>X00@0kL>X00<000000?ooo`000000<@3oool0
0`000000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01<0oooo0P0000060:IlYP800000202`=1X500000240oooo0`0000060:TQ00<000001`0800020000
0140[H:V00<000000>g3Z03]`jP0103]`jP00`000000oooo0000000b0?ooo`030000003oool0oooo
01P0oooo000A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04P3oool00`000000
2QjN000000070:IlYP8000002`2`=1X4000001/0oooo100000060:TQ00800000200800000`000000
[H:V0:f2YP0A0:f2YP030000003]`jP0kL>X00@0kL>X00<000000?ooo`000000<`3oool00`000000
oooo0?ooo`0G0?ooo`004@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0180oooo
0P0000090:IlYP8000003@2`=1X5000001D0oooo1@0000050:TQ0003000000080000200000L02000
00<000000:f2YP2]PZH04P2]PZH00`000000kL>X0>g3Z0050>g3Z0800000<`3oool00`000000oooo
0?ooo`0G0?ooo`004@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo0P00
000;0:IlYP800000402`=1X5000000l0oooo1@0000040:TQ0080000020080002000001D0[H:V00<0
00000>g3Z03]`jP01@3]`jP2000003@0oooo00<000000?ooo`3oool05P3oool00140oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0@0?ooo`030000000:7Yh0000000`0YWbV0P00000C
0;0d6PD000002@3oool600000080ZB400P00000900P000030000002]PZH0[H:V01@0[H:V00<00000
0>g3Z03]`jP01P3]`jP2000003D0oooo00<000000?ooo`3oool05@3oool00140oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0?0?ooo`030000000:7Yh0000000h0YWbV0P00000F0;0d
6PD000000`3oool6000000030:TQ00000000000000X0200000<000000:f2YP2]PZH05@2]PZH00`00
0000kL>X0>g3Z0060>g3Z0800000=@3oool00`000000oooo0?ooo`0E0?ooo`004@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00h0oooo00<0000000XNWP000000402VO:H2000001T0
/3@J2P00000;00P000030000002]PZH0[H:V01H0[H:V00<000000>g3Z03]`jP01`3]`jP2000003D0
oooo00<000000?ooo`3oool0503oool00100oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0=0?ooo`040000000:7Yh02QjN00000140YWbV0P00000L0;0d6P<000002`080002000001T0
[H:V00<000000>g3Z03]`jP01`3]`jP2000003D0oooo00<000000?ooo`3oool0503oool00100oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`040000000:7Yh02QjN000001<0
YWbV0`00000K0;0d6P03000000080000200000P0200000<000000:f2YP2]PZH06@2]PZH00`000000
kL>X0>g3Z0070>g3Z0800000=P3oool00`000000oooo0?ooo`0C0?ooo`00403oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00@0000000XNWP0:7Yh000005P2VO:H2000001P0
/3@J00<0000000P000080000200800000`000000[H:V0:f2YP0J0:f2YP030000003]`jP0kL>X00L0
kL>X0P00000g0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool02P3oool01@0000002QjN00XNWP0:7Yh0000001L0YWbV0P00000F0;0d6P03
000000080000200000L0200000<000000:f2YP2]PZH06P2]PZH00`000000kL>X0>g3Z0090>g3Z003
0000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`090?ooo`050000000:7Yh02QjN00XNWP0000006@2VO:H2000001@0
/3@J00<0000000P0000800001@080002000001d0[H:V00<000000>g3Z03]`jP02@3]`jP00`000000
oooo0?ooo`0e0?ooo`8000004`3oool00100oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`080?ooo`050000000:7Yh02QjN00XNWP0000006`2VO:H200000140/3@J00<0000000P00008
00001@0800000`000000[H:V0:f2YP0M0:f2YP030000003]`jP0kL>X00T0kL>X00<000000?ooo`3o
ool0<P3oool3000000030?ooo`000000oooo0180oooo000@0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0203oool01@0000002QjN00XNWP0:7Yh0000001`0YWbV0P00000?0;0d6P03
000000080000200000@0200000<000000:f2YP2]PZH07P2]PZH00`000000kL>X0>g3Z0090>g3Z003
0000003oool0oooo02l0oooo0`0000040?ooo`030000003oool0oooo0140oooo000@0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0203oool01@0000002QjN00XNWP0:7Yh0000001h0
YWbV0P00000=0;0d6P030000000800002000008020000P00000Q0:f2YP030000003]`jP0kL>X00T0
kL>X0P00000]0?ooo`<000001`3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00L0oooo00D0000000XNWP0:7Yh02QjN0000000P0:IlYP80
00002`2`=1X01@000000200000P00008000000000280[H:V00<000000>g3Z03]`jP02P3]`jP20000
02X0oooo0`00000:0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool01P3oool00`0000002QjN00XNWP0200XNWP030000002VO:H0YWbV01l0
YWbV0P0000080;0d6P05000000080000200000P0000000008`2]PZH00`000000kL>X0>g3Z00:0>g3
Z08000009`3oool3000000h0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`050?ooo`030000000:7Yh02QjN00802QjN00<000000:IlYP2V
O:H08@2VO:H2000000H0/3@J00@0000000P0000800000000902]PZH00`000000kL>X0>g3Z00:0>g3
Z0800000903oool300000140oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`040?ooo`030000000:7Yh02QjN00802QjN00<000000:IlYP2V
O:H08`2VO:H2000000@0/3@J0`00000U0:f2YP030000003]`jP0kL>X00X0kL>X00<000000>g3Z000
0000803oool3000001@0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`030?ooo`030000000:7Yh02QjN00<02QjN00<000000:IlYP2VO:H0
902VO:H2000000030;0d6P000000000002L0[H:V00<000000>g3Z03]`jP02P3]`jP00`000000kL>X
0000000M0?ooo`<000005`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0080oooo00<0000000XNWP0:7Yh00`0:7Yh00`000000YWbV0:Il
YP0V0:IlYP800000:02]PZH00`000000kL>X0>g3Z00:0>g3Z0030000003]`jP0000001X0oooo0`00
000J0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo0340oooo00D00000
0?ooo`3oool0oooo0000000500XNWP030000002VO:H0YWbV02H0YWbV1000000U0:f2YP030000003]
`jP0kL>X00/0kL>X00<000000>g3Z00000005`3oool3000001d0oooo00<000000?ooo`3oool0403o
ool000h0oooo00<000000?ooo`3oool0<`3oool010000000oooo0?ooo`00000500XNWP030000002V
O:H0YWbV02D0YWbV0P0000030;i@>P8000008`2]PZH00`000000kL>X0>g3Z00;0>g3Z0040000003]
`jP0kL>X000001@0oooo0P00000P0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`0000001P0:7Yh00`000000YWbV0:IlYP0R0:IlYP80000000<0
700A0000002nD3X0102nD3X200000240[H:V00<000000>g3Z03]`jP02`3]`jP010000000kL>X0>g3
Z000000A0?ooo`<000008P3oool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0000000D02QjN00<000000:IlYP2VO:H08@2VO:H01@000000700A01`0
4@0L0140000000L0_U0j00<000000:f2YP2]PZH07P2]PZH00`000000kL>X0>g3Z00;0>g3Z0040000
003]`jP0kL>X000000h0oooo0`00000V0?ooo`030000003oool0oooo00l0oooo000>0?ooo`030000
003oool0oooo03H0oooo0P00000500XNWP030000002VO:H0YWbV0200YWbV00<0000001`04@0L0140
0P0L01400`000000_U0j0;i@>P060;i@>P8000007P2]PZH00`000000kL>X0>g3Z00;0>g3Z0040000
003]`jP0kL>X000000/0oooo0`00000Y0?ooo`030000003oool0oooo00l0oooo000>0?ooo`030000
003oool0oooo03L0oooo00<0000000XNWP0:7Yh0100:7Yh00`000000YWbV0:IlYP0N0:IlYP030000
000L0140700A0080700A00<000000;i@>P2nD3X02@2nD3X2000001`0[H:V00<000000>g3Z03]`jP0
303]`jP00`000000kL>X0>g3Z002000000H0oooo0`00000/0?ooo`030000003oool0oooo00l0oooo
000>0?ooo`030000003oool0oooo03L0oooo00<0000000XNWP0:7Yh0100:7Yh00`000000YWbV0:Il
YP0M0:IlYP030000000L0140700A00<0700A00<000000;i@>P2nD3X02`2nD3X2000001T0[H:V00<0
00000>g3Z03]`jP03@3]`jP01@000000kL>X0>g3Z0000000^cT600H00000;`3oool00`000000oooo
0?ooo`0?0?ooo`003P3oool00`000000oooo0?ooo`0g0?ooo`030000000:7Yh02QjN00@02QjN00<0
00000:IlYP2VO:H06`2VO:H2000000H0700A00<000000;i@>P2nD3X03@2nD3X00`000000[H:V0:f2
YP0F0:f2YP030000003]`jP0kL>X00d0kL>X00@000000>g3Z03]`jP00000102k>@H200000300oooo
00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0=`3oool00`0000002QjN00XN
WP0500XNWP030000002VO:H0YWbV01T0YWbV00<0000001`04@0L01401P0L01400`000000_U0j0;i@
>P0>0;i@>P8000005P2]PZH00`000000kL>X0>g3Z00=0>g3Z0040000003]`jP0kL>X000000H0^cT6
0`00000]0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo03P0oooo00<0
000000XNWP0:7Yh01@0:7Yh00`000000YWbV0:IlYP0H0:IlYP030000000L0140700A00H0700A00<0
00000;i@>P2nD3X04@2nD3X2000001@0[H:V00<000000>g3Z03]`jP03@3]`jP01@000000kL>X0>g3
Z03]`jP0000000P0^cT60P00000[0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003o
ool0oooo03P0oooo00<0000000XNWP0:7Yh01@0:7Yh00`000000YWbV0:IlYP0G0:IlYP030000000L
0140700A00L0700A00<000000;i@>P2nD3X04`2nD3X200000180[H:V00<000000>g3Z03]`jP03@3]
`jP01@000000kL>X0>g3Z03]`jP0000000X0^cT60P00000Y0?ooo`030000003oool0oooo00l0oooo
000=0?ooo`030000003oool0oooo03P0oooo00<0000000XNWP0:7Yh01P0:7Yh00`000000YWbV0:Il
YP0E0:IlYP030000000L0140700A00P0700A00<000000;i@>P2nD3X05@2nD3X200000100[H:V00<0
00000>g3Z03]`jP03@3]`jP01@000000kL>X0>g3Z03]`jP0000000`0^cT60`00000W0?ooo`030000
003oool0oooo00h0oooo000=0?ooo`030000003oool0oooo03P0oooo00<0000000XNWP0:7Yh01P0:
7Yh00`000000YWbV0:IlYP0D0:IlYP030000000L0140700A00T0700A00<000000;i@>P2nD3X05`2n
D3X00`000000[H:V0:f2YP0<0:f2YP030000003]`jP0kL>X00h0kL>X00D000000>g3Z03]`jP0kL>X
0000000?0;/i1P8000009@3oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?oo
o`0h0?ooo`030000000:7Yh02QjN00H02QjN00<000000:IlYP2VO:H04P2VO:H2000000/0700A00<0
00000;i@>P2nD3X06@2nD3X2000000`0[H:V00<000000>g3Z03]`jP03P3]`jP00`000000kL>X0>g3
Z0020>g3Z0030000002k>@H0^cT600h0^cT60P00000S0?ooo`030000003oool0oooo00h0oooo000=
0?ooo`030000003oool0oooo03T0oooo00<0000000XNWP0:7Yh01P0:7Yh00`000000YWbV0:IlYP0@
0:IlYP030000000L0140700A00/0700A00<000000;i@>P2nD3X06`2nD3X2000000X0[H:V00<00000
0>g3Z03]`jP03P3]`jP00`000000kL>X0>g3Z0020>g3Z0030000002k>@H0^cT60100^cT60`00000P
0?ooo`030000003oool0oooo00h0oooo000=0?ooo`030000003oool0oooo03T0oooo00<0000000XN
WP0:7Yh01P0:7Yh00`000000YWbV0:IlYP0?0:IlYP030000000L0140700A00`0700A00<000000;i@
>P2nD3X07@2nD3X2000000P0[H:V00<000000>g3Z03]`jP03P3]`jP00`000000kL>X0>g3Z0020>g3
Z0030000002k>@H0^cT601<0^cT60P00000N0?ooo`030000003oool0oooo00h0oooo000<0?ooo`03
0000003oool0oooo03X0oooo00<0000000XNWP0:7Yh01P0:7Yh00`000000YWbV0:IlYP0>0:IlYP03
0000000L0140700A00d0700A00<000000;i@>P2nD3X07`2nD3X00`000000[H:V0:f2YP050:f2YP03
0000003]`jP0kL>X00h0kL>X00<000000>g3Z03]`jP00P3]`jP00`000000^cT60;/i1P0E0;/i1P80
0000703oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`0j0?ooo`030000
000:7Yh02QjN00L02QjN00<000000:IlYP2VO:H0302VO:H00`000000700A01`04@0=01`04@030000
002nD3X0_U0j0240_U0j0P0000050:f2YP030000003]`jP0kL>X00h0kL>X00<000000>g3Z03]`jP0
0`3]`jP00`000000^cT60;/i1P0;0;/i1Pd000006P3oool00`000000oooo0?ooo`0>0?ooo`00303o
ool00`000000oooo0?ooo`0j0?ooo`030000000:7Yh02QjN00L02QjN00<000000:IlYP2VO:H02`2V
O:H00`000000700A01`04@0>01`04@030000002nD3X0_U0j02<0_U0j0P0000020:f2YP030000003]
`jP0kL>X00l0kL>X5000000;0?C=Y`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3o
ool000`0oooo00<000000?ooo`3oool0>P3oool00`0000002QjN00XNWP0700XNWP030000002VO:H0
YWbV00T0YWbV0P00000A01`04@030000002nD3X0_U0j02D0_U0j0`0000060>g3Z0`000001P36E340
0`000000m<fW0?C=Y`0E0?C=Y`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool0
00`0oooo00<000000?ooo`3oool0>P3oool00`0000002QjN00XNWP0800XNWP030000002VO:H0YWbV
00L0YWbV00<0000001`04@0L01404@0L01400`000000_U0j0;i@>P0T0;i@>PX000002`36E3400`00
0000aU@a0<ID<@050<ID<@030000003dcJL0m<fW01<0m<fW00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`0j0?ooo`030000000:7Yh02QjN00P0
2QjN00<000000:IlYP2VO:H01P2VO:H00`000000700A01`04@0A01`04@030000002nD3X0_U0j01h0
_U0j1`0000030>O2/@<000003`36E3400`000000aU@a0<ID<@050<ID<@030000003dcJL0m<fW01<0
m<fW00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo
0?ooo`0j0?ooo`030000000:7Yh02QjN00P02QjN00<000000:IlYP2VO:H01@2VO:H00`000000700A
01`04@0B01`04@030000002nD3X0_U0j01H0_U0j2000000:0>O2/@040000002`RJ`0/8V/000000h0
aU@a00<000000<ID<@36E3401P36E3400`000000m<fW0?C=Y`0A0?C=Y`030000003oool0oooo01`0
oooo00<000000?ooo`3oool03@3oool000`0oooo00<000000?ooo`3oool0>P3oool00`0000002QjN
00XNWP0900XNWP030000002VO:H0YWbV00<0YWbV00<0000001`04@0L01404`0L01400`000000_U0j
0;i@>P0?0;i@>PL000004@3W`[400`000000/8V/0;29[0020;29[08000003036E3400`000000aU@a
0<ID<@070<ID<@030000003dcJL0m<fW0100m<fW00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`0k0?ooo`030000000:7Yh02QjN00T02QjN00@0
00000:IlYP2VO:H0YWbV0P00000F01`04@030000002nD3X0_U0j00P0_U0j1`00000H0>O2/@030000
002`RJ`0/8V/00@0/8V/00<000000<ID<@36E3402@36E3400`000000aU@a0<ID<@080<ID<@030000
003dcJL0m<fW00h0m<fW00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`002`3o
ool00`000000oooo0?ooo`0k0?ooo`8000002P0:7Yh010000000YWbV0:IlYP00000G01`04@040000
002nD3X0_U0j0;i@>PP000007`3W`[400`000000/8V/0;29[0050;29[08000002@36E3400`000000
aU@a0<ID<@080<ID<@030000003dcJL0m<fW00h0m<fW00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`0j0?ooo`<000002`0:7Yh2000000`0700A
4000000W0>O2/@030000002`RJ`0/8V/00L0/8V/0P0000080<ID<@0300000036E340aU@a00P0aU@a
00<000000?C=Y`3dcJL0303dcJL00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00d0oooo
000;0?ooo`030000003oool0oooo03T0oooo1000000:00XNWPl00000300/?K42000002P0il:a00<0
00000;29[02`RJ`02P2`RJ`00`000000aU@a0<ID<@050<ID<@0300000036E340aU@a00T0aU@a00<0
00000?C=Y`3dcJL02`3dcJL00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo000;
0?ooo`030000003oool0oooo03P0oooo1@00000600XNWPH000006@0/?K400`000000YkgY0000000W
0>O2/@030000002`RJ`0/8V/00/0/8V/0P0000050<ID<@0300000036E340aU@a00X0aU@a00<00000
0?C=Y`3dcJL02@3dcJL00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00`0oooo000;0?oo
o`030000003oool0oooo03L0oooo1P00000200XNWPP000000P2UPJd00`000000;3fa02`m/@0E02`m
/@050000002W_NT0YkgY0:Nmj@0000009P3W`[400`000000/8V/0;29[00=0;29[00300000036E340
aU@a0080aU@a00<000000<ID<@36E3402P36E3400`000000m<fW0?C=Y`090?C=Y`030000003oool0
oooo0200oooo00<000000?ooo`3oool0303oool000/0oooo00<000000?ooo`3oool0=@3ooolA0000
00<0YH6]00<0000002`m/@0/?K405@0/?K400`000000YkgY0:Nmj@020:Nmj@030000003W`[40il:a
02<0il:a00<000000;29[02`RJ`03P2`RJ`200000080aU@a00<000000<ID<@36E3402`36E3400`00
0000m<fW0?C=Y`070?C=Y`030000003oool0oooo0240oooo00<000000?ooo`3oool0303oool000X0
oooo00<000000?ooo`3oool0=@3ooolA000000D0YH6]00<0000002`m/@0/?K40500/?K400`000000
YkgY0:Nmj@030:Nmj@030000003W`[40il:a0240il:a00<000000;29[02`RJ`04@2`RJ`00`000000
aU@a0000000>0<ID<@030000003dcJL0m<fW00D0m<fW00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`D000000`001I<9000000H0YH6]
00<0000002`m/@0/?K40500/?K400`000000YkgY0:Nmj@040:Nmj@030000003W`[40il:a0200il:a
00<000000;29[02`RJ`04P2`RJ`2000000l0aU@a00<000000?C=Y`3dcJL0103dcJL00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo03<0oooo0P00
00060005T`T000001`2UPJd00`000000;3fa02`m/@0C02`m/@030000002W_NT0YkgY00H0YkgY00<0
00000>O2/@3W`[407`3W`[400`000000/8V/0;29[00C0;29[08000003`36E3400`000000m<fW0?C=
Y`020?C=Y`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool000X0oooo00<00000
0?ooo`3oool0=03oool00`00000000FC0005T`030005T`T000002@2UPJd00`000000;3fa02`m/@0B
02`m/@030000002W_NT0YkgY00L0YkgY00<000000>O2/@3W`[407P3W`[400`000000/8V/0;29[00C
0;29[0040000002`RJ`00000000000d0aU@a00<000000?C=Y`3dcJL00P3dcJL00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo03@0oooo00<00000
0005T`001I<00P001I<9000000X0YH6]00<0000002`m/@0/?K404P0/?K400`000000YkgY0:Nmj@07
0:Nmj@030000003W`[40il:a01d0il:a00<000000;29[02`RJ`0502`RJ`01@000000/8V/0;29[02`
RJ`0000000d0aU@a00@000000?C=Y`3dcJL000009`3oool00`000000oooo0?ooo`0;0?ooo`002P3o
ool00`000000oooo0?ooo`0e0?ooo`04000000001I<000FC0005T`P00000302UPJd00`000000;3fa
02`m/@0A02`m/@030000002W_NT0YkgY00P0YkgY00<000000>O2/@3W`[40703W`[400`000000/8V/
0;29[00D0;29[0030000002`RJ`0/8V/0080/8V/0P00000<0<ID<@030000003dcJL0000002L0oooo
00<000000?ooo`3oool02`3oool000X0oooo00<000000?ooo`3oool0=@3oool00`00000000FC0005
T`08000000d0YH6]00<0000002`m/@0/?K40400/?K400`000000YkgY0:Nmj@0:0:Nmj@030000003W
`[40il:a01/0il:a00<000000;29[02`RJ`0502`RJ`00`000000/8V/0;29[0040;29[08000002`36
E3400`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0
oooo03H0oooo2P00000=0:F1[@030000000/?K40;3fa0100;3fa00<000000:Nmj@2W_NT02`2W_NT0
0`000000il:a0>O2/@0J0>O2/@030000002`RJ`0/8V/01@0/8V/00<000000;29[02`RJ`01P2`RJ`0
0`000000aU@a0<ID<@080<ID<@030000003oool0oooo02H0oooo00<000000?ooo`3oool02`3oool0
00T0oooo00<000000?ooo`3oool0=`3oool9000000l0YH6]00<0000002`m/@0/?K403`0/?K400`00
0000YkgY0:Nmj@0<0:Nmj@030000003W`[40il:a01P0il:a00<000000;29[02`RJ`05@2`RJ`00`00
0000/8V/0;29[0070;29[08000002@36E3400`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00/0oooo00090?ooo`030000003oool0oooo03L0oooo2000000@0:F1[@030000000/?K40;3fa00l0
;3fa00<000000:Nmj@2W_NT03@2W_NT00`000000il:a0>O2/@0G0>O2/@030000002`RJ`0/8V/01D0
/8V/00<000000;29[02`RJ`02@2`RJ`00`000000aU@a0<ID<@070<ID<@030000003oool0oooo02@0
oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0=P3oool800000180YH6]
00<0000002`m/@0/?K403@0/?K400`000000YkgY0:Nmj@0?0:Nmj@030000003W`[40il:a01H0il:a
00<000000;29[02`RJ`05@2`RJ`00`000000/8V/0;29[00:0;29[08000002036E3400`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo03D0oooo2000
000C0:F1[@030000000/?K40;3fa00d0;3fa00<000000:Nmj@2W_NT0402W_NT00`000000il:a0>O2
/@0E0>O2/@030000002`RJ`0/8V/01D0/8V/00<000000;29[02`RJ`0302`RJ`00`000000aU@a0<ID
<@060<ID<@030000003oool0oooo0280oooo00<000000?ooo`3oool02`3oool000T0oooo00<00000
0?ooo`3oool0=@3oool7000001@0YH6]00<0000002`m/@0/?K403@0/?K400`000000YkgY0:Nmj@0A
0:Nmj@030000003W`[40il:a01@0il:a00<000000;29[02`RJ`05@2`RJ`00`000000/8V/0;29[00=
0;29[08000001P36E3400`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo00090?oo
o`030000003oool0oooo03@0oooo1`00000F0:F1[@030000000/?K40;3fa00`0;3fa00<000000:Nm
j@2W_NT04P2W_NT00`000000il:a0>O2/@0B0>O2/@030000002`RJ`0/8V/01H0/8V/00<000000;29
[02`RJ`03`2`RJ`00`000000aU@a0<ID<@040<ID<@030000003oool0oooo0280oooo00<000000?oo
o`3oool02P3oool000T0oooo00<000000?ooo`3oool0<`3oool7000001L0YH6]00<0000002`m/@0/
?K402`0/?K400`000000YkgY0:Nmj@0D0:Nmj@030000003W`[40il:a0140il:a00<000000;29[02`
RJ`05P2`RJ`00`000000/8V/0;29[00@0;29[08000001@36E3400`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00X0oooo00090?ooo`030000003oool0oooo0380oooo1`00000I0:F1[@030000
000/?K40;3fa00X0;3fa00<000000:Nmj@2W_NT05@2W_NT00`000000il:a0>O2/@0@0>O2/@030000
002`RJ`0/8V/01L0/8V/00<000000;29[02`RJ`04@2`RJ`00`000000aU@a0<ID<@030<ID<@030000
003oool0oooo0200oooo00<000000?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool0<`3o
ool6000001X0YH6]00<0000002`m/@0/?K402P0/?K400`000000YkgY0:Nmj@0F0:Nmj@030000003W
`[40il:a00l0il:a00<000000;29[02`RJ`05`2`RJ`00`000000/8V/0;29[00B0;29[08000000`36
E3400`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0
oooo0380oooo1P00000K0:F1[@030000000/?K40;3fa00X0;3fa00<000000:Nmj@2W_NT05`2W_NT0
0`000000il:a0>O2/@0=0>O2/@030000002`RJ`0/8V/01P0/8V/00<000000;29[02`RJ`0502`RJ`2
00000080aU@a00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`00203oool00`00
0000oooo0?ooo`0a0?ooo`H000007@2UPJd00`000000;3fa02`m/@0802`m/@030000002W_NT0YkgY
01T0YkgY00<000000>O2/@3W`[40303W`[400`000000/8V/0;29[00H0;29[0030000002`RJ`0/8V/
01H0/8V/00@000000<ID<@36E3400000803oool00`000000oooo0?ooo`0:0?ooo`00203oool00`00
0000oooo0?ooo`0`0?ooo`H000007P2UPJd00`000000;3fa02`m/@0802`m/@030000002W_NT0YkgY
01X0YkgY00<000000>O2/@3W`[402`3W`[400`000000/8V/0;29[00H0;29[0030000002`RJ`0/8V/
01L0/8V/0P0000000`36E34000000?ooo`0N0?ooo`030000003oool0oooo00X0oooo00080?ooo`03
0000003oool0oooo0300oooo1@00000P0:F1[@030000000/?K40;3fa00L0;3fa00<000000:Nmj@2W
_NT06`2W_NT00`000000il:a0>O2/@0:0>O2/@030000002`RJ`0/8V/01P0/8V/00<000000;29[02`
RJ`06@2`RJ`200000200oooo00<000000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0
;`3oool500000240YH6]00<0000002`m/@0/?K401`0/?K400`000000YkgY0:Nmj@0L0:Nmj@030000
003W`[40il:a00P0il:a00<000000;29[02`RJ`06@2`RJ`00`000000/8V/0;29[00J0;29[0800000
7`3oool00`000000oooo0?ooo`090?ooo`00203oool00`000000oooo0?ooo`0^0?ooo`D000008P2U
PJd00`000000;3fa02`m/@0602`m/@030000002W_NT0YkgY01d0YkgY00<000000>O2/@3W`[40203W
`[400`000000/8V/0;29[00I0;29[0030000002`RJ`0/8V/01T0/8V/1000000N0?ooo`030000003o
ool0oooo00T0oooo00070?ooo`030000003oool0oooo02l0oooo1000000T0:F1[@030000000/?K40
;3fa00D0;3fa00<000000:Nmj@2W_NT07P2W_NT00`000000il:a0>O2/@070>O2/@030000002`RJ`0
/8V/01T0/8V/00<000000;29[02`RJ`04P2`RJ`7000000030:g7k0000000000001l0oooo00<00000
0?ooo`3oool02@3oool000L0oooo00<000000?ooo`3oool0;P3oool4000002D0YH6]00<0000002`m
/@0/?K401@0/?K400`000000YkgY0:Nmj@0O0:Nmj@030000003W`[40il:a00H0il:a00<000000;29
[02`RJ`06@2`RJ`00`000000/8V/0;29[00<0;29[0H000001`2]an`00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00T0oooo00070?ooo`030000003oool0oooo02d0oooo1000000W0:F1[@03
0000000/?K40;3fa00@0;3fa00<000000:Nmj@2W_NT0802W_NT00`000000il:a0>O2/@040>O2/@03
0000002`RJ`0/8V/01T0/8V/0P0000070;29[0L00000302]an`00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00T0oooo00070?ooo`030000003oool0oooo02`0oooo1000000X0:F1[@030000
000/?K40;3fa00<0;3fa00<000000:Nmj@2W_NT08P2W_NT00`000000il:a0>O2/@030>O2/@030000
002`RJ`0/8V/01H0/8V/0`0000020;29[0L000004@2]an`2000002<0oooo00<000000?ooo`3oool0
2@3oool000L0oooo00<000000?ooo`3oool0;03oool3000002T0YH6]00<0000002`m/@0/?K400`0/
?K400`000000YkgY0:Nmj@0S0:Nmj@030000003W`[40il:a0080il:a00<000000;29[02`RJ`04P2`
RJ`9000000030:g7k0000000[LO/01@0[LO/00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`090?ooo`001`3oool00`000000oooo0?ooo`0[0?ooo`<00000:`2UPJd00`000000;3fa02`m/@02
02`m/@030000002W_NT0YkgY02@0YkgY00D000000>O2/@3W`[40il:a0000000?0;29[0L000002@2]
an`00`000000[LO/0:g7k00@0:g7k08000009`3oool00`000000oooo0?ooo`080?ooo`001`3oool0
0`000000oooo0?ooo`0Z0?ooo`@00000:`2UPJd00`000000;3fa02`m/@0202`m/@030000002W_NT0
YkgY02D0YkgY00<000000>O2/@0000002P2`RJ`8000000h0[LO/00<000000:g7k02]an`03`2]an`0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo00070?ooo`030000003oool0oooo
02X0oooo0`00000]0:F1[@040000000/?K40;3fa000002T0YkgY0P0000030;29[0L000000P2]an`3
00000180[LO/00<000000:g7k02]an`03@2]an`00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00P0oooo00060?ooo`030000003oool0oooo02X0oooo0`00000^0:F1[@040000000/?K40;3fa
000002H0YkgY200000050:g7k0@000005P2]an`00`000000[LO/0:g7k00:0:g7k0800000:`3oool0
0`000000oooo0?ooo`080?ooo`001P3oool00`000000oooo0?ooo`0Y0?ooo`<00000;`2UPJd01000
0000;3fa02`m/@00000M0:Nmj@T00000102[R;02000000@0[LO/0`00000K0:g7k0030000002]an`0
[LO/00P0[LO/00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`001P3oool00`00
0000oooo0?ooo`0X0?ooo`<00000<@2UPJd00`000000;3fa0000000E0:Nmj@P00000302[R;000`00
0000jLbh0>W<^004000001l0[LO/00<000000:g7k02]an`01@2]an`2000002h0oooo00<000000?oo
o`3oool0203oool000H0oooo00<000000?ooo`3oool0:03oool200000380YH6]0P00000=0:Nmj@T0
0000502[R;0500000280[LO/00<000000:g7k02]an`00`2]an`00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo02L0oooo0P00000d0:F1[@030000
002W_NT0YkgY0080YkgY2@00000J0:^8/0@00000103Yc;P00`000000[LO/0:g7k00O0:g7k0030000
002]an`0[LO/0080[LO/00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`001P3o
ool00`000000oooo0?ooo`0V0?ooo`800000;02UPJd>00000200ZhR`0`0000030:^8/0030000003Y
c;P0jLbh00<0jLbh00<000000:g7k02]an`07`2]an`010000000[LO/00000000000c0?ooo`030000
003oool0oooo00L0oooo00060?ooo`030000003oool0oooo02D0oooo0P00000J0:F1[A<000002@2L
_>l00`000000ZhR`0:^8/00O0:^8/0<000001@2[R;000`000000jLbh0>W<^0040>W<^0030000002]
an`0[LO/0200[LO/00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`001@3oool0
0`000000oooo0?ooo`0V0?ooo`030000002UPJd0YH6]00H0YH6]4`00000L09blk`8000007@2[R;03
000000P0ZhR`00<000000>W<^03Yc;P01@3Yc;P00`000000[LO/0:g7k00M0:g7k080000000<0oooo
0000003oool0<`3oool00`000000oooo0?ooo`070?ooo`001@3oool00`000000oooo0?ooo`0U0?oo
o`X00000;P2L_>l00`0000008Cnh0000000I0:^8/0@000002`2[R;000`000000jLbh0>W<^0060>W<
^0030000002]an`0[LO/01/0[LO/00<000000?7C/P0000000P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00L0oooo00050?ooo`030000003oool0oooo02L0oooo0P00000d09blk`04
0000000Q?kP08Cnh000001D0ZhR`0`00000>0:^8/0030000003Yc;P0jLbh00P0jLbh00<000000:g7
k02]an`06@2]an`010000000lM>b0?7C/P0000030?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool01`3oool000D0oooo00<000000?ooo`3oool0:@3oool300000340W;c_00@00000024o
^00Q?kP000004P2[R;0300000140ZhR`00<000000>W<^03Yc;P02@3Yc;P00`000000[LO/0:g7k00F
0:g7k08000000`3adk800`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool01`3oool000D0oooo00<000000?ooo`3oool0;03oool3000002h0W;c_00D00000024o
^00Q?kP08Cnh0000000=0:^8/0@00000502[R;000`000000jLbh0>W<^00:0>W<^0030000002]an`0
[LO/01@0[LO/00<000000?7C/P3adk800`3adk800`000000oooo0?ooo`020?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool01`3oool000D0oooo00<000000?ooo`3oool0;`3oool20000
02`0W;c_00D00000024o^00Q?kP08Cnh0000000:0:^8/0<00000602[R;000`000000jLbh0>W<^00;
0>W<^0030000002]an`0[LO/0140[LO/0P0000060?7C/P030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`001@3oool00`000000oooo0?ooo`0a0?oo
o`<00000:@2L_>l00`0000008Cnh024o^002024o^0030000002[R;00ZhR`00@0ZhR`0`00000J0:^8
/0030000003Yc;P0jLbh00d0jLbh00<000000:g7k02]an`03`2]an`00`000000lM>b0?7C/P060?7C
/P030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`060?oo
o`001@3oool00`000000oooo0?ooo`0d0?ooo`<000009@2L_>l00`0000008Cnh024o^003024o^004
0000002[R;00ZhR`0:^8/0<000007@2[R;000`000000jLbh0>W<^00>0>W<^0030000002]an`0[LO/
00d0[LO/00<000000?7C/P3adk801`3adk800`000000oooo0?ooo`050?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool01P3oool000@0oooo00<000000?ooo`3oool0>03oool2000002<0
W;c_00<00000024o^00Q?kP00`0Q?kP400000200ZhR`00<000000>W<^03Yc;P03`3Yc;P00`000000
[LO/0:g7k00:0:g7k08000002P3adk800`000000oooo0?ooo`060?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool01P3oool000@0oooo00<000000?ooo`3oool0>P3oool300000200W;c_
00<00000024o^00Q?kP00`0000000`0Q?kP000000:^8/00P0:^8/0030000003Yc;P0jLbh0100jLbh
00<000000:g7k02]an`02@2]an`00`000000lM>b0?7C/P0:0?7C/P030000003oool0oooo00L0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`060?ooo`00103oool00`000000oooo0?oo
o`0m0?ooo`<000007@2L_>l3000000D08Cnh00<000000:^8/02[R;007P2[R;000`000000jLbh0>W<
^00A0>W<^0030000002]an`0[LO/00H0[LO/0P00000=0?7C/P030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`060?ooo`00103oool00`000000oooo0?ooo`10
0?ooo`800000602L_>l4000000L08Cnh00<000000:^8/02[R;007P2[R;000`000000jLbh0>W<^00B
0>W<^0030000002]an`0[LO/00@0[LO/00<000000?7C/P3adk803@3adk800`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01P3oool000@0oooo00<000000?oo
o`3oool0@P3oool300000140W;c_1000000309blk`030000000Q?kP08Cnh00H08Cnh00<000000:^8
/02[R;007@2[R;000`000000jLbh0>W<^00C0>W<^0030000002]an`0[LO/0080[LO/00<000000?7C
/P3adk803P3adk800`000000oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool01P3oool000@0oooo00<000000?ooo`3oool0A@3oool3000000/0W;c_0`00000609blk`03
0000000Q?kP08Cnh00L08Cnh00<000000:^8/02[R;00702[R;000`000000jLbh0>W<^00E0>W<^004
0000002]an`0000000000180lM>b00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00H0oooo00040?ooo`030000003oool0oooo04P0oooo0P00000609blk`<0
00002@2L_>l00`0000008Cnh024o^008024o^0030000002[R;00ZhR`01/0ZhR`00<000000>W<^03Y
c;P05P3Yc;P00`000000lM>b0?7C/P0B0?7C/P030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`050?ooo`000`3oool00`000000oooo0?ooo`1;0?ooo`H00000
302L_>l00`0000008Cnh024o^008024o^0030000002[R;00ZhR`01/0ZhR`00<000000>W<^03Yc;P0
5@3Yc;P00`000000Y/gd0000000C0?7C/P030000003oool0oooo00/0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`050?ooo`000`3oool00`000000oooo0?ooo`1:0?ooo`L00000302L
_>l00`0000008Cnh024o^009024o^0030000002[R;00ZhR`01T0ZhR`00<000000>W<^03Yc;P05@3Y
c;P01@000000Y/gd0:K=m02VcO@000000180lM>b00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00030?ooo`030000003oool0oooo04L0oooo0`00
00070?ooo`8000002P2L_>l00`0000008Cnh024o^009024o^0030000002[R;00ZhR`01T0ZhR`00<0
00000>W<^03Yc;P0503Yc;P00`000000Y/gd0:K=m0030:K=m0030000003adk80lM>b00l0lM>b00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo0003
0?ooo`030000003oool0oooo04@0oooo0`00000:0?ooo`03000000007ZL00000008000001`2L_>l0
0`0000008Cnh024o^00:024o^0030000002[R;00ZhR`01P0ZhR`00<000000>W<^03Yc;P04`3Yc;P0
0`000000Y/gd0:K=m0050:K=m0030000003adk80lM>b00h0lM>b00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00030?ooo`030000003oool0oooo
0440oooo0`00000>0?ooo`04000000007ZL001jW000NY`<000000`2L_>l00`0000008Cnh024o^00;
024o^0030000002[R;00ZhR`01P0ZhR`00<000000>W<^03Yc;P04P3Yc;P00`000000Y/gd0:K=m007
0:K=m0030000003adk80lM>b00d0lM>b00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00D0oooo00030?ooo`030000003oool0oooo03d0oooo1000000A0?oo
o`03000000007ZL001jW00@001jW0P0000000`2L_>l00000024o^00=024o^0030000002[R;00ZhR`
01H0ZhR`00<000000>W<^03Yc;P04P3Yc;P00`000000Y/gd0:K=m0080:K=m0030000003adk80lM>b
00d0lM>b00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00D0oooo00030?ooo`030000003oool0oooo03X0oooo0`00000E0?ooo`03000000007ZL001jW00H0
01jW0P00000>024o^0030000002[R;00ZhR`01H0ZhR`00<000000>W<^03Yc;P04P3Yc;P00`000000
Y/gd0:K=m0090:K=m0030000003adk80lM>b00`0lM>b00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00030?ooo`030000003oool0oooo03L0oooo
0`00000I0?ooo`03000000007ZL001jW00H001jW0P00000>024o^0030000002[R;00ZhR`01D0ZhR`
00<000000>W<^03Yc;P04@3Yc;P00`000000Y/gd0:K=m00;0:K=m0030000003adk80lM>b00/0lM>b
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo
00020?ooo`030000003oool0oooo03D0oooo0`00000L0?ooo`03000000007ZL001jW00H001jW00<0
000009W5mP0000003@0Q?kP00`000000ZhR`0:^8/00D0:^8/0030000003Yc;P0jLbh0140jLbh00<0
00000:K=m02VcO@03@2VcO@00`000000lM>b0?7C/P0:0?7C/P030000003oool0oooo0180oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`040?ooo`000P3oool00`000000oooo0?ooo`0a
0?ooo`@000007`3oool00`00000001jW000NY`06000NY`040000002IaOH0VLGf000000d08Cnh00<0
00000:^8/02[R;004`2[R;000`000000jLbh0>W<^00@0>W<^0030000002VcO@0Y/gd00l0Y/gd00<0
00000?7C/P3adk802@3adk800`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0103oool00080oooo00<000000?ooo`3oool0;P3oool3000002@0oooo00<00000
000NY`007ZL01@007ZL01@000000VLGf09W5mP2IaOH0000000`08Cnh00<000000:^8/02[R;004`2[
R;000`000000jLbh0>W<^00?0>W<^0030000002VcO@0Y/gd0140Y/gd00<000000?7C/P3adk80203a
dk800`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0103o
ool00080oooo00<000000?ooo`3oool0:`3oool3000002L0oooo00<00000000NY`007ZL01@007ZL0
0`000000VLGf09W5mP0209W5mP030000000Q?kP08Cnh00X08Cnh00<000000:^8/02[R;004P2[R;00
0`000000jLbh0>W<^00>0>W<^0030000002VcO@0Y/gd01<0Y/gd00<000000?7C/P3adk801`3adk80
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0103oool0
0080oooo00<000000?ooo`3oool0:03oool3000002X0oooo00<00000000NY`007ZL01@007ZL00`00
0000VLGf09W5mP0309W5mP030000000Q?kP08Cnh00T08Cnh00<000000:^8/02[R;004@2[R;000`00
0000jLbh0>W<^00>0>W<^0030000002VcO@0Y/gd01D0Y/gd00<000000?7C/P3adk801P3adk800`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool00080
oooo00<000000?ooo`3oool0903oool4000002d0oooo00<00000000NY`007ZL010007ZL00`000000
VLGf09W5mP0509W5mP030000000Q?kP08Cnh00T08Cnh00<000000:^8/02[R;00402[R;000`000000
jLbh0>W<^00=0>W<^0030000002VcO@0Y/gd01L0Y/gd00<000000?7C/P3adk801@3adk800`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool00080oooo
00<000000?ooo`3oool08@3oool300000380oooo00<00000000NY`007ZL00`007ZL00`000000VLGf
09W5mP0609W5mP030000000Q?kP08Cnh00P08Cnh00<000000:^8/02[R;00402[R;000`000000jLbh
0>W<^00<0>W<^0030000002VcO@0Y/gd01T0Y/gd00<000000?7C/P3adk80103adk800`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool000030?ooo`00
0000oooo0200oooo0`00000e0?ooo`03000000007ZL001jW00<001jW00<0000009W5mP2IaOH01`2I
aOH00`0000008Cnh024o^008024o^0030000002[R;00ZhR`00l0ZhR`00<000000>W<^03Yc;P02`3Y
c;P00`000000Y/gd0:K=m00K0:K=m0030000003adk80lM>b00<0lM>b00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00000`3oool000000?ooo`0L
0?ooo`@00000>03oool00`00000001jW000NY`03000NY`030000002IaOH0VLGf00P0VLGf00<00000
024o^00Q?kP01`0Q?kP00`000000ZhR`0:^8/00>0:^8/0030000003Yc;P0jLbh00/0jLbh00<00000
0:K=m02VcO@07@2VcO@00`000000lM>b0?7C/P020?7C/P030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000003oool06@3oool30000
03d0oooo00<00000000NY`007ZL00P007ZL00`000000VLGf09W5mP0909W5mP030000000Q?kP08Cnh
00L08Cnh00<000000:^8/02[R;003@2[R;000`000000jLbh0>W<^00:0>W<^0H000006`2VcO@00`00
0000lM>b0?7C/P020?7C/P030000003oool0oooo01T0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`030?ooo`0000<0oooo0000003oool05P3oool300000400oooo00<00000000NY`00
7ZL00P007ZL00`000000VLGf09W5mP0:09W5mP030000000Q?kP08Cnh00H08Cnh00<000000:^8/02[
R;003@2[R;000`000000jLbh0>W<^0090>W<^0030000003oool0oooo00@0oooo1`00000E0:K=m005
0000003adk80lM>b0?7C/P000000703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00<0oooo00000`3oool000000?ooo`0C0?ooo`<00000@`3oool00`00000001jW000NY`02000NY`03
0000002IaOH0VLGf00/0VLGf00<00000024o^00Q?kP01P0Q?kP00`000000ZhR`0:^8/00;0:^8/003
0000003Yc;P0jLbh00X0jLbh00<000000?ooo`3oool02`3oool8000000h0Y/gd00@000000?7C/P3a
dk8000007@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00000`3oool0
00000?ooo`0?0?ooo`@00000A`3oool01@00000001jW000NY`007ZL0000000h0VLGf00<00000024o
^00Q?kP01@0Q?kP00`000000ZhR`0:^8/00;0:^8/0030000003Yc;P0jLbh00T0jLbh00<000000?oo
o`3oool0503oool7000000P0Y/gd00<000000?7C/P0000007P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00<0oooo00000`3oool000000?ooo`0<0?ooo`<00000B`3oool01@000000
01jW000NY`007ZL0000000l0VLGf00<00000024o^00Q?kP01@0Q?kP00`000000ZhR`0:^8/00:0:^8
/0030000003Yc;P0jLbh00P0jLbh00<000000?ooo`3oool0703oool700000080Y/gd0P00000O0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool000030?ooo`000000oooo00T0
oooo0`00001>0?ooo`05000000007ZL001jW000NY`0000003`2IaOH00`0000008Cnh024o^005024o
^0030000002[R;00ZhR`00X0ZhR`00<000000>W<^03Yc;P01`3Yc;P00`000000oooo0?ooo`0T0?oo
o`@000007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00000`000000
oooo0?ooo`060?ooo`<00000DP3oool01000000001jW000NY`00000@09W5mP030000000Q?kP08Cnh
00D08Cnh00<000000:^8/02[R;00202[R;000`000000jLbh0>W<^0070>W<^0030000003oool0oooo
04T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`0000<000000?ooo`3o
ool00P3oool4000005D0oooo00@00000000NY`007ZL000003`2IaOH3000000H08Cnh00<000000:^8
/02[R;00202[R;000`000000jLbh0>W<^0060>W<^0030000003oool0oooo04/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`020?ooo`0000<000000?ooo`0000000P00001I0?ooo`03
000000007ZL0000000d0VLGf0`0000030?ooo`030000000Q?kP08Cnh00@08Cnh00<000000:^8/02[
R;001`2[R;000`000000jLbh0>W<^0050>W<^0030000003oool0oooo04d0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`000P00001L0?ooo`03000000007ZL0000000/0VLGf
0P0000070?ooo`030000000Q?kP08Cnh00<08Cnh00<000000:^8/02[R;001P2[R;000`000000jLbh
0>W<^0050>W<^0030000003oool0oooo04l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`0000<0oooo000000000000G03oool2000000P0VLGf0`00000:0?ooo`030000000Q
?kP08Cnh00<08Cnh00<000000:^8/02[R;001@2[R;000`000000jLbh0>W<^0040>W<^0030000003o
ool0oooo0540oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`000`3oool0
0`000000oooo0?ooo`1I0?ooo`8000001P2IaOH2000000h0oooo00<00000024o^00Q?kP00P0Q?kP0
0`000000ZhR`0:^8/0050:^8/0030000003Yc;P0jLbh00<0jLbh00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo
05P0oooo0P00000309W5mP<000004@3oool00`0000008Cnh024o^002024o^0030000002[R;00ZhR`
00@0ZhR`00<000000>W<^03Yc;P00P3Yc;P00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool00P3oool000D0oooo0P00001I0?ooo`040000002IaOH000000000
01D0oooo00D00000024o^00Q?kP08Cnh000000050:^8/0030000003Yc;P0jLbh0080jLbh00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00070?oo
o`030000003oool0oooo05H0oooo0P00000H0?ooo`050000000Q?kP08Cnh024o^0000000102[R;00
1@000000jLbh0>W<^03Yc;P0000005X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`010?ooo`00203oool2000005L0oooo00<000000?ooo`3oool05`3oool0100000008Cnh024o^000
00040:^8/0050000003Yc;P0jLbh0>W<^0000000F`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0040oooo000:0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0603o
ool0100000008Cnh024o^00000020:^8/0050000003Yc;P0jLbh0>W<^0000000G@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0040oooo000;0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool06@3oool00`0000008Cnh000000020:^8/0040000003Yc;P0jLbh000005l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`010?ooo`00303oool2000005<0oooo
00<000000?ooo`3oool06P3oool01`0000008Cnh0000002[R;0000000>W<^0000000H03oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0040oooo000>0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool06`3oool2000000030:^8/000000000000680oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`010?ooo`003`3oool200000500oooo00<000000?ooo`3oool0
703oool3000006@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`010?ooo`004@3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000B0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool1
0?ooo`004`3oool2000004`0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0:0?oo
o`4000000@3oool10?ooo`005@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool02@3oool100000040oooo0@3oool001H0oooo0P0000190?ooo`030000
003oool0oooo08L0oooo00<000000?ooo`3oool02@3oool100000040oooo0@3oool001P0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0@00
00010?ooo`40oooo000I0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`070?ooo`4000000@3oool10?ooo`006P3oool2000004D0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00703oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool01@3oool100000040
oooo0@3oool001d0oooo0P0000120?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
1@3oool100000040oooo000O0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`040?ooo`4000000@3oool00200oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`008@3oool20000
03h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`030?ooo`4000000@3oool002<0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080
oooo0@0000010?ooo`00903oool2000003X0oooo00<000000?ooo`3oool0T@3oool01@000000oooo
0?ooo`3oool000000040oooo000V0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
TP3oool010000000oooo0?ooo`0000010?ooo`009`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`0000000@3oool002P0oooo0P00000f0?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool00@00000002X0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`2D0?ooo`4000000@3oool100000000:`3oool2000003<0oooo00<000000?oo
o`3oool0U@3oool200000000;@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo09@0
oooo0`00000002h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2@0?ooo`@00000
0`3oool002l0oooo0P00000_0?ooo`030000003oool0oooo08`0oooo100000070?ooo`00<@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo08P0oooo1000000;0?ooo`00<P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo08<0oooo1@00000?0?ooo`00<`3oool2000002/0
oooo00<000000?ooo`3oool0O`3oool4000001@0oooo000e0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0N`3oool4000001P0oooo000f0?ooo`800000:03oool00`000000oooo0?oo
o`1f0?ooo`D00000703oool003P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1b
0?ooo`@000008@3oool003T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1^0?oo
o`@000009@3oool003X0oooo0P00000T0?ooo`030000003oool0oooo06X0oooo1000000Y0?ooo`00
?03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06D0oooo1@00000]0?ooo`00?@3o
ool200000240oooo00<000000?ooo`3oool0H@3oool400000380oooo000o0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0G@3oool4000003H0oooo00100?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0F03oool5000003X0oooo00110?ooo`8000007@3oool00`000000
oooo0?ooo`1D0?ooo`@00000?`3oool004<0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1@0?ooo`@00000@`3oool004@0oooo0P00000J0?ooo`030000003oool0oooo04`0oooo1000
00170?ooo`00AP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04L0oooo1@00001;
0?ooo`00A`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0oooo1000001@0?oo
o`00B03oool2000001H0oooo00<000000?ooo`3oool0?`3oool4000005@0oooo001:0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool4000005P0oooo001;0?ooo`8000004P3o
ool00`000000oooo0?ooo`0g0?ooo`D00000G03oool004d0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0c0?ooo`@00000H@3oool004h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0_0?ooo`@00000I@3oool004l0oooo0P00000>0?ooo`030000003oool0oooo02X0
oooo1@00001Y0?ooo`00D@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo
1000001^0?ooo`00DP3oool2000000/0oooo00<000000?ooo`3oool08P3oool400000780oooo001D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool4000007H0oooo001E0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool5000007X0oooo001F0?ooo`80
00001`3oool00`000000oooo0?ooo`0E0?ooo`@00000O`3oool005P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0A0?ooo`@00000P`3oool005T0oooo0P0000040?ooo`030000003o
ool0oooo00`0oooo1@0000270?ooo`00F`3oool01@000000oooo0?ooo`3oool0000000X0oooo1000
002<0?ooo`00G03oool010000000oooo0?ooo`0000060?ooo`@00000T03oool005d0oooo0`000002
0?ooo`@00000U03oool005l0oooo0`00002H0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 249.313}, {286.938, 0}} -> {0.0697179, -0.000217411, \
0.00331247, 0.00331247}}]
}, Closed]],

Cell["Give the symbolic expression representation of the graphic.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[dodo]\)], "Input",
  CellLabel->"In[194]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(Graphics3D[
          List[List[
              Polygon[List[
                  List[\(-2.664535259100376`*^-16\), 0.`, 
                    1.7013016167040798`], 
                  List[0.5257311121191336`, 0.3819660112501051`, 
                    0.8506508083520399`], 
                  List[\(-0.20081141588622764`\), 0.6180339887498949`, 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[\(-2.664535259100376`*^-16\), 0.`, 
                    1.7013016167040798`], 
                  List[\(-0.20081141588622764`\), 0.6180339887498949`, 
                    0.8506508083520399`], 
                  List[\(-0.6498393924658126`\), 0.`, 0.8506508083520399`]]], 
              Polygon[List[
                  List[\(-2.664535259100376`*^-16\), 0.`, 
                    1.7013016167040798`], 
                  List[\(-0.6498393924658126`\), 0.`, 0.8506508083520399`], 
                  List[\(-0.20081141588622764`\), \(-0.6180339887498949`\), 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[\(-2.664535259100376`*^-16\), 0.`, 
                    1.7013016167040798`], 
                  List[\(-0.20081141588622764`\), \(-0.6180339887498949`\), 
                    0.8506508083520399`], 
                  List[0.5257311121191336`, \(-0.3819660112501051`\), 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[\(-2.664535259100376`*^-16\), 0.`, 
                    1.7013016167040798`], 
                  List[0.5257311121191336`, \(-0.3819660112501051`\), 
                    0.8506508083520399`], 
                  List[0.5257311121191336`, 0.3819660112501051`, 
                    0.8506508083520399`]]]], 
            List[Polygon[
                List[List[1.5216904260722457`, 0.`, 0.760845213036123`], 
                  List[0.5257311121191336`, 0.3819660112501051`, 
                    0.8506508083520399`], 
                  List[0.5257311121191336`, \(-0.3819660112501051`\), 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[1.5216904260722457`, 0.`, 0.760845213036123`], 
                  List[0.5257311121191336`, \(-0.3819660112501051`\), 
                    0.8506508083520399`], 
                  List[0.8506508083520399`, \(-0.6180339887498949`\), 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[1.5216904260722457`, 0.`, 0.760845213036123`], 
                  List[0.8506508083520399`, \(-0.6180339887498949`\), 
                    0.20081141588622764`], 
                  List[1.0514622242382672`, 
                    0.`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[1.5216904260722457`, 0.`, 0.760845213036123`], 
                  List[1.0514622242382672`, 0.`, \(-0.20081141588622764`\)], 
                  List[0.8506508083520399`, 0.6180339887498949`, 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[1.5216904260722457`, 0.`, 0.760845213036123`], 
                  List[0.8506508083520399`, 0.6180339887498949`, 
                    0.20081141588622764`], 
                  List[0.5257311121191336`, 0.3819660112501051`, 
                    0.8506508083520399`]]]], 
            List[Polygon[
                List[List[0.47022820183397834`, 1.447213595499958`, 
                    0.760845213036123`], 
                  List[0.5257311121191336`, 0.3819660112501051`, 
                    0.8506508083520399`], 
                  List[0.8506508083520399`, 0.6180339887498949`, 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[0.47022820183397834`, 1.447213595499958`, 
                    0.760845213036123`], 
                  List[0.8506508083520399`, 0.6180339887498949`, 
                    0.20081141588622764`], 
                  List[0.3249196962329063`, 
                    1.`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[0.47022820183397834`, 1.447213595499958`, 
                    0.760845213036123`], 
                  List[0.3249196962329063`, 1.`, \(-0.20081141588622764`\)], 
                  List[\(-0.3249196962329063`\), 1.`, 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[0.47022820183397834`, 1.447213595499958`, 
                    0.760845213036123`], 
                  List[\(-0.3249196962329063`\), 1.`, 0.20081141588622764`], 
                  List[\(-0.20081141588622764`\), 0.6180339887498949`, 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[0.47022820183397834`, 1.447213595499958`, 
                    0.760845213036123`], 
                  List[\(-0.20081141588622764`\), 0.6180339887498949`, 
                    0.8506508083520399`], 
                  List[0.5257311121191336`, 0.3819660112501051`, 
                    0.8506508083520399`]]]], 
            List[Polygon[
                List[List[\(-1.2310734148701017`\), 0.894427190999916`, 
                    0.760845213036123`], 
                  List[\(-0.20081141588622764`\), 0.6180339887498949`, 
                    0.8506508083520399`], 
                  List[\(-0.3249196962329063`\), 1.`, 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[\(-1.2310734148701017`\), 0.894427190999916`, 
                    0.760845213036123`], 
                  List[\(-0.3249196962329063`\), 1.`, 0.20081141588622764`], 
                  List[\(-0.8506508083520399`\), 
                    0.6180339887498949`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[\(-1.2310734148701017`\), 0.894427190999916`, 
                    0.760845213036123`], 
                  List[\(-0.8506508083520399`\), 
                    0.6180339887498949`, \(-0.20081141588622764`\)], 
                  List[\(-1.0514622242382672`\), 0.`, 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[\(-1.2310734148701017`\), 0.894427190999916`, 
                    0.760845213036123`], 
                  List[\(-1.0514622242382672`\), 0.`, 0.20081141588622764`], 
                  List[\(-0.6498393924658126`\), 0.`, 0.8506508083520399`]]], 
              Polygon[List[
                  List[\(-1.2310734148701017`\), 0.894427190999916`, 
                    0.760845213036123`], 
                  List[\(-0.6498393924658126`\), 0.`, 0.8506508083520399`], 
                  List[\(-0.20081141588622764`\), 0.6180339887498949`, 
                    0.8506508083520399`]]]], 
            List[Polygon[
                List[List[\(-1.2310734148701015`\), \(-0.894427190999916`\), 
                    0.760845213036123`], 
                  List[\(-0.6498393924658126`\), 0.`, 0.8506508083520399`], 
                  List[\(-1.0514622242382672`\), 0.`, 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[\(-1.2310734148701015`\), \(-0.894427190999916`\), 
                    0.760845213036123`], 
                  List[\(-1.0514622242382672`\), 0.`, 0.20081141588622764`], 
                  List[\(-0.8506508083520399`\), \(-0.6180339887498949`\), \
\(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[\(-1.2310734148701015`\), \(-0.894427190999916`\), 
                    0.760845213036123`], 
                  List[\(-0.8506508083520399`\), \(-0.6180339887498949`\), \
\(-0.20081141588622764`\)], 
                  List[\(-0.3249196962329063`\), \(-1.`\), 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[\(-1.2310734148701015`\), \(-0.894427190999916`\), 
                    0.760845213036123`], 
                  List[\(-0.3249196962329063`\), \(-1.`\), 
                    0.20081141588622764`], 
                  List[\(-0.20081141588622764`\), \(-0.6180339887498949`\), 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[\(-1.2310734148701015`\), \(-0.894427190999916`\), 
                    0.760845213036123`], 
                  List[\(-0.20081141588622764`\), \(-0.6180339887498949`\), 
                    0.8506508083520399`], 
                  List[\(-0.6498393924658126`\), 0.`, 
                    0.8506508083520399`]]]], 
            List[Polygon[
                List[List[0.47022820183397834`, \(-1.447213595499958`\), 
                    0.760845213036123`], 
                  List[\(-0.3249196962329063`\), \(-1.`\), 
                    0.20081141588622764`], 
                  List[0.3249196962329063`, \(-1.`\), \(-0.20081141588622764`\
\)]]], Polygon[List[
                  List[0.47022820183397834`, \(-1.447213595499958`\), 
                    0.760845213036123`], 
                  List[0.3249196962329063`, \(-1.`\), \(-0.20081141588622764`\
\)], List[0.8506508083520399`, \(-0.6180339887498949`\), 
                    0.20081141588622764`]]], 
              Polygon[List[
                  List[0.47022820183397834`, \(-1.447213595499958`\), 
                    0.760845213036123`], 
                  List[0.8506508083520399`, \(-0.6180339887498949`\), 
                    0.20081141588622764`], 
                  List[0.5257311121191336`, \(-0.3819660112501051`\), 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[0.47022820183397834`, \(-1.447213595499958`\), 
                    0.760845213036123`], 
                  List[0.5257311121191336`, \(-0.3819660112501051`\), 
                    0.8506508083520399`], 
                  List[\(-0.20081141588622764`\), \(-0.6180339887498949`\), 
                    0.8506508083520399`]]], 
              Polygon[List[
                  List[0.47022820183397834`, \(-1.447213595499958`\), 
                    0.760845213036123`], 
                  List[\(-0.20081141588622764`\), \(-0.6180339887498949`\), 
                    0.8506508083520399`], 
                  List[\(-0.3249196962329063`\), \(-1.`\), 
                    0.20081141588622764`]]]], 
            List[Polygon[
                List[List[1.2310734148701015`, 
                    0.894427190999916`, \(-0.760845213036123`\)], 
                  List[0.8506508083520399`, 0.6180339887498949`, 
                    0.20081141588622764`], 
                  List[1.0514622242382672`, 
                    0.`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[1.2310734148701015`, 
                    0.894427190999916`, \(-0.760845213036123`\)], 
                  List[1.0514622242382672`, 0.`, \(-0.20081141588622764`\)], 
                  List[0.6498393924658126`, 0.`, \(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[1.2310734148701015`, 
                    0.894427190999916`, \(-0.760845213036123`\)], 
                  List[0.6498393924658126`, 0.`, \(-0.8506508083520399`\)], 
                  List[0.20081141588622764`, 
                    0.6180339887498949`, \(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[1.2310734148701015`, 
                    0.894427190999916`, \(-0.760845213036123`\)], 
                  List[0.20081141588622764`, 
                    0.6180339887498949`, \(-0.8506508083520399`\)], 
                  List[0.3249196962329063`, 
                    1.`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[1.2310734148701015`, 
                    0.894427190999916`, \(-0.760845213036123`\)], 
                  List[0.3249196962329063`, 1.`, \(-0.20081141588622764`\)], 
                  List[0.8506508083520399`, 0.6180339887498949`, 
                    0.20081141588622764`]]]], 
            List[Polygon[
                List[List[\(-0.47022820183397834`\), 
                    1.447213595499958`, \(-0.760845213036123`\)], 
                  List[\(-0.3249196962329063`\), 1.`, 0.20081141588622764`], 
                  List[0.3249196962329063`, 
                    1.`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[\(-0.47022820183397834`\), 
                    1.447213595499958`, \(-0.760845213036123`\)], 
                  List[0.3249196962329063`, 1.`, \(-0.20081141588622764`\)], 
                  List[0.20081141588622764`, 
                    0.6180339887498949`, \(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[\(-0.47022820183397834`\), 
                    1.447213595499958`, \(-0.760845213036123`\)], 
                  List[0.20081141588622764`, 
                    0.6180339887498949`, \(-0.8506508083520399`\)], 
                  List[\(-0.5257311121191336`\), 
                    0.3819660112501051`, \(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[\(-0.47022820183397834`\), 
                    1.447213595499958`, \(-0.760845213036123`\)], 
                  List[\(-0.5257311121191336`\), 
                    0.3819660112501051`, \(-0.8506508083520399`\)], 
                  List[\(-0.8506508083520399`\), 
                    0.6180339887498949`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[\(-0.47022820183397834`\), 
                    1.447213595499958`, \(-0.760845213036123`\)], 
                  List[\(-0.8506508083520399`\), 
                    0.6180339887498949`, \(-0.20081141588622764`\)], 
                  List[\(-0.3249196962329063`\), 1.`, 
                    0.20081141588622764`]]]], 
            List[Polygon[
                List[List[\(-1.5216904260722457`\), 
                    0.`, \(-0.760845213036123`\)], 
                  List[\(-1.0514622242382672`\), 0.`, 0.20081141588622764`], 
                  List[\(-0.8506508083520399`\), 
                    0.6180339887498949`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[\(-1.5216904260722457`\), 
                    0.`, \(-0.760845213036123`\)], 
                  List[\(-0.8506508083520399`\), 
                    0.6180339887498949`, \(-0.20081141588622764`\)], 
                  List[\(-0.5257311121191336`\), 
                    0.3819660112501051`, \(-0.8506508083520399`\)]]], 
              Polygon[
                List[List[\(-1.5216904260722457`\), 
                    0.`, \(-0.760845213036123`\)], 
                  List[\(-0.5257311121191336`\), 
                    0.3819660112501051`, \(-0.8506508083520399`\)], 
                  List[\(-0.5257311121191336`\), \(-0.3819660112501051`\), \
\(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[\(-1.5216904260722457`\), 
                    0.`, \(-0.760845213036123`\)], 
                  List[\(-0.5257311121191336`\), \(-0.3819660112501051`\), \
\(-0.8506508083520399`\)], 
                  List[\(-0.8506508083520399`\), \(-0.6180339887498949`\), \
\(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[\(-1.5216904260722457`\), 
                    0.`, \(-0.760845213036123`\)], 
                  List[\(-0.8506508083520399`\), \(-0.6180339887498949`\), \
\(-0.20081141588622764`\)], 
                  List[\(-1.0514622242382672`\), 0.`, 
                    0.20081141588622764`]]]], 
            List[Polygon[
                List[List[\(-0.47022820183397834`\), \(-1.447213595499958`\), \
\(-0.760845213036123`\)], 
                  List[\(-0.3249196962329063`\), \(-1.`\), 
                    0.20081141588622764`], 
                  List[\(-0.8506508083520399`\), \(-0.6180339887498949`\), \
\(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[\(-0.47022820183397834`\), \(-1.447213595499958`\), \
\(-0.760845213036123`\)], 
                  List[\(-0.8506508083520399`\), \(-0.6180339887498949`\), \
\(-0.20081141588622764`\)], 
                  List[\(-0.5257311121191336`\), \(-0.3819660112501051`\), \
\(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[\(-0.47022820183397834`\), \(-1.447213595499958`\), \
\(-0.760845213036123`\)], 
                  List[\(-0.5257311121191336`\), \(-0.3819660112501051`\), \
\(-0.8506508083520399`\)], 
                  List[0.20081141588622764`, \(-0.6180339887498949`\), \
\(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[\(-0.47022820183397834`\), \(-1.447213595499958`\), \
\(-0.760845213036123`\)], 
                  List[0.20081141588622764`, \(-0.6180339887498949`\), \
\(-0.8506508083520399`\)], 
                  List[0.3249196962329063`, \(-1.`\), \(-0.20081141588622764`\
\)]]], Polygon[List[
                  List[\(-0.47022820183397834`\), \(-1.447213595499958`\), \
\(-0.760845213036123`\)], 
                  List[0.3249196962329063`, \(-1.`\), \(-0.20081141588622764`\
\)], List[\(-0.3249196962329063`\), \(-1.`\), 0.20081141588622764`]]]], 
            List[Polygon[
                List[List[
                    1.2310734148701012`, \(-0.894427190999916`\), \
\(-0.760845213036123`\)], 
                  List[0.8506508083520399`, \(-0.6180339887498949`\), 
                    0.20081141588622764`], 
                  List[0.3249196962329063`, \(-1.`\), \(-0.20081141588622764`\
\)]]], Polygon[List[
                  List[1.2310734148701012`, \(-0.894427190999916`\), \
\(-0.760845213036123`\)], 
                  List[0.3249196962329063`, \(-1.`\), \(-0.20081141588622764`\
\)], List[
                    0.20081141588622764`, \(-0.6180339887498949`\), \
\(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[1.2310734148701012`, \(-0.894427190999916`\), \
\(-0.760845213036123`\)], 
                  List[0.20081141588622764`, \(-0.6180339887498949`\), \
\(-0.8506508083520399`\)], 
                  List[0.6498393924658126`, 0.`, \(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[1.2310734148701012`, \(-0.894427190999916`\), \
\(-0.760845213036123`\)], 
                  List[0.6498393924658126`, 0.`, \(-0.8506508083520399`\)], 
                  List[1.0514622242382672`, 
                    0.`, \(-0.20081141588622764`\)]]], 
              Polygon[List[
                  List[1.2310734148701012`, \(-0.894427190999916`\), \
\(-0.760845213036123`\)], 
                  List[1.0514622242382672`, 0.`, \(-0.20081141588622764`\)], 
                  List[0.8506508083520399`, \(-0.6180339887498949`\), 
                    0.20081141588622764`]]]], 
            List[Polygon[
                List[List[2.664535259100376`*^-16, 
                    0.`, \(-1.7013016167040798`\)], 
                  List[0.20081141588622764`, 
                    0.6180339887498949`, \(-0.8506508083520399`\)], 
                  List[0.6498393924658126`, 0.`, \(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[2.664535259100376`*^-16, 
                    0.`, \(-1.7013016167040798`\)], 
                  List[0.6498393924658126`, 0.`, \(-0.8506508083520399`\)], 
                  List[0.20081141588622764`, \(-0.6180339887498949`\), \
\(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[2.664535259100376`*^-16, 
                    0.`, \(-1.7013016167040798`\)], 
                  List[0.20081141588622764`, \(-0.6180339887498949`\), \
\(-0.8506508083520399`\)], 
                  List[\(-0.5257311121191336`\), \(-0.3819660112501051`\), \
\(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[2.664535259100376`*^-16, 
                    0.`, \(-1.7013016167040798`\)], 
                  List[\(-0.5257311121191336`\), \(-0.3819660112501051`\), \
\(-0.8506508083520399`\)], 
                  List[\(-0.5257311121191336`\), 
                    0.3819660112501051`, \(-0.8506508083520399`\)]]], 
              Polygon[List[
                  List[2.664535259100376`*^-16, 
                    0.`, \(-1.7013016167040798`\)], 
                  List[\(-0.5257311121191336`\), 
                    0.3819660112501051`, \(-0.8506508083520399`\)], 
                  List[0.20081141588622764`, 
                    0.6180339887498949`, \(-0.8506508083520399`\)]]]]], 
          List[Rule[AmbientLight, GrayLevel[0]], 
            Rule[AspectRatio, Automatic], Rule[Axes, False], 
            Rule[AxesEdge, Automatic], Rule[AxesLabel, None], 
            Rule[AxesStyle, Automatic], Rule[Background, Automatic], 
            Rule[Boxed, True], Rule[BoxRatios, Automatic], 
            Rule[BoxStyle, Automatic], Rule[ColorOutput, Automatic], 
            Rule[DefaultColor, Automatic], 
            RuleDelayed[DefaultFont, $DefaultFont], 
            RuleDelayed[DisplayFunction, $DisplayFunction], 
            Rule[Epilog, List[]], Rule[FaceGrids, None], 
            RuleDelayed[FormatType, $FormatType], Rule[ImageSize, Automatic], 
            Rule[Lighting, True], 
            Rule[LightSources, 
              List[List[List[1.`, 0.`, 1.`], RGBColor[1, 0, 0]], 
                List[List[1.`, 1.`, 1.`], RGBColor[0, 1, 0]], 
                List[List[0.`, 1.`, 1.`], RGBColor[0, 0, 1]]]], 
            Rule[Plot3Matrix, Automatic], Rule[PlotLabel, None], 
            Rule[PlotRange, All], Rule[PlotRegion, Automatic], 
            Rule[PolygonIntersections, True], Rule[Prolog, List[]], 
            Rule[RenderAll, True], Rule[Shading, True], 
            Rule[SphericalRegion, False], RuleDelayed[TextStyle, $TextStyle], 
            Rule[Ticks, Automatic], Rule[ViewCenter, Automatic], 
            Rule[ViewPoint, List[1.3`, \(-2.4`\), 2.`]], 
            Rule[ViewVertical, List[0.`, 0.`, 1.`]]]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[194]//FullForm="]
}, Closed]],

Cell["\<\
You can see that the image surface consists of polygons, which are \
specified by list of vertices.  A rule to transform polygons in a certain way \
can be applied to the whole image.\
\>", "Text"],

Cell["\<\
This defines a function which simply shrinks a polygon down by a \
given factor.\
\>", "MathCaption"],

Cell[BoxData[
    \(Shrink[Polygon[v_], \ f_]\  := \ 
      Module[{m\  = \ Mean[v] \((1\  - \ f)\)}, \ 
        Polygon[Map[\((m\  + \ f\ #)\) &, \ v]]]\)], "Input",
  CellLabel->"In[195]:="],

Cell["\<\
Note that this is a simple program which is itself a symbolic \
expression.  \
\>", "Text"],

Cell["\<\
This substitutes every polygon in the dodecahedron with its \
shrunken version.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[dodo\  /. \ p_Polygon \[RuleDelayed] Shrink[p,  .8]]\)], "Input",
  CellLabel->"In[202]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.13935 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0796788 1.20308 1.66967e-017 1.20308 [
[ 0 0 0 0 ]
[ 1 1.13935 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08703 .24255 m
0 .86264 L
s
0 .86264 m
.38562 1.13935 L
s
.38562 1.13935 m
.40496 .57228 L
s
.40496 .57228 m
.08703 .24255 L
s
.67424 0 m
.92591 .39938 L
s
.92591 .39938 m
1 .99628 L
s
1 .99628 m
.70884 .64834 L
s
.70884 .64834 m
.67424 0 L
s
.08703 .24255 m
0 .86264 L
s
0 .86264 m
.70884 .64834 L
s
.70884 .64834 m
.67424 0 L
s
.67424 0 m
.08703 .24255 L
s
.40496 .57228 m
.92591 .39938 L
s
.92591 .39938 m
1 .99628 L
s
1 .99628 m
.38562 1.13935 L
s
.38562 1.13935 m
.40496 .57228 L
s
0 0 m
1 0 L
1 1.13935 L
0 1.13935 L
closepath
clip
newpath
.5 Mabswid
.874 .733 .703 r
.55936 .64861 m .46937 .5501 L .44033 .67219 L closepath p F P
0 g
s
.673 .715 .881 r
.57152 .63782 m .60649 .52478 L .48206 .53883 L closepath p F P
0 g
s
.759 .39 .356 r
.56561 .66332 m .44673 .68769 L .55403 .75151 L closepath p F P
0 g
s
.321 .339 .723 r
.58532 .64586 m .67103 .6479 L .62106 .53306 L closepath p F P
0 g
s
.307 .004 .276 r
.58167 .66164 m .57109 .74981 L .66722 .66468 L closepath p F P
0 g
s
.692 .542 .679 r
.27302 .56927 m .41768 .66611 L .44695 .54364 L closepath p F P
0 g
s
.676 .541 .693 r
.52448 .34566 m .47812 .51596 L .60297 .50169 L closepath p F P
0 g
s
.694 .746 .892 r
.26979 .55357 m .44414 .52781 L .37875 .45687 L closepath p F P
0 g
s
.788 .41 .34 r
.26321 .58014 m .32179 .69088 L .40832 .67745 L closepath p F P
0 g
s
.882 .762 .725 r
.50911 .34071 m .3979 .43985 L .46261 .5114 L closepath p F P
0 g
s
.296 .353 .752 r
.53625 .33734 m .61516 .49392 L .6366 .41137 L closepath p F P
0 g
s
0 0 0 r
.25792 .55465 m .36699 .45746 L .29149 .54087 L closepath p F P
0 g
s
0 .012 .569 r
.25382 .57115 m .28713 .55856 L .31221 .68197 L closepath p F P
0 g
s
0 0 0 r
.5113 .32926 m .48954 .36474 L .39954 .42851 L closepath p F P
0 g
s
.658 .124 0 r
.52815 .32716 m .62858 .40104 L .50759 .36252 L closepath p F P
0 g
s
.682 .519 .658 r
.39763 .87971 m .5411 .76858 L .43335 .70422 L closepath p F P
0 g
s
.656 .516 .681 r
.81724 .50806 m .63881 .52199 L .68926 .63738 L closepath p F P
0 g
s
.895 .735 .676 r
.38155 .87591 m .41759 .70006 L .33126 .71445 L closepath p F P
0 g
s
.642 .713 .899 r
.81528 .4917 m .65882 .42371 L .63644 .50593 L closepath p F P
0 g
s
.66 .502 .659 r
.74215 .84756 m .67991 .67871 L .58309 .76442 L closepath p F P
0 g
s
.269 0 .177 r
.40513 .8905 m .53766 .8393 L .54927 .7788 L closepath p F P
0 g
s
.205 0 .227 r
.82682 .51708 m .69816 .64697 L .75697 .64522 L closepath p F P
0 g
s
.728 .322 .278 r
.7337 .86007 m .57421 .77634 L .56382 .83682 L closepath p F P
0 g
s
.238 .261 .683 r
.75538 .84092 m .75123 .671 L .69262 .67152 L closepath p F P
0 g
s
0 .112 .649 r
.37897 .88437 m .32828 .72206 L .38511 .80161 L closepath p F P
0 g
s
.599 .774 .964 r
.39363 .89345 m .40074 .81115 L .52639 .84208 L closepath p F P
0 g
s
.728 .22 .015 r
.82367 .49046 m .7365 .49013 L .66637 .42199 L closepath p F P
0 g
s
.956 .805 .653 r
.83085 .50624 m .76077 .63465 L .74402 .50692 L closepath p F P
0 g
s
.909 .787 .713 r
.27518 .33956 m .29307 .52469 L .36914 .44106 L closepath p F P
0 g
s
.676 .767 .919 r
.28938 .3269 m .38255 .42914 L .47276 .36486 L closepath p F P
0 g
s
.648 .803 .958 r
.7417 .86125 m .57089 .83787 L .67006 .78494 L closepath p F P
0 g
s
.945 .828 .697 r
.75519 .84934 m .68436 .77229 L .75101 .67851 L closepath p F P
0 g
s
.918 .768 .68 r
.1836 .70587 m .30771 .69275 L .28229 .56834 L closepath p F P
0 g
s
.777 .351 .237 r
.19045 .72351 m .37103 .78893 L .31431 .70927 L closepath p F P
0 g
s
.64 .745 .925 r
.66333 .27949 m .5173 .35937 L .63929 .39832 L closepath p F P
0 g
s
.181 .277 .728 r
.68001 .2885 m .65486 .40694 L .72508 .47501 L closepath p F P
0 g
s
.031 .113 .617 r
.27163 .34503 m .33072 .52321 L .28975 .53125 L closepath p F P
0 g
s
.733 .285 .189 r
.51449 .92277 m .53632 .84367 L .4096 .81245 L closepath p F P
0 g
s
0 0 0 r
.18408 .69509 m .28333 .55723 L .32402 .55056 L closepath p F P
0 g
s
.111 0 .025 r
.53425 .92099 m .65416 .78868 L .55467 .84193 L closepath p F P
0 g
s
.685 .201 .094 r
.29478 .3244 m .47926 .36269 L .46314 .40546 L closepath p F P
0 g
s
.135 .209 .677 r
.83726 .6373 m .74361 .51646 L .76054 .64525 L closepath p F P
0 g
s
.021 0 0 r
.65212 .27906 m .49102 .40209 L .50577 .35942 L closepath p F P
0 g
s
.064 0 .061 r
.83299 .65682 m .75651 .66333 L .68945 .75746 L closepath p F P
0 g
s
.611 .737 .935 r
.19525 .72381 m .38964 .71186 L .37697 .78967 L closepath p F P
0 g
s
.122 .245 .719 r
.50483 .91409 m .39991 .80366 L .41369 .72631 L closepath p F P
0 g
s
.93 .765 .656 r
.67927 .29374 m .72467 .4814 L .64266 .48739 L closepath p F P
0 g
s
.774 .327 .188 r
.8294 .62698 m .65399 .51319 L .73569 .50606 L closepath p F P
0 g
s
.651 .488 .65 r
.28379 .33565 m .45261 .41733 L .34342 .51442 L closepath p F P
0 g
s
.914 .799 .719 r
.53699 .91118 m .5919 .70809 L .65751 .77848 L closepath p F P
0 g
s
.679 .779 .926 r
.82244 .65874 m .67851 .7599 L .61377 .68872 L closepath p F P
0 g
s
.647 .505 .675 r
.1913 .70615 m .33206 .5609 L .38618 .69383 L closepath p F P
0 g
s
.677 .508 .649 r
.66194 .28789 m .62493 .48197 L .49999 .41163 L closepath p F P
0 g
s
.102 0 .06 r
.44327 .52258 m .35528 .52918 L .46535 .43133 L closepath p F P
0 g
s
.168 .236 .691 r
.43833 .54321 m .40533 .68198 L .35061 .54832 L closepath p F P
0 g
s
.743 .309 .221 r
.46425 .52019 m .48485 .429 L .6104 .50002 L closepath p F P
0 g
s
.671 .534 .69 r
.51873 .90686 m .42702 .71829 L .57383 .70322 L closepath p F P
0 g
s
.689 .536 .674 r
.82018 .64022 m .61091 .67038 L .6441 .52578 L closepath p F P
0 g
s
.655 .741 .913 r
.45628 .55362 m .56951 .67663 L .42212 .692 L closepath p F P
0 g
s
.905 .762 .693 r
.47233 .53937 m .61823 .51802 L .58473 .66315 L closepath p F P
0 g
s
.25 Mabswid
.67424 0 m
.92591 .39938 L
s
.92591 .39938 m
1 .99628 L
s
1 .99628 m
.70884 .64834 L
s
.70884 .64834 m
.67424 0 L
s
.08703 .24255 m
0 .86264 L
s
0 .86264 m
.70884 .64834 L
s
.70884 .64834 m
.67424 0 L
s
.67424 0 m
.08703 .24255 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[202]:=",
  ImageSize->{252.75, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003l00017b000`400?l00000o`00003oZ03oool2
00000580oooo002V0?ooo`80000000<0oooo000000000000D@3oool00:<0oooo0`0000030?ooo`80
0000D@3oool00:40oooo0P0000060?ooo`030000003oool000000500oooo002O0?ooo`800000203o
ool010000000oooo0?ooo`00001?0?ooo`00W03oool3000000X0oooo00@000000?ooo`3oool00000
C`3oool009X0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000CP3oool009L0oooo0`00
000?0?ooo`050000003oool0oooo0?ooo`000000CP3oool009D0oooo0P00000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0B`3oool00980oooo0`00000D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0BP3oool00900oooo0P00000H0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0BP3oool008h0oooo0P00000J0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0B@3oool008/0oooo0`00000L0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0B03oool008T0oooo0P00000O0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0B03oool008H0oooo0`00000Q0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0A`3oool008@0oooo0P00000T0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0AP3oool00840oooo0`00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0AP3oool007l0oooo0P00000Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
A@3oool007d0oooo0P00000[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A03o
ool007X0oooo0`00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A03oool0
07P0oooo0P00000`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@`3oool007D0
oooo0`00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@`3oool007<0oooo
0P00000e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@P3oool00700oooo0`00
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@@3oool006h0oooo0P00000j
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@@3oool006`0oooo0P00000l0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0@03oool006T0oooo0`00000n0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0?`3oool006L0oooo0P0000110?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0?`3oool006@0oooo0`0000140?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0?P3oool00680oooo0P0000170?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0?@3oool00600oooo0P0000190?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0?@3oool005d0oooo0`00001;0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0?03oool005/0oooo0P00001>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0?03oool005P0oooo0`00001@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0>`3oool005H0oooo0P00001C0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0>P3oool005<0oooo0`00001E0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0>P3oool00540oooo0P00001H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0>@3oool004l0oooo0P00001J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>03oool004`0oooo0`00001L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>03o
ool004X0oooo0P00001O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0=`3oool0
04L0oooo0`00001Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=P3oool004D0
oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=P3oool00480oooo
0`00001V0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=@3oool00400oooo0P00
001Y0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0=03oool003h0oooo0P00001[
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0=03oool003/0oooo0`00001]0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<`3oool003T0oooo0P00001a0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0<`3oool003H0oooo0`00001c0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0<P3oool003@0oooo0P00001f0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0<@3oool00340oooo0`00001h0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0<@3oool002l0oooo0P00001k0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0<03oool002d0oooo0P00001m0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0;`3oool002X0oooo0`00001o0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0;`3oool002P0oooo0P0000220?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0;P3oool002D0oooo0`0000240?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0;@3oool002<0oooo0P0000270?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0;@3oool00200oooo0`0000290?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0;03oool001h0oooo0P00002<0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
;03oool001`0oooo0P00002>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:`3o
ool001T0oooo0`00002@0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:P3oool0
01L0oooo0P00002C0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:P3oool001D0
oooo0P00002E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:@3oool001D0oooo
0P00002E0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0:03oool001D0oooo00<0
00000?ooo`000000U03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02P0oooo000E
0?ooo`040000003oool0oooo000009@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0W0?ooo`00503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`00503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0V0?oo
o`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0U0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`00503o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08<0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P03oool50000
00H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`00503oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo07d0oooo100000020:>nk0030000003oool0oooo0080
oooo00<000000?ooo`000000:@3oool00`000000oooo0?ooo`0R0?ooo`004`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo07X0oooo100000030:>nk0800000103oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo0240oooo000C0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0M`3oool20000000300D000000000Xkk/0080Xkk/0P0000000`2]PZH000000?oo
o`030?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool08@3oool001<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1e0?ooo`80000000<01@000000000000000`2S_^`0
10000000[H:V0:f2YP0000040?ooo`@00000:`3oool00`000000oooo0?ooo`0P0?ooo`004`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0780oooo0P00000200D000030000002S_^`0
Xkk/0080Xkk/00D000000:f2YP2]PZH0[H:V000000040?ooo`@00000;03oool00`000000oooo0?oo
o`0O0?ooo`004`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0700oooo00D00000
00D0000500001@00000000030:>nk0800000102]PZH00`000000oooo0?ooo`020?ooo`040000003^
`jL00000000002`0oooo00<000000?ooo`3oool07`3oool001<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1]0?ooo`8000000P050002000000<0Xkk/00<000000:f2YP2]PZH0102]
PZH00`000000oooo0?ooo`020?ooo`040000003^`jL00000000002d0oooo00<000000?ooo`3oool0
7P3oool001<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1Z0?ooo`8000000`05
00000`000000Xkk/0:>nk0020:>nk0030000002]PZH0[H:V00D0[H:V00@000000?ooo`3oool0oooo
0P0000000`3^`jL000000000000^0?ooo`030000003oool0oooo01d0oooo000B0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0I`3oool2000000@01@0000@000000:>nk02S_^`0Xkk/
0P0000080:f2YP040000003oool0oooo0?ooo`80000000<0k/>W000000000000;P3oool00`000000
oooo0?ooo`0M0?ooo`004P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo
0`0000120?ooo`80000010050002000000<0Xkk/00<000000:f2YP2]PZH01`2]PZH00`000000oooo
0?ooo`020?ooo`8000000P3^`jL00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01`0oooo
000B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool9000003<0oooo00<0
00000?ooo`3oool01P3oool2000000D01@0000<000000:>nk02S_^`00P2S_^`00`000000[H:V0:f2
YP080:f2YP030000003oool0oooo0080oooo00@000000>k3Y`3^`jL0k/>W0P00000^0?ooo`030000
003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0703o
ool00`000000[LC[0000000300000080[c<H1@00000Z0?ooo`050000003oool0oooo0000002X7`00
0P0000050?ooo`030000000500001@0000@01@0000@000000:>nk02S_^`0Xkk/0P00000;0:f2YP04
0000003oool0oooo0?ooo`8000000`3^`jL2000002l0oooo00<000000?ooo`3oool06`3oool00180
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0000
00@0[LC[0P0000050:lc60D00000903oool01@000000oooo0?ooo`3oool0000000<0Z1l000<00000
0?ooo`3oool00P00000500D0008000000`2S_^`00`000000[H:V0:f2YP0;0:f2YP040000003oool0
oooo0?ooo`8000000`3^`jL200000300oooo00<000000?ooo`3oool06P3oool00180oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool000000080000000<0oooo
0000002]a>/0102]a>/2000000P0[c<H1000000O0?ooo`<0000000<0oooo0000002X7`00102X7`02
000000H01@0000<000000:>nk02S_^`00P2S_^`00`000000[H:V0:f2YP0<0:f2YP040000003oool0
oooo0?ooo`800000103^`jL00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01X0oooo000B
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0503oool3000000030?ooo`000000
YWbV00<000001P2]a>/2000000X0[c<H1@00000H0?ooo`D0000000<0oooo0000002X7`000P2X7`02
000000L01@0000@000000:>nk02S_^`0Xkk/0P00000>0:f2YP030000003oool0oooo0080oooo00<0
00000>k3Y`3^`jL00`3^`jL00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01T0oooo000A
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool2000000030>S9]P000000
000000<0YWbV0P0000070:g4j`8000003@2_<aP4000001<0oooo1@000000103oool000000:PO002X
7`02000000L01@000P0000030:>nk0030000002]PZH0[H:V00h0[H:V00@000000?ooo`3oool0oooo
0P0000050>k3Y`800000<@3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0180oooo0P0000020>S9]P030000002VO:H0YWbV00<0YWbV0P00
00070:g4j`8000003`2_<aP5000000d0oooo100000000`3Q`kT000000?ooo`03000000P01@0000<0
00000:>nk02S_^`00P2S_^`00`000000[H:V0:f2YP0?0:f2YP040000003oool0oooo0?ooo`800000
1@3^`jL200000340oooo00<000000?ooo`3oool0603oool00140oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0A0?ooo`8000000`3XbKH00`000000YWbV0:IlYP040:IlYP8000001`2]
a>/200000180[c<H1@0000070?ooo`@000000P3Q`kT3000000T01@0000@000000:>nk02S_^`0Xkk/
0P00000B0:f2YP040000003oool0oooo0?ooo`8000001@3^`jL200000380oooo00<000000?ooo`3o
ool05`3oool00140oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`800000
0`3XbKH00`000000YWbV0:IlYP060:IlYP8000001`2]a>/2000001D0[c<H100000020?ooo`D00000
0P3Q`kT00`0000001@0000D0000700D0008000000`2S_^`00`000000[H:V0:f2YP0B0:f2YP040000
003oool0oooo0?ooo`8000001@3^`jL2000003<0oooo00<000000?ooo`3oool05P3oool00140oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000000779d000000080j<Vf
00<000000:IlYP2VO:H0202VO:H2000000L0[LC[0P00000G0:lc60H000000P3Q`kT2000000P01@00
00<000000:>nk02S_^`00P2S_^`00`000000[H:V0:f2YP0C0:f2YP050000003oool0oooo0?ooo`00
00001P3^`jL2000003<0oooo00<000000?ooo`3oool05P3oool00140oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0?0?ooo`8000000`3XbKH00`000000YWbV0:IlYP090:IlYP800000
1`2]a>/2000001L0[c<H0`0000030>73^@030000000500001@0000H01@000`0000000`2S_^`00000
0000000E0:f2YP040000003oool0oooo0?ooo`8000001P3^`jL3000003<0oooo00<000000?ooo`3o
ool05@3oool00140oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`800000
0`3XbKH00`000000YWbV0:IlYP0;0:IlYP8000001`2]a>/2000001@0[c<H0P0000050>73^@030000
000500001@0000@01@000P0000030:PO00030000002]PZH0[H:V01D0[H:V00@000000?ooo`3oool0
oooo0P0000060>k3Y`<00000=03oool00`000000oooo0?ooo`0D0?ooo`004@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo00<0000000LLW@0000000P3XbKH00`000000YWbV
0:IlYP0=0:IlYP8000001`2]a>/200000180[c<H00<000000>73^@3Q`kT00`3Q`kT2000000D01@00
00<000000:f:/@2]R[400`00000H0:f2YP040000003oool0oooo0?ooo`8000001P3^`jL00`000000
k/>W0000000d0?ooo`030000003oool0oooo01@0oooo000@0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0303oool00`0000001abM000000030>S9]P030000002VO:H0YWbV00h0YWbV
0P0000070:g4j`800000402_<aP00`000000hL>i0>73^@030>73^@030000000500001@0000<01@00
00@000000:f:/@2]R[40[HZa0P00000I0:f2YP040000003oool0oooo0?ooo`8000001P3^`jL00`00
0000k/>W0000000e0?ooo`030000003oool0oooo01<0oooo000@0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool02`3oool00`0000001abM000000030>S9]P030000002VO:H0YWbV0100
YWbV0P0000070:g4j`8000003@2_<aP00`000000hL>i0>73^@040>73^@040000000500001@0000D0
008000000`2]R[400`000000[H:V0:f2YP0I0:f2YP030000003oool0oooo008000001`3^`jL01000
0000k/>W00000000000d0?ooo`030000003oool0oooo01<0oooo000@0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool02P3oool0100000001abM00LLW@0000020>S9]P030000002VO:H0
YWbV0180YWbV0P0000070:g4j`8000002`2_<aP00`000000hL>i0>73^@030>73^@04000000050000
1@0000D0008000000`2]R[400`000000[H:V0:f2YP0I0:f2YP040000003oool0oooo0?ooo`800000
1`3^`jL010000000k/>W00000000000e0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool0100000001abM00LLW@0000030>S9]P03
0000002VO:H0YWbV01<0YWbV0P0000070:g4j`800000202_<aP00`000000hL>i0>73^@040>73^@07
0000000500001@000000003oool000000:f:/@02000001`0[H:V00@000000?ooo`3oool0oooo0P00
00070>k3Y`040000003^`jL0k/>W000003H0oooo00<000000?ooo`3oool04@3oool00100oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`040000000779d01abM000000<0j<Vf
00<000000:IlYP2VO:H05@2VO:H2000000H0[LC[0`0000060:lc60030000003Q`kT0hL>i00@0hL>i
0`0000020?ooo`8000007P2]PZH010000000oooo0?ooo`3oool2000000L0k/>W00@000000>k3Y`3^
`jL00000=P3oool00`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00L0oooo00D0000000LLW@0779d01abM000000020>S9]P030000002VO:H0YWbV
01L0YWbV0P0000030:g4j`H00000102_<aP00`000000hL>i0>73^@030>73^@8000000`3oool20000
01l0[H:V00H000000?ooo`3oool0000002i6^P0000080>k3Y`040000003^`jL00000000003D0oooo
0P00000B0?ooo`00403oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo00D0
000000LLW@0779d01abM000000030>S9]P030000002VO:H0YWbV01P0YWbV1`0000020>73^@800000
00<0[c<H0000003Q`kT01@3Q`kT200000080oooo0P00000P0:f2YP030000003oool0oooo00800000
2@3^`jL010000000k/>W00000000000b0?ooo`<0000000<0oooo0000003oool04@3oool000l0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`050000000779d01abM00LLW@00
00000`3XbKH00`000000YWbV0:IlYP0J0:IlYP80000000<0oooo0000003Q`kT0103Q`kT2000000H0
hL>i00@000000?ooo`3oool000008@2]PZH010000000oooo0?ooo`3oool2000000T0k/>W00@00000
0>k3Y`3^`jL00000;`3oool3000000@0oooo00<000000?ooo`3oool0403oool000l0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000000779d01abM00801abM00@00000
0>S9]P3XbKH000007P2VO:H2000000d0hL>i00<000000?ooo`0000008P2]PZH00`000000oooo0?oo
o`020?ooo`030000003^`jL0k/>W00L0k/>W00@000000>k3Y`3^`jL00000;03oool3000000L0oooo
00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`050?ooo`050000000779d01abM00LLW@0000000`3XbKH00`000000YWbV0:IlYP0M0:IlYP800000
2`3Q`kT00`000000oooo0?ooo`0200000200[H:V00<000000?ooo`3oool00P3oool00`000000k/>W
0>k3Y`070>k3Y`040000003^`jL0k/>W000002T0oooo0`00000:0?ooo`030000003oool0oooo0100
oooo000?0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0103oool01@0000001abM
00LLW@0779d0000000<0j<Vf00<000000:IlYP2VO:H07`2VO:H2000000P0hL>i00<000000?ooo`3o
ool00P3oool3000001h0[H:V00<000000?ooo`3oool00P3oool00`000000k/>W0>k3Y`070>k3Y`03
0000003^`jL0k/>W008000009@3oool3000000h0oooo00<000000?ooo`3oool03`3oool000l0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?ooo`030000000779d01abM00801abM
00@000000>S9]P3XbKH000008@2VO:H00`000000hL>i0>73^@070>73^@030000003oool0oooo0080
oooo00<000000:f:/@2]R[400P00000L0:f2YP050000003oool0oooo0?ooo`0000002P3^`jL00`00
0000k/>W0>k3Y`0200000280oooo0`00000A0?ooo`030000003oool0oooo00l0oooo000?0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`0000001abM00LLW@0200LLW@05
0000003XbKH0j<Vf0>S9]P0000007`2VO:H00`000000hL>i0>73^@080>73^@050000003oool0oooo
0?ooo`0000001@2]R[400`000000[H:V0:f2YP0I0:f2YP050000003oool0oooo0?ooo`0000002P3^
`jL01@000000k/>W0>k3Y`3^`jL0000001l0oooo0`00000D0?ooo`030000003oool0oooo00l0oooo
000?0?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo0000000400LLW@050000
003XbKH0j<Vf0>S9]P0000007P2VO:H00`000000hL>i0>73^@040>73^@030000003Q`kT0hL>i0080
hL>i00D000000?ooo`3oool0oooo000000060:f:/@800000602]PZH00`000000oooo0?ooo`020?oo
o`030000003^`jL0k/>W00P0k/>W00D000000>k3Y`3^`jL0k/>W0000000L0?ooo`<000005`3oool0
0`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo
000000D01abM00@000000>S9]P3XbKH00000702VO:H2000000H0hL>i0P0000030>73^@@0000000<0
oooo0000002]R[401`2]R[42000001H0[H:V00<000000?ooo`3oool00P3oool00`000000k/>W0>k3
Y`080>k3Y`040000003^`jL0k/>W0>k3Y`800000603oool3000001X0oooo00<000000?ooo`3oool0
3`3oool000h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0000000500LLW@050000003X
bKH0j<Vf0>S9]P0000006P2VO:H00`000000hL>i0>73^@050>73^@800000103Q`kT010000000_Tlh
0;i?>02nCcP2000000X0[HZa0P00000D0:f2YP050000003oool0oooo0?ooo`0000002`3^`jL01000
0000k/>W0>k3Y`3^`jL2000001D0oooo0`00000M0?ooo`030000003oool0oooo00l0oooo000>0?oo
o`030000003oool0oooo03@0oooo0P00000500LLW@050000003XbKH0j<Vf0>S9]P0000006@2VO:H0
0`000000hL>i0>73^@050>73^@030000000J00l0000000@0hL>i00<000000;i?>02nCcP00`2nCcP2
000000X0[HZa0P00000B0:f2YP050000003oool0oooo0?ooo`0000002`3^`jL00`000000k/>W0>k3
Y`020>k3Y`030000003oool0oooo0100oooo0`00000P0?ooo`030000003oool0oooo00l0oooo000>
0?ooo`030000003oool0oooo03D0oooo00<0000000LLW@0779d0100779d010000000j<Vf0>S9]P00
000H0:IlYP030000003Q`kT0hL>i00@0hL>i0P00000201X03`040000003Q`kT0hL>i0>73^@800000
1`2nCcP2000000X0[HZa00<000000:f2YP2]PZH03`2]PZH01@000000oooo0?ooo`3oool0000000/0
k/>W00<000000>k3Y`3^`jL00P3^`jL3000000d0oooo0`00000S0?ooo`030000003oool0oooo00l0
oooo000>0?ooo`030000003oool0oooo03D0oooo00<0000000LLW@0779d0100779d01@000000j<Vf
0>S9]P3XbKH0000001H0YWbV00<000000>73^@3Q`kT0103Q`kT00`0000006P0?01X03`0201X03`04
0000003Q`kT0hL>i0>73^@8000002@2nCcP2000000T0[HZa0P00000>0:f2YP030000003oool0oooo
0080oooo00<000000>k3Y`3^`jL02@3^`jL00`000000k/>W0>k3Y`020>k3Y`80000000<0^SP30000
00000000203oool3000002L0oooo00<000000?ooo`3oool03P3oool000h0oooo00<000000?ooo`3o
ool0=@3oool00`0000001abM00LLW@0400LLW@050000003XbKH0j<Vf0>S9]P0000005@2VO:H20000
00D0hL>i00<0000001X03`0J00l00P0J00l00`000000hL>i0>73^@020>73^@030000002nCcP0_Tlh
00X0_Tlh00<000000:f:/@2]R[40202]R[42000000`0[H:V00<000000?ooo`3oool00P3oool00`00
0000k/>W0>k3Y`090>k3Y`030000003^`jL0k/>W0080k/>W0P0000030;Xh0`8000000`3oool30000
02X0oooo00<000000?ooo`3oool03P3oool000h0oooo00<000000?ooo`3oool0=@3oool00`000000
1abM00LLW@0500LLW@040000003XbKH0j<Vf000001@0YWbV00<000000?ooo`000000103Q`kT00`00
00006P0?01X03`0301X03`030000003Q`kT0hL>i0080hL>i00<000000;i?>02nCcP02`2nCcP20000
00X0[HZa0P00000:0:f2YP050000003oool0oooo0?ooo`000000303^`jL00`000000k/>W0>k3Y`03
0>k3Y`030000002j>0<0^SP300<0^SP30`00000]0?ooo`030000003oool0oooo00h0oooo000>0?oo
o`030000003oool0oooo03H0oooo00<0000000LLW@0779d0100779d01@000000j<Vf0>S9]P3XbKH0
00000180YWbV00D000000?ooo`3oool0oooo000000020>73^@030000000J00l06P0?00@06P0?00@0
00000>73^@3Q`kT0hL>i0P00000?0;i?>0800000202]R[400`000000oooo000000090:f2YP050000
003oool0oooo0?ooo`000000303^`jL00`000000k/>W0>k3Y`030>k3Y`030000002j>0<0^SP300H0
^SP30P00000[0?ooo`030000003oool0oooo00h0oooo000=0?ooo`030000003oool0oooo03L0oooo
00<0000000LLW@0779d0100779d01@000000j<Vf0>S9]P3XbKH000000100YWbV0P0000050?ooo`80
00001`0J00l010000000hL>i0>73^@3Q`kT200000140_Tlh0P0000070:f:/@040000003oool00000
000000L0[H:V00D000000?ooo`3oool0oooo0000000<0>k3Y`030000003^`jL0k/>W00<0k/>W0P00
00090;Xh0`<00000:03oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`0g
0?ooo`030000000779d01abM00D01abM00@000000>S9]P3XbKH000003`2VO:H00`000000oooo0?oo
o`050?ooo`030000000J00l06P0?00D06P0?00<000000>73^@3Q`kT00P3Q`kT00`000000_Tlh0;i?
>00B0;i?>08000001@2]R[4010000000oooo0?ooo`3oool2000000D0[H:V00D000000?ooo`3oool0
oooo0000000=0>k3Y`030000003^`jL0k/>W0080k/>W0P00000<0;Xh0`8000009P3oool00`000000
oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`0g0?ooo`030000000779d01abM00D01abM
00D000000>S9]P3XbKH0j<Vf0000000=0:IlYP030000002a_^@0000000D0oooo00<0000001X03`0J
00l01P0J00l00`000000hL>i0>73^@020>73^@030000002nCcP0_Tlh01@0_Tlh00<000000:f:/@2]
R[400`2]R[4010000000oooo0?ooo`3oool300000080[H:V00<000000?ooo`3oool00P3oool00`00
0000k/>W0>k3Y`0;0>k3Y`030000003^`jL0k/>W00<0k/>W00<000000;Xh0`2j>0<0302j>0<20000
02@0oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0=`3oool00`000000
1abM00LLW@0500LLW@050000003XbKH0j<Vf0>S9]P000000302VO:H01@000000/KkT0;6ni02a_^@0
000000<0oooo00<0000001X03`0J00l01`0J00l010000000hL>i0>73^@3Q`kT2000001L0_Tlh0P00
00030:f:/@050000003oool0oooo0?ooo`0000000P1;F/03000000<0oooo00<000000>k3Y`3^`jL0
303^`jL00`000000k/>W0>k3Y`030>k3Y`030000002j>0<0^SP300h0^SP30`00000Q0?ooo`030000
003oool0oooo00h0oooo000=0?ooo`030000003oool0oooo03L0oooo00<0000000LLW@0779d01P07
79d010000000j<Vf0>S9]P00000;0:IlYP030000002a_^@0/KkT00<0/KkT0`00000:01X03`040000
003Q`kT0hL>i0>73^@8000006@2nCcP200000080[HZa00T000000?ooo`3oool0oooo0000001;F/00
00000?ooo`0000000`3oool00`000000k/>W0>k3Y`080>k3Y``000004P2j>0<200000200oooo00<0
00000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool0=`3oool00`0000001abM00LLW@06
00LLW@050000003XbKH000000?ooo`0000002@2VO:H00`000000/KkT0;6ni0040;6ni0030000000J
00l06P0?00T06P0?00<000000>73^@3Q`kT00P3Q`kT00`000000_Tlh0;i?>00J0;i?>0<000000`3o
ool00`000000Be[0000000050?ooo`/00000102T]^H00`000000Y;KV0:BfiP050:BfiP030000002j
>0<0^SP30140^SP30P00000N0?ooo`030000003oool0oooo00d0oooo000=0?ooo`030000003oool0
oooo03L0oooo00<0000000LLW@0779d01P0779d2000000030?ooo`000000000000P0YWbV00<00000
0;6ni02a_^@0102a_^@00`0000006P0?01X03`0:01X03`040000003Q`kT0hL>i0>73^@8000007P2n
CcP2000000<0oooo00<000000?ooo`3oool0103oool00`000000Y;KV0:BfiP0<0:BfiP030000002T
]^H0Y;KV00H0Y;KV5`00000L0?ooo`030000003oool0oooo00d0oooo000=0?ooo`030000003oool0
oooo03L0oooo00<0000000LLW@0779d01`0779d4000000L0YWbV00<000000;6ni02a_^@0102a_^@0
0`0000006P0?01X03`0;01X03`040000003Q`kT0hL>i0>73^@800000802nCcP2000000030?ooo`00
0000oooo00@0oooo0P00000>0:BfiP030000002T]^H0Y;KV00X0Y;KV2`00000T0?ooo`030000003o
ool0oooo00d0oooo000<0?ooo`030000003oool0oooo03P0oooo00<0000000LLW@0779d01`0779d3
000000030;6ni0000000YWbV00<0YWbV0P0000060;6ni0030000000J00l06P0?00`06P0?00@00000
0>73^@3Q`kT0hL>i0P00000O0;i?>0@000000`3oool4000000l0Y;KV3@00000_0?ooo`030000003o
ool0oooo00d0oooo000<0?ooo`030000003oool0oooo03P0oooo00<0000000LLW@0779d01`0779d2
00000080/KkT00D000000:IlYP2VO:H0YWbV000000070;6ni0030000000J00l06P0?00`06P0?00<0
00000?ooo`0000000P3Q`kT00`000000_Tlh0;i?>00H0;i?>0P000000P3oool3000000<0oooo00<0
00000:BfiP2T]^H00`2T]^H;000003/0oooo00<000000?ooo`3oool03@3oool000`0oooo00<00000
0?ooo`3oool0>03oool00`0000001abM00LLW@0800LLW@040000002a_^@0/KkT00000080YWbV00<0
00000;6ni02a_^@01@2a_^@00`0000006P0?01X03`0=01X03`030000003oool0oooo00<00000502n
CcP:000000<0oooo0`0000060?ooo`H000002P3oool010000000oooo0?ooo`3oool6000000030?oo
o`000000000001D000006P3oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?oo
o`0i0?ooo`030000000779d01abM00L01abM00@000000;6ni02a_^@0/KkT0P0000070;6ni0030000
000J00l06P0?00h06P0?00@000000?ooo`3oool0oooo0P00000>0;i?>0P00000203oool3000001<0
oooo2P0000060<IC<0800000503dcZL00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00d0
oooo000<0?ooo`030000003oool0oooo03T0oooo00<0000000LLW@0779d01`0779d01@000000/KkT
0;6ni02a_^@0000000H0/KkT0P00000A01X03`030000003oool0oooo0080oooo00<000000;i?>02n
CcP01P2nCcP6000000d0oooo0`00000@0?ooo`H000001P36Dc000`000000aU<`0<IC<0080<IC<003
0000003dcZL0m<jW0180m<jW00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`00
303oool00`000000oooo0?ooo`0i0?ooo`030000000779d01abM00P01abM00<000000;6ni02a_^@0
1P2a_^@00`0000006P0?01X03`0@01X03`030000003oool0oooo0080oooo00@000000;i?>02nCcP0
_Tlh1P00000@0?ooo`<000001`3oool4000000T0oooo0P0000090<IC<00300000036Dc00aU<`00P0
aU<`00<000000?C>Y`3dcZL04@3dcZL2000001`0oooo00<000000?ooo`3oool0303oool000`0oooo
00<000000?ooo`3oool0>@3oool00`0000001abM00LLW@0600LLW@<000001`2a_^@00`0000006P0?
01X03`0<01X03`H00000103oool4000001<0oooo0`0000020?ooo`P000000`3W`k400`000000oooo
0?ooo`020?ooo`P000002036Dc000`000000aU<`0<IC<0090<IC<0030000003dcZL0m<jW0100m<jW
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?oo
o`0j0?ooo`030000000779d01abM00H000002@2a_^@00`0000006P0?01X03`0201X03`/000000P2a
_^@4000001P0oooo2000000;0>O3/@030000003oool0oooo0080oooo00<000000:N4[P0000001@2W
Q:h2000000H0aU<`00<000000<IC<036Dc002P36Dc000`000000m<jW0?C>Y`0>0?C>Y`8000007@3o
ool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?ooo`0i0?ooo`H00000302a_^@6
000000L0/KkT1P00000F0?ooo`L000004@3W`k400`000000oooo0?ooo`040?ooo`@000001@2WQ:h2
000000@0aU<`00<000000<IC<036Dc002`36Dc000`000000m<jW0?C>Y`0=0?C>Y`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0303oool000/0oooo00<000000?ooo`3oool0>03oool60000
01@0/KkT1P00000D0?ooo`P00000603W`k400`000000oooo000000040?ooo`050000002`RJ`0/8V/
0;29[00000001P2WQ:h01@000000aU<`0<IC<036Dc00000000d0aU<`00<000000?C>Y`3dcZL0303d
cZL2000001h0oooo00<000000?ooo`3oool0303oool000/0oooo00<000000?ooo`3oool0=`3oool6
000000l0/KkT1P00000F0?ooo`@00000803W`k400`000000oooo000000040?ooo`030000002`RJ`0
/8V/0080/8V/0P0000050:N4[P80000000<0aU<`00000036Dc003@36Dc000`000000m<jW0?C>Y`0:
0?C>Y`8000007`3oool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?ooo`0e0?oo
o`L000002@2a_^@7000000<0oooo00<000000?ooo`3oool02@3oool8000000H0oooo00<000000>O3
/@3W`k40803W`k4200000003059F^@000000oooo0080oooo00<000000;29[02`RJ`0102`RJ`00`00
0000YhB^0:N4[P040:N4[P0300000036Dc00000000h0aU<`00<000000?C>Y`3dcZL02@3dcZL20000
01l0oooo00<000000?ooo`3oool0303oool000/0oooo00<000000?ooo`3oool0=03oool6000000D0
/KkT1P00000;0?ooo`/000001@0[?;000`000000/HZ]000000070?ooo`030000003W`k40il>a01h0
il>a00D000000?ooo`000000DUJi000000030?ooo`030000002`RJ`0/8V/00D0/8V/0P0000050:N4
[P8000003`36Dc000`000000m<jW0?C>Y`070?C>Y`800000803oool00`000000oooo0?ooo`0<0?oo
o`002`3oool00`000000oooo0?ooo`0c0?ooo`@000000P2a_^@600000080oooo0`0000060?ooo`H0
0000400[?;000`000000/HZ]000000050?ooo`@000007`3W`k400`000000oooo00000002059F^@03
0000003oool0000000X0/8V/00<000000:N4[P2WQ:h00`2WQ:h2000000h0aU<`00<000000?C>Y`3d
cZL01`3dcZL00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000
003oool0oooo03<0oooo0P0000000`3oool0000000000002000000<0oooo1`0000070?ooo`030000
000[?;00:cb`0180:cb`00<000000;6:[@0000000P3oool600000080oooo00<000000>O3/@3W`k40
703W`k42000000<0DUJi00<000000?ooo`0000002`2`RJ`2000000<0YhB^00@000000:N4[P000000
00003@36Dc000`000000m<jW0?C>Y`050?C>Y`8000008P3oool00`000000oooo0?ooo`0;0?ooo`00
2P3oool00`000000oooo0?ooo`0j0?ooo`T00000103oool6000001<0:cb`00<000000;6:[@000000
100000001@3oool000000=nk/`3O^k<000000080oooo00<000000>O3/@3W`k406`3W`k42000000<0
DUJi00<000000?ooo`0000003@2`RJ`010000000YhB^0:N4[P0000030:N4[P8000003036Dc000`00
0000m<jW0?C>Y`040?C>Y`030000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool000X0
oooo00<000000?ooo`3oool0=`3oool@000000D0/HZ]00<0000002/l/00[?;004@0[?;000`000000
/HZ]000000020?ooo`040000002W_NT00000000000<0gk^c00<000000?ooo`0000007@3W`k420000
00@0DUJi0P00000>0;29[0<000001@2WQ:h00`000000aU<`0<IC<00:0<IC<0030000003dcZL0m<jW
0080m<jW0P00000S0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0oooo03@0
oooo0`0000020003T@P00000102aRZd2000000H0/HZ]00<0000002/l/00[?;00400[?;001@000000
/HZ]0000003oool0000000<0YkgY00<000000=nk/`3O^k<00P3O^k<00`000000oooo0000000K0>O3
/@8000001@1BE[T00`000000/8V/0;29[00?0;29[0030000002WQ:h0YhB^00@0YhB^0P00000:0<IC
<0030000003dcZL0m<jW0080m<jW00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0;0?oo
o`002P3oool00`000000oooo0?ooo`0b0?ooo`80000010000i48000000@0/HZ]00@000000:F1[02U
PJ`000001@2aRZd00`000000:cb`02/l/00?02/l/0030000002aRZd000000080oooo00<000000:Nm
j@2W_NT00P2W_NT01@000000gk^c0=nk/`3O^k<000000080oooo00<000000>O3/@3W`k40603W`k42
000000D0DUJi00<000000;29[02`RJ`03`2`RJ`3000000H0YhB^00<000000<IC<036Dc002036Dc00
0`000000m<jW0?C>Y`02000002@0oooo00<000000?ooo`3oool02`3oool000X0oooo00<000000?oo
o`3oool0<`3oool01000000000>A0003T@000i48000000@0/HZ]00D000000:F1[02UPJ`0YH6/0000
00060;6:[@030000000[?;00:cb`00h0:cb`00<000000;6:[@0000000P3oool00`000000YkgY0:Nm
j@030:Nmj@050000003O^k<0gk^c0=nk/`0000000P3oool00`000000il>a0>O3/@0G0>O3/@800000
1@1BE[T00`000000/8V/0;29[00?0;29[0040000002`RJ`0/8V/000000H0YhB^0P0000090<IC<0<0
00009@3oool00`000000oooo0?ooo`0;0?ooo`002P3oool00`000000oooo0?ooo`0c0?ooo`030000
00000i4000>A00P00000102aRZd00`000000YH6/0:F1[0030:F1[0030000002aRZd0/HZ]00<0/HZ]
00<0000002/l/00[?;003P0[?;000`000000/HZ]000000020?ooo`030000002W_NT0YkgY00@0YkgY
00D000000=nk/`3O^k<0gk^c000000020?ooo`030000003W`k40il>a01H0il>a00<00000059F^@1B
E[T0101BE[T00`000000/8V/0;29[00?0;29[0040000002`RJ`0/8V/0;29[08000001@2WQ:h20000
00T0aU<`0P00000U0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0oooo03@0
oooo00<000000003T@0000001P0000040;6:[@030000002UPJ`0YH6/00@0YH6/00<000000;6:[@2a
RZd00`2aRZd00`000000:cb`02/l/00>02/l/0050000002aRZd000000?ooo`000000202W_NT01@00
0000gk^c0=nk/`3O^k<000000080oooo00<000000>O3/@3W`k405@3W`k400`000000DUJi059F^@03
059F^@030000002`RJ`0/8V/0100/8V/00<000000;29[02`RJ`00`2`RJ`01P000000YhB^0:N4[P2W
Q:h000000?ooo`<000002036Dc000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00X0oooo
00090?ooo`030000003oool0oooo03D0oooo2P0000020;6:[@030000002UPJ`0YH6/00H0YH6/00<0
00000;6:[@2aRZd00`2aRZd00`000000:cb`02/l/00<02/l/0060000002aRZd0/HZ]0000003oool0
0000202W_NT00`000000gk^c0=nk/`020=nk/`040000003oool0oooo000001D0il>a0P000005059F
^@030000002`RJ`0/8V/0100/8V/00<000000;29[02`RJ`0102`RJ`300000080oooo00<00000028e
[@0R=Jd00P0000060<IC<0030000003oool0oooo02@0oooo00<000000?ooo`3oool02P3oool000T0
oooo00<000000?ooo`3oool0=@3oool8000000040003T@0000000000000000T0YH6/00<000000;6:
[@2aRZd00`2aRZd00`000000:cb`02/l/00<02/l/0030000002aRZd000000080oooo00<000000:Nm
j@2W_NT01`2W_NT00`000000gk^c0=nk/`020=nk/`040000003oool0oooo000001@0il>a00<00000
059F^@1BE[T0101BE[T00`000000/8V/0;29[00@0;29[0030000002`RJ`0/8V/00H0/8V/0P000000
0`3oool00000028e[@03028e[@0300000036Dc00aU<`00@0aU<`00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`0e0?ooo`P0000000<000>A0000
000000002P2UPJ`00`000000/HZ]0;6:[@040;6:[@030000000[?;00:cb`00/0:cb`00<000000;6:
[@0000000P3oool00`000000YkgY0:Nmj@080:Nmj@030000003O^k<0gk^c0080gk^c00@000000?oo
o`3oool000004`3W`k400`000000DUJi059F^@04059F^@030000002`RJ`0/8V/0100/8V/00<00000
0;29[02`RJ`0202`RJ`2000000D08SF]0P0000050<IC<0030000003oool0oooo0280oooo00<00000
0?ooo`3oool02P3oool000T0oooo00<000000?ooo`3oool0=03oool7000000040>_4[P00000000>A
000000`0YH6/00<000000;6:[@2aRZd00`2aRZd00`000000:cb`02/l/00;02/l/0050000002aRZd0
00000?ooo`000000302W_NT00`000000gk^c0=nk/`020=nk/`040000003oool0oooo00000180il>a
00<00000059F^@1BE[T00`1BE[T00`000000/8V/0;29[00A0;29[0030000002`RJ`0/8V/00T0/8V/
0P000006028e[@0300000036Dc00aU<`00<0aU<`00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`0c0?ooo`L000000`3[a:h00`000000YH6/0:F1
[00;0:F1[0030000002aRZd0/HZ]00@0/HZ]00<0000002/l/00[?;002P0[?;001@000000/HZ]0000
003oool0000000d0YkgY00D000000=nk/`3O^k<0gk^c000000020?ooo`030000003W`k40il>a00l0
il>a0P000005059F^@030000002`RJ`0/8V/0140/8V/00<000000;29[02`RJ`02`2`RJ`00`000000
8SF]028e[@04028e[@8000000`36Dc000`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0
oooo00090?ooo`030000003oool0oooo0380oooo1`0000030>_4[P030000002UPJ`0YH6/00d0YH6/
00<000000;6:[@2aRZd00`2aRZd00`000000:cb`02/l/00902/l/0030000002aRZd000000080oooo
00<000000:Nmj@2W_NT0302W_NT01@000000gk^c0=nk/`3O^k<000000080oooo00<000000>O3/@3W
`k403P3W`k400`000000DUJi059F^@04059F^@030000002`RJ`0/8V/0140/8V/00<000000;29[02`
RJ`0302`RJ`2000000H08SF]00D000000<IC<036Dc00aU<`0000000R0?ooo`030000003oool0oooo
00X0oooo00090?ooo`030000003oool0oooo0380oooo1P0000030>_4[P030000002UPJ`0YH6/00h0
YH6/00<000000;6:[@2aRZd00`2aRZd00`000000:cb`02/l/00902/l/0030000002aRZd000000080
oooo00<000000:Nmj@2W_NT03@2W_NT01@000000gk^c0=nk/`3O^k<000000080oooo00<000000>O3
/@3W`k403@3W`k400`000000DUJi059F^@04059F^@030000002`RJ`0/8V/0140/8V/00<000000;29
[02`RJ`03P2`RJ`00`0000008SF]028e[@04028e[@8000000P36Dc000`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo0380oooo1P0000030>_4[P03
0000002UPJ`0YH6/0100YH6/00<000000;6:[@2aRZd00`2aRZd00`000000:cb`02/l/00802/l/003
0000002aRZd000000080oooo00<000000:Nmj@2W_NT03P2W_NT01@000000gk^c0=nk/`3O^k<00000
0080oooo00<000000>O3/@3W`k40303W`k400`000000DUJi059F^@03059F^@030000002`RJ`0/8V/
01<0/8V/00<000000;29[02`RJ`03P2`RJ`2000000H08SF]0P0000000`36Dc0000000?ooo`0O0?oo
o`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo0340oooo1P0000030>_4[P03
0000002UPJ`0YH6/0140YH6/00<000000;6:[@2aRZd00`2aRZd00`000000:cb`02/l/00802/l/005
0000002aRZd000000?ooo`0000004P2W_NT01@000000gk^c0=nk/`3O^k<000000080oooo00<00000
0>O3/@3W`k402`3W`k400`000000DUJi059F^@03059F^@030000002`RJ`0/8V/01<0/8V/00<00000
0;29[02`RJ`0402`RJ`00`0000008SF]028e[@05028e[@8000008@3oool00`000000oooo0?ooo`09
0?ooo`00203oool00`000000oooo0?ooo`0a0?ooo`D000000`3[a:h00`000000YH6/0:F1[00B0:F1
[0030000002aRZd0/HZ]00@0/HZ]00<0000002/l/00[?;001P0[?;000`000000/HZ]000000020?oo
o`030000002W_NT0YkgY0140YkgY00D000000=nk/`3O^k<0gk^c000000020?ooo`030000003W`k40
il>a00T0il>a00<00000059F^@1BE[T0101BE[T00`000000/8V/0;29[00C0;29[0030000002`RJ`0
/8V/0140/8V/0P000006028e[@800000803oool00`000000oooo0?ooo`090?ooo`00203oool00`00
0000oooo0?ooo`0`0?ooo`D000000`3[a:h00`000000YH6/0:F1[00D0:F1[0030000002aRZd0/HZ]
00<0/HZ]00<0000002/l/00[?;001P0[?;000`000000/HZ]000000020?ooo`030000002W_NT0YkgY
0180YkgY00D000000=nk/`3O^k<0gk^c000000020?ooo`030000003W`k40il>a00P0il>a00<00000
059F^@1BE[T0101BE[T00`000000/8V/0;29[00C0;29[0030000002`RJ`0/8V/01<0/8V/00<00000
028e[@0R=Jd01@0R=Jd00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00080?oo
o`030000003oool0oooo02l0oooo1@0000030>_4[P030000002UPJ`0YH6/01D0YH6/0P0000040;6:
[@030000000[?;00:cb`00H0:cb`00<000000;6:[@0000000P3oool00`000000YkgY0:Nmj@0C0:Nm
j@050000003O^k<0gk^c0=nk/`0000000P3oool00`000000il>a0>O3/@070>O3/@030000001BE[T0
DUJi00<0DUJi00<000000;29[02`RJ`0502`RJ`00`000000/8V/0;29[00D0;29[08000001@0R=Jd0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00080?ooo`030000003oool0oooo
02h0oooo1@0000030>_4[P030000002UPJ`0YH6/01L0YH6/0`0000030;6:[@030000000[?;00:cb`
00D0:cb`00D000000;6:[@000000oooo0000000G0:Nmj@040000003O^k<0gk^c000000<0oooo00<0
00000>O3/@3W`k401P3W`k400`000000DUJi059F^@03059F^@030000002`RJ`0/8V/01@0/8V/00<0
00000;29[02`RJ`05P2`RJ`00`0000008SF]028e[@03028e[@030000003oool0oooo01`0oooo00<0
00000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0;P3oool4000000@0jlB^00<00000
0:F1[02UPJ`05`2UPJ`010000000oooo0?ooo`0000020;6:[@030000000[?;00:cb`00D0:cb`00D0
00000;6:[@000000oooo0000000H0:Nmj@040000003O^k<0gk^c000000<0oooo00<000000>O3/@3W
`k401@3W`k400`000000DUJi059F^@03059F^@030000002`RJ`0/8V/01@0/8V/00<000000;29[02`
RJ`05`2`RJ`7000001d0oooo00<000000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0
;@3oool4000000@0jlB^00<000000:F1[02UPJ`0602UPJ`010000000oooo0?ooo`3oool200000003
0;6:[@000000:cb`00@0:cb`00<000000;6:[@0000000P3oool00`000000YkgY0:Nmj@0G0:Nmj@04
0000003O^k<0gk^c000000<0oooo00<000000>O3/@3W`k400`3W`k400`000000DUJi059F^@04059F
^@030000002`RJ`0/8V/01@0/8V/00<000000;29[02`RJ`05P2`RJ`400000240oooo00<000000?oo
o`3oool02@3oool000L0oooo00<000000?ooo`3oool0;@3oool4000000@0jlB^00<000000:F1[02U
PJ`06P2UPJ`00`000000oooo0?ooo`020?ooo`8000001@0[?;000`000000/HZ]000000020?ooo`03
0000002W_NT0YkgY01P0YkgY00@000000=nk/`3O^k<000000P3oool00`000000il>a0>O3/@030>O3
/@L000005`2`RJ`00`000000/8V/0;29[00>0;29[0P000009@3oool00`000000oooo0?ooo`090?oo
o`001`3oool00`000000oooo0?ooo`0]0?ooo`<00000103[a:h00`000000YH6/0:F1[00K0:F1[003
0000003oool0oooo00@0oooo00<0000002/l/00[?;000P0[?;000`000000/HZ]000000020?ooo`03
0000002W_NT0YkgY01P0YkgY00<000000=nk/`0000000P0000020?ooo`030000003W`k40il>a0080
il>a00<000000?ooo`3oool00`3oool00`000000/8V/0;29[00D0;29[08000002@2`RJ`7000002h0
oooo00<000000?ooo`3oool0203oool000L0oooo00<000000?ooo`3oool0;03oool3000000@0jlB^
00<000000:F1[02UPJ`07@2UPJ`00`000000oooo0?ooo`030?ooo`030000000[?;00:cb`0080:cb`
00D000000;6:[@000000oooo0000000L0:Nmj@030000003oool0oooo00@0oooo00D000000>O3/@3W
`k40il>a000000050?ooo`030000002`RJ`0/8V/0140/8V/0`0000020;29[0T00000=@3oool00`00
0000oooo0?ooo`080?ooo`001`3oool00`000000oooo0?ooo`0[0?ooo`<00000103[a:h00`000000
YH6/0:F1[00N0:F1[0<000000`3oool01`000000:cb`02/l/00[?;0000000;6:[@0000000P3oool0
0`000000YkgY0:Nmj@0K0:Nmj@030000003oool0oooo00@0oooo00<000000>O3/@0000001P3oool0
0`000000/8V/0;29[00=0;29[0/000005`3oool6000001l0oooo00<000000?ooo`3oool0203oool0
00L0oooo00<000000?ooo`3oool0:P3oool4000000<0jlB^00<000000:F1[02UPJ`0802UPJ`00`00
0000bFQG000000030?ooo`030000000[?;00:cb`00<000000P3oool00`000000YkgY0:Nmj@0L0:Nm
j@030000003oool0oooo00@0oooo2000000;0;29[0L000002@3oool00`000000oooo0?ooo`0;0?oo
o`T0000000<0[LO]0000000000000P00000P0?ooo`030000003oool0oooo00P0oooo00070?ooo`03
0000003oool0oooo02X0oooo0`0000030>_4[P030000002UPJ`0YH6/0240YH6/00<000000<UXE`39
J5L00P0000001`3oool0000002/l/00[?;0000000?ooo`0000000P3oool00`000000YkgY0:Nmj@0M
0:Nmj@<000000`3oool2000000D0CP5600@000000;29[02`RJ`0/8V/2`00000=0?ooo`030000003o
ool0oooo00H0oooo200000060:g7k@030000000@00l000000280oooo00<000000?ooo`3oool0203o
ool000L0oooo00<000000?ooo`3oool0:@3oool3000000<0jlB^00<000000:F1[02UPJ`08P2UPJ`0
0`000000bFQG0<UXE`020<UXE`<0000000<0:cb`0000003oool00P3oool00`000000YkgY0:Nmj@0O
0:Nmj@8000000`3oool00`000000CP5604h1AP0404h1AP@000000`1>0DH400000080CP5600<00000
0?ooo`3oool03@3oool00`000000oooo00000006000000`0[LO]0`00000S0?ooo`030000003oool0
oooo00P0oooo00060?ooo`030000003oool0oooo02T0oooo0`0000030>_4[P030000002UPJ`0YH6/
02@0YH6/00<000000<UXE`39J5L00P39J5L3000000@0oooo00<000000:Nmj@2W_NT0802W_NT01@00
0000oooo0?ooo`3oool0000000X0CP560`00000504h1AP030000003oool0oooo00H0oooo2P00000A
0:g7k@<000009@3oool00`000000oooo0?ooo`080?ooo`001P3oool00`000000oooo0?ooo`0Y0?oo
o`8000000`3[a:h00`000000YH6/0:F1[00U0:F1[00300000039J5L0bFQG0080bFQG0`0000040?oo
o`030000002W_NT0YkgY01d0YkgY1@0000000`3oool0000004h1AP0704h1AP<000001`1>0DH00`00
0000oooo0?ooo`040?ooo`L000001P2]and00`000000[LO]0:g7k@0=0:g7k@030000000@00l00000
02H0oooo00<000000?ooo`3oool0203oool000H0oooo00<000000?ooo`3oool0:03oool2000000<0
jlB^00<000000:F1[02UPJ`09`2UPJ`5000000030?ooo`000000oooo00<0oooo00<000000:Nmj@2W
_NT0502W_NT900000080`V=K00D000000?ooo`3oool0oooo0000000404h1AP@00000201>0DH90000
00h0[LO]00<000000:g7k@2]and02P2]and4000002P0oooo00<000000?ooo`3oool01`3oool000H0
oooo00<000000?ooo`3oool09`3oool300000080jlB^00<000000:F1[02UPJ`0:02UPJ`01@000000
oooo0?ooo`3oool0000000D0oooo00<000000:Nmj@2W_NT02`2W_NT:000000/0`V=K00H000000?oo
o`3oool0oooo0000001>0DH3000000P0CP561P00000F0:g7k@030000002]and0[LO]00P0[LO]00<0
000001003`000000:P3oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo0?ooo`0V
0?ooo`<000000P3[a:h00`000000YH6/0:F1[00Z0:F1[0040000003oool0oooo000000D0oooo00<0
00000:Nmj@2W_NT00P2W_NT9000001D0`V=K00<000000?ooo`3oool00`00000704h1AP@00000702]
and00`000000[LO]0:g7k@060:g7k@@00000:`3oool00`000000oooo0?ooo`070?ooo`001P3oool0
0`000000oooo0?ooo`0V0?ooo`8000000P3[a:h00`000000YH6/0:F1[00S0:F1[0T000000P3oool0
0`000000oooo0?ooo`030?ooo`D000000P3oool2000001X0`V=K0`0000000`3oool0000004h1AP08
04h1AP030000002]and0[LO]01d0[LO]00<000000:g7k@2]and0102]and00`000000400?0000000]
0?ooo`030000003oool0oooo00L0oooo00060?ooo`030000003oool0oooo02D0oooo0P0000020>_4
[P030000002UPJ`0YH6/01@0YH6/4000000;0?ooo`030000003oool0oooo00`0oooo0P00000D0<9S
F`D000000`3oool00`000000CP5604h1AP0804h1AP030000002]and0[LO]01d0[LO]00<000000:g7
k@2]and00P2]and3000002h0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?ooo`3o
ool09P3oool00`000000jlB^000000070:F1[10000006`3oool00`000000oooo00000003000000/0
oooo00<000000<9SF`32He/03P32He/3000000@0`V=K00D000000?ooo`3oool0oooo0000000;04h1
AP030000002]and0[LO]01d0[LO]00<000000:g7k@0000000P00000`0?ooo`030000003oool0oooo
00L0oooo00050?ooo`030000003oool0oooo02H0oooo2`00000V0?ooo`L000000`3U_:d01@000000
oooo0?ooo`3oool0000000P0oooo0P00000;0<9SF`<000001032He/7000000/0CP5600<000000?oo
o`0000007`2]and00`000000400?0000000a0?ooo`030000003oool0oooo00L0oooo00050?ooo`03
0000003oool0oooo04@0oooo100000070?ooo`P000002P3U_:d010000000oooo0?ooo`3oool30000
00P0oooo0P0000040<9SF``000001P2[R;000`000000CP5604h1AP0204h1AP030000001>0DH0CP56
0080CP560P0000020?ooo`030000002]and0[LO]01/0[LO]1000000b0?ooo`030000003oool0oooo
00L0oooo00050?ooo`030000003oool0oooo03`0oooo200000040<II?0030000003oool0oooo00@0
00000`3U_:d9000000D0iKb]00<000000?ooo`3oool00P3oool00`000000[XBX0:j4Z00?00000100
ZhR`0P00000404h1AP8000000P1>0DH00`000000oooo0?ooo`030?ooo`030000002]and0[LO]01T0
[LO]00D0000001003`000000oooo0000000b0?ooo`030000003oool0oooo00L0oooo00050?ooo`03
0000003oool0oooo03@0oooo200000060<II?1000000202L_>l00`000000iKb]0>Fl[@030>Fl[@03
0000003oool0oooo00L000001`2[R;03000001<0ZhR`0P00000304h1AP030000003Yc;P0jLbh0080
00001`3oool00`000000[LO]0:g7k@0F0:g7k@D000000P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00H0oooo00050?ooo`030000003oool0oooo02`0oooo5P00000H09blk`030000
003U_:d0iKb]00<0iKb]00@000000?ooo`3oool000002P2[R;03000001H0ZhR`0P00000304h1AP05
0000003Yc;P0jLbh0>W<^00000001@3oool2000000030:R0Z0000000[LO]01D0[LO]00<000000100
3`0000000P3adk801@000000oooo0?ooo`3oool000000340oooo00<000000?ooo`3oool01P3oool0
00D0oooo00<000000?ooo`3oool09`3oool;000002L0W;c_00<000000>Fl[@3U_:d0103U_:d01@00
0000oooo0?ooo`3oool0000000D0ZhR`1000000I0:^8/08000000`1>0DH00`000000jLbh0>W<^002
0>W<^0050000003oool0oooo0?ooo`000000102XP:P00`000000[LO]0:g7k@0B0:g7k@<000000`3a
dk800`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01P3o
ool000D0oooo00<000000?ooo`3oool0:@3oool5000002/0W;c_00<000000>Fl[@3U_:d0103U_:d0
1@000000oooo0?ooo`3oool000000080ZhR`0`00000L0:^8/0030000003oool0000000<0CP5600<0
00000>W<^03Yc;P00P3Yc;P010000000oooo0?ooo`0000060:R0Z0030000002]and0[LO]00l0[LO]
0`0000050?7C/P030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`060?ooo`00103oool00`000000oooo0?ooo`0]0?ooo`D00000:02L_>l00`000000iKb]0>Fl
[@030>Fl[@<000000P3oool3000001l0ZhR`00<000000?ooo`0000000P1>0DH00`000000jLbh0>W<
^0040>W<^0800000202XP:P00`000000[LO]0:g7k@0=0:g7k@<000001P3adk800`000000oooo0?oo
o`040?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool000@0oooo00<00000
0?ooo`3oool0<03oool4000002H0W;c_00<000000>Fl[@3U_:d00`3U_:d5000000030:j4Z0000000
ZhR`01l0ZhR`0P00000204h1AP8000001`3Yc;P00`000000Z82X0:R0Z0070:R0Z0030000002]and0
[LO]00X0[LO]0`0000080?7C/P030000003oool0oooo00@0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`060?ooo`00103oool00`000000oooo0?ooo`0c0?ooo`@000008`2L_>l01000
0000iKb]0>Fl[@3U_:d3000000807cjh0P0000020:j4Z0030000002[R;00ZhR`01d0ZhR`0P000000
101>0DH000000?ooo`0000080>W<^0030000002XP:P0Z82X00L0Z82X00<000000:g7k@2]and0202]
and00`000000400?000000090?7C/P030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`060?ooo`00103oool00`000000oooo0?ooo`0e0?ooo`D000007`2L_>l0
0`000000iKb]0000000200000080iKb]00<0000001ln^00O?[P00P0000020:j4Z0030000002[R;00
ZhR`01`0ZhR`00@000000?ooo`00000000000P3oool00`000000jLbh0>W<^0070>W<^0030000002X
P:P0Z82X00H0Z82X00<000000:g7k@2]and01P2]and4000000X0lM>b00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo00040?ooo`030000003oool0
oooo03P0oooo1@00000J09blk`@000001@3U_:d01@0000007cjh01ln^00O?[P0000000<0[XBX00<0
00000:^8/02[R;006`2[R;000`000000oooo000000020?ooo`030000003Yc;P0jLbh00T0jLbh00<0
00000:R0Z02XP:P01P2XP:P00`000000[LO]0:g7k@040:g7k@030000000@00l0000000`0lM>b00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo0004
0?ooo`030000003oool0oooo03/0oooo1@00000D09blk`<000000P2L_>l00`000000iKb]0>Fl[@03
0>Fl[@8000000`0O?[P01@000000[XBX0:j4Z02^Q:P0000001d0ZhR`00<000000?ooo`3oool00P3o
ool00`000000jLbh0>W<^00:0>W<^0030000002XP:P0Z82X00H0Z82X00<000000:g7k@2]and00P2]
and4000000`0lM>b00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00D0oooo00040?ooo`030000003oool0oooo03h0oooo1000000?09blk`<000001@2L_>l0
0`000000iKb]0>Fl[@030>Fl[@030000000O?[P07cjh00<07cjh00D000000:j4Z02^Q:P0[XBX0000
000K0:^8/0030000003oool0oooo00<0oooo00<000000>W<^03Yc;P02`3Yc;P00`000000Z82X0:R0
Z0060:R0Z0030000002]and000000080000000<0Z82X0000003adk80303adk800`000000oooo0?oo
o`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool000<0oooo00<00000
0?ooo`3oool0@P3oool4000000T0W;c_0`00000709blk`030000003U_:d0iKb]00@0iKb]00<00000
01ln^00O?[P00`0O?[P01@000000[XBX0:j4Z02^Q:P0000001/0ZhR`00<000000?ooo`3oool00P3o
ool00`000000jLbh0>W<^00=0>W<^0030000002XP:P0Z82X00H0Z82X00D000000:R0Z02XP:P0Z82X
0000000>0?7C/P8000002P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00D0oooo
00030?ooo`030000003oool0oooo04D0oooo1000000209blk`@000002P2L_>l00`000000iKb]0>Fl
[@040>Fl[@030000000O?[P07cjh00@07cjh00D000000:j4Z02^Q:P0[XBX0000000J0:^8/0030000
003oool0oooo0080oooo00<000000>W<^03Yc;P03@3Yc;P00`000000Z82X0:R0Z0090:R0Z0030000
003adk80lM>b00h0lM>b00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00D0oooo00030?ooo`030000003oool0oooo04P0oooo1000000=09blk`030000003U
_:d0iKb]00@0iKb]00<0000001ln^00O?[P0100O?[P01@000000[XBX0:j4Z02^Q:P0000001X0ZhR`
00<000000?ooo`3oool00P3oool00`000000jLbh0>W<^00>0>W<^0030000002XP:P0Z82X00P0Z82X
00<000000?7C/P3adk803P3adk800`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool01@3oool000<0oooo00<000000?ooo`3oool0A@3oool3000000<0oooo1000
000:09blk`030000003U_:d0iKb]00<0iKb]0P00000701ln^0050000002^Q:P0[XBX0:j4Z0000000
602[R;000`000000oooo0?ooo`030?ooo`030000003Yc;P0jLbh00l0jLbh00<000000:R0Z02XP:P0
1P2XP:P00`000000lM>b0?7C/P0?0?7C/P030000003oool0oooo00/0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`050?ooo`000`3oool00`000000oooo0?ooo`110?ooo`@00000203o
ool4000000P0W;c_00<000000>Fl[@3U_:d00`3U_:d00`0000007cjh01ln^00601ln^0050000002^
Q:P0[XBX0:j4Z0000000602[R;000`000000oooo0?ooo`020?ooo`030000003Yc;P0jLbh0140jLbh
00<000000:R0Z02XP:P01P2XP:P00`000000lM>b0?7C/P0>0?7C/P030000003oool0oooo00`0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`000`3oool00`000000oooo0?oo
o`0n0?ooo`<000003`3oool4000000@0W;c_00<000000>Fl[@3U_:d0103U_:d00`0000007cjh01ln
^00701ln^0050000002^Q:P0[XBX0:j4Z00000005`2[R;000`000000oooo0?ooo`020?ooo`030000
003Yc;P0jLbh0180jLbh00<000000:R0Z02XP:P01P2XP:P00`000000lM>b0?7C/P0=0?7C/P030000
003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`000`3o
ool00`000000oooo0?ooo`0k0?ooo`<000004`3oool00`00000001bV000000030000000309blk`00
0000iKb]00D0iKb]00<0000001ln^00O?[P01`0O?[P01@000000[XBX0:j4Z02^Q:P0000001L0ZhR`
00<000000?ooo`3oool00P3oool00`000000jLbh0>W<^00A0>W<^0050000002XP:P0Z82X0:R0Z000
00001P2XP:P00`000000lM>b0?7C/P0<0?7C/P030000003oool0oooo00h0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`040?ooo`000`3oool00`000000oooo0?ooo`0g0?ooo`@00000
5P3oool00`00000001bV000LYP02000LYP<000001@3U_:d2000000X07cjh00D000000:j4Z02^Q:P0
[XBX0000000E0:^8/0030000003oool0oooo0080oooo0P00000B0>W<^080000000D0Z82X00000000
0000YLge000000060:R0Z0030000003adk80lM>b00/0lM>b00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00020?ooo`030000003oool0oooo03D0
oooo0`00000K0?ooo`03000000007:H001bV00@001bV00<000000>Fl[@3U_:d00P3U_:d2000000X0
7cjh00D000000:j4Z02^Q:P0[XBX0000000E0:^8/0030000003oool0oooo0080oooo00<000000>W<
^03Yc;P0403Yc;P4000000@0YLge00<000000:R0Z02XP:P0102XP:P00`000000lM>b0?7C/P0:0?7C
/P030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`040?oo
o`000P3oool00`000000oooo0?ooo`0b0?ooo`<000007P3oool00`00000001bV000LYP04000LYP03
0000003U_:d0iKb]0080iKb]00<0000001ln^00O?[P02P0O?[P01@000000[XBX0:j4Z02^Q:P00000
01@0ZhR`00<000000?ooo`3oool00P3oool00`000000jLbh0>W<^00?0>W<^0<000001`2UcOD00`00
0000Z82X0:R0Z0040:R0Z0030000003adk80lM>b00T0lM>b00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00020?ooo`030000003oool0oooo02l0
oooo0`00000Q0?ooo`03000000007:H001bV00D001bV00D000000>Fl[@3U_:d0iKb]0000000<01ln
^0050000002^Q:P0[XBX0:j4Z00000004`2[R;000`000000oooo0?ooo`030?ooo`030000003Yc;P0
jLbh00h0jLbh0P00000:0:G=m@030000002XP:P0Z82X00@0Z82X00<000000?7C/P3adk80203adk80
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool0
0080oooo00<000000?ooo`3oool0:`3oool4000002D0oooo00<00000000LYP007:H010007:H01@00
0000iKb]0>Fl[@3U_:d0000000d07cjh00D000000:j4Z02^Q:P0[XBX0000000B0:^8/0030000003o
ool0oooo0080oooo00<000000>W<^03Yc;P03`3Yc;P00`000000YLge0:G=m@0:0:G=m@030000002X
P:P0Z82X00@0Z82X00<000000?7C/P3adk801`3adk800`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0103oool00080oooo00<000000?ooo`3oool0:03oool3
000002T0oooo00<00000000LYP007:H010007:H01P000000iKb]0>Fl[@000000oooo000000`07cjh
00D000000:j4Z02^Q:P0[XBX0000000B0:^8/0030000003oool0oooo0080oooo00<000000>W<^03Y
c;P03P3Yc;P00`000000YLge0:G=m@0<0:G=m@030000002XP:P0Z82X00@0Z82X00<000000?7C/P3a
dk801P3adk800`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0103oool00080oooo00<000000?ooo`3oool09@3oool3000002`0oooo00<00000000LYP007:H0
10007:H00`000000iKb]0>Fl[@04000000`07cjh00@000000:j4Z02^Q:P000004P2[R;000`000000
oooo0?ooo`020?ooo`030000003Yc;P0jLbh00d0jLbh0P00000?0:G=m@030000002XP:P0Z82X00<0
Z82X00<000000?7C/P3adk801P3adk800`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0103oool00080oooo00<000000?ooo`3oool08@3oool400000300oooo
00<00000000LYP007:H00`007:H00`000000iKb]0>Fl[@020000000309W6mP000000000000/07cjh
00D000000:j4Z02^Q:P0[XBX0000000@0:^8/0030000003oool0oooo00<0oooo00<000000>W<^03Y
c;P0303Yc;P200000140YLge00<000000:R0Z02XP:P00`2XP:P00`000000lM>b0?7C/P050?7C/P03
0000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`00
00<0oooo0000003oool0803oool3000003@0oooo00<00000000LYP007:H00`007:H00`000000iKb]
0>Fl[@02000000<0VLKf00<0000001ln^00O?[P0200O?[P01@000000[XBX0:j4Z02^Q:P000000100
ZhR`00<000000?ooo`3oool00P3oool00`000000jLbh0>W<^00<0>W<^08000004`2UcOD00`000000
Z82X0:R0Z0030:R0Z0030000003adk80lM>b00@0lM>b00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00000`3oool000000?ooo`0M0?ooo`<00000
=`3oool00`00000001bV000LYP03000LYP030000003U_:d0iKb]00800000102Ia_H00`0000007cjh
01ln^00801ln^0050000002^Q:P000000?ooo`0000003`2[R;000`000000oooo0?ooo`020?ooo`03
0000003Yc;P0jLbh00/0jLbh0P00000D0:G=m@030000002XP:P0Z82X00@0Z82X00<000000?7C/P3a
dk800`3adk800`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool00`3oool000030?ooo`000000oooo01X0oooo0`00000k0?ooo`03000000007:H001bV008001bV
00<000000>Fl[@0000000P00000509W6mP030000000O?[P07cjh00L07cjh1@00000>0:^8/0800000
103oool00`000000jLbh0>W<^00:0>W<^08000005P2UcOD00`000000Z82X0:R0Z0030:R0Z0800000
103adk800`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0`3oool000030?ooo`000000oooo01H0oooo1000000n0?ooo`03000000007:H001bV008001bV00<0
00000>Fl[@0000000P00000609W6mP030000000O?[P07cjh00L07cjh00D000000;]8<02kB300^dP`
0000000=0:^8/0030000003oool0oooo0080oooo00<000000>W<^03Yc;P02P3Yc;P2000001P0YLge
00<000000:R0Z02XP:P00`2XP:P2000000<0lM>b00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00000`3oool000000?ooo`0C0?ooo`<00000@P3o
ool00`00000001bV000LYP02000LYP030000003U_:d00000008000001`2Ia_H00`0000007cjh01ln
^00601ln^0050000002kB300^dP`0;]8<00000003@2[R;000`000000oooo0?ooo`020?ooo`030000
003Yc;P0jLbh00T0jLbh0P00000J0:G=m@8000000`2XP:P00`000000oooo000000020?7C/P030000
003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`0000<0
oooo0000003oool0403oool3000004H0oooo00H00000000LYP007:H001bV0000003U_:d3000000P0
VLKf00<0000001ln^00O?[P01P0O?[P01@000000^dP`0;]8<02kB300000000`0ZhR`00<000000?oo
o`3oool00P3oool00`000000jLbh0>W<^0080>W<^0800000702UcOD3000000070:R0Z0000000oooo
0?ooo`000000lM>b0000000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3o
ool000030?ooo`000000oooo00`0oooo100000190?ooo`04000000007:H001bV00000080iKb]0`00
000909W6mP030000000O?[P07cjh00D07cjh00D000000;]8<02kB300^dP`0000000;0:^8/0800000
0`3oool2000000T0jLbh1P00000J0:G=m@030000003oool00000008000000P3oool2000001`0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000003oool02@3o
ool3000004d0oooo00L00000000LYP007:H000000>Fl[@000000oooo008000002P2Ia_H00`000000
7cjh01ln^00501ln^0050000002kB300^dP`0;]8<00000002P2[R;02000000<0oooo00<000000>W<
^03Yc;P0203Yc;P00`000000oooo0?ooo`030?ooo`T000004P2UcOD010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`02
0?ooo`0000<000000?ooo`3oool01P3oool300000500oooo00L00000000LYP007:H000000>Fl[@00
0000oooo008000002`2Ia_H00`0000007cjh01ln^00401ln^0050000002kB300^dP`0;]8<0000000
2P2[R;0010000000oooo0?ooo`3oool2000000T0jLbh00<000000?ooo`3oool03@3oool9000000X0
YLge00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080
oooo00000`000000oooo0?ooo`020?ooo`@00000E03oool01`00000001bV0000003U_:d000000?oo
o`0000003@2Ia_H00`0000007cjh01ln^00401ln^0050000002kB300^dP`0;]8<00000002@2[R;00
10000000oooo0?ooo`3oool2000000P0jLbh0P00000H0?ooo`P000000`2UcOD00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool000030000003oool0
000000800000F03oool01`00000001bV0000003U_:d000000?ooo`0000003@2Ia_H00`0000007cjh
01ln^00401ln^0050000002kB300^dP`0;]8<0000000202[R;02000000<0oooo0P0000070>W<^080
0000803oool6000002<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00
0P00001K0?ooo`07000000007:H000000>Fl[@000000oooo0000000>09W6mP030000000O?[P07cjh
00@07cjh00D000000;]8<02kB300^dP`000000070:^8/0030000003oool0oooo0080oooo00<00000
0>W<^03Yc;P01@3Yc;P2000004/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02
0?ooo`0000<0oooo000000000000F`3oool300000080oooo00<0000009W6mP2Ia_H03@2Ia_H00`00
00007cjh01ln^00301ln^0050000002kB300^dP`0;]8<00000001`2[R;0010000000oooo0?ooo`3o
ool2000000H0jLbh0P00001=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3o
ool000<0oooo00<000000?ooo`3oool0F03oool300000080oooo00<0000009W6mP2Ia_H02`2Ia_H4
000000D07cjh00D000000;]8<02kB300^dP`000000050:^8/08000000`3oool2000000D0jLbh0P00
001?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool0E`3oool300000080oooo00<0000009W6mP2Ia_H02@2Ia_H2000000@0oooo00<00000
01ln^00O?[P00P0O?[P01@000000^dP`0;]8<02kB300000000D0ZhR`0P0000030?ooo`030000003Y
c;P0jLbh00<0jLbh0P00001A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3o
ool000D0oooo0P00001H0?ooo`050000003oool0oooo0?ooo`000000202Ia_H3000000L0oooo00<0
000001ln^00O?[P00P0O?[P01@000000^dP`0;]8<02kB300000000@0ZhR`00<000000?ooo`3oool0
0P3oool00`000000jLbh0>W<^0020>W<^0800000D`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0040oooo00070?ooo`030000003oool0oooo05D0oooo00D000000?ooo`3oool0oooo
0000000609W6mP8000002`3oool01@0000007cjh01ln^00O?[P0000000<0^dP`00<000000:^8/02[
R;000P2[R;0010000000oooo0?ooo`3oool2000000<0jLbh0P00001E0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool00@3oool000P0oooo0P00001I0?ooo`040000002Ia_H0VLKf09W6
mP<000003P3oool01@0000007cjh01ln^00O?[P0000000<0^dP`00<000000:^8/02[R;000P000003
0?ooo`8000000P3Yc;P2000005H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`01
0?ooo`002P3oool00`000000oooo0?ooo`1F0?ooo`040000002Ia_H0000000000180oooo00@00000
01ln^00O?[P000000`2kB30010000000ZhR`0:^8/00000040?ooo`050000003Yc;P0jLbh0>W<^000
0000F03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0040oooo000;0?ooo`030000
003oool0oooo05D0oooo0P00000E0?ooo`040000000O?[P07cjh000000<0^dP`00<000000:^8/000
0000103oool010000000jLbh0>W<^000001J0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00@3oool000`0oooo0P00001E0?ooo`030000003oool0oooo01D0oooo00<0000001ln^000
00000`2kB3000`000000ZhR`000000030?ooo`80000000<0jLbh000000000000F`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0040oooo000>0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool05P3oool00`0000007cjh000000030;]8<0030000003oool0oooo0080oooo
1000001M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00@3oool000l0oooo0P00
001B0?ooo`030000003oool0oooo01L0oooo0P0000030;]8<0030000003oool0oooo0080oooo0`00
001O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool00140oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0H0?ooo`8000000P2kB3000`000000oooo0?ooo`02
0?ooo`800000H03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo000B0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool06@3oool010000000^dP`0;]8<0000003
0?ooo`800000HP3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool10?ooo`004`3oool20000
04h0oooo00<000000?ooo`3oool06P3oool2000000@0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0;0?ooo`4000000@3oool10?ooo`005@3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0:0?ooo`40
00000@3oool10?ooo`005P3oool2000004X0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`090?ooo`4000000@3oool10?ooo`00603oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0203oool100000040oooo0@3oool001T0oooo0P000017
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0203oool100000040oooo0@3oool0
01/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo
00L0oooo0@0000010?ooo`40oooo000L0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`007@3oool2000004<0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`060?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`00803oool200000400oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`04
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo00@0oooo0@0000010?ooo`008`3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool00`3oool100000040oooo000T0?ooo`800000
?03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`009P3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0940oooo00D000000?ooo`3oool0oooo
000000010?ooo`009`3oool2000003T0oooo00<000000?ooo`3oool0TP3oool010000000oooo0?oo
o`0000010?ooo`00:@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool00@00000002X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo00400000000[0?ooo`800000=@3oool00`000000oooo0?ooo`2D0?oo
o`4000000@3oool100000000;@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo09D0
oooo0P00000002h0oooo0P00000b0?ooo`030000003oool0oooo09@0oooo0`0000000300oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`2@0?ooo`@000000`3oool00340oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2<0?ooo`@000001`3oool00380oooo0P00000^0?oo
o`030000003oool0oooo08P0oooo1000000;0?ooo`00=03oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo08<0oooo1@00000?0?ooo`00=@3oool2000002/0oooo00<000000?ooo`3oool0
O`3oool4000001@0oooo000g0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0N`3o
ool4000001P0oooo000h0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0MP3oool5
000001`0oooo000i0?ooo`8000009`3oool00`000000oooo0?ooo`1b0?ooo`@000008@3oool003/0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1^0?ooo`@000009@3oool003`0oooo
0P00000T0?ooo`030000003oool0oooo06X0oooo1000000Y0?ooo`00?P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo06D0oooo1@00000]0?ooo`00?`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0640oooo1000000b0?ooo`00@03oool200000200oooo00<000000?oo
o`3oool0G@3oool4000003H0oooo00120?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0F03oool5000003X0oooo00130?ooo`8000007@3oool00`000000oooo0?ooo`1D0?ooo`@00000
?`3oool004D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1@0?ooo`@00000@`3o
ool004H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1<0?ooo`@00000A`3oool0
04L0oooo0P00000I0?ooo`030000003oool0oooo04L0oooo1@00001;0?ooo`00B@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04@0oooo1000001@0?ooo`00BP3oool2000001D0oooo
00<000000?ooo`3oool0@03oool4000005@0oooo001<0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?03oool4000005P0oooo001=0?ooo`8000004P3oool00`000000oooo0?ooo`0g
0?ooo`D00000G03oool004l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0c0?oo
o`@00000H@3oool00500oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0_0?ooo`@0
0000I@3oool00540oooo0P00000>0?ooo`030000003oool0oooo02X0oooo1@00001Y0?ooo`00D`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo1000001^0?ooo`00E03oool2
000000/0oooo00<000000?ooo`3oool08P3oool400000780oooo001F0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool07P3oool4000007H0oooo001G0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06@3oool5000007X0oooo001H0?ooo`8000001`3oool00`000000oooo
0?ooo`0E0?ooo`@00000O`3oool005X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0A0?ooo`@00000P`3oool005/0oooo0P0000040?ooo`030000003oool0oooo00`0oooo1@000027
0?ooo`00G@3oool01@000000oooo0?ooo`3oool0000000X0oooo1000002<0?ooo`00GP3oool01000
0000oooo0?ooo`0000060?ooo`@00000T03oool005l0oooo0`0000020?ooo`@00000U03oool00640
oooo0`00002H0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 251.75}, {286.938, 0}} -> {0.0662249, -0.000179953, \
0.00330172, 0.00330172}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[202]="]
}, Closed]],

Cell["\<\
It is easy to make a sequence of plots with different shrinkage \
factors.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(Do[
        Show[dodo\  /. \ p_Polygon \[RuleDelayed] Shrink[p, f], \ 
          PlotRange \[Rule] 2 {{\(-1\), 1}, {\(-1\), 1}, {\(-1\), 1}}], {f, 
          0, 2,  .1}];\)\)], "Input",
  CellLabel->"In[201]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Symbolic\ Mathematical\ Computation\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "It makes sense that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " would be a good system for doing symbolic mathematica computations since \
much of this is done by transformations."
}], "Text"],

Cell["Define a function, log, with rules for sums and multiples.", \
"MathCaption"],

Cell[BoxData[
    \(log[a_\ b_]\  := \ log[a]\  + \ log[b]\)], "Input",
  CellLabel->"In[210]:="],

Cell[BoxData[
    \(log[a_\^b_]\  := \ b\ log[a]\)], "Input",
  CellLabel->"In[211]:="],

Cell["\<\
then evaluating expressions with it will invoke these rules as \
appropriate\
\>", "Text"],

Cell["\<\
Evaluating the expression will invoke the rules if they are \
applicable.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(log[a\ b\ c^d]\)], "Input",
  CellLabel->"In[212]:="],

Cell[BoxData[
    \(log[a] + log[b] + d\ log[c]\)], "Output",
  CellLabel->"Out[212]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Symbolic\ Mathematical\ Computation\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Many symbolic commands work much like we do mathematics using \
pencil and paper: typically, based on the type of expression you have and the \
desired outcome; you try different sorts of transformations until you get \
something that works.  \
\>", "Text"],

Cell["\<\
A simple example of this is the solution of the discrete logistic \
equation\
\>", "Text"],

Cell["Solve the discrete logistic equation.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[x[i + 1]\  == \ 4\ x[i] \((1\  - \ x[i])\), x[i], i]\)], "Input",\

  CellLabel->"In[115]:="],

Cell[BoxData[
    \({{x[i] \[Rule] 1\/2 - 1\/2\ Cos[2\^i\ C[1]]}}\)], "Output",
  CellLabel->"Out[115]="]
}, Open  ]],

Cell["Several transformations are required to get the solution.  ", "Text"],

Cell[TextData[{
  "Make a change of variables, ",
  Cell[BoxData[
      \(TraditionalForm\`x(k) \[Rule] \(sin\^2\)(s(k))\)]],
  " and simplify the result."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[i + 1]\  \[Equal] \ 4\ x[i]\ \((1\  - \ x[i])\)\  /. \ 
      x[k_] \[Rule] Sin[s[k]]^2\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(Sin[s[1 + i]]\^2 \[Equal] 
      4\ Sin[s[i]]\^2\ \((1 - Sin[s[i]]\^2)\)\)], "Output",
  CellLabel->"Out[116]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(Sin[s[1 + i]]\^2 \[Equal] 4\ Cos[s[i]]\^2\ Sin[s[i]]\^2\)], "Output",
  CellLabel->"Out[117]="]
}, Open  ]],

Cell["\<\
Take the square root on both sides of the resulting equation.  \
Symbols without assigned values are assumed to represent complex \
numbers.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Sqrt, \ %]\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(\@Sin[s[1 + i]]\^2 \[Equal] 
      2\ \@\(Cos[s[i]]\^2\ Sin[s[i]]\^2\)\)], "Output",
  CellLabel->"Out[118]="]
}, Open  ]],

Cell["\<\
Expand the powers; this is in general only correct if the arguments \
are real.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PowerExpand[%]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(Sin[s[1 + i]] \[Equal] 2\ Cos[s[i]]\ Sin[s[i]]\)], "Output",
  CellLabel->"Out[119]="]
}, Open  ]],

Cell["\<\
Do a trigonometric reduction on both sides of the equation.  \
TrigReduce rewrites products and powers of trigonometric functions in expr in \
terms of trigonometric functions with combined arguments.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[TrigReduce, \ %]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(Sin[s[1 + i]] \[Equal] Sin[2\ s[i]]\)], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell["\<\
Apply the inverse sine function to each side of the equation and \
use PowerExpand to get the formula valid for real numbers.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PowerExpand[Map[ArcSin, \ %]]\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(s[1 + i] \[Equal] 2\ s[i]\)], "Output",
  CellLabel->"Out[121]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Symbolic\ Mathematical\ Computation\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Piecewise functions provide a mechanism for handling discontinuous \
functions in an automatic way.\
\>", "Text"],

Cell[TextData[{
  "Define p to be a function that has value ",
  Cell[BoxData[
      \(TraditionalForm\`x\ \(sin(x)\)\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  "is positive and 0 otherwise."
}], "MathCaption"],

Cell[BoxData[
    \(p[x_]\  := \ Piecewise[{{x\ Sin[x], Sin[x\^3] > 0}}]\)], "Input",
  CellLabel->"In[106]:="],

Cell["Make a plot of the function.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[p[x], {x, 0, 4}, \ PlotRange \[Rule] All, \ 
        PlotPoints \[Rule] 100];\)\)], "Input",
  CellLabel->"In[108]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.382336 0.121439 [
[.2619 .36984 -3 -9 ]
[.2619 .36984 3 0 ]
[.5 .36984 -3 -9 ]
[.5 .36984 3 0 ]
[.7381 .36984 -3 -9 ]
[.7381 .36984 3 0 ]
[.97619 .36984 -3 -9 ]
[.97619 .36984 3 0 ]
[.01131 .01802 -12 -4.5 ]
[.01131 .01802 0 4.5 ]
[.01131 .13946 -12 -4.5 ]
[.01131 .13946 0 4.5 ]
[.01131 .2609 -12 -4.5 ]
[.01131 .2609 0 4.5 ]
[.01131 .50377 -6 -4.5 ]
[.01131 .50377 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .38234 m
.2619 .38859 L
s
[(1)] .2619 .36984 0 1 Mshowa
.5 .38234 m
.5 .38859 L
s
[(2)] .5 .36984 0 1 Mshowa
.7381 .38234 m
.7381 .38859 L
s
[(3)] .7381 .36984 0 1 Mshowa
.97619 .38234 m
.97619 .38859 L
s
[(4)] .97619 .36984 0 1 Mshowa
.125 Mabswid
.07143 .38234 m
.07143 .38609 L
s
.11905 .38234 m
.11905 .38609 L
s
.16667 .38234 m
.16667 .38609 L
s
.21429 .38234 m
.21429 .38609 L
s
.30952 .38234 m
.30952 .38609 L
s
.35714 .38234 m
.35714 .38609 L
s
.40476 .38234 m
.40476 .38609 L
s
.45238 .38234 m
.45238 .38609 L
s
.54762 .38234 m
.54762 .38609 L
s
.59524 .38234 m
.59524 .38609 L
s
.64286 .38234 m
.64286 .38609 L
s
.69048 .38234 m
.69048 .38609 L
s
.78571 .38234 m
.78571 .38609 L
s
.83333 .38234 m
.83333 .38609 L
s
.88095 .38234 m
.88095 .38609 L
s
.92857 .38234 m
.92857 .38609 L
s
.25 Mabswid
0 .38234 m
1 .38234 L
s
.02381 .01802 m
.03006 .01802 L
s
[(-3)] .01131 .01802 1 0 Mshowa
.02381 .13946 m
.03006 .13946 L
s
[(-2)] .01131 .13946 1 0 Mshowa
.02381 .2609 m
.03006 .2609 L
s
[(-1)] .01131 .2609 1 0 Mshowa
.02381 .50377 m
.03006 .50377 L
s
[(1)] .01131 .50377 1 0 Mshowa
.125 Mabswid
.02381 .04231 m
.02756 .04231 L
s
.02381 .06659 m
.02756 .06659 L
s
.02381 .09088 m
.02756 .09088 L
s
.02381 .11517 m
.02756 .11517 L
s
.02381 .16375 m
.02756 .16375 L
s
.02381 .18803 m
.02756 .18803 L
s
.02381 .21232 m
.02756 .21232 L
s
.02381 .23661 m
.02756 .23661 L
s
.02381 .28518 m
.02756 .28518 L
s
.02381 .30947 m
.02756 .30947 L
s
.02381 .33376 m
.02756 .33376 L
s
.02381 .35805 m
.02756 .35805 L
s
.02381 .40662 m
.02756 .40662 L
s
.02381 .43091 m
.02756 .43091 L
s
.02381 .4552 m
.02756 .4552 L
s
.02381 .47949 m
.02756 .47949 L
s
.02381 .52806 m
.02756 .52806 L
s
.02381 .55235 m
.02756 .55235 L
s
.02381 .57664 m
.02756 .57664 L
s
.02381 .60093 m
.02756 .60093 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .38234 m
.02409 .38234 L
.02435 .38234 L
.02465 .38234 L
.02494 .38234 L
.02544 .38234 L
.02599 .38235 L
.02659 .38235 L
.02722 .38236 L
.02837 .38238 L
.02955 .38241 L
.03066 .38244 L
.03318 .38252 L
.03575 .38264 L
.0381 .38277 L
.04339 .38316 L
.04799 .38359 L
.05302 .38416 L
.06287 .38559 L
.07236 .38735 L
.08244 .38962 L
.09215 .3922 L
.1015 .39504 L
.11144 .39842 L
.12101 .40202 L
.13021 .40579 L
.14001 .41013 L
.14945 .4146 L
.15947 .41966 L
.16913 .42482 L
.17842 .43002 L
.18831 .4358 L
.19783 .44158 L
.20698 .44733 L
.21673 .45362 L
.22611 .45983 L
.23608 .46657 L
.24569 .47318 L
.25492 .47962 L
.26476 .48654 L
.27422 .49323 L
.28428 .50037 L
.29398 .50724 L
.3033 .5138 L
.31322 .52073 L
.32277 .52731 L
.33196 .53353 L
.34174 .54002 L
.35115 .5461 L
.36115 .55236 L
Mistroke
.36616 .55541 L
.36859 .55687 L
.37079 .55817 L
.37133 .55849 L
.37191 .55883 L
.3722 .55901 L
.37237 .55911 L
.37253 .38234 L
.37281 .38234 L
.37311 .38234 L
.37339 .38234 L
.37369 .38234 L
.37398 .38234 L
.37425 .38234 L
.37449 .38234 L
.37475 .38234 L
.37503 .38234 L
.37528 .38234 L
.37556 .38234 L
.37587 .38234 L
.37619 .38234 L
.37649 .38234 L
.37677 .38234 L
.37702 .38234 L
.37731 .38234 L
.37759 .38234 L
.37789 .38234 L
.37821 .38234 L
.37848 .38234 L
.37878 .38234 L
.37894 .38234 L
.3791 .38234 L
.37927 .38234 L
.37944 .38234 L
.37974 .38234 L
.37991 .38234 L
.38007 .38234 L
.38035 .38234 L
.38065 .38234 L
.38091 .38234 L
.38119 .38234 L
.38149 .38234 L
.38166 .38234 L
.38181 .38234 L
.38211 .38234 L
.3824 .38234 L
.38266 .38234 L
.38294 .38234 L
.38318 .38234 L
.38345 .38234 L
Mistroke
.38373 .38234 L
.38403 .38234 L
.38432 .38234 L
.38458 .38234 L
.38489 .38234 L
.38506 .38234 L
.38522 .38234 L
.38552 .38234 L
.38581 .38234 L
.38597 .38234 L
.38614 .38234 L
.38645 .38234 L
.38662 .38234 L
.38678 .38234 L
.38696 .38234 L
.38714 .38234 L
.38746 .38234 L
.38763 .38234 L
.3878 .38234 L
.3881 .38234 L
.38842 .38234 L
.3887 .38234 L
.38897 .38234 L
.38926 .38234 L
.38958 .38234 L
.38988 .38234 L
.39016 .38234 L
.39048 .38234 L
.39078 .38234 L
.39106 .38234 L
.39132 .38234 L
.3916 .38234 L
.3919 .38234 L
.3922 .38234 L
.39237 .38234 L
.39252 .38234 L
.39282 .38234 L
.39311 .38234 L
.39327 .38234 L
.39344 .38234 L
.39374 .38234 L
.39393 .38234 L
.39411 .38234 L
.39427 .38234 L
.39444 .38234 L
.39476 .38234 L
.39506 .38234 L
.39523 .38234 L
.39539 .38234 L
.39557 .38234 L
Mistroke
.39574 .38234 L
.3959 .38234 L
.39608 .38234 L
.39639 .38234 L
.39657 .38234 L
.39673 .38234 L
.39691 .38234 L
.39711 .38234 L
.39742 .38234 L
.3976 .38234 L
.39776 .38234 L
.39806 .38234 L
.39823 .38234 L
.39838 .38234 L
.39867 .38234 L
.39899 .38234 L
.39928 .38234 L
.39955 .38234 L
.39986 .38234 L
.40015 .38234 L
.40041 .38234 L
.40069 .38234 L
.401 .38234 L
.40116 .38234 L
.40133 .38234 L
.40163 .38234 L
.40191 .38234 L
.40218 .38234 L
.40247 .38234 L
.40271 .38234 L
.40297 .38234 L
.40326 .38234 L
.40357 .38234 L
.40385 .38234 L
.40412 .38234 L
.40443 .38234 L
.40459 .38234 L
.40476 .38234 L
.40507 .38234 L
.40535 .38234 L
.40552 .38234 L
.40569 .38234 L
.406 .38234 L
.40617 .38234 L
.40633 .38234 L
.40651 .38234 L
.40669 .38234 L
.40701 .38234 L
.40719 .38234 L
.40735 .38234 L
Mistroke
.40765 .38234 L
.40797 .38234 L
.40825 .38234 L
.40852 .38234 L
.40881 .38234 L
.40912 .38234 L
.40942 .38234 L
.40959 .38234 L
.40975 .38234 L
.41007 .38234 L
.41024 .38234 L
.41041 .38234 L
.41068 .38234 L
.41099 .38234 L
.4113 .38234 L
.4116 .38234 L
.41176 .38234 L
.41195 .38234 L
.41212 .38234 L
.41228 .38234 L
.41258 .38234 L
.41289 .38234 L
.41306 .38234 L
.41324 .38234 L
.41356 .38234 L
.41375 .38234 L
.41393 .38234 L
.4141 .38234 L
.41428 .38234 L
.41458 .38234 L
.41486 .38234 L
.41517 .38234 L
.41535 .38234 L
.41551 .38234 L
.41581 .38234 L
.41598 .38234 L
.41614 .38234 L
.41631 .38234 L
.41647 .38234 L
.41665 .38234 L
.41681 .38234 L
.4171 .38234 L
.4174 .38234 L
.41766 .38234 L
.41794 .38234 L
.41824 .38234 L
.41841 .38234 L
.41857 .38234 L
.41887 .38234 L
.41916 .38234 L
Mistroke
.41946 .38234 L
.41963 .38234 L
.41979 .38234 L
.42008 .38234 L
.42038 .38234 L
.42065 .38234 L
.42091 .38234 L
.42119 .38234 L
.42149 .38234 L
.4218 .38234 L
.42198 .38234 L
.42215 .38234 L
.42246 .38234 L
.42261 .38234 L
.42278 .38234 L
.42308 .38234 L
.42339 .38234 L
.42369 .38234 L
.42396 .38234 L
.42422 .38234 L
.4245 .38234 L
.42476 .38234 L
.425 .38234 L
.42528 .38234 L
.42558 .38234 L
.42587 .38234 L
.42614 .38234 L
.42641 .38234 L
.42666 .38234 L
.42694 .38234 L
.42725 .38234 L
.42756 .38234 L
.42786 .38234 L
.42813 .38234 L
.42842 .38234 L
.42858 .38234 L
.42875 .38234 L
.42904 .38234 L
.42936 .38234 L
.42955 .38234 L
.42971 .38234 L
.43002 .38234 L
.4303 .38234 L
.43046 .38234 L
.43062 .38234 L
.43093 .38234 L
.4312 .38234 L
.4315 .38234 L
.43182 .38234 L
.43211 .38234 L
Mistroke
.43239 .38234 L
.43264 .38234 L
.43293 .38234 L
.4332 .38234 L
.43352 .38234 L
.43381 .38234 L
.43397 .38234 L
.43415 .38234 L
.43446 .38234 L
.43476 .38234 L
.43507 .38234 L
.43534 .38234 L
.43563 .38234 L
.43581 .38234 L
.43598 .38234 L
.4363 .38234 L
.43647 .38234 L
.43664 .38234 L
.43682 .38234 L
.43701 .38234 L
.43732 .38234 L
.43762 .38234 L
.43779 .38234 L
.43794 .38234 L
.43811 .38234 L
.43829 .38234 L
.43859 .38234 L
.43876 .38234 L
.43891 .38234 L
.4392 .38234 L
.4395 .38234 L
.43977 .38234 L
.44002 .38234 L
.4403 .38234 L
.4406 .38234 L
.44092 .38234 L
.4411 .38234 L
.44126 .38234 L
.44157 .38234 L
.44174 .38234 L
.44189 .38234 L
.44218 .38234 L
.4425 .38234 L
.4428 .38234 L
.44307 .38234 L
.44333 .38234 L
.44361 .38234 L
.44387 .38234 L
.4441 .38234 L
.44438 .38234 L
Mistroke
.44469 .38234 L
.44497 .38234 L
.44524 .38234 L
.44551 .38234 L
.44576 .38234 L
.44604 .38234 L
.44634 .38234 L
.44664 .38234 L
.44696 .38234 L
.44723 .38234 L
.44752 .38234 L
.44784 .38234 L
.44814 .38234 L
.44829 .38234 L
.44846 .38234 L
.44864 .38234 L
.44881 .38234 L
.44911 .38234 L
.44939 .38234 L
.44954 .38234 L
.44971 .38234 L
.45002 .38234 L
.45032 .38234 L
.45059 .38234 L
.4509 .38234 L
.45119 .38234 L
.45146 .38234 L
.45172 .38234 L
.45199 .38234 L
.45228 .38234 L
.4526 .38234 L
.45289 .38234 L
.45305 .38234 L
.45322 .38234 L
.45354 .38234 L
.45383 .38234 L
.45414 .38234 L
.45441 .38234 L
.45471 .38234 L
.45488 .38234 L
.45505 .38234 L
.45537 .38234 L
.45554 .38234 L
.45571 .38234 L
.45589 .38234 L
.45608 .38234 L
.45624 .38234 L
.45642 .38234 L
.45659 .38234 L
.45675 .38234 L
Mistroke
.45705 .38234 L
.45736 .38234 L
.45766 .38234 L
.45782 .38234 L
.45798 .38234 L
.45826 .38234 L
.45856 .38234 L
.45883 .38234 L
.45908 .38234 L
.45936 .38234 L
.45966 .38234 L
.45996 .38234 L
.46013 .38234 L
.46028 .38234 L
.4606 .38234 L
.46078 .38234 L
.46094 .38234 L
.46123 .38234 L
.46155 .38234 L
.46185 .38234 L
.46212 .38234 L
.46238 .38234 L
.46265 .38234 L
.46291 .38234 L
.46315 .38234 L
.46343 .5981 L
.46373 .59817 L
.46428 .5983 L
.46657 .59881 L
.47643 .60072 L
.48593 .60208 L
.49113 .60261 L
.49351 .60281 L
.49602 .60298 L
.49835 .60311 L
.49958 .60317 L
.5009 .60322 L
.50211 .60325 L
.50322 .60328 L
.50375 .60329 L
.50433 .6033 L
.50487 .60331 L
.50538 .60331 L
.50565 .60331 L
.50595 .60332 L
.50624 .60332 L
.50656 .60332 L
.50683 .60332 L
.50713 .60332 L
.50741 .60332 L
Mistroke
.50766 .60332 L
.50799 .60332 L
.50828 .60331 L
.50896 .60331 L
.50955 .6033 L
.51018 .60329 L
.51143 .60326 L
.51261 .60322 L
.51528 .60311 L
.5178 .60297 L
.5202 .6028 L
.52234 .60261 L
.52356 .6025 L
.5247 .60238 L
.52582 .60226 L
.52613 .60222 L
.52645 .60219 L
.52673 .60215 L
.52703 .38234 L
.5272 .38234 L
.52736 .38234 L
.52766 .38234 L
.52798 .38234 L
.52815 .38234 L
.52832 .38234 L
.5286 .38234 L
.5289 .38234 L
.52922 .38234 L
.52952 .38234 L
.52979 .38234 L
.53009 .38234 L
.53038 .38234 L
.53064 .38234 L
.5309 .38234 L
.53114 .38234 L
.53141 .38234 L
.53167 .38234 L
.53195 .38234 L
.53225 .38234 L
.5325 .38234 L
.53278 .38234 L
.53308 .38234 L
.53325 .38234 L
.5334 .38234 L
.5337 .38234 L
.53398 .38234 L
.53426 .38234 L
.53456 .38234 L
.53484 .38234 L
.5351 .38234 L
Mistroke
.53538 .38234 L
.53569 .38234 L
.53585 .38234 L
.53602 .38234 L
.53632 .38234 L
.53649 .38234 L
.53665 .38234 L
.53682 .38234 L
.53699 .38234 L
.5373 .38234 L
.53747 .38234 L
.53763 .38234 L
.53793 .38234 L
.5382 .38234 L
.53851 .38234 L
.53881 .38234 L
.53909 .38234 L
.53935 .38234 L
.53964 .38234 L
.53992 .38234 L
.54018 .38234 L
.54041 .38234 L
.54067 .38234 L
.54095 .38234 L
.54123 .38234 L
.54152 .38234 L
.5418 .38234 L
.54206 .38234 L
.54236 .38234 L
.54253 .38234 L
.54269 .38234 L
.54297 .38234 L
.54328 .38234 L
.54357 .38234 L
.54389 .38234 L
.54419 .38234 L
.54447 .38234 L
.54474 .38234 L
.54499 .38234 L
.54528 .38234 L
.54556 .38234 L
.54586 .38234 L
.54617 .38234 L
.54644 .38234 L
.54674 .38234 L
.54705 .38234 L
.54723 .38234 L
.54739 .38234 L
.54771 .38234 L
.54801 .38234 L
Mistroke
.54826 .38234 L
.54854 .38234 L
.54884 .38234 L
.54911 .38234 L
.54937 .38234 L
.5496 .38234 L
.54986 .38234 L
.55013 .38234 L
.55041 .38234 L
.55071 .38234 L
.55098 .38234 L
.55124 .38234 L
.55154 .38234 L
.5517 .38234 L
.55186 .38234 L
.55214 .38234 L
.55245 .38234 L
.55274 .38234 L
.55306 .38234 L
.55336 .38234 L
.55364 .38234 L
.55392 .38234 L
.55417 .38234 L
.55446 .38234 L
.55473 .38234 L
.55503 .38234 L
.55535 .38234 L
.55562 .38234 L
.55591 .38234 L
.55623 .38234 L
.55641 .38234 L
.55657 .38234 L
.55689 .38234 L
.55719 .38234 L
.55744 .38234 L
.55772 .38234 L
.55802 .38234 L
.55829 .38234 L
.55855 .38234 L
.55878 .38234 L
.55904 .38234 L
.55931 .38234 L
.55959 .38234 L
.55989 .38234 L
.56017 .38234 L
.56042 .38234 L
.56072 .38234 L
.56089 .38234 L
.56104 .38234 L
.56133 .38234 L
Mistroke
.56163 .38234 L
.56192 .38234 L
.56224 .38234 L
.56254 .38234 L
.56282 .38234 L
.56308 .38234 L
.56335 .38234 L
.56365 .38234 L
.56392 .38234 L
.56422 .38234 L
.56453 .38234 L
.56481 .38234 L
.5651 .38234 L
.56542 .38234 L
.5656 .38234 L
.56576 .38234 L
.56608 .38234 L
.56638 .38234 L
.56663 .38234 L
.56692 .38234 L
.56721 .38234 L
.56749 .38234 L
.56774 .38234 L
.56798 .38234 L
.56825 .38234 L
.56851 .38234 L
.56879 .38234 L
.56908 .38234 L
.56936 .38234 L
.56961 .38234 L
.56991 .38234 L
.57008 .38234 L
.57023 .38234 L
.57052 .38234 L
.57082 .38234 L
.57112 .38234 L
.57128 .38234 L
.57144 .38234 L
.57172 .38234 L
.57202 .38234 L
.57229 .38234 L
.57254 .38234 L
.57282 .38234 L
.57312 .38234 L
.57342 .38234 L
.57359 .38234 L
.57374 .38234 L
.57406 .38234 L
.57424 .38234 L
.5744 .38234 L
Mistroke
.57469 .38234 L
.57501 .38234 L
.57531 .38234 L
.57558 .38234 L
.57584 .38234 L
.57611 .38234 L
.57637 .38234 L
.57661 .38234 L
.57689 .38234 L
.57719 .38234 L
.57748 .58807 L
.57774 .58796 L
.58003 .58693 L
.58953 .58228 L
.59962 .57669 L
.60935 .57067 L
.61381 .56769 L
.61634 .56594 L
.61758 .56508 L
.6187 .56428 L
.61928 .56386 L
.61958 .56365 L
.61975 .56353 L
.61991 .56341 L
.62019 .38234 L
.6205 .38234 L
.62076 .38234 L
.62104 .38234 L
.62135 .38234 L
.62152 .38234 L
.62168 .38234 L
.62185 .38234 L
.62201 .38234 L
.62218 .38234 L
.62235 .38234 L
.62265 .38234 L
.62293 .38234 L
.62323 .38234 L
.62355 .38234 L
.62387 .38234 L
.62416 .38234 L
.62432 .38234 L
.62449 .38234 L
.62481 .38234 L
.6251 .38234 L
.62542 .38234 L
.62569 .38234 L
.62598 .38234 L
.62615 .38234 L
.62633 .38234 L
Mistroke
.62665 .38234 L
.62682 .38234 L
.62699 .38234 L
.62717 .38234 L
.62736 .38234 L
.62753 .38234 L
.62771 .38234 L
.62788 .38234 L
.62804 .38234 L
.62834 .38234 L
.62866 .38234 L
.62895 .38234 L
.62927 .38234 L
.62957 .38234 L
.62985 .38234 L
.63013 .38234 L
.63038 .38234 L
.63067 .38234 L
.63094 .38234 L
.63124 .38234 L
.63156 .38234 L
.63183 .38234 L
.63212 .38234 L
.63244 .38234 L
.63262 .38234 L
.63278 .38234 L
.6331 .38234 L
.6334 .38234 L
.63365 .38234 L
.63393 .38234 L
.63423 .38234 L
.6345 .38234 L
.63476 .38234 L
.63499 .38234 L
.63525 .38234 L
.63552 .38234 L
.6358 .38234 L
.6361 .38234 L
.63638 .38234 L
.63663 .38234 L
.63693 .38234 L
.63709 .38234 L
.63725 .38234 L
.63753 .38234 L
.63784 .38234 L
.63813 .38234 L
.63845 .38234 L
.63875 .38234 L
.63903 .38234 L
.63931 .38234 L
Mistroke
.63956 .38234 L
.63985 .38234 L
.64013 .38234 L
.64043 .38234 L
.64074 .38234 L
.64101 .38234 L
.64131 .38234 L
.64163 .38234 L
.64181 .38234 L
.64197 .38234 L
.64229 .38234 L
.64258 .38234 L
.64284 .38234 L
.64312 .38234 L
.64342 .38234 L
.64369 .38234 L
.64395 .38234 L
.64418 .38234 L
.64446 .38234 L
.64471 .38234 L
.64499 .38234 L
.64529 .38234 L
.64557 .38234 L
.64582 .38234 L
.64612 .38234 L
.64629 .38234 L
.64644 .38234 L
.64673 .38234 L
.64703 .38234 L
.64732 .38234 L
.64749 .38234 L
.64764 .38234 L
.64793 .38234 L
.64823 .38234 L
.6485 .38234 L
.64875 .38234 L
.64902 .38234 L
.64932 .38234 L
.64962 .38234 L
.64979 .38234 L
.64995 .38234 L
.65027 .38234 L
.65044 .38234 L
.65061 .38234 L
.6509 .38234 L
.65121 .38234 L
.65151 .38234 L
.65178 .38234 L
.65204 .38234 L
.65232 .38234 L
Mistroke
.65258 .38234 L
.65281 .38234 L
.65309 .38234 L
.65339 .38234 L
.65368 .38234 L
.65394 .38234 L
.65424 .38234 L
.65452 .38234 L
.65478 .38234 L
.65505 .38234 L
.65535 .38234 L
.65566 .38234 L
.65593 .38234 L
.65623 .38234 L
.65655 .38234 L
.65684 .38234 L
.65699 .38234 L
.65716 .38234 L
.65734 .38234 L
.6575 .53161 L
.65781 .53132 L
.65808 .53105 L
.65871 .53044 L
.66097 .52822 L
.66604 .52311 L
.67566 .51298 L
.6849 .50269 L
.68735 .49988 L
.68856 .49848 L
.68967 .49719 L
.69029 .49646 L
.6906 .4961 L
.69078 .49589 L
.69094 .38234 L
.69112 .38234 L
.69129 .38234 L
.69161 .38234 L
.69179 .38234 L
.69196 .38234 L
.69214 .38234 L
.69233 .38234 L
.69261 .38234 L
.69292 .38234 L
.69321 .38234 L
.69348 .38234 L
.69377 .38234 L
.69394 .38234 L
.6941 .38234 L
.69441 .38234 L
.69459 .38234 L
Mistroke
.69475 .38234 L
.69504 .38234 L
.69531 .38234 L
.6956 .38234 L
.69592 .38234 L
.69608 .38234 L
.69625 .38234 L
.69657 .38234 L
.69688 .38234 L
.69716 .38234 L
.69745 .38234 L
.69773 .38234 L
.69797 .38234 L
.69824 .38234 L
.69853 .38234 L
.69884 .38234 L
.6991 .38234 L
.69939 .38234 L
.69955 .38234 L
.69973 .38234 L
.70005 .38234 L
.70036 .38234 L
.70065 .38234 L
.70096 .38234 L
.70114 .38234 L
.7013 .38234 L
.70148 .38234 L
.70164 .38234 L
.70181 .38234 L
.702 .38234 L
.70229 .38234 L
.7026 .38234 L
.70289 .38234 L
.70316 .38234 L
.70347 .38234 L
.70365 .38234 L
.70381 .38234 L
.70411 .38234 L
.70443 .38234 L
.70472 .38234 L
.70504 .38234 L
.70535 .38234 L
.70563 .38234 L
.7059 .38234 L
.70616 .38234 L
.70645 .38234 L
.70672 .38234 L
.70702 .38234 L
.70733 .38234 L
.7076 .38234 L
Mistroke
.7079 .38234 L
.70822 .38234 L
.7084 .38234 L
.70856 .38234 L
.70888 .38234 L
.70918 .38234 L
.70943 .38234 L
.70971 .38234 L
.71001 .38234 L
.71028 .38234 L
.71054 .38234 L
.71078 .38234 L
.71105 .38234 L
.71131 .38234 L
.71158 .38234 L
.71188 .38234 L
.71216 .38234 L
.71241 .38234 L
.71271 .38234 L
.71288 .38234 L
.71303 .38234 L
.71332 .38234 L
.71362 .38234 L
.71391 .38234 L
.71408 .38234 L
.71423 .38234 L
.71452 .38234 L
.71482 .38234 L
.71509 .38234 L
.71534 .38234 L
.71561 .38234 L
.71591 .38234 L
.71621 .38234 L
.71638 .38234 L
.71654 .38234 L
.71686 .38234 L
.71703 .38234 L
.7172 .38234 L
.71749 .38234 L
.7178 .38234 L
.7181 .38234 L
.71837 .38234 L
.71863 .38234 L
.7189 .38234 L
.71916 .38234 L
.7194 .38234 L
.71968 .38234 L
.71998 .38234 L
.72027 .38234 L
.72053 .38234 L
Mistroke
.72083 .38234 L
.72111 .38234 L
.72137 .45715 L
.72164 .45678 L
.72282 .45518 L
.73276 .44137 L
.73772 .43429 L
.74234 .42757 L
.74463 .42421 L
.74679 .42101 L
.74799 .41923 L
.74831 .41874 L
.74866 .41822 L
.74896 .41777 L
.74913 .41752 L
.74929 .38234 L
.74956 .38234 L
.74986 .38234 L
.75011 .38234 L
.75038 .38234 L
.75067 .38234 L
.75099 .38234 L
.75129 .38234 L
.75156 .38234 L
.75185 .38234 L
.75212 .38234 L
.75242 .38234 L
.75274 .38234 L
.7529 .38234 L
.75307 .38234 L
.75339 .38234 L
.7537 .38234 L
.75398 .38234 L
.75427 .38234 L
.75455 .38234 L
.7548 .38234 L
.75506 .38234 L
.75536 .38234 L
.75566 .38234 L
.75593 .38234 L
.75621 .38234 L
.75638 .38234 L
.75655 .38234 L
.75672 .38234 L
.75687 .38234 L
.75717 .38234 L
.75748 .38234 L
.75764 .38234 L
.75781 .38234 L
.75812 .38234 L
Mistroke
.75831 .38234 L
.75849 .38234 L
.75865 .38234 L
.75883 .38234 L
.75915 .38234 L
.75944 .38234 L
.7596 .38234 L
.75977 .38234 L
.76009 .38234 L
.76038 .38234 L
.7607 .38234 L
.76096 .38234 L
.76126 .38234 L
.76157 .38234 L
.76187 .38234 L
.76202 .38234 L
.76219 .38234 L
.76236 .38234 L
.76253 .38234 L
.76283 .38234 L
.76311 .38234 L
.76341 .38234 L
.76373 .38234 L
.764 .38234 L
.76429 .38234 L
.76456 .38234 L
.76481 .38234 L
.7651 .38234 L
.76541 .38234 L
.76571 .38234 L
.76599 .38234 L
.76628 .38234 L
.76659 .38234 L
.76689 .38234 L
.76716 .38234 L
.76748 .38234 L
.76766 .38234 L
.76782 .38234 L
.76813 .38234 L
.7683 .38234 L
.76845 .38234 L
.76861 .38234 L
.76879 .38234 L
.7691 .38234 L
.76927 .38234 L
.76943 .38234 L
.7696 .38234 L
.76979 .38234 L
.76996 .38234 L
.77013 .38234 L
Mistroke
.7703 .38234 L
.77045 .38234 L
.77075 .38234 L
.77106 .38234 L
.77133 .38234 L
.77164 .38234 L
.77195 .38234 L
.77225 .38234 L
.77252 .38234 L
.77277 .38234 L
.77306 .38234 L
.77333 .38234 L
.77363 .38234 L
.77395 .38234 L
.77422 .38234 L
.77451 .38234 L
.77483 .38234 L
.77501 .38234 L
.77517 .37692 L
.77549 .37641 L
.77579 .37593 L
.78022 .36871 L
.7895 .35334 L
.79429 .34528 L
.79671 .34118 L
.79737 .34005 L
.79809 .33883 L
.79842 .33827 L
.79876 .33768 L
.79906 .33718 L
.79923 .33689 L
.79938 .38234 L
.79969 .38234 L
.79985 .38234 L
.80002 .38234 L
.80032 .38234 L
.8006 .38234 L
.80078 .38234 L
.80094 .38234 L
.80124 .38234 L
.80141 .38234 L
.80157 .38234 L
.80174 .38234 L
.80193 .38234 L
.80224 .38234 L
.80242 .38234 L
.80258 .38234 L
.80288 .38234 L
.80319 .38234 L
.80347 .38234 L
Mistroke
.80374 .38234 L
.80403 .38234 L
.80434 .38234 L
.80464 .38234 L
.80492 .38234 L
.80522 .38234 L
.80538 .38234 L
.80555 .38234 L
.80583 .38234 L
.80614 .38234 L
.80643 .38234 L
.80669 .38234 L
.80695 .38234 L
.80719 .38234 L
.80746 .38234 L
.80774 .38234 L
.80804 .38234 L
.80832 .38234 L
.80857 .38234 L
.80884 .38234 L
.80914 .38234 L
.80941 .38234 L
.80973 .38234 L
.81003 .38234 L
.8103 .38234 L
.81056 .38234 L
.81084 .38234 L
.81114 .38234 L
.81131 .38234 L
.81147 .38234 L
.81164 .38234 L
.81182 .38234 L
.81213 .38234 L
.8123 .38234 L
.81246 .38234 L
.81277 .38234 L
.81304 .38234 L
.81336 .38234 L
.81366 .38234 L
.81396 .38234 L
.81412 .38234 L
.81428 .38234 L
.81459 .38234 L
.81477 .38234 L
.81493 .38234 L
.81522 .38234 L
.81554 .38234 L
.81583 .38234 L
.81611 .38234 L
.81627 .38234 L
Mistroke
.81646 .38234 L
.81663 .38234 L
.81678 .38234 L
.81708 .38234 L
.81739 .38234 L
.81756 .38234 L
.81773 .38234 L
.81805 .38234 L
.81824 .38234 L
.81842 .38234 L
.81859 .38234 L
.81876 .38234 L
.81906 .38234 L
.81933 .38234 L
.81963 .38234 L
.81994 .38234 L
.82021 .38234 L
.82047 .38234 L
.82074 .38234 L
.82104 .38234 L
.82121 .38234 L
.82137 .38234 L
.82154 .38234 L
.82172 .38234 L
.82202 .38234 L
.8222 .2968 L
.82236 .29651 L
.82356 .29438 L
.82865 .28527 L
.83806 .26827 L
.84051 .2638 L
.84181 .26144 L
.84252 .26014 L
.84287 .2595 L
.84319 .25892 L
.8435 .25835 L
.84365 .25806 L
.84382 .38234 L
.844 .38234 L
.84418 .38234 L
.84435 .38234 L
.84451 .38234 L
.84481 .38234 L
.84498 .38234 L
.84513 .38234 L
.84541 .38234 L
.84571 .38234 L
.84599 .38234 L
.84629 .38234 L
.84657 .38234 L
Mistroke
.84683 .38234 L
.84712 .38234 L
.84743 .38234 L
.84759 .38234 L
.84776 .38234 L
.84806 .38234 L
.84836 .38234 L
.84853 .38234 L
.84869 .38234 L
.84886 .38234 L
.84901 .38234 L
.84919 .38234 L
.84935 .38234 L
.84965 .38234 L
.84992 .38234 L
.85023 .38234 L
.85055 .38234 L
.85086 .38234 L
.85104 .38234 L
.85121 .38234 L
.85151 .38234 L
.85183 .38234 L
.852 .38234 L
.85218 .38234 L
.85235 .38234 L
.8525 .38234 L
.85268 .38234 L
.85288 .38234 L
.85307 .38234 L
.85324 .38234 L
.85352 .38234 L
.85382 .38234 L
.85411 .38234 L
.85437 .38234 L
.85467 .38234 L
.85485 .38234 L
.85501 .38234 L
.8553 .38234 L
.85561 .38234 L
.85578 .38234 L
.85594 .38234 L
.85611 .38234 L
.85629 .38234 L
.8566 .38234 L
.85677 .38234 L
.85693 .38234 L
.85723 .38234 L
.85751 .38234 L
.85783 .38234 L
.85813 .38234 L
Mistroke
.8584 .38234 L
.8587 .38234 L
.85898 .38234 L
.85924 .38234 L
.85953 .38234 L
.85984 .38234 L
.86 .38234 L
.86017 .38234 L
.86047 .38234 L
.86064 .38234 L
.86079 .38234 L
.86096 .38234 L
.86114 .38234 L
.86144 .38234 L
.86161 .38234 L
.86177 .38234 L
.86207 .38234 L
.86234 .38234 L
.86266 .38234 L
.86296 .38234 L
.86324 .38234 L
.86349 .38234 L
.86379 .38234 L
.86406 .38234 L
.86432 .21992 L
.86456 .21948 L
.86509 .21849 L
.86742 .21415 L
.87238 .2049 L
.87701 .19626 L
.8793 .19197 L
.88146 .18792 L
.88266 .18568 L
.88298 .18507 L
.88333 .18442 L
.88363 .18386 L
.8838 .18355 L
.88396 .38234 L
.88423 .38234 L
.88453 .38234 L
.88478 .38234 L
.88505 .38234 L
.88535 .38234 L
.88566 .38234 L
.88596 .38234 L
.88623 .38234 L
.88652 .38234 L
.88679 .38234 L
.88709 .38234 L
.88741 .38234 L
Mistroke
.88757 .38234 L
.88774 .38234 L
.88806 .38234 L
.88837 .38234 L
.88865 .38234 L
.88892 .38234 L
.88917 .38234 L
.88944 .38234 L
.88974 .38234 L
.89003 .38234 L
.89034 .38234 L
.8906 .38234 L
.89089 .38234 L
.89105 .38234 L
.89123 .38234 L
.8914 .38234 L
.89155 .38234 L
.89184 .38234 L
.89215 .38234 L
.89231 .38234 L
.89248 .38234 L
.89279 .38234 L
.89298 .38234 L
.89316 .38234 L
.89333 .38234 L
.8935 .38234 L
.89382 .38234 L
.89411 .38234 L
.89427 .38234 L
.89445 .38234 L
.89476 .38234 L
.89506 .38234 L
.89537 .38234 L
.89564 .38234 L
.89593 .38234 L
.89625 .38234 L
.89654 .38234 L
.8967 .38234 L
.89687 .38234 L
.89704 .38234 L
.89721 .38234 L
.89751 .38234 L
.89779 .38234 L
.89809 .38234 L
.89841 .38234 L
.89868 .38234 L
.89897 .38234 L
.89924 .38234 L
.89949 .38234 L
.89978 .38234 L
Mistroke
.9001 .38234 L
.90039 .38234 L
.90067 .38234 L
.90096 .38234 L
.90128 .38234 L
.90157 .38234 L
.90184 .38234 L
.90216 .38234 L
.90234 .38234 L
.9025 .38234 L
.90281 .14792 L
.90298 .1476 L
.90313 .14732 L
.90574 .14244 L
.91081 .13296 L
.91547 .12427 L
.91783 .11988 L
.91898 .11774 L
.91949 .11681 L
.92003 .1158 L
.92033 .11525 L
.9206 .38234 L
.92086 .38234 L
.92114 .38234 L
.92143 .38234 L
.9217 .38234 L
.922 .38234 L
.92217 .38234 L
.92232 .38234 L
.92264 .38234 L
.92294 .38234 L
.92311 .38234 L
.92327 .38234 L
.92344 .38234 L
.92361 .38234 L
.92392 .38234 L
.9242 .38234 L
.92451 .38234 L
.92467 .38234 L
.92484 .38234 L
.92515 .38234 L
.92545 .38234 L
.9256 .38234 L
.92577 .38234 L
.92594 .38234 L
.92611 .38234 L
.92641 .38234 L
.92669 .38234 L
.92699 .38234 L
.92731 .38234 L
Mistroke
.92758 .38234 L
.92787 .38234 L
.92814 .38234 L
.92839 .38234 L
.92868 .38234 L
.92899 .38234 L
.92929 .38234 L
.92957 .38234 L
.92986 .38234 L
.93017 .38234 L
.93047 .38234 L
.93074 .38234 L
.93105 .38234 L
.93123 .38234 L
.9314 .38234 L
.9317 .38234 L
.93187 .38234 L
.93203 .38234 L
.93219 .38234 L
.93236 .38234 L
.93267 .38234 L
.93285 .38234 L
.93301 .38234 L
.93318 .38234 L
.93337 .38234 L
.93353 .38234 L
.93371 .38234 L
.93388 .38234 L
.93403 .38234 L
.93433 .38234 L
.93464 .38234 L
.93491 .38234 L
.93521 .38234 L
.93553 .38234 L
.93582 .38234 L
.9361 .38234 L
.93635 .38234 L
.93664 .38234 L
.93691 .38234 L
.93721 .38234 L
.93752 .38234 L
.93779 .08304 L
.93809 .0825 L
.93936 .08017 L
.9438 .0721 L
.94892 .06283 L
.95134 .05847 L
.95241 .05655 L
.95302 .05546 L
.95359 .05444 L
Mistroke
.95385 .05397 L
.95413 .05347 L
.95443 .38234 L
.95471 .38234 L
.95501 .38234 L
.95528 .38234 L
.95558 .38234 L
.95575 .38234 L
.9559 .38234 L
.95606 .38234 L
.95623 .38234 L
.95653 .38234 L
.95669 .38234 L
.95685 .38234 L
.95702 .38234 L
.9572 .38234 L
.95736 .38234 L
.95753 .38234 L
.95784 .38234 L
.95814 .38234 L
.95843 .38234 L
.95871 .38234 L
.95902 .38234 L
.95932 .38234 L
.95959 .38234 L
.95983 .38234 L
.9601 .38234 L
.96038 .38234 L
.96065 .38234 L
.96095 .38234 L
.96124 .38234 L
.9615 .38234 L
.96179 .38234 L
.9621 .38234 L
.96225 .38234 L
.96242 .38234 L
.96273 .38234 L
.96301 .38234 L
.9633 .38234 L
.9636 .38234 L
.96389 .38234 L
.96415 .38234 L
.96446 .38234 L
.96463 .38234 L
.96479 .38234 L
.96509 .38234 L
.9654 .38234 L
.96569 .38234 L
.96601 .38234 L
.96632 .38234 L
Mistroke
.96659 .38234 L
.96676 .38234 L
.96691 .38234 L
.96709 .38234 L
.96727 .38234 L
.96744 .38234 L
.9676 .38234 L
.96791 .38234 L
.96817 .38234 L
.96845 .38234 L
.96875 .38234 L
.96903 .38234 L
.96929 .38234 L
.96953 .38234 L
.9698 .38234 L
.97006 .38234 L
.97035 .38234 L
.97064 .02431 L
.9709 .02386 L
.97118 .02338 L
.97239 .02127 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[108]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000
003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00203oool2
000000D0oooo00<000000?ooo`3oool0o`3oool?0?ooo`001`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`050?ooo`002@3oool00`00
0000oooo0?ooo`030?ooo`<00000o`3oool60?ooo`030000003oool0oooo00H0oooo00000`3oool0
000000000002000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`H0
oooo00<000000?ooo`3oool01P3oool000L0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000050?ooo`030000
003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`070?ooo`003`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo00<000000?ooo`3oool01`3oool000l0oooo00<000000?ooo`3oool0o`3oool5
0?ooo`030000003oool0oooo00L0oooo000?0?ooo`030000003oool0oooo0?l0oooo1@3oool00`00
0000oooo0?ooo`070?ooo`003`3oool200000?l0oooo1P3oool00`000000oooo0?ooo`070?ooo`00
3`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool01`3oool000l0oooo00<0
00000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo00L0oooo000?0?ooo`030000003oool0
oooo0?l0oooo0@3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0
oooo0?l0oooo0P0000030?ooo`030000003oool0oooo00L0oooo000?0?ooo`030000003oool0oooo
0?h0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`003`3oool00`000000
oooo0?ooo`3n0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01`3oool000l0oooo
0P00003n0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01`3oool000l0oooo
00<000000?ooo`3oool0o@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0
oooo000?0?ooo`030000003oool0oooo0?`0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00L0oooo000?0?ooo`030000003oool0oooo0?`0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00L0oooo000?0?ooo`030000003oool0oooo0?/0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000
003oool0oooo0?/0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0
oooo000?0?ooo`800000o03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00002@3oool000l0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0n`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0
n`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo
00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00002@3oool000l0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0n`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo0P00003g0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0
oooo000?0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0
m@3oool2000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0
oooo000?0?ooo`030000003oool0oooo0?D0oooo0P0000040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`3d0?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00070?ooo`@00000103oool00`000000oooo0?ooo`3d0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo00070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0l`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`00203oool00`000000
oooo0?ooo`040?ooo`<00000l`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000090?ooo`0000<0oooo0000000000000P0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0lP3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo0007
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0l@3oool2000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
2@3oool000P0oooo0P0000050?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000090?ooo`003`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
2@3oool000l0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo
000?0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3o
ool200000?80oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`3a0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo0P00003]0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?oo
o`3[0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003o
ool0oooo0>X0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo
000?0?ooo`030000003oool0oooo0>X0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0>T0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0>T0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`03
0000003oool0oooo0>T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000T0oooo000?0?ooo`800000j@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`3X0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003o
ool0oooo0>L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3o
ool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0>L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
2@3oool000l0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3oool200000>P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
2@3oool000l0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?oo
o`3W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<0
00000?ooo`3oool0i`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000090?ooo`001`3oool5000000<0oooo00<000000?ooo`3oool0i`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000090?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>40oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000090?ooo`002@3oool00`000000oooo0?ooo`030?ooo`<00000h03o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000002@3oool000030?ooo`000000000000800000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000090?ooo`00203oool2000000D0oooo00<000000?ooo`3oool0gP3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0=h0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`3M0?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000090?ooo`003`3oool200000=h0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo000?0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0=`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0
oooo0=/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?
0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo000?0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0=/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo000?0?ooo`800000g03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<00000
0?ooo`3oool0f`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3o
ool000l0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0f`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<00000
0?ooo`3oool0f`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3o
ool000l0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000002@3oool000l0oooo0P00003L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`3D0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<00000
0?ooo`3oool0?@3oool5000003d0oooo100000100?ooo`8000003`3oool2000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01P000000oooo0?ooo`3oool000000?ooo`<000001@3oool000l0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0400oooo00@0
00000?ooo`3oool000003@3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo000?0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00/0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`D000001@3oool000l0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo000?0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0?@3oool010000000oooo0?ooo`00000o0?ooo`040000003oool0oooo000000/0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
oooo0P0000000`3oool000000?ooo`050?ooo`003`3oool2000003l0oooo0P0000100?ooo`800000
@@3oool2000000`0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00H000000?ooo`3oool0oooo0000003oool2000000H0oooo000?0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool0c`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo000?0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000002@3oool000P0ooooo`00000I000000003`3oool00`000000oooo0?ooo`0900000003
0?ooo`000000oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`8000001`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`003`3oool00`000000oooo0?ooo`090?ooo`H00000<03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000003h0oooo00<000000?ooo`3oool01@3oool000l0oooo00<0
00000?ooo`3oool03`3oool3000004`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo04@0oooo000?0?ooo`030000003oool0oooo0180oooo0P00001:
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`14
0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`<00000A`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A03oool000l0oooo00<000000?ooo`3o
ool05`3oool3000004@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo04@0oooo000?0?ooo`8000006`3oool200000480oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04@0oooo000?0?ooo`030000003o
ool0oooo01`0oooo0`00000o0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`140?ooo`003`3oool00`000000oooo0?ooo`0O0?ooo`800000?@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A03oool0
00l0oooo00<000000?ooo`3oool08@3oool2000003/0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo04@0oooo000?0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0A@3oool000l0oooo00<000000?ooo`3oool0903oool2000003P0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04H0oooo
000?0?ooo`030000003oool0oooo02H0oooo0P00000f0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`160?ooo`003`3oool2000002T0oooo0P00000d
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`17
0?ooo`003`3oool00`000000oooo0?ooo`0Z0?ooo`800000<P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool000l0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo0000001:0?ooo`003`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00001;0?ooo`003`3oool00`000000
oooo0?ooo`0^0?ooo`800000;P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000004`0
oooo000?0?ooo`030000003oool0oooo0300oooo0P00000/0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
0P00001=0?ooo`003`3oool00`000000oooo0?ooo`0b0?ooo`800000:P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`800000C@3oool000l0oooo0P00000e0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1<0?ooo`003`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E@3oool000l0oooo00<000000?ooo`3o
ool0=P3oool2000002H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0E@3oool000l0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05D0oooo000?0?ooo`030000003o
ool0oooo03T0oooo0P00000S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05D0oooo000?0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`003`3oool20000
03d0oooo0P00000P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo05D0oooo000?0?ooo`030000003oool0oooo03h0
oooo0P00000N0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo05D0oooo000?0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`003`3oool00`000000oooo0?oo
o`110?ooo`8000006`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`003`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E@3oool000L0oooo1@0000030?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1E0?oo
o`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1E0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`<00000
AP3oool2000001H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0EP3oool000T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3o
ool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`190?ooo`8000004`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1H0?ooo`00203oool2000000D0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo000?0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo0000001L0?ooo`003`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`000000G03oool000l0oooo00<000000?ooo`3oool0CP3oool2000000h0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
05d0oooo000?0?ooo`800000D@3oool2000000`0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`<00000GP3oool000l0oooo00<000000?ooo`3oool0DP3oool2000000X0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`800000G`3oool000l0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0J03oool000l0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0J03oool000l0oooo00<000000?oo
o`3oool0EP3oool2000000H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1X0?oo
o`003`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1X0?ooo`003`3oool00`000000oooo0?ooo`1I0?ooo`800000
0`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06P0oooo000?0?ooo`800000G03o
ool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06P0oooo000?0?ooo`030000003o
ool0oooo05`0oooo0`00000H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06P0oooo000?0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1X0?ooo`003`3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`800000JP3oool000l0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1Z0?ooo`003`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`800000K@3oool000l0oooo0P00
001h0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`030?ooo`800000K`3oool000l0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P00001a0?ooo`003`3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool0
10000000oooo0?ooo`00001c0?ooo`003`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02`3oool3000007@0oooo000?0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07@0oooo000?0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`220?ooo`003`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0PP3oool000l0oooo0P00001i0?ooo`D00000303oool00`000000oooo0?oo
o`220?ooo`003`3oool00`000000oooo0?ooo`1m0?ooo`d00000Q03oool000l0oooo00<000000?oo
o`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000
003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.233721, -3.22294, \
0.0151002, 0.0296056}}]
}, Open  ]],

Cell["\<\
Symbolic functions such as integration know how to handle the \
piecewise nature of the function.\
\>", "Text"],

Cell["Integrate the function over the interval [0,4].", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[p[x], {x, 0, 4}]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(\(-4\)\ Cos[4] - \[Pi]\^\(1/3\)\ Cos[\[Pi]\^\(1/3\)] + 
      2\ \[Pi]\^\(1/3\)\ Cos[2\ \[Pi]\^\(1/3\)] + 
      2\^\(2/3\)\ \[Pi]\^\(1/3\)\ Cos[2\^\(2/3\)\ \[Pi]\^\(1/3\)] - 
      3\^\(2/3\)\ \[Pi]\^\(1/3\)\ Cos[
          3\^\(2/3\)\ \[Pi]\^\(1/3\)] + \((2\ \[Pi])\)\^\(1/3\)\ Cos[\((2\ \
\[Pi])\)\^\(1/3\)] + 
      2\ \((2\ \[Pi])\)\^\(1/3\)\ Cos[2\ \((2\ \[Pi])\)\^\(1/3\)] + 
      3\^\(2/3\)\ \((2\ \[Pi])\)\^\(1/3\)\ Cos[
          3\^\(2/3\)\ \((2\ \[Pi])\)\^\(1/3\)] - \((3\ \[Pi])\)\^\(1/3\)\ \
Cos[\((3\ \[Pi])\)\^\(1/3\)] + 
      2\^\(2/3\)\ \((3\ \[Pi])\)\^\(1/3\)\ Cos[
          2\^\(2/3\)\ \((3\ \[Pi])\)\^\(1/3\)] - \((5\ \[Pi])\)\^\(1/3\)\ \
Cos[\((5\ \[Pi])\)\^\(1/3\)] + 
      2\^\(2/3\)\ \((5\ \[Pi])\)\^\(1/3\)\ Cos[
          2\^\(2/3\)\ \((5\ \[Pi])\)\^\(1/3\)] + \((6\ \[Pi])\)\^\(1/3\)\ \
Cos[\((6\ \[Pi])\)\^\(1/3\)] - \((7\ \[Pi])\)\^\(1/3\)\ Cos[\((7\ \
\[Pi])\)\^\(1/3\)] + \((10\ \[Pi])\)\^\(1/3\)\ Cos[\((10\ \[Pi])\)\^\(1/3\)] \
- \((11\ \[Pi])\)\^\(1/3\)\ Cos[\((11\ \[Pi])\)\^\(1/3\)] - \((13\ \[Pi])\)\^\
\(1/3\)\ Cos[\((13\ \[Pi])\)\^\(1/3\)] + \((14\ \[Pi])\)\^\(1/3\)\ Cos[\((14\ \
\[Pi])\)\^\(1/3\)] - \((15\ \[Pi])\)\^\(1/3\)\ Cos[\((15\ \[Pi])\)\^\(1/3\)] \
- \((17\ \[Pi])\)\^\(1/3\)\ Cos[\((17\ \[Pi])\)\^\(1/3\)] - \((19\ \[Pi])\)\^\
\(1/3\)\ Cos[\((19\ \[Pi])\)\^\(1/3\)] + Sin[4] + Sin[\[Pi]\^\(1/3\)] - 
      Sin[2\ \[Pi]\^\(1/3\)] - Sin[2\^\(2/3\)\ \[Pi]\^\(1/3\)] + 
      Sin[3\^\(2/3\)\ \[Pi]\^\(1/3\)] - Sin[\((2\ \[Pi])\)\^\(1/3\)] - 
      Sin[2\ \((2\ \[Pi])\)\^\(1/3\)] - 
      Sin[3\^\(2/3\)\ \((2\ \[Pi])\)\^\(1/3\)] + 
      Sin[\((3\ \[Pi])\)\^\(1/3\)] - 
      Sin[2\^\(2/3\)\ \((3\ \[Pi])\)\^\(1/3\)] + 
      Sin[\((5\ \[Pi])\)\^\(1/3\)] - 
      Sin[2\^\(2/3\)\ \((5\ \[Pi])\)\^\(1/3\)] - 
      Sin[\((6\ \[Pi])\)\^\(1/3\)] + Sin[\((7\ \[Pi])\)\^\(1/3\)] - 
      Sin[\((10\ \[Pi])\)\^\(1/3\)] + Sin[\((11\ \[Pi])\)\^\(1/3\)] + 
      Sin[\((13\ \[Pi])\)\^\(1/3\)] - Sin[\((14\ \[Pi])\)\^\(1/3\)] + 
      Sin[\((15\ \[Pi])\)\^\(1/3\)] + Sin[\((17\ \[Pi])\)\^\(1/3\)] + 
      Sin[\((19\ \[Pi])\)\^\(1/3\)]\)], "Output",
  CellLabel->"Out[114]="]
}, Open  ]],

Cell["\<\
Numerical functions often take advantage of symbolic information.  \
\
\>", "Text"],

Cell["\<\
Approximate numerically the integral of the function over the \
interval [0,4].  Purely numerical routines would have trouble with the \
discontinuities.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[p[x], {x, 0, 4}]\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(1.1846531425020792`\)], "Output",
  CellLabel->"Out[112]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Numerical\ \ Computation\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Due to time constraints I will just show you a few smaller examples that \
emphasize two unique features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", complete integration within the system and automatic algorithm \
selection. "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s arithmetic provides a simple example to start with that illustrates \
both of these features."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Multiplication",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["Consider the problem of multiplying two inputs together.  ", "Text"],

Cell[TextData[{
  "In a compiled language such as FORTRAN or C, these inputs would be numbers \
and the multiplication result would be determined by simple rules determined \
at compile time.\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " needs to determine more since there are many more types of inputs; \
symbolic expressions, machine and arbitrary sized integers, machine and \
arbitrary precision real and complex numbers."
}], "Text"],

Cell["\<\
\[Bullet] If one or both are symbolic, then attempts are made to \
reduce the result to a canonical form.\
\>", "Text"],

Cell["Multiply a symbol by itself.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a*a\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(a\^2\)], "Output",
  CellLabel->"Out[10]=",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
\[Bullet] If both are machine sized integers, hardware arithmetic \
is used, if possible.\
\>", "Text"],

Cell["Multiply two small integers together. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(101*444\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(44844\)], "Output",
  CellLabel->"Out[12]=",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
\[Bullet] Arbitrary sized integers use GMP multiplication routines, \
which for large size use transform methods to achieve O(n log n) \
complexity.\
\>", "Text"],

Cell["Compute the factorial of 10000.", "MathCaption"],

Cell[BoxData[
    \(Factorial[10000]\)], "Input",
  CellLabel->"In[126]:="],

Cell["\<\
\[Bullet]When appropriate, machine hardware arithmetic is used for \
real numbers.\
\>", "Text"],

Cell["\<\
Multiply machine number (IEEE) approximations to \[Pi] and \
\[ExponentialE] together.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(3.141592653589793*2.718281828459045\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(8.539734222673566`\)], "Output",
  CellLabel->"Out[118]="]
}, Open  ]],

Cell[TextData[{
  "In addition, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " supports arbitrary precision software arithmetic that keeps track of the \
error in results using an algorithm known as significance arithmetic."
}], "Text"],

Cell["\<\
\[Bullet]If both are arbitrary precision approximate numbers, the \
precision of the result computed with significance arithmetic.\
\>", "Text"],

Cell["\<\
Multiply a 32 digit approximation of \[Pi] by a 20 digit \
approximation of \[ExponentialE].\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\[Pi], \ 32]*N[\[ExponentialE], \ 20]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(8.5397342226735670654635508696`19.999999999999567\)], "Output",
  CellLabel->"Out[119]="]
}, Open  ]],

Cell["\<\
The precision of the result is, in this case, the lesser of the two \
input precisions.\
\>", "Text"],

Cell["Give the computed precision of the previous result.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[%]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(19.999999999999563`\)], "Output",
  CellLabel->"Out[120]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Significance\ Arithmetic\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Significance arithmetic is a powerful feature of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", since it provides an easy mechanism whereby you can get results with \
error determined.  Furthermore, some computations require more precision than \
hardware arithmetic to get reasonable results: it is typically very easy to \
increase the precision used for a computation in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " so that you can get the result to required accuracy or precision."
}], "Text"],

Cell[TextData[{
  "The commands ",
  StyleBox["Precision", "MR"],
  " and ",
  StyleBox["Accuracy", "MR"],
  " give the significance of a number.  They have formal definitions in terms \
of error intervals they relate to.  It is often useful in terms of intuition, \
though not always strictly correct, to make an analogy between the precision \
and the number of significant (decimal) digits."
}], "Text"],

Cell[BoxData[
    \(DefaultTraditionalFormatType\`\(\(\(\ \)\(x\_1\ x\_2\ \[CenterEllipsis]\
\ x\_s\)\)\+\(\[UnderBrace]\+Scale\) . \(x\_\(s + 1\)\ x\_\(s + 2\)\ \
\[CenterEllipsis]\ x\_\(s + a\)\)\+\(\[UnderBrace]\+Accuracy\)\)\&\(\
\[OverBrace]\&Precision\)\)], "DisplayFormula",
  Evaluatable->False,
  FontFamily->"Times",
  FontSize->16,
  CellTags->"M185A.1.2"],

Cell["\<\
This gives an approximate number which is equal to one with 30 \
significant digits.\
\>", "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x\  = \ N[1, \ 30]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \(1.`30. \)], "Output",
  CellLabel->"Out[137]="]
}, Open  ]],

Cell["\<\
Newton's method provides a good example to see the information that \
significance arithmetic provides.  \
\>", "Text"],

Cell[TextData[{
  "This takes a step of Newton's method for f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "- 1 and checks the significance of the difference between the result and \
",
  Cell[BoxData[
      \(\@2\)]]
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{x\  = \ x/2\  + \ 1/x, \ Precision[x], \ 
          Accuracy[x]}, {\@2\  - \ x, \ Precision[\@2\  - \ x], \ 
          Accuracy[\@2\  - \ x]}}]\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1.5`30.", "30.`", "29.823908740944315`"},
          {\(-0.085786437626904951198311275790301921430328124623`28.\
757327374604607\), "28.757327374604607`", "29.823908740944315`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[138]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "This takes a step of Newton's method for f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "- 1 and checks the significance of the difference between the result and \
",
  Cell[BoxData[
      \(\@2\)]]
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{x\  = \ x/2\  + \ 1/x, \ Precision[x], \ 
          Accuracy[x]}, {\@2\  - \ x, \ Precision[\@2\  - \ x], \ 
          Accuracy[\@2\  - \ x]}}]\)], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1.416666666666666666666666666666666666666666666667`30.", "30.`", 
            "29.84873232466935`"},
          {\(-0.00245310429357161786497794245696858809699479129`27.\
238448337270274\), "27.238448337270274`", "29.84873232466935`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[139]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "This takes a step of Newton's method for f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "- 1 and checks the significance of the difference between the result and \
",
  Cell[BoxData[
      \(\@2\)]]
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{x\  = \ x/2\  + \ 1/x, \ Precision[x], \ 
          Accuracy[x]}, {\@2\  - \ x, \ Precision[\@2\  - \ x], \ 
          Accuracy[\@2\  - \ x]}}]\)], "Input",
  CellLabel->"In[140]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1.414215686274509803921568627450980392156862745099`30.", "30.`", 
            "29.84948434993415`"},
          {\(-2.123901414755119879903241282313587190869722`24.17661870414136*^\
-6\), "24.17661870414136`", "29.849484349934144`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[140]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "This takes a step of Newton's method for f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "- 1 and checks the significance of the difference between the result and \
",
  Cell[BoxData[
      \(\@2\)]]
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{x\  = \ x/2\  + \ 1/x, \ Precision[x], \ 
          Accuracy[x]}, {\@2\  - \ x, \ Precision[\@2\  - \ x], \ 
          Accuracy[\@2\  - \ x]}}]\)], "Input",
  CellLabel->"In[141]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1.414213562374689910626295578890134910116559622116`30.", "30.`", 
            "29.84948500216752`"},
          {\(-1.594861824606854680436831546887746739`18.05220806485212*^-12\),
             "18.052208064852117`", "29.84948500216752`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[141]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "This takes a step of Newton's method for f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "- 1 and checks the significance of the difference between the result and \
",
  Cell[BoxData[
      \(\@2\)]]
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{x\  = \ x/2\  + \ 1/x, \ Precision[x], \ 
          Accuracy[x]}, {\@2\  - \ x, \ Precision[\@2\  - \ x], \ 
          Accuracy[\@2\  - \ x]}}]\)], "Input",
  CellLabel->"In[142]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1.414213562373095048801689623502530243614981925776`30.", "30.`", 
            "29.84948500216801`"},
          {\(-8.99292832165045310050399`5.803386134040743*^-25\), 
            "5.803386134040743`", "29.84948500216801`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[142]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "This takes a step of Newton's method for f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "- 1 and checks the significance of the difference between the result and \
",
  Cell[BoxData[
      \(\@2\)]]
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{x\  = \ x/2\  + \ 1/x, \ Precision[x], \ 
          Accuracy[x]}, {\@2\  - \ x, \ Precision[\@2\  - \ x], \ 
          Accuracy[\@2\  - \ x]}}]\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1.414213562373095048801688724209698078569671875377`30.", "30.`", 
            "29.84948500216801`"},
          {"0``29.84948500216801", "0.`", "29.84948500216801`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[143]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "This takes a step of Newton's method for f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "- 1 and checks the significance of the difference between the result and \
",
  Cell[BoxData[
      \(\@2\)]]
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{x\  = \ x/2\  + \ 1/x, \ Precision[x], \ 
          Accuracy[x]}, {\@2\  - \ x, \ Precision[\@2\  - \ x], \ 
          Accuracy[\@2\  - \ x]}}]\)], "Input",
  CellLabel->"In[144]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1.414213562373095048801688724209698078569671875377`30.", "30.`", 
            "29.84948500216801`"},
          {"0``29.84948500216801", "0.`", "29.84948500216801`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[144]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Multiplication",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
\[Bullet]When input types are mixed, the inputs and results are \
coerced automatically.\
\>", "Text"],

Cell["This expands a product with mixed inputs.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[\((3.141592653589793\  + \ a)\)*\((N[E, \ 20]\  + \ b\ x\  + \ 
            c)\)]\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \(\(\(8.539734222673566`\)\(\[InvisibleSpace]\)\) + 
      2.71828182845904523536028747135266249776`20. \ a + 
      4.442882938158366`\ b + 
      1.414213562373095048801688724209698078569671875377`30. \ a\ b + 
      3.141592653589793`\ c + a\ c\)], "Output",
  CellLabel->"Out[147]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Scalability",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
An important aspect of algorithm selection is scalability.  For a \
given computation, it is often appropriate to use different algorithms \
depending on the overall size of the computation.  For large inputs, there \
may be algorithms which involve a lot of overhead, but reduce the overall \
asymptotic complexity of the computation.\
\>", "Text"],

Cell["\<\
The factorial example I showed above provides an easy to understand \
example for algorithm selection for better scalability.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Factorials",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Using patterns, it is very easy to write a function that computes \
factorials in Mathematica\
\>", "Text"],

Cell["\<\
Define a function that will recursively compute the factorial of a \
positive integer.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(factr[1]\  := \ 1;\)\), "\[IndentingNewLine]", 
    \(\(factr[n_Integer\  /; \ Positive[n]]\  := \ 
        n\ factr[n - 1];\)\)}], "Input",
  CellLabel->"In[130]:="],

Cell["Use the function to compute a small factorial.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(factr[4]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(24\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell["\<\
Compute the factorial of a larger number.  The recursive definition \
is  limited because the size of the recursion stack can get too large.\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(factr[300]\)], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    RowBox[{\($RecursionLimit::"reclim"\), \(\(:\)\(\ \)\), "\<\"Recursion \
depth of \\!\\(256\\) exceeded. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"$RecursionLimit::reclim\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[161]:="],

Cell[BoxData[
    RowBox[{\($RecursionLimit::"reclim"\), \(\(:\)\(\ \)\), "\<\"Recursion \
depth of \\!\\(256\\) exceeded. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"$RecursionLimit::reclim\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[161]:="],

Cell[BoxData[
    \(255853394128682934271792456014756022284567647214795926502181770119143638\
306194393837072100904643727100066178884995557066500163182466384715154074231026\
841708452603339053764890010195255892544393688267028273004188884621933908229112\
811932083073208834191916262141620325999832958461588913836674274984370470006138\
708322506730175954654083896230304005244599155135905396622531006655050933401542\
390182337136075572120633738551117926859774602778037649805670957699161716073769\
220456877601175631686138117226496000000000000000000000000000000000000000000000\
0000000000000000000\ Hold[fact[46 - 1]]\)], "Output",
  CellLabel->"Out[161]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Factorials",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["It is just as simple to write a non-recursive definition:", "Text"],

Cell["Define a non-recursive function to compute factorials.", "MathCaption"],

Cell[BoxData[
    \(fact[n_]\  := \ 
      Module[{f\  = \ 1}, \ Do[f\  *= \ i, \ {i, \ 2, \ n}]; \ f]\)], "Input",\

  CellLabel->"In[162]:="],

Cell["Compute the factorial of a larger number.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fact[300]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \(306057512216440636035370461297268629388588804173576999416776741259476533\
176716867465515291422477573349939147888701726368864263907759003154226842927906\
974559841225476930271954604008012215776252176854255965356903506788725264321896\
264299365204576448830388909753943489625436053225980776521270822437639449120128\
678675368305712293681943649956460498166450227716500185176546469340112226034729\
724066333258583506870150169794168850353752137554910289126407157154830282284937\
952636580145235233156936482233436799254594095276820608062232812387383880817049\
600000000000000000000000000000000000000000000000000000000000000000000000000\)]\
, "Output",
  CellLabel->"Out[164]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Factorials",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Of course, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a built-in Factorial command."
}], "Text"],

Cell[TextData[{
  "This creates a table showing the times taken by my command for computing \
factorials versus the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Factorial command for inputs of different sizes."
}], "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Table[\[IndentingNewLine]n\  = \ 2^k; \[IndentingNewLine]{n, \ 
          First[Timing[fact[n]]], \ 
          First[Timing[Factorial[n]]]}, \[IndentingNewLine]{k, 10, 
          20}]]\)], "Input",
  CellLabel->"In[22]:=",
  Evaluatable->False],

Cell[BoxData[
    TagBox[GridBox[{
          {"1024", \(0.`\ Second\), \(0.`\ Second\)},
          {"2048", \(0.009999999999990905`\ Second\), \(0.`\ Second\)},
          {"4096", \(0.030000000000001137`\ Second\), \(0.`\ Second\)},
          {
            "8192", \(0.07999999999998408`\ Second\), \(0.010000000000019327`\
\ Second\)},
          {
            "16384", \(0.2609999999999957`\ Second\), \(0.030000000000001137`\
\ Second\)},
          {
            "32768", \(1.0209999999999866`\ Second\), \(0.0800000000000125`\ \
Second\)},
          {
            "65536", \(4.295999999999992`\ Second\), \(0.21100000000001273`\ \
Second\)},
          {
            "131072", \(20.899999999999977`\ Second\), \(0.6210000000000377`\ \
Second\)},
          {
            "262144", \(147.25099999999998`\ Second\), \(1.663000000000011`\ \
Second\)},
          {
            "524288", \(729.4689999999999`\ Second\), \(4.326000000000022`\ \
Second\)},
          {
            "1048576", \(3137.6020000000008`\ Second\), \(11.175999999999476`\
\ Second\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[22]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Binary\ Splitting\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "The built in factorial command uses the ",
  ButtonBox["binary splitting",
    ButtonData:>{
      URL[ 
      "http://numbers.computation.free.fr/Constants/Algorithms/splitting.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " algorithm of Borwein and Borwein.  The idea is, in essence, quite simple: \
 "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{\(\(n!\)\  \[Equal] \ 1\[Cross]2\[Cross]\), " ", 
              StyleBox[
                RowBox[{"..", 
                  StyleBox[".",
                    FontColor->RGBColor[1, 0, 0]]}]]}],
            FontWeight->"Bold"], 
          StyleBox[".",
            FontWeight->"Bold",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[" ",
            FontWeight->"Bold",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[
            RowBox[{
              StyleBox[\((n/2\  - 1)\),
                FontColor->RGBColor[1, 0, 0]], "\[Cross]", 
              StyleBox[\((n/2)\),
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox["\[Cross]",
                FontColor->RGBColor[0, 1, 0]]}],
            FontWeight->"Bold"]}], 
        StyleBox[" ",
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], 
        StyleBox[
          StyleBox[
            RowBox[{
              StyleBox["..",
                FontColor->RGBColor[0, 1, 0]], 
              StyleBox[".",
                FontColor->RGBColor[0, 0, 1]]}]],
          FontWeight->"Bold"]}], 
      StyleBox[".",
        FontWeight->"Bold",
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox[" ",
        FontWeight->"Bold",
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox[\(\(\[Cross]\)\(n\)\),
        FontWeight->"Bold",
        FontColor->RGBColor[0, 0, 1]]}], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"      ", 
        RowBox[{"\[Equal]", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\[Cross]2\[Cross]\), " ", 
                  StyleBox[
                    RowBox[{"..", 
                      StyleBox[".",
                        FontColor->RGBColor[1, 0, 0]]}]]}], 
                StyleBox[".",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[" ",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[\((n/2\  - 1)\),
                  FontColor->RGBColor[1, 0, 0]]}], ")"}], "\[Cross]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\((n/2)\)\(\[Cross]\)\),
                    FontColor->RGBColor[0, 1, 0]], 
                  StyleBox[" ",
                    FontColor->RGBColor[0, 1, 0]], 
                  StyleBox[
                    RowBox[{
                      StyleBox["..",
                        FontColor->RGBColor[0, 1, 0]], 
                      StyleBox[".",
                        FontColor->RGBColor[0, 0, 1]]}]]}], 
                StyleBox[".",
                  FontColor->RGBColor[0, 0, 1]], 
                StyleBox[" ",
                  FontColor->RGBColor[0, 0, 1]], 
                StyleBox[\(\(\[Cross]\)\(n\)\),
                  FontColor->RGBColor[0, 0, 1]]}], 
              StyleBox[")",
                FontColor->RGBColor[0, 0, 1]]}]}]}]}],
      FontWeight->"Bold"], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{"     ", 
        RowBox[{"\[Equal]", " ", 
          RowBox[{
            RowBox[{"(", 
              
              RowBox[{\((\(1\[Cross]2\[Cross]\  ... \)\ \((n/4\  - \ 1)\))\), 
                "\[Cross]", 
                
                StyleBox[\((\(\(\((n/4)\)\(\[Cross]\)\)\  ... \)\ \((n/2\  - 
                          1)\))\),
                  FontColor->RGBColor[1, 0, 0]]}], ")"}], "\[Cross]", " ", 
            "\[IndentingNewLine]", "                   ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["(",
                    FontColor->RGBColor[0, 1, 0]], 
                  
                  StyleBox[\(\(\(\((n/
                              2)\)\(\[Cross]\)\)\  ... \)\ \[Cross]\((3 
                             n/4\  - \ 1)\)\),
                    FontColor->RGBColor[0, 1, 0]], ")"}], "\[Cross]", 
                RowBox[{"(", 
                  
                  StyleBox[\(\(\(\((3  n/4)\)\(\[Cross]\)\) ... \)\[Cross]n\),
                    
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox[")",
                    FontColor->RGBColor[0, 0, 1]]}]}], ")"}]}]}]}],
      FontWeight->"Bold"]}], "DisplayFormula"],

Cell[TextData[{
  "Recursively divide the product into pairs of products.  This doesn't \
reduce the number of multiplications necessary, but it keeps the sizes of the \
multiplications balanced so that few multiplications are done at the largest \
size.  The effectiveness of this splitting for multiplication depends on \
having and multiplication algorithm with asymptotic complexity less than ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^2)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in Factorial command automatically switches to use binary \
splitting at a problem size where it typically works out to be faster.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s algorithm uses some additional tricks such as choosing the splitting to \
balance factors and handling powers of 2 separately to squeeze that extra bit \
of speed out. "
}], "Text"],

Cell[TextData[{
  "It is worth noting that if you do a product in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", binary splitting is used automatically."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          
          StyleBox[\(Symbolic\ Expressions\ and\ Automatic\ Algorithm\ \
Selection\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Symbolic expressions provide an important mechanism for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to choose algorithms. Since this feature is not available in dedicated \
numerical systems, I will use two different examples to demonstrate it in \
action; unconstrained minimization of a function and the solution of a \
partial differential equation."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Minimization",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
This loads a collection of standard test problems for unconstrained \
local optimization.\
\>", "MathCaption"],

Cell[BoxData[
    \(<< Optimization`UnconstrainedProblems`\)], "Input",
  CellLabel->"In[48]:="],

Cell["Get the \"Rosenbrock\" problem.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p\  = \ GetFindMinimumProblem[Rosenbrock]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(FindMinimumProblem[\((1 - X\_1)\)\^2 + 
        100\ \((\(-X\_1\%2\) + X\_2)\)\^2, {{X\_1, \(-1.2`\)}, {X\_2, 
          1.`}}, {}, Rosenbrock, {2, 2}]\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell["\<\
The so-called \"Rosenbrock\"  problem is commonly used to check on \
local optimization methods in low dimensions.  It difficulty lies in a curved \
valley: simple descent methods do quite poorly on this example.\
\>", "Text"],

Cell["\<\
The collection of problems also includes a function FindMinimumPlot \
that, for problems in two variables shows the steps and function evaluations \
used to solve the minimization problem.\
\>", "Text"],

Cell[TextData[{
  "This shows the steps and evaluations used by the method ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " chooses automatically."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p1\  = \ 
      FindMinimumPlot[\((1 - X\_1)\)\^2 + 
          100\ \((\(-X\_1\%2\) + X\_2)\)\^2, {{X\_1, \(-1.2`\)}, {X\_2, 
            1.`}}]\)], "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.543706 0.437063 0.782104 0.198665 [
[.10664 -0.0125 -6 -9 ]
[.10664 -0.0125 6 0 ]
[.32517 -0.0125 -12 -9 ]
[.32517 -0.0125 12 0 ]
[.54371 -0.0125 -3 -9 ]
[.54371 -0.0125 3 0 ]
[.76224 -0.0125 -9 -9 ]
[.76224 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .18611 -12 -4.5 ]
[-0.0125 .18611 0 4.5 ]
[-0.0125 .38477 -12 -4.5 ]
[-0.0125 .38477 0 4.5 ]
[-0.0125 .58344 -12 -4.5 ]
[-0.0125 .58344 0 4.5 ]
[-0.0125 .7821 -6 -4.5 ]
[-0.0125 .7821 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10664 0 m
.10664 .00625 L
s
[(-1)] .10664 -0.0125 0 1 Mshowa
.32517 0 m
.32517 .00625 L
s
[(-0.5)] .32517 -0.0125 0 1 Mshowa
.54371 0 m
.54371 .00625 L
s
[(0)] .54371 -0.0125 0 1 Mshowa
.76224 0 m
.76224 .00625 L
s
[(0.5)] .76224 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.15035 0 m
.15035 .00375 L
s
.19406 0 m
.19406 .00375 L
s
.23776 0 m
.23776 .00375 L
s
.28147 0 m
.28147 .00375 L
s
.36888 0 m
.36888 .00375 L
s
.41259 0 m
.41259 .00375 L
s
.45629 0 m
.45629 .00375 L
s
.5 0 m
.5 .00375 L
s
.58741 0 m
.58741 .00375 L
s
.63112 0 m
.63112 .00375 L
s
.67483 0 m
.67483 .00375 L
s
.71853 0 m
.71853 .00375 L
s
.80594 0 m
.80594 .00375 L
s
.84965 0 m
.84965 .00375 L
s
.89336 0 m
.89336 .00375 L
s
.93706 0 m
.93706 .00375 L
s
.06294 0 m
.06294 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .18611 m
.00625 .18611 L
s
[(-3)] -0.0125 .18611 1 0 Mshowa
0 .38477 m
.00625 .38477 L
s
[(-2)] -0.0125 .38477 1 0 Mshowa
0 .58344 m
.00625 .58344 L
s
[(-1)] -0.0125 .58344 1 0 Mshowa
0 .7821 m
.00625 .7821 L
s
[(0)] -0.0125 .7821 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .22584 m
.00375 .22584 L
s
0 .26558 m
.00375 .26558 L
s
0 .30531 m
.00375 .30531 L
s
0 .34504 m
.00375 .34504 L
s
0 .42451 m
.00375 .42451 L
s
0 .46424 m
.00375 .46424 L
s
0 .50397 m
.00375 .50397 L
s
0 .54371 m
.00375 .54371 L
s
0 .62317 m
.00375 .62317 L
s
0 .66291 m
.00375 .66291 L
s
0 .70264 m
.00375 .70264 L
s
0 .74237 m
.00375 .74237 L
s
0 .82184 m
.00375 .82184 L
s
0 .86157 m
.00375 .86157 L
s
0 .9013 m
.00375 .9013 L
s
0 .94104 m
.00375 .94104 L
s
0 .14638 m
.00375 .14638 L
s
0 .10664 m
.00375 .10664 L
s
0 .06691 m
.00375 .06691 L
s
0 .02718 m
.00375 .02718 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10664 .99375 m
.10664 1 L
s
.32517 .99375 m
.32517 1 L
s
.54371 .99375 m
.54371 1 L
s
.76224 .99375 m
.76224 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.15035 .99625 m
.15035 1 L
s
.19406 .99625 m
.19406 1 L
s
.23776 .99625 m
.23776 1 L
s
.28147 .99625 m
.28147 1 L
s
.36888 .99625 m
.36888 1 L
s
.41259 .99625 m
.41259 1 L
s
.45629 .99625 m
.45629 1 L
s
.5 .99625 m
.5 1 L
s
.58741 .99625 m
.58741 1 L
s
.63112 .99625 m
.63112 1 L
s
.67483 .99625 m
.67483 1 L
s
.71853 .99625 m
.71853 1 L
s
.80594 .99625 m
.80594 1 L
s
.84965 .99625 m
.84965 1 L
s
.89336 .99625 m
.89336 1 L
s
.93706 .99625 m
.93706 1 L
s
.06294 .99625 m
.06294 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .18611 m
1 .18611 L
s
.99375 .38477 m
1 .38477 L
s
.99375 .58344 m
1 .58344 L
s
.99375 .7821 m
1 .7821 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .22584 m
1 .22584 L
s
.99625 .26558 m
1 .26558 L
s
.99625 .30531 m
1 .30531 L
s
.99625 .34504 m
1 .34504 L
s
.99625 .42451 m
1 .42451 L
s
.99625 .46424 m
1 .46424 L
s
.99625 .50397 m
1 .50397 L
s
.99625 .54371 m
1 .54371 L
s
.99625 .62317 m
1 .62317 L
s
.99625 .66291 m
1 .66291 L
s
.99625 .70264 m
1 .70264 L
s
.99625 .74237 m
1 .74237 L
s
.99625 .82184 m
1 .82184 L
s
.99625 .86157 m
1 .86157 L
s
.99625 .9013 m
1 .9013 L
s
.99625 .94104 m
1 .94104 L
s
.99625 .14638 m
1 .14638 L
s
.99625 .10664 m
1 .10664 L
s
.99625 .06691 m
1 .06691 L
s
.99625 .02718 m
1 .02718 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.625 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .36349 m
.0232 .35917 L
.02894 .35297 L
.03222 .34946 L
.03866 .34264 L
.04141 .33974 L
.04837 .33251 L
.05077 .33003 L
.05808 .32257 L
.06031 .32032 L
.06779 .31283 L
.07004 .31061 L
.07751 .30329 L
.07998 .30089 L
.08722 .29395 L
.09013 .29118 L
.09693 .2848 L
.10052 .28147 L
.10664 .27584 L
.11115 .27176 L
.11636 .26709 L
.12205 .26204 L
.12607 .25853 L
.13324 .25233 L
.13578 .25016 L
.14475 .24262 L
.14549 .242 L
.15521 .23403 L
.15659 .23291 L
.16492 .22625 L
.16881 .22319 L
.17463 .21868 L
.18144 .21348 L
.18434 .2113 L
.19406 .20411 L
.19453 .20377 L
.20377 .19712 L
.20812 .19406 L
.21348 .19033 L
.22229 .18434 L
.22319 .18374 L
.23291 .17734 L
.23711 .17463 L
.24262 .17114 L
.25233 .16513 L
.25268 .16492 L
.26204 .15932 L
.26914 .15521 L
.27176 .15371 L
.28147 .1483 L
.28664 .14549 L
.29118 .14308 L
.30089 .13805 L
.30542 .13578 L
.31061 .13323 L
.32032 .1286 L
.3258 .12607 L
.33003 .12416 L
.33974 .11993 L
.3483 .11636 L
.34946 .11589 L
.35917 .11204 L
.36888 .10839 L
.37374 .10664 L
.37859 .10494 L
.38831 .10169 L
.39802 .09863 L
.40371 .09693 L
.40773 .09577 L
.41744 .0931 L
.42716 .09064 L
.43687 .08836 L
.44211 .08722 L
.44658 .08629 L
.45629 .08441 L
.46601 .08273 L
.47572 .08124 L
.48543 .07995 L
.49514 .07886 L
.50486 .07796 L
.51077 .07751 L
.51457 .07726 L
.52428 .07676 L
.53399 .07645 L
.54371 .07634 L
.55342 .07643 L
.56313 .07671 L
.57284 .07719 L
.57789 .07751 L
.58256 .07786 L
.59227 .07873 L
.60198 .0798 L
.61169 .08107 L
.62141 .08253 L
.63112 .08419 L
.64083 .08604 L
.64653 .08722 L
.65054 .08809 L
.66026 .09034 L
.66997 .09278 L
.67968 .09542 L
.68494 .09693 L
.68939 .09826 L
.69911 .10129 L
.70882 .10452 L
.7149 .10664 L
.71853 .10795 L
.72824 .11157 L
.73796 .11539 L
.74034 .11636 L
.74767 .1194 L
.75738 .12362 L
.76284 .12607 L
.76709 .12802 L
.77681 .13263 L
.78323 .13578 L
.78652 .13743 L
.79623 .14243 L
.80201 .14549 L
.80594 .14762 L
.81566 .15301 L
.81951 .15521 L
.82537 .1586 L
.83508 .16439 L
.83596 .16492 L
.84479 .17037 L
.85153 .17463 L
.85451 .17654 L
.86422 .18292 L
.86635 .18434 L
.87393 .18949 L
.88052 .19406 L
.88364 .19625 L
.89336 .20322 L
.89412 .20377 L
.90307 .21038 L
.9072 .21348 L
.91278 .21773 L
.91983 .22319 L
.92249 .22528 L
.93205 .23291 L
.93221 .23303 L
.94192 .24098 L
.94389 .24262 L
.95163 .24912 L
.9554 .25233 L
.96134 .25746 L
.96659 .26204 L
.97106 .26599 L
.97749 .27176 L
.98077 .27472 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .36349 m
.0232 .35917 L
.02894 .35297 L
.03222 .34946 L
.03866 .34264 L
.04141 .33974 L
.04837 .33251 L
.05077 .33003 L
.05808 .32257 L
.06031 .32032 L
.06779 .31283 L
.07004 .31061 L
.07751 .30329 L
.07998 .30089 L
.08722 .29395 L
.09013 .29118 L
.09693 .2848 L
.10052 .28147 L
.10664 .27584 L
.11115 .27176 L
.11636 .26709 L
.12205 .26204 L
.12607 .25853 L
.13324 .25233 L
.13578 .25016 L
.14475 .24262 L
.14549 .242 L
.15521 .23403 L
.15659 .23291 L
.16492 .22625 L
.16881 .22319 L
.17463 .21868 L
.18144 .21348 L
.18434 .2113 L
.19406 .20411 L
.19453 .20377 L
.20377 .19712 L
.20812 .19406 L
.21348 .19033 L
.22229 .18434 L
.22319 .18374 L
.23291 .17734 L
.23711 .17463 L
.24262 .17114 L
.25233 .16513 L
.25268 .16492 L
.26204 .15932 L
.26914 .15521 L
.27176 .15371 L
.28147 .1483 L
Mistroke
.28664 .14549 L
.29118 .14308 L
.30089 .13805 L
.30542 .13578 L
.31061 .13323 L
.32032 .1286 L
.3258 .12607 L
.33003 .12416 L
.33974 .11993 L
.3483 .11636 L
.34946 .11589 L
.35917 .11204 L
.36888 .10839 L
.37374 .10664 L
.37859 .10494 L
.38831 .10169 L
.39802 .09863 L
.40371 .09693 L
.40773 .09577 L
.41744 .0931 L
.42716 .09064 L
.43687 .08836 L
.44211 .08722 L
.44658 .08629 L
.45629 .08441 L
.46601 .08273 L
.47572 .08124 L
.48543 .07995 L
.49514 .07886 L
.50486 .07796 L
.51077 .07751 L
.51457 .07726 L
.52428 .07676 L
.53399 .07645 L
.54371 .07634 L
.55342 .07643 L
.56313 .07671 L
.57284 .07719 L
.57789 .07751 L
.58256 .07786 L
.59227 .07873 L
.60198 .0798 L
.61169 .08107 L
.62141 .08253 L
.63112 .08419 L
.64083 .08604 L
.64653 .08722 L
.65054 .08809 L
.66026 .09034 L
.66997 .09278 L
Mistroke
.67968 .09542 L
.68494 .09693 L
.68939 .09826 L
.69911 .10129 L
.70882 .10452 L
.7149 .10664 L
.71853 .10795 L
.72824 .11157 L
.73796 .11539 L
.74034 .11636 L
.74767 .1194 L
.75738 .12362 L
.76284 .12607 L
.76709 .12802 L
.77681 .13263 L
.78323 .13578 L
.78652 .13743 L
.79623 .14243 L
.80201 .14549 L
.80594 .14762 L
.81566 .15301 L
.81951 .15521 L
.82537 .1586 L
.83508 .16439 L
.83596 .16492 L
.84479 .17037 L
.85153 .17463 L
.85451 .17654 L
.86422 .18292 L
.86635 .18434 L
.87393 .18949 L
.88052 .19406 L
.88364 .19625 L
.89336 .20322 L
.89412 .20377 L
.90307 .21038 L
.9072 .21348 L
.91278 .21773 L
.91983 .22319 L
.92249 .22528 L
.93205 .23291 L
.93221 .23303 L
.94192 .24098 L
.94389 .24262 L
.95163 .24912 L
.9554 .25233 L
.96134 .25746 L
.96659 .26204 L
.97106 .26599 L
.97749 .27176 L
Mistroke
.98077 .27472 L
Mfstroke
.775 g
.01923 .44258 m
.02448 .43687 L
.02894 .43205 L
.03352 .42716 L
.03866 .42172 L
.04273 .41744 L
.04837 .41159 L
.05211 .40773 L
.05808 .40165 L
.06168 .39802 L
.06779 .3919 L
.07143 .38831 L
.07751 .38236 L
.08139 .37859 L
.08722 .37301 L
.09157 .36888 L
.09693 .36386 L
.10199 .35917 L
.10664 .3549 L
.11266 .34946 L
.11636 .34614 L
.12359 .33974 L
.12607 .33758 L
.13482 .33003 L
.13578 .32921 L
.14549 .32104 L
.14637 .32032 L
.15521 .31307 L
.15826 .31061 L
.16492 .30529 L
.17053 .30089 L
.17463 .29771 L
.18321 .29118 L
.18434 .29033 L
.19406 .28314 L
.19636 .28147 L
.20377 .27615 L
.21002 .27176 L
.21348 .26936 L
.22319 .26276 L
.22427 .26204 L
.23291 .25636 L
.23918 .25233 L
.24262 .25016 L
.25233 .24415 L
.25485 .24262 L
.26204 .23834 L
.27143 .23291 L
.27176 .23272 L
.28147 .2273 L
.28908 .22319 L
.29118 .22208 L
.30089 .21706 L
.30804 .21348 L
.31061 .21223 L
.32032 .20759 L
.32867 .20377 L
.33003 .20316 L
.33974 .19892 L
.34946 .19488 L
.35149 .19406 L
.35917 .19103 L
.36888 .18738 L
.37739 .18434 L
.37859 .18393 L
.38831 .18067 L
.39802 .17761 L
.40773 .17475 L
.40814 .17463 L
.41744 .17208 L
.42716 .16961 L
.43687 .16734 L
.44658 .16526 L
.44826 .16492 L
.45629 .16338 L
.46601 .16169 L
.47572 .1602 L
.48543 .15891 L
.49514 .15782 L
.50486 .15692 L
.51457 .15622 L
.52428 .15571 L
.53399 .1554 L
.54371 .15529 L
.55342 .15538 L
.56313 .15566 L
.57284 .15613 L
.58256 .15681 L
.59227 .15768 L
.60198 .15875 L
.61169 .16001 L
.62141 .16147 L
.63112 .16313 L
.64053 .16492 L
.64083 .16498 L
.65054 .16703 L
.66026 .16927 L
.66997 .17172 L
.67968 .17436 L
.68066 .17463 L
.68939 .17719 L
.69911 .18022 L
.70882 .18345 L
.7114 .18434 L
.71853 .18688 L
.72824 .1905 L
.73731 .19406 L
.73796 .19432 L
.74767 .19833 L
.75738 .20254 L
.76013 .20377 L
.76709 .20695 L
.77681 .21156 L
.78075 .21348 L
.78652 .21636 L
.79623 .22135 L
.79972 .22319 L
.80594 .22655 L
.81566 .23194 L
.81736 .23291 L
.82537 .23752 L
.83394 .24262 L
.83508 .24331 L
.84479 .24929 L
.84962 .25233 L
.85451 .25546 L
.86422 .26184 L
.86453 .26204 L
.87393 .26841 L
.87877 .27176 L
.88364 .27517 L
.89244 .28147 L
.89336 .28214 L
.90307 .28929 L
.90558 .29118 L
.91278 .29665 L
.91827 .30089 L
.92249 .3042 L
.93054 .31061 L
.93221 .31195 L
.94192 .3199 L
.94243 .32032 L
.95163 .32804 L
.95397 .33003 L
.96134 .33638 L
.9652 .33974 L
.97106 .34491 L
.97614 .34946 L
.98077 .35364 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .44258 m
.02448 .43687 L
.02894 .43205 L
.03352 .42716 L
.03866 .42172 L
.04273 .41744 L
.04837 .41159 L
.05211 .40773 L
.05808 .40165 L
.06168 .39802 L
.06779 .3919 L
.07143 .38831 L
.07751 .38236 L
.08139 .37859 L
.08722 .37301 L
.09157 .36888 L
.09693 .36386 L
.10199 .35917 L
.10664 .3549 L
.11266 .34946 L
.11636 .34614 L
.12359 .33974 L
.12607 .33758 L
.13482 .33003 L
.13578 .32921 L
.14549 .32104 L
.14637 .32032 L
.15521 .31307 L
.15826 .31061 L
.16492 .30529 L
.17053 .30089 L
.17463 .29771 L
.18321 .29118 L
.18434 .29033 L
.19406 .28314 L
.19636 .28147 L
.20377 .27615 L
.21002 .27176 L
.21348 .26936 L
.22319 .26276 L
.22427 .26204 L
.23291 .25636 L
.23918 .25233 L
.24262 .25016 L
.25233 .24415 L
.25485 .24262 L
.26204 .23834 L
.27143 .23291 L
.27176 .23272 L
.28147 .2273 L
Mistroke
.28908 .22319 L
.29118 .22208 L
.30089 .21706 L
.30804 .21348 L
.31061 .21223 L
.32032 .20759 L
.32867 .20377 L
.33003 .20316 L
.33974 .19892 L
.34946 .19488 L
.35149 .19406 L
.35917 .19103 L
.36888 .18738 L
.37739 .18434 L
.37859 .18393 L
.38831 .18067 L
.39802 .17761 L
.40773 .17475 L
.40814 .17463 L
.41744 .17208 L
.42716 .16961 L
.43687 .16734 L
.44658 .16526 L
.44826 .16492 L
.45629 .16338 L
.46601 .16169 L
.47572 .1602 L
.48543 .15891 L
.49514 .15782 L
.50486 .15692 L
.51457 .15622 L
.52428 .15571 L
.53399 .1554 L
.54371 .15529 L
.55342 .15538 L
.56313 .15566 L
.57284 .15613 L
.58256 .15681 L
.59227 .15768 L
.60198 .15875 L
.61169 .16001 L
.62141 .16147 L
.63112 .16313 L
.64053 .16492 L
.64083 .16498 L
.65054 .16703 L
.66026 .16927 L
.66997 .17172 L
.67968 .17436 L
.68066 .17463 L
Mistroke
.68939 .17719 L
.69911 .18022 L
.70882 .18345 L
.7114 .18434 L
.71853 .18688 L
.72824 .1905 L
.73731 .19406 L
.73796 .19432 L
.74767 .19833 L
.75738 .20254 L
.76013 .20377 L
.76709 .20695 L
.77681 .21156 L
.78075 .21348 L
.78652 .21636 L
.79623 .22135 L
.79972 .22319 L
.80594 .22655 L
.81566 .23194 L
.81736 .23291 L
.82537 .23752 L
.83394 .24262 L
.83508 .24331 L
.84479 .24929 L
.84962 .25233 L
.85451 .25546 L
.86422 .26184 L
.86453 .26204 L
.87393 .26841 L
.87877 .27176 L
.88364 .27517 L
.89244 .28147 L
.89336 .28214 L
.90307 .28929 L
.90558 .29118 L
.91278 .29665 L
.91827 .30089 L
.92249 .3042 L
.93054 .31061 L
.93221 .31195 L
.94192 .3199 L
.94243 .32032 L
.95163 .32804 L
.95397 .33003 L
.96134 .33638 L
.9652 .33974 L
.97106 .34491 L
.97614 .34946 L
.98077 .35364 L
Mfstroke
.85 g
.01923 .53324 m
.02748 .52428 L
.02894 .5227 L
.03657 .51457 L
.03866 .51237 L
.04583 .50486 L
.04837 .50223 L
.05527 .49514 L
.05808 .49228 L
.06489 .48543 L
.06779 .48254 L
.07471 .47572 L
.07751 .47299 L
.08473 .46601 L
.08722 .46363 L
.09498 .45629 L
.09693 .45447 L
.10547 .44658 L
.10664 .44551 L
.11622 .43687 L
.11636 .43675 L
.12607 .42818 L
.12725 .42716 L
.13578 .41981 L
.13857 .41744 L
.14549 .41164 L
.15022 .40773 L
.15521 .40366 L
.16222 .39802 L
.16492 .39588 L
.17461 .38831 L
.17463 .38829 L
.18434 .38091 L
.18744 .37859 L
.19406 .37371 L
.20074 .36888 L
.20377 .36672 L
.21348 .35992 L
.21457 .35917 L
.22319 .35332 L
.22902 .34946 L
.23291 .34691 L
.24262 .34071 L
.24415 .33974 L
.25233 .33469 L
.26009 .33003 L
.26204 .32888 L
.27176 .32326 L
.27698 .32032 L
.28147 .31784 L
.29118 .31261 L
.29501 .31061 L
.30089 .30758 L
.31061 .30275 L
.31445 .30089 L
.32032 .29811 L
.33003 .29368 L
.33569 .29118 L
.33974 .28943 L
.34946 .28539 L
.35917 .28154 L
.35934 .28147 L
.36888 .27788 L
.37859 .27443 L
.38651 .27176 L
.38831 .27117 L
.39802 .2681 L
.40773 .26524 L
.41744 .26257 L
.41944 .26204 L
.42716 .26009 L
.43687 .25782 L
.44658 .25574 L
.45629 .25385 L
.465 .25233 L
.46601 .25217 L
.47572 .25067 L
.48543 .24938 L
.49514 .24828 L
.50486 .24738 L
.51457 .24668 L
.52428 .24617 L
.53399 .24586 L
.54371 .24574 L
.55342 .24583 L
.56313 .2461 L
.57284 .24658 L
.58256 .24725 L
.59227 .24812 L
.60198 .24918 L
.61169 .25045 L
.62141 .2519 L
.62403 .25233 L
.63112 .25356 L
.64083 .25541 L
.65054 .25746 L
.66026 .2597 L
.66959 .26204 L
.66997 .26214 L
.67968 .26478 L
.68939 .26761 L
.69911 .27064 L
.70252 .27176 L
.70882 .27387 L
.71853 .27729 L
.72824 .28092 L
.72968 .28147 L
.73796 .28473 L
.74767 .28875 L
.75334 .29118 L
.75738 .29296 L
.76709 .29736 L
.77458 .30089 L
.77681 .30197 L
.78652 .30676 L
.79402 .31061 L
.79623 .31176 L
.80594 .31695 L
.81205 .32032 L
.81566 .32234 L
.82537 .32793 L
.82894 .33003 L
.83508 .33371 L
.84479 .33969 L
.84488 .33974 L
.85451 .34587 L
.86001 .34946 L
.86422 .35224 L
.87393 .35881 L
.87446 .35917 L
.88364 .36557 L
.88829 .36888 L
.89336 .37254 L
.90159 .37859 L
.90307 .37969 L
.91278 .38705 L
.91441 .38831 L
.92249 .3946 L
.92681 .39802 L
.93221 .40235 L
.93881 .40773 L
.94192 .4103 L
.95046 .41744 L
.95163 .41844 L
.96134 .42678 L
.96178 .42716 L
.97106 .43531 L
.97281 .43687 L
.98077 .44404 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .53324 m
.02748 .52428 L
.02894 .5227 L
.03657 .51457 L
.03866 .51237 L
.04583 .50486 L
.04837 .50223 L
.05527 .49514 L
.05808 .49228 L
.06489 .48543 L
.06779 .48254 L
.07471 .47572 L
.07751 .47299 L
.08473 .46601 L
.08722 .46363 L
.09498 .45629 L
.09693 .45447 L
.10547 .44658 L
.10664 .44551 L
.11622 .43687 L
.11636 .43675 L
.12607 .42818 L
.12725 .42716 L
.13578 .41981 L
.13857 .41744 L
.14549 .41164 L
.15022 .40773 L
.15521 .40366 L
.16222 .39802 L
.16492 .39588 L
.17461 .38831 L
.17463 .38829 L
.18434 .38091 L
.18744 .37859 L
.19406 .37371 L
.20074 .36888 L
.20377 .36672 L
.21348 .35992 L
.21457 .35917 L
.22319 .35332 L
.22902 .34946 L
.23291 .34691 L
.24262 .34071 L
.24415 .33974 L
.25233 .33469 L
.26009 .33003 L
.26204 .32888 L
.27176 .32326 L
.27698 .32032 L
.28147 .31784 L
Mistroke
.29118 .31261 L
.29501 .31061 L
.30089 .30758 L
.31061 .30275 L
.31445 .30089 L
.32032 .29811 L
.33003 .29368 L
.33569 .29118 L
.33974 .28943 L
.34946 .28539 L
.35917 .28154 L
.35934 .28147 L
.36888 .27788 L
.37859 .27443 L
.38651 .27176 L
.38831 .27117 L
.39802 .2681 L
.40773 .26524 L
.41744 .26257 L
.41944 .26204 L
.42716 .26009 L
.43687 .25782 L
.44658 .25574 L
.45629 .25385 L
.465 .25233 L
.46601 .25217 L
.47572 .25067 L
.48543 .24938 L
.49514 .24828 L
.50486 .24738 L
.51457 .24668 L
.52428 .24617 L
.53399 .24586 L
.54371 .24574 L
.55342 .24583 L
.56313 .2461 L
.57284 .24658 L
.58256 .24725 L
.59227 .24812 L
.60198 .24918 L
.61169 .25045 L
.62141 .2519 L
.62403 .25233 L
.63112 .25356 L
.64083 .25541 L
.65054 .25746 L
.66026 .2597 L
.66959 .26204 L
.66997 .26214 L
.67968 .26478 L
Mistroke
.68939 .26761 L
.69911 .27064 L
.70252 .27176 L
.70882 .27387 L
.71853 .27729 L
.72824 .28092 L
.72968 .28147 L
.73796 .28473 L
.74767 .28875 L
.75334 .29118 L
.75738 .29296 L
.76709 .29736 L
.77458 .30089 L
.77681 .30197 L
.78652 .30676 L
.79402 .31061 L
.79623 .31176 L
.80594 .31695 L
.81205 .32032 L
.81566 .32234 L
.82537 .32793 L
.82894 .33003 L
.83508 .33371 L
.84479 .33969 L
.84488 .33974 L
.85451 .34587 L
.86001 .34946 L
.86422 .35224 L
.87393 .35881 L
.87446 .35917 L
.88364 .36557 L
.88829 .36888 L
.89336 .37254 L
.90159 .37859 L
.90307 .37969 L
.91278 .38705 L
.91441 .38831 L
.92249 .3946 L
.92681 .39802 L
.93221 .40235 L
.93881 .40773 L
.94192 .4103 L
.95046 .41744 L
.95163 .41844 L
.96134 .42678 L
.96178 .42716 L
.97106 .43531 L
.97281 .43687 L
.98077 .44404 L
Mfstroke
.925 g
.01923 .64279 m
.02102 .64083 L
.02894 .63225 L
.03 .63112 L
.03866 .6219 L
.03913 .62141 L
.04837 .61175 L
.04843 .61169 L
.0579 .60198 L
.05808 .6018 L
.06757 .59227 L
.06779 .59205 L
.07744 .58256 L
.07751 .58249 L
.08722 .57313 L
.08751 .57284 L
.09693 .56396 L
.09782 .56313 L
.10664 .55499 L
.10837 .55342 L
.11636 .54622 L
.11918 .54371 L
.12607 .53764 L
.13027 .53399 L
.13578 .52926 L
.14167 .52428 L
.14549 .52108 L
.1534 .51457 L
.15521 .51309 L
.16492 .50531 L
.16549 .50486 L
.17463 .49771 L
.17798 .49514 L
.18434 .49032 L
.19091 .48543 L
.19406 .48312 L
.20377 .47612 L
.20433 .47572 L
.21348 .46931 L
.2183 .46601 L
.22319 .4627 L
.2329 .45629 L
.23291 .45629 L
.24262 .45007 L
.24822 .44658 L
.25233 .44405 L
.26204 .43823 L
.26437 .43687 L
.27176 .43261 L
.28147 .42718 L
.28151 .42716 L
.29118 .42195 L
.29985 .41744 L
.30089 .41691 L
.31061 .41207 L
.31967 .40773 L
.32032 .40743 L
.33003 .40298 L
.33974 .39873 L
.34142 .39802 L
.34946 .39468 L
.35917 .39083 L
.3658 .38831 L
.36888 .38717 L
.37859 .3837 L
.38831 .38044 L
.39407 .37859 L
.39802 .37737 L
.40773 .3745 L
.41744 .37182 L
.42716 .36934 L
.42906 .36888 L
.43687 .36706 L
.44658 .36498 L
.45629 .36309 L
.46601 .36139 L
.47572 .3599 L
.48099 .35917 L
.48543 .3586 L
.49514 .3575 L
.50486 .35659 L
.51457 .35588 L
.52428 .35537 L
.53399 .35506 L
.54371 .35494 L
.55342 .35501 L
.56313 .35529 L
.57284 .35576 L
.58256 .35643 L
.59227 .35729 L
.60198 .35835 L
.60845 .35917 L
.61169 .35961 L
.62141 .36107 L
.63112 .36272 L
.64083 .36457 L
.65054 .36661 L
.66026 .36885 L
.66038 .36888 L
.66997 .37129 L
.67968 .37392 L
.68939 .37675 L
.69537 .37859 L
.69911 .37978 L
.70882 .38301 L
.71853 .38643 L
.72364 .38831 L
.72824 .39005 L
.73796 .39386 L
.74767 .39787 L
.74802 .39802 L
.75738 .40208 L
.76709 .40648 L
.76977 .40773 L
.77681 .41109 L
.78652 .41588 L
.7896 .41744 L
.79623 .42088 L
.80594 .42607 L
.80793 .42716 L
.81566 .43146 L
.82507 .43687 L
.82537 .43704 L
.83508 .44282 L
.84123 .44658 L
.84479 .4488 L
.85451 .45497 L
.85654 .45629 L
.86422 .46135 L
.87114 .46601 L
.87393 .46791 L
.88364 .47468 L
.88511 .47572 L
.89336 .48164 L
.89854 .48543 L
.90307 .4888 L
.91147 .49514 L
.91278 .49615 L
.92249 .5037 L
.92396 .50486 L
.93221 .51145 L
.93605 .51457 L
.94192 .5194 L
.94778 .52428 L
.95163 .52754 L
.95917 .53399 L
.96134 .53587 L
.97027 .54371 L
.97106 .54441 L
.98077 .55314 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .64279 m
.02102 .64083 L
.02894 .63225 L
.03 .63112 L
.03866 .6219 L
.03913 .62141 L
.04837 .61175 L
.04843 .61169 L
.0579 .60198 L
.05808 .6018 L
.06757 .59227 L
.06779 .59205 L
.07744 .58256 L
.07751 .58249 L
.08722 .57313 L
.08751 .57284 L
.09693 .56396 L
.09782 .56313 L
.10664 .55499 L
.10837 .55342 L
.11636 .54622 L
.11918 .54371 L
.12607 .53764 L
.13027 .53399 L
.13578 .52926 L
.14167 .52428 L
.14549 .52108 L
.1534 .51457 L
.15521 .51309 L
.16492 .50531 L
.16549 .50486 L
.17463 .49771 L
.17798 .49514 L
.18434 .49032 L
.19091 .48543 L
.19406 .48312 L
.20377 .47612 L
.20433 .47572 L
.21348 .46931 L
.2183 .46601 L
.22319 .4627 L
.2329 .45629 L
.23291 .45629 L
.24262 .45007 L
.24822 .44658 L
.25233 .44405 L
.26204 .43823 L
.26437 .43687 L
.27176 .43261 L
.28147 .42718 L
Mistroke
.28151 .42716 L
.29118 .42195 L
.29985 .41744 L
.30089 .41691 L
.31061 .41207 L
.31967 .40773 L
.32032 .40743 L
.33003 .40298 L
.33974 .39873 L
.34142 .39802 L
.34946 .39468 L
.35917 .39083 L
.3658 .38831 L
.36888 .38717 L
.37859 .3837 L
.38831 .38044 L
.39407 .37859 L
.39802 .37737 L
.40773 .3745 L
.41744 .37182 L
.42716 .36934 L
.42906 .36888 L
.43687 .36706 L
.44658 .36498 L
.45629 .36309 L
.46601 .36139 L
.47572 .3599 L
.48099 .35917 L
.48543 .3586 L
.49514 .3575 L
.50486 .35659 L
.51457 .35588 L
.52428 .35537 L
.53399 .35506 L
.54371 .35494 L
.55342 .35501 L
.56313 .35529 L
.57284 .35576 L
.58256 .35643 L
.59227 .35729 L
.60198 .35835 L
.60845 .35917 L
.61169 .35961 L
.62141 .36107 L
.63112 .36272 L
.64083 .36457 L
.65054 .36661 L
.66026 .36885 L
.66038 .36888 L
.66997 .37129 L
Mistroke
.67968 .37392 L
.68939 .37675 L
.69537 .37859 L
.69911 .37978 L
.70882 .38301 L
.71853 .38643 L
.72364 .38831 L
.72824 .39005 L
.73796 .39386 L
.74767 .39787 L
.74802 .39802 L
.75738 .40208 L
.76709 .40648 L
.76977 .40773 L
.77681 .41109 L
.78652 .41588 L
.7896 .41744 L
.79623 .42088 L
.80594 .42607 L
.80793 .42716 L
.81566 .43146 L
.82507 .43687 L
.82537 .43704 L
.83508 .44282 L
.84123 .44658 L
.84479 .4488 L
.85451 .45497 L
.85654 .45629 L
.86422 .46135 L
.87114 .46601 L
.87393 .46791 L
.88364 .47468 L
.88511 .47572 L
.89336 .48164 L
.89854 .48543 L
.90307 .4888 L
.91147 .49514 L
.91278 .49615 L
.92249 .5037 L
.92396 .50486 L
.93221 .51145 L
.93605 .51457 L
.94192 .5194 L
.94778 .52428 L
.95163 .52754 L
.95917 .53399 L
.96134 .53587 L
.97027 .54371 L
.97106 .54441 L
.98077 .55314 L
Mistroke
Mfstroke
1 g
.01923 .79296 m
.02513 .78652 L
.02894 .7824 L
.03415 .77681 L
.03866 .77203 L
.04334 .76709 L
.04837 .76185 L
.0527 .75738 L
.05808 .75188 L
.06224 .74767 L
.06779 .7421 L
.07197 .73796 L
.07751 .73251 L
.0819 .72824 L
.08722 .72313 L
.09205 .71853 L
.09693 .71394 L
.10244 .70882 L
.10664 .70495 L
.11307 .69911 L
.11636 .69615 L
.12397 .68939 L
.12607 .68756 L
.13517 .67968 L
.13578 .67916 L
.14549 .67095 L
.14667 .66997 L
.15521 .66294 L
.15852 .66026 L
.16492 .65513 L
.17074 .65054 L
.17463 .64752 L
.18338 .64083 L
.18434 .64011 L
.19406 .63289 L
.19647 .63112 L
.20377 .62586 L
.21008 .62141 L
.21348 .61904 L
.22319 .61241 L
.22426 .61169 L
.23291 .60598 L
.2391 .60198 L
.24262 .59974 L
.25233 .59371 L
.25469 .59227 L
.26204 .58787 L
.27117 .58256 L
.27176 .58222 L
.28147 .57677 L
.28871 .57284 L
.29118 .57152 L
.30089 .56647 L
.30753 .56313 L
.31061 .56162 L
.32032 .55696 L
.32798 .55342 L
.33003 .55249 L
.33974 .54823 L
.34946 .54416 L
.35057 .54371 L
.35917 .54029 L
.36888 .53661 L
.37615 .53399 L
.37859 .53314 L
.38831 .52986 L
.39802 .52677 L
.40636 .52428 L
.40773 .52389 L
.41744 .5212 L
.42716 .5187 L
.43687 .51641 L
.44532 .51457 L
.44658 .51431 L
.45629 .5124 L
.46601 .5107 L
.47572 .50919 L
.48543 .50788 L
.49514 .50676 L
.50486 .50585 L
.51457 .50513 L
.51891 .50486 L
.52428 .5046 L
.53399 .50428 L
.54371 .50415 L
.55342 .50421 L
.56313 .50448 L
.57158 .50486 L
.57284 .50494 L
.58256 .50559 L
.59227 .50645 L
.60198 .5075 L
.61169 .50875 L
.62141 .51019 L
.63112 .51184 L
.64083 .51368 L
.64521 .51457 L
.65054 .51571 L
.66026 .51794 L
.66997 .52037 L
.67968 .523 L
.68417 .52428 L
.68939 .52583 L
.69911 .52885 L
.70882 .53206 L
.71438 .53399 L
.71853 .53548 L
.72824 .53909 L
.73796 .5429 L
.73996 .54371 L
.74767 .5469 L
.75738 .55111 L
.76254 .55342 L
.76709 .5555 L
.77681 .5601 L
.783 .56313 L
.78652 .56489 L
.79623 .56988 L
.80182 .57284 L
.80594 .57507 L
.81566 .58045 L
.81936 .58256 L
.82537 .58603 L
.83508 .59181 L
.83584 .59227 L
.84479 .59779 L
.85143 .60198 L
.85451 .60396 L
.86422 .61032 L
.86627 .61169 L
.87393 .61689 L
.88045 .62141 L
.88364 .62365 L
.89336 .63061 L
.89406 .63112 L
.90307 .63777 L
.90715 .64083 L
.91278 .64512 L
.91979 .65054 L
.92249 .65267 L
.93201 .66026 L
.93221 .66042 L
.94192 .66836 L
.94386 .66997 L
.95163 .6765 L
.95537 .67968 L
.96134 .68484 L
.96656 .68939 L
.97106 .69337 L
.97746 .69911 L
.98077 .7021 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .79296 m
.02513 .78652 L
.02894 .7824 L
.03415 .77681 L
.03866 .77203 L
.04334 .76709 L
.04837 .76185 L
.0527 .75738 L
.05808 .75188 L
.06224 .74767 L
.06779 .7421 L
.07197 .73796 L
.07751 .73251 L
.0819 .72824 L
.08722 .72313 L
.09205 .71853 L
.09693 .71394 L
.10244 .70882 L
.10664 .70495 L
.11307 .69911 L
.11636 .69615 L
.12397 .68939 L
.12607 .68756 L
.13517 .67968 L
.13578 .67916 L
.14549 .67095 L
.14667 .66997 L
.15521 .66294 L
.15852 .66026 L
.16492 .65513 L
.17074 .65054 L
.17463 .64752 L
.18338 .64083 L
.18434 .64011 L
.19406 .63289 L
.19647 .63112 L
.20377 .62586 L
.21008 .62141 L
.21348 .61904 L
.22319 .61241 L
.22426 .61169 L
.23291 .60598 L
.2391 .60198 L
.24262 .59974 L
.25233 .59371 L
.25469 .59227 L
.26204 .58787 L
.27117 .58256 L
.27176 .58222 L
.28147 .57677 L
Mistroke
.28871 .57284 L
.29118 .57152 L
.30089 .56647 L
.30753 .56313 L
.31061 .56162 L
.32032 .55696 L
.32798 .55342 L
.33003 .55249 L
.33974 .54823 L
.34946 .54416 L
.35057 .54371 L
.35917 .54029 L
.36888 .53661 L
.37615 .53399 L
.37859 .53314 L
.38831 .52986 L
.39802 .52677 L
.40636 .52428 L
.40773 .52389 L
.41744 .5212 L
.42716 .5187 L
.43687 .51641 L
.44532 .51457 L
.44658 .51431 L
.45629 .5124 L
.46601 .5107 L
.47572 .50919 L
.48543 .50788 L
.49514 .50676 L
.50486 .50585 L
.51457 .50513 L
.51891 .50486 L
.52428 .5046 L
.53399 .50428 L
.54371 .50415 L
.55342 .50421 L
.56313 .50448 L
.57158 .50486 L
.57284 .50494 L
.58256 .50559 L
.59227 .50645 L
.60198 .5075 L
.61169 .50875 L
.62141 .51019 L
.63112 .51184 L
.64083 .51368 L
.64521 .51457 L
.65054 .51571 L
.66026 .51794 L
.66997 .52037 L
Mistroke
.67968 .523 L
.68417 .52428 L
.68939 .52583 L
.69911 .52885 L
.70882 .53206 L
.71438 .53399 L
.71853 .53548 L
.72824 .53909 L
.73796 .5429 L
.73996 .54371 L
.74767 .5469 L
.75738 .55111 L
.76254 .55342 L
.76709 .5555 L
.77681 .5601 L
.783 .56313 L
.78652 .56489 L
.79623 .56988 L
.80182 .57284 L
.80594 .57507 L
.81566 .58045 L
.81936 .58256 L
.82537 .58603 L
.83508 .59181 L
.83584 .59227 L
.84479 .59779 L
.85143 .60198 L
.85451 .60396 L
.86422 .61032 L
.86627 .61169 L
.87393 .61689 L
.88045 .62141 L
.88364 .62365 L
.89336 .63061 L
.89406 .63112 L
.90307 .63777 L
.90715 .64083 L
.91278 .64512 L
.91979 .65054 L
.92249 .65267 L
.93201 .66026 L
.93221 .66042 L
.94192 .66836 L
.94386 .66997 L
.95163 .6765 L
.95537 .67968 L
.96134 .68484 L
.96656 .68939 L
.97106 .69337 L
.97746 .69911 L
Mistroke
.98077 .7021 L
Mfstroke
.55 g
.01923 .29242 m
.02037 .29118 L
.02894 .2819 L
.02935 .28147 L
.03849 .27176 L
.03866 .27158 L
.04779 .26204 L
.04837 .26145 L
.05728 .25233 L
.05808 .25151 L
.06695 .24262 L
.06779 .24178 L
.07682 .23291 L
.07751 .23224 L
.08691 .22319 L
.08722 .2229 L
.09693 .21375 L
.09722 .21348 L
.10664 .2048 L
.10777 .20377 L
.11636 .19604 L
.11859 .19406 L
.12607 .18749 L
.12969 .18434 L
.13578 .17913 L
.1411 .17463 L
.14549 .17096 L
.15284 .16492 L
.15521 .16299 L
.16492 .15522 L
.16494 .15521 L
.17463 .14765 L
.17744 .14549 L
.18434 .14027 L
.19038 .13578 L
.19406 .13309 L
.20377 .1261 L
.20381 .12607 L
.21348 .11931 L
.2178 .11636 L
.22319 .11272 L
.23241 .10664 L
.23291 .10632 L
.24262 .10012 L
.24774 .09693 L
.25233 .09412 L
.26204 .08831 L
.26391 .08722 L
.27176 .0827 L
.28107 .07751 L
.28147 .07729 L
.29118 .07207 L
.29943 .06779 L
.30089 .06705 L
.31061 .06222 L
.31928 .05808 L
.32032 .0576 L
.33003 .05316 L
.33974 .04893 L
.34106 .04837 L
.34946 .04489 L
.35917 .04105 L
.36548 .03866 L
.36888 .0374 L
.37859 .03395 L
.38831 .0307 L
.39381 .02894 L
.39802 .02764 L
.40773 .02478 L
.41744 .02212 L
.42716 .01965 L
.42889 .01923 L
.01923 .01923 L
F
0 g
.01923 .29242 m
.02037 .29118 L
.02894 .2819 L
.02935 .28147 L
.03849 .27176 L
.03866 .27158 L
.04779 .26204 L
.04837 .26145 L
.05728 .25233 L
.05808 .25151 L
.06695 .24262 L
.06779 .24178 L
.07682 .23291 L
.07751 .23224 L
.08691 .22319 L
.08722 .2229 L
.09693 .21375 L
.09722 .21348 L
.10664 .2048 L
.10777 .20377 L
.11636 .19604 L
.11859 .19406 L
.12607 .18749 L
.12969 .18434 L
.13578 .17913 L
.1411 .17463 L
.14549 .17096 L
.15284 .16492 L
.15521 .16299 L
.16492 .15522 L
.16494 .15521 L
.17463 .14765 L
.17744 .14549 L
.18434 .14027 L
.19038 .13578 L
.19406 .13309 L
.20377 .1261 L
.20381 .12607 L
.21348 .11931 L
.2178 .11636 L
.22319 .11272 L
.23241 .10664 L
.23291 .10632 L
.24262 .10012 L
.24774 .09693 L
.25233 .09412 L
.26204 .08831 L
.26391 .08722 L
.27176 .0827 L
.28107 .07751 L
Mistroke
.28147 .07729 L
.29118 .07207 L
.29943 .06779 L
.30089 .06705 L
.31061 .06222 L
.31928 .05808 L
.32032 .0576 L
.33003 .05316 L
.33974 .04893 L
.34106 .04837 L
.34946 .04489 L
.35917 .04105 L
.36548 .03866 L
.36888 .0374 L
.37859 .03395 L
.38831 .0307 L
.39381 .02894 L
.39802 .02764 L
.40773 .02478 L
.41744 .02212 L
.42716 .01965 L
.42889 .01923 L
Mfstroke
.475 g
.01923 .22734 m
.02304 .22319 L
.02894 .21682 L
.03207 .21348 L
.03866 .2065 L
.04126 .20377 L
.04837 .19637 L
.05062 .19406 L
.05808 .18644 L
.06016 .18434 L
.06779 .17671 L
.06989 .17463 L
.07751 .16717 L
.07983 .16492 L
.08722 .15783 L
.08998 .15521 L
.09693 .14868 L
.10037 .14549 L
.10664 .13973 L
.111 .13578 L
.11636 .13098 L
.12191 .12607 L
.12607 .12243 L
.1331 .11636 L
.13578 .11407 L
.1446 .10664 L
.14549 .1059 L
.15521 .09794 L
.15645 .09693 L
.16492 .09017 L
.16867 .08722 L
.17463 .08259 L
.1813 .07751 L
.18434 .07522 L
.19406 .06804 L
.19439 .06779 L
.20377 .06105 L
.20798 .05808 L
.21348 .05426 L
.22215 .04837 L
.22319 .04767 L
.23291 .04128 L
.23698 .03866 L
.24262 .03508 L
.25233 .02908 L
.25255 .02894 L
.26204 .02327 L
.26901 .01923 L
.01923 .01923 L
F
0 g
.01923 .22734 m
.02304 .22319 L
.02894 .21682 L
.03207 .21348 L
.03866 .2065 L
.04126 .20377 L
.04837 .19637 L
.05062 .19406 L
.05808 .18644 L
.06016 .18434 L
.06779 .17671 L
.06989 .17463 L
.07751 .16717 L
.07983 .16492 L
.08722 .15783 L
.08998 .15521 L
.09693 .14868 L
.10037 .14549 L
.10664 .13973 L
.111 .13578 L
.11636 .13098 L
.12191 .12607 L
.12607 .12243 L
.1331 .11636 L
.13578 .11407 L
.1446 .10664 L
.14549 .1059 L
.15521 .09794 L
.15645 .09693 L
.16492 .09017 L
.16867 .08722 L
.17463 .08259 L
.1813 .07751 L
.18434 .07522 L
.19406 .06804 L
.19439 .06779 L
.20377 .06105 L
.20798 .05808 L
.21348 .05426 L
.22215 .04837 L
.22319 .04767 L
.23291 .04128 L
.23698 .03866 L
.24262 .03508 L
.25233 .02908 L
.25255 .02894 L
.26204 .02327 L
.26901 .01923 L
s
.4 g
.01923 .16695 m
.02109 .16492 L
.02894 .15643 L
.03009 .15521 L
.03866 .14611 L
.03924 .14549 L
.04837 .13598 L
.04856 .13578 L
.05807 .12607 L
.05808 .12605 L
.06776 .11636 L
.06779 .11632 L
.07751 .10678 L
.07765 .10664 L
.08722 .09744 L
.08776 .09693 L
.09693 .0883 L
.09809 .08722 L
.10664 .07935 L
.10867 .07751 L
.11636 .0706 L
.11952 .06779 L
.12607 .06205 L
.13065 .05808 L
.13578 .05369 L
.14209 .04837 L
.14549 .04553 L
.15386 .03866 L
.15521 .03756 L
.16492 .02979 L
.166 .02894 L
.17463 .02222 L
.17854 .01923 L
.01923 .01923 L
F
0 g
.01923 .16695 m
.02109 .16492 L
.02894 .15643 L
.03009 .15521 L
.03866 .14611 L
.03924 .14549 L
.04837 .13598 L
.04856 .13578 L
.05807 .12607 L
.05808 .12605 L
.06776 .11636 L
.06779 .11632 L
.07751 .10678 L
.07765 .10664 L
.08722 .09744 L
.08776 .09693 L
.09693 .0883 L
.09809 .08722 L
.10664 .07935 L
.10867 .07751 L
.11636 .0706 L
.11952 .06779 L
.12607 .06205 L
.13065 .05808 L
.13578 .05369 L
.14209 .04837 L
.14549 .04553 L
.15386 .03866 L
.15521 .03756 L
.16492 .02979 L
.166 .02894 L
.17463 .02222 L
.17854 .01923 L
s
.325 g
.01923 .11036 m
.02264 .10664 L
.02894 .09984 L
.03166 .09693 L
.03866 .08952 L
.04084 .08722 L
.04837 .07939 L
.0502 .07751 L
.05808 .06946 L
.05973 .06779 L
.06779 .05973 L
.06946 .05808 L
.07751 .0502 L
.07939 .04837 L
.08722 .04086 L
.08954 .03866 L
.09693 .03172 L
.09992 .02894 L
.10664 .02277 L
.11055 .01923 L
.01923 .01923 L
F
0 g
.01923 .11036 m
.02264 .10664 L
.02894 .09984 L
.03166 .09693 L
.03866 .08952 L
.04084 .08722 L
.04837 .07939 L
.0502 .07751 L
.05808 .06946 L
.05973 .06779 L
.06779 .05973 L
.06946 .05808 L
.07751 .0502 L
.07939 .04837 L
.08722 .04086 L
.08954 .03866 L
.09693 .03172 L
.09992 .02894 L
.10664 .02277 L
.11055 .01923 L
s
.25 g
.01923 .05692 m
.02712 .04837 L
.02894 .04641 L
.03622 .03866 L
.03866 .03609 L
.04549 .02894 L
.04837 .02596 L
.05493 .01923 L
.01923 .01923 L
F
0 g
.01923 .05692 m
.02712 .04837 L
.02894 .04641 L
.03622 .03866 L
.03866 .03609 L
.04549 .02894 L
.04837 .02596 L
.05493 .01923 L
s
.55 g
.98077 .20378 m
.98075 .20377 L
.97106 .19505 L
.96994 .19406 L
.96134 .18652 L
.95884 .18434 L
.95163 .17818 L
.94743 .17463 L
.94192 .17004 L
.93569 .16492 L
.93221 .16209 L
.92359 .15521 L
.92249 .15434 L
.91278 .14679 L
.91109 .14549 L
.90307 .13943 L
.89815 .13578 L
.89336 .13227 L
.88472 .12607 L
.88364 .12531 L
.87393 .11854 L
.87073 .11636 L
.86422 .11197 L
.85612 .10664 L
.85451 .1056 L
.84479 .09942 L
.84079 .09693 L
.83508 .09344 L
.82537 .08766 L
.82462 .08722 L
.81566 .08207 L
.80746 .07751 L
.80594 .07668 L
.79623 .07148 L
.7891 .06779 L
.78652 .06648 L
.77681 .06168 L
.76925 .05808 L
.76709 .05708 L
.75738 .05267 L
.74767 .04845 L
.74747 .04837 L
.73796 .04444 L
.72824 .04062 L
.72305 .03866 L
.71853 .03699 L
.70882 .03357 L
.69911 .03034 L
.69472 .02894 L
.68939 .0273 L
.67968 .02447 L
.66997 .02183 L
.66026 .01938 L
.65964 .01923 L
.98077 .01923 L
F
0 g
.98077 .20378 m
.98075 .20377 L
.97106 .19505 L
.96994 .19406 L
.96134 .18652 L
.95884 .18434 L
.95163 .17818 L
.94743 .17463 L
.94192 .17004 L
.93569 .16492 L
.93221 .16209 L
.92359 .15521 L
.92249 .15434 L
.91278 .14679 L
.91109 .14549 L
.90307 .13943 L
.89815 .13578 L
.89336 .13227 L
.88472 .12607 L
.88364 .12531 L
.87393 .11854 L
.87073 .11636 L
.86422 .11197 L
.85612 .10664 L
.85451 .1056 L
.84479 .09942 L
.84079 .09693 L
.83508 .09344 L
.82537 .08766 L
.82462 .08722 L
.81566 .08207 L
.80746 .07751 L
.80594 .07668 L
.79623 .07148 L
.7891 .06779 L
.78652 .06648 L
.77681 .06168 L
.76925 .05808 L
.76709 .05708 L
.75738 .05267 L
.74767 .04845 L
.74747 .04837 L
.73796 .04444 L
.72824 .04062 L
.72305 .03866 L
.71853 .03699 L
.70882 .03357 L
.69911 .03034 L
.69472 .02894 L
.68939 .0273 L
Mistroke
.67968 .02447 L
.66997 .02183 L
.66026 .01938 L
.65964 .01923 L
Mfstroke
.475 g
.98077 .1388 m
.97744 .13578 L
.97106 .13006 L
.96654 .12607 L
.96134 .12153 L
.95535 .11636 L
.95163 .11319 L
.94384 .10664 L
.94192 .10505 L
.93221 .0971 L
.93199 .09693 L
.92249 .08935 L
.91977 .08722 L
.91278 .0818 L
.90714 .07751 L
.90307 .07444 L
.89406 .06779 L
.89336 .06729 L
.88364 .06032 L
.88046 .05808 L
.87393 .05355 L
.86629 .04837 L
.86422 .04698 L
.85451 .04061 L
.85147 .03866 L
.84479 .03443 L
.83589 .02894 L
.83508 .02845 L
.82537 .02267 L
.81944 .01923 L
.98077 .01923 L
F
0 g
.98077 .1388 m
.97744 .13578 L
.97106 .13006 L
.96654 .12607 L
.96134 .12153 L
.95535 .11636 L
.95163 .11319 L
.94384 .10664 L
.94192 .10505 L
.93221 .0971 L
.93199 .09693 L
.92249 .08935 L
.91977 .08722 L
.91278 .0818 L
.90714 .07751 L
.90307 .07444 L
.89406 .06779 L
.89336 .06729 L
.88364 .06032 L
.88046 .05808 L
.87393 .05355 L
.86629 .04837 L
.86422 .04698 L
.85451 .04061 L
.85147 .03866 L
.84479 .03443 L
.83589 .02894 L
.83508 .02845 L
.82537 .02267 L
.81944 .01923 L
s
.4 g
.98077 .07848 m
.9797 .07751 L
.97106 .06975 L
.96885 .06779 L
.96134 .06121 L
.95773 .05808 L
.95163 .05287 L
.94629 .04837 L
.94192 .04473 L
.93452 .03866 L
.93221 .03678 L
.92249 .02904 L
.92238 .02894 L
.91278 .02148 L
.90984 .01923 L
.98077 .01923 L
F
0 g
.98077 .07848 m
.9797 .07751 L
.97106 .06975 L
.96885 .06779 L
.96134 .06121 L
.95773 .05808 L
.95163 .05287 L
.94629 .04837 L
.94192 .04473 L
.93452 .03866 L
.93221 .03678 L
.92249 .02904 L
.92238 .02894 L
.91278 .02148 L
.90984 .01923 L
s
.325 g
.98077 .02195 m
.97777 .01923 L
.98077 .01923 L
F
0 g
.98077 .02195 m
.97777 .01923 L
s
0 0 0 r
.055 w
.98077 .98077 Mdot
.5 0 .5 r
.04 w
.01923 .98077 Mdot
.15147 .92436 Mdot
.20412 .89963 Mdot
.29231 .84032 Mdot
.33586 .82539 Mdot
.42134 .79042 Mdot
.46058 .78775 Mdot
.53846 .77594 Mdot
.5766 .78161 Mdot
.65332 .78843 Mdot
.72742 .81137 Mdot
.79835 .84418 Mdot
.86567 .8851 Mdot
.9293 .93248 Mdot
.98077 .97801 Mdot
.98077 .98077 Mdot
1 1 0 r
.025 w
.01923 .98077 Mdot
.98077 .01923 Mdot
.15147 .92436 Mdot
.38674 .75066 Mdot
.20412 .89963 Mdot
.29231 .84032 Mdot
.48189 .74905 Mdot
.33586 .82539 Mdot
.42134 .79042 Mdot
.60056 .7522 Mdot
.46058 .78775 Mdot
.53846 .77594 Mdot
.69571 .7804 Mdot
.5766 .78161 Mdot
.65332 .78843 Mdot
.72742 .81137 Mdot
.79835 .84418 Mdot
.86567 .8851 Mdot
.9293 .93248 Mdot
.98077 .97801 Mdot
.98077 .98077 Mdot
0 0 1 r
.5 Mabswid
.01923 .98077 m
.01923 .98077 L
.15147 .92436 L
.20412 .89963 L
.29231 .84032 L
.33586 .82539 L
.42134 .79042 L
.46058 .78775 L
.53846 .77594 L
.5766 .78161 L
.65332 .78843 L
.72742 .81137 L
.79835 .84418 L
.86567 .8851 L
.9293 .93248 L
.98077 .97801 L
.98077 .98077 L
s
.015 w
.01923 .98077 Mdot
.01923 .98077 Mdot
.15147 .92436 Mdot
.20412 .89963 Mdot
.29231 .84032 Mdot
.33586 .82539 Mdot
.42134 .79042 Mdot
.46058 .78775 Mdot
.53846 .77594 Mdot
.5766 .78161 Mdot
.65332 .78843 Mdot
.72742 .81137 Mdot
.79835 .84418 Mdot
.86567 .8851 Mdot
.9293 .93248 Mdot
.98077 .97801 Mdot
.98077 .98077 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00@`3oool7000004X0oooo1000
00060?ooo`8000001P3oool4000004P0oooo1000001<0?ooo`@000001P3oool2000000H0oooo1000
001;0?ooo`L000001P3oool004H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool004H0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool01`3oool004H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool003X0oooo1P0000060?ooo`030000
003oool0oooo0440oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`070?ooo`00AP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool4000004L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool4000004h0oooo00<000000?ooo`3oool01`3oool004H0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3oool0
04@0oooo0`00001<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C@3oool30000
00T0oooo00160?ooo`030000003oool0oooo04/0oooo1000000>0?ooo`D00000A`3oool4000004`0
oooo1000000>0?ooo`D00000C@3oool00`000000oooo0?ooo`070?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`005`3ooooo000009T000000@3oool001L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool100000040oooo000G0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`050?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooon=
0?ooo`80ool01P3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooR`3oool60?oo
00@0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?ooohX0oooo203oo`030?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`P0ool00`3oool100000040oooo
000G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0?@3oool2000005h0oooo0P00
000o0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool:0?oo0080oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`h0?clo00<0000005=CD`1CDe<0501CDe<0
0`000000IVIV06IVIP0H06IVIP030000001iNGT0NGUi0240NGUi0P00000m08b<S0<00000HP2OWil4
000003`0S8b<00<0000007UiN@1iNGT08P1iNGT00`000000IVIV06IVIP0D06IVIPX0ool00P3oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo3@0o?cl00`000000De=C05=CD`0D05=C
D`030000001VIVH0IVIV01P0IVIV00<0000007UiN@1iNGT08@1iNGT00`000000S8b<08b<S00k08b<
S0800000J@2OWil3000003X0S8b<00<0000007UiN@1iNGT08P1iNGT00`000000IVIV06IVIP0D06IV
IPP0ool00`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo300o?cl00`000000
De=C05=CD`0C05=CD`8000006@1VIVH200000280NGUi0P00000k08b<S0<00000KP2OWil2000003T0
S8b<0P00000S07UiN@800000501VIVH80?oo00<0oooo0@0000010?ooo`005`3oool2000000D0oooo
2`0o?cl00`000000De=C05=CD`0C05=CD`030000001VIVH0IVIV01P0IVIV00<0000007UiN@1iNGT0
801iNGT2000003P0S8b<1@00001c09nOW`@00000=`2<S8`2000002<0NGUi00<0000006IVIP1VIVH0
4P1VIVH60?oo00<0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`X0?clo00<0
000005=CD`1CDe<04`1CDe<00`000000IVIV06IVIP0I06IVIP030000001iNGT0NGUi01l0NGUi00<0
000008b<S02<S8`0=@2<S8`3000007`0WinO0`00000f08b<S08000008P1iNGT00`000000IVIV06IV
IP0C06IVIP80ool01P3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2@0o?cl0
0`000000De=C05=CD`0C05=CD`030000001VIVH0IVIV01T0IVIV00<0000007UiN@1iNGT07`1iNGT0
0`000000S8b<08b<S00c08b<S0<00000PP2OWil3000003D0S8b<0P00000Q07UiN@8000004`1VIVH8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool803lo?`030000001CDe<0De=C
01<0De=C00<0000006IVIP1VIVH0601VIVH200000200NGUi0P00000d08b<S0800000R02OWil20000
03D0S8b<0P00000Q07UiN@030000001VIVH0IVIV0100IVIV203oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo1`0o?cl00`000000De=C05=CD`0C05=CD`030000001VIVH0IVIV01L0
IVIV0P00000P07UiN@800000<P2<S8`4000008`0WinO1000000c08b<S0030000001iNGT0NGUi01l0
NGUi00<0000006IVIP1VIVH03`1VIVH80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103oool603lo?`030000001CDe<0De=C01<0De=C00<0000006IVIP1VIVH05`1VIVH00`000000NGUi
07UiN@0O07UiN@030000002<S8`0S8b<0300S8b<0P00002D09nOW`800000<P2<S8`00`000000NGUi
07UiN@0O07UiN@030000001VIVH0IVIV00h0IVIV203oool100000040oooo000G0?ooo`030000003o
ool0oooo00@0oooo1@0o?cl00`000000De=C05=CD`0C05=CD`030000001VIVH0IVIV01L0IVIV00<0
000007UiN@1iNGT07`1iNGT00`000000S8b<08b<S00_08b<S0800000V02OWil200000340S8b<00<0
000007UiN@1iNGT07`1iNGT00`000000IVIV06IVIP0=06IVIPP0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`@0?clo00<0000005=CD`1CDe<04`1CDe<00`000000IVIV06IVIP0G
06IVIP030000001iNGT0NGUi01h0NGUi0P00000_08b<S0<00000W02OWil200000300S8b<0P00000P
07UiN@030000001VIVH0IVIV00`0IVIV203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo100o?cl00`000000De=C05=CD`0B05=CD`030000001VIVH0IVIV01L0IVIV00<0000007Ui
N@1iNGT07@1iNGT2000002h0S8b<0`00002Q09nOW`<00000;`2<S8`2000001l0NGUi00<0000006IV
IP1VIVH02`1VIVH80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool303lo?`03
0000001CDe<0De=C0180De=C00<0000006IVIP1VIVH05P1VIVH2000001l0NGUi00<0000008b<S02<
S8`0;02<S8`200000:L0WinO0P00000_08b<S08000007P1iNGT2000000/0IVIV203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo0P0o?cl00`000000De=C05=CD`0B05=CD`030000
001VIVH0IVIV01H0IVIV00<0000007UiN@1iNGT07P1iNGT00`000000S8b<08b<S00[08b<S0800000
Z`2OWil2000002l0S8b<00<0000007UiN@1iNGT07@1iNGT00`000000IVIV06IVIP0806IVIPP0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`0303lo?`000000De=C01<0De=C00<0
000006IVIP1VIVH05P1VIVH00`000000NGUi07UiN@0M07UiN@800000;02<S8`200000:l0WinO0P00
000^08b<S08000007P1iNGT00`000000IVIV06IVIP0706IVIPP0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`030000001CDe<0De=C0180De=C00<0000006IVIP1VIVH05P1VIVH0
0`000000NGUi07UiN@0L07UiN@800000;02<S8`200000;<0WinO0`00000]08b<S0030000001iNGT0
NGUi01`0NGUi00<0000006IVIP1VIVH01P1VIVH80?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0103ooolD05=CD`030000001VIVH0IVIV01H0IVIV00<0000007UiN@1iNGT0701iNGT00`00
0000S8b<08b<S00Z08b<S0800000^02OWil2000002`0S8b<00<0000007UiN@1iNGT0701iNGT20000
00H0IVIV203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo4`1CDe<00`000000
IVIV06IVIP0F06IVIP030000001iNGT0NGUi01`0NGUi00<0000008b<S02<S8`0:@2<S8`200000;`0
WinO00<0000008b<S02<S8`0:P2<S8`00`000000NGUi07UiN@0M07UiN@030000001VIVH0IVIV00<0
IVIV203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo4P1CDe<00`000000IVIV
06IVIP0E06IVIP8000007@1iNGT2000002X0S8b<0P00002o09nOW`800000:`2<S8`2000001h0NGUi
00<0000006IVIP1VIVH00P1VIVH80?ooo`4000000@3oool001L0oooo0P0000050?oooa40De=C00<0
000006IVIP1VIVH05@1VIVH00`000000NGUi07UiN@0L07UiN@030000002<S8`0S8b<02P0S8b<0P00
003309nOW`<00000:P2<S8`00`000000NGUi07UiN@0L07UiN@040000001VIVH0IVIV06IVIPL0oooo
0P0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa00De=C00<0000006IVIP1VIVH05@1V
IVH00`000000NGUi07UiN@0L07UiN@030000002<S8`0S8b<02L0S8b<0P00003809nOW`800000:@2<
S8`00`000000NGUi07UiN@0L07UiN@030000001VIVH0IVIV00P0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`l0De=C00<0000006IVIP1VIVH05@1VIVH00`000000NGUi07UiN@0K
07UiN@800000:02<S8`200000<`0WinO00<0000008b<S02<S8`09`2<S8`2000001d0NGUi00<00000
06IVIP3oool01`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo3P1CDe<00`00
0000IVIV06IVIP0E06IVIP030000001iNGT0NGUi01/0NGUi00<0000008b<S02<S8`09P2<S8`20000
0<l0WinO0P00000Y08b<S0030000001iNGT0NGUi01/0NGUi00<000000?ooo`3oool01P3oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo3@1CDe<00`000000IVIV06IVIP0E06IVIP03
0000001iNGT0NGUi01/0NGUi00<0000008b<S02<S8`09@2<S8`2000005P0WinO8`00001H09nOW`<0
00009`2<S8`00`000000NGUi07UiN@0K07UiN@030000003oool0oooo00D0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo``0De=C00<0000006IVIP1VIVH05@1VIVH00`000000NGUi
07UiN@0J07UiN@8000009P2<S8`2000005<0WinO1`00000S0;>c/``00000C`2OWil2000002H0S8b<
0P00000K07UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`/0De=C00<0
000006IVIP1VIVH05@1VIVH00`000000NGUi07UiN@0J07UiN@030000002<S8`0S8b<02@0S8b<0P00
001=09nOW`P00000=P2c/k<4000004d0WinO00<0000008b<S02<S8`09@2<S8`00`000000NGUi07Ui
N@0H07UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`X0De=C00<00000
06IVIP1VIVH05@1VIVH00`000000NGUi07UiN@0I07UiN@8000009@2<S8`2000004/0WinO10000012
0;>c/`@00000BP2OWil2000002H0S8b<0P00000H07UiN@P0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`040?ooo`T0De=C00<0000006IVIP1VIVH0501VIVH2000001/0NGUi00<0000008b<
S02<S8`08`2<S8`2000004D0WinO2000001:0;>c/`P00000A02OWil2000002H0S8b<00<0000007Ui
N@1iNGT05@1iNGT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool805=CD`03
0000001VIVH0IVIV01@0IVIV00<0000007UiN@1iNGT06P1iNGT00`000000S8b<08b<S00S08b<S003
0000002OWil0WinO0440WinO1000001J0;>c/`@00000@P2OWil00`000000S8b<08b<S00T08b<S003
0000001iNGT0NGUi01@0NGUi203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
1`1CDe<00`000000IVIV06IVIP0D06IVIP030000001iNGT0NGUi01X0NGUi00<0000008b<S02<S8`0
8P2<S8`200000400WinO1000001R0;>c/`@00000?`2OWil2000002D0S8b<00<0000007UiN@1iNGT0
4`1iNGT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool705=CD`030000001V
IVH0IVIV01<0IVIV00<0000007UiN@1iNGT06@1iNGT2000002@0S8b<00<0000009nOW`2OWil0?@2O
Wil3000006X0/k>c0`00000n09nOW`030000002<S8`0S8b<02<0S8b<0P00000C07UiN@P0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`H0De=C00<0000006IVIP1VIVH04`1VIVH0
0`000000NGUi07UiN@0I07UiN@030000002<S8`0S8b<02<0S8b<00<0000009nOW`2OWil0?02OWil2
00000700/k>c0P00000m09nOW`8000009@2<S8`00`000000NGUi07UiN@0@07UiN@P0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0De=C0P00000E06IVIP030000001iNGT0NGUi
01T0NGUi00<0000008b<S02<S8`08P2<S8`2000003`0WinO0`00001d0;>c/`<00000?02OWil20000
02@0S8b<00<0000007UiN@1iNGT03`1iNGT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0103oool305=CD`030000001VIVH0IVIV01@0IVIV00<0000007UiN@1iNGT06@1iNGT00`000000
S8b<08b<S00R08b<S0030000002OWil0WinO03P0WinO1000001j0;>c/`@00000>P2OWil2000002<0
S8b<0P00000?07UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`<0De=C
00<0000006IVIP1VIVH04`1VIVH00`000000NGUi07UiN@0I07UiN@030000002<S8`0S8b<0240S8b<
0P00000h09nOW`<00000PP2c/k<3000003T0WinO0P00000S08b<S0030000001iNGT0NGUi00`0NGUi
203oool100000040oooo000G0?ooo`8000001@3oool205=CD`030000001VIVH0IVIV01<0IVIV00<0
000007UiN@1iNGT06@1iNGT00`000000S8b<08b<S00P08b<S0800000>02OWil2000008P0/k>c1000
000g09nOW`030000002<S8`0S8b<0200S8b<00<0000007UiN@1iNGT0301iNGT70?ooo`8000000@3o
ool001L0oooo00<000000?ooo`3oool0103oool2000001D0IVIV00<0000007UiN@1iNGT06@1iNGT0
0`000000S8b<08b<S00O08b<S0800000=`2OWil3000008h0/k>c0P00000f09nOW`8000008@2<S8`0
0`000000NGUi07UiN@0;07UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
oaH0IVIV00<0000007UiN@1iNGT0601iNGT200000240S8b<00<0000009nOW`2OWil0=02OWil30000
09<0/k>c0`00000e09nOW`030000002<S8`0S8b<01l0S8b<0P00000;07UiN@P0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`040?oooaD0IVIV00<0000007UiN@1iNGT0601iNGT00`000000
S8b<08b<S00O08b<S0800000=@2OWil2000009T0/k>c0P00000d09nOW`8000008@2<S8`00`000000
NGUi07UiN@0807UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa@0IVIV
00<0000007UiN@1iNGT0601iNGT00`000000S8b<08b<S00O08b<S0030000002OWil0WinO0380WinO
0`00002M0;>c/`800000=02OWil00`000000S8b<08b<S00O08b<S0030000001iNGT0NGUi00L0NGUi
203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo4`1VIVH00`000000NGUi07Ui
N@0G07UiN@8000008@2<S8`00`000000WinO09nOW`0`09nOW`<00000XP2c/k<2000003<0WinO00<0
000008b<S02<S8`07`2<S8`2000000L0NGUi203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo4P1VIVH00`000000NGUi07UiN@0G07UiN@030000002<S8`0S8b<0200S8b<00<00000
09nOW`2OWil0;`2OWil200000:L0/k>c0P00000b09nOW`030000002<S8`0S8b<0200S8b<00<00000
07UiN@1iNGT0101iNGT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolA06IV
IP030000001iNGT0NGUi01L0NGUi00<0000008b<S02<S8`07`2<S8`200000300WinO0P00002[0;>c
/`<00000<02OWil200000240S8b<00<0000007UiN@1iNGT00`1iNGT80?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103oool@06IVIP030000001iNGT0NGUi01L0NGUi00<0000008b<S02<
S8`07`2<S8`00`000000WinO09nOW`0^09nOW`800000/02c/k<200000300WinO00<0000008b<S02<
S8`07`2<S8`00`000000NGUi07UiN@0207UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?ooo`l0IVIV00<0000007UiN@1iNGT05`1iNGT00`000000S8b<08b<S00O08b<S0030000
002OWil0WinO02d0WinO0P00002d0;>c/`030000002OWil0WinO02h0WinO0P00000P08b<S0800000
0P1iNGT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool>06IVIP030000001i
NGT0NGUi01L0NGUi00<0000008b<S02<S8`07P2<S8`2000002h0WinO0P00002g0;>c/`800000<02O
Wil200000200S8b<00<0000007UiN@3oool01`3oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo3@1VIVH00`000000NGUi07UiN@0G07UiN@030000002<S8`0S8b<01h0S8b<00<00000
09nOW`2OWil0;02OWil200000;/0/k>c0`00000_09nOW`030000002<S8`0S8b<01d0S8b<00<00000
07UiN@3oool01`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo301VIVH00`00
0000NGUi07UiN@0G07UiN@030000002<S8`0S8b<01d0S8b<0P00000]09nOW`800000`02c/k<30000
02d0WinO00<0000008b<S02<S8`07@2<S8`00`000000oooo0?ooo`060?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103oool;06IVIP030000001iNGT0NGUi01H0NGUi0P00000O08b<S003
0000002OWil0WinO02/0WinO0P0000350;>c/`030000002OWil0WinO02/0WinO0P00000N08b<S003
0000003oool0oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`X0IVIV
00<0000007UiN@1iNGT05P1iNGT00`000000S8b<08b<S00N08b<S0030000002OWil0WinO02X0WinO
0P0000380;>c/`800000;@2OWil00`000000S8b<08b<S00K08b<S0P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo`X0IVIV00<0000007UiN@1iNGT05P1iNGT00`000000S8b<08b<
S00L08b<S0800000:`2OWil200000<`0/k>c0P00000/09nOW`030000002<S8`0S8b<01X0S8b<203o
ool100000040oooo000G0?ooo`8000001@3oool806IVIP800000601iNGT00`000000S8b<08b<S00L
08b<S0030000002OWil0WinO02T0WinO0P00003@0;>c/`800000:`2OWil2000001X0S8b<1`3oool2
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo1`1VIVH00`000000NGUi07UiN@0F07Ui
N@8000007P2<S8`00`000000WinO09nOW`0X09nOW`800000e02c/k<00`000000WinO09nOW`0Z09nO
W`030000002<S8`0S8b<01L0S8b<203oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo1P1VIVH00`000000NGUi07UiN@0F07UiN@030000002<S8`0S8b<01d0S8b<00<0000009nOW`2O
Wil09`2OWil200000=L0/k>c0P00000[09nOW`8000005`2<S8`80?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103oool606IVIP030000001iNGT0NGUi01D0NGUi00<0000008b<S02<S8`0
702<S8`2000002P0WinO0P00003K0;>c/`800000:`2OWil00`000000S8b<08b<S00D08b<S0P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0IVIV0P00000G07UiN@030000002<
S8`0S8b<01`0S8b<00<0000009nOW`2OWil09P2OWil2000005h0/k>c8`00001N0;>c/`800000:@2O
Wil00`000000S8b<08b<S00D08b<S0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`04
0?ooo`<0IVIV00<0000007UiN@1iNGT05P1iNGT00`000000S8b<08b<S00L08b<S0030000002OWil0
WinO02D0WinO0P00001I0;>c/`L000008`36a/H8000005P0/k>c0P00000X09nOW`030000002<S8`0
S8b<01<0S8b<203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo0P1VIVH00`00
0000NGUi07UiN@0F07UiN@030000002<S8`0S8b<01/0S8b<0P00000W09nOW`030000002c/k<0/k>c
0540/k>c2000000b0<K6aPP00000DP2c/k<2000002L0WinO0P00000C08b<S0P0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`040?ooo`80IVIV00<0000007UiN@1iNGT05@1iNGT00`000000
S8b<08b<S00K08b<S0030000002OWil0WinO02H0WinO00<000000;>c/`2c/k<0CP2c/k<400000480
a/K61000001@0;>c/`8000009`2OWil00`000000S8b<08b<S00@08b<S0P0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo`0306IVIP000000NGUi01H0NGUi00<0000008b<S02<S8`0
6`2<S8`00`000000WinO09nOW`0U09nOW`800000C@2c/k<4000004X0a/K61000001=0;>c/`030000
002OWil0WinO02H0WinO00<0000008b<S02<S8`03`2<S8`80?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103oool00`000000NGUi07UiN@0E07UiN@030000002<S8`0S8b<01X0S8b<0P00
000V09nOW`800000B`2c/k<400000580a/K6200000160;>c/`8000009`2OWil2000000l0S8b<203o
ool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo5`1iNGT00`000000S8b<08b<S00J
08b<S0030000002OWil0WinO02D0WinO00<000000;>c/`2c/k<0A`2c/k<4000005h0a/K60`000015
0;>c/`8000009`2OWil00`000000S8b<08b<S00<08b<S0P0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`040?oooaH0NGUi00<0000008b<S02<S8`06P2<S8`00`000000WinO09nOW`0T09nO
W`800000AP2c/k<4000006D0a/K60P0000150;>c/`8000009P2OWil00`000000S8b<08b<S00;08b<
S0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa@0NGUi0P00000L08b<S003
0000002OWil0WinO02@0WinO00<000000;>c/`2c/k<0@P2c/k<4000006/0a/K60`0000140;>c/`80
00009@2OWil00`000000S8b<08b<S00:08b<S0P0oooo0@0000010?ooo`002`3oool4000000P0oooo
00<000000?ooo`3oool0103ooolC07UiN@030000002<S8`0S8b<01X0S8b<0P00000V09nOW`030000
002c/k<0/k>c03l0/k>c1000001b0<K6aP@00000@P2c/k<00`000000WinO09nOW`0S09nOW`800000
2P2<S8`80?ooo`4000000@3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo4P1iNGT00`000000S8b<08b<S00J08b<S0030000002O
Wil0WinO02@0WinO0P00000n0;>c/`@00000NP36a/H4000003l0/k>c0P00000U09nOW`030000002<
S8`0S8b<00L0S8b<203oool100000040oooo000?0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103ooolB07UiN@030000002<S8`0S8b<01T0S8b<00<0000009nOW`2OWil08`2OWil2
000003d0/k>c0`0000220<K6aP<00000?P2c/k<00`000000WinO09nOW`0S09nOW`030000002<S8`0
S8b<00H0S8b<203oool100000040oooo000?0?ooo`030000003oool0oooo00D0oooo0`0000040?oo
oa00NGUi0P00000K08b<S0030000002OWil0WinO02<0WinO00<000000;>c/`2c/k<0>`2c/k<20000
08P0a/K60P00000m0;>c/`030000002OWil0WinO02<0WinO0P00000608b<S0H0oooo0`0000010?oo
o`0000<0oooo000000000000100000060?ooo`800000203oool00`000000oooo0?ooo`040?ooo`l0
NGUi00<0000008b<S02<S8`06P2<S8`00`000000WinO09nOW`0R09nOW`800000>`2c/k<3000008`0
a/K60`00000k0;>c/`8000009@2OWil00`000000S8b<08b<S00308b<S0P0oooo0@0000010?ooo`00
3`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo3P1iNGT00`000000S8b<
08b<S00J08b<S0030000002OWil0WinO0280WinO00<000000;>c/`2c/k<0>02c/k<300000980a/K6
0`00000j0;>c/`030000002OWil0WinO0280WinO00<0000008b<S02<S8`00`2<S8`80?ooo`400000
0@3oool000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`h0NGUi00<0
000008b<S02<S8`06@2<S8`00`000000WinO09nOW`0Q09nOW`800000>@2c/k<2000009P0a/K60P00
000i0;>c/`8000008`2OWil00`000000S8b<08b<S00208b<S0P0oooo0@0000010?ooo`002P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool=
07UiN@030000002<S8`0S8b<01P0S8b<0P00000S09nOW`030000002c/k<0/k>c03L0/k>c0P00002L
0<K6aP800000>@2c/k<200000280WinO0P00000208b<S0P0oooo0@0000010?ooo`002`3oool40000
00P0oooo00<000000?ooo`3oool0103oool<07UiN@030000002<S8`0S8b<01P0S8b<00<0000009nO
W`2OWil08P2OWil00`000000/k>c0;>c/`0f0;>c/`800000X036a/H3000003P0/k>c00<0000009nO
W`2OWil08@2OWil00`000000S8b<0?ooo`070?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0103oool;07UiN@030000002<S8`0S8b<01P0S8b<00<0000009nOW`2OWil08P2OWil00`000000
/k>c0;>c/`0d0;>c/`<00000Y@36a/H2000003L0/k>c0P00000Q09nOW`030000002<S8`0oooo00L0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`X0NGUi00<0000008b<S02<S8`0
6@2<S8`00`000000WinO09nOW`0P09nOW`800000=02c/k<300000:X0a/K60P00000g0;>c/`030000
002OWil0WinO01l0WinO00<000000?ooo`0000001P3oool100000040oooo000G0?ooo`030000003o
ool0oooo00@0oooo2@1iNGT00`000000S8b<08b<S00H08b<S08000008P2OWil00`000000/k>c0;>c
/`0c0;>c/`800000[P36a/H2000003D0/k>c00<0000009nOW`2OWil0802OWil00`000000oooo0?oo
o`050?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool807UiN@030000002<S8`0
S8b<01P0S8b<00<0000009nOW`2OWil08@2OWil00`000000/k>c0;>c/`0a0;>c/`<00000/P36a/H2
000003@0/k>c0P00000P09nOW`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
o`L0NGUi00<0000008b<S02<S8`05`2<S8`200000280WinO0P00000b0;>c/`800000]`36a/H20000
03@0/k>c0P00000N09nOW`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`H0
NGUi00<0000008b<S02<S8`05`2<S8`00`000000WinO09nOW`0P09nOW`800000<@2c/k<300000;/0
a/K61000000b0;>c/`030000002OWil0WinO01/0WinO203oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo1@1iNGT00`000000S8b<08b<S00H08b<S0030000002OWil0WinO01l0WinO
00<000000;>c/`2c/k<0;`2c/k<200000<80a/K600<000000;>c/`2c/k<0<02c/k<2000001/0WinO
203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo101iNGT00`000000S8b<08b<
S00H08b<S0030000002OWil0WinO01l0WinO00<000000;>c/`2c/k<0;`2c/k<00`000000a/K60<K6
aP330<K6aP030000002c/k<0/k>c0340/k>c00<0000009nOW`2OWil0602OWil80?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0103oool307UiN@030000002<S8`0S8b<01L0S8b<0P00000P
09nOW`800000<02c/k<200000<L0a/K60P00000b0;>c/`800000602OWil80?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0103oool207UiN@030000002<S8`0S8b<01L0S8b<00<0000009nO
W`2OWil07P2OWil2000002l0/k>c0`00003;0<K6aP@00000<02c/k<00`000000WinO09nOW`0E09nO
W`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`0307UiN@000000S8b<01P0
S8b<00<0000009nOW`2OWil07P2OWil00`000000/k>c0;>c/`0]0;>c/`800000dP36a/H00`000000
/k>c0;>c/`0^0;>c/`030000002OWil0WinO01@0WinO203oool100000040oooo000G0?ooo`800000
1@3oool00`000000S8b<08b<S00G08b<S0030000002OWil0WinO01l0WinO00<000000;>c/`2c/k<0
;02c/k<00`000000a/K60<K6aP3C0<K6aP030000002c/k<0/k>c02h0/k>c00<0000009nOW`2OWil0
4`2OWil70?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0103ooolI08b<S0030000002O
Wil0WinO01h0WinO0P00000]0;>c/`800000e`36a/H2000002l0/k>c0P00000C09nOW`P0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`040?oooaP0S8b<00<0000009nOW`2OWil07@2OWil2
000002d0/k>c0P00003K0<K6aP<00000;P2c/k<00`000000WinO09nOW`0@09nOW`P0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?oooaL0S8b<00<0000009nOW`2OWil07P2OWil00`00
0000/k>c0;>c/`0[0;>c/`0300000036a/H0a/K60=h0a/K60P00000]0;>c/`030000002OWil0WinO
00l0WinO203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo5P2<S8`00`000000
WinO09nOW`0N09nOW`030000002c/k<0/k>c02X0/k>c0P00003S0<K6aP030000002c/k<0/k>c02/0
/k>c00<0000009nOW`2OWil03P2OWil80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103ooolE08b<S0030000002OWil0WinO01d0WinO0P00000/0;>c/`0300000036a/H0a/K60>@0a/K6
0P00000/0;>c/`030000002OWil0WinO00d0WinO203oool100000040oooo000G0?ooo`030000003o
ool0oooo00@0oooo502<S8`00`000000WinO09nOW`0M09nOW`030000002c/k<0/k>c02X0/k>c0P00
003Y0<K6aP800000:`2c/k<00`000000WinO09nOW`0<09nOW`P0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?oooa<0S8b<00<0000009nOW`2OWil07@2OWil00`000000/k>c0;>c/`0Y
0;>c/`800000k036a/H00`000000/k>c0;>c/`0Z0;>c/`030000002OWil0WinO00/0WinO203oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo4P2<S8`00`000000WinO09nOW`0L09nO
W`800000:P2c/k<2000006H0a/K68`00001V0<K6aP800000:`2c/k<2000000/0WinO203oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo4@2<S8`00`000000WinO09nOW`0L09nOW`03
0000002c/k<0/k>c02T0/k>c00<000000<K6aP36a/H0G`36a/H7000002<0fMWI2000001P0<K6aP80
0000:`2c/k<00`000000WinO09nOW`0809nOW`P0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?oooa00S8b<00<0000009nOW`2OWil0702OWil00`000000/k>c0;>c/`0X0;>c/`800000
F@36a/H900000380fMWI2@00001I0<K6aP800000:P2c/k<00`000000WinO09nOW`0709nOW`P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`l0S8b<00<0000009nOW`2OWil0702O
Wil00`000000/k>c0;>c/`0X0;>c/`0300000036a/H0a/K605H0a/K60`0000140=WIf@<00000F036
a/H00`000000/k>c0;>c/`0X0;>c/`8000001`2OWil80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool>08b<S0030000002OWil0WinO01`0WinO00<000000;>c/`2c/k<0:02c/k<0
0`000000a/K60<K6aP1C0<K6aP@00000BP3IfMT800000540a/K600<000000;>c/`2c/k<0:@2c/k<0
0`000000WinO09nOW`0409nOW`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
o`d0S8b<00<0000009nOW`2OWil0702OWil00`000000/k>c0;>c/`0W0;>c/`800000CP36a/H80000
05H0fMWI1000001>0<K6aP800000:P2c/k<00`000000WinO09nOW`0309nOW`P0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`040?ooo``0S8b<00<0000009nOW`2OWil06`2OWil2000002P0
/k>c0P00001=0<K6aP<00000HP3IfMT4000004`0a/K60P00000Y0;>c/`030000002OWil0WinO0080
WinO203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2`2<S8`00`000000WinO
09nOW`0K09nOW`030000002c/k<0/k>c02P0/k>c00<000000<K6aP36a/H0BP36a/H2000006T0fMWI
0`00001;0<K6aP030000002c/k<0/k>c02L0/k>c00@0000009nOW`2OWil0WinO203oool100000040
oooo000G0?ooo`8000001@3oool:08b<S0030000002OWil0WinO01/0WinO00<000000;>c/`2c/k<0
9`2c/k<2000004X0a/K60`00001^0=WIf@800000BP36a/H2000002P0/k>c00<0000009nOW`2OWil0
1`3oool200000040oooo000G0?ooo`030000003oool0oooo00@0oooo2@2<S8`00`000000WinO09nO
W`0K09nOW`030000002c/k<0/k>c02H0/k>c0P0000180<K6aP@00000L`3IfMT3000004T0a/K600<0
00000;>c/`2c/k<09P2c/k<00`000000WinO0?ooo`070?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool808b<S0030000002OWil0WinO01/0WinO00<000000;>c/`2c/k<09@2c/k<2
000004D0a/K61@00001j0=WIf@D00000A@36a/H2000002L0/k>c00<000000?ooo`3oool01P3oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo1`2<S8`00`000000WinO09nOW`0K09nO
W`030000002c/k<0/k>c02D0/k>c00<000000<K6aP36a/H0@`36a/H2000008@0fMWI0`0000140<K6
aP030000002c/k<0/k>c02D0/k>c00<000000?ooo`3oool01@3oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo1P2<S8`00`000000WinO09nOW`0K09nOW`030000002c/k<0/k>c02D0
/k>c00<000000<K6aP36a/H0@P36a/H2000008T0fMWI0`0000120<K6aP030000002c/k<0/k>c02@0
/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo1P2<S8`00`000000WinO
09nOW`0J09nOW`030000002c/k<0/k>c02@0/k>c0P0000120<K6aP<00000SP3IfMT200000440a/K6
0P00000T0;>c/`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0S8b<0P00
000L09nOW`030000002c/k<0/k>c02@0/k>c00<000000<K6aP36a/H0?`36a/H3000009<0fMWI0P00
00110<K6aP8000008P2c/k<80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool3
08b<S0030000002OWil0WinO01/0WinO00<000000;>c/`2c/k<0902c/k<00`000000a/K60<K6aP0n
0<K6aP800000V03IfMT200000440a/K600<000000;>c/`2c/k<07`2c/k<80?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0103oool208b<S0030000002OWil0WinO01/0WinO00<000000;>c
/`2c/k<0902c/k<00`000000a/K60<K6aP0l0<K6aP<00000W03IfMT200000400a/K60P00000O0;>c
/`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`80S8b<00<0000009nOW`2O
Wil06@2OWil2000002D0/k>c0P00000l0<K6aP<00000X@3IfMT4000003h0a/K600<000000;>c/`2c
/k<0702c/k<80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool00`2<S8`00000
09nOW`0J09nOW`030000002c/k<0/k>c02<0/k>c0P00000l0<K6aP800000Z03IfMT2000003d0a/K6
00<000000;>c/`2c/k<06`2c/k<80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103o
ool00`000000WinO09nOW`0I09nOW`030000002c/k<0/k>c02<0/k>c00<000000<K6aP36a/H0>P36
a/H200000:`0fMWI00<000000<K6aP36a/H0>`36a/H2000001/0/k>c203oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo6`2OWil00`000000/k>c0;>c/`0S0;>c/`0300000036a/H0
a/K603T0a/K60P00002_0=WIf@800000?@36a/H00`000000/k>c0;>c/`0H0;>c/`P0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?oooaX0WinO00<000000;>c/`2c/k<08`2c/k<00`00
0000a/K60<K6aP0h0<K6aP800000/`3IfMT3000003/0a/K600<000000;>c/`2c/k<05`2c/k<80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolI09nOW`030000002c/k<0/k>c0280
/k>c0P00000i0<K6aP800000^03IfMT2000003X0a/K600<000000;>c/`2c/k<05P2c/k<80?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0103ooolH09nOW`030000002c/k<0/k>c0280/k>c
00<000000<K6aP36a/H0=`36a/H200000;`0fMWI00<000000<K6aP36a/H0>036a/H2000001H0/k>c
203oool100000040oooo000G0?ooo`8000001@3ooolG09nOW`030000002c/k<0/k>c0280/k>c00<0
00000<K6aP36a/H0=P36a/H200000;l0fMWI0P00000j0<K6aP030000002c/k<0/k>c01<0/k>c1`3o
ool200000040oooo000G0?ooo`030000003oool0oooo00@0oooo5P2OWil00`000000/k>c0;>c/`0Q
0;>c/`800000=`36a/H200000<<0fMWI0`00000h0<K6aP030000002c/k<0/k>c0180/k>c203oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo5@2OWil00`000000/k>c0;>c/`0Q0;>c
/`0300000036a/H0a/K603D0a/K60P0000380=WIf@800000=`36a/H00`000000/k>c0;>c/`0A0;>c
/`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa@0WinO00<000000;>c/`2c
/k<08@2c/k<00`000000a/K60<K6aP0d0<K6aP800000c03IfMT00`000000a/K60<K6aP0e0<K6aP03
0000002c/k<0/k>c0100/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
4`2OWil00`000000/k>c0;>c/`0Q0;>c/`0300000036a/H0a/K603<0a/K60P00003?0=WIf@800000
=P36a/H00`000000/k>c0;>c/`0?0;>c/`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`040?oooa80WinO00<000000;>c/`2c/k<0802c/k<2000003@0a/K60P00003C0=WIf@<00000=036
a/H2000000l0/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo4@2OWil0
0`000000/k>c0;>c/`0P0;>c/`0300000036a/H0a/K60380a/K60P00003H0=WIf@800000=036a/H0
0`000000/k>c0;>c/`0<0;>c/`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
oa00WinO00<000000;>c/`2c/k<0802c/k<00`000000a/K60<K6aP0a0<K6aP800000g03IfMT00`00
0000a/K60<K6aP0b0<K6aP030000002c/k<0/k>c00/0/k>c203oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo3`2OWil00`000000/k>c0;>c/`0P0;>c/`0300000036a/H0a/K60340
a/K600<000000=WIf@3IfMT0g@3IfMT2000003<0a/K60P00000;0;>c/`P0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo`h0WinO00<000000;>c/`2c/k<0802c/k<00`000000a/K6
0<K6aP0`0<K6aP800000hP3IfMT2000003<0a/K600<000000;>c/`2c/k<0202c/k<80?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103oool=09nOW`030000002c/k<0/k>c0200/k>c00<0
00000<K6aP36a/H0<036a/H00`000000fMWI0=WIf@3T0=WIf@800000<P36a/H00`000000/k>c0;>c
/`070;>c/`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo``0WinO00<00000
0;>c/`2c/k<0802c/k<00`000000a/K60<K6aP0_0<K6aP800000j@3IfMT200000340a/K600<00000
0;>c/`2c/k<01P2c/k<80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool;09nO
W`030000002c/k<0/k>c01l0/k>c0P00000`0<K6aP800000k@3IfMT00`000000a/K60<K6aP0_0<K6
aP030000002c/k<0/k>c00D0/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo2P2OWil00`000000/k>c0;>c/`0O0;>c/`0300000036a/H0a/K602h0a/K60P00003`0=WIf@80
0000<036a/H00`000000/k>c0;>c/`040;>c/`P0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?ooo`T0WinO00<000000;>c/`2c/k<07`2c/k<00`000000a/K60<K6aP0^0<K6aP030000
003IfMT0fMWI0?80fMWI00<000000<K6aP36a/H0;P36a/H00`000000/k>c0;>c/`030;>c/`P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`P0WinO00<000000;>c/`2c/k<07`2c
/k<00`000000a/K60<K6aP0^0<K6aP030000003IfMT0fMWI0?@0fMWI0P00000_0<K6aP8000000`2c
/k<80?ooo`4000000@3oool001L0oooo0P0000050?ooo`L0WinO00<000000;>c/`2c/k<07`2c/k<0
0`000000a/K60<K6aP0]0<K6aP800000n@3IfMT2000002l0a/K600<000000;>c/`2c/k<01`3oool2
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo1`2OWil00`000000/k>c0;>c/`0N0;>c
/`0300000036a/H0a/K602d0a/K600<000000=WIf@3IfMT0n`3IfMT00`000000a/K60<K6aP0]0<K6
aP030000002c/k<0oooo00L0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`H0
WinO00<000000;>c/`2c/k<07P2c/k<00`000000a/K60<K6aP0/0<K6aP800000o`3IfMT00`000000
a/K60<K6aP0]0<K6aP030000003oool0oooo00H0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?ooo`@0WinO0P00000O0;>c/`800000;@36a/H200000?l0fMWI0`3IfMT2000002d0a/K6
00<000000?ooo`3oool01P3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo0`2O
Wil00`000000/k>c0;>c/`0N0;>c/`0300000036a/H0a/K602`0a/K600<000000=WIf@3IfMT0M`3I
fMTG000007H0fMWI00<000000<K6aP36a/H0:`36a/H00`000000oooo0?ooo`050?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0103oool309nOW`030000002c/k<0/k>c01d0/k>c00<00000
0<K6aP36a/H0:`36a/H2000006h0fMWI3000000G0>c/k0P00000K`3IfMT2000002/0a/K6203oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo0P2OWil00`000000/k>c0;>c/`0M0;>c
/`0300000036a/H0a/K602/0a/K600<000000=WIf@3IfMT0I`3IfMT7000002/0k>c/2000001Y0=WI
f@0300000036a/H0a/K602P0a/K6203oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo00<0WinO0000002c/k<07P2c/k<00`000000a/K60<K6aP0[0<K6aP030000003IfMT0fMWI0600
fMWI2000000j0>c/k0P00000HP3IfMT2000002P0a/K6203oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo00<000000;>c/`2c/k<07@2c/k<00`000000a/K60<K6aP0Z0<K6aP800000
G`3IfMT4000004X0k>c/1000001P0=WIf@8000009P36a/H80?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103ooolO0;>c/`0300000036a/H0a/K602X0a/K600<000000=WIf@3IfMT0F`3I
fMT400000580k>c/1000001N0=WIf@0300000036a/H0a/K602<0a/K6203oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo7P2c/k<00`000000a/K60<K6aP0Y0<K6aP800000FP3IfMT4
000005X0k>c/1000001K0=WIf@0300000036a/H0a/K60280a/K6203oool100000040oooo000G0?oo
o`030000003oool0oooo00@0oooo7@2c/k<00`000000a/K60<K6aP0Y0<K6aP030000003IfMT0fMWI
05H0fMWI1000001R0>c/k0@00000F03IfMT200000280a/K6203oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo702c/k<00`000000a/K60<K6aP0Y0<K6aP030000003IfMT0fMWI05<0
fMWI1000001Z0>c/k0@00000EP3IfMT00`000000a/K60<K6aP0O0<K6aPP0oooo0@0000010?ooo`00
2P3oool6000000L0oooo00<000000?ooo`3oool0103ooolK0;>c/`0300000036a/H0a/K602P0a/K6
0P00001C0=WIf@<00000LP3/k>`3000005@0fMWI00<000000<K6aP36a/H07P36a/H80?ooo`400000
0@3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo6P2c/k<00`000000a/K60<K6aP0X0<K6aP030000003IfMT0fMWI0540fMWI0P00
001h0>c/k0@00000D@3IfMT2000001h0a/K6203oool100000040oooo000;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103ooolH0;>c/`800000:P36a/H00`000000fMWI0=WIf@1?
0=WIf@<00000OP3/k>`200000540fMWI00<000000<K6aP36a/H06`36a/H80?ooo`4000000@3oool0
00`0oooo00<000000?ooo`3oool0203oool3000000@0oooo5`2c/k<00`000000a/K60<K6aP0Y0<K6
aP030000003IfMT0fMWI04`0fMWI100000230>c/k0<00000C`3IfMT2000001/0a/K61P3oool30000
0040oooo00000`3oool0000000000004000000H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?oooaL0/k>c00<000000<K6aP36a/H09`36a/H2000004`0fMWI0`00002:0>c/k0<0
0000CP3IfMT00`000000a/K60<K6aP0H0<K6aPP0oooo0@0000010?ooo`003P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo5P2c/k<00`000000a/K60<K6aP0W0<K6aP030000
003IfMT0fMWI04X0fMWI0P00002@0>c/k0@00000BP3IfMT00`000000a/K60<K6aP0H0<K6aPP0oooo
0@0000010?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103ooolD0;>c/`800000:@36a/H00`000000fMWI0=WIf@180=WIf@<00000UP3/
k>`2000004T0fMWI0P00000H0<K6aPP0oooo0@0000010?ooo`002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103ooolC0;>c/`0300000036a/H0
a/K602L0a/K60P0000180=WIf@<00000V`3/k>`00`000000fMWI0=WIf@180=WIf@8000005P36a/H8
0?ooo`4000000@3oool000/0oooo100000080?ooo`030000003oool0oooo00@0oooo4`2c/k<00`00
0000a/K60<K6aP0V0<K6aP030000003IfMT0fMWI04H0fMWI0P00002O0>c/k0800000B@3IfMT00`00
0000a/K60<K6aP0D0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa80
/k>c00<000000<K6aP36a/H09P36a/H00`000000fMWI0=WIf@150=WIf@800000X`3/k>`4000004H0
fMWI0P00000D0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa00/k>c
0P00000W0<K6aP800000AP3IfMT200000:T0k>c/0P0000160=WIf@8000004P36a/H80?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103oool?0;>c/`0300000036a/H0a/K602H0a/K600<0
00000=WIf@3IfMT0A03IfMT200000:d0k>c/0P0000160=WIf@0300000036a/H0a/K600l0a/K6203o
ool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo3`2c/k<00`000000a/K60<K6aP0U
0<K6aP030000003IfMT0fMWI04<0fMWI0P00002a0>c/k0800000A03IfMT00`000000a/K60<K6aP0?
0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`h0/k>c00<000000<K6
aP36a/H09@36a/H00`000000fMWI0=WIf@110=WIf@<00000]@3/k>`2000004<0fMWI00<000000<K6
aP36a/H03P36a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool<0;>c/`80
00009P36a/H200000440fMWI0`00002j0>c/k0800000@P3IfMT2000000h0a/K6203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo2`2c/k<00`000000a/K60<K6aP0U0<K6aP030000
003IfMT0fMWI03l0fMWI0P00002o0>c/k0800000@P3IfMT00`000000a/K60<K6aP0;0<K6aPP0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`/0/k>c00<000000<K6aP36a/H09036
a/H00`000000fMWI0=WIf@0n0=WIf@800000``3/k>`200000440fMWI00<000000<K6aP36a/H02P36
a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool:0;>c/`0300000036a/H0
a/K602@0a/K600<000000=WIf@3IfMT0?P3IfMT200000<H0k>c/0P0000100=WIf@8000002P36a/H8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool80;>c/`8000009P36a/H00`00
0000fMWI0=WIf@0l0=WIf@<00000bP3/k>`200000400fMWI00<000000<K6aP36a/H01`36a/H80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool70;>c/`0300000036a/H0a/K602D0
a/K600<000000=WIf@3IfMT0?03IfMT00`000000k>c/0>c/k03=0>c/k0800000?`3IfMT2000000L0
a/K6203oool100000040oooo000G0?ooo`8000001@3oool70;>c/`0300000036a/H0a/K602<0a/K6
0P00000m0=WIf@800000dP3/k>`2000003l0fMWI00<000000<K6aP36a/H01036a/H70?ooo`800000
0@3oool001L0oooo00<000000?ooo`3oool0103oool60;>c/`0300000036a/H0a/K602<0a/K600<0
00000=WIf@3IfMT0?03IfMT00`000000k>c/0>c/k03D0>c/k0800000?@3IfMT00`000000a/K60<K6
aP040<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`D0/k>c00<00000
0<K6aP36a/H08`36a/H00`000000fMWI0=WIf@0k0=WIf@800000f@3/k>`2000003`0fMWI00<00000
0<K6aP36a/H00`36a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool40;>c
/`0300000036a/H0a/K602<0a/K600<000000=WIf@3IfMT0>P3IfMT200000=d0k>c/00<000000=WI
f@3IfMT0>P3IfMT2000000<0a/K6203oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo0`2c/k<00`000000a/K60<K6aP0S0<K6aP030000003IfMT0fMWI03T0fMWI0P00003P0>c/k080
0000?03IfMT00`000000a/K60<K6aP080?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103oool30;>c/`0300000036a/H0a/K60280a/K600<000000=WIf@3IfMT0>03IfMT200000>@0k>c/
00<000000=WIf@3IfMT0>@3IfMT00`000000a/K60<K6aP080?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103oool00`2c/k<000000000000T0<K6aP030000003IfMT0fMWI03L0fMWI0P00
003W0>c/k0800000>P3IfMT2000000P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`04
0?ooo`0300000036a/H0a/K60280a/K60P00000h0=WIf@800000j`3/k>`2000003X0fMWI00<00000
0?ooo`3oool01@3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo9036a/H00`00
0000fMWI0=WIf@0g0=WIf@030000003/k>`0k>c/0>d0k>c/0P00000h0=WIf@P0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`040?ooob@0a/K600<000000=WIf@3IfMT0=`3IfMT00`000000
k>c/0>c/k03_0>c/k0800000=P3IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103ooolS0<K6aP030000003IfMT0fMWI03H0fMWI0P00003d0>c/k0030000003IfMT0fMWI03<0fMWI
203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo8@36a/H2000003L0fMWI0P00
003g0>c/k0800000<`3IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolO
0<K6aP800000=`3IfMT200000?/0k>c/0P00000a0=WIf@P0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`040?oooah0a/K600<000000=WIf@3IfMT0=P3IfMT00`000000k>c/0>c/k03m0>c/
k0030000003IfMT0fMWI02h0fMWI203oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo7@36a/H00`000000fMWI0=WIf@0e0=WIf@800000o`3/k>`20>c/k0030000003IfMT0fMWI02d0
fMWI203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo7036a/H00`000000fMWI
0=WIf@0e0=WIf@030000003/k>`0k>c/0?l0k>c/0`3/k>`2000002d0fMWI203oool100000040oooo
000G0?ooo`8000001@3ooolK0<K6aP030000003IfMT0fMWI03@0fMWI0P00003o0>c/k0P0k>c/0P00
000[0=WIf@L0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooaX0a/K600<00000
0=WIf@3IfMT0=03IfMT00`000000k>c/0>c/k03o0>c/k0X0k>c/00<000000=WIf@3IfMT0:03IfMT8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolI0<K6aP030000003IfMT0fMWI
03@0fMWI00<000000>c/k03/k>`0o`3/k>`<0>c/k0030000003IfMT0fMWI02L0fMWI203oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo6036a/H00`000000fMWI0=WIf@0c0=WIf@80
0000o`3/k>`@0>c/k08000009`3IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103ooolG0<K6aP030000003IfMT0fMWI0380fMWI0P00003o0>c/k1@0k>c/00<000000=WIf@3IfMT0
903IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolF0<K6aP030000003I
fMT0fMWI03<0fMWI00<000000>c/k03/k>`0o`3/k>`D0>c/k0030000003IfMT0fMWI02<0fMWI203o
ool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo5@36a/H00`000000fMWI0=WIf@0b
0=WIf@800000o`3/k>`H0>c/k08000008`3IfMT80?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0103ooolD0<K6aP030000003IfMT0fMWI0340fMWI0P00003o0>c/k1`0k>c/00<000000=WI
f@3IfMT0803IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolC0<K6aP03
0000003IfMT0fMWI0300fMWI0P00003o0>c/k1l0k>c/0P00000P0=WIf@P0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?oooa80a/K600<000000=WIf@3IfMT0<03IfMT00`000000k>c/
0>c/k03o0>c/k240k>c/00<000000=WIf@3IfMT07@3IfMT80?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103ooolA0<K6aP030000003IfMT0fMWI0300fMWI00<000000>c/k03/k>`0o`3/
k>`S0>c/k0030000003IfMT0fMWI01`0fMWI203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo4036a/H00`000000fMWI0=WIf@0_0=WIf@800000o`3/k>`W0>c/k0800000703IfMT8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool?0<K6aP030000003IfMT0fMWI
02l0fMWI00<000000>c/k03/k>`0o`3/k>`Y0>c/k0030000003IfMT0fMWI01T0fMWI203oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo3P36a/H00`000000fMWI0=WIf@0_0=WIf@03
0000003/k>`0k>c/0?l0k>c/:`3/k>`00`000000fMWI0=WIf@0H0=WIf@P0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo`d0a/K600<000000=WIf@3IfMT0;`3IfMT00`000000k>c/
0>c/k03o0>c/k2d0k>c/00<000000=WIf@3IfMT05`3IfMT80?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103oool<0<K6aP030000003IfMT0fMWI02h0fMWI0P00003o0>c/k340k>c/0P00
000G0=WIf@P0oooo0@0000010?ooo`005`3oool2000000D0oooo2`36a/H00`000000fMWI0=WIf@0^
0=WIf@030000003/k>`0k>c/08X0k>c/6`00002=0>c/k0030000003IfMT0fMWI01@0fMWI1`3oool2
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo2P36a/H00`000000fMWI0=WIf@0^0=WI
f@030000003/k>`0k>c/08<0k>c/2000000K0?ooo``00000PP3/k>`00`000000fMWI0=WIf@0C0=WI
f@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`T0a/K600<000000=WIf@3I
fMT0;P3IfMT00`000000k>c/0>c/k01m0>c/k0L00000;`3oool8000007/0k>c/0P00000C0=WIf@P0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`P0a/K600<000000=WIf@3IfMT0
;P3IfMT00`000000k>c/0>c/k01f0>c/k0P00000?P3oool4000007T0k>c/00<000000=WIf@3IfMT0
403IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool80<K6aP030000003I
fMT0fMWI02`0fMWI0P00001d0>c/k0D00000BP3oool5000007D0k>c/00<000000=WIf@3IfMT03`3I
fMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool70<K6aP030000003IfMT0
fMWI02`0fMWI00<000000>c/k03/k>`0L@3/k>`3000005@0oooo0`00001c0>c/k08000003`3IfMT8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool60<K6aP030000003IfMT0fMWI
02`0fMWI00<000000>c/k03/k>`0KP3/k>`4000005X0oooo1000001a0>c/k0030000003IfMT0fMWI
00`0fMWI203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo1@36a/H00`000000
fMWI0=WIf@0/0=WIf@030000003/k>`0k>c/06/0k>c/1000001R0?ooo`@00000KP3/k>`00`000000
fMWI0=WIf@0;0=WIf@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0a/K6
00<000000=WIf@3IfMT0:`3IfMT2000006T0k>c/1@00001Z0?ooo`D00000JP3/k>`00`000000fMWI
0=WIf@0:0=WIf@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`<0a/K600<0
00000=WIf@3IfMT0:`3IfMT00`000000k>c/0>c/k01V0>c/k0<00000M03oool3000006P0k>c/00<0
00000=WIf@3IfMT02@3IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool2
0<K6aP030000003IfMT0fMWI02/0fMWI00<000000>c/k03/k>`0I03/k>`3000007X0oooo1000001U
0>c/k0030000003IfMT0fMWI00P0fMWI203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo00<0a/K60000003IfMT0;03IfMT00`000000k>c/0>c/k01S0>c/k0800000P@3oool30000
06<0k>c/0P0000080=WIf@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`03
0000003IfMT0fMWI02/0fMWI00<000000>c/k03/k>`0H03/k>`4000008H0oooo0P00001S0>c/k003
0000003IfMT0fMWI00D0fMWI203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
;@3IfMT00`000000k>c/0>c/k01O0>c/k0800000S03oool300000640k>c/00<000000=WIf@3IfMT0
103IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool/0=WIf@030000003/
k>`0k>c/05h0k>c/0P00002A0?ooo`<00000G`3/k>`00`000000fMWI0=WIf@030=WIf@P0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`040?ooobX0fMWI0P00001N0>c/k0<00000UP3oool2
000005h0k>c/00<000000=WIf@3IfMT00P3IfMT80?ooo`4000000@3oool001L0oooo0P0000050?oo
obT0fMWI00<000000>c/k03/k>`0F`3/k>`3000009/0oooo0`00001L0>c/k08000000P3IfMT70?oo
o`8000000@3oool001L0oooo00<000000?ooo`3oool0103ooolX0=WIf@030000003/k>`0k>c/05X0
k>c/0P00002Q0?ooo`800000G03/k>`00`000000fMWI0?ooo`070?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103ooolW0=WIf@030000003/k>`0k>c/05T0k>c/0P00002U0?ooo`800000
FP3/k>`00`000000fMWI0?ooo`070?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103o
oolV0=WIf@030000003/k>`0k>c/05P0k>c/0P00002Y0?ooo`800000F@3/k>`00`000000oooo0?oo
o`060?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolU0=WIf@030000003/k>`0
k>c/05H0k>c/0`00002]0?ooo`800000F03/k>`00`000000oooo0?ooo`050?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0103ooolT0=WIf@030000003/k>`0k>c/05D0k>c/0P00002b0?oo
o`800000EP3/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolS0=WIf@03
0000003/k>`0k>c/05@0k>c/0P00002f0?ooo`800000E03/k>`80?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103ooolQ0=WIf@800000E03/k>`300000;X0oooo0`00001A0>c/k0P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooob00fMWI00<000000>c/k03/k>`0DP3/
k>`200000<00oooo0P00001?0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`04
0?oooal0fMWI00<000000>c/k03/k>`0D@3/k>`200000<@0oooo00<000000>c/k03/k>`0C03/k>`8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolN0=WIf@030000003/k>`0k>c/
0500k>c/0P0000370?ooo`800000C03/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0103ooolM0=WIf@030000003/k>`0k>c/04l0k>c/0P00003;0?ooo`<00000B@3/k>`80?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0103ooolL0=WIf@030000003/k>`0k>c/04l0k>c/
00<000000?ooo`3oool0cP3oool2000004L0k>c/203oool100000040oooo000:0?ooo`L000001P3o
ool00`000000oooo0?ooo`040?oooa/0fMWI00<000000>c/k03/k>`0CP3/k>`200000=<0oooo00<0
00000>c/k03/k>`0A03/k>`80?ooo`4000000@3oool000d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?oooaX0fMWI00<000000>c/k03/k>`0CP3/k>`00`000000oooo0?ooo`3D
0?ooo`800000A03/k>`80?ooo`4000000@3oool000d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?oooaT0fMWI00<000000>c/k03/k>`0C@3/k>`200000=T0oooo0P0000120>c/
k0P0oooo0@0000010?ooo`003@3oool00`000000oooo0?ooo`070?ooo`<00000103ooolH0=WIf@03
0000003/k>`0k>c/04`0k>c/0P00003M0?ooo`800000@03/k>`60?ooo`<000000@3oool000030?oo
o`000000000000@000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
5`3IfMT00`000000k>c/0>c/k01;0>c/k0800000h@3oool2000003h0k>c/203oool100000040oooo
000=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103ooolF0=WIf@030000003/
k>`0k>c/04X0k>c/0P00003U0?ooo`030000003/k>`0k>c/03/0k>c/203oool100000040oooo000=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103ooolE0=WIf@030000003/k>`0
k>c/04T0k>c/0P00003X0?ooo`800000>`3/k>`80?ooo`4000000@3oool000/0oooo0`0000090?oo
o`030000003oool0oooo00@0oooo503IfMT00`000000k>c/0>c/k0190>c/k0030000003oool0oooo
0>X0oooo00<000000>c/k03/k>`0>03/k>`80?ooo`4000000@3oool000d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`040?oooa<0fMWI00<000000>c/k03/k>`0B@3/k>`00`000000
oooo0?ooo`3/0?ooo`800000>03/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103ooolB0=WIf@030000003/k>`0k>c/04P0k>c/0P00003a0?ooo`800000=P3/k>`80?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103ooolA0=WIf@030000003/k>`0k>c/04P0k>c/00<0
00000?ooo`3oool0l`3oool2000003@0k>c/203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo403IfMT00`000000k>c/0>c/k0170>c/k0800000n03oool00`000000k>c/0>c/k00a
0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`l0fMWI00<000000>c/
k03/k>`0A`3/k>`00`000000oooo0?ooo`3i0?ooo`030000003/k>`0k>c/0300k>c/203oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo3P3IfMT00`000000k>c/0>c/k0170>c/k003
0000003oool0oooo0?/0oooo0P00000`0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?ooo`d0fMWI00<000000>c/k03/k>`0AP3/k>`200000?l0oooo0@3oool2000002h0k>c/
203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo303IfMT00`000000k>c/0>c/
k0150>c/k0800000o`3oool50?ooo`030000003/k>`0k>c/02/0k>c/203oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo2`3IfMT00`000000k>c/0>c/k0150>c/k0030000003oool0
oooo0?l0oooo1P3oool2000002/0k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo2P3IfMT00`000000k>c/0>c/k0140>c/k0800000o`3oool;0?ooo`030000003/k>`0k>c/
02P0k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2P3IfMT00`000000
k>c/0>c/k0130>c/k0030000003oool0oooo0?l0oooo303oool2000002P0k>c/203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo203IfMT2000004@0k>c/0P00003o0?oooa40oooo
00<000000>c/k03/k>`09@3/k>`80?ooo`4000000@3oool001L0oooo0P0000050?ooo`L0fMWI00<0
00000>c/k03/k>`0@`3/k>`00`000000oooo0?ooo`3o0?oooa80oooo00<000000>c/k03/k>`0903/
k>`70?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0103oool60=WIf@030000003/k>`0
k>c/04<0k>c/00<000000?ooo`3oool0o`3ooolD0?ooo`030000003/k>`0k>c/02<0k>c/203oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo1P3IfMT00`000000k>c/0>c/k0110>c/
k0800000o`3ooolH0?ooo`8000008`3/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0103oool40=WIf@800000@P3/k>`200000?l0oooo703oool00`000000k>c/0>c/k00P0>c/k0P0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`<0fMWI00<000000>c/k03/k>`0
@@3/k>`00`000000oooo0?ooo`3o0?oooad0oooo0P00000P0>c/k0P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo`80fMWI00<000000>c/k03/k>`0@03/k>`200000?l0oooo8P3o
ool2000001h0k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo0P3IfMT0
0`000000k>c/0>c/k00o0>c/k0030000003oool0oooo0?l0oooo8`3oool00`000000k>c/0>c/k00L
0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030=WIf@000000k>c/
0400k>c/00<000000?ooo`3oool0o`3ooolU0?ooo`800000703/k>`80?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103oool00`000000k>c/0>c/k00n0>c/k0800000o`3ooolZ0?ooo`80
00006P3/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooom00>c/k0030000
003oool0oooo0?l0oooo;03oool00`000000k>c/0>c/k00G0>c/k0P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooocl0k>c/00<000000?ooo`3oool0o`3oool^0?ooo`030000003/
k>`0k>c/01H0k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo?P3/k>`0
0`000000oooo0?ooo`3o0?oooc00oooo00<000000>c/k03/k>`05@3/k>`80?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0103ooolm0>c/k0030000003oool0oooo0?l0oooo<P3oool00`00
0000k>c/0>c/k00D0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooc`0
k>c/00<000000?ooo`3oool0o`3ooold0?ooo`030000003/k>`0k>c/01<0k>c/203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo>P3/k>`200000?l0oooo>03oool2000001<0k>c/
203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo>@3/k>`00`000000oooo0?oo
o`3o0?ooocX0oooo00<000000>c/k03/k>`0403/k>`80?ooo`4000000@3oool001L0oooo0P000005
0?ooocP0k>c/00<000000?ooo`3oool0o`3oooll0?ooo`030000003/k>`0k>c/00l0k>c/1`3oool2
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo=`3/k>`00`000000oooo0?ooo`3o0?oo
och0oooo0P00000?0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooocD0
k>c/0P00003o0?oood<0oooo00<000000>c/k03/k>`0303/k>`80?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103ooold0>c/k0030000003oool0oooo0?l0oooo@`3oool00`000000k>c/
0>c/k00<0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooc<0k>c/00<0
00000?ooo`3oool0o`3ooom50?ooo`800000303/k>`80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103ooola0>c/k0800000o`3ooom:0?ooo`8000002P3/k>`80?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0103oool`0>c/k0030000003oool0oooo0?l0ooooB`3oool00`00
0000k>c/0>c/k0080>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooc00
k>c/00<000000?ooo`3oool0o`3ooom<0?ooo`030000003/k>`0k>c/00L0k>c/203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo;`3/k>`00`000000oooo0?ooo`3o0?ooodh0oooo
0P0000070>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooobd0k>c/0P00
003o0?oooe<0oooo00<000000>c/k03/k>`0103/k>`80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool/0>c/k0030000003oool0oooo0?l0ooooE03oool00`000000k>c/0>c/k003
0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooob/0k>c/00<000000?oo
o`3oool0o`3ooomF0?ooo`030000003/k>`0k>c/0080k>c/203oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo:@3/k>`200000?l0ooooFP3oool200000080k>c/203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo:03/k>`00`000000oooo0?ooo`3o0?oooe`0oooo
00<000000>c/k03oool01`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo9`3/
k>`00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool01P3oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo9P3/k>`00`000000oooo0?ooo`3o0?oooel0oooo00<00000
0?ooo`3oool01P3oool100000040oooo000G0?ooo`8000001@3ooolU0>c/k0030000003oool0oooo
0?l0ooooH@3oool00`000000oooo0?ooo`040?ooo`8000000@3oool001L0oooo00<000000?ooo`3o
ool0103ooolT0>c/k0030000003oool0oooo0?l0ooooJP3oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo8P3/k>`200000?l0ooooK@3oool100000040oooo000G0?ooo`030000003o
ool0oooo00@0oooo8@3/k>`00`000000oooo0?ooo`3o0?ooofd0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooob40k>c/00<000000?ooo`3oool0o`3ooom]0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0103ooolP0>c/k0030000003oool0oooo0?l0ooooKP3oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo7P3/k>`200000?l0ooooL@3oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo7@3/k>`00`000000oooo0?ooo`3o0?ooog40oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa`0k>c/00<000000?ooo`3oool0o`3o
oomb0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolK0>c/k0030000003oool0
oooo0?l0ooooL`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo6P3/k>`00`00
0000oooo0?ooo`3o0?ooog@0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooaT0
k>c/00<000000?ooo`3oool0o`3ooome0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103ooolH0>c/k0030000003oool0oooo0?l0ooooMP3oool100000040oooo000G0?ooo`030000003o
ool0oooo00@0oooo5`3/k>`00`000000oooo0?ooo`3o0?ooogL0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?oooaH0k>c/00<000000?ooo`3oool0Y03oool20?oo0=40oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?oooaD0k>c/00<000000?ooo`3oool0OP3oool20?oo
02<0oooo1P3oo`3?0?ooo`4000000@3oool001L0oooo0P0000050?oooa@0k>c/00<000000?ooo`3o
ool0O@3oool60?oo0200oooo203oo`0[0?ooo`80ool0X03oool200000040oooo000G0?ooo`030000
003oool0oooo00@0oooo4`3/k>`00`000000oooo0?ooo`1m0?ooo`P0ool07`3oool80?oo02T0oooo
1P3oo`2O0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolB0>c/k0030000003o
ool0oooo07h0oooo203oo`0N0?ooo`X0ool09`3oool80?oo09h0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?oooa40k>c/00<000000?ooo`3oool0OP3oool:0?oo01d0oooo2P3oo`0W
0?ooo`P0ool0WP3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo403/k>`00`00
0000oooo0?ooo`1o0?ooo`X0ool07P3oool80?oo02L0oooo2P3oo`2M0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103oool?0>c/k0030000003oool0oooo0840oooo203oo`0O0?ooo`P0
ool09`3oool:0?oo09d0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`h0k>c/
00<000000?ooo`3oool0PP3oool80?oo0200oooo1P3oo`0A0?ooo`H0O`1o4P3oool80?oo09h0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`d0k>c/00<000000?ooo`3oool0Q03o
ool60?oo02<0oooo0P3oo`0B0?ooo`P0O`1o4@3oool80?oo09h0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo``0k>c/00<000000?ooo`3oool0Q`3oool20?oo03L0oooo301o07l@
0?ooo`H0ool0W`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2`3/k>`00`00
0000oooo0?ooo`310?ooo`D0O`1o0P3oo`0507l0O`H0oooo1P1o07l60?ooo`80ool0X@3oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo2P3/k>`00`000000oooo0?ooo`310?ooo`@0
O`1o1P3oo`0407l0O`@0oooo201o07nX0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103oool90>c/k0030000003oool0oooo0:H0oooo1P1o07lE0?ooo`@0O`1o0`3oo`020000o`<0ool0
101o07l00`3oool0O`1o07l0O`0:07l0ObX0oooo0P3oo`1j0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103oool80>c/k0030000003oool0oooo09L0oooo1P1o07l90?ooo`P0O`1o503o
ool407l0O`80ool010000?l20?oo00@0O`1o00<0oooo07l0O`1o07l00`1o07l20?oo00D0O`1o5P3o
ool607l0O``0oooo1P3oo`1h0?ooo`4000000@3oool000/0oooo100000080?ooo`030000003oool0
oooo00@0oooo1`3/k>`00`000000oooo0?ooo`2G0?ooo`P0O`1o1P3oool<07l0Oa80oooo0`1o07l2
0?oo00H0003o0P3oo`0707l0O`H0ool0101o07lD0?ooo`P0O`1o2P3oool80?oo07L0oooo0@000001
0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool70>c/k0030000003oool0oooo09D0oooo301o07l40?ooo`D0O`1o0P3oo`0507l0
Oa80oooo0`1o07l00`3oo`00003o0000o`050000o`80ool01P1o07l30?oo0080003o0`3oo`0407l0
Oa40oooo1@1o07l20?oo00D0O`1o203oool80?oo07L0oooo0@0000010?ooo`002P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool50>c/k080
0000V03oool507l0O`80ool01@1o07l30?ooo`@0O`1o1P3oo`0407l0O`l0oooo1P000?l20?oo00@0
003o00<0ool00000o`000?l01P000?l20?oo00@0003o0P3oo`0407l0Oa40oooo0`1o07l60?oo00<0
O`1o1`3oool:0?oo07H0oooo0@0000010?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo0`0000040?ooo`@0k>c/00<000000?ooo`3oool0U`3oool407l0O`H0ool0
101o07l00`3oool0O`1o07l0O`0207l0O`<0ool00P000?l30?oo00@0O`1o203oool60000o`80oooo
101o07l30?oo0080003o0`3oo`0607l0O`030?oo00000?l0003o00P0003o0P1o07l@0?ooo`<0O`1o
0`3oo`020000o`<0ool00`1o07l60?ooo`X0ool0M03oool300000040oooo000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`<0k>c/00<0
00000?ooo`3oool0U`3oool407l0O`<0ool00P000?l30?oo00P0O`1o0P3oo`040000o`80ool0101o
07l00`3oool0003o0000o`050000o`T0oooo101o07l60?oo00L0O`1o0P3oo`060000o`80ool000<0
O`1o0000o`000?l020000?l70?ooo`@0O`1o0P3oo`040000o`80ool0101o07l60?ooo`P0ool0M`3o
ool100000040oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`<0k>c/00<000000?ooo`3oool0U`3oool407l0O`80ool010000?l2
0?oo00L0O`1o0P3oo`0<0000oa40oooo1@1o07l20?oo00D0O`1o00<0oooo07l0O`1o07l00P1o07l2
0?oo00@0003o0P3oo`0407l0O`P0oooo2P000?l20?oo00H0003o0P3oo`0307l0O`H0oooo203oo`1g
0?ooo`4000000@3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo0P3/k>`00`000000oooo0?ooo`2H0?ooo`<0O`1o0P3oo`060000
o`80ool00`1o07l;0000o`80ool00`1o07lB0?ooo``0O`1o00<0oooo07l0O`1o07l00P1o07l30?oo
0080003o0`3oo`0407l0O`l0oooo0`1o07l80000o`80ool00`1o07l70?ooo`H0ool0N03oool10000
0040oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030>c/k0000000oooo09X0oooo0`1o07l20?oo00/0003o101o07l20?oo00@0
003o0P3oo`0407l0Oa@0oooo201o07l40?ooo`@0O`1o1P3oo`0407l0Oa00oooo101o07l20?oo00L0
003o0`1o07l90?ooo`80ool0NP3oool100000040oooo000;0?ooo`@00000203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo09X0oooo101o07l60000o`80ool0201o07l30?oo0080003o
0`3oo`0407l0OaD0oooo1P1o07l60?ooo`D0O`1o0P3oo`0507l0Oa40oooo101o07l30?oo0080003o
0`3oo`000`1o07l0003o0000o`020000oa<0oooo1P1o07m[0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0X@3oool0101o07l0003o0000o`000?l30?oo0080003o0`3oo`0407l0O`030?oo
o`1o07l0O`1o0080O`1o1P3oo`0407l0Ob80oooo301o07lA0?ooo`D0O`1o1P3oo`0507l0O`040?oo
o`000?l0003o0000o`l0oooo201o07mZ0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
X03oool20000o`@0O`1o1P3oo`0407l0O`<0oooo1@1o07l20?oo00D0O`1o9@3oool807l0Oa@0oooo
1P1o07l20?oo00H0O`1o1@3oool30000o`X0oooo301o07mX0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0WP3oool20000o`<0oooo1@1o07l20?oo00D0O`1o103oool<07l0ObH0oooo1P1o
07lF0?ooo``0O`1o2@3oool40000o`H0oooo1@1o07l20?oo00D0O`1oJ03oool100000040oooo000G
0?ooo`030000003oool0oooo09/0oooo0`000?l50?ooo``0O`1o1P3oool807l0Od@0oooo301o07l=
0?ooo`<0003o0P3oool407l0O`H0ool0101o07mW0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0V@3oool20000o`X0oooo201o07l90?ooo`H0O`1oA`3oool807l0Oa80oooo0`000?l207l0
O`<0ool00P000?l30?oo00@0O`1oIP3oool100000040oooo000G0?ooo`030000003oool0oooo08<0
oooo1P1o07l=0?ooo`<0003o3@3oool607l0OeP0oooo1P1o07lD0?ooo`80O`1o20000?l20?oo00@0
O`1oIP3oool100000040oooo000G0?ooo`030000003oool0oooo0880oooo201o07l:0?ooo`80003o
R03oool307l0O`80ool01P000?l20?oo00<0O`1oIP3oool100000040oooo000G0?ooo`030000003o
ool0oooo0800oooo301o07l50?ooo`<0003oRP3oool307l0O`80ool01P000?l20?oo00<0O`1oIP3o
ool100000040oooo000G0?ooo`030000003oool0oooo0800oooo1@1o07l20?oo00D0O`1o0`3oool2
0000ohd0oooo101o07l20?oo00@0003o00<0ool00000o`000?l00`1o07mV0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0O`3oool407l0O`80ool00P000?l20?oo00@0O`1o0P000?n?0?oo
o`@0O`1o0`3oo`020000o`<0ool000@0O`1o0000o`000?l0O`1oIP3oool100000040oooo000G0?oo
o`030000003oool0oooo07h0oooo101o07l20?oo00@0003o0P3oo`030000o`0307l0O`3oool0oooo
08l0oooo101o07l60?oo00@0O`1o0P000?mU0?ooo`4000000@3oool001L0oooo0P00001b0?ooo`H0
O`1o1`3oool407l0O`030?oo00000?l0003o00D0003o101o07nB0?ooo`D0O`1o0P3oo`0507l0O`<0
oooo0P000?mR0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0L03oool807l0O`H0oooo
0`1o07l20?oo00H0003o0P3oo`0307l0Oi80oooo301o07l50?ooo`80003o303oool607l0Odl0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`1^0?ooo``0O`1o103oool307l0O`030?oo0000
0?l0003o00@0003o0`3oo`0307l0Oi@0oooo201o07l90?ooo`80003o2@3oool807l0Odh0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`1^0?ooo`D0O`1o0P3oo`0507l0O`@0oooo00@0O`1o
0000o`000?l0003o0`3oo`020000o`<0ool0101o07nE0?ooo`H0O`1o303oool20000o`D0oooo301o
07m<0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0K@3oool407l0O`H0ool0101o07l0
103oool0003o0000o`000?l307l0O`P0ool0101o07nY0?ooo`80003o0`3oool607l0O`80ool0101o
07m<0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0K03oool407l0O`<0ool00P000?l3
0?oo000407l0O`000?l0003o0000o`<0oooo101o07l60?oo00@0O`1o[03oool20000o`D0O`1o1P3o
o`0307l0Od/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1/0?ooo`@0O`1o0P3oo`07
0000o`<0O`1o103oool507l0O`80ool01@1o07n^0?ooo`0307l0O`000?l0003o0080O`1o0`3oo`02
0000o`<0ool00`1o07m:0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0K03oool307l0
O`80ool01P000?l20?oo00<0O`1o103oool<07l0Ojh0oooo0`1o07l20000o`80ool010000?l20?oo
00<0O`1oBP3oool100000040oooo000G0?ooo`030000003oool0oooo06`0oooo0`1o07l20?oo00H0
003o0P3oo`0307l0O`H0oooo201o07n`0?ooo`@0O`1o00<0ool00000o`000?l01@000?l20?oo0080
O`1oBP3oool100000040oooo000G0?ooo`030000003oool0oooo06`0oooo101o07l00`3oo`00003o
0000o`030000o`80ool0101o07l70?ooo`H0O`1o/@3oool407l0O`80ool01P000?l20?oo0080O`1o
BP3oool100000040oooo000G0?ooo`030000003oool0oooo06`0oooo0`1o07l20000o`80ool00P00
0?l30?oo00@0O`1o_P3oool507l0O`80ool010000?l20?oo00<0O`1oBP3oool100000040oooo000G
0?ooo`030000003oool0oooo06d0oooo00@0O`1o0000o`1o07l0O`1o1P3oo`0407l0Okl0oooo1@1o
07l30?oo0080003o00<0ool00000o`000?l00`1o07m:0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0K03oool20000o`D0O`1o0P3oo`0507l0Ol40oooo1@1o07l60?oo000307l0O`000?l0
003o04/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo
00`0O`1o`P3oool607l0O`80ool0101o07l00`3oool0003o0?ooo`190?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0J@3oool20000o`D0oooo201o07o40?ooo``0O`1o0P3oool20000odP0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo00H0oooo
1P1o07o70?ooo`P0O`1o1P3oool20000odH0oooo0@0000010?ooo`005`3oool2000006L0oooo0P00
0?oG0?ooo`H0O`1o2@3oool20000od<0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`1U
0?ooo`030000o`3oool0oooo0>P0oooo00<0003o0?ooo`3oool0@@3oool100000040oooo000G0?oo
o`030000003oool0oooo06<0oooo0P000?o/0?ooo`80003o203oool607l0Oc<0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`1R0?ooo`030000o`3oool0oooo0>h0oooo0P000?l50?ooo`P0
O`1o<P3oool100000040oooo000G0?ooo`030000003oool0oooo0600oooo0P000?oc0?ooo`80003o
00<0oooo07l0O`1o07l02P1o07l`0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0G`3o
ool00`000?l0oooo0?ooo`3e0?ooo`030000o`1o07l0O`1o00<0O`1o0P3oo`0507l0Oc00oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`1M0?ooo`80003on03oool0101o07l0003o0000o`1o
07l60?oo00@0O`1o;`3oool100000040oooo000G0?ooo`030000003oool0oooo05`0oooo00<0003o
0?ooo`3oool0m`3oool407l0O`80003o00<0ool00000o`000?l00`3oo`0407l0Obh0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`1=0?ooo`H0O`1o1`3oool20000ooX0oooo101o07l20?oo
00@0003o0P3oo`0407l0Obh0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1<0?ooo`P0
O`1o1@3oool00`000?l0oooo0?ooo`3j0?ooo`<0O`1o0P3oo`060000o`80ool00`1o07l^0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0BP3oool<07l0O`030?ooo`000?l0003o0?d0oooo
0`1o07l20?oo00H0003o0P3oo`0307l0Obh0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`1:0?ooo`D0O`1o0P3oo`0507l0O`030000o`3oool0oooo0?d0oooo101o07l20?oo00H0003o101o
07l^0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0B@3oool407l0O`H0ool000@0O`1o
0000o`000?l0O`1oo`3oool407l0O`<0ool00P000?l30?oo00040000o`1o07l0O`1o07l0Obh0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`180?ooo`@0O`1o0`3oo`020000o`80ool000<0
003o07l0O`1o07l00P1o07oo0?ooo`@0O`1o1P3oo`0207l0O`030000o`1o07l0oooo02h0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`180?ooo`@0O`1o0P3oo`050000o`030?oo001o07l0
O`1o0080O`1oo`3oool10?ooo`D0O`1o0P3oo`0507l0O`030000o`3oool0oooo02d0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`180?ooo`<0O`1o0P3oo`060000o`80ool00`1o07oo0?oo
o`40oooo301o07l00`3oool0003o0000o`0]0?ooo`4000000@3oool001L0oooo0P0000190?ooo`<0
O`1o0P3oo`060000o`80ool00`1o07oo0?ooo`<0oooo201o07l50?ooo`030000o`3oool0oooo02T0
oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`180?ooo`<0O`1o0P000?l00`3oo`00003o
0000o`020000o`80ool0101o07oo0?ooo`@0oooo1P1o07l70?ooo`030000o`3oool0oooo02T0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0h0?ooo`H0O`1o2P3oool0101o07l0003o0000
o`1o07l30?oo0080003o0`3oo`0407l0Ool0oooo4P3oool00`000?l0oooo0?ooo`0X0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0=`3oool807l0O`P0oooo0P000?l407l0O`H0ool0101o
07oo0?oooa@0oooo0P000?lX0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0=@3oool<
07l0O`<0oooo0`000?l30?ooo`D0O`1o0P3oo`0507l0Ool0oooo5`3oool00`000?l0oooo0?ooo`0U
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0=@3oool507l0O`80ool01@1o07l00`3o
ool0003o0000o`060?ooo``0O`1oo`3ooolH0?ooo`030000o`3oool0oooo00D0oooo1P1o07lI0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0=03oool407l0O`H0ool00P1o07l20000o`X0
oooo201o07oo0?oooa/0oooo00<0003o0?ooo`3oool00`3oool807l0OaP0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0c0?ooo`@0O`1o0`3oo`020000o`80ool00P000?l307l0O`X0oooo
1P1o07oo0?oooad0oooo0P000?l00`3oool0O`1o07l0O`0:07l0OaH0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0c0?ooo`@0O`1o0P3oo`050000o`030?oo001o07l0O`1o0080O`1oo`3o
ool_0?ooo`030000o`1o07l0O`1o00<0O`1o0P3oo`0507l0OaH0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0c0?ooo`<0O`1o0P3oo`060000o`80ool00`1o07oo0?ooobl0oooo00@0O`1o
0000o`1o07l0O`1o1P3oo`0407l0OaD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0c
0?ooo`<0O`1o00<0ool00000o`000?l01@000?l20?oo00<0O`1oo`3oool^0?ooo`<0O`1o00@0003o
0?oo003oo`00ool00P000?l30?oo00@0O`1o503oool100000040oooo000G0?ooo`030000003oool0
oooo03<0oooo0P1o07l20000o`80ool010000?l20?oo00@0O`1oo`3oool^0?ooo`@0O`1o1P000?l2
0?oo00@0O`1o503oool100000040oooo000G0?ooo`030000003oool0oooo0380oooo0`000?l207l0
O`<0ool00P000?l30?oo00@0O`1oo`3oool^0?ooo`<0O`1o0P3oo`060000o`80ool00`1o07lD0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0<03oool20000o`80oooo101o07l60?oo00@0
O`1oo`3oool_0?ooo`<0O`1o0P3oo`060000o`80ool00`1o07lD0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0;P3oool20000o`D0oooo1@1o07l20?oo00D0O`1oo`3oool`0?ooo`@0O`1o
0P3oo`040000o`80ool0101o07lD0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:`3o
ool30000o`L0oooo301o07oo0?oooc00oooo101o07l30?oo00<0003o0P3oo`0407l0Oa@0oooo0@00
00010?ooo`005`3oool2000002X0oooo0P000?l<0?ooo`P0O`1oo`3ooolc0?ooo`@0O`1o1@3oo`02
0000o`<0O`1o503oool200000040oooo000G0?ooo`030000003oool0oooo02L0oooo0P000?l?0?oo
o`H0O`1oo`3ooole0?ooo`D0O`1o0P3oo`0307l0O`030000o`1o07l0oooo01D0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0T0?ooo`<0003oo`3ooom<0?ooo`/0O`1o00<0003o0?ooo`3o
ool0503oool100000040oooo000G0?ooo`030000003oool0oooo0280oooo0P000?oo0?oooe40oooo
201o07l20?ooo`030000o`3oool0oooo01<0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0P0?ooo`80003oo`3ooomD0?ooo`H0O`1o103oool00`000?l0oooo0?ooo`0B0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool07@3oool30000ool0ooooH@3oool00`000?l0oooo0?ooo`0A
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool06`3oool20000ool0ooooI@3oool20000
oa40oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0H0?ooo`<0003oo`3ooomY0?ooo`03
0000o`3oool0oooo00D0oooo100000050?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
5P3oool20000ool0ooooK@3oool010000?l0oooo0?ooo`3oool2000000H0O`1o0P0000020?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool00P3oool607l0O``0oooo0P000?oo0?ooog00oooo
00@0003o0000000000000000201o07l400000040oooo000G0?ooo`040000003oool0oooo0?ooo`P0
O`1o203oool30000ool0ooooLP3oool00`000000003o07l0O`0;07l0O`8000000@3oool001L0oooo
00<000000?ooo`1o07l02`1o07l40?ooo`80003oo`3ooomd0?ooo`<0000000<0003o07l0O`1o07l0
0P1o07l20?oo00D0O`1o0P0000010?ooo`005`3oool00`000000oooo07l0O`0407l0O`80ool01@1o
07l20?ooo`80003oo`3ooomf0?ooo`8000000P1o07l20000o`H0ool0101o07l100000040oooo000:
0?ooo`L000001P3oool00`000000O`1o07l0O`0207l0O`H0ool00P1o07l30000ool0ooooM`3oool2
000000@0O`1o00<0ool00000o`3oo`000P000?l30?oo00@0O`1o0@3oool000d0oooo00<000000?oo
o`3oool01`3oool407l0O`<0ool00P000?l20?oo0080003o0`1o07oo0?ooogL0oooo0P00000407l0
O`80ool010000?l20?oo00@0O`1o0@3oool000d0oooo00<000000?ooo`3oool01`3oool407l0O`80
ool01@000?l00`3oo`00O`1o07l0O`0207l0Ool0ooooMP3oool3000000<0O`1o0P3oo`060000o`80
ool00`1o07l10?ooo`003@3oool00`000000oooo0?ooo`070?ooo`<0O`1o0P3oo`060000o`80ool0
0`1o07oo0?ooogH0oooo0`00000307l0O`80ool01P000?l20?oo00<0O`1o0@3oool000d0oooo00<0
00000?ooo`3oool01`3oool307l0O`80ool01P000?l20?oo00<0O`1oo`3ooomf0?ooo`<000000`1o
07l20?oo00H0003o0P3oo`0307l0O`40oooo000=0?ooo`030000003oool0oooo00L0oooo101o07l2
0?oo00@0003o0P3oo`0407l0Ool0ooooMP3oool3000000@0O`1o0P3oo`040000o`80ool0101o07l1
0?ooo`003@3oool00`000000oooo0?ooo`070?ooo`@0O`1o0`3oo`020000o`<0ool0101o07oo0?oo
ogH0oooo0`00000407l0O`<0ool00P000?l30?oo00@0O`1o0@3oool000/0oooo0`0000090?ooo`03
0000001o07l0O`1o0080O`1o1P3oo`0407l0Ool0ooooM`3oool4000000@0O`1o1P3oo`0407l0O`40
00000@3oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo07l0O`0407l0O`80ool0
1@1o07oo0?ooogT0oooo1000000507l0O`80ool01@1o07l200000040oooo000G0?ooo`030000003o
ool0O`1o00/0O`1o7@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`1=0?ooo`@00000301o07l200000040oooo000G
0?ooo`040000003oool0oooo0?ooo`P0O`1o3@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01P3oool5000000P0O`1o100000010?ooo`005`3oool5
000000H0O`1oo`000023000000H0O`1o1@0000010?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.37362, -4.19535, 0.00841771, \
0.018519}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({0.`, {X\_1 \[Rule] 1.`, X\_2 \[Rule] 1.`}}\), 
        ",", \({"Steps" \[Rule] 15, "Residual" \[Rule] 21, 
          "Jacobian" \[Rule] 16}\), ",", 
        TagBox[\(\[SkeletonIndicator]  
            ContourGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell[TextData[{
  "The reason that the reported evaluations include residual and Jacobian is \
because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has detected symbolically that the function is a sum of squares, so it is \
possible to use the Levenberg-Marquardt method, which is a Gauss-Newton \
method based on working with the residual vector ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`f = r . r\)]],
  ".  The residual function is found symbolically in this case."
}], "Text"],

Cell["\<\
This shows the steps and evaluations used by Newton's \
method..\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p2\  = \ 
      FindMinimumPlot[\((1 - X\_1)\)\^2 + 
          100\ \((\(-X\_1\%2\) + X\_2)\)\^2, {{X\_1, \(-1.2`\)}, {X\_2, 
            1.`}}, \ Method \[Rule] Newton]\)], "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.543706 0.437063 0.689361 0.211062 [
[.10664 -0.0125 -6 -9 ]
[.10664 -0.0125 6 0 ]
[.32517 -0.0125 -12 -9 ]
[.32517 -0.0125 12 0 ]
[.54371 -0.0125 -3 -9 ]
[.54371 -0.0125 3 0 ]
[.76224 -0.0125 -9 -9 ]
[.76224 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05617 -12 -4.5 ]
[-0.0125 .05617 0 4.5 ]
[-0.0125 .26724 -12 -4.5 ]
[-0.0125 .26724 0 4.5 ]
[-0.0125 .4783 -12 -4.5 ]
[-0.0125 .4783 0 4.5 ]
[-0.0125 .68936 -6 -4.5 ]
[-0.0125 .68936 0 4.5 ]
[-0.0125 .90042 -6 -4.5 ]
[-0.0125 .90042 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10664 0 m
.10664 .00625 L
s
[(-1)] .10664 -0.0125 0 1 Mshowa
.32517 0 m
.32517 .00625 L
s
[(-0.5)] .32517 -0.0125 0 1 Mshowa
.54371 0 m
.54371 .00625 L
s
[(0)] .54371 -0.0125 0 1 Mshowa
.76224 0 m
.76224 .00625 L
s
[(0.5)] .76224 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.15035 0 m
.15035 .00375 L
s
.19406 0 m
.19406 .00375 L
s
.23776 0 m
.23776 .00375 L
s
.28147 0 m
.28147 .00375 L
s
.36888 0 m
.36888 .00375 L
s
.41259 0 m
.41259 .00375 L
s
.45629 0 m
.45629 .00375 L
s
.5 0 m
.5 .00375 L
s
.58741 0 m
.58741 .00375 L
s
.63112 0 m
.63112 .00375 L
s
.67483 0 m
.67483 .00375 L
s
.71853 0 m
.71853 .00375 L
s
.80594 0 m
.80594 .00375 L
s
.84965 0 m
.84965 .00375 L
s
.89336 0 m
.89336 .00375 L
s
.93706 0 m
.93706 .00375 L
s
.06294 0 m
.06294 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05617 m
.00625 .05617 L
s
[(-3)] -0.0125 .05617 1 0 Mshowa
0 .26724 m
.00625 .26724 L
s
[(-2)] -0.0125 .26724 1 0 Mshowa
0 .4783 m
.00625 .4783 L
s
[(-1)] -0.0125 .4783 1 0 Mshowa
0 .68936 m
.00625 .68936 L
s
[(0)] -0.0125 .68936 1 0 Mshowa
0 .90042 m
.00625 .90042 L
s
[(1)] -0.0125 .90042 1 0 Mshowa
.125 Mabswid
0 .09839 m
.00375 .09839 L
s
0 .1406 m
.00375 .1406 L
s
0 .18281 m
.00375 .18281 L
s
0 .22502 m
.00375 .22502 L
s
0 .30945 m
.00375 .30945 L
s
0 .35166 m
.00375 .35166 L
s
0 .39387 m
.00375 .39387 L
s
0 .43609 m
.00375 .43609 L
s
0 .52051 m
.00375 .52051 L
s
0 .56272 m
.00375 .56272 L
s
0 .60494 m
.00375 .60494 L
s
0 .64715 m
.00375 .64715 L
s
0 .73157 m
.00375 .73157 L
s
0 .77379 m
.00375 .77379 L
s
0 .816 m
.00375 .816 L
s
0 .85821 m
.00375 .85821 L
s
0 .01396 m
.00375 .01396 L
s
0 .94264 m
.00375 .94264 L
s
0 .98485 m
.00375 .98485 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10664 .99375 m
.10664 1 L
s
.32517 .99375 m
.32517 1 L
s
.54371 .99375 m
.54371 1 L
s
.76224 .99375 m
.76224 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.15035 .99625 m
.15035 1 L
s
.19406 .99625 m
.19406 1 L
s
.23776 .99625 m
.23776 1 L
s
.28147 .99625 m
.28147 1 L
s
.36888 .99625 m
.36888 1 L
s
.41259 .99625 m
.41259 1 L
s
.45629 .99625 m
.45629 1 L
s
.5 .99625 m
.5 1 L
s
.58741 .99625 m
.58741 1 L
s
.63112 .99625 m
.63112 1 L
s
.67483 .99625 m
.67483 1 L
s
.71853 .99625 m
.71853 1 L
s
.80594 .99625 m
.80594 1 L
s
.84965 .99625 m
.84965 1 L
s
.89336 .99625 m
.89336 1 L
s
.93706 .99625 m
.93706 1 L
s
.06294 .99625 m
.06294 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .05617 m
1 .05617 L
s
.99375 .26724 m
1 .26724 L
s
.99375 .4783 m
1 .4783 L
s
.99375 .68936 m
1 .68936 L
s
.99375 .90042 m
1 .90042 L
s
.125 Mabswid
.99625 .09839 m
1 .09839 L
s
.99625 .1406 m
1 .1406 L
s
.99625 .18281 m
1 .18281 L
s
.99625 .22502 m
1 .22502 L
s
.99625 .30945 m
1 .30945 L
s
.99625 .35166 m
1 .35166 L
s
.99625 .39387 m
1 .39387 L
s
.99625 .43609 m
1 .43609 L
s
.99625 .52051 m
1 .52051 L
s
.99625 .56272 m
1 .56272 L
s
.99625 .60494 m
1 .60494 L
s
.99625 .64715 m
1 .64715 L
s
.99625 .73157 m
1 .73157 L
s
.99625 .77379 m
1 .77379 L
s
.99625 .816 m
1 .816 L
s
.99625 .85821 m
1 .85821 L
s
.99625 .01396 m
1 .01396 L
s
.99625 .94264 m
1 .94264 L
s
.99625 .98485 m
1 .98485 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.625 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .33913 m
.02711 .33003 L
.02894 .32794 L
.03567 .32032 L
.03866 .31696 L
.04437 .31061 L
.04837 .3062 L
.05322 .30089 L
.05808 .29564 L
.06224 .29118 L
.06779 .28529 L
.07143 .28147 L
.07751 .27514 L
.0808 .27176 L
.08722 .26521 L
.09036 .26204 L
.09693 .25549 L
.10013 .25233 L
.10664 .24597 L
.11012 .24262 L
.11636 .23667 L
.12034 .23291 L
.12607 .22757 L
.13082 .22319 L
.13578 .21868 L
.14157 .21348 L
.14549 .21 L
.15261 .20377 L
.15521 .20153 L
.16398 .19406 L
.16492 .19327 L
.17463 .18521 L
.17569 .18434 L
.18434 .17737 L
.18779 .17463 L
.19406 .16973 L
.20032 .16492 L
.20377 .1623 L
.21332 .15521 L
.21348 .15509 L
.22319 .14808 L
.22685 .14549 L
.23291 .14127 L
.24098 .13578 L
.24262 .13468 L
.25233 .1283 L
.2558 .12607 L
.26204 .12212 L
.27143 .11636 L
.27176 .11616 L
.28147 .1104 L
.28801 .10664 L
.29118 .10485 L
.30089 .09951 L
.30574 .09693 L
.31061 .09438 L
.32032 .08946 L
.32489 .08722 L
.33003 .08475 L
.33974 .08025 L
.34588 .07751 L
.34946 .07595 L
.35917 .07186 L
.36888 .06799 L
.36938 .06779 L
.37859 .06432 L
.38831 .06086 L
.39656 .05808 L
.39802 .05761 L
.40773 .05456 L
.41744 .05173 L
.42716 .0491 L
.43002 .04837 L
.43687 .04669 L
.44658 .04448 L
.45629 .04248 L
.46601 .04069 L
.47572 .03911 L
.47877 .03866 L
.48543 .03774 L
.49514 .03657 L
.50486 .03562 L
.51457 .03487 L
.52428 .03434 L
.53399 .03401 L
.54371 .03389 L
.55342 .03398 L
.56313 .03428 L
.57284 .03478 L
.58256 .0355 L
.59227 .03642 L
.60198 .03756 L
.61005 .03866 L
.61169 .0389 L
.62141 .04045 L
.63112 .04221 L
.64083 .04418 L
.65054 .04636 L
.65879 .04837 L
.66026 .04874 L
.66997 .05134 L
.67968 .05414 L
.68939 .05715 L
.69226 .05808 L
.69911 .06037 L
.70882 .0638 L
.71853 .06744 L
.71944 .06779 L
.72824 .07129 L
.73796 .07535 L
.74293 .07751 L
.74767 .07961 L
.75738 .08409 L
.76393 .08722 L
.76709 .08877 L
.77681 .09366 L
.78308 .09693 L
.78652 .09876 L
.79623 .10407 L
.80081 .10664 L
.80594 .10959 L
.81566 .11531 L
.81739 .11636 L
.82537 .12125 L
.83302 .12607 L
.83508 .12739 L
.84479 .13375 L
.84784 .13578 L
.85451 .14031 L
.86197 .14549 L
.86422 .14708 L
.87393 .15406 L
.8755 .15521 L
.88364 .16125 L
.8885 .16492 L
.89336 .16864 L
.90103 .17463 L
.90307 .17625 L
.91278 .18406 L
.91312 .18434 L
.92249 .19209 L
.92484 .19406 L
.93221 .20032 L
.9362 .20377 L
.94192 .20876 L
.94725 .21348 L
.95163 .21741 L
.958 .22319 L
.96134 .22627 L
.96848 .23291 L
.97106 .23534 L
.9787 .24262 L
.98077 .24461 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .33913 m
.02711 .33003 L
.02894 .32794 L
.03567 .32032 L
.03866 .31696 L
.04437 .31061 L
.04837 .3062 L
.05322 .30089 L
.05808 .29564 L
.06224 .29118 L
.06779 .28529 L
.07143 .28147 L
.07751 .27514 L
.0808 .27176 L
.08722 .26521 L
.09036 .26204 L
.09693 .25549 L
.10013 .25233 L
.10664 .24597 L
.11012 .24262 L
.11636 .23667 L
.12034 .23291 L
.12607 .22757 L
.13082 .22319 L
.13578 .21868 L
.14157 .21348 L
.14549 .21 L
.15261 .20377 L
.15521 .20153 L
.16398 .19406 L
.16492 .19327 L
.17463 .18521 L
.17569 .18434 L
.18434 .17737 L
.18779 .17463 L
.19406 .16973 L
.20032 .16492 L
.20377 .1623 L
.21332 .15521 L
.21348 .15509 L
.22319 .14808 L
.22685 .14549 L
.23291 .14127 L
.24098 .13578 L
.24262 .13468 L
.25233 .1283 L
.2558 .12607 L
.26204 .12212 L
.27143 .11636 L
.27176 .11616 L
Mistroke
.28147 .1104 L
.28801 .10664 L
.29118 .10485 L
.30089 .09951 L
.30574 .09693 L
.31061 .09438 L
.32032 .08946 L
.32489 .08722 L
.33003 .08475 L
.33974 .08025 L
.34588 .07751 L
.34946 .07595 L
.35917 .07186 L
.36888 .06799 L
.36938 .06779 L
.37859 .06432 L
.38831 .06086 L
.39656 .05808 L
.39802 .05761 L
.40773 .05456 L
.41744 .05173 L
.42716 .0491 L
.43002 .04837 L
.43687 .04669 L
.44658 .04448 L
.45629 .04248 L
.46601 .04069 L
.47572 .03911 L
.47877 .03866 L
.48543 .03774 L
.49514 .03657 L
.50486 .03562 L
.51457 .03487 L
.52428 .03434 L
.53399 .03401 L
.54371 .03389 L
.55342 .03398 L
.56313 .03428 L
.57284 .03478 L
.58256 .0355 L
.59227 .03642 L
.60198 .03756 L
.61005 .03866 L
.61169 .0389 L
.62141 .04045 L
.63112 .04221 L
.64083 .04418 L
.65054 .04636 L
.65879 .04837 L
.66026 .04874 L
Mistroke
.66997 .05134 L
.67968 .05414 L
.68939 .05715 L
.69226 .05808 L
.69911 .06037 L
.70882 .0638 L
.71853 .06744 L
.71944 .06779 L
.72824 .07129 L
.73796 .07535 L
.74293 .07751 L
.74767 .07961 L
.75738 .08409 L
.76393 .08722 L
.76709 .08877 L
.77681 .09366 L
.78308 .09693 L
.78652 .09876 L
.79623 .10407 L
.80081 .10664 L
.80594 .10959 L
.81566 .11531 L
.81739 .11636 L
.82537 .12125 L
.83302 .12607 L
.83508 .12739 L
.84479 .13375 L
.84784 .13578 L
.85451 .14031 L
.86197 .14549 L
.86422 .14708 L
.87393 .15406 L
.8755 .15521 L
.88364 .16125 L
.8885 .16492 L
.89336 .16864 L
.90103 .17463 L
.90307 .17625 L
.91278 .18406 L
.91312 .18434 L
.92249 .19209 L
.92484 .19406 L
.93221 .20032 L
.9362 .20377 L
.94192 .20876 L
.94725 .21348 L
.95163 .21741 L
.958 .22319 L
.96134 .22627 L
.96848 .23291 L
Mistroke
.97106 .23534 L
.9787 .24262 L
.98077 .24461 L
Mfstroke
.775 g
.01923 .41264 m
.02347 .40773 L
.02894 .40145 L
.03196 .39802 L
.03866 .39047 L
.04059 .38831 L
.04837 .37969 L
.04937 .37859 L
.05808 .36913 L
.05831 .36888 L
.06742 .35917 L
.06779 .35878 L
.07671 .34946 L
.07751 .34863 L
.08618 .33974 L
.08722 .33869 L
.09586 .33003 L
.09693 .32897 L
.10574 .32032 L
.10664 .31945 L
.11586 .31061 L
.11636 .31014 L
.12607 .30103 L
.12622 .30089 L
.13578 .29214 L
.13684 .29118 L
.14549 .28346 L
.14775 .28147 L
.15521 .27498 L
.15897 .27176 L
.16492 .26672 L
.17052 .26204 L
.17463 .25866 L
.18244 .25233 L
.18434 .25081 L
.19406 .24317 L
.19477 .24262 L
.20377 .23574 L
.20755 .23291 L
.21348 .22852 L
.22083 .22319 L
.22319 .22151 L
.23291 .2147 L
.23468 .21348 L
.24262 .20811 L
.24918 .20377 L
.25233 .20172 L
.26204 .19554 L
.26443 .19406 L
.27176 .18957 L
.28056 .18434 L
.28147 .18381 L
.29118 .17826 L
.29774 .17463 L
.30089 .17292 L
.31061 .16779 L
.31621 .16492 L
.32032 .16286 L
.33003 .15815 L
.33632 .15521 L
.33974 .15364 L
.34946 .14934 L
.35858 .14549 L
.35917 .14525 L
.36888 .14137 L
.37859 .1377 L
.38391 .13578 L
.38831 .13424 L
.39802 .13098 L
.40773 .12794 L
.41405 .12607 L
.41744 .1251 L
.42716 .12248 L
.43687 .12006 L
.44658 .11785 L
.45372 .11636 L
.45629 .11585 L
.46601 .11405 L
.47572 .11247 L
.48543 .1111 L
.49514 .10993 L
.50486 .10897 L
.51457 .10823 L
.52428 .10769 L
.53399 .10736 L
.54371 .10724 L
.55342 .10732 L
.56313 .10762 L
.57284 .10812 L
.58256 .10884 L
.59227 .10976 L
.60198 .11089 L
.61169 .11223 L
.62141 .11378 L
.63112 .11554 L
.63528 .11636 L
.64083 .11751 L
.65054 .11968 L
.66026 .12207 L
.66997 .12466 L
.67494 .12607 L
.67968 .12746 L
.68939 .13047 L
.69911 .13369 L
.70509 .13578 L
.70882 .13712 L
.71853 .14076 L
.72824 .14461 L
.73041 .14549 L
.73796 .14866 L
.74767 .15293 L
.75268 .15521 L
.75738 .1574 L
.76709 .16208 L
.77278 .16492 L
.77681 .16697 L
.78652 .17207 L
.79125 .17463 L
.79623 .17738 L
.80594 .1829 L
.80843 .18434 L
.81566 .18862 L
.82456 .19406 L
.82537 .19456 L
.83508 .2007 L
.83981 .20377 L
.84479 .20705 L
.85431 .21348 L
.85451 .21361 L
.86422 .22038 L
.86816 .22319 L
.87393 .22736 L
.88145 .23291 L
.88364 .23455 L
.89336 .24195 L
.89422 .24262 L
.90307 .24955 L
.90655 .25233 L
.91278 .25737 L
.91847 .26204 L
.92249 .26539 L
.93003 .27176 L
.93221 .27362 L
.94124 .28147 L
.94192 .28206 L
.95163 .29071 L
.95215 .29118 L
.96134 .29957 L
.96277 .30089 L
.97106 .30864 L
.97313 .31061 L
.98077 .31792 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .41264 m
.02347 .40773 L
.02894 .40145 L
.03196 .39802 L
.03866 .39047 L
.04059 .38831 L
.04837 .37969 L
.04937 .37859 L
.05808 .36913 L
.05831 .36888 L
.06742 .35917 L
.06779 .35878 L
.07671 .34946 L
.07751 .34863 L
.08618 .33974 L
.08722 .33869 L
.09586 .33003 L
.09693 .32897 L
.10574 .32032 L
.10664 .31945 L
.11586 .31061 L
.11636 .31014 L
.12607 .30103 L
.12622 .30089 L
.13578 .29214 L
.13684 .29118 L
.14549 .28346 L
.14775 .28147 L
.15521 .27498 L
.15897 .27176 L
.16492 .26672 L
.17052 .26204 L
.17463 .25866 L
.18244 .25233 L
.18434 .25081 L
.19406 .24317 L
.19477 .24262 L
.20377 .23574 L
.20755 .23291 L
.21348 .22852 L
.22083 .22319 L
.22319 .22151 L
.23291 .2147 L
.23468 .21348 L
.24262 .20811 L
.24918 .20377 L
.25233 .20172 L
.26204 .19554 L
.26443 .19406 L
.27176 .18957 L
Mistroke
.28056 .18434 L
.28147 .18381 L
.29118 .17826 L
.29774 .17463 L
.30089 .17292 L
.31061 .16779 L
.31621 .16492 L
.32032 .16286 L
.33003 .15815 L
.33632 .15521 L
.33974 .15364 L
.34946 .14934 L
.35858 .14549 L
.35917 .14525 L
.36888 .14137 L
.37859 .1377 L
.38391 .13578 L
.38831 .13424 L
.39802 .13098 L
.40773 .12794 L
.41405 .12607 L
.41744 .1251 L
.42716 .12248 L
.43687 .12006 L
.44658 .11785 L
.45372 .11636 L
.45629 .11585 L
.46601 .11405 L
.47572 .11247 L
.48543 .1111 L
.49514 .10993 L
.50486 .10897 L
.51457 .10823 L
.52428 .10769 L
.53399 .10736 L
.54371 .10724 L
.55342 .10732 L
.56313 .10762 L
.57284 .10812 L
.58256 .10884 L
.59227 .10976 L
.60198 .11089 L
.61169 .11223 L
.62141 .11378 L
.63112 .11554 L
.63528 .11636 L
.64083 .11751 L
.65054 .11968 L
.66026 .12207 L
.66997 .12466 L
Mistroke
.67494 .12607 L
.67968 .12746 L
.68939 .13047 L
.69911 .13369 L
.70509 .13578 L
.70882 .13712 L
.71853 .14076 L
.72824 .14461 L
.73041 .14549 L
.73796 .14866 L
.74767 .15293 L
.75268 .15521 L
.75738 .1574 L
.76709 .16208 L
.77278 .16492 L
.77681 .16697 L
.78652 .17207 L
.79125 .17463 L
.79623 .17738 L
.80594 .1829 L
.80843 .18434 L
.81566 .18862 L
.82456 .19406 L
.82537 .19456 L
.83508 .2007 L
.83981 .20377 L
.84479 .20705 L
.85431 .21348 L
.85451 .21361 L
.86422 .22038 L
.86816 .22319 L
.87393 .22736 L
.88145 .23291 L
.88364 .23455 L
.89336 .24195 L
.89422 .24262 L
.90307 .24955 L
.90655 .25233 L
.91278 .25737 L
.91847 .26204 L
.92249 .26539 L
.93003 .27176 L
.93221 .27362 L
.94124 .28147 L
.94192 .28206 L
.95163 .29071 L
.95215 .29118 L
.96134 .29957 L
.96277 .30089 L
.97106 .30864 L
Mistroke
.97313 .31061 L
.98077 .31792 L
Mfstroke
.85 g
.01923 .49692 m
.02076 .49514 L
.02894 .48572 L
.0292 .48543 L
.03778 .47572 L
.03866 .47473 L
.04651 .46601 L
.04837 .46395 L
.05539 .45629 L
.05808 .45339 L
.06444 .44658 L
.06779 .44303 L
.07366 .43687 L
.07751 .43287 L
.08307 .42716 L
.08722 .42293 L
.09267 .41744 L
.09693 .4132 L
.10248 .40773 L
.10664 .40367 L
.11251 .39802 L
.11636 .39436 L
.12278 .38831 L
.12607 .38525 L
.13331 .37859 L
.13578 .37635 L
.14412 .36888 L
.14549 .36766 L
.15521 .35918 L
.15522 .35917 L
.16492 .35091 L
.16665 .34946 L
.17463 .34285 L
.17844 .33974 L
.18434 .33499 L
.19062 .33003 L
.19406 .32735 L
.20323 .32032 L
.20377 .31991 L
.21348 .31269 L
.21633 .31061 L
.22319 .30567 L
.22997 .30089 L
.23291 .29886 L
.24262 .29226 L
.24423 .29118 L
.25233 .28587 L
.25921 .28147 L
.26204 .27969 L
.27176 .27371 L
.27501 .27176 L
.28147 .26795 L
.29118 .26239 L
.2918 .26204 L
.30089 .25704 L
.30979 .25233 L
.31061 .25191 L
.32032 .24698 L
.32927 .24262 L
.33003 .24226 L
.33974 .23775 L
.34946 .23344 L
.3507 .23291 L
.35917 .22935 L
.36888 .22547 L
.37482 .22319 L
.37859 .22179 L
.38831 .21832 L
.39802 .21507 L
.40298 .21348 L
.40773 .21202 L
.41744 .20918 L
.42716 .20655 L
.43687 .20412 L
.43837 .20377 L
.44658 .20191 L
.45629 .19991 L
.46601 .19811 L
.47572 .19652 L
.48543 .19515 L
.49443 .19406 L
.49514 .19398 L
.50486 .19302 L
.51457 .19227 L
.52428 .19172 L
.53399 .19139 L
.54371 .19127 L
.55342 .19135 L
.56313 .19164 L
.57284 .19215 L
.58256 .19286 L
.59227 .19378 L
.59485 .19406 L
.60198 .19491 L
.61169 .19625 L
.62141 .19779 L
.63112 .19955 L
.64083 .20151 L
.65054 .20369 L
.65089 .20377 L
.66026 .20607 L
.66997 .20866 L
.67968 .21146 L
.68628 .21348 L
.68939 .21447 L
.69911 .21769 L
.70882 .22111 L
.71444 .22319 L
.71853 .22475 L
.72824 .2286 L
.73796 .23265 L
.73856 .23291 L
.74767 .23691 L
.75738 .24138 L
.75999 .24262 L
.76709 .24606 L
.77681 .25095 L
.77947 .25233 L
.78652 .25605 L
.79623 .26136 L
.79746 .26204 L
.80594 .26687 L
.81425 .27176 L
.81566 .2726 L
.82537 .27853 L
.83005 .28147 L
.83508 .28467 L
.84479 .29103 L
.84503 .29118 L
.85451 .29759 L
.85929 .30089 L
.86422 .30436 L
.87293 .31061 L
.87393 .31133 L
.88364 .31852 L
.88603 .32032 L
.89336 .32592 L
.89864 .33003 L
.90307 .33352 L
.91082 .33974 L
.91278 .34134 L
.92249 .34936 L
.92261 .34946 L
.93221 .35759 L
.93404 .35917 L
.94192 .36603 L
.94515 .36888 L
.95163 .37468 L
.95595 .37859 L
.96134 .38354 L
.96648 .38831 L
.97106 .39261 L
.97675 .39802 L
.98077 .40188 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .49692 m
.02076 .49514 L
.02894 .48572 L
.0292 .48543 L
.03778 .47572 L
.03866 .47473 L
.04651 .46601 L
.04837 .46395 L
.05539 .45629 L
.05808 .45339 L
.06444 .44658 L
.06779 .44303 L
.07366 .43687 L
.07751 .43287 L
.08307 .42716 L
.08722 .42293 L
.09267 .41744 L
.09693 .4132 L
.10248 .40773 L
.10664 .40367 L
.11251 .39802 L
.11636 .39436 L
.12278 .38831 L
.12607 .38525 L
.13331 .37859 L
.13578 .37635 L
.14412 .36888 L
.14549 .36766 L
.15521 .35918 L
.15522 .35917 L
.16492 .35091 L
.16665 .34946 L
.17463 .34285 L
.17844 .33974 L
.18434 .33499 L
.19062 .33003 L
.19406 .32735 L
.20323 .32032 L
.20377 .31991 L
.21348 .31269 L
.21633 .31061 L
.22319 .30567 L
.22997 .30089 L
.23291 .29886 L
.24262 .29226 L
.24423 .29118 L
.25233 .28587 L
.25921 .28147 L
.26204 .27969 L
.27176 .27371 L
Mistroke
.27501 .27176 L
.28147 .26795 L
.29118 .26239 L
.2918 .26204 L
.30089 .25704 L
.30979 .25233 L
.31061 .25191 L
.32032 .24698 L
.32927 .24262 L
.33003 .24226 L
.33974 .23775 L
.34946 .23344 L
.3507 .23291 L
.35917 .22935 L
.36888 .22547 L
.37482 .22319 L
.37859 .22179 L
.38831 .21832 L
.39802 .21507 L
.40298 .21348 L
.40773 .21202 L
.41744 .20918 L
.42716 .20655 L
.43687 .20412 L
.43837 .20377 L
.44658 .20191 L
.45629 .19991 L
.46601 .19811 L
.47572 .19652 L
.48543 .19515 L
.49443 .19406 L
.49514 .19398 L
.50486 .19302 L
.51457 .19227 L
.52428 .19172 L
.53399 .19139 L
.54371 .19127 L
.55342 .19135 L
.56313 .19164 L
.57284 .19215 L
.58256 .19286 L
.59227 .19378 L
.59485 .19406 L
.60198 .19491 L
.61169 .19625 L
.62141 .19779 L
.63112 .19955 L
.64083 .20151 L
.65054 .20369 L
.65089 .20377 L
Mistroke
.66026 .20607 L
.66997 .20866 L
.67968 .21146 L
.68628 .21348 L
.68939 .21447 L
.69911 .21769 L
.70882 .22111 L
.71444 .22319 L
.71853 .22475 L
.72824 .2286 L
.73796 .23265 L
.73856 .23291 L
.74767 .23691 L
.75738 .24138 L
.75999 .24262 L
.76709 .24606 L
.77681 .25095 L
.77947 .25233 L
.78652 .25605 L
.79623 .26136 L
.79746 .26204 L
.80594 .26687 L
.81425 .27176 L
.81566 .2726 L
.82537 .27853 L
.83005 .28147 L
.83508 .28467 L
.84479 .29103 L
.84503 .29118 L
.85451 .29759 L
.85929 .30089 L
.86422 .30436 L
.87293 .31061 L
.87393 .31133 L
.88364 .31852 L
.88603 .32032 L
.89336 .32592 L
.89864 .33003 L
.90307 .33352 L
.91082 .33974 L
.91278 .34134 L
.92249 .34936 L
.92261 .34946 L
.93221 .35759 L
.93404 .35917 L
.94192 .36603 L
.94515 .36888 L
.95163 .37468 L
.95595 .37859 L
.96134 .38354 L
Mistroke
.96648 .38831 L
.97106 .39261 L
.97675 .39802 L
.98077 .40188 L
Mfstroke
.925 g
.01923 .59881 m
.02488 .59227 L
.02894 .5876 L
.03338 .58256 L
.03866 .5766 L
.04202 .57284 L
.04837 .56582 L
.05081 .56313 L
.05808 .55523 L
.05977 .55342 L
.06779 .54486 L
.06889 .54371 L
.07751 .5347 L
.07819 .53399 L
.08722 .52475 L
.08768 .52428 L
.09693 .515 L
.09737 .51457 L
.10664 .50547 L
.10727 .50486 L
.11636 .49614 L
.11741 .49514 L
.12607 .48703 L
.12779 .48543 L
.13578 .47812 L
.13844 .47572 L
.14549 .46942 L
.14937 .46601 L
.15521 .46093 L
.16061 .45629 L
.16492 .45265 L
.17219 .44658 L
.17463 .44457 L
.18415 .43687 L
.18434 .43671 L
.19406 .42906 L
.19651 .42716 L
.20377 .42161 L
.20933 .41744 L
.21348 .41438 L
.22266 .40773 L
.22319 .40735 L
.23291 .40053 L
.23656 .39802 L
.24262 .39392 L
.25113 .38831 L
.25233 .38752 L
.26204 .38133 L
.26645 .37859 L
.27176 .37535 L
.28147 .36958 L
.28266 .36888 L
.29118 .36401 L
.29995 .35917 L
.30089 .35866 L
.31061 .35351 L
.31856 .34946 L
.32032 .34858 L
.33003 .34385 L
.33883 .33974 L
.33974 .33933 L
.34946 .33502 L
.35917 .33092 L
.36134 .33003 L
.36888 .32703 L
.37859 .32334 L
.38702 .32032 L
.38831 .31987 L
.39802 .31661 L
.40773 .31355 L
.41744 .3107 L
.41779 .31061 L
.42716 .30807 L
.43687 .30564 L
.44658 .30342 L
.45629 .30141 L
.45895 .30089 L
.46601 .29961 L
.47572 .29801 L
.48543 .29663 L
.49514 .29546 L
.50486 .29449 L
.51457 .29373 L
.52428 .29319 L
.53399 .29285 L
.54371 .29272 L
.55342 .2928 L
.56313 .29309 L
.57284 .29358 L
.58256 .29429 L
.59227 .29521 L
.60198 .29633 L
.61169 .29766 L
.62141 .29921 L
.63078 .30089 L
.63112 .30096 L
.64083 .30292 L
.65054 .30509 L
.66026 .30747 L
.66997 .31006 L
.67194 .31061 L
.67968 .31285 L
.68939 .31586 L
.69911 .31907 L
.70271 .32032 L
.70882 .3225 L
.71853 .32613 L
.72824 .32997 L
.72839 .33003 L
.73796 .33402 L
.74767 .33828 L
.7509 .33974 L
.75738 .34275 L
.76709 .34743 L
.77118 .34946 L
.77681 .35231 L
.78652 .35741 L
.78978 .35917 L
.79623 .36272 L
.80594 .36823 L
.80707 .36888 L
.81566 .37395 L
.82329 .37859 L
.82537 .37988 L
.83508 .38602 L
.83861 .38831 L
.84479 .39237 L
.85317 .39802 L
.85451 .39893 L
.86422 .4057 L
.86708 .40773 L
.87393 .41268 L
.8804 .41744 L
.88364 .41986 L
.89322 .42716 L
.89336 .42726 L
.90307 .43486 L
.90559 .43687 L
.91278 .44268 L
.91754 .44658 L
.92249 .4507 L
.92912 .45629 L
.93221 .45893 L
.94037 .46601 L
.94192 .46737 L
.9513 .47572 L
.95163 .47602 L
.96134 .48488 L
.96195 .48543 L
.97106 .49394 L
.97233 .49514 L
.98077 .50322 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .59881 m
.02488 .59227 L
.02894 .5876 L
.03338 .58256 L
.03866 .5766 L
.04202 .57284 L
.04837 .56582 L
.05081 .56313 L
.05808 .55523 L
.05977 .55342 L
.06779 .54486 L
.06889 .54371 L
.07751 .5347 L
.07819 .53399 L
.08722 .52475 L
.08768 .52428 L
.09693 .515 L
.09737 .51457 L
.10664 .50547 L
.10727 .50486 L
.11636 .49614 L
.11741 .49514 L
.12607 .48703 L
.12779 .48543 L
.13578 .47812 L
.13844 .47572 L
.14549 .46942 L
.14937 .46601 L
.15521 .46093 L
.16061 .45629 L
.16492 .45265 L
.17219 .44658 L
.17463 .44457 L
.18415 .43687 L
.18434 .43671 L
.19406 .42906 L
.19651 .42716 L
.20377 .42161 L
.20933 .41744 L
.21348 .41438 L
.22266 .40773 L
.22319 .40735 L
.23291 .40053 L
.23656 .39802 L
.24262 .39392 L
.25113 .38831 L
.25233 .38752 L
.26204 .38133 L
.26645 .37859 L
.27176 .37535 L
Mistroke
.28147 .36958 L
.28266 .36888 L
.29118 .36401 L
.29995 .35917 L
.30089 .35866 L
.31061 .35351 L
.31856 .34946 L
.32032 .34858 L
.33003 .34385 L
.33883 .33974 L
.33974 .33933 L
.34946 .33502 L
.35917 .33092 L
.36134 .33003 L
.36888 .32703 L
.37859 .32334 L
.38702 .32032 L
.38831 .31987 L
.39802 .31661 L
.40773 .31355 L
.41744 .3107 L
.41779 .31061 L
.42716 .30807 L
.43687 .30564 L
.44658 .30342 L
.45629 .30141 L
.45895 .30089 L
.46601 .29961 L
.47572 .29801 L
.48543 .29663 L
.49514 .29546 L
.50486 .29449 L
.51457 .29373 L
.52428 .29319 L
.53399 .29285 L
.54371 .29272 L
.55342 .2928 L
.56313 .29309 L
.57284 .29358 L
.58256 .29429 L
.59227 .29521 L
.60198 .29633 L
.61169 .29766 L
.62141 .29921 L
.63078 .30089 L
.63112 .30096 L
.64083 .30292 L
.65054 .30509 L
.66026 .30747 L
.66997 .31006 L
Mistroke
.67194 .31061 L
.67968 .31285 L
.68939 .31586 L
.69911 .31907 L
.70271 .32032 L
.70882 .3225 L
.71853 .32613 L
.72824 .32997 L
.72839 .33003 L
.73796 .33402 L
.74767 .33828 L
.7509 .33974 L
.75738 .34275 L
.76709 .34743 L
.77118 .34946 L
.77681 .35231 L
.78652 .35741 L
.78978 .35917 L
.79623 .36272 L
.80594 .36823 L
.80707 .36888 L
.81566 .37395 L
.82329 .37859 L
.82537 .37988 L
.83508 .38602 L
.83861 .38831 L
.84479 .39237 L
.85317 .39802 L
.85451 .39893 L
.86422 .4057 L
.86708 .40773 L
.87393 .41268 L
.8804 .41744 L
.88364 .41986 L
.89322 .42716 L
.89336 .42726 L
.90307 .43486 L
.90559 .43687 L
.91278 .44268 L
.91754 .44658 L
.92249 .4507 L
.92912 .45629 L
.93221 .45893 L
.94037 .46601 L
.94192 .46737 L
.9513 .47572 L
.95163 .47602 L
.96134 .48488 L
.96195 .48543 L
.97106 .49394 L
Mistroke
.97233 .49514 L
.98077 .50322 L
Mfstroke
1 g
.01923 .73865 m
.01982 .73796 L
.02822 .72824 L
.02894 .72741 L
.03675 .71853 L
.03866 .71638 L
.04543 .70882 L
.04837 .70556 L
.05426 .69911 L
.05808 .69495 L
.06325 .68939 L
.06779 .68455 L
.07241 .67968 L
.07751 .67436 L
.08176 .66997 L
.08722 .66438 L
.09129 .66026 L
.09693 .65461 L
.10103 .65054 L
.10664 .64505 L
.11099 .64083 L
.11636 .63569 L
.12119 .63112 L
.12607 .62655 L
.13163 .62141 L
.13578 .61762 L
.14235 .61169 L
.14549 .60889 L
.15335 .60198 L
.15521 .60037 L
.16468 .59227 L
.16492 .59207 L
.17463 .58397 L
.17635 .58256 L
.18434 .57608 L
.18841 .57284 L
.19406 .5684 L
.20088 .56313 L
.20377 .56093 L
.21348 .55367 L
.21383 .55342 L
.22319 .54662 L
.2273 .54371 L
.23291 .53978 L
.24136 .53399 L
.24262 .53315 L
.25233 .52673 L
.25611 .52428 L
.26204 .52051 L
.27166 .51457 L
.27176 .51451 L
.28147 .50871 L
.28814 .50486 L
.29118 .50313 L
.30089 .49775 L
.30575 .49514 L
.31061 .49259 L
.32032 .48763 L
.32476 .48543 L
.33003 .48288 L
.33974 .47834 L
.34557 .47572 L
.34946 .47401 L
.35917 .46989 L
.36882 .46601 L
.36888 .46598 L
.37859 .46228 L
.38831 .45879 L
.39563 .45629 L
.39802 .45551 L
.40773 .45243 L
.41744 .44957 L
.42716 .44691 L
.42843 .44658 L
.43687 .44447 L
.44658 .44223 L
.45629 .4402 L
.46601 .43839 L
.47514 .43687 L
.47572 .43678 L
.48543 .43538 L
.49514 .43419 L
.50486 .43321 L
.51457 .43244 L
.52428 .43188 L
.53399 .43152 L
.54371 .43138 L
.55342 .43145 L
.56313 .43172 L
.57284 .43221 L
.58256 .4329 L
.59227 .43381 L
.60198 .43492 L
.61169 .43624 L
.61584 .43687 L
.62141 .43777 L
.63112 .43951 L
.64083 .44146 L
.65054 .44362 L
.66026 .44599 L
.66255 .44658 L
.66997 .44857 L
.67968 .45136 L
.68939 .45435 L
.69535 .45629 L
.69911 .45756 L
.70882 .46098 L
.71853 .4646 L
.72216 .46601 L
.72824 .46843 L
.73796 .47248 L
.7454 .47572 L
.74767 .47673 L
.75738 .48119 L
.76622 .48543 L
.76709 .48586 L
.77681 .49074 L
.78523 .49514 L
.78652 .49583 L
.79623 .50113 L
.80284 .50486 L
.80594 .50664 L
.81566 .51236 L
.81932 .51457 L
.82537 .51828 L
.83486 .52428 L
.83508 .52442 L
.84479 .53077 L
.84961 .53399 L
.85451 .53732 L
.86368 .54371 L
.86422 .54409 L
.87393 .55106 L
.87715 .55342 L
.88364 .55824 L
.8901 .56313 L
.89336 .56563 L
.90258 .57284 L
.90307 .57324 L
.91278 .58105 L
.91463 .58256 L
.92249 .58907 L
.9263 .59227 L
.93221 .5973 L
.93763 .60198 L
.94192 .60573 L
.94864 .61169 L
.95163 .61438 L
.95935 .62141 L
.96134 .62324 L
.9698 .63112 L
.97106 .63231 L
.97999 .64083 L
.98077 .64158 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .73865 m
.01982 .73796 L
.02822 .72824 L
.02894 .72741 L
.03675 .71853 L
.03866 .71638 L
.04543 .70882 L
.04837 .70556 L
.05426 .69911 L
.05808 .69495 L
.06325 .68939 L
.06779 .68455 L
.07241 .67968 L
.07751 .67436 L
.08176 .66997 L
.08722 .66438 L
.09129 .66026 L
.09693 .65461 L
.10103 .65054 L
.10664 .64505 L
.11099 .64083 L
.11636 .63569 L
.12119 .63112 L
.12607 .62655 L
.13163 .62141 L
.13578 .61762 L
.14235 .61169 L
.14549 .60889 L
.15335 .60198 L
.15521 .60037 L
.16468 .59227 L
.16492 .59207 L
.17463 .58397 L
.17635 .58256 L
.18434 .57608 L
.18841 .57284 L
.19406 .5684 L
.20088 .56313 L
.20377 .56093 L
.21348 .55367 L
.21383 .55342 L
.22319 .54662 L
.2273 .54371 L
.23291 .53978 L
.24136 .53399 L
.24262 .53315 L
.25233 .52673 L
.25611 .52428 L
.26204 .52051 L
.27166 .51457 L
Mistroke
.27176 .51451 L
.28147 .50871 L
.28814 .50486 L
.29118 .50313 L
.30089 .49775 L
.30575 .49514 L
.31061 .49259 L
.32032 .48763 L
.32476 .48543 L
.33003 .48288 L
.33974 .47834 L
.34557 .47572 L
.34946 .47401 L
.35917 .46989 L
.36882 .46601 L
.36888 .46598 L
.37859 .46228 L
.38831 .45879 L
.39563 .45629 L
.39802 .45551 L
.40773 .45243 L
.41744 .44957 L
.42716 .44691 L
.42843 .44658 L
.43687 .44447 L
.44658 .44223 L
.45629 .4402 L
.46601 .43839 L
.47514 .43687 L
.47572 .43678 L
.48543 .43538 L
.49514 .43419 L
.50486 .43321 L
.51457 .43244 L
.52428 .43188 L
.53399 .43152 L
.54371 .43138 L
.55342 .43145 L
.56313 .43172 L
.57284 .43221 L
.58256 .4329 L
.59227 .43381 L
.60198 .43492 L
.61169 .43624 L
.61584 .43687 L
.62141 .43777 L
.63112 .43951 L
.64083 .44146 L
.65054 .44362 L
.66026 .44599 L
Mistroke
.66255 .44658 L
.66997 .44857 L
.67968 .45136 L
.68939 .45435 L
.69535 .45629 L
.69911 .45756 L
.70882 .46098 L
.71853 .4646 L
.72216 .46601 L
.72824 .46843 L
.73796 .47248 L
.7454 .47572 L
.74767 .47673 L
.75738 .48119 L
.76622 .48543 L
.76709 .48586 L
.77681 .49074 L
.78523 .49514 L
.78652 .49583 L
.79623 .50113 L
.80284 .50486 L
.80594 .50664 L
.81566 .51236 L
.81932 .51457 L
.82537 .51828 L
.83486 .52428 L
.83508 .52442 L
.84479 .53077 L
.84961 .53399 L
.85451 .53732 L
.86368 .54371 L
.86422 .54409 L
.87393 .55106 L
.87715 .55342 L
.88364 .55824 L
.8901 .56313 L
.89336 .56563 L
.90258 .57284 L
.90307 .57324 L
.91278 .58105 L
.91463 .58256 L
.92249 .58907 L
.9263 .59227 L
.93221 .5973 L
.93763 .60198 L
.94192 .60573 L
.94864 .61169 L
.95163 .61438 L
.95935 .62141 L
.96134 .62324 L
Mistroke
.9698 .63112 L
.97106 .63231 L
.97999 .64083 L
.98077 .64158 L
Mfstroke
.55 g
.01923 .27308 m
.02037 .27176 L
.02881 .26204 L
.02894 .2619 L
.0374 .25233 L
.03866 .25092 L
.04613 .24262 L
.04837 .24016 L
.05502 .23291 L
.05808 .2296 L
.06407 .22319 L
.06779 .21925 L
.0733 .21348 L
.07751 .20912 L
.08271 .20377 L
.08722 .19919 L
.09232 .19406 L
.09693 .18946 L
.10213 .18434 L
.10664 .17995 L
.11217 .17463 L
.11636 .17065 L
.12245 .16492 L
.12607 .16155 L
.13298 .15521 L
.13578 .15267 L
.14379 .14549 L
.14549 .14399 L
.1549 .13578 L
.15521 .13552 L
.16492 .12726 L
.16634 .12607 L
.17463 .11921 L
.17814 .11636 L
.18434 .11137 L
.19032 .10664 L
.19406 .10373 L
.20295 .09693 L
.20377 .09631 L
.21348 .08909 L
.21605 .08722 L
.22319 .08209 L
.2297 .07751 L
.23291 .07529 L
.24262 .0687 L
.24398 .06779 L
.25233 .06232 L
.25896 .05808 L
.26204 .05615 L
.27176 .05018 L
.27478 .04837 L
.28147 .04443 L
.29118 .03888 L
.29158 .03866 L
.30089 .03354 L
.30959 .02894 L
.31061 .02842 L
.32032 .0235 L
.32909 .01923 L
.01923 .01923 L
F
0 g
.01923 .27308 m
.02037 .27176 L
.02881 .26204 L
.02894 .2619 L
.0374 .25233 L
.03866 .25092 L
.04613 .24262 L
.04837 .24016 L
.05502 .23291 L
.05808 .2296 L
.06407 .22319 L
.06779 .21925 L
.0733 .21348 L
.07751 .20912 L
.08271 .20377 L
.08722 .19919 L
.09232 .19406 L
.09693 .18946 L
.10213 .18434 L
.10664 .17995 L
.11217 .17463 L
.11636 .17065 L
.12245 .16492 L
.12607 .16155 L
.13298 .15521 L
.13578 .15267 L
.14379 .14549 L
.14549 .14399 L
.1549 .13578 L
.15521 .13552 L
.16492 .12726 L
.16634 .12607 L
.17463 .11921 L
.17814 .11636 L
.18434 .11137 L
.19032 .10664 L
.19406 .10373 L
.20295 .09693 L
.20377 .09631 L
.21348 .08909 L
.21605 .08722 L
.22319 .08209 L
.2297 .07751 L
.23291 .07529 L
.24262 .0687 L
.24398 .06779 L
.25233 .06232 L
.25896 .05808 L
.26204 .05615 L
.27176 .05018 L
Mistroke
.27478 .04837 L
.28147 .04443 L
.29118 .03888 L
.29158 .03866 L
.30089 .03354 L
.30959 .02894 L
.31061 .02842 L
.32032 .0235 L
.32909 .01923 L
Mfstroke
.475 g
.01923 .2126 m
.02689 .20377 L
.02894 .20142 L
.03544 .19406 L
.03866 .19045 L
.04414 .18434 L
.04837 .17969 L
.053 .17463 L
.05808 .16913 L
.06201 .16492 L
.06779 .15879 L
.0712 .15521 L
.07751 .14865 L
.08057 .14549 L
.08722 .13872 L
.09014 .13578 L
.09693 .129 L
.09991 .12607 L
.10664 .11949 L
.1099 .11636 L
.11636 .11019 L
.12012 .10664 L
.12607 .1011 L
.1306 .09693 L
.13578 .09222 L
.14135 .08722 L
.14549 .08354 L
.15239 .07751 L
.15521 .07507 L
.16376 .06779 L
.16492 .06682 L
.17463 .05877 L
.17547 .05808 L
.18434 .05093 L
.18757 .04837 L
.19406 .04329 L
.20009 .03866 L
.20377 .03587 L
.21309 .02894 L
.21348 .02866 L
.22319 .02165 L
.22662 .01923 L
.01923 .01923 L
F
0 g
.01923 .2126 m
.02689 .20377 L
.02894 .20142 L
.03544 .19406 L
.03866 .19045 L
.04414 .18434 L
.04837 .17969 L
.053 .17463 L
.05808 .16913 L
.06201 .16492 L
.06779 .15879 L
.0712 .15521 L
.07751 .14865 L
.08057 .14549 L
.08722 .13872 L
.09014 .13578 L
.09693 .129 L
.09991 .12607 L
.10664 .11949 L
.1099 .11636 L
.11636 .11019 L
.12012 .10664 L
.12607 .1011 L
.1306 .09693 L
.13578 .09222 L
.14135 .08722 L
.14549 .08354 L
.15239 .07751 L
.15521 .07507 L
.16376 .06779 L
.16492 .06682 L
.17463 .05877 L
.17547 .05808 L
.18434 .05093 L
.18757 .04837 L
.19406 .04329 L
.20009 .03866 L
.20377 .03587 L
.21309 .02894 L
.21348 .02866 L
.22319 .02165 L
.22662 .01923 L
s
.4 g
.01923 .15648 m
.02033 .15521 L
.02878 .14549 L
.02894 .1453 L
.03736 .13578 L
.03866 .13433 L
.0461 .12607 L
.04837 .12357 L
.05499 .11636 L
.05808 .11302 L
.06405 .10664 L
.06779 .10268 L
.07328 .09693 L
.07751 .09254 L
.08269 .08722 L
.08722 .08262 L
.0923 .07751 L
.09693 .0729 L
.10212 .06779 L
.10664 .06339 L
.11216 .05808 L
.11636 .05409 L
.12244 .04837 L
.12607 .045 L
.13298 .03866 L
.13578 .03612 L
.1438 .02894 L
.14549 .02744 L
.15491 .01923 L
.01923 .01923 L
F
0 g
.01923 .15648 m
.02033 .15521 L
.02878 .14549 L
.02894 .1453 L
.03736 .13578 L
.03866 .13433 L
.0461 .12607 L
.04837 .12357 L
.05499 .11636 L
.05808 .11302 L
.06405 .10664 L
.06779 .10268 L
.07328 .09693 L
.07751 .09254 L
.08269 .08722 L
.08722 .08262 L
.0923 .07751 L
.09693 .0729 L
.10212 .06779 L
.10664 .06339 L
.11216 .05808 L
.11636 .05409 L
.12244 .04837 L
.12607 .045 L
.13298 .03866 L
.13578 .03612 L
.1438 .02894 L
.14549 .02744 L
.15491 .01923 L
s
.325 g
.01923 .1039 m
.02526 .09693 L
.02894 .09272 L
.03379 .08722 L
.03866 .08175 L
.04247 .07751 L
.04837 .07099 L
.05129 .06779 L
.05808 .06044 L
.06028 .05808 L
.06779 .0501 L
.06944 .04837 L
.07751 .03997 L
.07878 .03866 L
.08722 .03004 L
.08831 .02894 L
.09693 .02033 L
.09804 .01923 L
.01923 .01923 L
F
0 g
.01923 .1039 m
.02526 .09693 L
.02894 .09272 L
.03379 .08722 L
.03866 .08175 L
.04247 .07751 L
.04837 .07099 L
.05129 .06779 L
.05808 .06044 L
.06028 .05808 L
.06779 .0501 L
.06944 .04837 L
.07751 .03997 L
.07878 .03866 L
.08722 .03004 L
.08831 .02894 L
.09693 .02033 L
.09804 .01923 L
s
.25 g
.01923 .05425 m
.02432 .04837 L
.02894 .04308 L
.03284 .03866 L
.03866 .03211 L
.04149 .02894 L
.04837 .02135 L
.05031 .01923 L
.01923 .01923 L
F
0 g
.01923 .05425 m
.02432 .04837 L
.02894 .04308 L
.03284 .03866 L
.03866 .03211 L
.04149 .02894 L
.04837 .02135 L
.05031 .01923 L
s
.925 g
.71622 .98077 m
.70882 .97799 L
.69911 .97453 L
.68939 .97127 L
.68873 .97106 L
.67968 .96822 L
.66997 .96538 L
.66026 .96275 L
.65474 .96134 L
.65054 .96032 L
.64083 .9581 L
.63112 .95609 L
.62141 .95429 L
.61169 .95269 L
.6044 .95163 L
.60198 .95131 L
.59227 .95013 L
.58256 .94915 L
.57284 .94839 L
.56313 .94783 L
.55342 .94748 L
.54371 .94734 L
.53399 .94741 L
.52428 .94768 L
.51457 .94816 L
.50486 .94885 L
.49514 .94974 L
.48543 .95085 L
.47942 .95163 L
.47572 .95216 L
.46601 .95368 L
.45629 .9554 L
.44658 .95734 L
.43687 .95948 L
.42908 .96134 L
.42716 .96183 L
.41744 .96438 L
.40773 .96715 L
.39802 .97012 L
.39509 .97106 L
.38831 .9733 L
.37859 .97668 L
.36888 .98028 L
.3676 .98077 L
F
0 g
.71622 .98077 m
.70882 .97799 L
.69911 .97453 L
.68939 .97127 L
.68873 .97106 L
.67968 .96822 L
.66997 .96538 L
.66026 .96275 L
.65474 .96134 L
.65054 .96032 L
.64083 .9581 L
.63112 .95609 L
.62141 .95429 L
.61169 .95269 L
.6044 .95163 L
.60198 .95131 L
.59227 .95013 L
.58256 .94915 L
.57284 .94839 L
.56313 .94783 L
.55342 .94748 L
.54371 .94734 L
.53399 .94741 L
.52428 .94768 L
.51457 .94816 L
.50486 .94885 L
.49514 .94974 L
.48543 .95085 L
.47942 .95163 L
.47572 .95216 L
.46601 .95368 L
.45629 .9554 L
.44658 .95734 L
.43687 .95948 L
.42908 .96134 L
.42716 .96183 L
.41744 .96438 L
.40773 .96715 L
.39802 .97012 L
.39509 .97106 L
.38831 .9733 L
.37859 .97668 L
.36888 .98028 L
.3676 .98077 L
s
.55 g
.98077 .17872 m
.97652 .17463 L
.97106 .16944 L
.96624 .16492 L
.96134 .16037 L
.95571 .15521 L
.95163 .15151 L
.9449 .14549 L
.94192 .14286 L
.93379 .13578 L
.93221 .13442 L
.92249 .12619 L
.92235 .12607 L
.91278 .11817 L
.91055 .11636 L
.90307 .11035 L
.89837 .10664 L
.89336 .10275 L
.88574 .09693 L
.88364 .09535 L
.87393 .08816 L
.87264 .08722 L
.86422 .08118 L
.85899 .07751 L
.85451 .07441 L
.84479 .06785 L
.84471 .06779 L
.83508 .06149 L
.82973 .05808 L
.82537 .05535 L
.81566 .04941 L
.81391 .04837 L
.80594 .04369 L
.79711 .03866 L
.79623 .03817 L
.78652 .03286 L
.7791 .02894 L
.77681 .02776 L
.76709 .02286 L
.7596 .01923 L
.98077 .01923 L
F
0 g
.98077 .17872 m
.97652 .17463 L
.97106 .16944 L
.96624 .16492 L
.96134 .16037 L
.95571 .15521 L
.95163 .15151 L
.9449 .14549 L
.94192 .14286 L
.93379 .13578 L
.93221 .13442 L
.92249 .12619 L
.92235 .12607 L
.91278 .11817 L
.91055 .11636 L
.90307 .11035 L
.89837 .10664 L
.89336 .10275 L
.88574 .09693 L
.88364 .09535 L
.87393 .08816 L
.87264 .08722 L
.86422 .08118 L
.85899 .07751 L
.85451 .07441 L
.84479 .06785 L
.84471 .06779 L
.83508 .06149 L
.82973 .05808 L
.82537 .05535 L
.81566 .04941 L
.81391 .04837 L
.80594 .04369 L
.79711 .03866 L
.79623 .03817 L
.78652 .03286 L
.7791 .02894 L
.77681 .02776 L
.76709 .02286 L
.7596 .01923 L
s
.475 g
.98077 .11835 m
.9787 .11636 L
.97106 .10908 L
.96847 .10664 L
.96134 .10001 L
.95799 .09693 L
.95163 .09115 L
.94724 .08722 L
.94192 .0825 L
.9362 .07751 L
.93221 .07406 L
.92484 .06779 L
.92249 .06583 L
.91312 .05808 L
.91278 .0578 L
.90307 .04999 L
.90102 .04837 L
.89336 .04238 L
.8885 .03866 L
.88364 .03498 L
.8755 .02894 L
.87393 .0278 L
.86422 .02082 L
.86197 .01923 L
.98077 .01923 L
F
0 g
.98077 .11835 m
.9787 .11636 L
.97106 .10908 L
.96847 .10664 L
.96134 .10001 L
.95799 .09693 L
.95163 .09115 L
.94724 .08722 L
.94192 .0825 L
.9362 .07751 L
.93221 .07406 L
.92484 .06779 L
.92249 .06583 L
.91312 .05808 L
.91278 .0578 L
.90307 .04999 L
.90102 .04837 L
.89336 .04238 L
.8885 .03866 L
.88364 .03498 L
.8755 .02894 L
.87393 .0278 L
.86422 .02082 L
.86197 .01923 L
s
.4 g
.98077 .06233 m
.97635 .05808 L
.97106 .05305 L
.96607 .04837 L
.96134 .04398 L
.95553 .03866 L
.95163 .03512 L
.94472 .02894 L
.94192 .02647 L
.9336 .01923 L
.98077 .01923 L
F
0 g
.98077 .06233 m
.97635 .05808 L
.97106 .05305 L
.96607 .04837 L
.96134 .04398 L
.95553 .03866 L
.95163 .03512 L
.94472 .02894 L
.94192 .02647 L
.9336 .01923 L
s
0 0 0 r
.055 w
.98077 .90042 Mdot
0 1 1 r
.045 w
.01923 .90042 Mdot
.03003 .98077 Mdot
.07211 .93302 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
1 0 0 r
.0325 w
.01923 .90042 Mdot
.03003 .98077 Mdot
.87724 .01923 Mdot
.17336 .81811 Mdot
.07211 .93302 Mdot
.37811 .6162 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.50814 .64425 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.65504 .67874 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.90361 .81949 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
0 1 0 r
.02 w
.01923 .90042 Mdot
.03003 .98077 Mdot
.87724 .01923 Mdot
.17336 .81811 Mdot
.07211 .93302 Mdot
.37811 .6162 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.50814 .64425 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.65504 .67874 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.90361 .81949 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
0 0 1 r
.5 Mabswid
.01923 .90042 m
.01923 .90042 L
.03003 .98077 L
.07211 .93302 L
.13859 .86419 L
.25607 .76553 L
.30297 .75096 L
.36146 .72054 L
.4609 .68601 L
.50669 .68856 L
.56182 .68491 L
.63714 .69274 L
.68666 .70923 L
.76911 .73799 L
.79519 .75849 L
.83361 .7801 L
.88258 .81359 L
.91054 .83718 L
.94916 .86935 L
.9615 .88205 L
.97812 .89757 L
.98017 .89984 L
.98077 .90042 L
.98077 .90042 L
s
.015 w
.01923 .90042 Mdot
.01923 .90042 Mdot
.03003 .98077 Mdot
.07211 .93302 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{288, 288},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00@`3oool7000004X0oooo1000
00060?ooo`8000001P3oool4000004P0oooo1000001<0?ooo`@000001P3oool2000000H0oooo1000
001;0?ooo`L000001P3oool004H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool004H0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool01`3oool004H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool003X0oooo1P0000060?ooo`030000
003oool0oooo0440oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`070?ooo`00AP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool4000004L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool4000004h0oooo00<000000?ooo`3oool01`3oool004H0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3oool0
04@0oooo0`00001<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C@3oool30000
00T0oooo00160?ooo`030000003oool0oooo04/0oooo1000000>0?ooo`D00000A`3oool4000004`0
oooo1000000>0?ooo`D00000C@3oool00`000000oooo0?ooo`070?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`005`3ooooo000009T000000@3oool001L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1P3oool50?l000@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo02T0oooo1`3o000V0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`3o0?oooel0oooo2@3o000]0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0o`3ooomN0?ooo`D0o`000P00o`040?l002`0oooo0@0000010?ooo`005`3oool200000?l0
ooooG`3oool30?l000H00?l00P3o000[0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0
o`3ooomM0?ooo`@0o`001P00o`030?l002/0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?oo
o`0W0?ooo`<0o`002000o`020?l00100oooo00<000000?ooo`3oool0603oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo300o?cl00`000000De=C05=CD`0A05=CD`030000001VIVH0
IVIV01@0IVIV00<0000007UiN@1iNGT06P1iNGT00`000000S8b<08b<S00V08b<S0800000/02OWil2
000002L0S8b<0`3o0008003o0080o`004@1iNGT00`000000IVIV06IVIP0?06IVIPP0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`/0?clo00<0000005=CD`1CDe<04@1CDe<00`00
0000IVIV06IVIP0D06IVIP030000001iNGT0NGUi01X0NGUi00<0000008b<S02<S8`09@2<S8`20000
0;@0WinO00<0000008b<S02<S8`09@2<S8`30?l000H00?l00P3o000C07UiN@8000003`1VIVH80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool;03lo?`030000001CDe<0De=C0100
De=C00<0000006IVIP1VIVH0501VIVH00`000000NGUi07UiN@0I07UiN@8000009P2<S8`200000;L0
WinO0P00000U08b<S0<0o`001P00o`020?l001D0NGUi00<0000006IVIP1VIVH0301VIVH80?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0103oool:03lo?`030000001CDe<0De=C0100De=C
00<0000006IVIP1VIVH04`1VIVH2000001X0NGUi0P00000V08b<S0800000^`2OWil3000002<0S8b<
103o0002003o00<0o`005`1iNGT00`000000IVIV06IVIP0;06IVIPP0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo`T0?clo00<0000005=CD`1CDe<0401CDe<00`000000IVIV06IV
IP0C06IVIP030000001iNGT0NGUi01T0NGUi00<0000008b<S02<S8`0902<S8`200000<00WinO0P00
000R08b<S0L0o`006@1iNGT00`000000IVIV06IVIP0:06IVIPP0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`P0?clo00<0000005=CD`1CDe<0401CDe<00`000000IVIV06IVIP0C
06IVIP030000001iNGT0NGUi01T0NGUi00<0000008b<S02<S8`08`2<S8`2000005P0WinO4`00001I
09nOW`030000002<S8`0S8b<0200S8b<1@3o000K07UiN@030000001VIVH0IVIV00T0IVIV203oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo1`0o?cl00`000000De=C05=CD`0@05=C
D`030000001VIVH0IVIV01<0IVIV00<0000007UiN@1iNGT06@1iNGT00`000000S8b<08b<S00R08b<
S0800000CP2OWil<000001<0/k>c3000001>09nOW`8000009@2<S8`00`000000NGUi07UiN@0I07Ui
N@030000001VIVH0IVIV00P0IVIV203oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo1P0o?cl00`000000De=C05=CD`0@05=CD`030000001VIVH0IVIV01<0IVIV00<0000007UiN@1i
NGT0601iNGT2000002<0S8b<0P00001909nOW`L00000:`2c/k<8000004P0WinO0`00000S08b<S080
00006P1iNGT00`000000IVIV06IVIP0706IVIPP0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?ooo`D0?clo00<0000005=CD`1CDe<0401CDe<00`000000IVIV06IVIP0C06IVIP030000
001iNGT0NGUi01P0NGUi00<0000008b<S02<S8`08P2<S8`00`000000WinO09nOW`1509nOW`@00000
>P2c/k<4000004L0WinO0P00000S08b<S0030000001iNGT0NGUi01P0NGUi0P00000706IVIPP0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0?clo00<0000005=CD`1CDe<0401C
De<00`000000IVIV06IVIP0C06IVIP030000001iNGT0NGUi01P0NGUi00<0000008b<S02<S8`08@2<
S8`2000004@0WinO100000120;>c/`P00000@@2OWil00`000000S8b<08b<S00Q08b<S0030000001i
NGT0NGUi01T0NGUi00<0000006IVIP1VIVH0101VIVH80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool303lo?`030000001CDe<0De=C0100De=C00<0000006IVIP1VIVH04`1VIVH0
0`000000NGUi07UiN@0G07UiN@8000008`2<S8`00`000000WinO09nOW`0l09nOW`P00000CP2c/k<4
000003h0WinO0P00000R08b<S08000006@1iNGT00`000000IVIV06IVIP0406IVIPP0oooo0@000001
0?ooo`002`3oool4000000P0oooo00<000000?ooo`3oool0103oool303lo?`030000001CDe<0De=C
00l0De=C00<0000006IVIP1VIVH04`1VIVH00`000000NGUi07UiN@0G07UiN@030000002<S8`0S8b<
0240S8b<0P00000l09nOW`<00000FP2c/k<4000003`0WinO00<0000008b<S02<S8`08@2<S8`00`00
0000NGUi07UiN@0G07UiN@030000001VIVH0IVIV00<0IVIV203oool100000040oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`80
?clo00<0000005=CD`1CDe<03`1CDe<00`000000IVIV06IVIP0B06IVIP8000006@1iNGT00`000000
S8b<08b<S00P08b<S0800000?02OWil200000640/k>c0`00000j09nOW`030000002<S8`0S8b<0240
S8b<00<0000007UiN@1iNGT05`1iNGT2000000<0IVIV203oool100000040oooo000?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`0o?cl0000005=CD`0@05=CD`030000
001VIVH0IVIV0180IVIV00<0000007UiN@1iNGT0601iNGT00`000000S8b<08b<S00O08b<S0800000
>`2OWil3000006H0/k>c0P00000i09nOW`8000008P2<S8`00`000000NGUi07UiN@0H07UiN@030000
001VIVH0IVIV00P0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`050?ooo`<00000103o
ool00`000000De=C05=CD`0?05=CD`030000001VIVH0IVIV0180IVIV00<0000007UiN@1iNGT05`1i
NGT200000200S8b<0P00000i09nOW`@00000J`2c/k<3000003P0WinO0P00000Q08b<S08000006@1i
NGT00`000000IVIV0?ooo`050?ooo`<000000@3oool000030?ooo`000000000000@000001P3oool2
000000P0oooo00<000000?ooo`3oool0103ooolA05=CD`030000001VIVH0IVIV0180IVIV00<00000
07UiN@1iNGT05`1iNGT00`000000S8b<08b<S00O08b<S0030000002OWil0WinO03@0WinO1@00001b
0;>c/`D00000=@2OWil200000240S8b<00<0000007UiN@1iNGT05`1iNGT00`000000oooo0?ooo`06
0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
oa00De=C00<0000006IVIP1VIVH04P1VIVH00`000000NGUi07UiN@0G07UiN@030000002<S8`0S8b<
01h0S8b<0P00000e09nOW`800000O02c/k<3000003@0WinO00<0000008b<S02<S8`07`2<S8`00`00
0000NGUi07UiN@0F07UiN@030000003oool0oooo00H0oooo0@0000010?ooo`003`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo3`1CDe<00`000000IVIV06IVIP0B06IVIP03
0000001iNGT0NGUi01L0NGUi00<0000008b<S02<S8`07P2<S8`00`000000WinO09nOW`0c09nOW`80
0000P@2c/k<300000380WinO00<0000008b<S02<S8`07`2<S8`2000001L0NGUi00<000000?ooo`3o
ool01@3oool100000040oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`l0De=C00<0000006IVIP1VIVH04@1VIVH00`000000NGUi
07UiN@0G07UiN@030000002<S8`0S8b<01d0S8b<0P00000c09nOW`<00000QP2c/k<200000340WinO
0P00000Q08b<S0030000001iNGT0NGUi01@0NGUi203oool100000040oooo000;0?ooo`@00000203o
ool00`000000oooo0?ooo`040?ooo`h0De=C00<0000006IVIP1VIVH04@1VIVH00`000000NGUi07Ui
N@0F07UiN@8000007`2<S8`00`000000WinO09nOW`0`09nOW`<00000R`2c/k<200000340WinO0P00
000P08b<S0030000001iNGT0NGUi01<0NGUi203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo301CDe<2000001<0IVIV00<0000007UiN@1iNGT05P1iNGT00`000000S8b<08b<S00N
08b<S0030000002OWil0WinO02l0WinO0P00002@0;>c/`800000<@2OWil00`000000S8b<08b<S00N
08b<S0030000001iNGT0NGUi0180NGUi203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo2`1CDe<00`000000IVIV06IVIP0B06IVIP030000001iNGT0NGUi01H0NGUi00<0000008b<
S02<S8`07@2<S8`2000002l0WinO0`00002D0;>c/`<00000;`2OWil2000001l0S8b<00<0000007Ui
N@1iNGT04@1iNGT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool;05=CD`03
0000001VIVH0IVIV0140IVIV00<0000007UiN@1iNGT05P1iNGT00`000000S8b<08b<S00M08b<S003
0000002OWil0WinO02`0WinO0`00002J0;>c/`<00000;P2OWil00`000000S8b<08b<S00M08b<S003
0000001iNGT0NGUi0100NGUi203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
2P1CDe<00`000000IVIV06IVIP0A06IVIP030000001iNGT0NGUi01H0NGUi00<0000008b<S02<S8`0
702<S8`2000002d0WinO0P00002P0;>c/`800000;@2OWil2000001h0S8b<00<0000007UiN@1iNGT0
3`1iNGT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool905=CD`030000001V
IVH0IVIV0140IVIV00<0000007UiN@1iNGT05P1iNGT00`000000S8b<08b<S00L08b<S0030000002O
Wil0WinO02/0WinO0P00002T0;>c/`030000002OWil0WinO02`0WinO00<0000008b<S02<S8`0702<
S8`2000000l0NGUi203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo201CDe<0
0`000000IVIV06IVIP0A06IVIP030000001iNGT0NGUi01H0NGUi00<0000008b<S02<S8`0702<S8`0
0`000000WinO09nOW`0Z09nOW`800000Y`2c/k<2000002d0WinO00<0000008b<S02<S8`07@2<S8`0
0`000000NGUi07UiN@0<07UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
o`L0De=C00<0000006IVIP1VIVH04@1VIVH00`000000NGUi07UiN@0F07UiN@030000002<S8`0S8b<
01/0S8b<0P00000[09nOW`800000Z`2c/k<3000002/0WinO0P00000N08b<S0030000001iNGT0NGUi
00/0NGUi203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo1P1CDe<00`000000
IVIV06IVIP0A06IVIP030000001iNGT0NGUi01D0NGUi0P00000M08b<S0030000002OWil0WinO02T0
WinO0P00002`0;>c/`800000:`2OWil2000001d0S8b<00<0000007UiN@1iNGT02P1iNGT80?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0103oool505=CD`030000001VIVH0IVIV0140IVIV
00<0000007UiN@1iNGT05@1iNGT00`000000S8b<08b<S00L08b<S0030000002OWil0WinO02P0WinO
0P00002d0;>c/`030000002OWil0WinO02X0WinO00<0000008b<S02<S8`06`2<S8`00`000000NGUi
07UiN@0907UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0De=C00<0
000006IVIP1VIVH04@1VIVH00`000000NGUi07UiN@0E07UiN@030000002<S8`0S8b<01`0S8b<00<0
000009nOW`2OWil09`2OWil200000;L0/k>c0P00000[09nOW`800000702<S8`00`000000NGUi07Ui
N@0807UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`<0De=C00<00000
06IVIP1VIVH04@1VIVH00`000000NGUi07UiN@0E07UiN@030000002<S8`0S8b<01/0S8b<0P00000X
09nOW`800000^`2c/k<3000002X0WinO00<0000008b<S02<S8`06P2<S8`00`000000NGUi07UiN@07
07UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`<0De=C00<0000006IV
IP1VIVH0401VIVH00`000000NGUi07UiN@0E07UiN@030000002<S8`0S8b<01X0S8b<0P00000X09nO
W`800000`02c/k<2000002T0WinO00<0000008b<S02<S8`06P2<S8`00`000000NGUi07UiN@0607Ui
N@P0oooo0@0000010?ooo`005`3oool2000000D0oooo0P1CDe<00`000000IVIV06IVIP0@06IVIP03
0000001iNGT0NGUi01D0NGUi00<0000008b<S02<S8`06P2<S8`00`000000WinO09nOW`0V09nOW`80
0000a02c/k<00`000000WinO09nOW`0W09nOW`8000006`2<S8`2000000H0NGUi1`3oool200000040
oooo000G0?ooo`030000003oool0oooo00@0oooo00<0De=C0000001VIVH04@1VIVH00`000000NGUi
07UiN@0E07UiN@030000002<S8`0S8b<01X0S8b<00<0000009nOW`2OWil09@2OWil200000<L0/k>c
0P00000Y09nOW`030000002<S8`0S8b<01X0S8b<00<0000007UiN@1iNGT00`1iNGT80?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103oool00`000000IVIV06IVIP0@06IVIP030000001i
NGT0NGUi01D0NGUi00<0000008b<S02<S8`06P2<S8`00`000000WinO09nOW`0T09nOW`800000b`2c
/k<2000002P0WinO00<0000008b<S02<S8`06@2<S8`00`000000NGUi07UiN@0307UiN@P0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`040?oooa<0IVIV00<0000007UiN@1iNGT0501iNGT0
0`000000S8b<08b<S00I08b<S08000009@2OWil2000005h0/k>c4`00001N0;>c/`8000009`2OWil0
0`000000S8b<08b<S00I08b<S0030000001iNGT0NGUi0080NGUi203oool100000040oooo000G0?oo
o`030000003oool0oooo00@0oooo4P1VIVH00`000000NGUi07UiN@0C07UiN@8000006`2<S8`00`00
0000WinO09nOW`0S09nOW`800000E02c/k<<000001<0a/K63000001D0;>c/`8000009P2OWil20000
01X0S8b<0P00000207UiN@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa40
IVIV00<0000007UiN@1iNGT04`1iNGT00`000000S8b<08b<S00J08b<S0030000002OWil0WinO02<0
WinO00<000000;>c/`2c/k<0C@2c/k<7000002/0a/K62000001>0;>c/`8000009P2OWil00`000000
S8b<08b<S00I08b<S0030000001iNGT0oooo00L0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?oooa00IVIV00<0000007UiN@1iNGT04`1iNGT00`000000S8b<08b<S00I08b<S0800000
902OWil2000004`0/k>c1000000j0<K6aP@00000C02c/k<2000002D0WinO00<0000008b<S02<S8`0
6@2<S8`00`000000oooo0?ooo`060?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103o
ool?06IVIP030000001iNGT0NGUi01<0NGUi00<0000008b<S02<S8`06@2<S8`00`000000WinO09nO
W`0S09nOW`030000002c/k<0/k>c04@0/k>c200000120<K6aPP00000AP2c/k<00`000000WinO09nO
W`0S09nOW`030000002<S8`0S8b<01T0S8b<00<000000?ooo`3oool01@3oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo3P1VIVH00`000000NGUi07UiN@0C07UiN@030000002<S8`0
S8b<01T0S8b<00<0000009nOW`2OWil08P2OWil2000004<0/k>c1000001B0<K6aP@00000@`2c/k<2
000002@0WinO00<0000008b<S02<S8`0602<S8`00`000000oooo0?ooo`050?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0103oool=06IVIP030000001iNGT0NGUi01<0NGUi00<0000008b<
S02<S8`06@2<S8`00`000000WinO09nOW`0Q09nOW`800000@@2c/k<4000005X0a/K6100000110;>c
/`030000002OWil0WinO0280WinO00<0000008b<S02<S8`05`2<S8`80?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103oool<06IVIP030000001iNGT0NGUi01<0NGUi00<0000008b<S02<
S8`0602<S8`2000002<0WinO00<000000;>c/`2c/k<0?P2c/k<300000680a/K60`00000o0;>c/`80
00008`2OWil2000001L0S8b<203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
2`1VIVH00`000000NGUi07UiN@0C07UiN@030000002<S8`0S8b<01P0S8b<00<0000009nOW`2OWil0
8P2OWil00`000000/k>c0;>c/`0m0;>c/`800000J036a/H4000003d0/k>c0P00000S09nOW`030000
002<S8`0S8b<01@0S8b<203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2P1V
IVH00`000000NGUi07UiN@0C07UiN@030000002<S8`0S8b<01P0S8b<00<0000009nOW`2OWil08@2O
Wil2000003d0/k>c0`00001^0<K6aP800000?@2c/k<00`000000WinO09nOW`0Q09nOW`030000002<
S8`0S8b<01<0S8b<203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2@1VIVH0
0`000000NGUi07UiN@0C07UiN@030000002<S8`0S8b<01P0S8b<00<0000009nOW`2OWil0802OWil2
000003/0/k>c1000001c0<K6aP<00000>`2c/k<200000280WinO0P00000C08b<S0P0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`P0IVIV00<0000007UiN@1iNGT04`1iNGT00`00
0000S8b<08b<S00H08b<S0030000002OWil0WinO0200WinO00<000000;>c/`2c/k<0>02c/k<30000
07X0a/K60`00000j0;>c/`030000002OWil0WinO0240WinO00<0000008b<S02<S8`0402<S8`80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool806IVIP030000001iNGT0NGUi0180
NGUi00<0000008b<S02<S8`0602<S8`00`000000WinO09nOW`0P09nOW`030000002c/k<0/k>c03L0
/k>c0P0000200<K6aP@00000=`2c/k<00`000000WinO09nOW`0P09nOW`030000002<S8`0S8b<0100
S8b<203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo1`1VIVH00`000000NGUi
07UiN@0B07UiN@030000002<S8`0S8b<01P0S8b<00<0000009nOW`2OWil07`2OWil2000003L0/k>c
0`0000260<K6aP800000=P2c/k<200000240WinO00<0000008b<S02<S8`03`2<S8`80?ooo`400000
0@3oool001L0oooo0P0000050?ooo`H0IVIV00<0000007UiN@1iNGT04P1iNGT00`000000S8b<08b<
S00G08b<S08000008@2OWil00`000000/k>c0;>c/`0d0;>c/`<00000R`36a/H3000003D0/k>c00<0
000009nOW`2OWil07`2OWil2000000l0S8b<1`3oool200000040oooo000G0?ooo`030000003oool0
oooo00@0oooo1@1VIVH00`000000NGUi07UiN@0B07UiN@030000002<S8`0S8b<01L0S8b<00<00000
09nOW`2OWil07`2OWil2000003D0/k>c0P00002A0<K6aP<00000<`2c/k<200000240WinO00<00000
08b<S02<S8`0302<S8`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool406IV
IP030000001iNGT0NGUi0180NGUi00<0000008b<S02<S8`05`2<S8`00`000000WinO09nOW`0O09nO
W`030000002c/k<0/k>c0380/k>c0`00002E0<K6aP800000=02c/k<200000200WinO00<0000008b<
S02<S8`02`2<S8`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool306IVIP03
0000001iNGT0NGUi0180NGUi00<0000008b<S02<S8`05`2<S8`00`000000WinO09nOW`0O09nOW`03
0000002c/k<0/k>c0300/k>c0`00002J0<K6aP800000=02c/k<00`000000WinO09nOW`0N09nOW`80
00002`2<S8`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool206IVIP030000
001iNGT0NGUi0180NGUi00<0000008b<S02<S8`05`2<S8`00`000000WinO09nOW`0O09nOW`030000
002c/k<0/k>c02l0/k>c0P00002O0<K6aP800000<`2c/k<200000200WinO00<0000008b<S02<S8`0
202<S8`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool206IVIP030000001i
NGT0NGUi0180NGUi00<0000008b<S02<S8`05P2<S8`00`000000WinO09nOW`0N09nOW`800000<02c
/k<200000:<0a/K60P00000c0;>c/`030000002OWil0WinO01d0WinO00<0000008b<S02<S8`0202<
S8`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool2000001@0NGUi00<00000
08b<S02<S8`05P2<S8`00`000000WinO09nOW`0N09nOW`030000002c/k<0/k>c02h0/k>c0P00002W
0<K6aP800000<P2c/k<00`000000WinO09nOW`0M09nOW`030000002<S8`0S8b<00L0S8b<203oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo501iNGT2000001L0S8b<0P00000P09nO
W`030000002c/k<0/k>c02d0/k>c0P00002[0<K6aP800000<@2c/k<2000001h0WinO0P00000708b<
S0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa<0NGUi00<0000008b<S02<
S8`05P2<S8`00`000000WinO09nOW`0N09nOW`800000;P2c/k<200000:l0a/K60P00000a0;>c/`03
0000002OWil0WinO01d0WinO00<0000008b<S02<S8`0102<S8`80?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103ooolC07UiN@030000002<S8`0S8b<01D0S8b<00<0000009nOW`2OWil0
7P2OWil00`000000/k>c0;>c/`0/0;>c/`800000/`36a/H3000002l0/k>c00<0000009nOW`2OWil0
7@2OWil00`000000S8b<08b<S00308b<S0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`040?oooa80NGUi00<0000008b<S02<S8`05P2<S8`00`000000WinO09nOW`0L09nOW`800000;@2c
/k<200000;P0a/K60P00000^0;>c/`030000002OWil0WinO01d0WinO00<0000008b<S02<S8`00P2<
S8`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool@07UiN@8000005`2<S8`2
000001h0WinO00<000000;>c/`2c/k<0:`2c/k<200000;`0a/K600<000000;>c/`2c/k<0;02c/k<2
000001h0WinO00@0000008b<S02<S8`0S8b<203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo3`1iNGT00`000000S8b<08b<S00F08b<S0030000002OWil0WinO01d0WinO00<00000
0;>c/`2c/k<0:P2c/k<200000;l0a/K60P00000^0;>c/`030000002OWil0WinO01`0WinO00<00000
08b<S02<S8`0203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo3`1iNGT00`00
0000S8b<08b<S00E08b<S0030000002OWil0WinO01`0WinO0P00000[0;>c/`800000``36a/H20000
02d0/k>c00<0000009nOW`2OWil0702OWil00`000000S8b<0?ooo`070?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103oool>07UiN@030000002<S8`0S8b<01D0S8b<00<0000009nOW`2O
Wil0702OWil00`000000/k>c0;>c/`0Y0;>c/`800000a`36a/H2000002`0/k>c0P00000M09nOW`03
0000003oool0oooo00H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`d0NGUi
00<0000008b<S02<S8`05@2<S8`00`000000WinO09nOW`0L09nOW`030000002c/k<0/k>c02P0/k>c
0P00003;0<K6aP800000;02c/k<00`000000WinO09nOW`0K09nOW`030000003oool0oooo00D0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo``0NGUi00<0000008b<S02<S8`05@2<
S8`00`000000WinO09nOW`0L09nOW`030000002c/k<0/k>c02L0/k>c0P00003?0<K6aP800000:`2c
/k<2000001/0WinO203oool100000040oooo000G0?ooo`8000001@3oool;07UiN@030000002<S8`0
S8b<01D0S8b<00<0000009nOW`2OWil06`2OWil2000002P0/k>c0P00003C0<K6aP800000:`2c/k<0
0`000000WinO09nOW`0H09nOW`L0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
o`/0NGUi00<0000008b<S02<S8`0502<S8`00`000000WinO09nOW`0K09nOW`030000002c/k<0/k>c
02P0/k>c00<000000<K6aP36a/H0e036a/H2000002T0/k>c00<0000009nOW`2OWil0602OWil80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool907UiN@8000005P2<S8`00`000000
WinO09nOW`0K09nOW`030000002c/k<0/k>c02L0/k>c0P00003I0<K6aP800000:02c/k<00`000000
WinO09nOW`0G09nOW`P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`P0NGUi
00<0000008b<S02<S8`05@2<S8`00`000000WinO09nOW`0J09nOW`800000:02c/k<2000006P0a/K6
2`00001Z0<K6aP030000002c/k<0/k>c02H0/k>c0P00000G09nOW`P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo`L0NGUi00<0000008b<S02<S8`05@2<S8`00`000000WinO09nO
W`0J09nOW`030000002c/k<0/k>c02H0/k>c0P00001N0<K6aP`000002`3IfMT?000005`0a/K60P00
000X0;>c/`030000002OWil0WinO01@0WinO203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo1`1iNGT00`000000S8b<08b<S00D08b<S0030000002OWil0WinO01X0WinO00<00000
0;>c/`2c/k<09@2c/k<2000005T0a/K61`00000V0=WIf@T00000E@36a/H00`000000/k>c0;>c/`0V
0;>c/`030000002OWil0WinO01<0WinO203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo1P1iNGT00`000000S8b<08b<S00D08b<S0030000002OWil0WinO01X0WinO00<000000;>c
/`2c/k<09@2c/k<00`000000a/K60<K6aP1A0<K6aPP00000=P3IfMT400000580a/K60P00000W0;>c
/`8000004`2OWil80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool507UiN@03
0000002<S8`0S8b<01@0S8b<00<0000009nOW`2OWil06P2OWil00`000000/k>c0;>c/`0T0;>c/`80
0000D036a/H400000480fMWI1000001@0<K6aP8000009`2c/k<00`000000WinO09nOW`0@09nOW`P0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0NGUi00<0000008b<S02<S8`0
502<S8`00`000000WinO09nOW`0J09nOW`030000002c/k<0/k>c02@0/k>c00<000000<K6aP36a/H0
C036a/H4000004X0fMWI1`00001;0<K6aP030000002c/k<0/k>c02@0/k>c00<0000009nOW`2OWil0
402OWil80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool407UiN@030000002<
S8`0S8b<01<0S8b<00<0000009nOW`2OWil06P2OWil00`000000/k>c0;>c/`0T0;>c/`0300000036
a/H0a/K604T0a/K61000001D0=WIf@D00000B036a/H00`000000/k>c0;>c/`0T0;>c/`030000002O
Wil0WinO00l0WinO203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo0`1iNGT0
0`000000S8b<08b<S00C08b<S0030000002OWil0WinO01T0WinO0P00000U0;>c/`800000B036a/H4
000005d0fMWI0P0000170<K6aP8000009@2c/k<2000000l0WinO203oool100000040oooo000G0?oo
o`030000003oool0oooo00@0oooo00<0NGUi0000000000005@2<S8`00`000000WinO09nOW`0I09nO
W`030000002c/k<0/k>c02<0/k>c0P0000160<K6aP@00000H`3IfMT3000004H0a/K60P00000U0;>c
/`030000002OWil0WinO00`0WinO203oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo00<0000008b<S02<S8`04`2<S8`2000001X0WinO0P00000T0;>c/`800000@`36a/H5000006X0
fMWI1@0000130<K6aP800000902c/k<2000000`0WinO203oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo5@2<S8`00`000000WinO09nOW`0I09nOW`030000002c/k<0/k>c02@0/k>c
00<000000<K6aP36a/H0?`36a/H3000007@0fMWI0`0000110<K6aP030000002c/k<0/k>c02@0/k>c
00<0000009nOW`2OWil02@2OWil80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103o
oolE08b<S0030000002OWil0WinO01T0WinO00<000000;>c/`2c/k<08`2c/k<00`000000a/K60<K6
aP0m0<K6aP<00000NP3IfMT3000003l0a/K60P00000U0;>c/`030000002OWil0WinO00P0WinO203o
ool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo502<S8`00`000000WinO09nOW`0I
09nOW`030000002c/k<0/k>c0280/k>c0P00000n0<K6aP800000P03IfMT2000003l0a/K60P00000T
0;>c/`030000002OWil0WinO00L0WinO203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo4`2<S8`00`000000WinO09nOW`0H09nOW`8000008`2c/k<2000003`0a/K6100000240=WI
f@@00000?@36a/H2000002<0/k>c00<0000009nOW`2OWil01P2OWil80?ooo`4000000@3oool001L0
oooo0P0000050?oooa80S8b<00<0000009nOW`2OWil0602OWil00`000000/k>c0;>c/`0R0;>c/`03
00000036a/H0a/K603X0a/K60P00002<0=WIf@800000?@36a/H00`000000/k>c0;>c/`0Q0;>c/`03
0000002OWil0WinO00D0WinO1`3oool200000040oooo000G0?ooo`030000003oool0oooo00@0oooo
4@2<S8`00`000000WinO09nOW`0H09nOW`030000002c/k<0/k>c0280/k>c00<000000<K6aP36a/H0
>@36a/H200000900fMWI0P00000l0<K6aP030000002c/k<0/k>c0240/k>c00<0000009nOW`2OWil0
102OWil80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool@08b<S0030000002O
Wil0WinO01P0WinO00<000000;>c/`2c/k<08@2c/k<2000003T0a/K60`00002D0=WIf@<00000>P36
a/H200000280/k>c00<0000009nOW`2OWil00`2OWil80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool?08b<S0030000002OWil0WinO01P0WinO00<000000;>c/`2c/k<0802c/k<2
000003T0a/K60P00002J0=WIf@<00000>@36a/H00`000000/k>c0;>c/`0P0;>c/`030000002OWil0
WinO0080WinO203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo3P2<S8`00`00
0000WinO09nOW`0H09nOW`030000002c/k<0/k>c0200/k>c00<000000<K6aP36a/H0=`36a/H20000
09l0fMWI0P00000h0<K6aP030000002c/k<0/k>c0200/k>c0P00000209nOW`P0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`040?ooo`d0S8b<00<0000009nOW`2OWil0602OWil00`000000
/k>c0;>c/`0Q0;>c/`0300000036a/H0a/K603@0a/K60`00002S0=WIf@0300000036a/H0a/K603H0
a/K600<000000;>c/`2c/k<08@2c/k<00`000000WinO0?ooo`070?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103oool<08b<S0030000002OWil0WinO01L0WinO0P00000R0;>c/`800000
=@36a/H200000:L0fMWI0P00000g0<K6aP8000008P2c/k<00`000000oooo0?ooo`060?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103oool;08b<S0030000002OWil0WinO01L0WinO00<0
00000;>c/`2c/k<0802c/k<2000003D0a/K60P00002[0=WIf@<00000=P36a/H00`000000/k>c0;>c
/`0P0;>c/`030000003oool0oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`04
0?ooo`X0S8b<00<0000009nOW`2OWil05`2OWil00`000000/k>c0;>c/`0Q0;>c/`0300000036a/H0
a/K60380a/K60P00002`0=WIf@800000=@36a/H00`000000/k>c0;>c/`0O0;>c/`030000003oool0
oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`T0S8b<00<0000009nO
W`2OWil0602OWil00`000000/k>c0;>c/`0P0;>c/`0300000036a/H0a/K60340a/K60P00002d0=WI
f@0300000036a/H0a/K603<0a/K60P00000O0;>c/`P0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`040?ooo`T0S8b<00<0000009nOW`2OWil05P2OWil200000240/k>c0P00000b0<K6aP80
0000]`3IfMT2000003D0a/K600<000000;>c/`2c/k<0702c/k<80?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103oool808b<S0030000002OWil0WinO01H0WinO00<000000;>c/`2c/k<0
7`2c/k<200000380a/K60P00002k0=WIf@<00000<`36a/H00`000000/k>c0;>c/`0K0;>c/`P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`L0S8b<00<0000009nOW`2OWil05P2O
Wil00`000000/k>c0;>c/`0O0;>c/`0300000036a/H0a/K60300a/K60P0000300=WIf@800000<P36
a/H2000001/0/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo1P2<S8`0
0`000000WinO09nOW`0G09nOW`030000002c/k<0/k>c01h0/k>c00<000000<K6aP36a/H0;`36a/H2
00000<@0fMWI00<000000<K6aP36a/H0<@36a/H00`000000/k>c0;>c/`0H0;>c/`P0oooo0@000001
0?ooo`002P3oool6000000L0oooo00<000000?ooo`3oool0103oool508b<S0030000002OWil0WinO
01H0WinO0P00000P0;>c/`0300000036a/H0a/K602h0a/K60P0000370=WIf@800000<P36a/H00`00
0000/k>c0;>c/`0G0;>c/`P0oooo0@0000010?ooo`002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool408b<S0030000002OWil0WinO01H0
WinO00<000000;>c/`2c/k<07P2c/k<2000002l0a/K60P00003;0=WIf@<00000<036a/H00`000000
/k>c0;>c/`0F0;>c/`P0oooo0@0000010?ooo`002`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo0`2<S8`00`000000WinO09nOW`0F09nOW`030000002c/k<0/k>c01h0/k>c
00<000000<K6aP36a/H0;P36a/H00`000000fMWI0=WIf@3>0=WIf@800000;`36a/H00`000000/k>c
0;>c/`0E0;>c/`P0oooo0@0000010?ooo`00303oool00`000000oooo0?ooo`080?ooo`<00000103o
ool208b<S0030000002OWil0WinO01L0WinO00<000000;>c/`2c/k<07@2c/k<00`000000a/K60<K6
aP0]0<K6aP800000d`3IfMT00`000000a/K60<K6aP0]0<K6aP030000002c/k<0/k>c01@0/k>c1P3o
ool300000040oooo00000`3oool0000000000004000000H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`80S8b<00<0000009nOW`2OWil05P2OWil00`000000/k>c0;>c/`0L
0;>c/`800000;`36a/H00`000000fMWI0=WIf@3D0=WIf@800000;P36a/H2000001@0/k>c203oool1
00000040oooo000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`2<
S8`0000009nOW`0G09nOW`030000002c/k<0/k>c01`0/k>c00<000000<K6aP36a/H0;@36a/H20000
0=T0fMWI0P00000^0<K6aP030000002c/k<0/k>c0140/k>c203oool100000040oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000002OWil0WinO01H0WinO00<000000;>c/`2c/k<0702c/k<00`000000a/K60<K6aP0/0<K6aP80
0000g03IfMT00`000000a/K60<K6aP0]0<K6aP030000002c/k<0/k>c0100/k>c203oool100000040
oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?oooaP0WinO00<000000;>c/`2c/k<07@2c/k<00`000000a/K60<K6aP0Z0<K6aP800000
g`3IfMT2000002h0a/K600<000000;>c/`2c/k<03`2c/k<80?ooo`4000000@3oool000/0oooo1000
00080?ooo`030000003oool0oooo00@0oooo5`2OWil00`000000/k>c0;>c/`0L0;>c/`800000:`36
a/H200000><0fMWI0P00000]0<K6aP030000002c/k<0/k>c00h0/k>c203oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo5P2OWil00`000000/k>c0;>c/`0L0;>c/`0300000036a/H0
a/K602X0a/K600<000000=WIf@3IfMT0i@3IfMT2000002`0a/K60P00000>0;>c/`P0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?oooaD0WinO00<000000;>c/`2c/k<0702c/k<00`00
0000a/K60<K6aP0Y0<K6aP800000jP3IfMT00`000000a/K60<K6aP0[0<K6aP030000002c/k<0/k>c
00/0/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo502OWil00`000000
/k>c0;>c/`0L0;>c/`0300000036a/H0a/K602T0a/K600<000000=WIf@3IfMT0j`3IfMT00`000000
a/K60<K6aP0[0<K6aP030000002c/k<0/k>c00X0/k>c203oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo4`2OWil00`000000/k>c0;>c/`0K0;>c/`800000:P36a/H200000>l0fMWI
0P00000/0<K6aP030000002c/k<0/k>c00T0/k>c203oool100000040oooo000G0?ooo`030000003o
ool0oooo00@0oooo4P2OWil00`000000/k>c0;>c/`0K0;>c/`0300000036a/H0a/K602T0a/K600<0
00000=WIf@3IfMT0l@3IfMT2000002/0a/K600<000000;>c/`2c/k<0202c/k<80?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0103ooolA09nOW`030000002c/k<0/k>c01`0/k>c00<00000
0<K6aP36a/H0:@36a/H00`000000fMWI0=WIf@1Z0=WIfAl00000JP3IfMT00`000000a/K60<K6aP0Y
0<K6aP030000002c/k<0/k>c00L0/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo402OWil00`000000/k>c0;>c/`0L0;>c/`0300000036a/H0a/K602P0a/K60P00001R0=WI
f@/000007`3/k>`8000006<0fMWI0P00000Z0<K6aP030000002c/k<0/k>c00H0/k>c203oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo3`2OWil00`000000/k>c0;>c/`0K0;>c/`80
0000:@36a/H200000600fMWI1000000b0>c/k0P00000G@3IfMT00`000000a/K60<K6aP0X0<K6aP03
0000002c/k<0/k>c00D0/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
3P2OWil00`000000/k>c0;>c/`0K0;>c/`0300000036a/H0a/K602L0a/K60P00001J0=WIf@P00000
?P3/k>`4000005X0fMWI0P00000Y0<K6aP030000002c/k<0/k>c00@0/k>c203oool100000040oooo
000G0?ooo`030000003oool0oooo00@0oooo3@2OWil00`000000/k>c0;>c/`0K0;>c/`0300000036
a/H0a/K602L0a/K600<000000=WIf@3IfMT0EP3IfMT4000004X0k>c/1000001H0=WIf@0300000036
a/H0a/K602L0a/K600<000000;>c/`2c/k<00`2c/k<80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool<09nOW`030000002c/k<0/k>c01/0/k>c00<000000<K6aP36a/H09`36a/H0
0`000000fMWI0=WIf@1C0=WIf@@00000DP3/k>`4000005D0fMWI00<000000<K6aP36a/H09`36a/H2
000000<0/k>c203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2`2OWil00`00
0000/k>c0;>c/`0K0;>c/`0300000036a/H0a/K602H0a/K60P00001B0=WIf@@00000FP3/k>`40000
0580fMWI0P00000Y0<K6aP030000002c/k<0/k>c00P0oooo0@0000010?ooo`005`3oool2000000D0
oooo2`2OWil00`000000/k>c0;>c/`0J0;>c/`0300000036a/H0a/K602H0a/K600<000000=WIf@3I
fMT0CP3IfMT400000680k>c/1@00001?0=WIf@8000009`36a/H00`000000/k>c0;>c/`070?ooo`80
00000@3oool001L0oooo00<000000?ooo`3oool0103oool:09nOW`030000002c/k<0/k>c01X0/k>c
00<000000<K6aP36a/H09P36a/H00`000000fMWI0=WIf@1<0=WIf@<00000J`3/k>`3000004h0fMWI
00<000000<K6aP36a/H09@36a/H00`000000/k>c0?ooo`070?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103oool909nOW`030000002c/k<0/k>c01X0/k>c00<000000<K6aP36a/H09P36
a/H00`000000fMWI0=WIf@1;0=WIf@800000L@3/k>`3000004`0fMWI0P00000V0<K6aP030000003o
ool0oooo00H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`P0WinO00<00000
0;>c/`2c/k<06P2c/k<00`000000a/K60<K6aP0U0<K6aP800000B`3IfMT3000007H0k>c/0P00001<
0=WIf@0300000036a/H0a/K602@0a/K600<000000?ooo`3oool01@3oool100000040oooo000G0?oo
o`030000003oool0oooo00@0oooo1`2OWil00`000000/k>c0;>c/`0J0;>c/`0300000036a/H0a/K6
02@0a/K60P0000180=WIf@D00000N`3/k>`4000004T0fMWI00<000000<K6aP36a/H08`36a/H80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool609nOW`030000002c/k<0/k>c01X0
/k>c00<000000<K6aP36a/H09036a/H00`000000fMWI0=WIf@160=WIf@800000Q03/k>`3000004L0
fMWI0P00000S0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`D0WinO
00<000000;>c/`2c/k<06P2c/k<00`000000a/K60<K6aP0T0<K6aP030000003IfMT0fMWI04D0fMWI
0P0000290>c/k0<00000AP3IfMT00`000000a/K60<K6aP0P0<K6aPP0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo`@0WinO00<000000;>c/`2c/k<06P2c/k<00`000000a/K60<K6
aP0T0<K6aP030000003IfMT0fMWI04<0fMWI0`00002>0>c/k0800000A@3IfMT00`000000a/K60<K6
aP0O0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@0WinO00<00000
0;>c/`2c/k<06@2c/k<00`000000a/K60<K6aP0S0<K6aP800000@`3IfMT3000009<0k>c/0P000014
0=WIf@0300000036a/H0a/K601h0a/K6203oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo0`2OWil00`000000/k>c0;>c/`0I0;>c/`0300000036a/H0a/K602<0a/K600<000000=WI
f@3IfMT0@@3IfMT2000009P0k>c/0P0000130=WIf@8000007P36a/H80?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103oool209nOW`030000002c/k<0/k>c01T0/k>c00<000000<K6aP36
a/H08`36a/H00`000000fMWI0=WIf@100=WIf@800000W03/k>`2000004<0fMWI00<000000<K6aP36
a/H06`36a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool00`2OWil00000
0;>c/`0J0;>c/`0300000036a/H0a/K60280a/K60P0000110=WIf@800000X03/k>`300000440fMWI
00<000000<K6aP36a/H06P36a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103o
ool00`000000/k>c0;>c/`0I0;>c/`0300000036a/H0a/K60280a/K600<000000=WIf@3IfMT0?`3I
fMT200000:D0k>c/0P0000100=WIf@0300000036a/H0a/K601T0a/K6203oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo6`2c/k<00`000000a/K60<K6aP0R0<K6aP030000003IfMT0
fMWI03h0fMWI0P00002Y0>c/k0800000?`3IfMT00`000000a/K60<K6aP0H0<K6aPP0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?oooaX0/k>c00<000000<K6aP36a/H08P36a/H00`00
0000fMWI0=WIf@0m0=WIf@800000[@3/k>`2000003h0fMWI00<000000<K6aP36a/H05`36a/H80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolI0;>c/`0300000036a/H0a/K60280
a/K600<000000=WIf@3IfMT0?03IfMT200000;40k>c/0P00000m0=WIf@8000005`36a/H80?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0103ooolH0;>c/`0300000036a/H0a/K60280a/K6
00<000000=WIf@3IfMT0>P3IfMT300000;D0k>c/0P00000m0=WIf@0300000036a/H0a/K601@0a/K6
203oool100000040oooo000G0?ooo`8000001@3ooolG0;>c/`0300000036a/H0a/K60280a/K600<0
00000=WIf@3IfMT0>@3IfMT200000;X0k>c/0P00000l0=WIf@0300000036a/H0a/K601<0a/K61`3o
ool200000040oooo000G0?ooo`030000003oool0oooo00@0oooo5P2c/k<00`000000a/K60<K6aP0R
0<K6aP030000003IfMT0fMWI03T0fMWI00<000000>c/k03/k>`0_03/k>`2000003/0fMWI0P00000C
0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooaD0/k>c00<000000<K6
aP36a/H08@36a/H2000003X0fMWI0P0000310>c/k0800000>`3IfMT00`000000a/K60<K6aP0@0<K6
aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa@0/k>c00<000000<K6aP36
a/H08@36a/H00`000000fMWI0=WIf@0h0=WIf@800000a@3/k>`2000003T0fMWI00<000000<K6aP36
a/H04036a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolC0;>c/`030000
0036a/H0a/K60240a/K600<000000=WIf@3IfMT0=`3IfMT200000<T0k>c/0P00000h0=WIf@030000
0036a/H0a/K600l0a/K6203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo4P2c
/k<00`000000a/K60<K6aP0P0<K6aP800000>03IfMT200000<d0k>c/00<000000=WIf@3IfMT0=P3I
fMT2000000l0a/K6203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo4@2c/k<0
0`000000a/K60<K6aP0P0<K6aP030000003IfMT0fMWI03H0fMWI0P00003@0>c/k0800000>03IfMT0
0`000000a/K60<K6aP0<0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
oa00/k>c00<000000<K6aP36a/H08036a/H00`000000fMWI0=WIf@0e0=WIf@800000e03/k>`20000
03L0fMWI00<000000<K6aP36a/H02`36a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0103oool?0;>c/`0300000036a/H0a/K60200a/K600<000000=WIf@3IfMT0=03IfMT200000=P0
k>c/0P00000f0=WIf@8000002`36a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103oool>0;>c/`0300000036a/H0a/K60200a/K600<000000=WIf@3IfMT0<`3IfMT200000=`0k>c/
00<000000=WIf@3IfMT0=@3IfMT00`000000a/K60<K6aP080<K6aPP0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo`h0/k>c00<000000<K6aP36a/H07`36a/H00`000000fMWI0=WI
f@0c0=WIf@030000003/k>`0k>c/0=d0k>c/0P00000e0=WIf@0300000036a/H0a/K600P0a/K6203o
ool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo302c/k<200000240a/K600<00000
0=WIf@3IfMT0<`3IfMT00`000000k>c/0>c/k03P0>c/k0800000=03IfMT00`000000a/K60<K6aP07
0<K6aPP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`/0/k>c00<000000<K6
aP36a/H08036a/H00`000000fMWI0=WIf@0b0=WIf@800000i@3/k>`00`000000fMWI0=WIf@0b0=WI
f@8000001`36a/H80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool:0;>c/`03
00000036a/H0a/K60200a/K600<000000=WIf@3IfMT0<@3IfMT200000>P0k>c/0P00000d0=WIf@03
00000036a/H0a/K600@0a/K6203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
2P2c/k<00`000000a/K60<K6aP0O0<K6aP030000003IfMT0fMWI0300fMWI0P00003/0>c/k0030000
003IfMT0fMWI0380fMWI00<000000<K6aP36a/H00`36a/H80?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103oool90;>c/`0300000036a/H0a/K601l0a/K600<000000=WIf@3IfMT0<@3I
fMT00`000000k>c/0>c/k03/0>c/k0800000<`3IfMT00`000000a/K60<K6aP020<K6aPP0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`P0/k>c00<000000<K6aP36a/H07P36a/H2
00000380fMWI0P00003a0>c/k0800000<P3IfMT010000000a/K60<K6aP36a/H80?ooo`4000000@3o
ool001L0oooo0P0000050?ooo`L0/k>c00<000000<K6aP36a/H07P36a/H00`000000fMWI0=WIf@0a
0=WIf@030000003/k>`0k>c/0?<0k>c/00<000000=WIf@3IfMT0<03IfMT00`000000a/K60<K6aP07
0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0103oool70;>c/`0300000036a/H0a/K6
01d0a/K600<000000=WIf@3IfMT0<03IfMT200000?L0k>c/00<000000=WIf@3IfMT0<03IfMT00`00
0000a/K60?ooo`070?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool60;>c/`03
00000036a/H0a/K601d0a/K600<000000=WIf@3IfMT0<03IfMT00`000000k>c/0>c/k03h0>c/k080
0000<@3IfMT00`000000oooo0?ooo`060?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103oool40;>c/`8000007`36a/H00`000000fMWI0=WIf@0`0=WIf@030000003/k>`0k>c/0?/0k>c/
00<000000=WIf@3IfMT0;`3IfMT00`000000oooo0?ooo`050?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103oool30;>c/`0300000036a/H0a/K601h0a/K600<000000=WIf@3IfMT0<03I
fMT00`000000k>c/0>c/k03m0>c/k0800000;`3IfMT80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool30;>c/`0300000036a/H0a/K601d0a/K600<000000=WIf@3IfMT0;`3IfMT2
00000?l0k>c/0`3/k>`00`000000fMWI0=WIf@0/0=WIf@P0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`040?ooo`80/k>c00<000000<K6aP36a/H07@36a/H00`000000fMWI0=WIf@0^0=WI
f@800000o`3/k>`60>c/k0030000003IfMT0fMWI02/0fMWI203oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo00<0/k>c00000036a/H07P36a/H00`000000fMWI0=WIf@0]0=WIf@80
0000o`3/k>`90>c/k0800000:`3IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
103oool00`000000a/K60<K6aP0M0<K6aP030000003IfMT0fMWI02d0fMWI00<000000>c/k03/k>`0
o`3/k>`;0>c/k0030000003IfMT0fMWI02P0fMWI203oool100000040oooo000G0?ooo`030000003o
ool0oooo00@0oooo7`36a/H00`000000fMWI0=WIf@0]0=WIf@030000003/k>`0k>c/0?l0k>c/3@3/
k>`2000002P0fMWI203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo7P36a/H0
0`000000fMWI0=WIf@0]0=WIf@030000003/k>`0k>c/0?l0k>c/403/k>`00`000000fMWI0=WIf@0U
0=WIf@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooad0a/K600<000000=WI
f@3IfMT0;03IfMT200000?l0k>c/503/k>`00`000000fMWI0=WIf@0T0=WIf@P0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`040?oooa`0a/K600<000000=WIf@3IfMT0;03IfMT00`000000
k>c/0>c/k03o0>c/k1D0k>c/00<000000=WIf@3IfMT08`3IfMT80?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103ooolK0<K6aP030000003IfMT0fMWI02`0fMWI00<000000>c/k03/k>`0
o`3/k>`G0>c/k08000008`3IfMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103o
oolJ0<K6aP030000003IfMT0fMWI02/0fMWI0P00003o0>c/k1`0k>c/00<000000=WIf@3IfMT0803I
fMT80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolI0<K6aP030000003IfMT0
fMWI02/0fMWI00<000000>c/k03/k>`0Q`3/k>`?000008H0k>c/00<000000=WIf@3IfMT07`3IfMT8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolH0<K6aP030000003IfMT0fMWI
02X0fMWI0P00001j0>c/k10000003`3oool<000007/0k>c/0P00000O0=WIf@P0oooo0@0000010?oo
o`005`3oool2000000D0oooo5`36a/H00`000000fMWI0=WIf@0Z0=WIf@030000003/k>`0k>c/07L0
k>c/0`00000[0?ooo`L00000MP3/k>`00`000000fMWI0=WIf@0L0=WIf@L0oooo0P0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?oooaL0a/K600<000000=WIf@3IfMT0:P3IfMT00`000000k>c/
0>c/k01_0>c/k0P00000=@3oool500000780k>c/00<000000=WIf@3IfMT06`3IfMT80?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103ooolE0<K6aP800000;03IfMT00`000000k>c/0>c/
k01/0>c/k0@00000@P3oool8000006/0k>c/0P00000K0=WIf@P0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?oooa@0a/K600<000000=WIf@3IfMT0:P3IfMT2000006/0k>c/1000001>
0?ooo`@00000J@3/k>`00`000000fMWI0=WIf@0H0=WIf@P0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`040?oooa<0a/K600<000000=WIf@3IfMT0:P3IfMT00`000000k>c/0>c/k01W0>c/
k0@00000EP3oool3000006L0k>c/00<000000=WIf@3IfMT05`3IfMT80?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0103ooolC0<K6aP030000003IfMT0fMWI02T0fMWI00<000000>c/k03/
k>`0I03/k>`4000005d0oooo1@00001S0>c/k0030000003IfMT0fMWI01H0fMWI203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo4@36a/H2000002X0fMWI0P00001S0>c/k0@00000
IP3oool300000640k>c/0P00000F0=WIf@P0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`040?oooa00a/K600<000000=WIf@3IfMT0:@3IfMT00`000000k>c/0>c/k01O0>c/k0@00000K@3o
ool200000640k>c/00<000000=WIf@3IfMT04`3IfMT80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool?0<K6aP030000003IfMT0fMWI02P0fMWI0P00001M0>c/k0D00000L`3oool4
000005h0k>c/00<000000=WIf@3IfMT04P3IfMT80?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0103oool>0<K6aP030000003IfMT0fMWI02P0fMWI00<000000>c/k03/k>`0F`3/k>`20000
07`0oooo0`00001L0>c/k0030000003IfMT0fMWI0140fMWI203oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo3@36a/H00`000000fMWI0=WIf@0X0=WIf@030000003/k>`0k>c/05X0
k>c/0P0000210?ooo`<00000FP3/k>`00`000000fMWI0=WIf@0@0=WIf@P0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo`d0a/K600<000000=WIf@3IfMT09`3IfMT00`000000k>c/
0>c/k01H0>c/k0<00000QP3oool2000005T0k>c/0P00000@0=WIf@P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo``0a/K600<000000=WIf@3IfMT09`3IfMT00`000000k>c/0>c/
k01F0>c/k0<00000R`3oool4000005L0k>c/00<000000=WIf@3IfMT03@3IfMT80?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0103oool;0<K6aP030000003IfMT0fMWI02L0fMWI00<00000
0>c/k03/k>`0E@3/k>`200000980oooo0P00001F0>c/k0030000003IfMT0fMWI00`0fMWI203oool1
00000040oooo000:0?ooo`L000001P3oool00`000000oooo0?ooo`040?ooo`X0a/K600<000000=WI
f@3IfMT09`3IfMT00`000000k>c/0>c/k01D0>c/k0800000UP3oool2000005D0k>c/00<000000=WI
f@3IfMT02`3IfMT80?ooo`4000000@3oool000d0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`T0a/K600<000000=WIf@3IfMT09P3IfMT2000005D0k>c/0P00002J0?ooo`80
0000E03/k>`00`000000fMWI0=WIf@0:0=WIf@P0oooo0@0000010?ooo`003@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo2036a/H00`000000fMWI0=WIf@0V0=WIf@030000
003/k>`0k>c/0540k>c/1000002N0?ooo`<00000DP3/k>`00`000000fMWI0=WIf@090=WIf@P0oooo
0@0000010?ooo`003@3oool00`000000oooo0?ooo`070?ooo`<00000103oool70<K6aP030000003I
fMT0fMWI02H0fMWI00<000000>c/k03/k>`0D03/k>`200000:@0oooo00<000000>c/k03/k>`0D@3/
k>`00`000000fMWI0=WIf@080=WIf@H0oooo0`0000010?ooo`0000<0oooo00000000000010000006
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool60<K6aP030000003IfMT0
fMWI02H0fMWI00<000000>c/k03/k>`0C`3/k>`200000:L0oooo0P00001B0>c/k0030000003IfMT0
fMWI00L0fMWI203oool100000040oooo000=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool60<K6aP030000003IfMT0fMWI02D0fMWI00<000000>c/k03/k>`0CP3/k>`20000
0:/0oooo0`00001@0>c/k08000001`3IfMT80?ooo`4000000@3oool000d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`040?ooo`@0a/K60P00000W0=WIf@030000003/k>`0k>c/04d0
k>c/0P00002`0?ooo`<00000C`3/k>`00`000000fMWI0=WIf@040=WIf@P0oooo0@0000010?ooo`00
2`3oool3000000T0oooo00<000000?ooo`3oool0103oool30<K6aP030000003IfMT0fMWI02H0fMWI
00<000000>c/k03/k>`0C03/k>`200000;@0oooo00<000000>c/k03/k>`0CP3/k>`00`000000fMWI
0=WIf@030=WIf@P0oooo0@0000010?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo0P36a/H00`000000fMWI0=WIf@0V0=WIf@030000003/k>`0k>c/04/0k>c/0P00
002g0?ooo`800000C`3/k>`00`000000fMWI0=WIf@020=WIf@P0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`80a/K600<000000=WIf@3IfMT0903IfMT2000004`0k>c/0P00002k
0?ooo`<00000C@3/k>`010000000fMWI0=WIf@3IfMT80?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0103oool00`36a/H000000=WIf@0U0=WIf@030000003/k>`0k>c/04X0k>c/0P000030
0?ooo`<00000B`3/k>`00`000000fMWI0=WIf@080?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0103oool00`000000fMWI0=WIf@0U0=WIf@030000003/k>`0k>c/04P0k>c/0P0000340?oo
o`030000003/k>`0k>c/04X0k>c/00<000000=WIf@3oool01`3oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo9`3IfMT00`000000k>c/0>c/k0180>c/k0030000003oool0oooo0<D0
oooo0P00001:0>c/k0030000003IfMT0oooo00L0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`040?ooobD0fMWI0P0000190>c/k0800000bP3oool3000004P0k>c/00<000000?ooo`3oool0
1P3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo903IfMT00`000000k>c/0>c/
k0170>c/k0800000c`3oool2000004L0k>c/00<000000?ooo`3oool01@3oool100000040oooo000G
0?ooo`030000003oool0oooo00@0oooo903IfMT00`000000k>c/0>c/k0150>c/k0800000d`3oool0
0`000000k>c/0>c/k0140>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
ob<0fMWI00<000000>c/k03/k>`0A@3/k>`00`000000oooo0?ooo`3D0?ooo`800000A03/k>`80?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolQ0=WIf@800000AP3/k>`200000=T0
oooo0P0000120>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooob00fMWI
00<000000>c/k03/k>`0A03/k>`200000=d0oooo0P0000100>c/k0P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?oooal0fMWI00<000000>c/k03/k>`0A03/k>`00`000000oooo0?oo
o`3O0?ooo`030000003/k>`0k>c/03d0k>c/203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo7P3IfMT00`000000k>c/0>c/k0130>c/k0800000h`3oool00`000000k>c/0>c/k00l
0>c/k0P0oooo0@0000010?ooo`005`3oool2000000D0oooo7@3IfMT00`000000k>c/0>c/k0130>c/
k0030000003oool0oooo0>@0oooo0P00000l0>c/k0L0oooo0P0000010?ooo`005`3oool00`000000
oooo0?ooo`040?oooa`0fMWI00<000000>c/k03/k>`0@P3/k>`200000>T0oooo0P00000j0>c/k0P0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa/0fMWI00<000000>c/k03/k>`0
@@3/k>`200000>d0oooo00<000000>c/k03/k>`0=`3/k>`80?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103ooolJ0=WIf@030000003/k>`0k>c/0440k>c/00<000000?ooo`3oool0kP3o
ool2000003L0k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo6@3IfMT0
0`000000k>c/0>c/k0110>c/k0030000003oool0oooo0?40oooo00<000000>c/k03/k>`0=03/k>`8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolH0=WIf@030000003/k>`0k>c/
0400k>c/0P00003e0?ooo`800000=03/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0103ooolG0=WIf@030000003/k>`0k>c/0400k>c/00<000000?ooo`3oool0m`3oool00`000000
k>c/0>c/k00a0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooaH0fMWI
00<000000>c/k03/k>`0@03/k>`00`000000oooo0?ooo`3i0?ooo`030000003/k>`0k>c/0300k>c/
203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo5P3IfMT00`000000k>c/0>c/
k00n0>c/k0800000o@3oool200000300k>c/203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo5@3IfMT00`000000k>c/0>c/k00m0>c/k0800000o`3oool20?ooo`800000;P3/k>`8
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103ooolD0=WIf@030000003/k>`0k>c/
03d0k>c/00<000000?ooo`3oool0o`3oool40?ooo`030000003/k>`0k>c/02/0k>c/203oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo4`3IfMT00`000000k>c/0>c/k00m0>c/k003
0000003oool0oooo0?l0oooo1P3oool2000002/0k>c/203oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo4P3IfMT00`000000k>c/0>c/k00l0>c/k0800000o`3oool;0?ooo`030000
003/k>`0k>c/02P0k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo4@3I
fMT00`000000k>c/0>c/k00l0>c/k0030000003oool0oooo0?l0oooo303oool00`000000k>c/0>c/
k00W0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa00fMWI00<00000
0>c/k03/k>`0?03/k>`00`000000oooo0?ooo`3o0?ooo`h0oooo0P00000W0>c/k0P0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`l0fMWI00<000000>c/k03/k>`0>`3/k>`20000
0?l0oooo4`3oool00`000000k>c/0>c/k00T0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`040?ooo`h0fMWI00<000000>c/k03/k>`0>`3/k>`00`000000oooo0?ooo`3o0?oooa@0
oooo0P00000T0>c/k0P0oooo0@0000010?ooo`005`3oool2000000D0oooo3@3IfMT00`000000k>c/
0>c/k00k0>c/k0030000003oool0oooo0?l0oooo5`3oool00`000000k>c/0>c/k00Q0>c/k0L0oooo
0P0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo``0fMWI00<000000>c/k03/k>`0>P3/
k>`200000?l0oooo6`3oool00`000000k>c/0>c/k00P0>c/k0P0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`/0fMWI00<000000>c/k03/k>`0>P3/k>`00`000000oooo0?ooo`3o
0?oooa`0oooo00<000000>c/k03/k>`07`3/k>`80?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0103oool;0=WIf@030000003/k>`0k>c/03P0k>c/0P00003o0?ooob00oooo0P00000O0>c/
k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`X0fMWI00<000000>c/k03/
k>`0>03/k>`00`000000oooo0?ooo`3o0?ooob80oooo00<000000>c/k03/k>`0703/k>`80?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0103oool90=WIf@030000003/k>`0k>c/03P0k>c/
00<000000?ooo`3oool0o`3ooolT0?ooo`030000003/k>`0k>c/01/0k>c/203oool100000040oooo
000G0?ooo`030000003oool0oooo00@0oooo203IfMT00`000000k>c/0>c/k00h0>c/k0030000003o
ool0oooo0?l0oooo9P3oool2000001/0k>c/203oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo1`3IfMT00`000000k>c/0>c/k00h0>c/k0030000003oool0oooo0?l0oooo:@3oool0
0`000000k>c/0>c/k00H0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oo
o`H0fMWI00<000000>c/k03/k>`0>03/k>`00`000000oooo0?ooo`3o0?ooob/0oooo00<000000>c/
k03/k>`05`3/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool50=WIf@03
0000003/k>`0k>c/03P0k>c/00<000000?ooo`3oool0o`3oool]0?ooo`030000003/k>`0k>c/01H0
k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo103IfMT00`000000k>c/
0>c/k00h0>c/k0030000003oool0oooo0?l0oooo;`3oool00`000000k>c/0>c/k00E0>c/k0P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`<0fMWI00<000000>c/k03/k>`0=`3/
k>`200000?l0oooo<`3oool00`000000k>c/0>c/k00D0>c/k0P0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`<0fMWI00<000000>c/k03/k>`0=P3/k>`00`000000oooo0?ooo`3o
0?oooc@0oooo00<000000>c/k03/k>`04`3/k>`80?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0103oool20=WIf@030000003/k>`0k>c/03H0k>c/00<000000?ooo`3oool0o`3ooolf0?oo
o`8000004`3/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool00`3IfMT0
00000>c/k00f0>c/k0800000o`3ooolk0?ooo`030000003/k>`0k>c/0100k>c/203oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo00<000000>c/k03/k>`0=@3/k>`00`000000oooo
0?ooo`3o0?oooc`0oooo00<000000>c/k03/k>`03`3/k>`80?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0103ooolg0>c/k0030000003oool0oooo05L0oooo1@3o003Q0?ooo`030000003/
k>`0k>c/00h0k>c/203oool100000040oooo000G0?ooo`8000001@3ooolf0>c/k0030000003oool0
oooo05L0oooo1`3o003Q0?ooo`8000003P3/k>`70?ooo`8000000@3oool001L0oooo00<000000?oo
o`3oool0103ooole0>c/k0030000003oool0oooo05L0oooo0`3o0002003o00@0o`00hP3oool00`00
0000k>c/0>c/k00;0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooc@0
k>c/00<000000?ooo`3oool0E`3oool20?l000H00?l00`3o003Q0?ooo`030000003/k>`0k>c/00/0
k>c/203oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo<`3/k>`00`000000oooo
0?ooo`1H0?ooo`80o`001P00o`030?l00>80oooo00<000000>c/k03/k>`02P3/k>`80?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103ooola0>c/k0800000FP3oool20?l000P00?l00`3o
003R0?ooo`8000002P3/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool`
0>c/k0030000003oool0oooo05X0oooo0P3o0008003o00<0o`00i03oool00`000000k>c/0>c/k007
0>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooobl0k>c/00<000000?oo
o`3oool0F`3oool30?l000H00?l0103o003U0?ooo`030000003/k>`0k>c/00H0k>c/203oool10000
0040oooo000G0?ooo`030000003oool0oooo00@0oooo;P3/k>`00`000000oooo0?ooo`1M0?ooo`80
o`001P00o`030?l00>L0oooo00<000000>c/k03/k>`01@3/k>`80?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103oool]0>c/k0030000003oool0oooo05h0oooo103o0002003o00D0o`00
j03oool00`000000k>c/0>c/k0040>c/k0P0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`040?ooob`0k>c/00<000000?ooo`3oool0H03oool90?l00>X0oooo00<000000>c/k03/k>`00`3/
k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool[0>c/k0030000003oool0
oooo0680oooo1`3o000_0?ooo`D0o`00^03oool00`000000k>c/0>c/k0020>c/k0P0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`040?ooobX0k>c/00<000000?ooo`3oool0I03oool50?l0
02l0oooo1`3o002h0?ooo`8000000P3/k>`80?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0103ooolY0>c/k0030000003oool0oooo09P0oooo2@3o002i0?ooo`030000003/k>`0oooo00L0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooobP0k>c/00<000000?ooo`3oool0
V03oool40?l000800?l01@3o002h0?ooo`030000003/k>`0oooo00L0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`040?ooobL0k>c/00<000000?ooo`3oool0V@3oool20?l000H00?l00`3o
002i0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`04
0?ooobH0k>c/00<000000?ooo`3oool0V@3oool30?l000H00?l0103o002i0?ooo`030000003oool0
oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooob@0k>c/0P00002L0?oo
o`80o`002000o`030?l00<40oooo0@0000010?ooo`005`3oool2000000D0oooo8`3/k>`00`000000
oooo0?ooo`2L0?ooo`80o`002000o`030?l00<00oooo0P0000010?ooo`005`3oool00`000000oooo
0?ooo`040?ooob<0k>c/00<000000?ooo`3oool0W@3oool20?l000H00?l00`3o00320?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103ooolR0>c/k0030000003oool0oooo09h0oooo0P3o
0006003o00<0o`00`P3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo803/k>`2
00000:80oooo0`3o0002003o00@0o`00``3oool100000040oooo000G0?ooo`030000003oool0oooo
00@0oooo7`3/k>`00`000000oooo0?ooo`2S0?ooo`L0o`00a03oool100000040oooo000G0?ooo`03
0000003oool0oooo00@0oooo7`3/k>`00`000000oooo0?ooo`2T0?ooo`D0o`00a@3oool100000040
oooo000G0?ooo`030000003oool0oooo00@0oooo7P3/k>`00`000000oooo0?ooo`3o0?ooog00oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa`0k>c/0P00002n0?ooo`@00?oo8P3o
ool50?l008T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?oooa/0k>c/00<00000
0?ooo`3oool0U@3oool4003oob80oooo2P00oolN0?ooo`L0o`00R03oool100000040oooo000G0?oo
o`030000003oool0oooo00@0oooo6`3/k>`00`000000oooo0?ooo`2B0?ooo`X00?oo303oool4003o
o`h0oooo3000oolL0?ooo`T0o`00Q`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0
oooo6P3/k>`00`000000oooo0?ooo`2B0?ooo`<00?oo1@3o0004003oo`P0oooo2P00ool:0?ooo`D0
0?oo1@3o0004003ooaX0oooo103o0002003o00D0o`00QP3oool100000040oooo000G0?ooo`030000
003oool0oooo00@0oooo603/k>`2000009@0oooo0`00ool70?l000@00?oo1P3oool3003oo`D0o`00
1000ool80?ooo`D00?oo1`3o0004003ooaD0oooo1000ool20?l000H00?l00`3o00260?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0103ooolG0>c/k0030000003oool0oooo09<0oooo0`00
ool90?l000@00?oo103oool3003oo`L0o`001000ool70?ooo`@00?oo0`3o0002003o00@0o`000`00
oolB0?ooo`H00?oo0`3o0006003o00@0o`00Q@3oool100000040oooo000G0?ooo`030000003oool0
oooo00@0oooo5`3/k>`00`000000oooo0?ooo`2C0?ooo`800?oo1@3o0002003o00@0o`000`00ool3
0?ooo`<00?oo2@3o0004003oo`H0oooo0`00ool20?l000800?l00P000?l2003o00<0o`000P00oolA
0?ooo`<00?oo1P3o0008003o00<0o`00Q@3oool100000040oooo000;0?ooo`@00000203oool00`00
0000oooo0?ooo`040?oooaH0k>c/00<000000?ooo`3oool0U03oool2003oo`<0o`000P00o`020000
o`800?l00P3o0003003oo`<0oooo0P00ool50?l000800?l0103o0003003oo`D0oooo1000ool20?l0
0003003o00000?l0003o0080003o00@00?l00?l0003o0000o`000`00ool?0?ooo`<00?oo1`3o0008
003o00<0o`00Q@3oool100000040oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?oooaD0k>c/00<000000?ooo`3oool0U03oool2003o
o`@0o`0000<00?l00000o`000?l00P000?l01000o`00o`000?l0003o0003003oo`80oooo0P00ool3
0?l000800?l00P000?l2003o0080o`000`00ool50?ooo`<00?oo0P3o00000`00o`00003o0000o`04
0000o`04003o003o0000o`000?l000800?oo3P3oool3003oo`@0o`000P00o`030?l000H00?l00`3o
00260?ooo`4000000@3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo503/k>`00`000000oooo0?ooo`2E0?ooo`800?oo0`3o0000
0`00o`00003o0000o`0:0000o`030?ooo`00ool00?oo00@0o`0000<00?l00000o`000?l00P000?l0
1000o`00o`000?l0003o0003003oo`80oooo40000?l20?l000800?oo3P3oool2003oo`<0o`000P00
o`020000o`800?l000<0o`00003o0000o`001000o`030?l008H0oooo0@0000010?ooo`002P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103ooolC
0>c/k0030000003oool0oooo09H0oooo0P00ool30?l000L0003o00<00?l00?l0003o00000`00oolE
0000o`80oooo0`00ool30?l00003003o00000?l0003o0080003o00<00?l00?l0003o00002P000?l8
0?ooo`800?oo0`3o00000`00o`00003o0000o`020000o`04003o003o0000o`000?l000800?l0103o
00060?ooo`@00?ooO@3oool100000040oooo000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool3000000@0oooo4P3/k>`00`000000oooo0?ooo`2G0?ooo`800?oo0`000?l0
0`3o00000?l00000o`030000o`03003o003o0000o`0000@00?oo00<0oooo003oo`00ool00`3o0000
0`00o`00003o0000o`040000o`03003o003o0000o`0000<00?oo1@3oool3003oo`80o`000P00o`02
0000o`800?l00`3o0002003oo`L0oooo2P000?l20?l00003003o00000?l0003o00@0003o00<00?l0
0?l0003o00001@3o00040?ooo`X00?ooN03oool300000040oooo000:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oooa40k>c/00<000000?oo
o`3oool0U`3oool30000o`04003oo`3o0000o`000?l000800?l00P000?l2003o0080o`000`00ool2
0?ooo`<00?oo0`3o00000`00o`00003o0000o`020000o`03003o003o0000o`0000@00?oo1@3oool3
003oo`@0o`000P00o`050?l000800?oo3P3oool2003oo`030?l000000?l0003o00L0003o00<00?l0
0?l0003o0000103o00040?ooo``00?ooN@3oool100000040oooo000:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oooa00k>c/00<000000?oo
o`3oool0U@3oool30000o`80oooo0`00ool40?l000800?l00`3o0004003oo`<0oooo0P00ool30?l0
00800?l00P000?l2003o0080o`000`00ool60?ooo`@00?oo2@3o0003003oo`h0oooo0P00ool40?l0
0003003o00000?l0003o00@0003o0P3o0003003oo`@0oooo1000ool50?l000D00?ooN03oool10000
0040oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`l0k>c/00<000000?ooo`3oool0T`3oool30000o`D0oooo1000ool70?l000D0
0?oo0`3oool3003oo`@0o`000P00o`030?l000@00?oo1`3oool4003oo`L0o`000`00ool?0?ooo`<0
0?oo0`3o0002003o0080003o0P00o`00103o0000003o0000o`000?l2003oo`<0oooo1000ool70?l0
00D00?ooM`3oool100000040oooo000;0?ooo`@00000203oool00`000000oooo0?ooo`040?ooo`h0
k>c/00<000000?ooo`3oool0N@3oool4003ooa@0oooo0`000?l90?ooo`@00?oo1@3o0005003oo`@0
oooo1000ool70?l000D00?oo203oool4003oo`D0o`000`00oolA0?ooo`800?oo1@3o0002003o00@0
o`000P00ool30000o`80oooo0`00ool40?l000800?l00`3o0004003oogL0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`040?ooo`d0k>c/00<000000?ooo`3oool0M`3oool:003oo`l0oooo
0P000?l=0?ooo``00?oo1P3oool4003oo`D0o`001@00ool:0?ooo`X00?oo4P3oool3003oo`T0o`00
1000ool20?ooo`<0003o00@00?oo0?l0003o0000o`000P00o`020000o`800?l00P3o0003003oogL0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo``0k>c/00<000000?ooo`3oool0
M`3oool4003oo`D0o`000`00ool;0?ooo`<0003o403oool:003oo`P0oooo3000ool>0?ooo`@00?oo
5@3oool4003oo`L0o`001@00ool30?ooo`800?oo0`000?l00`3o00000?l00000o`030000o`03003o
003o0000o`0000@00?ooMP3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo2`3/
k>`00`000000oooo0?ooo`1g0?ooo`@00?oo1`3o0003003oo`L0oooo0`000?lF0?ooo`@00?oo303o
ool:003oobT0oooo1000ool50?l000D00?oo103oool2003oo`<0o`001`000?l00`00o`00o`000?l0
0003003oogH0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`X0k>c/00<00000
0?ooo`3oool0M`3oool4003oo`T0o`000`00ool30?ooo`<0003o;03oool4003oobd0oooo3000ool5
0?ooo`800?oo0`3o00000`00o`00003o0000o`040000o`03003o003o0000o`0000<00?ooMP3oool1
00000040oooo000G0?ooo`030000003oool0oooo00@0oooo2@3/k>`00`000000oooo0?ooo`1h0?oo
o`<00?oo103o0002003o00D0o`000P00ool30000of40oooo2P00ool60?ooo`800?oo103o00000`00
o`00003o0000o`050000o`040?l00000ool00?oo003oogH0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`040?ooo`T0k>c/00<000000?ooo`3oool0N03oool3003oo`80o`000P00o`020000
o`800?l00P3o00030000ofL0oooo1000ool:0?ooo`800?oo0`3o0002003o0080003o0P00o`020?l0
00<0003oM`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo203/k>`00`000000
oooo0?ooo`1h0?ooo`<00?oo0`3o00000`00o`00003o0000o`050000o`80o`000P00oomd0?ooo`80
0?oo1@3o0002003o00@0o`000`00ool30000oaD0oooo1000oomK0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0103oool70>c/k0030000003oool0oooo07T0oooo0`00ool20?l00003003o
00000?l0003o00@0003o00@00?l00?l0003o0000o`000P00oomd0?ooo`<00?oo2@3o0004003oo`<0
oooo0`000?l?0?ooo`X00?ooF03oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
1P3/k>`00`000000oooo0?ooo`1j0?ooo`<00?oo0P3o00000`00o`00003o0000o`040000o`04003o
003o0000o`000?l000800?ooM@3oool3003oo`L0o`001000ool70?ooo`<0003o2`3oool3003oo`D0
o`001000oomG0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool50>c/k0030000
003oool0oooo07/0oooo1000ool00`3o0000003o0000o`040000o`04003o003o0000o`000?l000<0
0?ooMP3oool3003oo`D0o`001000ool;0?ooo`<0003o1`3oool3003oo`L0o`001000oomF0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0103oool40>c/k0030000003oool0oooo07d0oooo
0P00ool20000o`030?l00000o`000?l00080003o0P00o`030?l000800?ooN03oool:003oo`l0oooo
0`000?l30?ooo`<00?oo2@3o0004003ooeD0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`040?ooo`<0k>c/00<000000?ooo`3oool0K03oool4003oo`h0oooo0P000?l2003oo`<0o`000P00
o`040?l000<00?ooN`3oool4003ooaD0oooo0`000?l2003oo`D0o`000P00o`040?l000<00?ooE@3o
ool100000040oooo000G0?ooo`8000001@3oool20>c/k0030000003oool0oooo06X0oooo2P00ool9
0?ooo`80003o1@00ool70?l000@00?ooU`3oool30000o`80o`000P00o`020000o`800?l00P3o0003
003ooe@0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`80k>c/00<000000?oo
o`3oool0J@3oool<003oo`L0oooo00@0003o0?ooo`3oool0oooo1@00ool50?l000@00?ooU`3oool2
003oo`80o`001`000?l01000o`00o`000?l0003o0003003ooe@0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`040?ooo`030>c/k0000000oooo06X0oooo1@00ool50?l000@00?oo103oool2
0000o`D0oooo3000oonH0?ooo`800?oo0`3o00000`00o`00003o0000o`040000o`03003o003o0000
o`0000H00?ooD@3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0J@3oool5003oo`L0o`001000ool00`3oool0003o0000o`080?ooo`X00?ooV@3oool2003o
o`<0o`0000<00?l00000o`000?l010000?l00`00o`00o`000?l00009003oodh0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`1`0?ooo`@00?oo103o0002003o00<0o`000P00ool20000o`d0
oooo1000oonL0?ooo`<00?oo0`3o00000`00o`00003o0000o`030000o`80o`002`00oom=0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0H`3oool4003oo`T0oooo0`00ool30?l000800?l0
0P000?l2003o00040?l000000?l0003o003oojl0oooo0P00ool30?l000800?l00P000?l2003o0003
0000o`3o00000?oo00800?oo1@3o0004003ood`0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`1P0?ooo`X00?oo1@3oool4003oo`<0o`0000<00?l00000o`000?l010000?l0103o00000?oo
003oo`00oon^0?ooo`<00?oo103o0002003o00<0o`0000<0003o003oo`00ool01`3o0004003ood/0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1O0?ooo``00?oo103oool3003oo`<0o`00
00<00?l00000o`000?l010000?l00`00o`00o`000?l00002003oojh0oooo1000ool70?l000800?oo
00@0003o0?l0003o0000o`000P00o`040?l000<00?ooB`3oool100000040oooo000G0?ooo`030000
003oool0oooo05h0oooo1@00ool50?l000@00?oo0`3oool3003oo`<0o`0000<00?l00000o`000?l0
10000?l00`00o`00o`000?l00002003oojl0oooo1000ool50?l000<00?oo00@0o`000000o`00o`00
0?l00P000?l2003o00<0o`000P00oom;0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
G@3oool5003oo`L0o`001000ool20?ooo`<00?oo0P3o00070000o`04003o003o0000o`000?l00080
0?oo/03oool;003oo`80o`001@000?l01000o`00o`000?l0003o0003003oodX0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`1M0?ooo`@00?oo0`3o0002003o00@0o`000`00ool30?ooo`04
003oo`000?l0003o0000o`80o`000P00o`020000o`800?l00P3o0002003ook80oooo2@00ool20?l0
0003003o00000?l0003o00@0003o00@00?l00?l0003o0000o`000P00oom:0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0G@3oool3003oo`80o`000`00o`020000o`04003o003o0000o`00
0?l000800?oo10000?l2003oo`D0o`000P00o`040?l000800?oo]@3oool6003oo`80o`0000<00?l0
0000o`000?l010000?l01000o`00o`000?l0003o0002003oo`D0oooo1000oom10?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0G03oool4003oo`80o`000P00o`040000o`80o`000`000?l0
0`00ool0oooo0?ooo`04003oo`T0o`000`00oonh0?ooo`<00?oo0`3o00000`00o`00003o0000o`03
0000o`@0o`000P00ool20?ooo`X00?oo?P3oool100000040oooo000G0?ooo`030000003oool0oooo
05`0oooo0`00ool20?l000800?l01`000?l20?l000800?oo0`3oool4003oo`L0o`000`00oonj0?oo
o`<00?oo0P3o0002003o0080003o0P00o`020000o`030?l00000ool00?oo0080oooo3000oolm0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0G03oool3003oo`80o`000P00o`060000o`<0
o`000P00ool40?ooo`@00?oo1@3o0003003ook/0oooo0`00ool40?l000800?l0103o00020000o`03
003oo`3oool00?oo00<00?oo1@3o0005003ooc`0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`1L0?ooo`<00?oo0`3o0002003o00@0003o103o0002003oo`D0oooo2P00oonl0?ooo`@00?oo
2@3o0002003oo`80003o0`00ool70?l000D00?oo>`3oool100000040oooo000G0?ooo`030000003o
ool0oooo05d0oooo0`00ool20?l00003003o00000?l00?l00080003o00@00?l00?l0003o0000o`00
0P00ool90?ooo`@00?oo`03oool4003oo`L0o`000`00ool0103oool00?oo0000o`000?l40?l00080
0?l00`3o0004003ooc/0oooo0@0000010?ooo`005`3oool2000005h0oooo0`00ool0103o0000003o
0000o`3o0002003o00D0o`000P00ooo>0?ooo`@00?oo1@3o0003003oo`80oooo0P00ool00`3o0000
003o0000o`02003o0080003o0P00o`020?l000<00?oo>P3oool200000040oooo000G0?ooo`030000
003oool0oooo05d0oooo0`00ool00`000?l0o`000?l000070?l000<00?ooc`3oool:003oo`80oooo
0`00ool30?l000D0003o00<00?l00?l0003o00001000oolj0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0GP3oool01000ool0003o003oo`00ool70?l000<00?ood`3oool4003oo`D0oooo
0P00ool30?l00003003o00000?l0003o00@0003o00<00?l00?l0003o00000`00oolj0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0GP3oool00`000?l00?oo003oo`02003oo`D0o`000`00
oooM0?ooo`800?oo0`3o00000`00o`00003o0000o`040000o`03003o003o0000o`0000<00?oo>P3o
ool100000040oooo000G0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool02P00oooN
0?ooo`800?oo103o00000`00o`00003o0000o`030000o`<0o`000`00oolj0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0F`3oool20000o`H0oooo1000oooR0?ooo`800?oo0`3o0002003o
0080003o0P00o`000`000?l0o`00003oo`02003ooc/0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`1J0?ooo`030000o`3oool0oooo0>`0oooo0P00ool50?l000800?l00`3o00020000o`80
0?oo>`3oool100000040oooo000G0?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3oool0
k@3oool3003oo`T0o`000P00ool00`000?l00?oo0?ooo`0j0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0F03oool00`000?l0oooo0?ooo`3_0?ooo`<00?oo1`3o0004003oo`80003o2@3o
ool4003oobd0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0
oooo0?40oooo0`00ool50?l000@00?oo0`3oool00`000?l0oooo0?ooo`030?ooo`X00?oo:P3oool1
00000040oooo000G0?ooo`030000003oool0oooo05D0oooo0P000?oe0?ooo`X00?oo1@3oool20000
o`80oooo0`00ool50?l000@00?oo:@3oool100000040oooo000G0?ooo`030000003oool0oooo05@0
oooo00<0003o0?ooo`3oool0n03oool4003oo`X0oooo00@0003o003oo`00ool00?oo1`3o0004003o
obP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`110?ooo`D0o`003@3oool00`000?l0
oooo0?ooo`3o0?ooo`P0oooo00<00?oo0000o`00ool02@3o0004003oobL0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`100?ooo`L0o`002`3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo
0P00ool20000o`<0o`000P00o`040?l00003003oo`3o0000o`0000<0o`00903oool100000040oooo
000G0?ooo`030000003oool0oooo03l0oooo2@3o00090?ooo`030000o`3oool0oooo0?l0oooo2P3o
ool2003oo`80o`0000<0003o003o0000o`000P000?l2003o00T0o`008`3oool100000040oooo000G
0?ooo`030000003oool0oooo03h0oooo1@3o0002003o00@0o`001P3oool20000ool0oooo303oool2
003oo`@0o`001@000?l00`00o`00o`000?l000020?l000800?l0103o000R0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0?P3oool30?l000H00?l00P3o00050?ooo`030000o`3oool0oooo
0?l0oooo303oool2003oo`<0o`0000<00?l00000o`000?l010000?l00`00o`00o`00003o0005003o
00<0o`008@3oool100000040oooo000G0?ooo`800000?P3oool40?l000H00?l00`3o00030?ooo`03
0000o`3oool0oooo0?l0oooo3@3oool2003oo`<0o`0000<00?l00000o`000?l010000?l00`00o`00
o`00003o0005003o00<0o`00803oool200000040oooo000G0?ooo`030000003oool0oooo03d0oooo
0`3o0008003o0080o`000P3oool00`000?l0oooo0?ooo`3o0?ooo`h0oooo0`00ool30?l00003003o
00000?l0003o0080003o00<00?l00?l00000o`001`00o`030?l00003003oo`3oool0oooo01d0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0m0?ooo`<0o`002000o`020?l000030?ooo`00
0?l0oooo0?l0oooo4@3oool2003oo`<0o`000P00o`020000o`03003o00000?l0003o00P00?l00`3o
0002003ooah0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0n0?ooo`<0o`001P00o`02
0?l00080003oo`3ooolC0?ooo`<00?oo103o0002003o00<0o`0000<0003o003o0000o`001000o`04
0?l000<00?oo7@3oool100000040oooo000G0?ooo`030000003oool0oooo03h0oooo0`3o0006003o
00030?l000000?l0oooo0?l0oooo503oool4003oo`T0o`0000<0003o003o0000o`000`00o`040?l0
00@00?oo703oool100000040oooo000G0?ooo`030000003oool0oooo03l0oooo103o0002003o0080
o`0000<0003o0?ooo`3oool0o`3ooolE0?ooo`@00?oo1@3o00001@00ool0o`000?l0003o0000003o
00800?l000<0o`00003o0000o`00103o0003003ooa`0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`100?ooo`H0o`0000<0003o0?ooo`3oool0o`3ooolG0?ooo`X00?oo0`3o00000`000?l0
0?l0003o00020000o`800?l00`3o0002003ooa`0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`110?ooo`@0o`0000<0003o0?ooo`3oool0o`3ooolI0?ooo`X00?oo0`3o00050000o`04003o
003o0000o`000?l000<00?oo6`3oool100000040oooo000G0?ooo`030000003oool0oooo04<0oooo
0P000?oo0?oooal0oooo1`00ool20?l00003003o00000?l0003o00@0003o00@00?l00?l0003o0000
o`000P00oolK0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo
0?ooo`3o0?ooob<0oooo0`00ool20?l00003003o00000?l0003o00@0003o00@00?l00?l0003o0000
o`000P00oolK0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo
0?ooo`3o0?ooob@0oooo0`00ool30?l00003003o00000?l0003o0080003o00<00?l00?l0003o0000
0P3o0002003ooa/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0c0?ooo`@00?oo2@3o
ool00`000?l0oooo0?ooo`3o0?ooobH0oooo0`00ool20?l000800?l00P000?l00`00o`00003o0000
o`020?l000800?oo703oool100000040oooo000G0?ooo`030000003oool0oooo0300oooo2P00ool5
0?ooo`030000o`3oool0oooo0?l0oooo9`3oool3003oo`@0o`000P00o`030?l000040000o`3o0000
0?oo003ooa`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0_0?ooo``00?oo0P3oool2
0000ool0oooo:P3oool4003oo`T0o`0000<0003o003oo`00ool0703oool100000040oooo000G0?oo
o`030000003oool0oooo02h0oooo1@00ool50?l000@00?oo00<0003o0?ooo`3oool0o`3oool[0?oo
o`@00?oo1`3o0002003oo`030000o`3oool0oooo00D0oooo1000oolB0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0;@3oool5003oo`L0o`000P00ool00`000?l00?oo0?ooo`3o0?ooobd0
oooo1000ool50?l000<00?oo00<0oooo0000o`3oool00P3oool:003oo`l0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0]0?ooo`@00?oo103o0002003o00<0o`0000<0003o003oo`00ool0
o`3oool_0?ooo`X00?oo0`3oool20000o`<00?oo1@3o0004003oo`h0oooo0@0000010?ooo`005`3o
ool2000002h0oooo0`00ool30?l000800?l00P000?l2003o00040000o`3o00000?oo003oool0oooo
<P3oool4003oo`L0oooo00<00?oo0000o`00ool01`3o0004003oo``0oooo0P0000010?ooo`005`3o
ool00`000000oooo0?ooo`0/0?ooo`@00?oo0`3o00000`00o`00003o0000o`030000o`80o`000`00
oooo0?oooc/0oooo0`00ool010000?l0o`000?l0003o0002003o00<0o`001000ool<0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0;03oool3003oo`<0o`0000<00?l00000o`000?l01000
0?l00`00o`00o`000?l00002003oool0oooo>`3oool2003oo`80o`0000<0003o003o0000o`000P00
0?l2003o0080o`000`00ool<0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0;03oool3
003oo`<0o`0000<00?l00000o`000?l010000?l00`00o`00o`000?l00002003oool0oooo>`3oool2
003oo`<0o`001@000?l00`00o`00o`000?l00005003oo`X0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0/0?ooo`<00?oo103o00000`00o`00003o0000o`020000o`04003o003o0000o`00
0?l000800?ooo`3ooolj0?ooo`800?oo0`3o00000`00o`00003o0000o`040000o`04003o003o0000
o`000?l000@00?oo2@3oool100000040oooo000G0?ooo`030000003oool0oooo02d0oooo0`00ool3
0?l000040000o`00o`00003o0000o`800?l00P3o0002003oool0oooo>`3oool2003oo`<0o`0000<0
0?l00000o`000?l010000?l00`00o`00o`000?l000020?l000@00?oo203oool100000040oooo000G
0?ooo`030000003oool0oooo02d0oooo0`00ool20?l000030000o`3o0000o`0000800?l0103o0002
003oool0oooo>`3oool2003oo`@0o`0000<00?l00000o`000?l00P000?l00`00o`00o`000?l00004
0?l000@00?oo1`3oool100000040oooo000G0?ooo`030000003oool0oooo02d0oooo1000ool00`00
0?l0o`000?l000060?l000<00?ooo`3ooolk0?ooo`<00?oo0`3o0002003o0080003o00<00?l00000
o`3o00000P00o`040?l000<00?oo0P0000050?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0;P3oool2003oo`030000o`00ool0o`0000H0o`000`00oooo0?ooocd0oooo0P00ool50?l00080
0?l000<0o`00003o00000?l00P000?l2003o0080o`001000ool400000080oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`030?ooo`@00?oo:03oool010000?l00?oo003oo`00ool50?l000<0
0?ooo`3oooln0?ooo`<00?oo1`3o00000`00o`00003o0000o`020000o`04003o003o0000o`000?l0
00H00?oo100000010?ooo`005`3oool00`000000oooo0?ooo`0:003oob@0oooo00<0003o0?ooo`00
ool02@00oooo0?ooocl0oooo1000ool50?l00003003o00000?l0003o00@0003o00<00?l00?l0003o
00001`00ool300000040oooo000G0?ooo`030000003oool00?oo00/00?oo8P3oool00`000?l0oooo
0?ooo`030?ooo`@00?ooo`3ooom30?ooo`@00?oo103o00000`00o`00003o0000o`040000o`03003o
003o0000o`0000@0o`001000ool200000040oooo000G0?ooo`0300000000ool00?oo00800?oo1@3o
0005003oob00oooo00<0003o0?ooo`3oool0o`3ooom<0?ooo`D00?oo0`3o00000`00o`00003o0000
o`030000o`P0o`001000ool100000040oooo000G0?ooo`@00?oo1`3o0005003ooah0oooo00<0003o
0?ooo`3oool0o`3ooom>0?ooo`@00?oo0`3o0002003o0080003o0P00o`000`000?l0o`000?l00002
003o00@0o`001000ool10?ooo`002P3oool7000000H0oooo0`00ool40?l000800?l00`3o0004003o
oad0oooo00<0003o0?ooo`3oool0o`3ooomA0?ooo`<00?oo103o0002003o00<0o`0000@0003o003o
00000?l0003o0P00o`030?l000<00?oo0@3oool000d0oooo00<000000?ooo`3oool01`3oool2003o
o`<0o`000P00o`020000o`800?l00P3o0003003ooa`0oooo00<0003o0?ooo`3oool0o`3ooomB0?oo
o`@00?oo203o00000`00o`00003o0000o`020000o`800?l00P3o0003003oo`40oooo000=0?ooo`03
0000003oool0oooo00L0oooo0P00ool30?l00003003o00000?l0003o0080003o00<00?l00?l0003o
00001000oolJ0?ooo`030000o`3oool0oooo0?l0ooooE03oool4003oo`H0o`0000<00?l00000o`00
0?l010000?l01000o`00o`000?l0003o0002003oo`40oooo000=0?ooo`030000003oool0oooo00L0
oooo00D00?oo0?l0003o0000o`00003o00060000o`03003o003o0000o`0000<00?oo6@3oool00`00
0?l0oooo0?ooo`3o0?oooeH0oooo1P00ool30?l00003003o00000?l0003o00D0003o00<00?l00?l0
003o00000P00ool10?ooo`003@3oool00`000000oooo0?ooo`070?ooo`05003oo`3o0000o`000?l0
0000o`001P000?l00`00o`00o`000?l00003003ooaT0oooo00<0003o0?ooo`3oool0o`3ooomG0?oo
o`D00?oo103o00000`00o`00003o0000o`040000o`03003o003o0000o`0000800?oo0@3oool000d0
oooo00<000000?ooo`3oool01`3oool00`00ool0o`000?l000020?l00003003o00000?l0003o0080
003o00@00?l00?l0003o0000o`000`00oolH0?ooo`030000o`3oool0oooo0?l0ooooFP3oool01000
00000?oo003oo`00ool30?l000800?l010000?l01000o`00o`000?l0003o0002003oo`40oooo000=
0?ooo`030000003oool0oooo00L0oooo0P00ool30?l000800?l00P000?l2003o0080o`000`00oolH
0?ooo`030000o`3oool0oooo0?l0ooooF`3oool2000000800?oo103o0002003o0080003o0P00o`02
0?l000<00?oo0@3oool000/0oooo0`0000090?ooo`800?oo1@3o00000`000?l00?l00?l000030?l0
00<00?oo5`3oool00`000?l0oooo0?ooo`3o0?oooed0oooo00@00000003oo`00ool00?oo1@3o0002
003o00@0o`000`00ool10?ooo`003@3oool00`000000oooo0?ooo`070?ooo`<00?oo1@3o00001000
0?l0o`000?l0003o0004003oo`/0oooo1000ool70?ooo`030000o`3oool0oooo0?l0ooooGP3oool2
000000<00?oo2@3o0004003oo`40oooo000G0?ooo`0400000000ool00?oo003oo`@0o`0000<0003o
0?l0003o00001000ool90?ooo`X00?oo0`3oool00`000?l0oooo0?ooo`3o0?ooof00oooo0P000003
003oo`L0o`001000ool100000040oooo000G0?ooo`030000003oool00?oo00800?oo0`3o00000`00
0?l0o`00003oo`03003oo`T0oooo3000ool00`3oool0003o0?ooo`3o0?ooof80oooo0`000003003o
o`D0o`001000ool200000040oooo000G0?ooo`030000003oool0oooo00D00?oo00<0003o003oo`00
ool00P00ool90?ooo`D00?oo1@3o0003003oo`030000o`3oool0oooo0?l0ooooH`3oool3000000X0
0?oo0`0000010?ooo`005`3oool00`000000oooo0?ooo`030?ooo`800?oo00<0003o003oo`3oool0
2P3oool5003oo`L0o`0000@00?oo0000o`00ool00?ooo`3ooomU0?ooo`D000001000ool600000040
oooo000G0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool4003oo`<0o`00
0P00o`030?l000040000o`00ool00?oo003oool0ooooI`3oool:00000080oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo0`00ool20?l000<00?l0
0P000?l01000o`00003o0?l0003o0002003oool0ooooJ@3oool6000000@0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo1000ool20?l000800?l0
10000?l30?l000<00?ooo`3ooomb0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`<00?oo0P3o0002003o00H0003o0`3o0002003oool0ooooLP3o
ool100000040oooo000G0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool3
003oo`80o`000P00o`060000o`<0o`000P00oooo0?ooog80oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo0`00ool30?l000800?l010000?l40?l0
00800?ooo`3ooomb0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`090?ooo`<00?oo0P3o00000`00o`00003o003o00020000o`04003o003o0000o`000?l0
00800?ooo`3ooomc0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`090?ooo`<00?oo0P3o000010000?l0o`00003o0000o`050?l000800?ooo`3ooomc0?oo
o`4000000@3oool001L0oooo0P0000080?ooo`030000o`3oool0oooo00P0oooo1000ool00`000?l0
o`000?l000060?l000<00?ooo`3ooomb0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`090?ooo`<00?oo00<0003o0?l0003o00001@3o0003003oool0oooo
M03oool100000040oooo000G0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool02P3o
ool01000ool0003o003oo`00ool50?l000<00?ooZ@3ooolS00000:P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo00<0003o003oo`00ool02000
oonQ0?ooo`T000008`3/k>`9000009l0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool4003ooih0oooo1P00000e
0>c/k0<00000W03oool100000040oooo000G0?ooo`030000003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`2Q0?ooo`@00000?P3/k>`8000009@0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool0WP3oool4000004X0k>c/1000002@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
1`3oool01000ool0003o003oo`00ool50?ooo`030000o`3oool0oooo09T0oooo1P00001B0>c/k0D0
0000R`3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo1000ool00`000?l00?oo
003oo`03003oo`030?ooo`000?l0oooo09T0oooo0P00001M0>c/k0<00000R03oool100000040oooo
000G0?ooo`030000003oool0oooo00<0oooo1000ool00`3o0000003o0?l000020?l000800?oo00<0
003o0?ooo`3oool0U@3oool400000680k>c/100000240?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool00P3oool4003oo`80o`0000<0003o0?l0003o00000P3o00000`000?l00?oo003oo`2B
0?ooo`@00000JP3/k>`400000800oooo0@0000010?ooo`005`3oool010000000oooo0?ooo`3oool4
003oo`<0o`0000<0003o0?l0003o00000P3o000010000?l00?oo003oo`00oon<0?ooo`D00000LP3/
k>`3000007d0oooo0@0000010?ooo`005`3oool010000000oooo0?ooo`3oool3003oo`@0o`0000D0
0?l00000o`3o0000o`000000o`020?l000800?ooRP3oool2000007X0k>c/0P00001k0?ooo`400000
0@3oool001L0oooo00@000000?ooo`3oool0oooo0`00ool20?l000800?l00P000?l00`00o`00003o
0?l000020?l000800?ooR03oool2000007h0k>c/0`00001h0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool00`00ool30?l00003003o00000?l0003o0080003o00<00?l00?l0003o00000P3o
0002003ooh@0oooo0`0000230>c/k0@00000M03oool100000040oooo000G0?ooo`030000003oool0
oooo00<00?oo0P3o00000`00o`00003o0000o`040000o`04003o003o0000o`000?l000800?ooP03o
ool4000008X0k>c/0P00001b0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool00`00ool2
0?l00003003o00000?l0003o00@0003o00@00?l00?l0003o0000o`000P00oooo0?oooh<0oooo0@00
00010?ooo`005`3oool2000000030?ooo`00ool00?oo00800?oo0P3o00000`00o`00003o0000o`02
0000o`04003o003o0000o`000?l000<00?ooo`3ooon20?ooo`8000000@3oool001L0oooo00@00000
0?ooo`3oool0oooo0`00ool20?l000800?l00P000?l2003o00<0o`000P00oooo0?oooh@0oooo0@00
00010?ooo`005`3oool010000000oooo0?ooo`3oool4003oo`<0o`000P00o`040?l000<00?ooo`3o
oon40?ooo`4000000@3oool001L0oooo00@000000?ooo`3oool0oooo1@00ool70?l000@00?ooo`3o
oon40?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool00P3oool5003oo`D0o`001000oolH
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool01@3oool100000040oooo000G0?oo
o`030000003oool0oooo00<0oooo3000ool70?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`005`3oool7000000X00?ooo`00002800000040oooo003o0?oook40oooo003o0?oook40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.37362, -3.50952, 0.00841771, \
0.0174312}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({4.9696177196758636`*^-18, {X\_1 \[Rule] 0.9999999977999193`, 
            X\_2 \[Rule] 0.9999999955638855`}}\), 
        ",", \({"Steps" \[Rule] 22, "Function" \[Rule] 29, 
          "Gradient" \[Rule] 29, "Hessian" \[Rule] 23}\), ",", 
        TagBox[\(\[SkeletonIndicator]  
            ContourGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell["\<\
This shows the steps and evaluations used by the BFGS quasi-Newton \
method.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p3\  = \ 
      FindMinimumPlot[\((1 - X\_1)\)\^2 + 
          100\ \((\(-X\_1\%2\) + X\_2)\)\^2, {{X\_1, \(-1.2`\)}, {X\_2, 
            1.`}}, \ Method \[Rule] QuasiNewton]\)], "Input",
  CellLabel->"In[53]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.541113 0.434902 0.109336 0.672845 [
[.10621 -0.0125 -6 -9 ]
[.10621 -0.0125 6 0 ]
[.32366 -0.0125 -12 -9 ]
[.32366 -0.0125 12 0 ]
[.54111 -0.0125 -3 -9 ]
[.54111 -0.0125 3 0 ]
[.75856 -0.0125 -9 -9 ]
[.75856 -0.0125 9 0 ]
[.97602 -0.0125 -3 -9 ]
[.97602 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10934 -6 -4.5 ]
[-0.0125 .10934 0 4.5 ]
[-0.0125 .24391 -18 -4.5 ]
[-0.0125 .24391 0 4.5 ]
[-0.0125 .37847 -18 -4.5 ]
[-0.0125 .37847 0 4.5 ]
[-0.0125 .51304 -18 -4.5 ]
[-0.0125 .51304 0 4.5 ]
[-0.0125 .64761 -18 -4.5 ]
[-0.0125 .64761 0 4.5 ]
[-0.0125 .78218 -6 -4.5 ]
[-0.0125 .78218 0 4.5 ]
[-0.0125 .91675 -18 -4.5 ]
[-0.0125 .91675 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10621 0 m
.10621 .00625 L
s
[(-1)] .10621 -0.0125 0 1 Mshowa
.32366 0 m
.32366 .00625 L
s
[(-0.5)] .32366 -0.0125 0 1 Mshowa
.54111 0 m
.54111 .00625 L
s
[(0)] .54111 -0.0125 0 1 Mshowa
.75856 0 m
.75856 .00625 L
s
[(0.5)] .75856 -0.0125 0 1 Mshowa
.97602 0 m
.97602 .00625 L
s
[(1)] .97602 -0.0125 0 1 Mshowa
.125 Mabswid
.1497 0 m
.1497 .00375 L
s
.19319 0 m
.19319 .00375 L
s
.23668 0 m
.23668 .00375 L
s
.28017 0 m
.28017 .00375 L
s
.36715 0 m
.36715 .00375 L
s
.41064 0 m
.41064 .00375 L
s
.45413 0 m
.45413 .00375 L
s
.49762 0 m
.49762 .00375 L
s
.5846 0 m
.5846 .00375 L
s
.62809 0 m
.62809 .00375 L
s
.67158 0 m
.67158 .00375 L
s
.71507 0 m
.71507 .00375 L
s
.80205 0 m
.80205 .00375 L
s
.84554 0 m
.84554 .00375 L
s
.88903 0 m
.88903 .00375 L
s
.93253 0 m
.93253 .00375 L
s
.06272 0 m
.06272 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10934 m
.00625 .10934 L
s
[(0)] -0.0125 .10934 1 0 Mshowa
0 .24391 m
.00625 .24391 L
s
[(0.2)] -0.0125 .24391 1 0 Mshowa
0 .37847 m
.00625 .37847 L
s
[(0.4)] -0.0125 .37847 1 0 Mshowa
0 .51304 m
.00625 .51304 L
s
[(0.6)] -0.0125 .51304 1 0 Mshowa
0 .64761 m
.00625 .64761 L
s
[(0.8)] -0.0125 .64761 1 0 Mshowa
0 .78218 m
.00625 .78218 L
s
[(1)] -0.0125 .78218 1 0 Mshowa
0 .91675 m
.00625 .91675 L
s
[(1.2)] -0.0125 .91675 1 0 Mshowa
.125 Mabswid
0 .14298 m
.00375 .14298 L
s
0 .17662 m
.00375 .17662 L
s
0 .21026 m
.00375 .21026 L
s
0 .27755 m
.00375 .27755 L
s
0 .31119 m
.00375 .31119 L
s
0 .34483 m
.00375 .34483 L
s
0 .41212 m
.00375 .41212 L
s
0 .44576 m
.00375 .44576 L
s
0 .4794 m
.00375 .4794 L
s
0 .54669 m
.00375 .54669 L
s
0 .58033 m
.00375 .58033 L
s
0 .61397 m
.00375 .61397 L
s
0 .68125 m
.00375 .68125 L
s
0 .7149 m
.00375 .7149 L
s
0 .74854 m
.00375 .74854 L
s
0 .81582 m
.00375 .81582 L
s
0 .84947 m
.00375 .84947 L
s
0 .88311 m
.00375 .88311 L
s
0 .07569 m
.00375 .07569 L
s
0 .04205 m
.00375 .04205 L
s
0 .00841 m
.00375 .00841 L
s
0 .95039 m
.00375 .95039 L
s
0 .98403 m
.00375 .98403 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10621 .99375 m
.10621 1 L
s
.32366 .99375 m
.32366 1 L
s
.54111 .99375 m
.54111 1 L
s
.75856 .99375 m
.75856 1 L
s
.97602 .99375 m
.97602 1 L
s
.125 Mabswid
.1497 .99625 m
.1497 1 L
s
.19319 .99625 m
.19319 1 L
s
.23668 .99625 m
.23668 1 L
s
.28017 .99625 m
.28017 1 L
s
.36715 .99625 m
.36715 1 L
s
.41064 .99625 m
.41064 1 L
s
.45413 .99625 m
.45413 1 L
s
.49762 .99625 m
.49762 1 L
s
.5846 .99625 m
.5846 1 L
s
.62809 .99625 m
.62809 1 L
s
.67158 .99625 m
.67158 1 L
s
.71507 .99625 m
.71507 1 L
s
.80205 .99625 m
.80205 1 L
s
.84554 .99625 m
.84554 1 L
s
.88903 .99625 m
.88903 1 L
s
.93253 .99625 m
.93253 1 L
s
.06272 .99625 m
.06272 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .10934 m
1 .10934 L
s
.99375 .24391 m
1 .24391 L
s
.99375 .37847 m
1 .37847 L
s
.99375 .51304 m
1 .51304 L
s
.99375 .64761 m
1 .64761 L
s
.99375 .78218 m
1 .78218 L
s
.99375 .91675 m
1 .91675 L
s
.125 Mabswid
.99625 .14298 m
1 .14298 L
s
.99625 .17662 m
1 .17662 L
s
.99625 .21026 m
1 .21026 L
s
.99625 .27755 m
1 .27755 L
s
.99625 .31119 m
1 .31119 L
s
.99625 .34483 m
1 .34483 L
s
.99625 .41212 m
1 .41212 L
s
.99625 .44576 m
1 .44576 L
s
.99625 .4794 m
1 .4794 L
s
.99625 .54669 m
1 .54669 L
s
.99625 .58033 m
1 .58033 L
s
.99625 .61397 m
1 .61397 L
s
.99625 .68125 m
1 .68125 L
s
.99625 .7149 m
1 .7149 L
s
.99625 .74854 m
1 .74854 L
s
.99625 .81582 m
1 .81582 L
s
.99625 .84947 m
1 .84947 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .07569 m
1 .07569 L
s
.99625 .04205 m
1 .04205 L
s
.99625 .00841 m
1 .00841 L
s
.99625 .95039 m
1 .95039 L
s
.99625 .98403 m
1 .98403 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.925 g
.01923 .88973 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85283 L
.03107 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81663 L
.03892 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74628 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71214 L
.06874 .70882 L
.07154 .69911 L
.07436 .68939 L
.07721 .67968 L
.07751 .67869 L
.08006 .66997 L
.08293 .66026 L
.08583 .65054 L
.08722 .64593 L
.08874 .64083 L
.09166 .63112 L
.09462 .62141 L
.09693 .61385 L
.09759 .61169 L
.10057 .60198 L
.10358 .59227 L
.10662 .58256 L
.10664 .58247 L
.10965 .57284 L
.11272 .56313 L
.11583 .55342 L
.11636 .55177 L
.11893 .54371 L
.12207 .53399 L
.12524 .52428 L
.12607 .52176 L
.12842 .51457 L
.13163 .50486 L
.13487 .49514 L
.13578 .49244 L
.13813 .48543 L
.14141 .47572 L
.14473 .46601 L
.14549 .4638 L
.14807 .45629 L
.15144 .44658 L
.15485 .43687 L
.15521 .43585 L
.15827 .42716 L
.16173 .41744 L
.16492 .40859 L
.16523 .40773 L
.16874 .39802 L
.1723 .38831 L
.17463 .38201 L
.17589 .37859 L
.17952 .36888 L
.18318 .35917 L
.18434 .35612 L
.18688 .34946 L
.19062 .33974 L
.19406 .33092 L
.1944 .33003 L
.19822 .32032 L
.20208 .31061 L
.20377 .3064 L
.20598 .30089 L
.20993 .29118 L
.21348 .28257 L
.21393 .28147 L
.21798 .27176 L
.22208 .26204 L
.22319 .25942 L
.22622 .25233 L
.23043 .24262 L
.23291 .23696 L
.23469 .23291 L
.23901 .22319 L
.24262 .21518 L
.24339 .21348 L
.24783 .20377 L
.25233 .19409 L
.25235 .19406 L
.25692 .18434 L
.26158 .17463 L
.26204 .17368 L
.26631 .16492 L
.27113 .15521 L
.27176 .15396 L
.27603 .14549 L
.28102 .13578 L
.28147 .13492 L
.28611 .12607 L
.29118 .11657 L
.2913 .11636 L
.29659 .10664 L
.30089 .0989 L
.302 .09693 L
.30753 .08722 L
.31061 .08191 L
.31319 .07751 L
.31899 .06779 L
.32032 .06561 L
.32495 .05808 L
.33003 .04999 L
.33107 .04837 L
.33736 .03866 L
.33974 .03506 L
.34385 .02894 L
.34946 .02081 L
.35056 .01923 L
.01923 .01923 L
F
0 g
.01923 .88973 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85283 L
.03107 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81663 L
.03892 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74628 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71214 L
.06874 .70882 L
.07154 .69911 L
.07436 .68939 L
.07721 .67968 L
.07751 .67869 L
.08006 .66997 L
.08293 .66026 L
.08583 .65054 L
.08722 .64593 L
.08874 .64083 L
.09166 .63112 L
.09462 .62141 L
.09693 .61385 L
.09759 .61169 L
.10057 .60198 L
.10358 .59227 L
.10662 .58256 L
.10664 .58247 L
.10965 .57284 L
.11272 .56313 L
.11583 .55342 L
.11636 .55177 L
.11893 .54371 L
.12207 .53399 L
.12524 .52428 L
.12607 .52176 L
Mistroke
.12842 .51457 L
.13163 .50486 L
.13487 .49514 L
.13578 .49244 L
.13813 .48543 L
.14141 .47572 L
.14473 .46601 L
.14549 .4638 L
.14807 .45629 L
.15144 .44658 L
.15485 .43687 L
.15521 .43585 L
.15827 .42716 L
.16173 .41744 L
.16492 .40859 L
.16523 .40773 L
.16874 .39802 L
.1723 .38831 L
.17463 .38201 L
.17589 .37859 L
.17952 .36888 L
.18318 .35917 L
.18434 .35612 L
.18688 .34946 L
.19062 .33974 L
.19406 .33092 L
.1944 .33003 L
.19822 .32032 L
.20208 .31061 L
.20377 .3064 L
.20598 .30089 L
.20993 .29118 L
.21348 .28257 L
.21393 .28147 L
.21798 .27176 L
.22208 .26204 L
.22319 .25942 L
.22622 .25233 L
.23043 .24262 L
.23291 .23696 L
.23469 .23291 L
.23901 .22319 L
.24262 .21518 L
.24339 .21348 L
.24783 .20377 L
.25233 .19409 L
.25235 .19406 L
.25692 .18434 L
.26158 .17463 L
.26204 .17368 L
Mistroke
.26631 .16492 L
.27113 .15521 L
.27176 .15396 L
.27603 .14549 L
.28102 .13578 L
.28147 .13492 L
.28611 .12607 L
.29118 .11657 L
.2913 .11636 L
.29659 .10664 L
.30089 .0989 L
.302 .09693 L
.30753 .08722 L
.31061 .08191 L
.31319 .07751 L
.31899 .06779 L
.32032 .06561 L
.32495 .05808 L
.33003 .04999 L
.33107 .04837 L
.33736 .03866 L
.33974 .03506 L
.34385 .02894 L
.34946 .02081 L
.35056 .01923 L
Mfstroke
.85 g
.01923 .74154 m
.02019 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70516 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66945 L
.04118 .66026 L
.04387 .65054 L
.04658 .64083 L
.04837 .63443 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56641 L
.06875 .56313 L
.07159 .55342 L
.07445 .54371 L
.07734 .53399 L
.07751 .53342 L
.08023 .52428 L
.08314 .51457 L
.08608 .50486 L
.08722 .50111 L
.08903 .49514 L
.092 .48543 L
.095 .47572 L
.09693 .46948 L
.09801 .46601 L
.10104 .45629 L
.10409 .44658 L
.10664 .43853 L
.10717 .43687 L
.11026 .42716 L
.11338 .41744 L
.11636 .40825 L
.11652 .40773 L
.11969 .39802 L
.12288 .38831 L
.12607 .37866 L
.12609 .37859 L
.12932 .36888 L
.13259 .35917 L
.13578 .34974 L
.13588 .34946 L
.13919 .33974 L
.14253 .33003 L
.14549 .3215 L
.14591 .32032 L
.1493 .31061 L
.15273 .30089 L
.15521 .29394 L
.15619 .29118 L
.15968 .28147 L
.1632 .27176 L
.16492 .26706 L
.16676 .26204 L
.17035 .25233 L
.17397 .24262 L
.17463 .24086 L
.17763 .23291 L
.18132 .22319 L
.18434 .21534 L
.18506 .21348 L
.18883 .20377 L
.19265 .19406 L
.19406 .19049 L
.1965 .18434 L
.2004 .17463 L
.20377 .16633 L
.20434 .16492 L
.20833 .15521 L
.21237 .14549 L
.21348 .14284 L
.21645 .13578 L
.22059 .12607 L
.22319 .12003 L
.22478 .11636 L
.22903 .10664 L
.23291 .0979 L
.23334 .09693 L
.2377 .08722 L
.24213 .07751 L
.24262 .07644 L
.24662 .06779 L
.25119 .05808 L
.25233 .05567 L
.25582 .04837 L
.26053 .03866 L
.26204 .03557 L
.26532 .02894 L
.27019 .01923 L
.01923 .01923 L
F
0 g
.01923 .74154 m
.02019 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70516 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66945 L
.04118 .66026 L
.04387 .65054 L
.04658 .64083 L
.04837 .63443 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56641 L
.06875 .56313 L
.07159 .55342 L
.07445 .54371 L
.07734 .53399 L
.07751 .53342 L
.08023 .52428 L
.08314 .51457 L
.08608 .50486 L
.08722 .50111 L
.08903 .49514 L
.092 .48543 L
.095 .47572 L
.09693 .46948 L
.09801 .46601 L
.10104 .45629 L
.10409 .44658 L
.10664 .43853 L
.10717 .43687 L
.11026 .42716 L
.11338 .41744 L
.11636 .40825 L
.11652 .40773 L
.11969 .39802 L
.12288 .38831 L
.12607 .37866 L
.12609 .37859 L
Mistroke
.12932 .36888 L
.13259 .35917 L
.13578 .34974 L
.13588 .34946 L
.13919 .33974 L
.14253 .33003 L
.14549 .3215 L
.14591 .32032 L
.1493 .31061 L
.15273 .30089 L
.15521 .29394 L
.15619 .29118 L
.15968 .28147 L
.1632 .27176 L
.16492 .26706 L
.16676 .26204 L
.17035 .25233 L
.17397 .24262 L
.17463 .24086 L
.17763 .23291 L
.18132 .22319 L
.18434 .21534 L
.18506 .21348 L
.18883 .20377 L
.19265 .19406 L
.19406 .19049 L
.1965 .18434 L
.2004 .17463 L
.20377 .16633 L
.20434 .16492 L
.20833 .15521 L
.21237 .14549 L
.21348 .14284 L
.21645 .13578 L
.22059 .12607 L
.22319 .12003 L
.22478 .11636 L
.22903 .10664 L
.23291 .0979 L
.23334 .09693 L
.2377 .08722 L
.24213 .07751 L
.24262 .07644 L
.24662 .06779 L
.25119 .05808 L
.25233 .05567 L
.25582 .04837 L
.26053 .03866 L
.26204 .03557 L
.26532 .02894 L
Mistroke
.27019 .01923 L
Mfstroke
.775 g
.01923 .64098 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02707 .61169 L
.02894 .60475 L
.02969 .60198 L
.03233 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56919 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46658 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43373 L
.07947 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40156 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37006 L
.0973 .36888 L
.10034 .35917 L
.1034 .34946 L
.10648 .33974 L
.10664 .33925 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .3091 L
.11904 .30089 L
.12224 .29118 L
.12546 .28147 L
.12607 .27964 L
.1287 .27176 L
.13198 .26204 L
.13528 .25233 L
.13578 .25085 L
.1386 .24262 L
.14195 .23291 L
.14533 .22319 L
.14549 .22274 L
.14874 .21348 L
.15218 .20377 L
.15521 .1953 L
.15565 .19406 L
.15915 .18434 L
.16269 .17463 L
.16492 .16854 L
.16625 .16492 L
.16985 .15521 L
.17349 .14549 L
.17463 .14246 L
.17716 .13578 L
.18087 .12607 L
.18434 .11706 L
.18461 .11636 L
.1884 .10664 L
.19223 .09693 L
.19406 .09233 L
.1961 .08722 L
.20001 .07751 L
.20377 .06827 L
.20397 .06779 L
.20797 .05808 L
.21202 .04837 L
.21348 .0449 L
.21612 .03866 L
.22028 .02894 L
.22319 .0222 L
.22449 .01923 L
.01923 .01923 L
F
0 g
.01923 .64098 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02707 .61169 L
.02894 .60475 L
.02969 .60198 L
.03233 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56919 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46658 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43373 L
.07947 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40156 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37006 L
.0973 .36888 L
.10034 .35917 L
.1034 .34946 L
.10648 .33974 L
.10664 .33925 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .3091 L
.11904 .30089 L
.12224 .29118 L
.12546 .28147 L
.12607 .27964 L
Mistroke
.1287 .27176 L
.13198 .26204 L
.13528 .25233 L
.13578 .25085 L
.1386 .24262 L
.14195 .23291 L
.14533 .22319 L
.14549 .22274 L
.14874 .21348 L
.15218 .20377 L
.15521 .1953 L
.15565 .19406 L
.15915 .18434 L
.16269 .17463 L
.16492 .16854 L
.16625 .16492 L
.16985 .15521 L
.17349 .14549 L
.17463 .14246 L
.17716 .13578 L
.18087 .12607 L
.18434 .11706 L
.18461 .11636 L
.1884 .10664 L
.19223 .09693 L
.19406 .09233 L
.1961 .08722 L
.20001 .07751 L
.20377 .06827 L
.20397 .06779 L
.20797 .05808 L
.21202 .04837 L
.21348 .0449 L
.21612 .03866 L
.22028 .02894 L
.22319 .0222 L
.22449 .01923 L
Mfstroke
.7 g
.01923 .55956 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.02871 .52428 L
.02894 .52341 L
.03135 .51457 L
.034 .50486 L
.03667 .49514 L
.03866 .48793 L
.03935 .48543 L
.04204 .47572 L
.04475 .46601 L
.04748 .45629 L
.04837 .45313 L
.05022 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08142 .33974 L
.08437 .33003 L
.08722 .32068 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28925 L
.09937 .28147 L
.10243 .27176 L
.10551 .26204 L
.10664 .25851 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22843 L
.11807 .22319 L
.12127 .21348 L
.12449 .20377 L
.12607 .19904 L
.12774 .19406 L
.13101 .18434 L
.13431 .17463 L
.13578 .17032 L
.13763 .16492 L
.14098 .15521 L
.14437 .14549 L
.14549 .14227 L
.14777 .13578 L
.15121 .12607 L
.15468 .11636 L
.15521 .1149 L
.15818 .10664 L
.16172 .09693 L
.16492 .08821 L
.16528 .08722 L
.16888 .07751 L
.17252 .06779 L
.17463 .06219 L
.17619 .05808 L
.1799 .04837 L
.18364 .03866 L
.18434 .03685 L
.18743 .02894 L
.19125 .01923 L
.01923 .01923 L
F
0 g
.01923 .55956 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.02871 .52428 L
.02894 .52341 L
.03135 .51457 L
.034 .50486 L
.03667 .49514 L
.03866 .48793 L
.03935 .48543 L
.04204 .47572 L
.04475 .46601 L
.04748 .45629 L
.04837 .45313 L
.05022 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08142 .33974 L
.08437 .33003 L
.08722 .32068 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28925 L
.09937 .28147 L
.10243 .27176 L
.10551 .26204 L
.10664 .25851 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22843 L
.11807 .22319 L
.12127 .21348 L
.12449 .20377 L
.12607 .19904 L
.12774 .19406 L
Mistroke
.13101 .18434 L
.13431 .17463 L
.13578 .17032 L
.13763 .16492 L
.14098 .15521 L
.14437 .14549 L
.14549 .14227 L
.14777 .13578 L
.15121 .12607 L
.15468 .11636 L
.15521 .1149 L
.15818 .10664 L
.16172 .09693 L
.16492 .08821 L
.16528 .08722 L
.16888 .07751 L
.17252 .06779 L
.17463 .06219 L
.17619 .05808 L
.1799 .04837 L
.18364 .03866 L
.18434 .03685 L
.18743 .02894 L
.19125 .01923 L
Mfstroke
.625 g
.01923 .4893 m
.02026 .48543 L
.02286 .47572 L
.02548 .46601 L
.0281 .45629 L
.02894 .45319 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41777 L
.03875 .41744 L
.04144 .40773 L
.04415 .39802 L
.04688 .38831 L
.04837 .38301 L
.04962 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34894 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25075 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21938 L
.09878 .21348 L
.10184 .20377 L
.10492 .19406 L
.10664 .18867 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15865 L
.11748 .15521 L
.12068 .14549 L
.1239 .13578 L
.12607 .1293 L
.12715 .12607 L
.13042 .11636 L
.13372 .10664 L
.13578 .10062 L
.13705 .09693 L
.1404 .08722 L
.14378 .07751 L
.14549 .07262 L
.14719 .06779 L
.15063 .05808 L
.1541 .04837 L
.15521 .04529 L
.1576 .03866 L
.16113 .02894 L
.1647 .01923 L
.01923 .01923 L
F
0 g
.01923 .4893 m
.02026 .48543 L
.02286 .47572 L
.02548 .46601 L
.0281 .45629 L
.02894 .45319 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41777 L
.03875 .41744 L
.04144 .40773 L
.04415 .39802 L
.04688 .38831 L
.04837 .38301 L
.04962 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34894 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25075 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21938 L
.09878 .21348 L
.10184 .20377 L
.10492 .19406 L
.10664 .18867 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15865 L
.11748 .15521 L
.12068 .14549 L
.1239 .13578 L
.12607 .1293 L
.12715 .12607 L
Mistroke
.13042 .11636 L
.13372 .10664 L
.13578 .10062 L
.13705 .09693 L
.1404 .08722 L
.14378 .07751 L
.14549 .07262 L
.14719 .06779 L
.15063 .05808 L
.1541 .04837 L
.15521 .04529 L
.1576 .03866 L
.16113 .02894 L
.1647 .01923 L
Mfstroke
.55 g
.01923 .42656 m
.02167 .41744 L
.02428 .40773 L
.0269 .39802 L
.02894 .3905 L
.02954 .38831 L
.03219 .37859 L
.03485 .36888 L
.03753 .35917 L
.03866 .3551 L
.04022 .34946 L
.04293 .33974 L
.04565 .33003 L
.04837 .32039 L
.04839 .32032 L
.05114 .31061 L
.05391 .30089 L
.05669 .29118 L
.05808 .28634 L
.05949 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25298 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18826 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15692 L
.09747 .15521 L
.10052 .14549 L
.1036 .13578 L
.10664 .12625 L
.1067 .12607 L
.10982 .11636 L
.11297 .10664 L
.11613 .09693 L
.11636 .09626 L
.11933 .08722 L
.12254 .07751 L
.12578 .06779 L
.12607 .06694 L
.12905 .05808 L
.13234 .04837 L
.13566 .03866 L
.13578 .03829 L
.139 .02894 L
.14237 .01923 L
.01923 .01923 L
F
0 g
.01923 .42656 m
.02167 .41744 L
.02428 .40773 L
.0269 .39802 L
.02894 .3905 L
.02954 .38831 L
.03219 .37859 L
.03485 .36888 L
.03753 .35917 L
.03866 .3551 L
.04022 .34946 L
.04293 .33974 L
.04565 .33003 L
.04837 .32039 L
.04839 .32032 L
.05114 .31061 L
.05391 .30089 L
.05669 .29118 L
.05808 .28634 L
.05949 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25298 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18826 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15692 L
.09747 .15521 L
.10052 .14549 L
.1036 .13578 L
.10664 .12625 L
.1067 .12607 L
.10982 .11636 L
.11297 .10664 L
.11613 .09693 L
.11636 .09626 L
.11933 .08722 L
.12254 .07751 L
.12578 .06779 L
.12607 .06694 L
.12905 .05808 L
Mistroke
.13234 .04837 L
.13566 .03866 L
.13578 .03829 L
.139 .02894 L
.14237 .01923 L
Mfstroke
.475 g
.01923 .36936 m
.01936 .36888 L
.02196 .35917 L
.02457 .34946 L
.0272 .33974 L
.02894 .33332 L
.02984 .33003 L
.03249 .32032 L
.03516 .31061 L
.03784 .30089 L
.03866 .29795 L
.04054 .29118 L
.04325 .28147 L
.04597 .27176 L
.04837 .26326 L
.04871 .26204 L
.05147 .25233 L
.05424 .24262 L
.05703 .23291 L
.05808 .22925 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .19591 L
.06834 .19406 L
.07121 .18434 L
.0741 .17463 L
.077 .16492 L
.07751 .16324 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06928 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03931 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
.01923 .01923 L
F
0 g
.01923 .36936 m
.01936 .36888 L
.02196 .35917 L
.02457 .34946 L
.0272 .33974 L
.02894 .33332 L
.02984 .33003 L
.03249 .32032 L
.03516 .31061 L
.03784 .30089 L
.03866 .29795 L
.04054 .29118 L
.04325 .28147 L
.04597 .27176 L
.04837 .26326 L
.04871 .26204 L
.05147 .25233 L
.05424 .24262 L
.05703 .23291 L
.05808 .22925 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .19591 L
.06834 .19406 L
.07121 .18434 L
.0741 .17463 L
.077 .16492 L
.07751 .16324 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06928 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03931 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
s
.4 g
.01923 .31644 m
.02079 .31061 L
.0234 .30089 L
.02602 .29118 L
.02866 .28147 L
.02894 .28042 L
.03131 .27176 L
.03397 .26204 L
.03665 .25233 L
.03866 .24508 L
.03934 .24262 L
.04204 .23291 L
.04476 .22319 L
.0475 .21348 L
.04837 .21041 L
.05025 .20377 L
.05302 .19406 L
.0558 .18434 L
.05808 .17641 L
.0586 .17463 L
.06141 .16492 L
.06424 .15521 L
.06709 .14549 L
.06779 .14309 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08159 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10578 .01923 L
.01923 .01923 L
F
0 g
.01923 .31644 m
.02079 .31061 L
.0234 .30089 L
.02602 .29118 L
.02866 .28147 L
.02894 .28042 L
.03131 .27176 L
.03397 .26204 L
.03665 .25233 L
.03866 .24508 L
.03934 .24262 L
.04204 .23291 L
.04476 .22319 L
.0475 .21348 L
.04837 .21041 L
.05025 .20377 L
.05302 .19406 L
.0558 .18434 L
.05808 .17641 L
.0586 .17463 L
.06141 .16492 L
.06424 .15521 L
.06709 .14549 L
.06779 .14309 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08159 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10578 .01923 L
s
.325 g
.01923 .26696 m
.02055 .26204 L
.02316 .25233 L
.02578 .24262 L
.02841 .23291 L
.02894 .23096 L
.03106 .22319 L
.03373 .21348 L
.0364 .20377 L
.03866 .19564 L
.03909 .19406 L
.0418 .18434 L
.04452 .17463 L
.04726 .16492 L
.04837 .16099 L
.05001 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12701 L
.05835 .12607 L
.06117 .11636 L
.064 .10664 L
.06684 .09693 L
.06779 .0937 L
.06971 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06107 L
.07841 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02912 L
.08727 .02894 L
.09026 .01923 L
.01923 .01923 L
F
0 g
.01923 .26696 m
.02055 .26204 L
.02316 .25233 L
.02578 .24262 L
.02841 .23291 L
.02894 .23096 L
.03106 .22319 L
.03373 .21348 L
.0364 .20377 L
.03866 .19564 L
.03909 .19406 L
.0418 .18434 L
.04452 .17463 L
.04726 .16492 L
.04837 .16099 L
.05001 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12701 L
.05835 .12607 L
.06117 .11636 L
.064 .10664 L
.06684 .09693 L
.06779 .0937 L
.06971 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06107 L
.07841 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02912 L
.08727 .02894 L
.09026 .01923 L
s
.25 g
.01923 .22034 m
.02107 .21348 L
.02368 .20377 L
.02631 .19406 L
.02894 .18435 L
.02895 .18434 L
.0316 .17463 L
.03427 .16492 L
.03695 .15521 L
.03866 .14904 L
.03964 .14549 L
.04235 .13578 L
.04508 .12607 L
.04782 .11636 L
.04837 .1144 L
.05057 .10664 L
.05334 .09693 L
.05613 .08722 L
.05808 .08044 L
.05893 .07751 L
.06175 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04715 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
.01923 .01923 L
F
0 g
.01923 .22034 m
.02107 .21348 L
.02368 .20377 L
.02631 .19406 L
.02894 .18435 L
.02895 .18434 L
.0316 .17463 L
.03427 .16492 L
.03695 .15521 L
.03866 .14904 L
.03964 .14549 L
.04235 .13578 L
.04508 .12607 L
.04782 .11636 L
.04837 .1144 L
.05057 .10664 L
.05334 .09693 L
.05613 .08722 L
.05808 .08044 L
.05893 .07751 L
.06175 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04715 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
s
.925 g
.96253 .98077 m
.96134 .97722 L
.95928 .97106 L
.956 .96134 L
.9527 .95163 L
.95163 .94849 L
.94937 .94192 L
.94602 .93221 L
.94264 .92249 L
.94192 .92043 L
.93923 .91278 L
.93579 .90307 L
.93232 .89336 L
.93221 .89303 L
.92882 .88364 L
.92529 .87393 L
.92249 .8663 L
.92173 .86422 L
.91813 .85451 L
.9145 .84479 L
.91278 .84022 L
.91084 .83508 L
.90713 .82537 L
.9034 .81566 L
.90307 .81481 L
.89962 .80594 L
.8958 .79623 L
.89336 .79006 L
.89195 .78652 L
.88805 .77681 L
.8841 .76709 L
.88364 .76597 L
.88012 .75738 L
.87608 .74767 L
.87393 .74254 L
.872 .73796 L
.86787 .72824 L
.86422 .71977 L
.86368 .71853 L
.85944 .70882 L
.85515 .69911 L
.85451 .69766 L
.85079 .68939 L
.84638 .67968 L
.84479 .67622 L
.8419 .66997 L
.83736 .66026 L
.83508 .65544 L
.83275 .65054 L
.82806 .64083 L
.82537 .63532 L
.8233 .63112 L
.81846 .62141 L
.81566 .61586 L
.81353 .61169 L
.80852 .60198 L
.80594 .59706 L
.80341 .59227 L
.7982 .58256 L
.79623 .57893 L
.79289 .57284 L
.78747 .56313 L
.78652 .56145 L
.78192 .55342 L
.77681 .54464 L
.77626 .54371 L
.77045 .53399 L
.76709 .52849 L
.7645 .52428 L
.75838 .51457 L
.75738 .513 L
.7521 .50486 L
.74767 .49817 L
.74563 .49514 L
.73896 .48543 L
.73796 .484 L
.73205 .47572 L
.72824 .4705 L
.7249 .46601 L
.71853 .45766 L
.71747 .45629 L
.70972 .44658 L
.70882 .44547 L
.70162 .43687 L
.69911 .43395 L
.6931 .42716 L
.68939 .42309 L
.68409 .41744 L
.67968 .41289 L
.67451 .40773 L
.66997 .40336 L
.66422 .39802 L
.66026 .39448 L
.65303 .38831 L
.65054 .38626 L
.64083 .37871 L
.64068 .37859 L
.63112 .37182 L
.62668 .36888 L
.62141 .36558 L
.61169 .36001 L
.61012 .35917 L
.60198 .3551 L
.59227 .35085 L
.58872 .34946 L
.58256 .34726 L
.57284 .34434 L
.56313 .34207 L
.55342 .34046 L
.54679 .33974 L
.54371 .33951 L
.53399 .33923 L
.52428 .3396 L
.52173 .33974 L
.51457 .34064 L
.50486 .34234 L
.49514 .34469 L
.48543 .34771 L
.48057 .34946 L
.47572 .35138 L
.46601 .35572 L
.45916 .35917 L
.45629 .36072 L
.44658 .36637 L
.4426 .36888 L
.43687 .37269 L
.42859 .37859 L
.42716 .37966 L
.41744 .3873 L
.41622 .38831 L
.40773 .39559 L
.40503 .39802 L
.39802 .40455 L
.39473 .40773 L
.38831 .41416 L
.38513 .41744 L
.37859 .42443 L
.37612 .42716 L
.36888 .43537 L
.36759 .43687 L
.35947 .44658 L
.35917 .44696 L
.35172 .45629 L
.34946 .45921 L
.34428 .46601 L
.33974 .47212 L
.33712 .47572 L
.33021 .48543 L
.33003 .48568 L
.32352 .49514 L
.32032 .49991 L
.31704 .50486 L
.31075 .51457 L
.31061 .51479 L
.30463 .52428 L
.30089 .53034 L
.29867 .53399 L
.29285 .54371 L
.29118 .54654 L
.28717 .55342 L
.28162 .56313 L
.28147 .5634 L
.27619 .57284 L
.27176 .58092 L
.27086 .58256 L
.26565 .59227 L
.26204 .59909 L
.26053 .60198 L
.25551 .61169 L
.25233 .61792 L
.25057 .62141 L
.24572 .63112 L
.24262 .63741 L
.24095 .64083 L
.23626 .65054 L
.23291 .65756 L
.23163 .66026 L
.22708 .66997 L
.22319 .67837 L
.22259 .67968 L
.21817 .68939 L
.2138 .69911 L
.21348 .69983 L
.2095 .70882 L
.20525 .71853 L
.20377 .72195 L
.20106 .72824 L
.19692 .73796 L
.19406 .74472 L
.19282 .74767 L
.18878 .75738 L
.18478 .76709 L
.18434 .76815 L
.18083 .77681 L
.17692 .78652 L
.17463 .79224 L
.17305 .79623 L
.16923 .80594 L
.16544 .81566 L
.16492 .81699 L
.16169 .82537 L
.15798 .83508 L
.15521 .84239 L
.1543 .84479 L
.15067 .85451 L
.14706 .86422 L
.14549 .86844 L
.14348 .87393 L
.13995 .88364 L
.13643 .89336 L
.13578 .89516 L
.13296 .90307 L
.12951 .91278 L
.12608 .92249 L
.12607 .92252 L
.1227 .93221 L
.11933 .94192 L
.11636 .95055 L
.11599 .95163 L
.11268 .96134 L
.10939 .97106 L
.10664 .97922 L
.10613 .98077 L
F
0 g
.96253 .98077 m
.96134 .97722 L
.95928 .97106 L
.956 .96134 L
.9527 .95163 L
.95163 .94849 L
.94937 .94192 L
.94602 .93221 L
.94264 .92249 L
.94192 .92043 L
.93923 .91278 L
.93579 .90307 L
.93232 .89336 L
.93221 .89303 L
.92882 .88364 L
.92529 .87393 L
.92249 .8663 L
.92173 .86422 L
.91813 .85451 L
.9145 .84479 L
.91278 .84022 L
.91084 .83508 L
.90713 .82537 L
.9034 .81566 L
.90307 .81481 L
.89962 .80594 L
.8958 .79623 L
.89336 .79006 L
.89195 .78652 L
.88805 .77681 L
.8841 .76709 L
.88364 .76597 L
.88012 .75738 L
.87608 .74767 L
.87393 .74254 L
.872 .73796 L
.86787 .72824 L
.86422 .71977 L
.86368 .71853 L
.85944 .70882 L
.85515 .69911 L
.85451 .69766 L
.85079 .68939 L
.84638 .67968 L
.84479 .67622 L
.8419 .66997 L
.83736 .66026 L
.83508 .65544 L
.83275 .65054 L
.82806 .64083 L
Mistroke
.82537 .63532 L
.8233 .63112 L
.81846 .62141 L
.81566 .61586 L
.81353 .61169 L
.80852 .60198 L
.80594 .59706 L
.80341 .59227 L
.7982 .58256 L
.79623 .57893 L
.79289 .57284 L
.78747 .56313 L
.78652 .56145 L
.78192 .55342 L
.77681 .54464 L
.77626 .54371 L
.77045 .53399 L
.76709 .52849 L
.7645 .52428 L
.75838 .51457 L
.75738 .513 L
.7521 .50486 L
.74767 .49817 L
.74563 .49514 L
.73896 .48543 L
.73796 .484 L
.73205 .47572 L
.72824 .4705 L
.7249 .46601 L
.71853 .45766 L
.71747 .45629 L
.70972 .44658 L
.70882 .44547 L
.70162 .43687 L
.69911 .43395 L
.6931 .42716 L
.68939 .42309 L
.68409 .41744 L
.67968 .41289 L
.67451 .40773 L
.66997 .40336 L
.66422 .39802 L
.66026 .39448 L
.65303 .38831 L
.65054 .38626 L
.64083 .37871 L
.64068 .37859 L
.63112 .37182 L
.62668 .36888 L
.62141 .36558 L
Mistroke
.61169 .36001 L
.61012 .35917 L
.60198 .3551 L
.59227 .35085 L
.58872 .34946 L
.58256 .34726 L
.57284 .34434 L
.56313 .34207 L
.55342 .34046 L
.54679 .33974 L
.54371 .33951 L
.53399 .33923 L
.52428 .3396 L
.52173 .33974 L
.51457 .34064 L
.50486 .34234 L
.49514 .34469 L
.48543 .34771 L
.48057 .34946 L
.47572 .35138 L
.46601 .35572 L
.45916 .35917 L
.45629 .36072 L
.44658 .36637 L
.4426 .36888 L
.43687 .37269 L
.42859 .37859 L
.42716 .37966 L
.41744 .3873 L
.41622 .38831 L
.40773 .39559 L
.40503 .39802 L
.39802 .40455 L
.39473 .40773 L
.38831 .41416 L
.38513 .41744 L
.37859 .42443 L
.37612 .42716 L
.36888 .43537 L
.36759 .43687 L
.35947 .44658 L
.35917 .44696 L
.35172 .45629 L
.34946 .45921 L
.34428 .46601 L
.33974 .47212 L
.33712 .47572 L
.33021 .48543 L
.33003 .48568 L
.32352 .49514 L
Mistroke
.32032 .49991 L
.31704 .50486 L
.31075 .51457 L
.31061 .51479 L
.30463 .52428 L
.30089 .53034 L
.29867 .53399 L
.29285 .54371 L
.29118 .54654 L
.28717 .55342 L
.28162 .56313 L
.28147 .5634 L
.27619 .57284 L
.27176 .58092 L
.27086 .58256 L
.26565 .59227 L
.26204 .59909 L
.26053 .60198 L
.25551 .61169 L
.25233 .61792 L
.25057 .62141 L
.24572 .63112 L
.24262 .63741 L
.24095 .64083 L
.23626 .65054 L
.23291 .65756 L
.23163 .66026 L
.22708 .66997 L
.22319 .67837 L
.22259 .67968 L
.21817 .68939 L
.2138 .69911 L
.21348 .69983 L
.2095 .70882 L
.20525 .71853 L
.20377 .72195 L
.20106 .72824 L
.19692 .73796 L
.19406 .74472 L
.19282 .74767 L
.18878 .75738 L
.18478 .76709 L
.18434 .76815 L
.18083 .77681 L
.17692 .78652 L
.17463 .79224 L
.17305 .79623 L
.16923 .80594 L
.16544 .81566 L
.16492 .81699 L
Mistroke
.16169 .82537 L
.15798 .83508 L
.15521 .84239 L
.1543 .84479 L
.15067 .85451 L
.14706 .86422 L
.14549 .86844 L
.14348 .87393 L
.13995 .88364 L
.13643 .89336 L
.13578 .89516 L
.13296 .90307 L
.12951 .91278 L
.12608 .92249 L
.12607 .92252 L
.1227 .93221 L
.11933 .94192 L
.11636 .95055 L
.11599 .95163 L
.11268 .96134 L
.10939 .97106 L
.10664 .97922 L
.10613 .98077 L
Mfstroke
.85 g
.91742 .98077 m
.91378 .97106 L
.91278 .96841 L
.9101 .96134 L
.90639 .95163 L
.90307 .94302 L
.90264 .94192 L
.89885 .93221 L
.89502 .92249 L
.89336 .91829 L
.89115 .91278 L
.88724 .90307 L
.88364 .89423 L
.88329 .89336 L
.87928 .88364 L
.87523 .87393 L
.87393 .87084 L
.87113 .86422 L
.86698 .85451 L
.86422 .84811 L
.86278 .84479 L
.85852 .83508 L
.85451 .82604 L
.85421 .82537 L
.84983 .81566 L
.84539 .80594 L
.84479 .80464 L
.84089 .79623 L
.83632 .78652 L
.83508 .7839 L
.83168 .77681 L
.82697 .76709 L
.82537 .76383 L
.82218 .75738 L
.8173 .74767 L
.81566 .74443 L
.81234 .73796 L
.80729 .72824 L
.80594 .72569 L
.80214 .71853 L
.79689 .70882 L
.79623 .70761 L
.79153 .69911 L
.78652 .6902 L
.78606 .68939 L
.78046 .67968 L
.77681 .67345 L
.77473 .66997 L
.76886 .66026 L
.76709 .65737 L
.76284 .65054 L
.75738 .64196 L
.75665 .64083 L
.75029 .63112 L
.74767 .62721 L
.74372 .62141 L
.73796 .61312 L
.73695 .61169 L
.72993 .60198 L
.72824 .5997 L
.72265 .59227 L
.71853 .58694 L
.71507 .58256 L
.70882 .57485 L
.70715 .57284 L
.69911 .56343 L
.69885 .56313 L
.69009 .55342 L
.68939 .55266 L
.68081 .54371 L
.67968 .54257 L
.67088 .53399 L
.66997 .53314 L
.66026 .52437 L
.66016 .52428 L
.65054 .51627 L
.6484 .51457 L
.64083 .50883 L
.63525 .50486 L
.63112 .50206 L
.62141 .49595 L
.62004 .49514 L
.61169 .49051 L
.60198 .48573 L
.60133 .48543 L
.59227 .48162 L
.58256 .47817 L
.57417 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47181 L
.54371 .47102 L
.53399 .4709 L
.52428 .47144 L
.51457 .47264 L
.50486 .47451 L
.49984 .47572 L
.49514 .47704 L
.48543 .48024 L
.47572 .48411 L
.47272 .48543 L
.46601 .48863 L
.45629 .49383 L
.45401 .49514 L
.44658 .49968 L
.4388 .50486 L
.43687 .5062 L
.42716 .51339 L
.42564 .51457 L
.41744 .52124 L
.41389 .52428 L
.40773 .52976 L
.40316 .53399 L
.39802 .53894 L
.39323 .54371 L
.38831 .54878 L
.38394 .55342 L
.37859 .55929 L
.37519 .56313 L
.36888 .57046 L
.36688 .57284 L
.35917 .5823 L
.35896 .58256 L
.35138 .59227 L
.34946 .5948 L
.3441 .60198 L
.33974 .60796 L
.33708 .61169 L
.3303 .62141 L
.33003 .62179 L
.32373 .63112 L
.32032 .63629 L
.31736 .64083 L
.31117 .65054 L
.31061 .65145 L
.30515 .66026 L
.30089 .66727 L
.29928 .66997 L
.29355 .67968 L
.29118 .68376 L
.28795 .68939 L
.28247 .69911 L
.28147 .70091 L
.27711 .70882 L
.27186 .71853 L
.27176 .71872 L
.26671 .72824 L
.26204 .7372 L
.26165 .73796 L
.25669 .74767 L
.25233 .75634 L
.25181 .75738 L
.24702 .76709 L
.24262 .77615 L
.2423 .77681 L
.23766 .78652 L
.23309 .79623 L
.23291 .79662 L
.22859 .80594 L
.22415 .81566 L
.22319 .81776 L
.21977 .82537 L
.21545 .83508 L
.21348 .83956 L
.21119 .84479 L
.20699 .85451 L
.20377 .86202 L
.20283 .86422 L
.19873 .87393 L
.19468 .88364 L
.19406 .88515 L
.19067 .89336 L
.18672 .90307 L
.18434 .90894 L
.1828 .91278 L
.17893 .92249 L
.1751 .93221 L
.17463 .93339 L
.17131 .94192 L
.16755 .95163 L
.16492 .95851 L
.16384 .96134 L
.16016 .97106 L
.15652 .98077 L
F
0 g
.91742 .98077 m
.91378 .97106 L
.91278 .96841 L
.9101 .96134 L
.90639 .95163 L
.90307 .94302 L
.90264 .94192 L
.89885 .93221 L
.89502 .92249 L
.89336 .91829 L
.89115 .91278 L
.88724 .90307 L
.88364 .89423 L
.88329 .89336 L
.87928 .88364 L
.87523 .87393 L
.87393 .87084 L
.87113 .86422 L
.86698 .85451 L
.86422 .84811 L
.86278 .84479 L
.85852 .83508 L
.85451 .82604 L
.85421 .82537 L
.84983 .81566 L
.84539 .80594 L
.84479 .80464 L
.84089 .79623 L
.83632 .78652 L
.83508 .7839 L
.83168 .77681 L
.82697 .76709 L
.82537 .76383 L
.82218 .75738 L
.8173 .74767 L
.81566 .74443 L
.81234 .73796 L
.80729 .72824 L
.80594 .72569 L
.80214 .71853 L
.79689 .70882 L
.79623 .70761 L
.79153 .69911 L
.78652 .6902 L
.78606 .68939 L
.78046 .67968 L
.77681 .67345 L
.77473 .66997 L
.76886 .66026 L
.76709 .65737 L
Mistroke
.76284 .65054 L
.75738 .64196 L
.75665 .64083 L
.75029 .63112 L
.74767 .62721 L
.74372 .62141 L
.73796 .61312 L
.73695 .61169 L
.72993 .60198 L
.72824 .5997 L
.72265 .59227 L
.71853 .58694 L
.71507 .58256 L
.70882 .57485 L
.70715 .57284 L
.69911 .56343 L
.69885 .56313 L
.69009 .55342 L
.68939 .55266 L
.68081 .54371 L
.67968 .54257 L
.67088 .53399 L
.66997 .53314 L
.66026 .52437 L
.66016 .52428 L
.65054 .51627 L
.6484 .51457 L
.64083 .50883 L
.63525 .50486 L
.63112 .50206 L
.62141 .49595 L
.62004 .49514 L
.61169 .49051 L
.60198 .48573 L
.60133 .48543 L
.59227 .48162 L
.58256 .47817 L
.57417 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47181 L
.54371 .47102 L
.53399 .4709 L
.52428 .47144 L
.51457 .47264 L
.50486 .47451 L
.49984 .47572 L
.49514 .47704 L
.48543 .48024 L
.47572 .48411 L
Mistroke
.47272 .48543 L
.46601 .48863 L
.45629 .49383 L
.45401 .49514 L
.44658 .49968 L
.4388 .50486 L
.43687 .5062 L
.42716 .51339 L
.42564 .51457 L
.41744 .52124 L
.41389 .52428 L
.40773 .52976 L
.40316 .53399 L
.39802 .53894 L
.39323 .54371 L
.38831 .54878 L
.38394 .55342 L
.37859 .55929 L
.37519 .56313 L
.36888 .57046 L
.36688 .57284 L
.35917 .5823 L
.35896 .58256 L
.35138 .59227 L
.34946 .5948 L
.3441 .60198 L
.33974 .60796 L
.33708 .61169 L
.3303 .62141 L
.33003 .62179 L
.32373 .63112 L
.32032 .63629 L
.31736 .64083 L
.31117 .65054 L
.31061 .65145 L
.30515 .66026 L
.30089 .66727 L
.29928 .66997 L
.29355 .67968 L
.29118 .68376 L
.28795 .68939 L
.28247 .69911 L
.28147 .70091 L
.27711 .70882 L
.27186 .71853 L
.27176 .71872 L
.26671 .72824 L
.26204 .7372 L
.26165 .73796 L
.25669 .74767 L
Mistroke
.25233 .75634 L
.25181 .75738 L
.24702 .76709 L
.24262 .77615 L
.2423 .77681 L
.23766 .78652 L
.23309 .79623 L
.23291 .79662 L
.22859 .80594 L
.22415 .81566 L
.22319 .81776 L
.21977 .82537 L
.21545 .83508 L
.21348 .83956 L
.21119 .84479 L
.20699 .85451 L
.20377 .86202 L
.20283 .86422 L
.19873 .87393 L
.19468 .88364 L
.19406 .88515 L
.19067 .89336 L
.18672 .90307 L
.18434 .90894 L
.1828 .91278 L
.17893 .92249 L
.1751 .93221 L
.17463 .93339 L
.17131 .94192 L
.16755 .95163 L
.16492 .95851 L
.16384 .96134 L
.16016 .97106 L
.15652 .98077 L
Mfstroke
.775 g
.88062 .98077 m
.87658 .97106 L
.87393 .96474 L
.8725 .96134 L
.86836 .95163 L
.86422 .94202 L
.86417 .94192 L
.85993 .93221 L
.85563 .92249 L
.85451 .91997 L
.85127 .91278 L
.84685 .90307 L
.84479 .89859 L
.84237 .89336 L
.83782 .88364 L
.83508 .87787 L
.8332 .87393 L
.8285 .86422 L
.82537 .85782 L
.82373 .85451 L
.81888 .84479 L
.81566 .83843 L
.81394 .83508 L
.80892 .82537 L
.80594 .81971 L
.80379 .81566 L
.79857 .80594 L
.79623 .80166 L
.79324 .79623 L
.78779 .78652 L
.78652 .78427 L
.78223 .77681 L
.77681 .76755 L
.77653 .76709 L
.7707 .75738 L
.76709 .7515 L
.76472 .74767 L
.75857 .73796 L
.75738 .73611 L
.75225 .72824 L
.74767 .72139 L
.74573 .71853 L
.73901 .70882 L
.73796 .70733 L
.73205 .69911 L
.72824 .69394 L
.72483 .68939 L
.71853 .68122 L
.71732 .67968 L
.70949 .66997 L
.70882 .66916 L
.70127 .66026 L
.69911 .65777 L
.69263 .65054 L
.68939 .64705 L
.68347 .64083 L
.67968 .63699 L
.67369 .63112 L
.66997 .6276 L
.66316 .62141 L
.66026 .61887 L
.65165 .61169 L
.65054 .61081 L
.64083 .60342 L
.63884 .60198 L
.63112 .59669 L
.62415 .59227 L
.62141 .59063 L
.61169 .58523 L
.60638 .58256 L
.60198 .5805 L
.59227 .57644 L
.58256 .57304 L
.58193 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56685 L
.54371 .56612 L
.53399 .56605 L
.52428 .56665 L
.51457 .56792 L
.50486 .56985 L
.49514 .57245 L
.49384 .57284 L
.48543 .57571 L
.47572 .57964 L
.46939 .58256 L
.46601 .58424 L
.45629 .5895 L
.45162 .59227 L
.44658 .59543 L
.43693 .60198 L
.43687 .60202 L
.42716 .60928 L
.42411 .61169 L
.41744 .61721 L
.41261 .62141 L
.40773 .6258 L
.40207 .63112 L
.39802 .63506 L
.39229 .64083 L
.38831 .64499 L
.38313 .65054 L
.37859 .65558 L
.37449 .66026 L
.36888 .66683 L
.36627 .66997 L
.35917 .67876 L
.35844 .67968 L
.35093 .68939 L
.34946 .69134 L
.34371 .69911 L
.33974 .7046 L
.33675 .70882 L
.33003 .71852 L
.33002 .71853 L
.32351 .72824 L
.32032 .7331 L
.31718 .73796 L
.31103 .74767 L
.31061 .74836 L
.30505 .75738 L
.30089 .76427 L
.29921 .76709 L
.29352 .77681 L
.29118 .78086 L
.28795 .78652 L
.28251 .79623 L
.28147 .79811 L
.27718 .80594 L
.27195 .81566 L
.27176 .81602 L
.26683 .82537 L
.26204 .8346 L
.2618 .83508 L
.25686 .84479 L
.25233 .85385 L
.25201 .85451 L
.24723 .86422 L
.24262 .87376 L
.24254 .87393 L
.23792 .88364 L
.23336 .89336 L
.23291 .89434 L
.22888 .90307 L
.22446 .91278 L
.22319 .91559 L
.2201 .92249 L
.2158 .93221 L
.21348 .9375 L
.21156 .94192 L
.20737 .95163 L
.20377 .96007 L
.20323 .96134 L
.19914 .97106 L
.19511 .98077 L
F
0 g
.88062 .98077 m
.87658 .97106 L
.87393 .96474 L
.8725 .96134 L
.86836 .95163 L
.86422 .94202 L
.86417 .94192 L
.85993 .93221 L
.85563 .92249 L
.85451 .91997 L
.85127 .91278 L
.84685 .90307 L
.84479 .89859 L
.84237 .89336 L
.83782 .88364 L
.83508 .87787 L
.8332 .87393 L
.8285 .86422 L
.82537 .85782 L
.82373 .85451 L
.81888 .84479 L
.81566 .83843 L
.81394 .83508 L
.80892 .82537 L
.80594 .81971 L
.80379 .81566 L
.79857 .80594 L
.79623 .80166 L
.79324 .79623 L
.78779 .78652 L
.78652 .78427 L
.78223 .77681 L
.77681 .76755 L
.77653 .76709 L
.7707 .75738 L
.76709 .7515 L
.76472 .74767 L
.75857 .73796 L
.75738 .73611 L
.75225 .72824 L
.74767 .72139 L
.74573 .71853 L
.73901 .70882 L
.73796 .70733 L
.73205 .69911 L
.72824 .69394 L
.72483 .68939 L
.71853 .68122 L
.71732 .67968 L
.70949 .66997 L
Mistroke
.70882 .66916 L
.70127 .66026 L
.69911 .65777 L
.69263 .65054 L
.68939 .64705 L
.68347 .64083 L
.67968 .63699 L
.67369 .63112 L
.66997 .6276 L
.66316 .62141 L
.66026 .61887 L
.65165 .61169 L
.65054 .61081 L
.64083 .60342 L
.63884 .60198 L
.63112 .59669 L
.62415 .59227 L
.62141 .59063 L
.61169 .58523 L
.60638 .58256 L
.60198 .5805 L
.59227 .57644 L
.58256 .57304 L
.58193 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56685 L
.54371 .56612 L
.53399 .56605 L
.52428 .56665 L
.51457 .56792 L
.50486 .56985 L
.49514 .57245 L
.49384 .57284 L
.48543 .57571 L
.47572 .57964 L
.46939 .58256 L
.46601 .58424 L
.45629 .5895 L
.45162 .59227 L
.44658 .59543 L
.43693 .60198 L
.43687 .60202 L
.42716 .60928 L
.42411 .61169 L
.41744 .61721 L
.41261 .62141 L
.40773 .6258 L
.40207 .63112 L
.39802 .63506 L
Mistroke
.39229 .64083 L
.38831 .64499 L
.38313 .65054 L
.37859 .65558 L
.37449 .66026 L
.36888 .66683 L
.36627 .66997 L
.35917 .67876 L
.35844 .67968 L
.35093 .68939 L
.34946 .69134 L
.34371 .69911 L
.33974 .7046 L
.33675 .70882 L
.33003 .71852 L
.33002 .71853 L
.32351 .72824 L
.32032 .7331 L
.31718 .73796 L
.31103 .74767 L
.31061 .74836 L
.30505 .75738 L
.30089 .76427 L
.29921 .76709 L
.29352 .77681 L
.29118 .78086 L
.28795 .78652 L
.28251 .79623 L
.28147 .79811 L
.27718 .80594 L
.27195 .81566 L
.27176 .81602 L
.26683 .82537 L
.26204 .8346 L
.2618 .83508 L
.25686 .84479 L
.25233 .85385 L
.25201 .85451 L
.24723 .86422 L
.24262 .87376 L
.24254 .87393 L
.23792 .88364 L
.23336 .89336 L
.23291 .89434 L
.22888 .90307 L
.22446 .91278 L
.22319 .91559 L
.2201 .92249 L
.2158 .93221 L
.21348 .9375 L
Mistroke
.21156 .94192 L
.20737 .95163 L
.20377 .96007 L
.20323 .96134 L
.19914 .97106 L
.19511 .98077 L
Mfstroke
.7 g
.8468 .98077 m
.84479 .9764 L
.84232 .97106 L
.83776 .96134 L
.83508 .95569 L
.83314 .95163 L
.82844 .94192 L
.82537 .93565 L
.82367 .93221 L
.81881 .92249 L
.81566 .91628 L
.81387 .91278 L
.80883 .90307 L
.80594 .89757 L
.80371 .89336 L
.79848 .88364 L
.79623 .87953 L
.79314 .87393 L
.78769 .86422 L
.78652 .86216 L
.78212 .85451 L
.77681 .84545 L
.77642 .84479 L
.77057 .83508 L
.76709 .82941 L
.76458 .82537 L
.75842 .81566 L
.75738 .81404 L
.75209 .80594 L
.74767 .79933 L
.74556 .79623 L
.73882 .78652 L
.73796 .78529 L
.73185 .77681 L
.72824 .77192 L
.72461 .76709 L
.71853 .75922 L
.71708 .75738 L
.70922 .74767 L
.70882 .74718 L
.70099 .73796 L
.69911 .73581 L
.69231 .72824 L
.68939 .72511 L
.68311 .71853 L
.67968 .71507 L
.67328 .70882 L
.66997 .7057 L
.66268 .69911 L
.66026 .69699 L
.65109 .68939 L
.65054 .68896 L
.64083 .68159 L
.63817 .67968 L
.63112 .67489 L
.62329 .66997 L
.62141 .66885 L
.61169 .66348 L
.60519 .66026 L
.60198 .65878 L
.59227 .65475 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64664 L
.55342 .64528 L
.54371 .64458 L
.53399 .64454 L
.52428 .64518 L
.51457 .64648 L
.50486 .64844 L
.49689 .65054 L
.49514 .65108 L
.48543 .65438 L
.47572 .65834 L
.47153 .66026 L
.46601 .66298 L
.45629 .66828 L
.45343 .66997 L
.44658 .67425 L
.43856 .67968 L
.43687 .68088 L
.42716 .68819 L
.42563 .68939 L
.41744 .69615 L
.41404 .69911 L
.40773 .70479 L
.40344 .70882 L
.39802 .71409 L
.39361 .71853 L
.38831 .72406 L
.38441 .72824 L
.37859 .7347 L
.37573 .73796 L
.36888 .746 L
.36749 .74767 L
.35963 .75738 L
.35917 .75797 L
.3521 .76709 L
.34946 .7706 L
.34487 .77681 L
.33974 .78391 L
.33789 .78652 L
.33115 .79623 L
.33003 .79788 L
.32462 .80594 L
.32032 .81251 L
.31829 .81566 L
.31213 .82537 L
.31061 .82782 L
.30614 .83508 L
.30089 .84379 L
.30029 .84479 L
.29459 .85451 L
.29118 .86042 L
.28902 .86422 L
.28357 .87393 L
.28147 .87773 L
.27823 .88364 L
.273 .89336 L
.27176 .8957 L
.26787 .90307 L
.26284 .91278 L
.26204 .91433 L
.2579 .92249 L
.25304 .93221 L
.25233 .93364 L
.24826 .94192 L
.24356 .95163 L
.24262 .95361 L
.23894 .96134 L
.23438 .97106 L
.23291 .97424 L
.2299 .98077 L
F
0 g
.8468 .98077 m
.84479 .9764 L
.84232 .97106 L
.83776 .96134 L
.83508 .95569 L
.83314 .95163 L
.82844 .94192 L
.82537 .93565 L
.82367 .93221 L
.81881 .92249 L
.81566 .91628 L
.81387 .91278 L
.80883 .90307 L
.80594 .89757 L
.80371 .89336 L
.79848 .88364 L
.79623 .87953 L
.79314 .87393 L
.78769 .86422 L
.78652 .86216 L
.78212 .85451 L
.77681 .84545 L
.77642 .84479 L
.77057 .83508 L
.76709 .82941 L
.76458 .82537 L
.75842 .81566 L
.75738 .81404 L
.75209 .80594 L
.74767 .79933 L
.74556 .79623 L
.73882 .78652 L
.73796 .78529 L
.73185 .77681 L
.72824 .77192 L
.72461 .76709 L
.71853 .75922 L
.71708 .75738 L
.70922 .74767 L
.70882 .74718 L
.70099 .73796 L
.69911 .73581 L
.69231 .72824 L
.68939 .72511 L
.68311 .71853 L
.67968 .71507 L
.67328 .70882 L
.66997 .7057 L
.66268 .69911 L
.66026 .69699 L
Mistroke
.65109 .68939 L
.65054 .68896 L
.64083 .68159 L
.63817 .67968 L
.63112 .67489 L
.62329 .66997 L
.62141 .66885 L
.61169 .66348 L
.60519 .66026 L
.60198 .65878 L
.59227 .65475 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64664 L
.55342 .64528 L
.54371 .64458 L
.53399 .64454 L
.52428 .64518 L
.51457 .64648 L
.50486 .64844 L
.49689 .65054 L
.49514 .65108 L
.48543 .65438 L
.47572 .65834 L
.47153 .66026 L
.46601 .66298 L
.45629 .66828 L
.45343 .66997 L
.44658 .67425 L
.43856 .67968 L
.43687 .68088 L
.42716 .68819 L
.42563 .68939 L
.41744 .69615 L
.41404 .69911 L
.40773 .70479 L
.40344 .70882 L
.39802 .71409 L
.39361 .71853 L
.38831 .72406 L
.38441 .72824 L
.37859 .7347 L
.37573 .73796 L
.36888 .746 L
.36749 .74767 L
.35963 .75738 L
.35917 .75797 L
.3521 .76709 L
.34946 .7706 L
Mistroke
.34487 .77681 L
.33974 .78391 L
.33789 .78652 L
.33115 .79623 L
.33003 .79788 L
.32462 .80594 L
.32032 .81251 L
.31829 .81566 L
.31213 .82537 L
.31061 .82782 L
.30614 .83508 L
.30089 .84379 L
.30029 .84479 L
.29459 .85451 L
.29118 .86042 L
.28902 .86422 L
.28357 .87393 L
.28147 .87773 L
.27823 .88364 L
.273 .89336 L
.27176 .8957 L
.26787 .90307 L
.26284 .91278 L
.26204 .91433 L
.2579 .92249 L
.25304 .93221 L
.25233 .93364 L
.24826 .94192 L
.24356 .95163 L
.24262 .95361 L
.23894 .96134 L
.23438 .97106 L
.23291 .97424 L
.2299 .98077 L
Mfstroke
.625 g
.81389 .98077 m
.80886 .97106 L
.80594 .96552 L
.80373 .96134 L
.7985 .95163 L
.79623 .94749 L
.79316 .94192 L
.78771 .93221 L
.78652 .93012 L
.78213 .92249 L
.77681 .91342 L
.77642 .91278 L
.77058 .90307 L
.76709 .8974 L
.76458 .89336 L
.75842 .88364 L
.75738 .88203 L
.75208 .87393 L
.74767 .86734 L
.74555 .86422 L
.7388 .85451 L
.73796 .85331 L
.73182 .84479 L
.72824 .83995 L
.72458 .83508 L
.71853 .82726 L
.71704 .82537 L
.70917 .81566 L
.70882 .81523 L
.70092 .80594 L
.69911 .80388 L
.69222 .79623 L
.68939 .79319 L
.68301 .78652 L
.67968 .78316 L
.67316 .77681 L
.66997 .77381 L
.66253 .76709 L
.66026 .76512 L
.6509 .75738 L
.65054 .7571 L
.64083 .74974 L
.63792 .74767 L
.63112 .74306 L
.62296 .73796 L
.62141 .73704 L
.61169 .73169 L
.6047 .72824 L
.60198 .72701 L
.59227 .72299 L
.58256 .71964 L
.57888 .71853 L
.57284 .71696 L
.56313 .71495 L
.55342 .7136 L
.54371 .71292 L
.53399 .71291 L
.52428 .71356 L
.51457 .71488 L
.50486 .71688 L
.49847 .71853 L
.49514 .71953 L
.48543 .72286 L
.47572 .72685 L
.47265 .72824 L
.46601 .73151 L
.45629 .73684 L
.45439 .73796 L
.44658 .74283 L
.43943 .74767 L
.43687 .74949 L
.42716 .75682 L
.42645 .75738 L
.41744 .76482 L
.41482 .76709 L
.40773 .77348 L
.40419 .77681 L
.39802 .78281 L
.39434 .78652 L
.38831 .79281 L
.38512 .79623 L
.37859 .80347 L
.37643 .80594 L
.36888 .81481 L
.36818 .81566 L
.3603 .82537 L
.35917 .82681 L
.35277 .83508 L
.34946 .83947 L
.34552 .84479 L
.33974 .85281 L
.33854 .85451 L
.33179 .86422 L
.33003 .86681 L
.32526 .87393 L
.32032 .88148 L
.31892 .88364 L
.31276 .89336 L
.31061 .89682 L
.30676 .90307 L
.30092 .91278 L
.30089 .91282 L
.29521 .92249 L
.29118 .92949 L
.28963 .93221 L
.28418 .94192 L
.28147 .94683 L
.27884 .95163 L
.27361 .96134 L
.27176 .96484 L
.26848 .97106 L
.26345 .98077 L
F
0 g
.81389 .98077 m
.80886 .97106 L
.80594 .96552 L
.80373 .96134 L
.7985 .95163 L
.79623 .94749 L
.79316 .94192 L
.78771 .93221 L
.78652 .93012 L
.78213 .92249 L
.77681 .91342 L
.77642 .91278 L
.77058 .90307 L
.76709 .8974 L
.76458 .89336 L
.75842 .88364 L
.75738 .88203 L
.75208 .87393 L
.74767 .86734 L
.74555 .86422 L
.7388 .85451 L
.73796 .85331 L
.73182 .84479 L
.72824 .83995 L
.72458 .83508 L
.71853 .82726 L
.71704 .82537 L
.70917 .81566 L
.70882 .81523 L
.70092 .80594 L
.69911 .80388 L
.69222 .79623 L
.68939 .79319 L
.68301 .78652 L
.67968 .78316 L
.67316 .77681 L
.66997 .77381 L
.66253 .76709 L
.66026 .76512 L
.6509 .75738 L
.65054 .7571 L
.64083 .74974 L
.63792 .74767 L
.63112 .74306 L
.62296 .73796 L
.62141 .73704 L
.61169 .73169 L
.6047 .72824 L
.60198 .72701 L
.59227 .72299 L
Mistroke
.58256 .71964 L
.57888 .71853 L
.57284 .71696 L
.56313 .71495 L
.55342 .7136 L
.54371 .71292 L
.53399 .71291 L
.52428 .71356 L
.51457 .71488 L
.50486 .71688 L
.49847 .71853 L
.49514 .71953 L
.48543 .72286 L
.47572 .72685 L
.47265 .72824 L
.46601 .73151 L
.45629 .73684 L
.45439 .73796 L
.44658 .74283 L
.43943 .74767 L
.43687 .74949 L
.42716 .75682 L
.42645 .75738 L
.41744 .76482 L
.41482 .76709 L
.40773 .77348 L
.40419 .77681 L
.39802 .78281 L
.39434 .78652 L
.38831 .79281 L
.38512 .79623 L
.37859 .80347 L
.37643 .80594 L
.36888 .81481 L
.36818 .81566 L
.3603 .82537 L
.35917 .82681 L
.35277 .83508 L
.34946 .83947 L
.34552 .84479 L
.33974 .85281 L
.33854 .85451 L
.33179 .86422 L
.33003 .86681 L
.32526 .87393 L
.32032 .88148 L
.31892 .88364 L
.31276 .89336 L
.31061 .89682 L
.30676 .90307 L
Mistroke
.30092 .91278 L
.30089 .91282 L
.29521 .92249 L
.29118 .92949 L
.28963 .93221 L
.28418 .94192 L
.28147 .94683 L
.27884 .95163 L
.27361 .96134 L
.27176 .96484 L
.26848 .97106 L
.26345 .98077 L
Mfstroke
.55 g
.78049 .98077 m
.77681 .97451 L
.77475 .97106 L
.76885 .96134 L
.76709 .95849 L
.76281 .95163 L
.75738 .94314 L
.75659 .94192 L
.7502 .93221 L
.74767 .92845 L
.7436 .92249 L
.73796 .91443 L
.73678 .91278 L
.72972 .90307 L
.72824 .90108 L
.72239 .89336 L
.71853 .88839 L
.71476 .88364 L
.70882 .87638 L
.70677 .87393 L
.69911 .86503 L
.69839 .86422 L
.68954 .85451 L
.68939 .85435 L
.68014 .84479 L
.67968 .84434 L
.67006 .83508 L
.66997 .83499 L
.66026 .82632 L
.65915 .82537 L
.65054 .81831 L
.64714 .81566 L
.64083 .81096 L
.63362 .80594 L
.63112 .80429 L
.62141 .79828 L
.61782 .79623 L
.61169 .79295 L
.60198 .78828 L
.59793 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77827 L
.56619 .77681 L
.56313 .77627 L
.55342 .77494 L
.54371 .77427 L
.53399 .77428 L
.52428 .77495 L
.51457 .77629 L
.51162 .77681 L
.50486 .77829 L
.49514 .78097 L
.48543 .78431 L
.47987 .78652 L
.47572 .78832 L
.46601 .793 L
.45998 .79623 L
.45629 .79834 L
.44658 .80436 L
.44418 .80594 L
.43687 .81104 L
.43066 .81566 L
.42716 .81839 L
.41865 .82537 L
.41744 .8264 L
.40774 .83508 L
.40773 .83509 L
.39802 .84444 L
.39766 .84479 L
.38831 .85446 L
.38826 .85451 L
.37941 .86422 L
.37859 .86514 L
.37103 .87393 L
.36888 .8765 L
.36304 .88364 L
.35917 .88852 L
.35541 .89336 L
.34946 .90121 L
.34807 .90307 L
.34101 .91278 L
.33974 .91457 L
.3342 .92249 L
.33003 .92859 L
.3276 .93221 L
.3212 .94192 L
.32032 .94329 L
.31499 .95163 L
.31061 .95865 L
.30894 .96134 L
.30305 .97106 L
.30089 .97467 L
.2973 .98077 L
F
0 g
.78049 .98077 m
.77681 .97451 L
.77475 .97106 L
.76885 .96134 L
.76709 .95849 L
.76281 .95163 L
.75738 .94314 L
.75659 .94192 L
.7502 .93221 L
.74767 .92845 L
.7436 .92249 L
.73796 .91443 L
.73678 .91278 L
.72972 .90307 L
.72824 .90108 L
.72239 .89336 L
.71853 .88839 L
.71476 .88364 L
.70882 .87638 L
.70677 .87393 L
.69911 .86503 L
.69839 .86422 L
.68954 .85451 L
.68939 .85435 L
.68014 .84479 L
.67968 .84434 L
.67006 .83508 L
.66997 .83499 L
.66026 .82632 L
.65915 .82537 L
.65054 .81831 L
.64714 .81566 L
.64083 .81096 L
.63362 .80594 L
.63112 .80429 L
.62141 .79828 L
.61782 .79623 L
.61169 .79295 L
.60198 .78828 L
.59793 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77827 L
.56619 .77681 L
.56313 .77627 L
.55342 .77494 L
.54371 .77427 L
.53399 .77428 L
.52428 .77495 L
.51457 .77629 L
Mistroke
.51162 .77681 L
.50486 .77829 L
.49514 .78097 L
.48543 .78431 L
.47987 .78652 L
.47572 .78832 L
.46601 .793 L
.45998 .79623 L
.45629 .79834 L
.44658 .80436 L
.44418 .80594 L
.43687 .81104 L
.43066 .81566 L
.42716 .81839 L
.41865 .82537 L
.41744 .8264 L
.40774 .83508 L
.40773 .83509 L
.39802 .84444 L
.39766 .84479 L
.38831 .85446 L
.38826 .85451 L
.37941 .86422 L
.37859 .86514 L
.37103 .87393 L
.36888 .8765 L
.36304 .88364 L
.35917 .88852 L
.35541 .89336 L
.34946 .90121 L
.34807 .90307 L
.34101 .91278 L
.33974 .91457 L
.3342 .92249 L
.33003 .92859 L
.3276 .93221 L
.3212 .94192 L
.32032 .94329 L
.31499 .95163 L
.31061 .95865 L
.30894 .96134 L
.30305 .97106 L
.30089 .97467 L
.2973 .98077 L
Mfstroke
.475 g
.74519 .98077 m
.73842 .97106 L
.73796 .9704 L
.73142 .96134 L
.72824 .95706 L
.72415 .95163 L
.71853 .94438 L
.71658 .94192 L
.70882 .93237 L
.70868 .93221 L
.70039 .92249 L
.69911 .92103 L
.69165 .91278 L
.68939 .91036 L
.68238 .90307 L
.67968 .90035 L
.67247 .89336 L
.66997 .89102 L
.66176 .88364 L
.66026 .88235 L
.65054 .87435 L
.65002 .87393 L
.64083 .86701 L
.63688 .86422 L
.63112 .86035 L
.62167 .85451 L
.62141 .85435 L
.61169 .84902 L
.60294 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57567 .83508 L
.57284 .83439 L
.56313 .8324 L
.55342 .83108 L
.54371 .83043 L
.53399 .83044 L
.52428 .83113 L
.51457 .83248 L
.50486 .8345 L
.50249 .83508 L
.49514 .83719 L
.48543 .84054 L
.47572 .84456 L
.47521 .84479 L
.46601 .84926 L
.45648 .85451 L
.45629 .85461 L
.44658 .86064 L
.44127 .86422 L
.43687 .86734 L
.42813 .87393 L
.42716 .8747 L
.41744 .88273 L
.41639 .88364 L
.40773 .89143 L
.40568 .89336 L
.39802 .9008 L
.39576 .90307 L
.38831 .91083 L
.38649 .91278 L
.37859 .92154 L
.37775 .92249 L
.36946 .93221 L
.36888 .93291 L
.36156 .94192 L
.35917 .94495 L
.354 .95163 L
.34946 .95765 L
.34673 .96134 L
.33974 .97103 L
.33972 .97106 L
.33296 .98077 L
F
0 g
.74519 .98077 m
.73842 .97106 L
.73796 .9704 L
.73142 .96134 L
.72824 .95706 L
.72415 .95163 L
.71853 .94438 L
.71658 .94192 L
.70882 .93237 L
.70868 .93221 L
.70039 .92249 L
.69911 .92103 L
.69165 .91278 L
.68939 .91036 L
.68238 .90307 L
.67968 .90035 L
.67247 .89336 L
.66997 .89102 L
.66176 .88364 L
.66026 .88235 L
.65054 .87435 L
.65002 .87393 L
.64083 .86701 L
.63688 .86422 L
.63112 .86035 L
.62167 .85451 L
.62141 .85435 L
.61169 .84902 L
.60294 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57567 .83508 L
.57284 .83439 L
.56313 .8324 L
.55342 .83108 L
.54371 .83043 L
.53399 .83044 L
.52428 .83113 L
.51457 .83248 L
.50486 .8345 L
.50249 .83508 L
.49514 .83719 L
.48543 .84054 L
.47572 .84456 L
.47521 .84479 L
.46601 .84926 L
.45648 .85451 L
.45629 .85461 L
.44658 .86064 L
Mistroke
.44127 .86422 L
.43687 .86734 L
.42813 .87393 L
.42716 .8747 L
.41744 .88273 L
.41639 .88364 L
.40773 .89143 L
.40568 .89336 L
.39802 .9008 L
.39576 .90307 L
.38831 .91083 L
.38649 .91278 L
.37859 .92154 L
.37775 .92249 L
.36946 .93221 L
.36888 .93291 L
.36156 .94192 L
.35917 .94495 L
.354 .95163 L
.34946 .95765 L
.34673 .96134 L
.33974 .97103 L
.33972 .97106 L
.33296 .98077 L
Mfstroke
.4 g
.70583 .98077 m
.69911 .97299 L
.69739 .97106 L
.68939 .96233 L
.68847 .96134 L
.67968 .95233 L
.67898 .95163 L
.66997 .943 L
.6688 .94192 L
.66026 .93434 L
.65775 .93221 L
.65054 .92634 L
.64555 .92249 L
.64083 .91902 L
.63177 .91278 L
.63112 .91236 L
.62141 .90637 L
.61553 .90307 L
.61169 .90105 L
.60198 .8964 L
.59474 .89336 L
.59227 .89241 L
.58256 .8891 L
.57284 .88645 L
.56313 .88447 L
.55824 .88364 L
.55342 .88316 L
.54371 .88251 L
.53399 .88254 L
.52428 .88323 L
.52032 .88364 L
.51457 .88459 L
.50486 .88662 L
.49514 .88932 L
.48543 .89269 L
.48369 .89336 L
.47572 .89672 L
.46601 .90142 L
.46289 .90307 L
.45629 .90679 L
.44666 .91278 L
.44658 .91283 L
.43687 .91954 L
.43287 .92249 L
.42716 .92692 L
.42068 .93221 L
.41744 .93496 L
.40962 .94192 L
.40773 .94367 L
.39944 .95163 L
.39802 .95305 L
.38996 .96134 L
.38831 .9631 L
.38104 .97106 L
.37859 .97381 L
.37259 .98077 L
F
0 g
.70583 .98077 m
.69911 .97299 L
.69739 .97106 L
.68939 .96233 L
.68847 .96134 L
.67968 .95233 L
.67898 .95163 L
.66997 .943 L
.6688 .94192 L
.66026 .93434 L
.65775 .93221 L
.65054 .92634 L
.64555 .92249 L
.64083 .91902 L
.63177 .91278 L
.63112 .91236 L
.62141 .90637 L
.61553 .90307 L
.61169 .90105 L
.60198 .8964 L
.59474 .89336 L
.59227 .89241 L
.58256 .8891 L
.57284 .88645 L
.56313 .88447 L
.55824 .88364 L
.55342 .88316 L
.54371 .88251 L
.53399 .88254 L
.52428 .88323 L
.52032 .88364 L
.51457 .88459 L
.50486 .88662 L
.49514 .88932 L
.48543 .89269 L
.48369 .89336 L
.47572 .89672 L
.46601 .90142 L
.46289 .90307 L
.45629 .90679 L
.44666 .91278 L
.44658 .91283 L
.43687 .91954 L
.43287 .92249 L
.42716 .92692 L
.42068 .93221 L
.41744 .93496 L
.40962 .94192 L
.40773 .94367 L
.39944 .95163 L
Mistroke
.39802 .95305 L
.38996 .96134 L
.38831 .9631 L
.38104 .97106 L
.37859 .97381 L
.37259 .98077 L
Mfstroke
.325 g
.65757 .98077 m
.65054 .97506 L
.64534 .97106 L
.64083 .96774 L
.63151 .96134 L
.63112 .96109 L
.62141 .95511 L
.6152 .95163 L
.61169 .94979 L
.60198 .94515 L
.59424 .94192 L
.59227 .94117 L
.58256 .93786 L
.57284 .93522 L
.56313 .93325 L
.5563 .93221 L
.55342 .93194 L
.54371 .93131 L
.53399 .93134 L
.52428 .93204 L
.52255 .93221 L
.51457 .93341 L
.50486 .93545 L
.49514 .93815 L
.48543 .94153 L
.48441 .94192 L
.47572 .94557 L
.46601 .95028 L
.46345 .95163 L
.45629 .95566 L
.44714 .96134 L
.44658 .96171 L
.43687 .96843 L
.43331 .97106 L
.42716 .97581 L
.42108 .98077 L
F
0 g
.65757 .98077 m
.65054 .97506 L
.64534 .97106 L
.64083 .96774 L
.63151 .96134 L
.63112 .96109 L
.62141 .95511 L
.6152 .95163 L
.61169 .94979 L
.60198 .94515 L
.59424 .94192 L
.59227 .94117 L
.58256 .93786 L
.57284 .93522 L
.56313 .93325 L
.5563 .93221 L
.55342 .93194 L
.54371 .93131 L
.53399 .93134 L
.52428 .93204 L
.52255 .93221 L
.51457 .93341 L
.50486 .93545 L
.49514 .93815 L
.48543 .94153 L
.48441 .94192 L
.47572 .94557 L
.46601 .95028 L
.46345 .95163 L
.45629 .95566 L
.44714 .96134 L
.44658 .96171 L
.43687 .96843 L
.43331 .97106 L
.42716 .97581 L
.42108 .98077 L
s
.25 g
.57084 .98077 m
.56313 .97929 L
.55342 .97799 L
.54371 .97736 L
.53399 .9774 L
.52428 .97811 L
.51457 .97948 L
.50798 .98077 L
F
0 g
.57084 .98077 m
.56313 .97929 L
.55342 .97799 L
.54371 .97736 L
.53399 .9774 L
.52428 .97811 L
.51457 .97948 L
.50798 .98077 L
s
.925 g
.98077 .5573 m
.97951 .55342 L
.97638 .54371 L
.97325 .53399 L
.97106 .52725 L
.97009 .52428 L
.9669 .51457 L
.96367 .50486 L
.96134 .49789 L
.96043 .49514 L
.95716 .48543 L
.95386 .47572 L
.95163 .4692 L
.95054 .46601 L
.94719 .45629 L
.94381 .44658 L
.94192 .4412 L
.9404 .43687 L
.93696 .42716 L
.93349 .41744 L
.93221 .41387 L
.92999 .40773 L
.92646 .39802 L
.92289 .38831 L
.92249 .38723 L
.9193 .37859 L
.91566 .36888 L
.91278 .36127 L
.91199 .35917 L
.90828 .34946 L
.90453 .33974 L
.90307 .33599 L
.90075 .33003 L
.89692 .32032 L
.89336 .31139 L
.89304 .31061 L
.88913 .30089 L
.88517 .29118 L
.88364 .28747 L
.88117 .28147 L
.87711 .27176 L
.87393 .26423 L
.87301 .26204 L
.86885 .25233 L
.86463 .24262 L
.86422 .24167 L
.86037 .23291 L
.85604 .22319 L
.85451 .21979 L
.85165 .21348 L
.8472 .20377 L
.84479 .19859 L
.84268 .19406 L
.83809 .18434 L
.83508 .17808 L
.83342 .17463 L
.82868 .16492 L
.82537 .15824 L
.82386 .15521 L
.81895 .14549 L
.81566 .13908 L
.81395 .13578 L
.80885 .12607 L
.80594 .12061 L
.80366 .11636 L
.79835 .10664 L
.79623 .10281 L
.79294 .09693 L
.7874 .08722 L
.78652 .0857 L
.78173 .07751 L
.77681 .06927 L
.77592 .06779 L
.76995 .05808 L
.76709 .05352 L
.76383 .04837 L
.75752 .03866 L
.75738 .03845 L
.75102 .02894 L
.74767 .02406 L
.74431 .01923 L
.98077 .01923 L
F
0 g
.98077 .5573 m
.97951 .55342 L
.97638 .54371 L
.97325 .53399 L
.97106 .52725 L
.97009 .52428 L
.9669 .51457 L
.96367 .50486 L
.96134 .49789 L
.96043 .49514 L
.95716 .48543 L
.95386 .47572 L
.95163 .4692 L
.95054 .46601 L
.94719 .45629 L
.94381 .44658 L
.94192 .4412 L
.9404 .43687 L
.93696 .42716 L
.93349 .41744 L
.93221 .41387 L
.92999 .40773 L
.92646 .39802 L
.92289 .38831 L
.92249 .38723 L
.9193 .37859 L
.91566 .36888 L
.91278 .36127 L
.91199 .35917 L
.90828 .34946 L
.90453 .33974 L
.90307 .33599 L
.90075 .33003 L
.89692 .32032 L
.89336 .31139 L
.89304 .31061 L
.88913 .30089 L
.88517 .29118 L
.88364 .28747 L
.88117 .28147 L
.87711 .27176 L
.87393 .26423 L
.87301 .26204 L
.86885 .25233 L
.86463 .24262 L
.86422 .24167 L
.86037 .23291 L
.85604 .22319 L
.85451 .21979 L
.85165 .21348 L
Mistroke
.8472 .20377 L
.84479 .19859 L
.84268 .19406 L
.83809 .18434 L
.83508 .17808 L
.83342 .17463 L
.82868 .16492 L
.82537 .15824 L
.82386 .15521 L
.81895 .14549 L
.81566 .13908 L
.81395 .13578 L
.80885 .12607 L
.80594 .12061 L
.80366 .11636 L
.79835 .10664 L
.79623 .10281 L
.79294 .09693 L
.7874 .08722 L
.78652 .0857 L
.78173 .07751 L
.77681 .06927 L
.77592 .06779 L
.76995 .05808 L
.76709 .05352 L
.76383 .04837 L
.75752 .03866 L
.75738 .03845 L
.75102 .02894 L
.74767 .02406 L
.74431 .01923 L
Mfstroke
.85 g
.98077 .42918 m
.98012 .42716 L
.977 .41744 L
.97386 .40773 L
.97106 .39913 L
.97069 .39802 L
.9675 .38831 L
.96429 .37859 L
.96134 .36976 L
.96105 .36888 L
.95779 .35917 L
.9545 .34946 L
.95163 .34107 L
.95118 .33974 L
.94783 .33003 L
.94446 .32032 L
.94192 .31306 L
.94106 .31061 L
.93763 .30089 L
.93417 .29118 L
.93221 .28572 L
.93067 .28147 L
.92715 .27176 L
.92359 .26204 L
.92249 .25906 L
.92 .25233 L
.91638 .24262 L
.91278 .23308 L
.91272 .23291 L
.90902 .22319 L
.90528 .21348 L
.90307 .20778 L
.90151 .20377 L
.89769 .19406 L
.89383 .18434 L
.89336 .18315 L
.88993 .17463 L
.88599 .16492 L
.88364 .1592 L
.882 .15521 L
.87796 .14549 L
.87393 .13593 L
.87387 .13578 L
.86973 .12607 L
.86554 .11636 L
.86422 .11333 L
.86129 .10664 L
.85698 .09693 L
.85451 .09141 L
.85261 .08722 L
.84818 .07751 L
.84479 .07017 L
.84369 .06779 L
.83912 .05808 L
.83508 .04961 L
.83448 .04837 L
.82977 .03866 L
.82537 .02972 L
.82498 .02894 L
.82011 .01923 L
.98077 .01923 L
F
0 g
.98077 .42918 m
.98012 .42716 L
.977 .41744 L
.97386 .40773 L
.97106 .39913 L
.97069 .39802 L
.9675 .38831 L
.96429 .37859 L
.96134 .36976 L
.96105 .36888 L
.95779 .35917 L
.9545 .34946 L
.95163 .34107 L
.95118 .33974 L
.94783 .33003 L
.94446 .32032 L
.94192 .31306 L
.94106 .31061 L
.93763 .30089 L
.93417 .29118 L
.93221 .28572 L
.93067 .28147 L
.92715 .27176 L
.92359 .26204 L
.92249 .25906 L
.92 .25233 L
.91638 .24262 L
.91278 .23308 L
.91272 .23291 L
.90902 .22319 L
.90528 .21348 L
.90307 .20778 L
.90151 .20377 L
.89769 .19406 L
.89383 .18434 L
.89336 .18315 L
.88993 .17463 L
.88599 .16492 L
.88364 .1592 L
.882 .15521 L
.87796 .14549 L
.87393 .13593 L
.87387 .13578 L
.86973 .12607 L
.86554 .11636 L
.86422 .11333 L
.86129 .10664 L
.85698 .09693 L
.85451 .09141 L
.85261 .08722 L
Mistroke
.84818 .07751 L
.84479 .07017 L
.84369 .06779 L
.83912 .05808 L
.83508 .04961 L
.83448 .04837 L
.82977 .03866 L
.82537 .02972 L
.82498 .02894 L
.82011 .01923 L
Mfstroke
.775 g
.98077 .33534 m
.97906 .33003 L
.97594 .32032 L
.97279 .31061 L
.97106 .3053 L
.96961 .30089 L
.96642 .29118 L
.96319 .28147 L
.96134 .27593 L
.95995 .27176 L
.95667 .26204 L
.95337 .25233 L
.95163 .24724 L
.95005 .24262 L
.94669 .23291 L
.94331 .22319 L
.94192 .21922 L
.9399 .21348 L
.93646 .20377 L
.93299 .19406 L
.93221 .19188 L
.92949 .18434 L
.92595 .17463 L
.92249 .16521 L
.92239 .16492 L
.91879 .15521 L
.91515 .14549 L
.91278 .13922 L
.91148 .13578 L
.90777 .12607 L
.90402 .11636 L
.90307 .11391 L
.90023 .10664 L
.89641 .09693 L
.89336 .08927 L
.89254 .08722 L
.88862 .07751 L
.88466 .06779 L
.88364 .06531 L
.88066 .05808 L
.87661 .04837 L
.87393 .04202 L
.8725 .03866 L
.86835 .02894 L
.86422 .01942 L
.86414 .01923 L
.98077 .01923 L
F
0 g
.98077 .33534 m
.97906 .33003 L
.97594 .32032 L
.97279 .31061 L
.97106 .3053 L
.96961 .30089 L
.96642 .29118 L
.96319 .28147 L
.96134 .27593 L
.95995 .27176 L
.95667 .26204 L
.95337 .25233 L
.95163 .24724 L
.95005 .24262 L
.94669 .23291 L
.94331 .22319 L
.94192 .21922 L
.9399 .21348 L
.93646 .20377 L
.93299 .19406 L
.93221 .19188 L
.92949 .18434 L
.92595 .17463 L
.92249 .16521 L
.92239 .16492 L
.91879 .15521 L
.91515 .14549 L
.91278 .13922 L
.91148 .13578 L
.90777 .12607 L
.90402 .11636 L
.90307 .11391 L
.90023 .10664 L
.89641 .09693 L
.89336 .08927 L
.89254 .08722 L
.88862 .07751 L
.88466 .06779 L
.88364 .06531 L
.88066 .05808 L
.87661 .04837 L
.87393 .04202 L
.8725 .03866 L
.86835 .02894 L
.86422 .01942 L
.86414 .01923 L
s
.7 g
.98077 .25759 m
.97908 .25233 L
.97595 .24262 L
.9728 .23291 L
.97106 .22755 L
.96963 .22319 L
.96643 .21348 L
.96321 .20377 L
.96134 .19818 L
.95996 .19406 L
.95669 .18434 L
.95339 .17463 L
.95163 .16948 L
.95007 .16492 L
.94671 .15521 L
.94333 .14549 L
.94192 .14146 L
.93992 .13578 L
.93648 .12607 L
.93301 .11636 L
.93221 .11412 L
.92951 .10664 L
.92598 .09693 L
.92249 .08745 L
.92241 .08722 L
.91881 .07751 L
.91517 .06779 L
.91278 .06146 L
.9115 .05808 L
.90779 .04837 L
.90405 .03866 L
.90307 .03614 L
.90026 .02894 L
.89643 .01923 L
.98077 .01923 L
F
0 g
.98077 .25759 m
.97908 .25233 L
.97595 .24262 L
.9728 .23291 L
.97106 .22755 L
.96963 .22319 L
.96643 .21348 L
.96321 .20377 L
.96134 .19818 L
.95996 .19406 L
.95669 .18434 L
.95339 .17463 L
.95163 .16948 L
.95007 .16492 L
.94671 .15521 L
.94333 .14549 L
.94192 .14146 L
.93992 .13578 L
.93648 .12607 L
.93301 .11636 L
.93221 .11412 L
.92951 .10664 L
.92598 .09693 L
.92249 .08745 L
.92241 .08722 L
.91881 .07751 L
.91517 .06779 L
.91278 .06146 L
.9115 .05808 L
.90779 .04837 L
.90405 .03866 L
.90307 .03614 L
.90026 .02894 L
.89643 .01923 L
s
.625 g
.98077 .18972 m
.97905 .18434 L
.97592 .17463 L
.97277 .16492 L
.97106 .15967 L
.96959 .15521 L
.9664 .14549 L
.96317 .13578 L
.96134 .1303 L
.95993 .12607 L
.95665 .11636 L
.95335 .10664 L
.95163 .10161 L
.95003 .09693 L
.94667 .08722 L
.94329 .07751 L
.94192 .07359 L
.93988 .06779 L
.93644 .05808 L
.93297 .04837 L
.93221 .04624 L
.92947 .03866 L
.92594 .02894 L
.92249 .01957 L
.92237 .01923 L
.98077 .01923 L
F
0 g
.98077 .18972 m
.97905 .18434 L
.97592 .17463 L
.97277 .16492 L
.97106 .15967 L
.96959 .15521 L
.9664 .14549 L
.96317 .13578 L
.96134 .1303 L
.95993 .12607 L
.95665 .11636 L
.95335 .10664 L
.95163 .10161 L
.95003 .09693 L
.94667 .08722 L
.94329 .07751 L
.94192 .07359 L
.93988 .06779 L
.93644 .05808 L
.93297 .04837 L
.93221 .04624 L
.92947 .03866 L
.92594 .02894 L
.92249 .01957 L
.92237 .01923 L
s
.55 g
.98077 .1287 m
.97993 .12607 L
.9768 .11636 L
.97366 .10664 L
.97106 .09866 L
.97049 .09693 L
.9673 .08722 L
.96409 .07751 L
.96134 .06929 L
.96084 .06779 L
.95758 .05808 L
.95429 .04837 L
.95163 .04059 L
.95097 .03866 L
.94762 .02894 L
.94425 .01923 L
.98077 .01923 L
F
0 g
.98077 .1287 m
.97993 .12607 L
.9768 .11636 L
.97366 .10664 L
.97106 .09866 L
.97049 .09693 L
.9673 .08722 L
.96409 .07751 L
.96134 .06929 L
.96084 .06779 L
.95758 .05808 L
.95429 .04837 L
.95163 .04059 L
.95097 .03866 L
.94762 .02894 L
.94425 .01923 L
s
.475 g
.98077 .07281 m
.97916 .06779 L
.97603 .05808 L
.97288 .04837 L
.97106 .04276 L
.96971 .03866 L
.96651 .02894 L
.96329 .01923 L
.98077 .01923 L
F
0 g
.98077 .07281 m
.97916 .06779 L
.97603 .05808 L
.97288 .04837 L
.97106 .04276 L
.96971 .03866 L
.96651 .02894 L
.96329 .01923 L
s
.4 g
.98077 .02093 m
.98023 .01923 L
.98077 .01923 L
F
0 g
.98077 .02093 m
.98023 .01923 L
s
0 0 0 r
.055 w
.97602 .78218 Mdot
1 0 0 r
.0325 w
.01923 .78218 Mdot
.33371 .98077 Mdot
.09568 .83046 Mdot
.09386 .82807 Mdot
.0936 .82644 Mdot
.09392 .82297 Mdot
.09631 .8104 Mdot
.10405 .77863 Mdot
.12414 .70608 Mdot
.15136 .61887 Mdot
.18883 .51573 Mdot
.23885 .40789 Mdot
.28608 .33284 Mdot
.43908 .01923 Mdot
.32312 .25693 Mdot
.39714 .14482 Mdot
.41211 .16272 Mdot
.48523 .09751 Mdot
.51896 .09174 Mdot
.5547 .1236 Mdot
.73319 .10878 Mdot
.60093 .11976 Mdot
.77963 .1353 Mdot
.62632 .12197 Mdot
.64427 .131 Mdot
.68681 .16705 Mdot
.71616 .21142 Mdot
.77663 .28392 Mdot
.74596 .24715 Mdot
.79803 .33134 Mdot
.81766 .38714 Mdot
.88181 .50424 Mdot
.84016 .42821 Mdot
.98077 .70105 Mdot
.86297 .47246 Mdot
.8796 .50863 Mdot
.89216 .54121 Mdot
.91265 .59904 Mdot
.94777 .68904 Mdot
.92654 .63463 Mdot
.95072 .70244 Mdot
.95708 .72522 Mdot
.97018 .76332 Mdot
.97303 .77257 Mdot
.97544 .78036 Mdot
.976 .78211 Mdot
.976 .78213 Mdot
.97602 .78219 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
0 1 0 r
.02 w
.01923 .78218 Mdot
.33371 .98077 Mdot
.09568 .83046 Mdot
.09386 .82807 Mdot
.0936 .82644 Mdot
.09392 .82297 Mdot
.09631 .8104 Mdot
.10405 .77863 Mdot
.12414 .70608 Mdot
.15136 .61887 Mdot
.18883 .51573 Mdot
.23885 .40789 Mdot
.28608 .33284 Mdot
.43908 .01923 Mdot
.32312 .25693 Mdot
.39714 .14482 Mdot
.41211 .16272 Mdot
.48523 .09751 Mdot
.51896 .09174 Mdot
.5547 .1236 Mdot
.73319 .10878 Mdot
.60093 .11976 Mdot
.77963 .1353 Mdot
.62632 .12197 Mdot
.64427 .131 Mdot
.68681 .16705 Mdot
.71616 .21142 Mdot
.77663 .28392 Mdot
.74596 .24715 Mdot
.79803 .33134 Mdot
.81766 .38714 Mdot
.88181 .50424 Mdot
.84016 .42821 Mdot
.98077 .70105 Mdot
.86297 .47246 Mdot
.8796 .50863 Mdot
.89216 .54121 Mdot
.91265 .59904 Mdot
.94777 .68904 Mdot
.92654 .63463 Mdot
.95072 .70244 Mdot
.95708 .72522 Mdot
.97018 .76332 Mdot
.97303 .77257 Mdot
.97544 .78036 Mdot
.976 .78211 Mdot
.976 .78213 Mdot
.97602 .78219 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
0 0 1 r
.5 Mabswid
.01923 .78218 m
.01923 .78218 L
.09568 .83046 L
.09386 .82807 L
.0936 .82644 L
.09392 .82297 L
.09631 .8104 L
.10405 .77863 L
.12414 .70608 L
.15136 .61887 L
.18883 .51573 L
.23885 .40789 L
.28608 .33284 L
.32312 .25693 L
.39714 .14482 L
.41211 .16272 L
.48523 .09751 L
.51896 .09174 L
.5547 .1236 L
.60093 .11976 L
.62632 .12197 L
.64427 .131 L
.68681 .16705 L
.71616 .21142 L
.74596 .24715 L
.79803 .33134 L
.81766 .38714 L
.84016 .42821 L
.86297 .47246 L
.8796 .50863 L
.89216 .54121 L
.91265 .59904 L
.92654 .63463 L
.95072 .70244 L
.95708 .72522 L
.97018 .76332 L
.97303 .77257 L
.97544 .78036 L
.976 .78211 L
.976 .78213 L
.97602 .78219 L
.97602 .78218 L
.97602 .78218 L
.97602 .78218 L
s
.015 w
.01923 .78218 Mdot
.01923 .78218 Mdot
.09568 .83046 Mdot
.09386 .82807 Mdot
.0936 .82644 Mdot
.09392 .82297 Mdot
.09631 .8104 Mdot
.10405 .77863 Mdot
.12414 .70608 Mdot
.15136 .61887 Mdot
.18883 .51573 Mdot
.23885 .40789 Mdot
.28608 .33284 Mdot
.32312 .25693 Mdot
.39714 .14482 Mdot
.41211 .16272 Mdot
.48523 .09751 Mdot
.51896 .09174 Mdot
.5547 .1236 Mdot
.60093 .11976 Mdot
.62632 .12197 Mdot
.64427 .131 Mdot
.68681 .16705 Mdot
.71616 .21142 Mdot
.74596 .24715 Mdot
.79803 .33134 Mdot
.81766 .38714 Mdot
.84016 .42821 Mdot
.86297 .47246 Mdot
.8796 .50863 Mdot
.89216 .54121 Mdot
.91265 .59904 Mdot
.92654 .63463 Mdot
.95072 .70244 Mdot
.95708 .72522 Mdot
.97018 .76332 Mdot
.97303 .77257 Mdot
.97544 .78036 Mdot
.976 .78211 Mdot
.976 .78213 Mdot
.97602 .78219 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{288, 288},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00B`3oool7000004P0oooo1000
00060?ooo`8000001P3oool4000004D0oooo1000001:0?ooo`@000001P3oool2000000H0oooo1000
00180?ooo`L00000203oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool02@3oool004h0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool02@3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool02@3oool00480oooo1P0000060?ooo`030000
003oool0oooo03l0oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`090?ooo`00CP3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool4000004@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool4000004/0oooo00<000000?ooo`3oool02@3oool004h0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02@3oool0
04`0oooo0`00001:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0BP3oool30000
00/0oooo001>0?ooo`030000003oool0oooo04T0oooo1000000>0?ooo`D00000A03oool4000004X0
oooo1000000>0?ooo`D00000BP3oool00`000000oooo0?ooo`090?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`007`3ooooo0000094000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
:P3oool20?l002L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo00H0oooo0@0000010?ooo`007`3oool300000:T0oooo203o003J0?ooo`8000000@3o
ool001l0oooo00<000000?ooo`3oool0Z03oool:0?l00=X0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`2X0?ooo`<0o`000`00o`040?l00=X0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`2X0?ooo`80o`001@00o`030?l00=X0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01/0oooo0P3o0007003o00<0o`00L`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?oooaL0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001i
NGT0NGUi00@0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO09nOW`0609nOW`030000002c
/k<0/k>c00L0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/
k>`0k>c/01h0k>c/00<000000?ooo`3oool06`3oool20?l000L00?l00`3o001d0?ooo`030000003/
k>`0k>c/01/0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c
/k<0/k>c00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00508b<S0030000001i
NGT0NGUi00@0NGUi00<000000?ooo`3oool0103oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo5P0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00@0IVIV00<00000
07UiN@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<00000
0;>c/`2c/k<0202c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00h0fMWI00<00000
0>c/k03/k>`07@3/k>`00`000000oooo0?ooo`0M0?ooo`030?l00000o`000?l000D00?l00P3o001f
0?ooo`030000003/k>`0k>c/01/0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0:
0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil00`000000S8b<08b<S005
08b<S0030000001iNGT0NGUi00@0NGUi1`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo5P0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007Ui
N@1iNGT0101iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00H0WinO00<000000;>c
/`2c/k<01`2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/
k03/k>`07P3/k>`00`000000oooo0?ooo`0M0?ooo`80o`001@00o`030?l007H0oooo00<000000>c/
k03/k>`06`3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600X0a/K600<000000;>c
/`2c/k<01`2c/k<00`000000WinO09nOW`0609nOW`030000002<S8`0S8b<00D0S8b<00<0000007Ui
N@1iNGT00`1iNGT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3ooolF03lo?`03
0000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@03
0000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`070;>c/`03
00000036a/H0a/K600X0a/K600<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00M0>c/k003
0000003oool0oooo01h0oooo0`3o0003003o00@0o`00M`3oool00`000000k>c/0>c/k00K0>c/k003
0000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02P36a/H00`000000/k>c0;>c/`070;>c/`03
0000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000NGUi07UiN@0307UiN@L0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oooaH0?clo00<0000005=CD`1CDe<0
0P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0
1@2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00P0/k>c00<000000<K6aP36a/H0
2P36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/01`0k>c/00<000000?ooo`3oool0
803oool80?l007T0oooo00<000000>c/k03/k>`06P3/k>`00`000000fMWI0=WIf@0>0=WIf@030000
0036a/H0a/K600X0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`030000
002<S8`0S8b<00D0S8b<00<0000007UiN@1iNGT00`1iNGT70?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3ooolE03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1V
IVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01P2O
Wil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3IfMT03`3I
fMT00`000000k>c/0>c/k00M0>c/k0030000003oool0oooo02<0oooo0P3o001l0?ooo`030000003/
k>`0k>c/01X0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0;0<K6aP030000002c
/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00408b<S0030000001i
NGT0NGUi00<0NGUi1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo5@0o?cl0
0`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT0
0`000000S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<0202c/k<0
0`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`0703/k>`0
0`000000oooo0?ooo`2S0?ooo`030000003/k>`0k>c/01X0k>c/00<000000=WIf@3IfMT03P3IfMT0
0`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil0
0`000000S8b<08b<S00508b<S0030000001iNGT0NGUi0080NGUi1`3oool100000040oooo000O0?oo
o`030000003oool0oooo00D0oooo5@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV
00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO
00D0WinO00<000000;>c/`2c/k<0202c/k<00`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI
00h0fMWI00<000000>c/k03/k>`0703/k>`00`000000oooo0?ooo`2U0?ooo`030000003/k>`0k>c/
01T0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c
00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00408b<S0030000001iNGT0NGUi
0080NGUi1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo5@0o?cl00`000000
De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000
S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c/k<00`000000
a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`06`3/k>`00`000000
oooo0?ooo`2V0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000
a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000
S8b<08b<S00408b<S0030000001iNGT0NGUi0080NGUi1`3oool100000040oooo000O0?ooo`<00000
1@3ooolD03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi
07UiN@0507UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c
0;>c/`080;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/
0>c/k00L0>c/k0030000003oool0oooo0:L0oooo00<000000>c/k03/k>`06@3/k>`00`000000fMWI
0=WIf@0>0=WIf@0300000036a/H0a/K600X0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO
09nOW`0509nOW`030000002<S8`0S8b<00D0S8b<00@0000007UiN@1iNGT0NGUi1P3oool200000040
oooo000O0?ooo`030000003oool0oooo00D0oooo500o?cl00`000000De=C05=CD`0205=CD`030000
001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000
002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP0;0<K6aP030000
003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`06`3/k>`00`000000oooo0?ooo`2X0?ooo`030000
003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0:0<K6aP030000
002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00408b<S0040000
001iNGT0NGUi07UiN@L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oooa<0?clo
0P00000405=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<
08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K6
0<K6aP0:0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`06`3/k>`00`000000oooo
0?ooo`2Y0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K6
0<K6aP0:0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil00`000000S8b<
08b<S00408b<S0040000001iNGT0NGUi07UiN@L0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?oooa<0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0306IVIP030000
001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO09nOW`0609nOW`030000
002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0?0=WIf@030000
003/k>`0k>c/01/0k>c/00<000000?ooo`3oool0ZP3oool00`000000k>c/0>c/k00J0>c/k0030000
003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02P36a/H00`000000/k>c0;>c/`070;>c/`030000
002OWil0WinO00D0WinO00<0000008b<S02<S8`0102<S8`010000000NGUi07UiN@1iNGT70?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3ooolB03lo?`030000001CDe<0De=C00<0De=C
00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00@0S8b<
00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600X0a/K6
00<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00J0>c/k0030000003oool0oooo0:`0oooo
00<000000>c/k03/k>`06@3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600T0a/K6
00<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0S8b<00D0S8b<
00<0000007UiN@1iNGT01`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo4P0o
?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1i
NGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c
/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`06`3/
k>`00`000000oooo0?ooo`2]0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03@3I
fMT00`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2O
Wil00`000000S8b<08b<S00408b<S0030000001iNGT0NGUi00L0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?oooa80?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP03
06IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO09nOW`06
09nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0?
0=WIf@030000003/k>`0k>c/01X0k>c/00<000000?ooo`3oool0[`3oool00`000000k>c/0>c/k00H
0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`07
0;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000NGUi0?ooo`06
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3ooolB03lo?`030000001CDe<0De=C
0080De=C00<0000006IVIP1VIVH0101VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<
00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K6
00X0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00J0>c/k0030000003oool0oooo
0;00oooo00<000000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K6
00X0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0S8b<
00D0S8b<00<0000007UiN@3oool01P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo4@0o?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1i
NGT00`1iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c
/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/
k>`06P3/k>`00`000000oooo0?ooo`2a0?ooo`030000003/k>`0k>c/01P0k>c/00<000000=WIf@3I
fMT03P3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2O
Wil01P2OWil00`000000S8b<08b<S00408b<S0030000001iNGT0oooo00H0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`050?oooa40?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV
06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO
09nOW`0509nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI
0=WIf@0>0=WIf@030000003/k>`0k>c/01X0k>c/00<000000?ooo`3oool0/P3oool00`000000k>c/
0>c/k00H0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c
0;>c/`070;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000oooo
0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3ooolA03lo?`030000001C
De<0De=C00<0De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<
S8`0S8b<00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036
a/H0a/K600X0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00J0>c/k0030000003o
ool0oooo0;<0oooo00<000000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036
a/H0a/K600T0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0609nOW`030000002<
S8`0S8b<00@0S8b<00<000000?ooo`3oool01@3oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo4@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<00000
07UiN@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<00000
0;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00h0fMWI00<00000
0>c/k03/k>`06P3/k>`00`000000oooo0?ooo`2d0?ooo`030000003/k>`0k>c/01P0k>c/00<00000
0=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00L0/k>c00<00000
09nOW`2OWil01P2OWil00`000000S8b<08b<S00408b<S0030000003oool0oooo00D0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?oooa00?clo00<0000005=CD`1CDe<00`1CDe<00`00
0000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`00
0000WinO09nOW`0609nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02P36a/H00`00
0000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/01T0k>c/00<000000?ooo`3oool0]P3oool00`00
0000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02@36a/H00`00
0000/k>c0;>c/`070;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`00
0000oooo0?ooo`040?ooo`4000000@3oool001l0oooo0`0000050?oooa00?clo00<0000005=CD`1C
De<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<
S8`0102<S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36
a/H02@36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/01X0k>c/00<000000?ooo`3o
ool0]P3oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36
a/H02@36a/H00`000000/k>c0;>c/`070;>c/`030000002OWil0WinO00H0WinO00<0000008b<S02<
S8`0102<S8`60?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool@03lo?`030000
001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000
002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`070;>c/`030000
0036a/H0a/K600T0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00I0>c/k0030000
003oool0oooo04l0oooo0P3o001W0?ooo`030000003/k>`0k>c/01P0k>c/00<000000=WIf@3IfMT0
3@3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil0
1@2OWil00`000000S8b<08b<S00408b<S0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?oooa00?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001i
NGT0NGUi00@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c
/k<0/k>c00L0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/
k>`0k>c/01T0k>c/00<000000?ooo`3oool0C@3oool80?l006D0oooo00<000000>c/k03/k>`05`3/
k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01`2c
/k<00`000000WinO09nOW`0509nOW`030000002<S8`0S8b<00@0S8b<1`3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo400o?cl01@000000De=C05=CD`1CDe<0000000D0IVIV00<0
000007UiN@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<0
00000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00h0fMWI00<0
00000>c/k03/k>`06@3/k>`00`000000oooo0?ooo`1<0?ooo`X0o`00I03oool00`000000k>c/0>c/
k00H0>c/k0030000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c
/`070;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`0102<S8`70?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool?03lo?`030000001CDe<0De=C0080De=C00<00000
06IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00@0S8b<00<00000
09nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600X0a/K600<00000
0=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00I0>c/k0030000003oool0oooo04<0oooo0P3o0008
0?ooo`<0o`000`00o`040?l006D0oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI0=WIf@0=
0=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`05
09nOW`030000002<S8`0S8b<00<0S8b<1`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo3`0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007Ui
N@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c
/`2c/k<01`2c/k<00`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/
k03/k>`06@3/k>`00`000000oooo0?ooo`100?ooo`P0o`001@3oool20?l00005003o00000?l0003o
0000o`00o`000`3o001V0?ooo`030000003/k>`0k>c/01L0k>c/00<000000=WIf@3IfMT0303IfMT2
000000X0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0
S8b<00<0S8b<1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo3`0o?cl00`00
0000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`00
0000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01`2c/k<00`00
0000a/K60<K6aP090<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`0603/k>`00`00
0000oooo0?ooo`100?ooo`@0o`000`00o`030?l000<0oooo0P3o00000`00o`00003o0000o`030000
o`04003o003o0000o`000?l006H0oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0=
0=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`06
09nOW`030000002<S8`0S8b<0080S8b<1`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo3P0o?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV0080IVIV00<0000007Ui
N@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c
/`2c/k<01`2c/k<00`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/
k03/k>`06@3/k>`00`000000oooo0?ooo`100?ooo`<0o`0000D00?l00000o`000?l0003o003o0002
0?l00080oooo2@000?l01000o`00o`000?l0003o001V0?ooo`030000003/k>`0k>c/01H0k>c/00<0
00000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0/k>c00<0
000009nOW`2OWil01@2OWil00`000000S8b<08b<S00208b<S0L0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`h0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP03
06IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`05
09nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0>
0=WIf@030000003/k>`0k>c/01P0k>c/00<000000?ooo`3oool0@@3oool20?l00003003o00000?l0
003o00L0003o0P3oool00`3o00000?l00000o`040000o`03003o003o0000o`0004l0oooo0P3o000G
0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP09
0<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil010000000S8b<08b<S02<
S8`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool>03lo?`030000001CDe<0
De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0
S8b<00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0
a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00H0>c/k0030000003oool0
oooo0440oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0000<0oooo0P3o0000
1@00o`00003o0000o`000?l00?l00080003o00<0o`000?ooo`3oool0BP3oool80?l001@0oooo00<0
00000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600T0a/K600<0
00000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0609nOW`040000002<S8`0S8b<08b<S0L0oooo
0@0000010?ooo`00503oool4000000L0oooo00<000000?ooo`3oool01@3oool=03lo?`030000001C
De<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000002<
S8`0S8b<00@0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`060;>c/`0300000036
a/H0a/K600T0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00H0>c/k0030000003o
ool0oooo0440oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0000<0oooo0`3o
0003003o00<0o`0000<0003o0?ooo`3oool0B@3oool:0?l001@0oooo00<000000>c/k03/k>`05P3/
k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01`2c
/k<00`000000WinO09nOW`0509nOW`040000002<S8`0S8b<08b<S0L0oooo0@0000010?ooo`004`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool=03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07Ui
N@0307UiN@030000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c
/`070;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/
k00H0>c/k0030000003oool0oooo04<0oooo0`3o00040000o`03003o003o0000o`0000D0oooo203o
00000`3oool0003o0?ooo`190?ooo`<0o`000`00o`040?l001@0oooo00<000000>c/k03/k>`05P3/
k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01P2c
/k<00`000000WinO09nOW`0609nOW`030000002<S8`0S8b<00L0oooo0@0000010?ooo`004`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool=
03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@03
07UiN@030000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`07
0;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00H
0>c/k0030000003oool0oooo04<0oooo0P3o00000`000?l0o`00003o0002003o00<0o`00203oool2
0?l000D0oooo00<0003o0?ooo`3oool0A`3oool20?l000D00?l00`3o000E0?ooo`030000003/k>`0
k>c/01H0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0
/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil00`000000S8b<08b<S0070?ooo`4000000@3oool0
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`@00000103oool=03lo
?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0407Ui
N@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`060;>c
/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00H0>c/
k0030000003oool0oooo04@0oooo0P000?l80?l00100oooo00<0003o0?ooo`3oool05@3oool20?l0
00P0oooo0P3o000T0?ooo`80o`001`00o`030?l001@0oooo00<000000>c/k03/k>`05P3/k>`00`00
0000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01`2c/k<00`00
0000WinO09nOW`0509nOW`030000002<S8`0S8b<00D0oooo0`0000010?ooo`004`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool<03lo?`03
0000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@03
0000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c/`03
00000036a/H0a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00H0>c/k003
0000003oool0oooo04<0oooo00<0003o0?ooo`3o00001`3o000B0?ooo`030000o`3oool0oooo0080
oooo0P3o000=0?ooo`P0o`000P3oool80?l00240oooo0P3o0007003o00<0o`005@3oool00`000000
k>c/0>c/k00F0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02036a/H00`000000
/k>c0;>c/`060;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`01`3oool100000040
oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo``0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000
001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0609nOW`030000
002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0=0=WIf@030000
003/k>`0k>c/01P0k>c/00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`030?ooo`80o`00
5P3oool00`000?l0o`000?l000060?l000T0oooo103o0003003o00d0o`008@3oool00`3o00000?l0
003o0005003o0080o`005P3oool00`000000k>c/0>c/k00F0>c/k0030000003IfMT0fMWI00d0fMWI
00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`070;>c/`030000002OWil0WinO00D0WinO
00<0000008b<S03oool01P3oool100000040oooo000C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo``0?clo00<0000005=CD`1CDe<00P1C
De<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<
S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36
a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/01P0k>c/00<000000?ooo`3oool0@P3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l000000?l0003o00L0o`00203oool30?l00005003o0000
0?l0003o0000o`00o`001P3o0003003o00<0o`008@3oool20?l000D00?l00`3o000G0?ooo`030000
003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6aP090<K6aP030000
002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01@2OWil00`000000S8b<0?ooo`060?ooo`400000
0@3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo2`0o?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<0
000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<0
00000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00d0fMWI00<0
00000>c/k03/k>`05`3/k>`00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo01d0oooo0`3o
00000`000?l00?l0003o00040?l000P0oooo0P3o00000`00o`00003o0000o`030000o`03003o003o
0000o`000080o`0000D00?l00000o`000?l0003o003o00020?l00080oooo0P3o000M0?ooo`<0o`00
0`00o`040?l001L0oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0<0=WIf@030000
0036a/H0a/K600T0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0509nOW`030000
002<S8`0oooo00H0oooo0@0000010?ooo`00503oool4000000L0oooo00<000000?ooo`3oool01@3o
ool;03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07Ui
N@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c
/`060;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/
k00G0>c/k0030000003oool0oooo0440oooo00<0003o0?ooo`3oool07P3oool20?l00005003o0000
0?l0003o0000o`00o`000`3o00050?oooaD0003o00<00?l00?l0003o00001P3o000K0?ooo`P0o`00
6@3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H0
2036a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00D0WinO00<0000008b<S03oool0
1P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo2P0o?cl00`000000De=C05=C
D`0305=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<
S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K60<K6
aP090<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`05`3/k>`00`000000oooo0?oo
o`110?ooo`030000o`3oool0oooo01h0oooo0P3o00000`00o`00003o0000o`0;0000o`80oooo0`3o
00000`00o`00003o0000o`030000o`05003o003o0000o`000?l00000o`001@000?l00`00o`00o`00
0?l000070?l001d0oooo0P3o000@0?ooo`80o`002P3oool00`000000k>c/0>c/k00F0>c/k0030000
003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`060;>c/`030000
002OWil0WinO00D0WinO00<000000?ooo`3oool01@3oool100000040oooo000O0?ooo`030000003o
ool0oooo00D0oooo2P0o?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<0
000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<0
00000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00`0fMWI00<0
00000>c/k03/k>`0603/k>`00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo01l0oooo0P3o
00000`00o`00003o0000o`030000o`04003o003o0000o`000?l000L0oooo0`3o00001@00o`00003o
0000o`000?l00?l000@0o`0000<00?l00000o`000?l01@000?l0103o00000?l0003o0000o`040?l0
02`0oooo203o00080?ooo`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT03@3IfMT00`00
0000a/K60<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01@2OWil00`00
0000oooo0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool:03lo?`03
0000001CDe<0De=C00<0De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0307UiN@03
0000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`03
00000036a/H0a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00G0>c/k003
0000003oool0oooo0400oooo00<0003o0?ooo`3oool08@3oool00`3o00000?l00000o`040000o`03
003o003o0000o`0000P0oooo103o0003003o00H0o`0000D00?l00000o`000?l0003o003o00020?l0
00@0003o00@00?l00?l0003o0000o`00:`3oool40?l000<00?l00`3o00070?ooo`030000003/k>`0
k>c/01D0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0
/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil00`000000oooo0?ooo`040?ooo`4000000@3oool0
01l0oooo00<000000?ooo`3oool01@3oool903lo?`030000001CDe<0De=C00<0De=C00<0000006IV
IP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nO
W`2OWil01P2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600T0a/K600<000000=WI
f@3IfMT0303IfMT00`000000k>c/0>c/k00H0>c/k0030000003oool0oooo03h0oooo0P000?lT0?oo
o`80o`0000D00?l00000o`000?l0003o003o00030?l000P0oooo3P3o0003003o0080o`0000<00?l0
0000o`000?l00`000?l01000o`00o`000?l0003o000Z0?ooo`<0o`001@00o`020?l000P0oooo00<0
00000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600P0a/K600<0
00000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`L0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`T0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP02
06IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`05
09nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0=
0=WIf@030000003/k>`0k>c/01L0k>c/00<000000?ooo`3oool0:P3oool20?l00180oooo00<0003o
0?ooo`3oool0903oool30?l000<00?l0103o00090?ooo`P0o`000P3oool80?l00003003o00000?l0
003o00<0003o00@00?l00?l0003o0000o`00:P3oool20?l000L00?l000<0o`000?ooo`3oool01P3o
ool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02036
a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00D0WinO1`3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo2@0o?cl00`000000De=C05=CD`0305=CD`030000001VIVH0
IVIV0080IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0
WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0
fMWI00d0fMWI00<000000>c/k03/k>`05`3/k>`00`000000oooo0?ooo`0W0?ooo`P0o`003P3oool0
0`000?l0oooo0?ooo`0V0?ooo`P0o`003@3oool20?l000P0oooo0P3o00020?ooo`030?l00000o`00
003o00D0003o0P3o000Z0?ooo`<0o`001`00o`020?l000P0oooo00<000000>c/k03/k>`05@3/k>`0
0`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01`2c/k<0
0`000000WinO09nOW`0409nOW`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`T0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi
00@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c
00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/
01H0k>c/00<000000?ooo`3oool09`3oool30?l000<00?l0103o000<0?ooo`030000o`3oool0oooo
02X0oooo0P3o000N0?ooo`80o`0000P00?l00000o`000?l0003o003o003o0000003o0?l002X0oooo
0`3o0007003o0080o`002@3oool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI00d0fMWI
00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`070;>c/`030000002OWil0WinO00@0WinO
1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo200o?cl00`000000De=C05=C
D`0305=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<
S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K60<K6
aP080<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`05`3/k>`00`000000oooo0?oo
o`0W0?ooo`80o`0000D00?l00000o`000?l0003o003o00030?l000/0oooo00<0003o0?ooo`3oool0
B`3oool30?l000<00?l00`3o00000`000?l0oooo0?ooo`0Y0?ooo`<0o`001@00o`020?l000X0oooo
00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600P0a/K6
00<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0409nOW`L0oooo0@0000010?ooo`007`3o
ool3000000D0oooo200o?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<0
000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<0
00000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00d0fMWI00<0
00000>c/k03/k>`05P3/k>`00`000000oooo0?ooo`0X0?ooo`030?l00000o`00003o00@0003o00<0
0?l00?l0003o00002P3oool00`000?l0oooo0?ooo`1=0?ooo`P0o`0000<0oooo0000o`3oool0:@3o
ool40?l000<00?l00`3o000;0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT0303I
fMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil00`2O
Wil60?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool803lo?`030000001CDe<0
De=C00<0De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0
S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0
a/K600T0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00G0>c/k0030000003oool0
oooo02L0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l000P0oooo00<0
003o0?ooo`3oool0D@3oool20?l000D0oooo00<0003o0?ooo`3oool09`3oool:0?l000/0oooo00<0
00000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600T0a/K600<0
00000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0309nOW`L0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`P0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP03
06IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`05
09nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0=
0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0:03oool20?l00003003o00000?l0
003o00<0003o00@00?l00?l0003o0000o`001`3oool00`000?l0oooo0?ooo`1J0?ooo`80003o:03o
ool80?l000`0oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036
a/H0a/K600T0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0309nOW`L0oooo0@00
00010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`P0?clo00<0000005=CD`1CDe<00P1CDe<0
0`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0102<S8`0
0`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H0
0`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01L0k>c/00<000000?ooo`3oool0:@3oool2
0?l00006003o00000?l0003o0000o`00o`00003o103o00050?ooo`030000o`3oool0oooo05d0oooo
00<0003o0?ooo`3oool0:03oool20?l00100oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI
0=WIf@0<0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO
09nOW`0309nOW`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`L0?clo00<0
000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0
000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00L0/k>c00<0
00000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/01H0k>c/00<0
00000?ooo`3oool0:P3oool30?l000030000o`00o`000?l00080o`0000<0003o0?l0003o0000103o
00020000of40oooo00<0003o0?ooo`3oool00P3oool20?l003D0oooo00<000000>c/k03/k>`05@3/
k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01P2c
/k<00`000000WinO09nOW`0209nOW`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`L0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0
NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0
/k>c00L0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0
k>c/01H0k>c/00<000000?ooo`3oool0:P3oool20?l000030000o`3o0000o`0000<0o`0000@0003o
003o0000o`000?l00P3o00000`000?l0o`000?ooo`1R0?ooo`030000o`3o0000o`0000H0o`00<`3o
ool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02036
a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO0080WinO1`3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo1`0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0
IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0
WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0
fMWI00`0fMWI00<000000>c/k03/k>`05P3/k>`00`000000oooo0?ooo`0/0?ooo`030?l000000?l0
o`0000@0o`0000H00?l00000o`000?l0003o003o00000?l20?l006<0oooo00<0o`000000o`3o0000
1`3o000c0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K6
0<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil00P2OWil70?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool01@3oool603lo?`030000001CDe<0De=C00<0De=C00<0
000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0
000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<0
00000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo02`0oooo00<0
003o0?ooo`3oool00`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0006<0oooo0P3o
00020000o`<00?l00`3o000c0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT02`3I
fMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0/k>c00@0000009nOW`2OWil0WinO
1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P0o?cl00`000000De=C05=C
D`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<
S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6
aP090<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`05P3/k>`00`000000oooo0?oo
o`0/0?ooo`030000o`3oool0oooo0080oooo0P3o00000`00o`00003o0000o`030000o`04003o003o
0000o`000?l00680oooo0`3o00001@00o`00003o0000o`000?l00?l00080o`00=03oool00`000000
k>c/0>c/k00D0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H02036a/H00`000000
/k>c0;>c/`060;>c/`040000002OWil0WinO09nOW`L0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`H0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP03
0000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`03
0000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0<0=WIf@03
0000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`020?ooo`80
o`0000<00?l00000o`000?l00`000?l01000o`00o`000?l0003o001Q0?ooo`<0o`0000<00?l00000
o`000?l00`000?l00`00o`00o`000?l0000c0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WI
f@3IfMT02`3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00@0000009nO
W`2OWil0WinO1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P0o?cl00`00
0000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`00
0000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`00
0000a/K60<K6aP080<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`05P3/k>`00`00
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00@0oooo0P3o00001@00o`00003o0000o`000?l0
0?l000<0o`00HP3oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0003o0000=03oool0
0`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02036a/H0
0`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00L0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`D0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IV
IP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nO
W`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0=0=WI
f@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`050?oo
o`<0o`000`00o`040?l006<0oooo0P3o00000`00o`00003o0000o`030000o`03003o003o0000oooo
03@0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K6
00P0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`070?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool503lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1V
IVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2O
Wil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3I
fMT0303IfMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo02/0oooo00<0003o0?ooo`3o
ool01P3oool:0?l006<0oooo0`3o00000`00o`00003o0000o`020000o`80o`00=P3oool00`000000
k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02036a/H00`000000
/k>c0;>c/`060;>c/`030000002OWil0oooo00H0oooo0@0000010?ooo`007`3oool3000000D0oooo
1@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0
0`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<0
1P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`0
5@3/k>`00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00L0oooo203o001T0?ooo`@0o`00
0`00o`000`3o0000003o0?l0000f0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT0
303IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`3oool0
1@3oool200000040oooo000O0?ooo`030000003oool0oooo00D0oooo100o?cl00`000000De=C05=C
D`0205=CD`030000001VIVH0IVIV00@0IVIV00<0000007UiN@1iNGT00P1iNGT00`000000S8b<08b<
S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6
aP080<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`05P3/k>`00`000000oooo0?oo
o`0[0?ooo`030000o`3oool0oooo00/0oooo0P3o001X0?ooo`L0o`0000<0003o0?ooo`3oool0=P3o
ool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H02036
a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0oooo00H0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`@0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP03
06IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`05
09nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0<
0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`1i
0?ooo`80o`000`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003/k>`0k>c/01<0k>c/00<00000
0=WIf@3IfMT0303IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00<00000
0?ooo`3oool01@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo100o?cl00`00
0000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`00
0000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`00
0000a/K60<K6aP080<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`05@3/k>`00`00
0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo07l0oooo00<0003o0?ooo`3oool0=@3oool00`00
0000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H02036a/H00`00
0000/k>c0;>c/`060;>c/`030000003oool0oooo00D0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`@0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP03
0000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`03
0000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0<0=WIf@03
0000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`200?ooo`03
0000o`3oool0oooo03D0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0;0=WIf@03
00000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01P2c/k<00`000000oooo0?ooo`050?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3oool303lo?`030000001CDe<0De=C0080De=C
00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<
00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K6
00<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00E0>c/k0030000003oool0oooo02X0oooo
00<0003o0?ooo`3oool0PP3oool00`000?l0oooo0?ooo`0e0?ooo`030000003/k>`0k>c/01<0k>c/
00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP070<K6aP030000002c/k<0/k>c00L0/k>c
00<000000?ooo`3oool0103oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0`0o
?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1i
NGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01P2c
/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`0503/
k>`00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo08<0oooo00<0003o0?ooo`3oool0=03o
ool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H02036
a/H00`000000/k>c0;>c/`060;>c/`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`<0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0
NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0
/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0
k>c/01D0k>c/00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`240?ooo`030000o`3oool0
oooo03D0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0
a/K600L0a/K600<000000;>c/`2c/k<01P2c/k<70?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool303lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`00
0000NGUi07UiN@0307UiN@030000002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil01@2OWil00`00
0000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT0303IfMT00`00
0000k>c/0>c/k00D0>c/k0030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0QP3oool00`00
0?l0oooo0?ooo`0d0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT02`3IfMT00`00
0000a/K60<K6aP070<K6aP030000002c/k<0/k>c00H0/k>c1`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo0P0o?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV0080
IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00@0
WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00/0
fMWI00<000000>c/k03/k>`05@3/k>`00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo08L0
oooo00@0003o0?ooo`3o0000o`00<P3oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI
00/0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`050;>c/`L0oooo0@0000010?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`80?clo00<0000005=CD`1CDe<00P1CDe<00`000000
IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000
WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000
fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool0:P3oool00`000?l0
oooo0?ooo`270?ooo`030?l000000?l0o`0000D0o`00;`3oool00`000000k>c/0>c/k00D0>c/k003
0000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`050;>c/`L0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80?clo00<0000005=CD`1CDe<0
0P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0
0`2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H0
2036a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool0
:@3oool00`000?l0oooo0?ooo`270?ooo`<0o`0000<0003o0?l0003o0000103o000_0?ooo`030000
003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP080<K6aP030000
002c/k<0/k>c00@0/k>c1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P0o
?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00P1i
NGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c
/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`05@3/
k>`00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo08L0oooo103o00000`000?l00?l0003o
00030?l002l0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036
a/H0a/K600P0a/K600<000000;>c/`2c/k<0102c/k<70?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool00`0o?cl0000005=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<00000
07UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00D0WinO00<00000
0;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00`0fMWI00<00000
0>c/k03/k>`0503/k>`00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo08P0oooo0`3o0000
1@00o`00003o0000o`000?l00?l00080o`00<03oool00`000000k>c/0>c/k00C0>c/k0030000003I
fMT0fMWI00X0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`040;>c/`L0oooo0@00
00010?ooo`007`3oool3000000D0oooo00<0?clo0000001CDe<00`1CDe<00`000000IVIV06IVIP03
06IVIP030000001iNGT0NGUi0080NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`05
09nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;
0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`28
0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l0000_0?ooo`030000003/k>`0
k>c/01<0k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0
/k>c00<0/k>c1P3oool200000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0?clo0000
001CDe<00`1CDe<00`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<
S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6
aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`280?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00
o`00o`000?l0000`0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT02P3IfMT00`00
0000a/K60<K6aP080<K6aP030000002c/k<0/k>c00<0/k>c1`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo00<0?clo0000001CDe<00`1CDe<00`000000IVIV06IVIP0206IVIP03
0000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`03
0000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@03
0000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`2:0?ooo`80
o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?ooo`0`0?ooo`030000003/k>`0k>c/01<0
k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00<0
/k>c1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0000005=CD`1CDe<0
0P1CDe<00`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0
102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H0
2036a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`2;0?ooo`<0o`0000L00?l00000o`000?l0003o003o00000?l0o`00
0380oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K6
00L0a/K600<000000;>c/`2c/k<00`2c/k<70?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1i
NGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c
/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/
k>`0503/k>`00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo08/0oooo103o0003003o0003
0?l000000?l0o`000380oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0:0=WIf@03
00000036a/H0a/K600P0a/K600<000000;>c/`2c/k<00P2c/k<70?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool01@3oool505=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1iNGT0
0`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<0
1P2c/k<00`000000a/K60<K6aP070<K6aP8000003@3IfMT00`000000k>c/0>c/k00D0>c/k0030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool0S@3oool80?l000030000o`3oool0oooo0340oooo
00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600L0a/K6
00<000000;>c/`2c/k<00P2c/k<70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool505=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<
S00408b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6
aP080<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo0940oooo0P3o00040?ooo`030000o`3oool0oooo0300oooo00<0
00000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600L0a/K600<0
00000;>c/`2c/k<00P2c/k<70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool4
05=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<08b<S003
08b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP07
0<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0V
0?ooo`030000o`3oool0oooo09T0oooo00<0003o0?ooo`3oool0<03oool00`000000k>c/0>c/k00B
0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H02036a/H010000000/k>c0;>c/`2c
/k<70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool405=CD`030000001VIVH0
IVIV0080IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0
WinO00@0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0
fMWI00/0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo09X0oooo00<0003o0?ooo`3oool0;`3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0
fMWI00/0fMWI00<000000<K6aP36a/H01`36a/H010000000/k>c0;>c/`2c/k<70?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool405=CD`030000001VIVH0IVIV0080IVIV00<00000
07UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO00<00000
0;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00/0fMWI00<00000
0>c/k03/k>`0503/k>`00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo09`0oooo00<0003o
0?ooo`3oool00P3o000]0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT02P3IfMT0
0`000000a/K60<K6aP070<K6aP040000002c/k<0/k>c0;>c/`L0oooo0@0000010?ooo`000P3oool4
000000H0oooo0P0000050?ooo`H000001P3oool00`000000oooo0?ooo`050?ooo`@0De=C00<00000
06IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<00000
09nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<00000
0=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo02H0oooo00<0003o
0?ooo`3oool0W@3oool00`3o0000003o0?l000050?l002X0oooo00<000000>c/k03/k>`04P3/k>`0
0`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600L0a/K600@000000;>c/`2c/k<0/k>c1`3o
ool100000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo0P000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`<0De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0
S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0
a/K600P0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0
oooo02H0oooo00<0003o0?ooo`3oool0W03oool20?l000030000o`3o0000o`0000D0o`00:P3oool0
0`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H02036a/H0
0`000000/k>c0;>c/`070?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo0`1CDe<00`00
0000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`00
0000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`00
0000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`2M0?ooo`<0o`0000@0003o003o0000o`000?l00`3o000Z0?ooo`030000003/k>`0
k>c/0180k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP070<K6aP030000002c/k<0
/k>c00L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00L0oooo100000040?ooo`<0De=C00<0000006IVIP1VIVH00P1VIVH00`00
0000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`00
0000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT02`3IfMT00`00
0000k>c/0>c/k00C0>c/k0030000003oool0oooo0240oooo0P3o00020?ooo`030000o`3oool0oooo
09h0oooo0`3o00001@00o`00003o0000o`000?l00?l00080o`00:P3oool00`000000k>c/0>c/k00B
0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0?ooo`04
0?ooo`<000000@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0`1CDe<00`000000IVIV06IVIP0206IV
IP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nO
W`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0:0=WI
f@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool07P3oool70?l000030000o`3oool0oooo
09d0oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0002X0oooo00<000000>c/
k03/k>`04@3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600L0a/K600<000000;>c
/`3oool01P3oool100000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`80De=C00<0000006IVIP1V
IVH00P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2O
Wil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3I
fMT02`3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo01h0oooo1`3o00000`000?l0
o`000?l0002N0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l0000Z0?ooo`03
0000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP080<K6aP03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`80De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0307UiN@030000
002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`030000
0036a/H0a/K600L0a/K60P00000<0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool0
7P3oool40?l000800?l000@0003o0?l0003o0000o`00W`3oool20?l00003003o00000?l0003o00<0
003o00<00?l00?l0003oool0:`3oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00/0
fMWI00<000000<K6aP36a/H01`36a/H00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool205=CD`030000001VIVH0IVIV0080IVIV
00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO
00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00/0fMWI
00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0N0?ooo`<0o`0000D00?l00000o`000?l0
003o003o00020?l009l0oooo0`3o00000`00o`00003o0000o`020000o`80o`00;03oool00`000000
k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H01`36a/H00`000000
oooo0?ooo`050?ooo`4000000@3oool00080oooo1000000>0?ooo`@000001`3oool00`000000oooo
0?ooo`050?ooo`0305=CD`000000IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<
08b<S00408b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K6
0<K6aP070<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo
0?ooo`0N0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l0002N0?ooo`@0o`00
0`00o`000`000?l0o`000?l0000]0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT0
2P3IfMT00`000000a/K60<K6aP080<K6aP030000003oool0oooo00@0oooo0@0000010?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`0305=CD`000000IVIV00<0IVIV00<0000007UiN@1iNGT00`1i
NGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01P2c
/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`0503/
k>`00`000000oooo0?ooo`0N0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l0
002O0?ooo`L0o`0000<0003o0?ooo`3oool0;03oool00`000000k>c/0>c/k00A0>c/k0030000003I
fMT0fMWI00/0fMWI00<000000<K6aP36a/H01`36a/H00`000000oooo0?ooo`040?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool00`1CDe<0000006IVIP0306IVIP030000001iNGT0
NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0
/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0
k>c/01<0k>c/00<000000?ooo`3oool0803oool20?l00003003o00000?l0003o00<0003o00<00?l0
0?l0003oool0XP3oool20?l000<0oooo00<0003o0?ooo`3oool0;03oool00`000000k>c/0>c/k00A
0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H01`36a/H70?ooo`4000000@3oool0
01l0oooo00<000000?ooo`3oool01@3oool00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi
00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c
00D0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/
01<0k>c/00<000000?ooo`3oool08@3oool30?l00005003o00000?l0003o0000o`00o`000P3o002X
0?ooo`030000o`3oool0oooo02`0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0:
0=WIf@0300000036a/H0a/K600L0a/K61`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<
0080S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K6
00L0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo
0240oooo0`3o000010000?l00?l0003o0000o`030?l00:T0oooo00<0003o0?ooo`3oool0:`3oool0
0`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H01`36a/H7
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool506IVIP030000001iNGT0NGUi
00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c
00D0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/
0180k>c/00<000000?ooo`3oool08`3oool20?l000030000o`3o0000o`0000<0o`00Z`3oool00`00
0?l0oooo0?ooo`0[0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT02P3IfMT00`00
0000a/K60<K6aP060<K6aPL0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0
IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00D0
WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00/0
fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0T0?ooo`040000o`3oool0o`000?l0
0:h0oooo00<0003o0?ooo`3oool00P3oool20?l002L0oooo00<000000>c/k03/k>`04@3/k>`00`00
0000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600H0a/K61`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo1@1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00<0
S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600P0
a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo02@0
oooo00<0003o0?ooo`3oool0/03oool00`000?l0o`000?l000060?l002@0oooo00<000000>c/k03/
k>`04@3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600H0a/K61`3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo101VIVH00`000000NGUi07UiN@0307UiN@030000
002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`050;>c/`030000
0036a/H0a/K600P0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00B0>c/k0030000
003oool0oooo02@0oooo00<0003o0?ooo`3oool0/@3oool00`000?l0o`000?l000070?l002@0oooo
00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600D0a/K6
1`3oool100000040oooo000O0?ooo`<000001@3oool406IVIP030000001iNGT0NGUi00<0NGUi00<0
000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00D0/k>c00<0
00000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/01<0k>c/00<0
00000?ooo`3oool0903oool00`000?l0oooo0?ooo`2a0?ooo`040?l000000?l0o`000?l000<00?l0
0`3o000T0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K6
0<K6aP050<K6aPH0oooo0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0IVIV00<0
000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00D0WinO00<0
00000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00X0fMWI00<0
00000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0;80oooo0P3o
00000`000?l00?l0003o0003003o0080o`009@3oool00`000000k>c/0>c/k00A0>c/k0030000003I
fMT0fMWI00X0fMWI00<000000<K6aP36a/H01036a/H70?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool406IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`0
0`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H0
0`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`2a0?ooo`<0o`0000<0003o003o0000o`001000o`020?l002@0oooo00<00000
0>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600@0a/K61`3oool1
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo0`1VIVH00`000000NGUi07UiN@0307Ui
N@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`050;>c
/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00C0>c/
k0030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0/@3oool30?l00003003o00000?l00?l0
00@00?l00P3o000U0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02P3IfMT00`00
0000a/K60<K6aP040<K6aPL0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0
IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00@0
WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00/0
fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0;<0
oooo0P3o00000`00o`00003o003o0004003o00030?l0003oool0oooo02@0oooo00<000000>c/k03/
k>`0403/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600<0a/K61`3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo0`1VIVH00`000000NGUi07UiN@0307UiN@030000
002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`030000
0036a/H0a/K600L0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00B0>c/k0030000
003oool0oooo02@0oooo00<0003o0?ooo`3oool0/`3oool30?l00003003o00000?l00?l000800?l0
0P3o000W0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K6
0<K6aP030<K6aPL0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0IVIV00<0
000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00@0WinO00<0
00000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00X0fMWI00<0
00000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0;@0oooo103o
00000`00o`00003o003o00030?l002L0oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WI
f@0:0=WIf@0300000036a/H0a/K600<0a/K61`3oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo0P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00<0S8b<00<00000
09nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<00000
0=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo02@0oooo00<0003o
0?ooo`3oool0]@3oool40?l000040000o`3o0000o`000?l002P0oooo00<000000>c/k03/k>`0403/
k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600<0a/K61`3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo0P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0
S8b<00<0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0
a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0
oooo02<0oooo00<0003o0?ooo`3oool0^@3oool20?l000030000o`3oool0oooo02T0oooo00<00000
0>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K60080a/K61`3oool1
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P1VIVH00`000000NGUi07UiN@0307Ui
N@030000002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c
/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00C0>c/
k0030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0_03oool00`000?l0oooo0?ooo`0X0?oo
o`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP020<K6
aPL0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80IVIV00<0000007UiN@1i
NGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c
/k<01P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/
k>`04P3/k>`00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0;d0oooo00<0003o0?ooo`3o
ool0:03oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36
a/H00P36a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`1VIVH00000
07UiN@0407UiN@030000002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c
0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/
0>c/k00C0>c/k0030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0_P3oool00`000?l0oooo
0?ooo`0X0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02P3IfMT010000000a/K6
0<K6aP36a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`1VIVH00000
07UiN@0407UiN@030000002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c
0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/
0>c/k00B0>c/k0030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0_P3oool00`000?l0oooo
0?ooo`0X0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02P3IfMT010000000a/K6
0<K6aP36a/H70?ooo`4000000@3oool001l0oooo0`0000050?ooo`0306IVIP000000NGUi00@0NGUi
00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c
00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0180k>c/
00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`300?ooo`030000o`3oool0oooo02P0oooo
00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@090=WIf@0400000036a/H0a/K60<K6aPH0
oooo0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000001iNGT0NGUi00<0NGUi
00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c
00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/0180k>c/
00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`310?ooo`030000o`3oool0oooo02L0oooo
00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@090=WIf@0400000036a/H0a/K60<K6aPL0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000001iNGT0NGUi00<0NGUi
00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00D0/k>c
00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0180k>c/
00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`320?ooo`030000o`3oool0oooo02L0oooo
00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600L0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0NGUi00<0000008b<S02<S8`0102<
S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36
a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`330?ooo`040000o`3oool0o`000?l002H0oooo00<000000>c/k03/k>`0
403/k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0a/K600L0oooo0@0000010?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`D0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nO
W`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WI
f@0;0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07`3oool20?l000030?ooo`00
0?l0oooo0<@0oooo0P3o00000`000?l0o`000?l000030?l002<0oooo00<000000>c/k03/k>`0403/
k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0oooo00H0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`D0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`04
09nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:
0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07@3oool60?l000030000o`3o0000
oooo0<80oooo0`3o00000`000?l00?l0003o00040?l002<0oooo00<000000>c/k03/k>`0403/k>`0
0`000000fMWI0=WIf@090=WIf@0300000036a/H0oooo00H0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nO
W`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;0=WI
f@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0703oool30?l000<00?l000@0003o0?l0
003o0000o`00`P3oool20?l00005003o00000?l0003o0000o`00o`000`3o000S0?ooo`030000003/
k>`0k>c/0100k>c/00<000000=WIf@3IfMT02P3IfMT00`000000oooo0?ooo`050?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool407UiN@030000002<S8`0S8b<00@0S8b<00<00000
09nOW`2OWil0102OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<00000
0=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo01d0oooo0P3o0000
0`00o`00003o0000o`020000o`<0o`00`P3oool00`3o00000?l00000o`040000o`03003o003o0000
o`0002@0oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@090=WIf@030000003oool0
oooo00D0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0NGUi00<0000008b<
S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6
aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0180k>c/00<000000?oo
o`3oool07@3oool00`3o00000?l00000o`040000o`03003o003o0000o`000<40oooo0P3o00000`00
o`00003o0000o`030000o`04003o003o0000o`000?l002<0oooo00<000000>c/k03/k>`0403/k>`0
0`000000fMWI0=WIf@090=WIf@030000003oool0oooo00D0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`@0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0409nO
W`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WI
f@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool0703oool20?l00003003o00000?l0003o
00<0003o00@00?l00?l0003o0000o`00`03oool20?l00003003o00000?l0003o00<0003o00@00?l0
0?l0003o0000o`00903oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00X0fMWI00<0
00000?ooo`3oool0103oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0`1iNGT0
0`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<0
0`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`04P3/k>`0
0`000000oooo0?ooo`0M0?ooo`80o`0000<00?l00000o`000?l00`000?l01000o`00o`000?l0003o
00310?ooo`80o`0000<00?l00000o`000?l00P000?l30?l002D0oooo00<000000>c/k03/k>`0403/
k>`00`000000fMWI0=WIf@090=WIf@030000003oool0oooo00@0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`04
09nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:
0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07P3oool20?l00005003o00000?l0
003o0000o`00o`000`3o001H0?ooo``00000GP3oool30?l000<00?l000@0003o0?l0003o0000o`00
9@3oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00T0fMWI1`3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo0`1iNGT00`000000S8b<08b<S00408b<S0030000002O
Wil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003I
fMT0fMWI00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0O0?ooo`<0o`0000<0
003o003o0000o`00103o001A0?ooo`L00000303/k>`7000005L0oooo1P3o000010000?l0o`000?l0
003o000U0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02@3IfMT70?ooo`400000
0@3oool001l0oooo0`0000050?ooo`80NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nO
W`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WI
f@0:0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07`3oool20?l000030000o`3o
0000o`0000D0o`00CP3oool3000001X0k>c/1000001D0?ooo`H0o`0000<0003o0?l0003oool09P3o
ool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00T0fMWI1P3oool200000040oooo000O
0?ooo`030000003oool0oooo00D0oooo0P1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0
WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0
fMWI00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0Q0?ooo`030?l000000?l0
o`0000D0o`00C@3oool200000240k>c/0`00001D0?ooo`80o`0000<0oooo0000o`3oool09`3oool0
0`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00P0fMWI1`3oool100000040oooo000O0?oo
o`030000003oool0oooo00D0oooo0P1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO
00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI
00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo
0080o`00C03oool4000002H0k>c/0P00001F0?ooo`030000o`3oool0oooo02H0oooo00<000000>c/
k03/k>`03`3/k>`00`000000fMWI0=WIf@080=WIf@L0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`80NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0409nOW`03
0000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@090=WIf@03
0000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`1<0?ooo`80
0000;03/k>`3000005<0oooo00<0003o0?ooo`3oool09P3oool00`000000k>c/0>c/k00?0>c/k003
0000003IfMT0fMWI00P0fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
00<0NGUi0000002<S8`01@2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c
00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140k>c/
00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`1;0?ooo`800000<@3/k>`300000500oooo
00<0003o0?ooo`3oool09P3oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00P0fMWI
1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0NGUi0000002<S8`0102<
S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36
a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0803o
ool00`000?l0oooo0?ooo`1:0?ooo`800000=P3/k>`2000004l0oooo00<0003o0?ooo`3oool09P3o
ool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00L0fMWI1`3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo00<0NGUi0000002<S8`0102<S8`00`000000WinO09nOW`04
09nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@09
0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`18
0?ooo`800000>P3/k>`00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo02H0oooo00<00000
0>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@070=WIf@L0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`0307UiN@000000S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`00
0000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`00
0000k>c/0>c/k00A0>c/k0030000003oool0oooo0200oooo00<0003o0?ooo`3oool0A`3oool20000
03d0k>c/00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0W0?ooo`030000003/k>`0k>c/
00h0k>c/00<000000=WIf@3IfMT01`3IfMT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool00`000000S8b<08b<S00308b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c
/k<01P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/
k>`04P3/k>`00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo04H0oooo0P0000100>c/k080
0000C03oool00`000?l0oooo0?ooo`0V0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3I
fMT01P3IfMT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000S8b<
08b<S00308b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K6
0<K6aP070<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo
0?ooo`0P0?ooo`030000o`3oool0oooo04D0oooo00<000000>c/k03/k>`0@P3/k>`00`000000oooo
0?ooo`190?ooo`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI
0=WIf@060=WIf@L0oooo0@0000010?ooo`000P3oool4000000H0oooo0P0000070?ooo`@000001P3o
ool00`000000oooo0?ooo`050?ooo`030000002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil0102O
Wil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3I
fMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0A03o
ool2000004H0k>c/0P0000190?ooo`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`03`3/
k>`00`000000fMWI0=WIf@050=WIf@L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo1P2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<00000
0<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140k>c/00<00000
0?ooo`3oool07P3oool00`000?l0oooo0?ooo`130?ooo`800000BP3/k>`2000004P0oooo00<0003o
0?ooo`3oool09P3oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00D0fMWI1`3oool1
00000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`D0S8b<00<0000009nOW`2OWil0102OWil00`00
0000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`00
0000k>c/0>c/k00A0>c/k0030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0@P3oool00`00
0000k>c/0>c/k01<0>c/k0030000003oool0oooo04D0oooo00<0003o0?l0003o00009P3oool00`00
0000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00D0fMWI1`3oool100000040oooo00000`3oool0
00000?ooo`030?ooo`030000003oool0oooo00X0oooo1P0000060?ooo`030000003oool0oooo00D0
oooo1@2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36
a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`110?ooo`800000D03/k>`2000004<0oooo0`3o00000`000?l0
o`000?l000020?l002@0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@040=WIf@L0
oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo000000L0oooo100000040?ooo`D0S8b<00<0000009nOW`2OWil0102OWil00`000000
/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`000000
k>c/0>c/k00A0>c/k0030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0@03oool00`000000
k>c/0>c/k01B0>c/k0030000003oool0oooo03l0oooo103o00000`000?l0o`000?l000030?l002<0
oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@040=WIf@D0oooo0`0000010?ooo`00
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool01@3oool508b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c
/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/
k>`04@3/k>`00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0400oooo00<000000>c/k03/
k>`0E03/k>`00`000000oooo0?ooo`0n0?ooo`<0o`0000<00?l00000o`00o`00103o000S0?ooo`03
0000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT0103IfMT70?ooo`4000000@3oool000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo000000070?ooo`030000
003oool0oooo00D0oooo102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00D0/k>c
00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140k>c/
00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0o0?ooo`800000F03/k>`2000003h0oooo
0P3o00001@00o`00003o0000o`000?l00?l000<0o`00903oool00`000000k>c/0>c/k00>0>c/k003
0000003IfMT0fMWI00@0fMWI1`3oool100000040oooo00000`3oool000000?ooo`030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`@0S8b<
00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600H0a/K6
00<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01h0oooo
00<0003o0?ooo`3oool0?P3oool00`000000k>c/0>c/k01J0>c/k0030000003oool0oooo03X0oooo
0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l002<0oooo00<000000>c/k03/
k>`03`3/k>`00`000000fMWI0=WIf@030=WIf@L0oooo0@0000010?ooo`000P3oool400000100oooo
0P0000070?ooo`030000003oool0oooo00D0oooo102<S8`00`000000WinO09nOW`0409nOW`030000
002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@090=WIf@030000
003/k>`0k>c/0140k>c/00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0n0?ooo`030000
003/k>`0k>c/05`0k>c/00<000000?ooo`3oool0>@3oool20?l00003003o00000?l0003o00<0003o
00@00?l00?l0003o0000o`00903oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00<0
fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo102<S8`00`000000WinO
09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI
0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool0703oool00`000?l0oooo
0?ooo`0n0?ooo`030000003/k>`0k>c/05h0k>c/0P00000j0?ooo`030?l00000o`00003o00@0003o
00<00?l00?l0003o00009@3oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00<0fMWI
1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo102<S8`00`000000WinO09nO
W`0309nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WI
f@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool0603oool20?l000<0oooo00<0
003o0?ooo`3oool0?@3oool00`000000k>c/0>c/k01Q0>c/k0030000003oool0oooo03L0oooo0P3o
00001P00o`00003o0000o`000?l00?l00000o`80o`009@3oool00`000000k>c/0>c/k00?0>c/k003
0000003IfMT0fMWI0080fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
0`2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H0
1`36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool0
5@3oool70?l000030000o`3oool0oooo03d0oooo00<000000>c/k03/k>`0HP3/k>`00`000000oooo
0?ooo`0g0?ooo`<0o`000`00o`00103o0000003o0?l0003o000V0?ooo`030000003/k>`0k>c/00h0
k>c/00<000000=WIf@3IfMT00P3IfMT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool308b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K6
0<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo
0?ooo`0D0?ooo`P0o`0000<0003o0?l0003oool0?03oool00`000000k>c/0>c/k01T0>c/k0030000
003oool0oooo03L0oooo1`3o00000`000?l0oooo0?ooo`0U0?ooo`030000003/k>`0k>c/00l0k>c/
00@000000=WIf@3IfMT0fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
0`2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H0
1P36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0
5@3oool30?l000<00?l000@0o`000000o`3o0000o`00>`3oool2000006P0k>c/0P00000j0?ooo`80
o`000P3oool00`000?l0oooo0?ooo`0U0?ooo`030000003/k>`0k>c/00l0k>c/00@000000=WIf@3I
fMT0fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P2<S8`00`000000
WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000
fMWI0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool05@3oool20?l00003
003o00000?l0003o0080003o0`3o000j0?ooo`030000003/k>`0k>c/06X0k>c/00<000000?ooo`3o
ool0?03oool00`000?l0oooo0?ooo`0U0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3I
fMT01`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P2<S8`00`000000WinO
09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI
0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool05@3oool20?l00003003o
00000?l0003o00<0003o00@00?l00?l0003o0000o`00>03oool00`000000k>c/0>c/k01/0>c/k003
0000003oool0oooo03/0oooo00<0003o0?ooo`3oool09@3oool00`000000k>c/0>c/k00?0>c/k003
0000003IfMT0fMWI00L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80S8b<
00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600H0a/K6
00<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01D0oooo
0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l003L0oooo00<000000>c/k03/
k>`0KP3/k>`2000003`0oooo00<0003o0?ooo`3oool0903oool00`000000k>c/0>c/k00?0>c/k003
0000003IfMT0fMWI00L0oooo0@0000010?ooo`007`3oool3000000D0oooo00<0S8b<0000002OWil0
1@2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT0
2P3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01H0oooo00<0o`00003o00000?l0
10000?l00`00o`00o`000?l0000g0?ooo`030000003/k>`0k>c/0740k>c/00<000000?ooo`3oool0
>@3oool00`000?l0oooo0?ooo`0U0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT0
1P3oool200000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0S8b<0000002OWil01@2O
Wil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02P3I
fMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01L0oooo0P3o00001@00o`00003o0000
o`000?l00?l000<0o`00=P3oool00`000000k>c/0>c/k01b0>c/k0030000003oool0oooo03X0oooo
00<0003o0?ooo`3oool0903oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0oooo00H0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`0308b<S0000000WinO00D0WinO00<0
00000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00X0fMWI00<0
00000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0G0?ooo`<0o`0000<00?l00000o`00o`00103o
000e0?ooo`030000003/k>`0k>c/07@0k>c/00<000000?ooo`3oool0>@3oool010000?l0oooo0?l0
003o000T0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3oool01P3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo00<0S8b<0000002OWil01@2OWil00`000000/k>c0;>c
/`050;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/
k00A0>c/k0030000003oool0oooo01P0oooo0P3o00000`000?l0o`000?l000030?l003D0oooo00<0
00000>c/k03/k>`0MP3/k>`00`000000oooo0?ooo`0g0?ooo`80o`0000<0003o0?l0003o00000`3o
000Q0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3oool01P3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`06
0;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00@
0>c/k0030000003oool0oooo01/0oooo00<0003o0?l0003o0000=`3oool00`000000k>c/0>c/k01g
0>c/k0030000003oool0oooo03H0oooo0`3o00000`000?l00?l0003o00040?l00200oooo00<00000
0>c/k03/k>`03P3/k>`00`000000fMWI0?ooo`060?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6
aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?oo
o`3oool06P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003/k>`0k>c/07T0k>c/00<000000?oo
o`3oool0=@3oool20?l00005003o00000?l0003o0000o`00o`000`3o000Q0?ooo`030000003/k>`0
k>c/00h0k>c/00<000000?ooo`3oool01@3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K6
00H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo
01X0oooo00<0003o0?ooo`3oool0=P3oool00`000000k>c/0>c/k01k0>c/k0800000=@3oool00`3o
00000?l00000o`040000o`03003o003o0000o`000240oooo00<000000>c/k03/k>`03P3/k>`00`00
0000oooo0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool709nOW`03
0000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@03
0000003/k>`0k>c/0100k>c/00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0f0?ooo`03
0000003/k>`0k>c/07h0k>c/00<000000?ooo`3oool0<@3oool20?l00003003o00000?l0003o00<0
003o00@00?l00?l0003o0000o`00803oool00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo
00@0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0WinO00<000000;>c/`2c
/k<01@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/
k>`04@3/k>`00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo03H0oooo00<000000>c/k03/
k>`0OP3/k>`00`000000oooo0?ooo`0a0?ooo`80o`0000<00?l00000o`000?l00`000?l01000o`00
o`000?l0003o000Q0?ooo`030000003/k>`0k>c/00h0k>c/1`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo1P2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600H0
a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01X0
oooo00<0003o0?ooo`3oool0=P3oool00`000000k>c/0>c/k0200>c/k0030000003oool0oooo0340
oooo0P3o00000`00o`00003o0000o`020000o`<0o`008P3oool00`000000k>c/0>c/k00>0>c/k0L0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0WinO00<000000;>c/`2c/k<0
1@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0
403/k>`00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo03D0oooo00<000000>c/k03/k>`0
PP3/k>`00`000000oooo0?ooo`0`0?ooo`<0o`000`00o`00103o0000003o0?l0003o000S0?ooo`03
0000003/k>`0k>c/00d0k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
1P2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0
2@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0
=@3oool00`000000k>c/0>c/k0240>c/k0030000003oool0oooo02l0oooo1`3o00000`000?l0o`00
0?l0000S0?ooo`030000003/k>`0k>c/00d0k>c/1`3oool100000040oooo000O0?ooo`030000003o
ool0oooo00D0oooo1@2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600H0a/K600<0
00000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01X0oooo00<0
003o0?ooo`3oool0=03oool00`000000k>c/0>c/k0260>c/k0030000003oool0oooo02l0oooo1`3o
00000`000?l0oooo0?ooo`0R0?ooo`030000003/k>`0k>c/00d0k>c/1`3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo1@2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0
a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0
oooo01T0oooo00<0003o0?ooo`3oool0=@3oool00`000000k>c/0>c/k0270>c/k0030000003oool0
oooo0340oooo0P3o00020?ooo`030000o`3oool0oooo0280oooo00<000000>c/k03/k>`03@3/k>`7
0?ooo`4000000@3oool001l0oooo0`0000050?ooo`D0WinO00<000000;>c/`2c/k<01@2c/k<00`00
0000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0403/k>`00`00
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03@0oooo00<000000>c/k03/k>`0R@3/k>`00`00
0000oooo0?ooo`0e0?ooo`030000o`3oool0oooo0280oooo00<000000>c/k03/k>`0303/k>`60?oo
o`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool509nOW`030000002c/k<0/k>c00D0
/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0100
k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0c0?ooo`030000003/k>`0k>c/08/0
k>c/00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0R0?ooo`030000003/k>`0k>c/00`0
k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo102OWil00`000000/k>c
0;>c/`050;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/
0>c/k00@0>c/k0030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0<`3oool00`000000k>c/
0>c/k02<0>c/k0030000003oool0oooo03D0oooo00<0003o0?ooo`3oool08@3oool00`000000k>c/
0>c/k00<0>c/k0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0WinO00<0
00000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<0
00000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03<0oooo00<0
00000>c/k03/k>`0S@3/k>`00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0280oooo00<0
00000>c/k03/k>`02`3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool4
09nOW`030000002c/k<0/k>c00@0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@09
0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0c
0?ooo`030000003/k>`0k>c/08l0k>c/00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0Q
0?ooo`030000003/k>`0k>c/00/0k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo102OWil00`000000/k>c0;>c/`040;>c/`0300000036a/H0a/K600L0a/K600<000000=WI
f@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01P0oooo00<0003o0?oo
o`3oool0<P3oool00`000000k>c/0>c/k02A0>c/k0030000003oool0oooo03<0oooo00@0003o0?oo
o`3o0000o`00803oool00`000000k>c/0>c/k00;0>c/k0L0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`<0WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K60<K6aP070<K6
aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo0380oooo00<000000>c/k03/k>`0TP3/k>`00`000000oooo0?ooo`0b0?oo
o`80o`0000<0003o0?l0003o00000`3o000N0?ooo`030000003/k>`0k>c/00X0k>c/1`3oool10000
0040oooo000O0?ooo`030000003oool0oooo00D0oooo0`2OWil00`000000/k>c0;>c/`040;>c/`03
00000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k003
0000003oool0oooo01P0oooo00<0003o0?ooo`3oool0<P3oool00`000000k>c/0>c/k02C0>c/k003
0000003oool0oooo0300oooo0`3o00000`000?l0o`000?l000040?l001d0oooo00<000000>c/k03/
k>`02P3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool309nOW`030000
002c/k<0/k>c00@0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@090=WIf@030000
003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0b0?ooo`030000
003/k>`0k>c/09D0k>c/00<000000?ooo`3oool0;`3oool30?l00003003o00000?l00?l000@0o`00
7P3oool00`000000k>c/0>c/k0090>c/k0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?ooo`<0WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K60<K6aP060<K6aP030000003I
fMT0fMWI00T0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo0340oooo00<000000>c/k03/k>`0U`3/k>`00`000000oooo0?ooo`0^0?ooo`80o`0000D0
0?l00000o`000?l0003o003o00030?l001h0oooo00<000000>c/k03/k>`02@3/k>`70?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool01@3oool209nOW`030000002c/k<0/k>c00@0/k>c00<0
00000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/00l0k>c/00<0
00000?ooo`3oool0603oool00`000?l0oooo0?ooo`0a0?ooo`030000003/k>`0k>c/0480k>c/4P00
00140>c/k0030000003oool0oooo02d0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o
0000o`000?l001d0oooo00<000000>c/k03/k>`02@3/k>`70?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool209nOW`030000002c/k<0/k>c00@0/k>c00<000000<K6aP36a/H01P36
a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0`0?ooo`030000003/k>`0k>c/0400k>c/0`00000B0=WIf@L00000?P3/
k>`00`000000oooo0?ooo`0/0?ooo`80o`0000<00?l00000o`000?l00`000?l01000o`00o`000?l0
003o000N0?ooo`030000003/k>`0k>c/00P0k>c/1`3oool100000040oooo000O0?ooo`030000003o
ool0oooo00D0oooo0P2OWil00`000000/k>c0;>c/`040;>c/`0300000036a/H0a/K600H0a/K600<0
00000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01L0oooo00<0
003o0?ooo`3oool0<@3oool00`000000k>c/0>c/k00k0>c/k0D000006`3IfMT2000003d0k>c/00<0
00000?ooo`3oool0;@3oool00`3o00000?l00000o`040000o`03003o003o0000o`0001l0oooo00<0
00000>c/k03/k>`0203/k>`70?ooo`4000000@3oool001l0oooo0`0000050?ooo`80WinO00<00000
0;>c/`2c/k<0102c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<00000
0>c/k03/k>`0403/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0300oooo00<00000
0>c/k03/k>`0>@3/k>`300000280fMWI1000000j0>c/k0030000003oool0oooo02`0oooo0P3o0000
0`00o`00003o0000o`020000o`<0o`007`3oool00`000000k>c/0>c/k0080>c/k0H0oooo0P000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`0309nOW`000000/k>c00D0/k>c00<000000<K6
aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?oo
o`3oool0603oool00`000?l0oooo0?ooo`0_0?ooo`030000003/k>`0k>c/03P0k>c/0P00000Y0=WI
f@@00000=`3/k>`00`000000oooo0?ooo`0[0?ooo`<0o`000`00o`00103o0000003o0?l0003o000P
0?ooo`030000003/k>`0k>c/00L0k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo00<0WinO0000002c/k<01@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI
00T0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
02l0oooo00<000000>c/k03/k>`0=P3/k>`3000002l0fMWI0P00000f0>c/k0030000003oool0oooo
02/0oooo1P3o00000`000?l0o`000?ooo`0P0?ooo`030000003/k>`0k>c/00L0k>c/1`3oool10000
0040oooo000O0?ooo`030000003oool0oooo00D0oooo00<000000;>c/`2c/k<01@2c/k<00`000000
a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0403/k>`00`000000
oooo0?ooo`0G0?ooo`030000o`3oool0oooo02l0oooo00<000000>c/k03/k>`0=03/k>`2000003@0
fMWI0P00000e0>c/k0030000003oool0oooo02d0oooo0P3o00000`3oool0003o0?ooo`0Q0?ooo`03
0000003/k>`0k>c/00L0k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00T0fMWI
00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo02l0oooo
00<000000>c/k03/k>`0=03/k>`00`000000fMWI0=WIf@0f0=WIf@800000<`3/k>`00`000000oooo
0?ooo`0a0?ooo`030000o`3oool0oooo0200oooo00<000000>c/k03/k>`01P3/k>`70?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool01@3oool70;>c/`0300000036a/H0a/K600H0a/K600<0
00000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01L0oooo00<0
003o0?ooo`3oool0;`3oool00`000000k>c/0>c/k00b0>c/k0800000>`3IfMT200000380k>c/00<0
00000?ooo`3oool0<03oool00`000?l0oooo0?ooo`020?l001h0oooo00<000000>c/k03/k>`01P3/
k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool70;>c/`0300000036a/H0
a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0
oooo01L0oooo00<0003o0?ooo`3oool0;`3oool00`000000k>c/0>c/k00a0>c/k0800000?`3IfMT2
00000340k>c/00<000000?ooo`3oool0;`3oool00`3o0000003o0?l000050?l001`0oooo00<00000
0>c/k03/k>`01@3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool70;>c
/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00?0>c/
k0030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0;P3oool00`000000k>c/0>c/k00`0>c/
k0800000@P3IfMT00`000000k>c/0>c/k00_0>c/k0030000003oool0oooo02h0oooo0P3o00000`00
0?l0o`00003o0002003o00<0o`006`3oool00`000000k>c/0>c/k0050>c/k0L0oooo0@0000010?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`H0/k>c00<000000<K6aP36a/H01`36a/H00`000000
fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`0^0?ooo`030000003/k>`0k>c/0300k>c/00<000000=WIf@3IfMT0@`3IfMT200000300
k>c/00<000000?ooo`3oool0;@3oool20?l000030000o`00o`000?l000<00?l00P3o000K0?ooo`03
0000003/k>`0k>c/00D0k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
1P2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0
3`3/k>`00`000000oooo0?ooo`0C0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0]0?ooo`030000
003/k>`0k>c/02l0k>c/0P0000180=WIf@800000;P3/k>`00`000000oooo0?ooo`0/0?ooo`<0o`00
00<00?l00000o`00o`001000o`000`3o0000oooo0?ooo`0J0?ooo`030000003/k>`0k>c/00@0k>c/
1`3oool100000040oooo00020?ooo`@000001P3oool2000000L0oooo100000060?ooo`030000003o
ool0oooo00D0oooo1P2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<0
00000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0@0?ooo`H0o`0000<0003o0?l0003oool0;P3o
ool00`000000k>c/0>c/k00]0>c/k0800000C03IfMT2000002d0k>c/00<000000?ooo`3oool0:`3o
ool30?l00004003o00000?l0003o0000o`<00?l00P3o000K0?ooo`030000003/k>`0k>c/00@0k>c/
1`3oool100000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo0P00
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`H0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/
k>`0k>c/00l0k>c/00<000000?ooo`3oool03`3oool70?l000030000o`3o0000o`0002d0oooo00<0
00000>c/k03/k>`0;P3/k>`00`000000fMWI0=WIf@1=0=WIf@030000003/k>`0k>c/02/0k>c/00<0
00000?ooo`3oool0:P3oool20?l00003003o00000?l0003o00<0003o0P00o`020?l001/0oooo00<0
00000>c/k03/k>`0103/k>`70?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool50;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT0
0`000000k>c/0>c/k00?0>c/k0030000003oool0oooo0100oooo0`3o0003003o00040000o`3o0000
o`000?l002`0oooo00<000000>c/k03/k>`0;P3/k>`00`000000fMWI0=WIf@1?0=WIf@030000003/
k>`0k>c/02/0k>c/00<000000?ooo`3oool0:03oool30?l00003003o00000?l0003o00<0003o00<0
0?l00?l0003o0000703oool00`000000k>c/0>c/k0040>c/k0L0oooo0@0000010?ooo`0000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool00`000000oooo0?ooo`03
0?ooo`@00000103oool50;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT0
0`000000k>c/0>c/k00?0>c/k0030000003oool0oooo0100oooo0P3o00000`00o`00003o0000o`02
0000o`<0o`00;03oool00`000000k>c/0>c/k00/0>c/k0800000D`3IfMT2000002`0k>c/00<00000
0?ooo`3oool09`3oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0003o00007@3oool0
0`000000k>c/0>c/k0030>c/k0D0oooo0`0000010?ooo`0000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool00000008000001P3oool00`000000oooo0?ooo`050?oo
o`D0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/
00l0k>c/00<000000?ooo`3oool03`3oool20?l00003003o00000?l0003o00<0003o00@00?l00?l0
003o0000o`00:P3oool00`000000k>c/0>c/k00[0>c/k0800000E`3IfMT00`000000k>c/0>c/k00Y
0>c/k0030000003oool0oooo02P0oooo0`3o00001@00o`00003o0000o`000?l00?l000<0o`007@3o
ool00`000000k>c/0>c/k0030>c/k0L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool5
0;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00@
0>c/k0030000003oool0oooo00l0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000
o`000?l002T0oooo00<000000>c/k03/k>`0:`3/k>`00`000000fMWI0=WIf@1H0=WIf@030000003/
k>`0k>c/02P0k>c/00<000000?ooo`3oool0:03oool40?l000800?l000@0003o0?l0003o0000o`00
7P3oool00`000000k>c/0>c/k0030>c/k0L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool40;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/
k00?0>c/k0030000003oool0oooo0140oooo00<0o`00003o00000?l010000?l00`00o`00o`000?l0
000Z0?ooo`030000003/k>`0k>c/02X0k>c/00<000000=WIf@3IfMT0FP3IfMT00`000000k>c/0>c/
k00X0>c/k0030000003oool0oooo02L0oooo1`3o00000`000?l0o`000?l0000N0?ooo`030000003/
k>`0k>c/00<0k>c/1`3oool100000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`@0/k>c00<00000
0<K6aP36a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/0100k>c/00<00000
0?ooo`3oool04@3oool20?l00005003o00000?l0003o0000o`00o`000`3o000Y0?ooo`030000003/
k>`0k>c/02X0k>c/00<000000=WIf@3IfMT0G03IfMT2000002P0k>c/00<000000?ooo`3oool0:03o
ool60?l000030000o`3o0000oooo01l0oooo00<000000>c/k03/k>`00P3/k>`70?ooo`4000000@3o
ool00080oooo1000000A0?ooo`<000001@3oool00`000000oooo0?ooo`050?ooo`@0/k>c00<00000
0<K6aP36a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<00000
0?ooo`3oool04P3oool30?l00003003o00000?l00?l000@0o`00:@3oool00`000000k>c/0>c/k00Y
0>c/k0030000003IfMT0fMWI05l0fMWI00<000000>c/k03/k>`09P3/k>`00`000000oooo0?ooo`0Z
0?ooo`80o`0000<0oooo0000o`3oool0803oool00`000000k>c/0>c/k0020>c/k0L0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0/k>c00<000000<K6aP36a/H01P36a/H00`00
0000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool04`3oool30?l0
00030000o`3o0000o`000080o`00:@3oool00`000000k>c/0>c/k00X0>c/k0800000H`3IfMT00`00
0000k>c/0>c/k00U0>c/k0030000003oool0oooo02h0oooo00<0003o0?ooo`3oool07`3oool01000
0000k>c/0>c/k03/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool30;>c
/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00?0>c/
k0030000003oool0oooo01H0oooo00<0003o0?l0003o0000:`3oool00`000000k>c/0>c/k00X0>c/
k0030000003IfMT0fMWI06@0fMWI0P00000V0>c/k0030000003oool0oooo02d0oooo00<0003o0?l0
003o00007`3oool010000000k>c/0>c/k03/k>`70?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool30;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`00
0000k>c/0>c/k00?0>c/k0030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0:`3oool00`00
0000k>c/0>c/k00W0>c/k0030000003IfMT0fMWI06L0fMWI00<000000>c/k03/k>`0903/k>`00`00
0000oooo0?ooo`0Z0?ooo`80o`0000<0003o0?l0003o00000`3o000M0?ooo`030000003/k>`0k>c/
00L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0/k>c00<000000<K6aP36
a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003/k>`0k>c/02H0k>c/00<000000=WIf@3I
fMT0J03IfMT00`000000k>c/0>c/k00U0>c/k0030000003oool0oooo02P0oooo103o00000`000?l0
0?l0003o00030?l001`0oooo00<000000>c/k03/k>`01`3oool100000040oooo000O0?ooo`030000
003oool0oooo00D0oooo0`2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00P0fMWI
00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo02/0oooo
00<000000>c/k03/k>`09P3/k>`00`000000fMWI0=WIf@1Z0=WIf@030000003/k>`0k>c/02@0k>c/
00<000000?ooo`3oool0:03oool30?l00005003o00000?l0003o0000o`00o`000P3o000L0?ooo`03
0000003/k>`0k>c/00L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80/k>c
00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/
00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003/k>`0k>c/02H0k>c/
00<000000=WIf@3IfMT0K03IfMT2000002D0k>c/00<000000?ooo`3oool09`3oool20?l00003003o
00000?l0003o00<0003o00<00?l00?l0003oool06`3oool00`000000k>c/0>c/k0070?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool01@3oool20;>c/`0300000036a/H0a/K600H0a/K600<0
00000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01D0oooo00<0
003o0?ooo`3oool0:`3oool00`000000k>c/0>c/k00U0>c/k0030000003IfMT0fMWI06l0fMWI00<0
00000>c/k03/k>`08P3/k>`00`000000oooo0?ooo`0V0?ooo`<0o`0000<00?l00000o`000?l00`00
0?l00`00o`00o`000?l0000L0?ooo`030000003/k>`0oooo00H0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`80/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@08
0=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0Z
0?ooo`030000003/k>`0k>c/02D0k>c/00<000000=WIf@3IfMT0L03IfMT00`000000k>c/0>c/k00S
0>c/k0030000003oool0oooo02D0oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000
o`0001`0oooo00<000000>c/k03oool01P3oool100000040oooo000O0?ooo`<000001@3oool20;>c
/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00?0>c/
k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0:P3oool00`000000k>c/0>c/k00T0>c/
k0030000003IfMT0fMWI0780fMWI00<000000>c/k03/k>`08P3/k>`00`000000oooo0?ooo`0V0?oo
o`<0o`0000D00?l00000o`000?l0003o003o00020?l001d0oooo00<000000>c/k03oool01@3oool2
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0/k>c00000036a/H01`36a/H00`00
0000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0Z0?ooo`030000003/k>`0k>c/02@0k>c/00<000000=WIf@3IfMT0M03IfMT00`00
0000k>c/0>c/k00R0>c/k0030000003oool0oooo02D0oooo103o0002003o00040000o`3o0000o`00
0?l001d0oooo00<000000>c/k03oool01P3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo00<0/k>c00000036a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/
00l0k>c/00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003/k>`0k>c/
02<0k>c/00<000000=WIf@3IfMT0MP3IfMT00`000000k>c/0>c/k00Q0>c/k0030000003oool0oooo
02D0oooo1P3o000010000?l0o`000?l0003o000N0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030;>c/`000000a/K600L0a/K600<000000=WI
f@3IfMT0203IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01D0oooo00<0003o0?oo
o`3oool0:@3oool00`000000k>c/0>c/k00T0>c/k0030000003IfMT0fMWI07L0fMWI00<000000>c/
k03/k>`08@3/k>`00`000000oooo0?ooo`0U0?ooo`H0o`0000<0003o0?l0003oool07P3oool00`00
0000oooo0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000
a/K60<K6aP070<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`08`3/k>`2000007/0
fMWI00<000000>c/k03/k>`08@3/k>`00`000000oooo0?ooo`0W0?ooo`80o`0000<0oooo0000o`3o
ool0803oool00`000000oooo0?ooo`040?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`0
3`3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`0
8P3/k>`00`000000fMWI0=WIf@1l0=WIf@030000003/k>`0k>c/0200k>c/00<000000?ooo`3oool0
:P3oool00`000?l0oooo0?ooo`0V0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool90<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`08P3/k>`00`000000fMWI0=WI
f@1n0=WIf@030000003/k>`0k>c/0200k>c/0P00000[0?ooo`030000o`3oool0oooo02D0oooo0@00
00010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`T0a/K600<000000=WIf@3IfMT0203IfMT0
0`000000k>c/0>c/k00>0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0:@3oool0
0`000000k>c/0>c/k00Q0>c/k0030000003IfMT0fMWI07l0fMWI00<000000>c/k03/k>`08@3/k>`0
0`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo02D0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`P0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00=0>c/
k0030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0:03oool00`000000k>c/0>c/k00R0>c/
k0030000003IfMT0fMWI03D0fMWI5P00000e0=WIf@030000003/k>`0k>c/0240k>c/00<000000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`0U0?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool80<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`08@3/k>`00`000000
fMWI0=WIf@0b0=WIf@@000005P36a/H400000380fMWI0P00000Q0>c/k0030000003oool0oooo02T0
oooo00<0003o0?ooo`3oool0903oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
2036a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0X0?ooo`030000003/k>`0k>c/0240k>c/00<000000=WIf@3IfMT0
;P3IfMT5000001h0a/K60`00000a0=WIf@030000003/k>`0k>c/01l0k>c/00<000000?ooo`3oool0
:03oool00`000?l0oooo0?ooo`0T0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool70<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`08@3/k>`00`000000fMWI0=WI
f@0]0=WIf@8000009P36a/H2000002l0fMWI00<000000>c/k03/k>`07`3/k>`00`000000oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo02<0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`L0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0
oooo01D0oooo00<0003o0?ooo`3oool0:03oool00`000000k>c/0>c/k00P0>c/k0030000003IfMT0
fMWI02`0fMWI0P00000Z0<K6aP<00000;@3IfMT00`000000k>c/0>c/k00O0>c/k0030000003oool0
oooo02P0oooo00<0003o0?ooo`3oool08`3oool100000040oooo000O0?ooo`<000001@3oool60<K6
aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`08@3/k>`00`000000fMWI0=WIf@0Z0=WI
f@800000;`36a/H3000002/0fMWI00<000000>c/k03/k>`07P3/k>`00`000000oooo0?ooo`0X0?oo
o`030000o`3oool0oooo0280oooo0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0
a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool0:03oool00`000000k>c/0>c/k00P0>c/k0030000003IfMT0fMWI02T0
fMWI0P00000d0<K6aP030000003IfMT0fMWI02T0fMWI00<000000>c/k03/k>`07P3/k>`00`000000
oooo0?ooo`0X0?ooo`030000o`3oool0oooo0280oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00>0>c/k0030000
003oool0oooo01@0oooo00<0003o0?ooo`3oool09`3oool00`000000k>c/0>c/k00P0>c/k0030000
003IfMT0fMWI02P0fMWI0P00000g0<K6aP800000:@3IfMT00`000000k>c/0>c/k00N0>c/k0030000
003oool0oooo02P0oooo00<0003o0?ooo`3oool08P3oool100000040oooo000O0?ooo`030000003o
ool0oooo00D0oooo1@36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/00h0k>c/00<0
00000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0V0?ooo`030000003/k>`0k>c/0200k>c/00<0
00000=WIf@3IfMT09`3IfMT2000003/0a/K60P00000X0=WIf@030000003/k>`0k>c/01h0k>c/00<0
00000?ooo`3oool09`3oool010000?l0oooo0?l0003o000Q0?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool50<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`03P3/
k>`00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`0803/
k>`00`000000fMWI0=WIf@0U0=WIf@800000?`36a/H2000002L0fMWI00<000000>c/k03/k>`07@3/
k>`00`000000oooo0?ooo`0V0?ooo`80o`0000<0003o0?l0003o00000`3o000N0?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool50<K6aP030000003IfMT0fMWI00T0fMWI00<00000
0>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo02H0oooo00<00000
0>c/k03/k>`0803/k>`00`000000fMWI0=WIf@0U0=WIf@0300000036a/H0a/K60440a/K600<00000
0=WIf@3IfMT09@3IfMT00`000000k>c/0>c/k00M0>c/k0030000003oool0oooo02@0oooo0`3o0000
0`000?l00?l0003o00040?l001d0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`D0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo
01@0oooo00<0003o0?ooo`3oool09P3oool00`000000k>c/0>c/k00O0>c/k0030000003IfMT0fMWI
02@0fMWI0P0000150<K6aP8000009P3IfMT00`000000k>c/0>c/k00L0>c/k0030000003oool0oooo
02@0oooo0P3o00001@00o`00003o0000o`000?l00?l000<0o`007@3oool100000040oooo000O0?oo
o`030000003oool0oooo00D0oooo1036a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/
00h0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0V0?ooo`030000003/k>`0k>c/
01l0k>c/00<000000=WIf@3IfMT0903IfMT00`000000a/K60<K6aP170<K6aP030000003IfMT0fMWI
02<0fMWI00<000000>c/k03/k>`07@3/k>`00`000000oooo0?ooo`0S0?ooo`030?l00000o`00003o
00@0003o00<00?l00?l0003o00007@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo1036a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`0V0?ooo`030000003/k>`0k>c/01l0k>c/00<000000=WIf@3I
fMT08P3IfMT2000004/0a/K60P00000T0=WIf@030000003/k>`0k>c/01`0k>c/00<000000?ooo`3o
ool08P3oool20?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000o`00703oool10000
0040oooo000O0?ooo`030000003oool0oooo00D0oooo1036a/H00`000000fMWI0=WIf@080=WIf@03
0000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0U0?ooo`03
0000003/k>`0k>c/01l0k>c/00<000000=WIf@3IfMT08P3IfMT00`000000a/K60<K6aP1=0<K6aP80
00008`3IfMT00`000000k>c/0>c/k00L0>c/k0030000003oool0oooo0240oooo0P3o00000`00o`00
003o0000o`030000o`04003o003o0000o`000?l001`0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`@0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k003
0000003oool0oooo01@0oooo00<0003o0?ooo`3oool09@3oool00`000000k>c/0>c/k00O0>c/k003
0000003IfMT0fMWI0280fMWI00<000000<K6aP36a/H0D036a/H00`000000fMWI0=WIf@0P0=WIf@03
0000003/k>`0k>c/01`0k>c/00<000000?ooo`3oool08P3oool20?l00005003o00000?l0003o0000
o`00o`000`3o000M0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool40<K6aP03
0000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0A0?ooo`80
o`0000<0oooo0000o`3oool09P3oool00`000000k>c/0>c/k00N0>c/k0030000003IfMT0fMWI0240
fMWI0P00001D0<K6aP8000008@3IfMT00`000000k>c/0>c/k00L0>c/k0030000003oool0oooo0240
oooo0`3o0002003o00030000o`3o0000o`000080o`007@3oool100000040oooo000O0?ooo`030000
003oool0oooo00D0oooo0`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00h0k>c/
00<000000?ooo`3oool03`3oool50?l000030000o`3o0000o`0002D0oooo00<000000>c/k03/k>`0
7P3/k>`00`000000fMWI0=WIf@0Q0=WIf@0300000036a/H0a/K605H0a/K600<000000=WIf@3IfMT0
7P3IfMT00`000000k>c/0>c/k00L0>c/k0030000003oool0oooo0240oooo1P3o000010000?l0o`00
0?l0003o000M0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool30<K6aP030000
003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0>0?ooo`<0o`00
0`00o`0010000?l0o`000?l0003o000T0?ooo`030000003/k>`0k>c/01h0k>c/00<000000=WIf@3I
fMT0803IfMT00`000000a/K60<K6aP1G0<K6aP030000003IfMT0fMWI01l0fMWI0P00000M0>c/k003
0000003oool0oooo0240oooo1@3o00000`000?l0o`000?l0000N0?ooo`4000000@3oool001l0oooo
0`0000050?ooo`<0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000
003oool0oooo00h0oooo0P3o00000`00o`00003o0000o`020000o`<0o`008`3oool00`000000k>c/
0>c/k00N0>c/k0030000003IfMT0fMWI01l0fMWI0P00001K0<K6aP030000003IfMT0fMWI01l0fMWI
00<000000>c/k03/k>`0703/k>`00`000000oooo0?ooo`0S0?ooo`80o`0000<0oooo0000o`3oool0
7@3oool200000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P36a/H00`000000fMWI0=WI
f@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool03P3oool00`3o00000?l00000
o`040000o`03003o003o0000o`0002<0oooo00<000000>c/k03/k>`07@3/k>`00`000000fMWI0=WI
f@0O0=WIf@0300000036a/H0a/K605`0a/K60P00000P0=WIf@030000003/k>`0k>c/01/0k>c/00<0
00000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0M0?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool20<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`0
0`000000oooo0?ooo`0>0?ooo`80o`0000<00?l00000o`000?l00`000?l01000o`00o`000?l0003o
000Q0?ooo`030000003/k>`0k>c/01h0k>c/00<000000=WIf@3IfMT07P3IfMT00`000000a/K60<K6
aP1O0<K6aP030000003IfMT0fMWI01d0fMWI00<000000>c/k03/k>`0703/k>`00`000000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo01d0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`80a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0
oooo00h0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l00240oooo00<0
00000>c/k03/k>`07@3/k>`00`000000fMWI0=WIf@0N0=WIf@0300000036a/H0a/K60640a/K600<0
00000=WIf@3IfMT07@3IfMT00`000000k>c/0>c/k00K0>c/k0030000003oool0oooo02H0oooo00<0
003o0?l0003o0000703oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P36a/H0
0`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool03`3oool2
0?l00005003o00000?l0003o0000o`00o`000`3o000Q0?ooo`030000003/k>`0k>c/01d0k>c/00<0
00000=WIf@3IfMT07@3IfMT2000006D0a/K60P00000N0=WIf@030000003/k>`0k>c/01X0k>c/00<0
00000?ooo`3oool0903oool20?l000030000o`3o0000o`0000<0o`006@3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo00<0a/K60000003IfMT02@3IfMT00`000000k>c/0>c/k00>
0>c/k0030000003oool0oooo0100oooo0`3o00000`00o`00003o003o00040?l00240oooo00<00000
0>c/k03/k>`07@3/k>`00`000000fMWI0=WIf@0L0=WIf@0300000036a/H0a/K606L0a/K600<00000
0=WIf@3IfMT0703IfMT00`000000k>c/0>c/k00J0>c/k0030000003oool0oooo0280oooo103o0000
0`000?l00?l0003o00030?l001P0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`030<K6aP000000fMWI00T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0@0?oo
o`@0o`0000<0003o0?l0003o00000`3o000P0?ooo`030000003/k>`0k>c/01d0k>c/00<000000=WI
f@3IfMT07@3IfMT00`000000a/K60<K6aP1W0<K6aP030000003IfMT0fMWI01`0fMWI00<000000>c/
k03/k>`06P3/k>`00`000000oooo0?ooo`0R0?ooo`<0o`0000D00?l00000o`000?l0003o003o0002
0?l001P0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030<K6aP000000fMWI
00T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0A0?ooo`80o`0000<0003o0?l0
003o00000`3o000Q0?ooo`030000003/k>`0k>c/01d0k>c/00<000000=WIf@3IfMT0703IfMT00`00
0000a/K60<K6aP1Y0<K6aP030000003IfMT0fMWI01`0fMWI00<000000>c/k03/k>`06P3/k>`00`00
0000oooo0?ooo`0Q0?ooo`80o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?ooo`0G0?oo
o`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`36a/H000000=WIf@090=WIf@03
0000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool04`3oool00`000?l0o`000?l0000S0?ooo`03
0000003/k>`0k>c/01d0k>c/00<000000=WIf@3IfMT06`3IfMT2000006d0a/K60P00000M0=WIf@03
0000003/k>`0k>c/01X0k>c/00<000000?ooo`3oool07`3oool30?l00003003o00000?l0003o00<0
003o00<00?l00?l0003o00005`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
00<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo01@0oooo
00<0003o0?ooo`3oool08`3oool00`000000k>c/0>c/k00L0>c/k0030000003IfMT0fMWI01/0fMWI
00<000000<K6aP36a/H0K`36a/H00`000000fMWI0=WIf@0J0=WIf@030000003/k>`0k>c/01X0k>c/
00<000000?ooo`3oool07`3oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0003o0000
5`3oool100000040oooo00020?ooo`@000001P3oool2000000H0oooo100000070?ooo`030000003o
ool0oooo00D0oooo00<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000003o
ool0oooo01<0oooo00<0003o0?ooo`3oool0903oool00`000000k>c/0>c/k00K0>c/k0030000003I
fMT0fMWI01/0fMWI00<000000<K6aP36a/H0L@36a/H00`000000fMWI0=WIf@0J0=WIf@030000003/
k>`0k>c/01X0k>c/00<000000?ooo`3oool07`3oool30?l00005003o00000?l0003o0000o`00o`00
0P3o000H0?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo2`3IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo01@0oooo00<0
003o0?ooo`3oool08`3oool00`000000k>c/0>c/k00K0>c/k0030000003IfMT0fMWI01/0fMWI00<0
00000<K6aP36a/H0L`36a/H00`000000fMWI0=WIf@0J0=WIf@030000003/k>`0k>c/01T0k>c/00<0
00000?ooo`3oool07`3oool40?l000800?l000@0003o0?l0003o0000o`00603oool100000040oooo
00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo2P3IfMT00`000000k>c/0>c/
k00>0>c/k0030000003oool0oooo01@0oooo00<0003o0?ooo`3oool08`3oool00`000000k>c/0>c/
k00K0>c/k0030000003IfMT0fMWI01X0fMWI00<000000<K6aP36a/H0<`36a/H>000003<0a/K600<0
00000=WIf@3IfMT06`3IfMT00`000000k>c/0>c/k00I0>c/k0030000003oool0oooo01h0oooo1P3o
000010000?l0o`000?l0003o000H0?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo1000
00040?ooo`X0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo02<0oooo00<000000>c/k03/k>`06`3/k>`00`000000fMWI0=WIf@0J0=WIf@0300000036
a/H0a/K602`0a/K62000000>0;>c/`@00000<036a/H00`000000fMWI0=WIf@0J0=WIf@030000003/
k>`0k>c/01T0k>c/00<000000?ooo`3oool07`3oool60?l000030000o`3o0000oooo01H0oooo0`00
00010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`@000001`3oool0
0`000000oooo0?ooo`050?ooo`X0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo02<0oooo00<000000>c/k03/k>`06`3/k>`00`000000fMWI0=WIf@0I
0=WIf@0300000036a/H0a/K602X0a/K60`00000J0;>c/`H00000:`36a/H2000001/0fMWI00<00000
0>c/k03/k>`06@3/k>`00`000000oooo0?ooo`0Q0?ooo`80o`0000<0oooo0000o`3oool06@3oool1
00000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo2P3IfMT00`00
0000k>c/0>c/k00>0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool08P3oool00`00
0000k>c/0>c/k00K0>c/k0030000003IfMT0fMWI01T0fMWI00<000000<K6aP36a/H0:@36a/H20000
02<0/k>c0P00000[0<K6aP030000003IfMT0fMWI01P0fMWI00<000000>c/k03/k>`06@3/k>`00`00
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01L0oooo0@0000010?ooo`0000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo02<0oooo00<000000>c/k03/k>`06P3/k>`00`000000
fMWI0=WIf@0I0=WIf@0300000036a/H0a/K602L0a/K60`00000W0;>c/`<00000:036a/H00`000000
fMWI0=WIf@0I0=WIf@030000003/k>`0k>c/01T0k>c/00<000000?ooo`3oool0903oool00`000?l0
oooo0?ooo`0G0?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool90=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0R0?ooo`030000003/k>`0k>c/01/0k>c/00<000000=WIf@3IfMT0603IfMT00`000000a/K6
0<K6aP0U0<K6aP<00000;@2c/k<2000002L0a/K600<000000=WIf@3IfMT0603IfMT00`000000k>c/
0>c/k00I0>c/k0030000003oool0oooo02@0oooo00<0003o0?ooo`3oool05`3oool100000040oooo
00020?ooo`@000003P3oool4000000L0oooo00<000000?ooo`3oool01@3oool90=WIf@030000003/
k>`0k>c/00h0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0R0?ooo`030000003/
k>`0k>c/01X0k>c/00<000000=WIf@3IfMT06@3IfMT00`000000a/K60<K6aP0S0<K6aP800000<P2c
/k<3000002D0a/K600<000000=WIf@3IfMT0603IfMT00`000000k>c/0>c/k00H0>c/k0030000003o
ool0oooo02D0oooo00<0003o0?ooo`3oool05P3oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo2@3IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo01<0oooo00<0003o
0?ooo`3oool08P3oool00`000000k>c/0>c/k00J0>c/k0030000003IfMT0fMWI01T0fMWI00<00000
0<K6aP36a/H08P36a/H2000003L0/k>c0P00000T0<K6aP030000003IfMT0fMWI01L0fMWI00<00000
0>c/k03/k>`0603/k>`00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01H0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`P0fMWI00<000000>c/k03/k>`03P3/k>`00`00
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0280oooo00<000000>c/k03/k>`06P3/k>`00`00
0000fMWI0=WIf@0I0=WIf@0300000036a/H0a/K60200a/K60P00000k0;>c/`0300000036a/H0a/K6
0240a/K600<000000=WIf@3IfMT0603IfMT00`000000k>c/0>c/k00H0>c/k0030000003oool0oooo
02@0oooo00<0003o0?ooo`3oool05P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo203IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo01@0oooo00<0003o0?ooo`3o
ool08@3oool00`000000k>c/0>c/k00J0>c/k0030000003IfMT0fMWI01T0fMWI00<000000<K6aP36
a/H07`36a/H2000003h0/k>c0P00000R0<K6aP030000003IfMT0fMWI01L0fMWI00<000000>c/k03/
k>`0603/k>`00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01D0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`050?ooo`P0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo0240oooo00<000000>c/k03/k>`06P3/k>`00`000000fMWI
0=WIf@0H0=WIf@0300000036a/H0a/K601l0a/K600<000000;>c/`2c/k<0@02c/k<200000240a/K6
00<000000=WIf@3IfMT05`3IfMT00`000000k>c/0>c/k00H0>c/k0030000003oool0oooo02@0oooo
00<0003o0?ooo`3oool05@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo203I
fMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool08P3o
ool00`000000k>c/0>c/k00I0>c/k0030000003IfMT0fMWI01P0fMWI00<000000<K6aP36a/H07`36
a/H00`000000/k>c0;>c/`130;>c/`8000008036a/H00`000000fMWI0=WIf@0G0=WIf@030000003/
k>`0k>c/01L0k>c/00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0D0?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool70=WIf@030000003/k>`0k>c/00d0k>c/00<00000
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0Q0?ooo`030000003/k>`0k>c/01X0k>c/00<00000
0=WIf@3IfMT05`3IfMT00`000000a/K60<K6aP0O0<K6aP030000002c/k<0/k>c04H0/k>c00<00000
0<K6aP36a/H07P36a/H00`000000fMWI0=WIf@0G0=WIf@030000003/k>`0k>c/01L0k>c/00<00000
0?ooo`3oool0903oool00`000?l0oooo0?ooo`0D0?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool70=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0Q0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT0603IfMT00`00
0000a/K60<K6aP0M0<K6aP800000BP2c/k<2000001l0a/K600<000000=WIf@3IfMT05P3IfMT00`00
0000k>c/0>c/k00G0>c/k0030000003oool0oooo02@0oooo00@0003o0?ooo`3o0000o`004`3oool1
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo1`3IfMT00`000000k>c/0>c/k00=0>c/
k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool08@3oool00`000000k>c/0>c/k00J0>c/
k0030000003IfMT0fMWI01H0fMWI0P00000N0<K6aP800000CP2c/k<00`000000a/K60<K6aP0M0<K6
aP030000003IfMT0fMWI01H0fMWI00<000000>c/k03/k>`05`3/k>`00`000000oooo0?ooo`0R0?oo
o`80o`0000<0003o0?l0003o00000`3o000@0?ooo`4000000@3oool001l0oooo0`0000050?ooo`L0
fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0240
oooo00<000000>c/k03/k>`06@3/k>`00`000000fMWI0=WIf@0F0=WIf@0300000036a/H0a/K601d0
a/K600<000000;>c/`2c/k<0C`2c/k<00`000000a/K60<K6aP0L0<K6aP030000003IfMT0fMWI01H0
fMWI00<000000>c/k03/k>`05`3/k>`00`000000oooo0?ooo`0Q0?ooo`<0o`0000<0003o003o0000
o`00103o000>0?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool60=WIf@030000
003/k>`0k>c/00d0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0P0?ooo`030000
003/k>`0k>c/01X0k>c/00<000000=WIf@3IfMT05@3IfMT00`000000a/K60<K6aP0L0<K6aP800000
D`2c/k<00`000000a/K60<K6aP0L0<K6aP030000003IfMT0fMWI01H0fMWI00<000000>c/k03/k>`0
5`3/k>`00`000000oooo0?ooo`0P0?ooo`80o`0000<00?l00000o`00o`000P00o`030?l000l0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0fMWI00<000000>c/k03/k>`03@3/
k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0240oooo00<000000>c/k03/k>`06@3/
k>`00`000000fMWI0=WIf@0F0=WIf@0300000036a/H0a/K601/0a/K600<000000;>c/`2c/k<0E02c
/k<2000001d0a/K600<000000=WIf@3IfMT05@3IfMT00`000000k>c/0>c/k00G0>c/k0030000003o
ool0oooo0200oooo00D0o`00003o0000o`000?l00000o`03003o0080o`001`3oool20?l000H0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0fMWI00<000000>c/k03/k>`03@3/
k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0240oooo00<000000>c/k03/k>`0603/
k>`00`000000fMWI0=WIf@0F0=WIf@0300000036a/H0a/K601/0a/K600<000000;>c/`2c/k<0E`2c
/k<00`000000a/K60<K6aP0K0<K6aP030000003IfMT0fMWI01D0fMWI00<000000>c/k03/k>`05`3/
k>`00`000000oooo0?ooo`0N0?ooo`80o`000`00o`0010000?l00?l0003o0000o`030?l000<0oooo
203o00030?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool60=WIf@030000003/
k>`0k>c/00d0k>c/00<000000?ooo`3oool0403oool20?l000030?ooo`000?l0oooo0240oooo00<0
00000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0G0=WIf@0300000036a/H0a/K601T0a/K60P00
001K0;>c/`0300000036a/H0a/K601X0a/K600<000000=WIf@3IfMT05@3IfMT00`000000k>c/0>c/
k00G0>c/k0030000003oool0oooo01h0oooo0P3o0004003o00030000o`00o`000?l000<0o`000P3o
ool:0?l00080oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0fMWI00<00000
0>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0>0?ooo`D0o`0000<0003o0?l0003o00008@3oool0
0`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01H0fMWI00<000000<K6aP36a/H06@36a/H0
0`000000/k>c0;>c/`1L0;>c/`8000006`36a/H00`000000fMWI0=WIf@0E0=WIf@030000003/k>`0
k>c/01L0k>c/00<000000?ooo`3oool07P3oool20?l000<00?l000<0003o003o003o00000`3o0002
0?ooo`<0o`000`00o`040?l00080oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`D0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0=0?ooo`H0o`0000@0003o0?l0
003o0000o`007`3oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01L0fMWI00<00000
0<K6aP36a/H06036a/H00`000000/k>c0;>c/`1O0;>c/`0300000036a/H0a/K601P0a/K600<00000
0=WIf@3IfMT05@3IfMT00`000000k>c/0>c/k00G0>c/k0030000003oool0oooo01h0oooo0`3o0000
1@00o`00003o0000o`000?l00?l000<0o`000P3oool20?l000D00?l00`3o00020?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool50=WIf@030000003/k>`0k>c/00d0k>c/00<00000
0?ooo`3oool03@3oool40?l000800?l000@0003o0?l0003o0000o`007`3oool00`000000k>c/0>c/
k00H0>c/k0030000003IfMT0fMWI01H0fMWI00<000000<K6aP36a/H06@36a/H00`000000/k>c0;>c
/`1P0;>c/`0300000036a/H0a/K601P0a/K600<000000=WIf@3IfMT05@3IfMT00`000000k>c/0>c/
k00G0>c/k0030000003oool0oooo01d0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o
0000o`000?ooo`80o`001`00o`030?l00040oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?ooo`@0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0=0?ooo`<0o`0000D0
0?l00000o`000?l0003o003o00020?l001h0oooo00<000000>c/k03/k>`0603/k>`00`000000fMWI
0=WIf@0F0=WIf@0300000036a/H0a/K601P0a/K60P00001T0;>c/`8000006@36a/H00`000000fMWI
0=WIf@0E0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool07@3oool20?l00003003o
00000?l0003o00<0003o00<00?l00?l0003o00000`3o0007003o00<0o`000@3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo103IfMT00`000000k>c/0>c/k00=0>c/k0030000003o
ool0oooo00d0oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0001d0oooo00<0
00000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0E0=WIf@0300000036a/H0a/K601P0a/K600<0
00000;>c/`2c/k<0IP2c/k<00`000000a/K60<K6aP0G0<K6aP030000003IfMT0fMWI01@0fMWI00<0
00000>c/k03/k>`05P3/k>`00`000000oooo0?ooo`0M0?ooo`80o`0000<00?l00000o`000?l00`00
0?l01P00o`00o`000?l0003o0000oooo0?l000L00?l00P3o00020?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool01@3oool40=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool0
3@3oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0003o0000703oool00`000000k>c/
0>c/k00H0>c/k0030000003IfMT0fMWI01D0fMWI00<000000<K6aP36a/H06036a/H00`000000/k>c
0;>c/`1W0;>c/`0300000036a/H0a/K601P0a/K600<000000=WIf@3IfMT0503IfMT00`000000k>c/
0>c/k00F0>c/k0030000003oool0oooo01d0oooo0P3o00001@00o`00003o0000o`000?l00?l000<0
o`000P3oool20?l000D00?l00`3o00020?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool40=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool03P3oool20?l00003003o
00000?l0003o00<0003o00<00?l00?l0003oool0703oool00`000000k>c/0>c/k00H0>c/k0030000
003IfMT0fMWI01D0fMWI00<000000<K6aP36a/H05`36a/H00`000000/k>c0;>c/`1Y0;>c/`030000
0036a/H0a/K601L0a/K600<000000=WIf@3IfMT0503IfMT00`000000k>c/0>c/k00F0>c/k0030000
003oool0oooo01d0oooo0`3o0003003o00040000o`3o0000o`000?l00080oooo0`3o0003003o00@0
o`000P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo103IfMT00`000000k>c/
0>c/k00=0>c/k0030000003oool0oooo00h0oooo0`3o00001@00o`00003o0000o`000?l00?l00080
o`00703oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01D0fMWI00<000000<K6aP36
a/H05`36a/H00`000000/k>c0;>c/`0^0;>c/`h00000;`2c/k<2000001P0a/K600<000000=WIf@3I
fMT0503IfMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo01`0oooo1P3o000010000?l0
o`000?l0003o00030?ooo`P0o`000`3oool100000040oooo000O0?ooo`<000001@3oool30=WIf@03
0000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool03`3oool40?l000030000o`00o`000?l000<0
o`00703oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01@0fMWI00<000000<K6aP36
a/H05`36a/H00`000000/k>c0;>c/`0[0;>c/`@000003P2OWil4000002d0/k>c00<000000<K6aP36
a/H05P36a/H00`000000fMWI0=WIf@0C0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3o
ool07@3oool50?l000030000o`3o0000o`000080o`001@3oool20?l000D0oooo0P0000010?ooo`00
7`3oool00`000000oooo0?ooo`050?ooo`<0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo
0?ooo`0@0?ooo`<0o`0000<0003o0?l0003o00000P3o000L0?ooo`030000003/k>`0k>c/01P0k>c/
00<000000=WIf@3IfMT0503IfMT00`000000a/K60<K6aP0F0<K6aP800000:02c/k<6000001H0WinO
1@00000Y0;>c/`0300000036a/H0a/K601H0a/K600<000000=WIf@3IfMT04`3IfMT00`000000k>c/
0>c/k00F0>c/k0030000003oool0oooo01d0oooo103o00000`000?l0o`000?l000030?l000`0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0fMWI00<000000>c/k03/k>`03@3/
k>`00`000000oooo0?ooo`0B0?ooo`030000o`3o0000o`0001l0oooo00<000000>c/k03/k>`05`3/
k>`00`000000fMWI0=WIf@0D0=WIf@0300000036a/H0a/K601H0a/K600<000000;>c/`2c/k<09P2c
/k<200000240WinO0`00000W0;>c/`0300000036a/H0a/K601D0a/K600<000000=WIf@3IfMT0503I
fMT00`000000k>c/0>c/k00E0>c/k0030000003oool0oooo01d0oooo103o00000`00o`00003o003o
00030?l000`0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80fMWI00<00000
0>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01l0oooo00<00000
0>c/k03/k>`05`3/k>`00`000000fMWI0=WIf@0D0=WIf@0300000036a/H0a/K601H0a/K600<00000
0;>c/`2c/k<08`2c/k<3000002H0WinO0`00000T0;>c/`0300000036a/H0a/K601H0a/K600<00000
0=WIf@3IfMT04`3IfMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo01`0oooo0`3o0000
1@00o`00003o0000o`000?l00?l00080o`00303oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo0P3IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo01<0oooo00<0003o
0?ooo`3oool07P3oool00`000000k>c/0>c/k00G0>c/k0030000003IfMT0fMWI01@0fMWI00<00000
0<K6aP36a/H05P36a/H00`000000/k>c0;>c/`0R0;>c/`800000;02OWil2000002<0/k>c00<00000
0<K6aP36a/H05P36a/H00`000000fMWI0=WIf@0C0=WIf@030000003/k>`0k>c/01D0k>c/00<00000
0?ooo`3oool06`3oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0003o00002`3oool1
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P3IfMT00`000000k>c/0>c/k00=0>c/
k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool07P3oool00`000000k>c/0>c/k00G0>c/
k0030000003IfMT0fMWI01@0fMWI00<000000<K6aP36a/H05@36a/H00`000000/k>c0;>c/`0P0;>c
/`<00000<02OWil300000240/k>c0P00000G0<K6aP030000003IfMT0fMWI0180fMWI00<000000>c/
k03/k>`05P3/k>`00`000000oooo0?ooo`0J0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00
o`00o`000?l0000;0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool20=WIf@03
0000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0N0?ooo`03
0000003/k>`0k>c/01L0k>c/00<000000=WIf@3IfMT0503IfMT00`000000a/K60<K6aP0E0<K6aP03
0000002c/k<0/k>c01l0/k>c0P00000f09nOW`030000002c/k<0/k>c0200/k>c00<000000<K6aP36
a/H05@36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3o
ool06`3oool20?l00003003o00000?l0003o00<0003o00<00?l00?l0003oool02`3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo00<0fMWI0000003/k>`03P3/k>`00`000000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo01h0oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI
0=WIf@0C0=WIf@0300000036a/H0a/K601D0a/K600<000000;>c/`2c/k<07`2c/k<00`000000WinO
09nOW`0g09nOW`030000002c/k<0/k>c01l0/k>c00<000000<K6aP36a/H05@36a/H00`000000fMWI
0=WIf@0B0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?ooo`3oool06`3oool30?l00005003o
00000?l0003o0000o`00o`000P3o000<0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool00`3IfMT000000>c/k00>0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0
7@3oool00`000000k>c/0>c/k00G0>c/k0030000003IfMT0fMWI01<0fMWI00<000000<K6aP36a/H0
5@36a/H00`000000/k>c0;>c/`0N0;>c/`800000>`2OWil200000200/k>c00<000000<K6aP36a/H0
5@36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0
6P3oool40?l000800?l000@0003o0?l0003o0000o`00303oool100000040oooo000O0?ooo`030000
003oool0oooo00D0oooo00<0fMWI0000003/k>`03P3/k>`00`000000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo01h0oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI0=WIf@0C0=WIf@030000
0036a/H0a/K601@0a/K600<000000;>c/`2c/k<07@2c/k<2000003l0WinO0`00000N0;>c/`030000
0036a/H0a/K601@0a/K600<000000=WIf@3IfMT04P3IfMT00`000000k>c/0>c/k00E0>c/k0030000
003oool0oooo01/0oooo1P3o00000`000?l0o`000?ooo`0<0?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo0180oooo00<0
003o0?ooo`3oool07P3oool00`000000k>c/0>c/k00F0>c/k0030000003IfMT0fMWI01<0fMWI00<0
00000<K6aP36a/H05036a/H00`000000/k>c0;>c/`0L0;>c/`800000A02OWil2000001d0/k>c00<0
00000<K6aP36a/H04`36a/H00`000000fMWI0=WIf@0C0=WIf@030000003/k>`0k>c/01@0k>c/00<0
00000?ooo`3oool07P3oool20?l000030?ooo`000?l0oooo00d0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0M0?ooo`030000003/k>`0k>c/01L0k>c/00<000000=WIf@3IfMT04`3IfMT0
0`000000a/K60<K6aP0D0<K6aP030000002c/k<0/k>c01/0/k>c00<0000009nOW`2OWil0AP2OWil0
0`000000/k>c0;>c/`0J0;>c/`0300000036a/H0a/K601@0a/K600<000000=WIf@3IfMT04P3IfMT0
0`000000k>c/0>c/k00E0>c/k0030000003oool0oooo0200oooo00<0003o0?ooo`3oool0303oool1
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo403/k>`00`000000oooo0?ooo`0C0?oo
o`030000o`3oool0oooo01d0oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0C0=WI
f@0300000036a/H0a/K601@0a/K600<000000;>c/`2c/k<06P2c/k<2000004X0WinO0P00000K0;>c
/`0300000036a/H0a/K601<0a/K600<000000=WIf@3IfMT04`3IfMT00`000000k>c/0>c/k00D0>c/
k0030000003oool0oooo0240oooo00<0003o0?ooo`3oool02`3oool100000040oooo000O0?ooo`<0
00001@3oool?0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool07@3oool00`000000
k>c/0>c/k00G0>c/k0030000003IfMT0fMWI0180fMWI0P00000E0<K6aP030000002c/k<0/k>c01X0
/k>c00<0000009nOW`2OWil0C02OWil00`000000/k>c0;>c/`0I0;>c/`0300000036a/H0a/K601<0
a/K600<000000=WIf@3IfMT04P3IfMT00`000000k>c/0>c/k00E0>c/k0030000003oool0oooo0200
oooo00<0003o0?ooo`3oool02P3oool200000040oooo000O0?ooo`030000003oool0oooo00D0oooo
3`3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01d0oooo00<000000>c/k03/k>`0
5P3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K601@0a/K600<000000;>c/`2c/k<0
6P2c/k<00`000000WinO09nOW`1>09nOW`030000002c/k<0/k>c01T0/k>c00<000000<K6aP36a/H0
4P36a/H00`000000fMWI0=WIf@0B0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?ooo`3oool0
803oool00`000?l0o`000?l0000;0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool>0>c/k0030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0703oool00`000000k>c/0>c/
k00G0>c/k0030000003IfMT0fMWI0180fMWI00<000000<K6aP36a/H04`36a/H00`000000/k>c0;>c
/`0J0;>c/`030000002OWil0WinO0500WinO00<000000;>c/`2c/k<0602c/k<00`000000a/K60<K6
aP0C0<K6aP030000003IfMT0fMWI0180fMWI00<000000>c/k03/k>`05@3/k>`00`000000oooo0?oo
o`0M0?ooo`<0o`0000<0003o0?l0003o00000P3o00080?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool>0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool07@3oool0
0`000000k>c/0>c/k00F0>c/k0030000003IfMT0fMWI0180fMWI00<000000<K6aP36a/H05036a/H0
0`000000/k>c0;>c/`0H0;>c/`800000E02OWil2000001T0/k>c00<000000<K6aP36a/H04`36a/H0
0`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?ooo`3oool0703oool4
0?l000030000o`3o0000o`0000<0o`001`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo3P3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01d0oooo00<000000>c/
k03/k>`05P3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K601<0a/K600<000000;>c
/`2c/k<0602c/k<00`000000WinO09nOW`1F09nOW`030000002c/k<0/k>c01L0/k>c00<000000<K6
aP36a/H04`36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?oo
o`3oool06`3oool40?l000030000o`00o`000?l000<0o`001`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo3P3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01`0
oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K601<0
a/K600<000000;>c/`2c/k<0602c/k<00`000000WinO09nOW`1H09nOW`030000002c/k<0/k>c01L0
/k>c00<000000<K6aP36a/H04P36a/H00`000000fMWI0=WIf@0B0=WIf@030000003/k>`0k>c/01@0
k>c/00<000000?ooo`3oool06`3oool30?l00005003o00000?l0003o0000o`00o`000P3o00020000
00D0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`d0k>c/00<000000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`0L0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3I
fMT04P3IfMT00`000000a/K60<K6aP0B0<K6aP030000002c/k<0/k>c01L0/k>c0P00001L09nOW`80
0000602c/k<00`000000a/K60<K6aP0B0<K6aP030000003IfMT0fMWI0180fMWI00<000000>c/k03/
k>`0503/k>`00`000000oooo0?ooo`0I0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00
o`000?l00003000000<0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`d0k>c/
00<000000?ooo`3oool04@3oool20?l000030000o`3oool0oooo01`0oooo00<000000>c/k03/k>`0
5P3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K601<0a/K600<000000;>c/`2c/k<0
5P2c/k<00`000000WinO09nOW`1N09nOW`030000002c/k<0/k>c01D0/k>c00<000000<K6aP36a/H0
4P36a/H00`000000fMWI0=WIf@0B0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool0
6@3oool30?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000o`000`0000020?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3oool=0>c/k0030000003oool0oooo00h0oooo
1@3o00000`000?l0o`000?l0000L0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT0
4P3IfMT00`000000a/K60<K6aP0B0<K6aP030000002c/k<0/k>c01H0/k>c00<0000009nOW`2OWil0
H02OWil00`000000/k>c0;>c/`0E0;>c/`0300000036a/H0a/K60180a/K600<000000=WIf@3IfMT0
4@3IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01T0oooo00@000000?l0003o0000
0?l01@000?l01000o`00o`000?l0003o000400000040oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`040?ooo`80o`00303/k>`00`000000oooo0?ooo`0=0?ooo`H0o`0000@0003o0?l0003o
0000o`006`3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI0180fMWI00<000000<K6
aP36a/H04P36a/H00`000000/k>c0;>c/`0E0;>c/`800000I02OWil2000001H0/k>c00<000000<K6
aP36a/H04@36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?oo
o`3oool06@3oool01@000000o`000?l0003o00000?l000D0003o00<00?l00?l0003o000010000001
0?ooo`4000000@3oool001<0oooo1`0000050?ooo`040000003oool0oooo0?ooo`P0o`00203/k>`0
0`000000oooo0?ooo`0>0?ooo`@0o`000P00o`0010000?l0o`000?l0003o000J0?ooo`030000003/
k>`0k>c/01H0k>c/00<000000=WIf@3IfMT04P3IfMT00`000000a/K60<K6aP0A0<K6aP030000002c
/k<0/k>c01D0/k>c00<0000009nOW`2OWil0IP2OWil00`000000/k>c0;>c/`0D0;>c/`0300000036
a/H0a/K60140a/K600<000000=WIf@3IfMT04@3IfMT00`000000k>c/0>c/k00D0>c/k0030000003o
ool0oooo01L0oooo0P0000030?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000o`00
1@0000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0o`000`00
o`030?l000L0k>c/00<000000?ooo`3oool03P3oool30?l00005003o00000?l0003o0000o`00o`00
0P3o000J0?ooo`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT04P3IfMT00`000000a/K6
0<K6aP0B0<K6aP030000002c/k<0/k>c01@0/k>c00<0000009nOW`2OWil0:@2OWilD000002X0WinO
00<000000;>c/`2c/k<0502c/k<00`000000a/K60<K6aP0A0<K6aP030000003IfMT0fMWI0140fMWI
00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0G0?ooo`<000000P3o00000`00o`00003o
0000o`030000o`04003o003o0000o`000?l000D000000@3oool001H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?l00005003o00000?l0003o0000o`00o`000P3o00070>c/k003
0000003oool0oooo00d0oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0001T0
oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K60140
a/K600<000000;>c/`2c/k<05@2c/k<00`000000WinO09nOW`0T09nOW`D00000502<S8`5000002H0
WinO00<000000;>c/`2c/k<0502c/k<00`000000a/K60<K6aP0A0<K6aP030000003IfMT0fMWI0140
fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0E0?ooo`D000000P3o00000`00o`00
003o0000o`030000o`03003o003o0000o`0000D000000@3oool001H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?l00003003o00000?l0003o00<0003o00<00?l00?l0003/k>`0
1P3/k>`00`000000oooo0?ooo`0=0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`00
0?l0000H0?ooo`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT04P3IfMT00`000000a/K6
0<K6aP0A0<K6aP030000002c/k<0/k>c01@0/k>c0P00000T09nOW`<000007P2<S8`3000002@0WinO
0P00000E0;>c/`0300000036a/H0a/K60140a/K600<000000=WIf@3IfMT04@3IfMT00`000000k>c/
0>c/k00C0>c/k0030000003oool0oooo01D0oooo1@0000020?l00003003o00000?l0003o00<0003o
00@00?l00?l0003o0000o`00100000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`800000
0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0000H0k>c/00<000000?ooo`3oool0
3P3oool20?l00003003o00000?l0003o00<0003o00<00?l00?l0003oool0603oool00`000000k>c/
0>c/k00E0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04@36a/H00`000000/k>c
0;>c/`0D0;>c/`030000002OWil0WinO0280WinO0P00000T08b<S0800000902OWil00`000000/k>c
0;>c/`0C0;>c/`0300000036a/H0a/K60100a/K600<000000=WIf@3IfMT04P3IfMT00`000000k>c/
0>c/k00B0>c/k0030000003oool0oooo01D0oooo1@0000020?l00003003o00000?l0003o00<0003o
00@00?l00?l0003o0000o`00100000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0o`000080o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l000050>c/k0030000
003oool0oooo00l0oooo0`3o00001@00o`00003o0000o`000?l00?l00080o`00603oool00`000000
k>c/0>c/k00E0>c/k0030000003IfMT0fMWI0180fMWI00<000000<K6aP36a/H04036a/H00`000000
/k>c0;>c/`0D0;>c/`030000002OWil0WinO0240WinO0P00000X08b<S08000008P2OWil00`000000
/k>c0;>c/`0D0;>c/`0300000036a/H0a/K60100a/K600<000000=WIf@3IfMT04@3IfMT00`000000
k>c/0>c/k00C0>c/k0030000003oool0oooo01@0oooo1@0000020?l00003003o00000?l0003o00<0
003o00@00?l00?l0003o0000o`00100000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0o`0000D00?l00000o`000?l0003o003o00020000o`H0k>c/00<000000?oo
o`3oool03`3oool40?l000030000o`00o`000?l000<0o`00603oool00`000000k>c/0>c/k00E0>c/
k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04@36a/H00`000000/k>c0;>c/`0D0;>c
/`030000002OWil0WinO01d0WinO1000000/08b<S0@000007`2OWil00`000000/k>c0;>c/`0C0;>c
/`0300000036a/H0a/K60140a/K600<000000=WIf@3IfMT0403IfMT00`000000k>c/0>c/k00C0>c/
k0030000003oool0oooo01@0oooo1P0000020?l00005003o00000?l0003o0000o`00o`000`3o0005
00000040oooo000D0?ooo`<00000203oool00`000000oooo0?ooo`040?l000<00?l00`3o00000`00
0?l0k>c/0>c/k0030>c/k0030000003oool0oooo0100oooo0`3o00000`000?l0o`000?l000020?l0
01P0oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0A0=WIf@0300000036a/H0a/K6
0140a/K600<000000;>c/`2c/k<04`2c/k<2000001h0WinO0P00000d08b<S08000007P2OWil00`00
0000/k>c0;>c/`0C0;>c/`0300000036a/H0a/K60140a/K600<000000=WIf@3IfMT0403IfMT00`00
0000k>c/0>c/k00C0>c/k0030000003oool0oooo01@0oooo1@0000030?l000<00?l0103o00050000
0040oooo000F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o00000`3/k>`0
003o0000o`020>c/k0030000003oool0oooo01@0oooo00<0003o0?l0003oool06P3oool00`000000
k>c/0>c/k00E0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04@36a/H00`000000
/k>c0;>c/`0B0;>c/`030000002OWil0WinO01`0WinO0P00000h08b<S08000007@2OWil00`000000
/k>c0;>c/`0C0;>c/`0300000036a/H0a/K60100a/K600<000000=WIf@3IfMT0403IfMT00`000000
k>c/0>c/k00C0>c/k0030000003oool0oooo01@0oooo1@00000:0?l000D000000@3oool001l0oooo
00@000000?ooo`3oool0oooo203o00040>c/k0030000o`3/k>`0000001D0oooo00<0003o0?ooo`3o
ool06`3oool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36
a/H04@36a/H00`000000/k>c0;>c/`0B0;>c/`030000002OWil0WinO01/0WinO0P00000l08b<S080
0000702OWil2000001@0/k>c00<000000<K6aP36a/H04036a/H00`000000fMWI0=WIf@0@0=WIf@03
0000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool0503oool5000000P0o`00100000010?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool0103oool20?l000P0k>c/0P000?lC0?ooo`80o`00
00<0003o0?ooo`3oool06P3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI0140fMWI
00<000000<K6aP36a/H04036a/H00`000000/k>c0;>c/`0B0;>c/`030000002OWil0WinO01X0WinO
0P00001008b<S0030000002OWil0WinO01/0WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K6
0<K6aP0@0<K6aP030000003IfMT0fMWI0100fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo
0?ooo`0D0?ooo`P000000P3o000700000040oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?ooo`T0k>c/00@000000?ooo`000?l0003o3P3oool50?l000030000o`3o0000o`0001X0oooo
00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0@0=WIf@0300000036a/H0a/K60100a/K6
00<000000;>c/`2c/k<04P2c/k<00`000000WinO09nOW`0J09nOW`030000002<S8`0S8b<0440S8b<
00<0000009nOW`2OWil06P2OWil00`000000/k>c0;>c/`0B0;>c/`0300000036a/H0a/K60100a/K6
00<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo01D0oooo
3`0000020?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool90>c/k0050000003o
ool0oooo0?ooo`000?l0303oool30?l000<00?l000@0003o0?l0003o0000o`00603oool00`000000
k>c/0>c/k00E0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04036a/H00`000000
/k>c0;>c/`0A0;>c/`030000002OWil0WinO01X0WinO00<0000008b<S02<S8`0@`2<S8`2000001/0
WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K60<K6aP0@0<K6aP030000003IfMT0fMWI0100
fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0E0?ooo`d000000`3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo2@3/k>`00`000000oooo0?ooo`020?ooo`80003o
2P3oool20?l00005003o00000?l0003o0000o`00o`000`3o000H0?ooo`030000003/k>`0k>c/01D0
k>c/00<000000=WIf@3IfMT0403IfMT00`000000a/K60<K6aP0@0<K6aP030000002c/k<0/k>c0180
/k>c00<0000009nOW`2OWil0602OWil2000004P0S8b<0P00000J09nOW`030000002c/k<0/k>c0140
/k>c00<000000<K6aP36a/H04036a/H00`000000fMWI0=WIf@0?0=WIf@800000503/k>`00`000000
oooo0?ooo`0G0?ooo`T000001@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
2@3/k>`00`000000oooo0?ooo`040?ooo`80003o203oool00`3o00000?l00000o`040000o`03003o
003o0000o`0001L0oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0@0=WIf@030000
0036a/H0a/K60100a/K600<000000;>c/`2c/k<04P2c/k<00`000000WinO09nOW`0G09nOW`800000
C02<S8`2000001T0WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K60<K6aP0?0<K6aP030000
003IfMT0fMWI0100fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0I0?ooo`D00000
1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo203/k>`00`000000oooo0?oo
o`070?ooo`030000o`3oool0oooo00@0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o
0000o`000?l001H0oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0@0=WIf@030000
0036a/H0a/K60100a/K600<000000;>c/`2c/k<04@2c/k<00`000000WinO09nOW`0G09nOW`030000
002<S8`0S8b<04h0S8b<00<0000009nOW`2OWil05P2OWil00`000000/k>c0;>c/`0B0;>c/`030000
0036a/H0a/K600l0a/K600<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00C0>c/k0030000
003oool0oooo02@0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`P0k>c/00<0
00000?ooo`3oool0203oool20000o`@0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o
0000o`000?l001D0oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0@0=WIf@030000
0036a/H0a/K60100a/K600<000000;>c/`2c/k<04P2c/k<00`000000WinO09nOW`0E09nOW`800000
DP2<S8`2000001L0WinO00<000000;>c/`2c/k<04P2c/k<00`000000a/K60<K6aP0>0<K6aP030000
003IfMT0fMWI0100fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0T0?ooo`400000
0@3oool001l0oooo0`0000050?ooo`P0k>c/00<000000?ooo`3oool02P3oool20000o`80oooo0`3o
00001@00o`00003o0000o`000?l00?l000<0o`005P3oool00`000000k>c/0>c/k00E0>c/k0030000
003IfMT0fMWI0100fMWI00<000000<K6aP36a/H03`36a/H00`000000/k>c0;>c/`0A0;>c/`800000
5`2OWil00`000000S8b<08b<S01D08b<S0030000002OWil0WinO01D0WinO00<000000;>c/`2c/k<0
4@2c/k<00`000000a/K60<K6aP0?0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`0
4`3/k>`00`000000oooo0?ooo`0R0?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool80>c/k0030000003oool0oooo00`0oooo00<0003o0?ooo`3o00000P3o00001@00o`00003o0000
o`000?l00?l000<0o`005P3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI00l0fMWI
00<000000<K6aP36a/H03`36a/H00`000000/k>c0;>c/`0A0;>c/`030000002OWil0WinO01H0WinO
00<0000008b<S02<S8`0EP2<S8`00`000000WinO09nOW`0E09nOW`030000002c/k<0/k>c0100/k>c
00<000000<K6aP36a/H03`36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/01<0k>c/
00<000000?ooo`3oool08`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo203/
k>`00`000000oooo0?ooo`0=0?ooo`80003o00<0o`00003o00000?l010000?l00`00o`00o`000?l0
000F0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT0403IfMT00`000000a/K60<K6
aP0?0<K6aP030000002c/k<0/k>c0100/k>c00<0000009nOW`2OWil05P2OWil00`000000S8b<08b<
S01H08b<S0030000002OWil0WinO01@0WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K60<K6
aP0?0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?oo
o`0S0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool70>c/k0030000003oool0
oooo00h0oooo0P3o00000`000?l00?l00000o`040000o`03003o003o0000o`0001D0oooo00<00000
0>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0?0=WIf@0300000036a/H0a/K600l0a/K600<00000
0;>c/`2c/k<04@2c/k<00`000000WinO09nOW`0D09nOW`800000G02<S8`00`000000WinO09nOW`0D
09nOW`030000002c/k<0/k>c0100/k>c00<000000<K6aP36a/H03`36a/H00`000000fMWI0=WIf@0?
0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool08P3oool100000040oooo000O0?oo
o`030000003oool0oooo00D0oooo1`3/k>`00`000000oooo0?ooo`0>0?ooo`80o`0000<00?l00000
o`000?l010000?l00`00o`00o`000?l0000E0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WI
f@3IfMT0403IfMT00`000000a/K60<K6aP0?0<K6aP030000002c/k<0/k>c0100/k>c00<0000009nO
W`2OWil0502OWil00`000000S8b<08b<S01M08b<S08000005@2OWil00`000000/k>c0;>c/`0@0;>c
/`0300000036a/H0a/K600l0a/K600<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00B0>c/
k0030000003oool0oooo0280oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`L0
k>c/00<000000?ooo`3oool03P3oool20?l00003003o00000?l0003o00@0003o00<00?l00?l0003o
0000503oool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI0100fMWI00<000000<K6aP36
a/H03`36a/H00`000000/k>c0;>c/`0A0;>c/`030000002OWil0WinO01<0WinO00<0000008b<S02<
S8`0H02<S8`00`000000WinO09nOW`0C09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36
a/H03`36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3o
ool08P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P3/k>`00`000000oooo
0?ooo`0?0?ooo`80o`0000<00?l00000o`000?l010000?l01000o`00o`000?l0003o000C0?ooo`03
0000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT0403IfMT00`000000a/K60<K6aP0?0<K6aP03
0000002c/k<0/k>c0100/k>c00<0000009nOW`2OWil04`2OWil00`000000S8b<08b<S00Y08b<S0h0
0000:`2<S8`00`000000WinO09nOW`0C09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36
a/H03`36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3o
ool08@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P3/k>`00`000000oooo
0?ooo`0@0?ooo`030?l00000o`00003o00D0003o00@00?l00?l0003o0000o`004P3oool00`000000
k>c/0>c/k00D0>c/k0030000003IfMT0fMWI0100fMWI00<000000<K6aP36a/H03`36a/H00`000000
/k>c0;>c/`0@0;>c/`030000002OWil0WinO01<0WinO00<0000008b<S02<S8`09P2<S8`4000000h0
NGUi1000000X08b<S0030000002OWil0WinO0180WinO00<000000;>c/`2c/k<0402c/k<00`000000
a/K60<K6aP0>0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`04P3/k>`00`000000
oooo0?ooo`0Q0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool60>c/k0030000
003oool0oooo0100oooo0P3o00000`00o`00003o0000o`020000o`04003o003o0000o`000?l001<0
oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0@0=WIf@0300000036a/H0a/K600l0
a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO09nOW`0C09nOW`030000002<S8`0S8b<0280
S8b<1@00000F07UiN@D00000902<S8`00`000000WinO09nOW`0B09nOW`030000002c/k<0/k>c0100
/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/0180
k>c/00<000000?ooo`3oool0803oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
1P3/k>`00`000000oooo0?ooo`0@0?ooo`<0o`001000o`040?l001<0oooo00<000000>c/k03/k>`0
503/k>`00`000000fMWI0=WIf@0?0=WIf@0300000036a/H0a/K600l0a/K600<000000;>c/`2c/k<0
3`2c/k<00`000000WinO09nOW`0C09nOW`030000002<S8`0S8b<0200S8b<0`00000P07UiN@<00000
8P2<S8`00`000000WinO09nOW`0B09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H0
3`36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0
803oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1@3/k>`00`000000oooo0?oo
o`0B0?ooo`X0o`004P3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI00l0fMWI00<0
00000<K6aP36a/H03P36a/H00`000000/k>c0;>c/`0@0;>c/`030000002OWil0WinO0180WinO00<0
000008b<S02<S8`07P2<S8`3000002H0NGUi0`00000P08b<S0030000002OWil0WinO0180WinO00<0
00000;>c/`2c/k<03`2c/k<00`000000a/K60<K6aP0>0<K6aP030000003IfMT0fMWI00l0fMWI00<0
00000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0O0?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool50>c/k0030000003oool0oooo01<0oooo203o000C0?ooo`030000003/k>`0
k>c/01@0k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0
/k>c0100/k>c00<0000009nOW`2OWil04P2OWil00`000000S8b<08b<S00M08b<S0800000;01iNGT2
000001l0S8b<00<0000009nOW`2OWil04@2OWil00`000000/k>c0;>c/`0?0;>c/`0300000036a/H0
a/K600l0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0
oooo01l0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0k>c/00<000000?oo
o`3oool05P3oool20?l001H0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0?0=WI
f@0300000036a/H0a/K600h0a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO09nOW`0B09nO
W`030000002<S8`0S8b<01`0S8b<0P00000`07UiN@<000007@2<S8`00`000000WinO09nOW`0A09nO
W`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0?0=WI
f@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool07`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo1@3/k>`00`000000oooo0?ooo`0^0?ooo`030000003/k>`0k>c/01<0
k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00l0
/k>c00<0000009nOW`2OWil04P2OWil00`000000S8b<08b<S00K08b<S0800000=@1iNGT2000001`0
S8b<00<0000009nOW`2OWil04@2OWil00`000000/k>c0;>c/`0>0;>c/`0300000036a/H0a/K600h0
a/K600<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01l0
oooo0@0000010?ooo`007`3oool3000000D0oooo103/k>`00`000000oooo0?ooo`0^0?ooo`030000
003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000
002c/k<0/k>c00l0/k>c00<0000009nOW`2OWil04@2OWil00`000000S8b<08b<S00J08b<S0800000
>@1iNGT00`000000S8b<08b<S00I08b<S0030000002OWil0WinO0180WinO00<000000;>c/`2c/k<0
3P2c/k<00`000000a/K60<K6aP0>0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`0
4P3/k>`00`000000oooo0?ooo`0M0?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool40>c/k0030000003oool0oooo02h0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WI
f@0?0=WIf@0300000036a/H0a/K600h0a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO09nO
W`0A09nOW`030000002<S8`0S8b<01T0S8b<0P00000l07UiN@8000006P2<S8`00`000000WinO09nO
W`0B09nOW`030000002c/k<0/k>c00d0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WI
f@0?0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool07P3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo103/k>`00`000000oooo0?ooo`0^0?ooo`030000003/k>`0
k>c/01<0k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0
/k>c00l0/k>c00<0000009nOW`2OWil0402OWil00`000000S8b<08b<S00H08b<S0800000@01iNGT0
0`000000S8b<08b<S00H08b<S0030000002OWil0WinO0140WinO00<000000;>c/`2c/k<03P2c/k<0
0`000000a/K60<K6aP0>0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`04P3/k>`0
0`000000oooo0?ooo`0M0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool40>c/
k0030000003oool0oooo02d0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0>0=WI
f@0300000036a/H0a/K600h0a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO09nOW`0@09nO
W`030000002<S8`0S8b<01L0S8b<0P00001307UiN@8000006@2<S8`00`000000WinO09nOW`0A09nO
W`030000002c/k<0/k>c00h0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0=0=WI
f@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07@3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo0`3/k>`00`000000oooo0?ooo`0^0?ooo`030000003/k>`0k>c/01<0
k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00h0
/k>c00<0000009nOW`2OWil0402OWil00`000000S8b<08b<S00G08b<S0030000001iNGT0NGUi04D0
NGUi0P00000H08b<S0030000002OWil0WinO0100WinO00<000000;>c/`2c/k<03P2c/k<00`000000
a/K60<K6aP0>0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`04@3/k>`00`000000
oooo0?ooo`0M0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool30>c/k0030000
003oool0oooo02d0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0>0=WIf@030000
0036a/H0a/K600h0a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO09nOW`0@09nOW`030000
002<S8`0S8b<01D0S8b<0P00001:07UiN@030000002<S8`0S8b<01H0S8b<00<0000009nOW`2OWil0
402OWil00`000000/k>c0;>c/`0>0;>c/`0300000036a/H0a/K600h0a/K600<000000=WIf@3IfMT0
3@3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo01`0oooo0@0000010?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`<0k>c/00<000000?ooo`3oool0;@3oool00`000000k>c/0>c/
k00C0>c/k0030000003IfMT0fMWI00l0fMWI00<000000<K6aP36a/H03P36a/H00`000000/k>c0;>c
/`0>0;>c/`030000002OWil0WinO00l0WinO0P00000G08b<S0030000001iNGT0NGUi04/0NGUi00<0
000008b<S02<S8`05P2<S8`00`000000WinO09nOW`0@09nOW`030000002c/k<0/k>c00h0/k>c00<0
00000<K6aP36a/H03@36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/0140k>c/00<0
00000?ooo`3oool0703oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0`3/k>`0
0`000000oooo0?ooo`0]0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT03P3IfMT0
0`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00h0/k>c00<0000009nOW`2OWil03`2OWil0
0`000000S8b<08b<S00F08b<S0030000001iNGT0NGUi04d0NGUi0P00000G08b<S0030000002OWil0
WinO0100WinO00<000000;>c/`2c/k<03P2c/k<00`000000a/K60<K6aP0=0<K6aP030000003IfMT0
fMWI00d0fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0K0?ooo`4000000@3oool0
01l0oooo00<000000?ooo`3oool01@3oool20>c/k0030000003oool0oooo02d0oooo00<000000>c/
k03/k>`04`3/k>`00`000000fMWI0=WIf@0?0=WIf@0300000036a/H0a/K600h0a/K600<000000;>c
/`2c/k<03@2c/k<00`000000WinO09nOW`0?09nOW`030000002<S8`0S8b<01D0S8b<0P00001B07Ui
N@8000005P2<S8`00`000000WinO09nOW`0?09nOW`030000002c/k<0/k>c00h0/k>c00<000000<K6
aP36a/H03@36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/0140k>c/00<000000?oo
o`3oool06`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P3/k>`00`000000
oooo0?ooo`0]0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000
a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00d0/k>c00<0000009nOW`2OWil03`2OWil00`000000
S8b<08b<S00D08b<S0800000EP1iNGT2000001D0S8b<00<0000009nOW`2OWil03`2OWil00`000000
/k>c0;>c/`0>0;>c/`0300000036a/H0a/K600d0a/K600<000000=WIf@3IfMT03P3IfMT00`000000
k>c/0>c/k00A0>c/k0030000003oool0oooo01X0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`80k>c/00<000000?ooo`3oool0;03oool00`000000k>c/0>c/k00C0>c/k0030000
003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H03P36a/H00`000000/k>c0;>c/`0=0;>c/`030000
002OWil0WinO0100WinO00<0000008b<S02<S8`0502<S8`00`000000NGUi07UiN@1F07UiN@030000
002<S8`0S8b<01@0S8b<00<0000009nOW`2OWil03`2OWil00`000000/k>c0;>c/`0=0;>c/`030000
0036a/H0a/K600d0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00A0>c/k0030000
003oool0oooo01X0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030>c/k000
0000oooo02h0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036
a/H0a/K600h0a/K600<000000;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0?09nOW`030000002<
S8`0S8b<01@0S8b<00<0000007UiN@1iNGT0F01iNGT00`000000S8b<08b<S00D08b<S0030000002O
Wil0WinO00h0WinO00<000000;>c/`2c/k<03P2c/k<00`000000a/K60<K6aP0=0<K6aP030000003I
fMT0fMWI00d0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0J0?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool00`3/k>`000000?ooo`0]0?ooo`030000003/k>`0
k>c/01<0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0
/k>c00d0/k>c00<0000009nOW`2OWil03`2OWil00`000000S8b<08b<S00C08b<S0800000G01iNGT2
000001D0S8b<00<0000009nOW`2OWil03P2OWil00`000000/k>c0;>c/`0=0;>c/`0300000036a/H0
a/K600d0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0
oooo01T0oooo0@0000010?ooo`007`3oool3000000D0oooo00<0k>c/0000003oool0;@3oool00`00
0000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H03@36a/H00`00
0000/k>c0;>c/`0>0;>c/`030000002OWil0WinO00h0WinO00<0000008b<S02<S8`04`2<S8`00`00
0000NGUi07UiN@0V07UiNA000000:01iNGT00`000000S8b<08b<S00C08b<S0030000002OWil0WinO
00h0WinO00<000000;>c/`2c/k<03@2c/k<00`000000a/K60<K6aP0=0<K6aP030000003IfMT0fMWI
00d0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0H0?ooo`8000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool00`3/k>`000000?ooo`0]0?ooo`030000003/k>`0k>c/01<0
k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0<0<K6aP030000002c/k<0/k>c00h0
/k>c00<0000009nOW`2OWil03P2OWil00`000000S8b<08b<S00C08b<S0030000001iNGT0NGUi0240
NGUi1P00000@06IVIPL000008P1iNGT00`000000S8b<08b<S00B08b<S0030000002OWil0WinO00h0
WinO00<000000;>c/`2c/k<03@2c/k<00`000000a/K60<K6aP0=0<K6aP030000003IfMT0fMWI00d0
fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0I0?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`030000003/k>`0k>c/01@0k>c/
00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0=0<K6aP030000002c/k<0/k>c00d0/k>c
00<0000009nOW`2OWil03`2OWil00`000000S8b<08b<S00A08b<S08000008P1iNGT2000001d0IVIV
0`00000P07UiN@8000004`2<S8`00`000000WinO09nOW`0>09nOW`030000002c/k<0/k>c00d0/k>c
00<000000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/0100k>c/
00<000000?ooo`3oool06@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0;03oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00h0fMWI00<0
00000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0>0;>c/`030000002OWil0WinO00h0WinO00<0
000008b<S02<S8`04@2<S8`00`000000NGUi07UiN@0O07UiN@<000008P1VIVH200000200NGUi00<0
000008b<S02<S8`04@2<S8`00`000000WinO09nOW`0=09nOW`030000002c/k<0/k>c00d0/k>c00<0
00000<K6aP36a/H03@36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/0140k>c/00<0
00000?ooo`3oool0603oool100000040oooo000O0?ooo`030000003oool0oooo03@0oooo00<00000
0>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600`0a/K600<00000
0;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0>09nOW`030000002<S8`0S8b<0140S8b<00<00000
07UiN@1iNGT06`1iNGT5000002L0IVIV1000000M07UiN@030000002<S8`0S8b<0140S8b<00<00000
09nOW`2OWil03@2OWil00`000000/k>c0;>c/`0=0;>c/`0300000036a/H0a/K600`0a/K600<00000
0=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01P0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`0d0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WI
f@3IfMT03P3IfMT00`000000a/K60<K6aP0=0<K6aP030000002c/k<0/k>c00`0/k>c00<0000009nO
W`2OWil03P2OWil00`000000S8b<08b<S00A08b<S0030000001iNGT0NGUi01X0NGUi0P00000`06IV
IP800000701iNGT00`000000S8b<08b<S00A08b<S0030000002OWil0WinO00`0WinO00<000000;>c
/`2c/k<03@2c/k<00`000000a/K60<K6aP0<0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/
k03/k>`0403/k>`00`000000oooo0?ooo`0H0?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool0=03oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36
a/H03036a/H00`000000/k>c0;>c/`0=0;>c/`030000002OWil0WinO00h0WinO00<0000008b<S02<
S8`0402<S8`00`000000NGUi07UiN@0I07UiN@800000=01VIVH2000001/0NGUi00<0000008b<S02<
S8`0402<S8`00`000000WinO09nOW`0=09nOW`030000002c/k<0/k>c00d0/k>c00<000000<K6aP36
a/H03036a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3o
ool05`3oool100000040oooo000O0?ooo`030000003oool0oooo03<0oooo00<000000>c/k03/k>`0
4P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600d0a/K600<000000;>c/`2c/k<0
302c/k<00`000000WinO09nOW`0>09nOW`030000002<S8`0S8b<0100S8b<00<0000007UiN@1iNGT0
601iNGT2000003P0IVIV00<0000007UiN@1iNGT06@1iNGT00`000000S8b<08b<S00@08b<S0030000
002OWil0WinO00d0WinO00<000000;>c/`2c/k<0302c/k<00`000000a/K60<K6aP0<0<K6aP030000
003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0G0?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool0<`3oool00`000000k>c/0>c/k00B0>c/k0030000003I
fMT0fMWI00h0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0=0;>c/`030000002O
Wil0WinO00d0WinO00<0000008b<S02<S8`0402<S8`00`000000NGUi07UiN@0G07UiN@800000>`1V
IVH2000001X0NGUi00<0000008b<S02<S8`0402<S8`00`000000WinO09nOW`0=09nOW`030000002c
/k<0/k>c00`0/k>c00<000000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0=0=WIf@030000003/
k>`0k>c/0140k>c/00<000000?ooo`3oool05P3oool100000040oooo000O0?ooo`030000003oool0
oooo0380oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0
a/K600`0a/K600<000000;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0=09nOW`030000002<S8`0
S8b<0100S8b<00<0000007UiN@1iNGT05P1iNGT2000003l0IVIV0P00000I07UiN@030000002<S8`0
S8b<00l0S8b<00<0000009nOW`2OWil03@2OWil00`000000/k>c0;>c/`0<0;>c/`0300000036a/H0
a/K600`0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0
oooo01H0oooo0@0000010?ooo`0000<0oooo0000000000001@0000040?ooo`8000001@3oool60000
00H0oooo00<000000?ooo`3oool0<P3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI
00h0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0=0;>c/`030000002OWil0WinO
00`0WinO00<0000008b<S02<S8`0402<S8`00`000000NGUi07UiN@0F07UiN@030000001VIVH0IVIV
0440IVIV00<0000007UiN@1iNGT05P1iNGT00`000000S8b<08b<S00@08b<S0030000002OWil0WinO
00d0WinO00<000000;>c/`2c/k<0302c/k<00`000000a/K60<K6aP0<0<K6aP030000003IfMT0fMWI
00d0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0F0?ooo`4000000@3oool000@0
oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0340oooo00<000000>c/k03/k>`04P3/k>`00`000000
fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600`0a/K600<000000;>c/`2c/k<03@2c/k<00`000000
WinO09nOW`0=09nOW`030000002<S8`0S8b<00l0S8b<00<0000007UiN@1iNGT05P1iNGT00`000000
IVIV06IVIP1306IVIP8000005`1iNGT00`000000S8b<08b<S00?08b<S0030000002OWil0WinO00d0
WinO00<000000;>c/`2c/k<0302c/k<00`000000a/K60<K6aP0<0<K6aP030000003IfMT0fMWI00d0
fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0E0?ooo`4000000@3oool000@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0340oooo
00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600`0a/K6
00<000000;>c/`2c/k<0302c/k<2000000h0WinO00<0000008b<S02<S8`0402<S8`00`000000NGUi
07UiN@0E07UiN@030000001VIVH0IVIV04H0IVIV00<0000007UiN@1iNGT05@1iNGT00`000000S8b<
08b<S00?08b<S0030000002OWil0WinO00d0WinO00<000000;>c/`2c/k<0302c/k<00`000000a/K6
0<K6aP0<0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo
0?ooo`0E0?ooo`4000000@3oool000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`070?ooo`@00000<03oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI00h0fMWI00<0
00000<K6aP36a/H02`36a/H00`000000/k>c0;>c/`0<0;>c/`030000002OWil0WinO00h0WinO00<0
000008b<S02<S8`03`2<S8`00`000000NGUi07UiN@0E07UiN@030000001VIVH0IVIV04P0IVIV0P00
000F07UiN@030000002<S8`0S8b<00l0S8b<00<0000009nOW`2OWil0302OWil00`000000/k>c0;>c
/`0=0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/
k00@0>c/k0030000003oool0oooo01<0oooo0`0000010?ooo`00103oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<03oool00`000000k>c/0>c/k00B
0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0<
0;>c/`030000002OWil0WinO00d0WinO00<0000008b<S02<S8`03P2<S8`2000001H0NGUi0P00001=
06IVIP8000005@1iNGT00`000000S8b<08b<S00?08b<S0030000002OWil0WinO00`0WinO00<00000
0;>c/`2c/k<0302c/k<00`000000a/K60<K6aP0<0<K6aP030000003IfMT0fMWI00d0fMWI00<00000
0>c/k03/k>`0403/k>`00`000000oooo0?ooo`0D0?ooo`4000000@3oool000@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo00<000000>c/
k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c
/`2c/k<0302c/k<00`000000WinO09nOW`0>09nOW`030000002<S8`0S8b<00d0S8b<00<0000007Ui
N@1iNGT05@1iNGT00`000000IVIV06IVIP1?06IVIP030000001iNGT0NGUi01<0NGUi00<0000008b<
S02<S8`03P2<S8`00`000000WinO09nOW`0<09nOW`030000002c/k<0/k>c00d0/k>c00<000000<K6
aP36a/H02`36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/0100k>c/00<000000?oo
o`3oool0503oool100000040oooo00040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0300oooo00<000000>c/k03/
k>`04P3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600`0a/K600<000000;>c/`2c
/k<0302c/k<00`000000WinO09nOW`0=09nOW`030000002<S8`0S8b<00h0S8b<00<0000007UiN@1i
NGT04`1iNGT2000005<0IVIV00<0000007UiN@1iNGT04`1iNGT00`000000S8b<08b<S00>08b<S003
0000002OWil0WinO00`0WinO00<000000;>c/`2c/k<0302c/k<00`000000a/K60<K6aP0<0<K6aP03
0000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0D0?ooo`40
00000@3oool00080oooo0`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0_0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT0
3P3IfMT00`000000a/K60<K6aP0;0<K6aP030000002c/k<0/k>c00d0/k>c00<0000009nOW`2OWil0
302OWil00`000000S8b<08b<S00>08b<S0030000001iNGT0NGUi01<0NGUi00<0000006IVIP1VIVH0
E01VIVH2000001@0NGUi00<0000008b<S02<S8`03P2<S8`00`000000WinO09nOW`0<09nOW`030000
002c/k<0/k>c00/0/k>c00<000000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0<0=WIf@030000
003/k>`0k>c/0100k>c/00<000000?ooo`3oool0503oool100000040oooo00040?ooo`030000003o
ool0oooo00d0oooo100000070?ooo`030000003oool0oooo02l0oooo00<000000>c/k03/k>`04P3/
k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600`0a/K600<000000;>c/`2c/k<0302c
/k<00`000000WinO09nOW`0<09nOW`030000002<S8`0S8b<00h0S8b<00<0000007UiN@1iNGT04`1i
NGT00`000000IVIV06IVIP1G06IVIP030000001iNGT0NGUi0140NGUi00<0000008b<S02<S8`03`2<
S8`00`000000WinO09nOW`0;09nOW`030000002c/k<0/k>c00`0/k>c00<000000<K6aP36a/H02`36
a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool04`3o
ool100000040oooo000O0?ooo`030000003oool0oooo02h0oooo00<000000>c/k03/k>`04P3/k>`0
0`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c/k<03@2c/k<0
0`000000WinO09nOW`0;09nOW`030000002<S8`0S8b<00l0S8b<00<0000007UiN@1iNGT04@1iNGT2
000002T0IVIV1`00000[06IVIP030000001iNGT0NGUi0140NGUi00<0000008b<S02<S8`03P2<S8`0
0`000000WinO09nOW`0<09nOW`030000002c/k<0/k>c00/0/k>c00<000000<K6aP36a/H03036a/H0
0`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool04`3oool1
00000040oooo000O0?ooo`030000003oool0oooo02h0oooo00<000000>c/k03/k>`04P3/k>`00`00
0000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c/k<0302c/k<00`00
0000WinO09nOW`0<09nOW`030000002<S8`0S8b<00h0S8b<00<0000007UiN@1iNGT04@1iNGT00`00
0000IVIV06IVIP0R06IVIPL000001`1CDe<8000002@0IVIV0P00000B07UiN@030000002<S8`0S8b<
00h0S8b<00<0000009nOW`2OWil0302OWil00`000000/k>c0;>c/`0;0;>c/`0300000036a/H0a/K6
00/0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo
0180oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0^0?ooo`030000003/k>`0k>c/0180
k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0<0<K6aP030000002c/k<0/k>c00/0
/k>c00<0000009nOW`2OWil0302OWil00`000000S8b<08b<S00>08b<S0030000001iNGT0NGUi0140
NGUi00<0000006IVIP1VIVH07`1VIVH4000001H0De=C1000000R06IVIP030000001iNGT0NGUi0100
NGUi00<0000008b<S02<S8`03P2<S8`00`000000WinO09nOW`0<09nOW`030000002c/k<0/k>c00/0
/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/0100
k>c/00<000000?ooo`3oool04P3oool100000040oooo000O0?ooo`030000003oool0oooo02d0oooo
00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600/0a/K6
00<000000;>c/`2c/k<0302c/k<00`000000WinO09nOW`0<09nOW`030000002<S8`0S8b<00d0S8b<
00<0000007UiN@1iNGT0401iNGT2000001h0IVIV1000000N05=CD`@000007`1VIVH00`000000NGUi
07UiN@0@07UiN@030000002<S8`0S8b<00d0S8b<00<0000009nOW`2OWil0302OWil00`000000/k>c
0;>c/`0;0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/
0>c/k00@0>c/k0030000003oool0oooo0140oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`0]0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6
aP0<0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil0302OWil00`000000S8b<08b<
S00=08b<S0030000001iNGT0NGUi0100NGUi00<0000006IVIP1VIVH06`1VIVH3000002H0De=C0`00
000M06IVIP030000001iNGT0NGUi0100NGUi00<0000008b<S02<S8`03@2<S8`00`000000WinO09nO
W`0<09nOW`030000002c/k<0/k>c00/0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WI
f@0<0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool04@3oool100000040oooo000O
0?ooo`030000003oool0oooo02d0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0=
0=WIf@0300000036a/H0a/K600`0a/K600<000000;>c/`2c/k<02`2c/k<00`000000WinO09nOW`0<
09nOW`030000002<S8`0S8b<00d0S8b<00<0000007UiN@1iNGT0401iNGT00`000000IVIV06IVIP0J
06IVIP800000;01CDe<2000001`0IVIV00<0000007UiN@1iNGT0401iNGT00`000000S8b<08b<S00=
08b<S0030000002OWil0WinO00/0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP0;
0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0A
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0;03oool00`000000k>c/0>c/k00B0>c/
k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0;0;>c
/`030000002OWil0WinO00/0WinO00<0000008b<S02<S8`03P2<S8`00`000000NGUi07UiN@0?07Ui
N@030000001VIVH0IVIV01T0IVIV0P00000`05=CD`8000006`1VIVH00`000000NGUi07UiN@0@07Ui
N@030000002<S8`0S8b<00d0S8b<00<0000009nOW`2OWil02`2OWil00`000000/k>c0;>c/`0;0;>c
/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00@0>c/
k0030000003oool0oooo0100oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0<0<K6aP03
0000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil0302OWil00`000000S8b<08b<S00=08b<S003
0000001iNGT0NGUi00l0NGUi00<0000006IVIP1VIVH0601VIVH2000003@0De=C0P00000J06IVIP03
0000001iNGT0NGUi00l0NGUi00<0000008b<S02<S8`03@2<S8`00`000000WinO09nOW`0;09nOW`03
0000002c/k<0/k>c00/0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0=0=WIf@03
0000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0403oool100000040oooo000O0?ooo`<00000
;03oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H0
3036a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO00/0WinO00<0000008b<S02<S8`0
3@2<S8`00`000000NGUi07UiN@0?07UiN@030000001VIVH0IVIV01H0IVIV0`00000h05=CD`<00000
601VIVH00`000000NGUi07UiN@0?07UiN@030000002<S8`0S8b<00d0S8b<00<0000009nOW`2OWil0
2`2OWil00`000000/k>c0;>c/`0;0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT0
303IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo00l0oooo0P0000010?ooo`007`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03@3I
fMT00`000000a/K60<K6aP0;0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil02`2O
Wil00`000000S8b<08b<S00=08b<S0030000001iNGT0NGUi00l0NGUi00<0000006IVIP1VIVH05@1V
IVH2000003h0De=C00<0000006IVIP1VIVH05P1VIVH00`000000NGUi07UiN@0?07UiN@030000002<
S8`0S8b<00`0S8b<00<0000009nOW`2OWil02`2OWil00`000000/k>c0;>c/`0;0;>c/`0300000036
a/H0a/K600/0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00?0>c/k0030000003o
ool0oooo0100oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0[0?ooo`030000003/k>`0
k>c/0140k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0<0<K6aP030000002c/k<0
/k>c00/0/k>c00<0000009nOW`2OWil02`2OWil00`000000S8b<08b<S00=08b<S0030000001iNGT0
NGUi00h0NGUi00<0000006IVIP1VIVH05@1VIVH00`000000De=C05=CD`0o05=CD`030000001VIVH0
IVIV01H0IVIV00<0000007UiN@1iNGT03P1iNGT00`000000S8b<08b<S00=08b<S0030000002OWil0
WinO00/0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP0:0<K6aP030000003IfMT0
fMWI00`0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0?0?ooo`4000000@3oool0
01l0oooo00<000000?ooo`3oool0:P3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI
00d0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO
00/0WinO00<0000008b<S02<S8`03@2<S8`00`000000NGUi07UiN@0>07UiN@030000001VIVH0IVIV
01@0IVIV0P00001305=CD`8000005`1VIVH00`000000NGUi07UiN@0>07UiN@030000002<S8`0S8b<
00`0S8b<00<0000009nOW`2OWil02`2OWil00`000000/k>c0;>c/`0;0;>c/`0300000036a/H0a/K6
00/0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo
00l0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0Z0?ooo`030000003/k>`0k>c/0180
k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0;0<K6aP030000002c/k<0/k>c00/0
/k>c00<0000009nOW`2OWil02`2OWil00`000000S8b<08b<S00<08b<S0030000001iNGT0NGUi00h0
NGUi00<0000006IVIP1VIVH0501VIVH00`000000De=C05=CD`1505=CD`8000005P1VIVH00`000000
NGUi07UiN@0>07UiN@030000002<S8`0S8b<00`0S8b<00<0000009nOW`2OWil02`2OWil00`000000
/k>c0;>c/`0;0;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3IfMT0303IfMT00`000000
k>c/0>c/k00@0>c/k0030000003oool0oooo00h0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K6
0<K6aP0;0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil02`2OWil00`000000S8b<
08b<S00<08b<S0030000001iNGT0NGUi00h0NGUi00<0000006IVIP1VIVH0501VIVH00`000000De=C
05=CD`1805=CD`030000001VIVH0IVIV01<0IVIV00<0000007UiN@1iNGT03`1iNGT00`000000S8b<
08b<S00;08b<S0030000002OWil0WinO00/0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K6
0<K6aP0:0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo
0?ooo`0>0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0:@3oool00`000000k>c/0>c/
k00B0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c0;>c
/`0;0;>c/`030000002OWil0WinO00X0WinO00<0000008b<S02<S8`0302<S8`00`000000NGUi07Ui
N@0>07UiN@030000001VIVH0IVIV01<0IVIV0P00001<05=CD`800000501VIVH00`000000NGUi07Ui
N@0>07UiN@030000002<S8`0S8b<00`0S8b<00<0000009nOW`2OWil02`2OWil00`000000/k>c0;>c
/`0:0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/
k00?0>c/k0030000003oool0oooo00h0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0;
0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil02`2OWil00`000000S8b<08b<S008
08b<S080o`000P2<S8`00`000000NGUi07UiN@0=07UiN@030000001VIVH0IVIV01<0IVIV00<00000
05=CD`1CDe<0CP1CDe<00`000000IVIV06IVIP0B06IVIP8000003`1iNGT00`000000S8b<08b<S00;
08b<S0030000002OWil0WinO00/0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP0:
0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0=
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0:@3oool00`000000k>c/0>c/k00A0>c/
k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c0;>c/`0;0;>c
/`030000002OWil0WinO00X0WinO00<0000008b<S02<S8`01P2<S8`80?l000h0NGUi00<0000006IV
IP1VIVH04P1VIVH200000580De=C0P00000D06IVIP030000001iNGT0NGUi00d0NGUi00<0000008b<
S02<S8`02`2<S8`00`000000WinO09nOW`0;09nOW`030000002c/k<0/k>c00X0/k>c00<000000<K6
aP36a/H02`36a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/00l0k>c/00<000000?oo
o`3oool03@3oool100000040oooo000O0?ooo`030000003oool0oooo02T0oooo00<000000>c/k03/
k>`04@3/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c
/k<02`2c/k<00`000000WinO09nOW`0:09nOW`030000002<S8`0S8b<00H0S8b<0`3o0003003o00@0
o`00301iNGT00`000000IVIV06IVIP0B06IVIP030000001CDe<0De=C05@0De=C00<0000006IVIP1V
IVH04@1VIVH00`000000NGUi07UiN@0>07UiN@030000002<S8`0S8b<00/0S8b<00<0000009nOW`2O
Wil02P2OWil00`000000/k>c0;>c/`0:0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3I
fMT0303IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo00d0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`0X0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT0
3@3IfMT00`000000a/K60<K6aP0;0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil0
2P2OWil00`000000S8b<08b<S00608b<S080o`001@00o`030?l000/0NGUi00<0000006IVIP1VIVH0
4P1VIVH00`000000De=C05=CD`1F05=CD`030000001VIVH0IVIV0140IVIV00<0000007UiN@1iNGT0
3@1iNGT00`000000S8b<08b<S00<08b<S0030000002OWil0WinO00X0WinO00<000000;>c/`2c/k<0
2P2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`0
403/k>`00`000000oooo0?ooo`0<0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0:03o
ool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02`36
a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO00X0WinO00<0000008b<S02<S8`01`2<
S8`00`3o00000?l0003o0005003o0080o`002`1iNGT00`000000IVIV06IVIP0@06IVIP8000008P1C
De<F00000280De=C0P00000B06IVIP030000001iNGT0NGUi00d0NGUi00<0000008b<S02<S8`02`2<
S8`00`000000WinO09nOW`0:09nOW`030000002c/k<0/k>c00X0/k>c00<000000<K6aP36a/H02`36
a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0303o
ool100000040oooo000O0?ooo`030000003oool0oooo02P0oooo00<000000>c/k03/k>`04@3/k>`0
0`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c/k<02`2c/k<0
0`000000WinO09nOW`0:09nOW`030000002<S8`0S8b<00H0S8b<0P3o0007003o00<0o`002@1iNGT0
0`000000IVIV06IVIP0@06IVIP030000001CDe<0De=C0200De=C0P00000F03lo?`8000008P1CDe<0
0`000000IVIV06IVIP0@06IVIP030000001iNGT0NGUi00d0NGUi00<0000008b<S02<S8`02`2<S8`0
0`000000WinO09nOW`0:09nOW`030000002c/k<0/k>c00X0/k>c00<000000<K6aP36a/H02`36a/H0
0`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0303oool1
00000040oooo000O0?ooo`<00000O@3oool20?l000L00?l00`3o003o0?ooo`<0oooo0P0000010?oo
o`007`3oool00`000000oooo0?ooo`1n0?ooo`80o`001@00o`030?l00?l0oooo1@3oool100000040
oooo000O0?ooo`030000003oool0oooo07h0oooo0`3o0003003o00@0o`00o`3oool50?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool0OP3oool:0?l00?l0oooo1@3oool100000040oooo000O
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0E03oool80?l004h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3o000<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`060?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`007`3ooooo000009400000
0@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.42864, -0.256895, 0.00864808, \
0.00558979}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({3.009122763698238`*^-21, {X\_1 \[Rule] 1.0000000000278046`, 
            X\_2 \[Rule] 1.0000000000508806`}}\), 
        ",", \({"Steps" \[Rule] 42, "Function" \[Rule] 51, 
          "Gradient" \[Rule] 51}\), ",", 
        TagBox[\(\[SkeletonIndicator]  
            ContourGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell[TextData[{
  "By default ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses symbolically computed derivatives when they can be computed.  \
Usually this allows for a more accurate solution."
}], "Text"],

Cell["\<\
This shows the steps and evaluations used by the BFGS quasi-Newton \
method with derivatives approximated with finite differences.\
\>", \
"MathCaption"],

Cell[BoxData[
    \(the\ BFGS\ quasi - Newton\ \(\(method\)\(.\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p4\  = \ 
      FindMinimumPlot[\((1 - X\_1)\)\^2 + 
          100\ \((\(-X\_1\%2\) + X\_2)\)\^2, {{X\_1, \(-1.2`\)}, {X\_2, 
            1.`}}, \ Method \[Rule] QuasiNewton, \ 
        Gradient -> "\<FiniteDifference\>"]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    RowBox[{\(FindMinimum::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the function.  \
You may need more than \\!\\(MachinePrecision\\) digits of working precision \
to meet these tolerances. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FindMinimum::lstol\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[54]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.541189 0.434965 0.109337 0.672845 [
[.10622 -0.0125 -6 -9 ]
[.10622 -0.0125 6 0 ]
[.32371 -0.0125 -12 -9 ]
[.32371 -0.0125 12 0 ]
[.54119 -0.0125 -3 -9 ]
[.54119 -0.0125 3 0 ]
[.75867 -0.0125 -9 -9 ]
[.75867 -0.0125 9 0 ]
[.97615 -0.0125 -3 -9 ]
[.97615 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10934 -6 -4.5 ]
[-0.0125 .10934 0 4.5 ]
[-0.0125 .24391 -18 -4.5 ]
[-0.0125 .24391 0 4.5 ]
[-0.0125 .37847 -18 -4.5 ]
[-0.0125 .37847 0 4.5 ]
[-0.0125 .51304 -18 -4.5 ]
[-0.0125 .51304 0 4.5 ]
[-0.0125 .64761 -18 -4.5 ]
[-0.0125 .64761 0 4.5 ]
[-0.0125 .78218 -6 -4.5 ]
[-0.0125 .78218 0 4.5 ]
[-0.0125 .91675 -18 -4.5 ]
[-0.0125 .91675 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10622 0 m
.10622 .00625 L
s
[(-1)] .10622 -0.0125 0 1 Mshowa
.32371 0 m
.32371 .00625 L
s
[(-0.5)] .32371 -0.0125 0 1 Mshowa
.54119 0 m
.54119 .00625 L
s
[(0)] .54119 -0.0125 0 1 Mshowa
.75867 0 m
.75867 .00625 L
s
[(0.5)] .75867 -0.0125 0 1 Mshowa
.97615 0 m
.97615 .00625 L
s
[(1)] .97615 -0.0125 0 1 Mshowa
.125 Mabswid
.14972 0 m
.14972 .00375 L
s
.19322 0 m
.19322 .00375 L
s
.23671 0 m
.23671 .00375 L
s
.28021 0 m
.28021 .00375 L
s
.3672 0 m
.3672 .00375 L
s
.4107 0 m
.4107 .00375 L
s
.4542 0 m
.4542 .00375 L
s
.49769 0 m
.49769 .00375 L
s
.58469 0 m
.58469 .00375 L
s
.62818 0 m
.62818 .00375 L
s
.67168 0 m
.67168 .00375 L
s
.71518 0 m
.71518 .00375 L
s
.80217 0 m
.80217 .00375 L
s
.84567 0 m
.84567 .00375 L
s
.88916 0 m
.88916 .00375 L
s
.93266 0 m
.93266 .00375 L
s
.06273 0 m
.06273 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10934 m
.00625 .10934 L
s
[(0)] -0.0125 .10934 1 0 Mshowa
0 .24391 m
.00625 .24391 L
s
[(0.2)] -0.0125 .24391 1 0 Mshowa
0 .37847 m
.00625 .37847 L
s
[(0.4)] -0.0125 .37847 1 0 Mshowa
0 .51304 m
.00625 .51304 L
s
[(0.6)] -0.0125 .51304 1 0 Mshowa
0 .64761 m
.00625 .64761 L
s
[(0.8)] -0.0125 .64761 1 0 Mshowa
0 .78218 m
.00625 .78218 L
s
[(1)] -0.0125 .78218 1 0 Mshowa
0 .91675 m
.00625 .91675 L
s
[(1.2)] -0.0125 .91675 1 0 Mshowa
.125 Mabswid
0 .14298 m
.00375 .14298 L
s
0 .17662 m
.00375 .17662 L
s
0 .21026 m
.00375 .21026 L
s
0 .27755 m
.00375 .27755 L
s
0 .31119 m
.00375 .31119 L
s
0 .34483 m
.00375 .34483 L
s
0 .41212 m
.00375 .41212 L
s
0 .44576 m
.00375 .44576 L
s
0 .4794 m
.00375 .4794 L
s
0 .54669 m
.00375 .54669 L
s
0 .58033 m
.00375 .58033 L
s
0 .61397 m
.00375 .61397 L
s
0 .68125 m
.00375 .68125 L
s
0 .7149 m
.00375 .7149 L
s
0 .74854 m
.00375 .74854 L
s
0 .81582 m
.00375 .81582 L
s
0 .84947 m
.00375 .84947 L
s
0 .88311 m
.00375 .88311 L
s
0 .07569 m
.00375 .07569 L
s
0 .04205 m
.00375 .04205 L
s
0 .00841 m
.00375 .00841 L
s
0 .95039 m
.00375 .95039 L
s
0 .98403 m
.00375 .98403 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10622 .99375 m
.10622 1 L
s
.32371 .99375 m
.32371 1 L
s
.54119 .99375 m
.54119 1 L
s
.75867 .99375 m
.75867 1 L
s
.97615 .99375 m
.97615 1 L
s
.125 Mabswid
.14972 .99625 m
.14972 1 L
s
.19322 .99625 m
.19322 1 L
s
.23671 .99625 m
.23671 1 L
s
.28021 .99625 m
.28021 1 L
s
.3672 .99625 m
.3672 1 L
s
.4107 .99625 m
.4107 1 L
s
.4542 .99625 m
.4542 1 L
s
.49769 .99625 m
.49769 1 L
s
.58469 .99625 m
.58469 1 L
s
.62818 .99625 m
.62818 1 L
s
.67168 .99625 m
.67168 1 L
s
.71518 .99625 m
.71518 1 L
s
.80217 .99625 m
.80217 1 L
s
.84567 .99625 m
.84567 1 L
s
.88916 .99625 m
.88916 1 L
s
.93266 .99625 m
.93266 1 L
s
.06273 .99625 m
.06273 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .10934 m
1 .10934 L
s
.99375 .24391 m
1 .24391 L
s
.99375 .37847 m
1 .37847 L
s
.99375 .51304 m
1 .51304 L
s
.99375 .64761 m
1 .64761 L
s
.99375 .78218 m
1 .78218 L
s
.99375 .91675 m
1 .91675 L
s
.125 Mabswid
.99625 .14298 m
1 .14298 L
s
.99625 .17662 m
1 .17662 L
s
.99625 .21026 m
1 .21026 L
s
.99625 .27755 m
1 .27755 L
s
.99625 .31119 m
1 .31119 L
s
.99625 .34483 m
1 .34483 L
s
.99625 .41212 m
1 .41212 L
s
.99625 .44576 m
1 .44576 L
s
.99625 .4794 m
1 .4794 L
s
.99625 .54669 m
1 .54669 L
s
.99625 .58033 m
1 .58033 L
s
.99625 .61397 m
1 .61397 L
s
.99625 .68125 m
1 .68125 L
s
.99625 .7149 m
1 .7149 L
s
.99625 .74854 m
1 .74854 L
s
.99625 .81582 m
1 .81582 L
s
.99625 .84947 m
1 .84947 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .07569 m
1 .07569 L
s
.99625 .04205 m
1 .04205 L
s
.99625 .00841 m
1 .00841 L
s
.99625 .95039 m
1 .95039 L
s
.99625 .98403 m
1 .98403 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.925 g
.01923 .88972 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85282 L
.03106 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81662 L
.03891 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74629 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71215 L
.06874 .70882 L
.07154 .69911 L
.07437 .68939 L
.07722 .67968 L
.07751 .6787 L
.08006 .66997 L
.08294 .66026 L
.08584 .65054 L
.08722 .64595 L
.08874 .64083 L
.09167 .63112 L
.09462 .62141 L
.09693 .61388 L
.0976 .61169 L
.10057 .60198 L
.10359 .59227 L
.10662 .58256 L
.10664 .5825 L
.10966 .57284 L
.11273 .56313 L
.11584 .55342 L
.11636 .5518 L
.11894 .54371 L
.12208 .53399 L
.12525 .52428 L
.12607 .52179 L
.12843 .51457 L
.13164 .50486 L
.13488 .49514 L
.13578 .49247 L
.13814 .48543 L
.14143 .47572 L
.14475 .46601 L
.14549 .46384 L
.14809 .45629 L
.15146 .44658 L
.15486 .43687 L
.15521 .43589 L
.15828 .42716 L
.16175 .41744 L
.16492 .40863 L
.16524 .40773 L
.16876 .39802 L
.17232 .38831 L
.17463 .38206 L
.17591 .37859 L
.17954 .36888 L
.1832 .35917 L
.18434 .35617 L
.1869 .34946 L
.19064 .33974 L
.19406 .33097 L
.19442 .33003 L
.19824 .32032 L
.2021 .31061 L
.20377 .30645 L
.20601 .30089 L
.20996 .29118 L
.21348 .28262 L
.21396 .28147 L
.218 .27176 L
.2221 .26204 L
.22319 .25948 L
.22625 .25233 L
.23045 .24262 L
.23291 .23702 L
.23471 .23291 L
.23903 .22319 L
.24262 .21524 L
.24342 .21348 L
.24786 .20377 L
.25233 .19415 L
.25237 .19406 L
.25695 .18434 L
.26161 .17463 L
.26204 .17374 L
.26634 .16492 L
.27116 .15521 L
.27176 .15402 L
.27606 .14549 L
.28105 .13578 L
.28147 .13498 L
.28614 .12607 L
.29118 .11663 L
.29133 .11636 L
.29662 .10664 L
.30089 .09896 L
.30203 .09693 L
.30756 .08722 L
.31061 .08197 L
.31323 .07751 L
.31903 .06779 L
.32032 .06567 L
.32498 .05808 L
.33003 .05005 L
.3311 .04837 L
.3374 .03866 L
.33974 .03512 L
.34389 .02894 L
.34946 .02087 L
.3506 .01923 L
.01923 .01923 L
F
0 g
.01923 .88972 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85282 L
.03106 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81662 L
.03891 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74629 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71215 L
.06874 .70882 L
.07154 .69911 L
.07437 .68939 L
.07722 .67968 L
.07751 .6787 L
.08006 .66997 L
.08294 .66026 L
.08584 .65054 L
.08722 .64595 L
.08874 .64083 L
.09167 .63112 L
.09462 .62141 L
.09693 .61388 L
.0976 .61169 L
.10057 .60198 L
.10359 .59227 L
.10662 .58256 L
.10664 .5825 L
.10966 .57284 L
.11273 .56313 L
.11584 .55342 L
.11636 .5518 L
.11894 .54371 L
.12208 .53399 L
.12525 .52428 L
.12607 .52179 L
Mistroke
.12843 .51457 L
.13164 .50486 L
.13488 .49514 L
.13578 .49247 L
.13814 .48543 L
.14143 .47572 L
.14475 .46601 L
.14549 .46384 L
.14809 .45629 L
.15146 .44658 L
.15486 .43687 L
.15521 .43589 L
.15828 .42716 L
.16175 .41744 L
.16492 .40863 L
.16524 .40773 L
.16876 .39802 L
.17232 .38831 L
.17463 .38206 L
.17591 .37859 L
.17954 .36888 L
.1832 .35917 L
.18434 .35617 L
.1869 .34946 L
.19064 .33974 L
.19406 .33097 L
.19442 .33003 L
.19824 .32032 L
.2021 .31061 L
.20377 .30645 L
.20601 .30089 L
.20996 .29118 L
.21348 .28262 L
.21396 .28147 L
.218 .27176 L
.2221 .26204 L
.22319 .25948 L
.22625 .25233 L
.23045 .24262 L
.23291 .23702 L
.23471 .23291 L
.23903 .22319 L
.24262 .21524 L
.24342 .21348 L
.24786 .20377 L
.25233 .19415 L
.25237 .19406 L
.25695 .18434 L
.26161 .17463 L
.26204 .17374 L
Mistroke
.26634 .16492 L
.27116 .15521 L
.27176 .15402 L
.27606 .14549 L
.28105 .13578 L
.28147 .13498 L
.28614 .12607 L
.29118 .11663 L
.29133 .11636 L
.29662 .10664 L
.30089 .09896 L
.30203 .09693 L
.30756 .08722 L
.31061 .08197 L
.31323 .07751 L
.31903 .06779 L
.32032 .06567 L
.32498 .05808 L
.33003 .05005 L
.3311 .04837 L
.3374 .03866 L
.33974 .03512 L
.34389 .02894 L
.34946 .02087 L
.3506 .01923 L
Mfstroke
.85 g
.01923 .74152 m
.02018 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70515 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66944 L
.04118 .66026 L
.04387 .65054 L
.04657 .64083 L
.04837 .63442 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56642 L
.06875 .56313 L
.07159 .55342 L
.07446 .54371 L
.07734 .53399 L
.07751 .53343 L
.08023 .52428 L
.08315 .51457 L
.08609 .50486 L
.08722 .50113 L
.08904 .49514 L
.09201 .48543 L
.095 .47572 L
.09693 .4695 L
.09801 .46601 L
.10105 .45629 L
.1041 .44658 L
.10664 .43855 L
.10718 .43687 L
.11027 .42716 L
.11339 .41744 L
.11636 .40828 L
.11653 .40773 L
.1197 .39802 L
.12288 .38831 L
.12607 .37869 L
.1261 .37859 L
.12933 .36888 L
.1326 .35917 L
.13578 .34977 L
.13589 .34946 L
.1392 .33974 L
.14255 .33003 L
.14549 .32154 L
.14592 .32032 L
.14932 .31061 L
.15275 .30089 L
.15521 .29398 L
.15621 .29118 L
.1597 .28147 L
.16322 .27176 L
.16492 .2671 L
.16677 .26204 L
.17036 .25233 L
.17399 .24262 L
.17463 .2409 L
.17765 .23291 L
.18134 .22319 L
.18434 .21538 L
.18508 .21348 L
.18885 .20377 L
.19266 .19406 L
.19406 .19054 L
.19652 .18434 L
.20042 .17463 L
.20377 .16637 L
.20436 .16492 L
.20835 .15521 L
.21239 .14549 L
.21348 .14289 L
.21648 .13578 L
.22061 .12607 L
.22319 .12008 L
.22481 .11636 L
.22905 .10664 L
.23291 .09795 L
.23336 .09693 L
.23772 .08722 L
.24215 .07751 L
.24262 .0765 L
.24665 .06779 L
.25121 .05808 L
.25233 .05572 L
.25585 .04837 L
.26056 .03866 L
.26204 .03563 L
.26535 .02894 L
.27022 .01923 L
.01923 .01923 L
F
0 g
.01923 .74152 m
.02018 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70515 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66944 L
.04118 .66026 L
.04387 .65054 L
.04657 .64083 L
.04837 .63442 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56642 L
.06875 .56313 L
.07159 .55342 L
.07446 .54371 L
.07734 .53399 L
.07751 .53343 L
.08023 .52428 L
.08315 .51457 L
.08609 .50486 L
.08722 .50113 L
.08904 .49514 L
.09201 .48543 L
.095 .47572 L
.09693 .4695 L
.09801 .46601 L
.10105 .45629 L
.1041 .44658 L
.10664 .43855 L
.10718 .43687 L
.11027 .42716 L
.11339 .41744 L
.11636 .40828 L
.11653 .40773 L
.1197 .39802 L
.12288 .38831 L
.12607 .37869 L
.1261 .37859 L
Mistroke
.12933 .36888 L
.1326 .35917 L
.13578 .34977 L
.13589 .34946 L
.1392 .33974 L
.14255 .33003 L
.14549 .32154 L
.14592 .32032 L
.14932 .31061 L
.15275 .30089 L
.15521 .29398 L
.15621 .29118 L
.1597 .28147 L
.16322 .27176 L
.16492 .2671 L
.16677 .26204 L
.17036 .25233 L
.17399 .24262 L
.17463 .2409 L
.17765 .23291 L
.18134 .22319 L
.18434 .21538 L
.18508 .21348 L
.18885 .20377 L
.19266 .19406 L
.19406 .19054 L
.19652 .18434 L
.20042 .17463 L
.20377 .16637 L
.20436 .16492 L
.20835 .15521 L
.21239 .14549 L
.21348 .14289 L
.21648 .13578 L
.22061 .12607 L
.22319 .12008 L
.22481 .11636 L
.22905 .10664 L
.23291 .09795 L
.23336 .09693 L
.23772 .08722 L
.24215 .07751 L
.24262 .0765 L
.24665 .06779 L
.25121 .05808 L
.25233 .05572 L
.25585 .04837 L
.26056 .03866 L
.26204 .03563 L
.26535 .02894 L
Mistroke
.27022 .01923 L
Mfstroke
.775 g
.01923 .64096 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02706 .61169 L
.02894 .60473 L
.02969 .60198 L
.03232 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56918 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46659 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43374 L
.07948 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40157 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37008 L
.0973 .36888 L
.10034 .35917 L
.10341 .34946 L
.10649 .33974 L
.10664 .33926 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .30913 L
.11905 .30089 L
.12224 .29118 L
.12547 .28147 L
.12607 .27966 L
.12871 .27176 L
.13199 .26204 L
.13528 .25233 L
.13578 .25088 L
.13861 .24262 L
.14196 .23291 L
.14534 .22319 L
.14549 .22277 L
.14875 .21348 L
.15219 .20377 L
.15521 .19534 L
.15566 .19406 L
.15917 .18434 L
.1627 .17463 L
.16492 .16858 L
.16627 .16492 L
.16987 .15521 L
.1735 .14549 L
.17463 .1425 L
.17717 .13578 L
.18088 .12607 L
.18434 .1171 L
.18463 .11636 L
.18842 .10664 L
.19224 .09693 L
.19406 .09237 L
.19611 .08722 L
.20003 .07751 L
.20377 .06832 L
.20398 .06779 L
.20799 .05808 L
.21204 .04837 L
.21348 .04494 L
.21614 .03866 L
.2203 .02894 L
.22319 .02225 L
.22451 .01923 L
.01923 .01923 L
F
0 g
.01923 .64096 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02706 .61169 L
.02894 .60473 L
.02969 .60198 L
.03232 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56918 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46659 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43374 L
.07948 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40157 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37008 L
.0973 .36888 L
.10034 .35917 L
.10341 .34946 L
.10649 .33974 L
.10664 .33926 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .30913 L
.11905 .30089 L
.12224 .29118 L
.12547 .28147 L
.12607 .27966 L
Mistroke
.12871 .27176 L
.13199 .26204 L
.13528 .25233 L
.13578 .25088 L
.13861 .24262 L
.14196 .23291 L
.14534 .22319 L
.14549 .22277 L
.14875 .21348 L
.15219 .20377 L
.15521 .19534 L
.15566 .19406 L
.15917 .18434 L
.1627 .17463 L
.16492 .16858 L
.16627 .16492 L
.16987 .15521 L
.1735 .14549 L
.17463 .1425 L
.17717 .13578 L
.18088 .12607 L
.18434 .1171 L
.18463 .11636 L
.18842 .10664 L
.19224 .09693 L
.19406 .09237 L
.19611 .08722 L
.20003 .07751 L
.20377 .06832 L
.20398 .06779 L
.20799 .05808 L
.21204 .04837 L
.21348 .04494 L
.21614 .03866 L
.2203 .02894 L
.22319 .02225 L
.22451 .01923 L
Mfstroke
.7 g
.01923 .55954 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.0287 .52428 L
.02894 .52339 L
.03134 .51457 L
.03399 .50486 L
.03666 .49514 L
.03866 .48792 L
.03934 .48543 L
.04204 .47572 L
.04475 .46601 L
.04747 .45629 L
.04837 .45312 L
.05021 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08143 .33974 L
.08437 .33003 L
.08722 .32069 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28927 L
.09937 .28147 L
.10244 .27176 L
.10552 .26204 L
.10664 .25852 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22845 L
.11808 .22319 L
.12127 .21348 L
.1245 .20377 L
.12607 .19906 L
.12774 .19406 L
.13102 .18434 L
.13432 .17463 L
.13578 .17034 L
.13764 .16492 L
.14099 .15521 L
.14438 .14549 L
.14549 .1423 L
.14779 .13578 L
.15122 .12607 L
.1547 .11636 L
.15521 .11493 L
.1582 .10664 L
.16173 .09693 L
.16492 .08824 L
.1653 .08722 L
.1689 .07751 L
.17253 .06779 L
.17463 .06223 L
.1762 .05808 L
.17991 .04837 L
.18366 .03866 L
.18434 .03689 L
.18744 .02894 L
.19127 .01923 L
.01923 .01923 L
F
0 g
.01923 .55954 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.0287 .52428 L
.02894 .52339 L
.03134 .51457 L
.03399 .50486 L
.03666 .49514 L
.03866 .48792 L
.03934 .48543 L
.04204 .47572 L
.04475 .46601 L
.04747 .45629 L
.04837 .45312 L
.05021 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08143 .33974 L
.08437 .33003 L
.08722 .32069 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28927 L
.09937 .28147 L
.10244 .27176 L
.10552 .26204 L
.10664 .25852 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22845 L
.11808 .22319 L
.12127 .21348 L
.1245 .20377 L
.12607 .19906 L
.12774 .19406 L
Mistroke
.13102 .18434 L
.13432 .17463 L
.13578 .17034 L
.13764 .16492 L
.14099 .15521 L
.14438 .14549 L
.14549 .1423 L
.14779 .13578 L
.15122 .12607 L
.1547 .11636 L
.15521 .11493 L
.1582 .10664 L
.16173 .09693 L
.16492 .08824 L
.1653 .08722 L
.1689 .07751 L
.17253 .06779 L
.17463 .06223 L
.1762 .05808 L
.17991 .04837 L
.18366 .03866 L
.18434 .03689 L
.18744 .02894 L
.19127 .01923 L
Mfstroke
.625 g
.01923 .48927 m
.02026 .48543 L
.02286 .47572 L
.02547 .46601 L
.0281 .45629 L
.02894 .45317 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41775 L
.03874 .41744 L
.04144 .40773 L
.04415 .39802 L
.04687 .38831 L
.04837 .383 L
.04961 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34893 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25076 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21939 L
.09878 .21348 L
.10184 .20377 L
.10493 .19406 L
.10664 .18869 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15866 L
.11749 .15521 L
.12069 .14549 L
.12391 .13578 L
.12607 .12932 L
.12716 .12607 L
.13043 .11636 L
.13373 .10664 L
.13578 .10064 L
.13705 .09693 L
.14041 .08722 L
.14379 .07751 L
.14549 .07264 L
.1472 .06779 L
.15064 .05808 L
.15411 .04837 L
.15521 .04532 L
.15761 .03866 L
.16115 .02894 L
.16471 .01923 L
.01923 .01923 L
F
0 g
.01923 .48927 m
.02026 .48543 L
.02286 .47572 L
.02547 .46601 L
.0281 .45629 L
.02894 .45317 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41775 L
.03874 .41744 L
.04144 .40773 L
.04415 .39802 L
.04687 .38831 L
.04837 .383 L
.04961 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34893 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25076 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21939 L
.09878 .21348 L
.10184 .20377 L
.10493 .19406 L
.10664 .18869 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15866 L
.11749 .15521 L
.12069 .14549 L
.12391 .13578 L
.12607 .12932 L
.12716 .12607 L
Mistroke
.13043 .11636 L
.13373 .10664 L
.13578 .10064 L
.13705 .09693 L
.14041 .08722 L
.14379 .07751 L
.14549 .07264 L
.1472 .06779 L
.15064 .05808 L
.15411 .04837 L
.15521 .04532 L
.15761 .03866 L
.16115 .02894 L
.16471 .01923 L
Mfstroke
.55 g
.01923 .42653 m
.02166 .41744 L
.02427 .40773 L
.0269 .39802 L
.02894 .39047 L
.02953 .38831 L
.03218 .37859 L
.03485 .36888 L
.03752 .35917 L
.03866 .35508 L
.04022 .34946 L
.04292 .33974 L
.04565 .33003 L
.04837 .32037 L
.04838 .32032 L
.05113 .31061 L
.0539 .30089 L
.05669 .29118 L
.05808 .28633 L
.05948 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25297 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18827 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15693 L
.09747 .15521 L
.10053 .14549 L
.1036 .13578 L
.10664 .12626 L
.1067 .12607 L
.10983 .11636 L
.11297 .10664 L
.11614 .09693 L
.11636 .09627 L
.11933 .08722 L
.12255 .07751 L
.12579 .06779 L
.12607 .06695 L
.12905 .05808 L
.13234 .04837 L
.13566 .03866 L
.13578 .03831 L
.13901 .02894 L
.14238 .01923 L
.01923 .01923 L
F
0 g
.01923 .42653 m
.02166 .41744 L
.02427 .40773 L
.0269 .39802 L
.02894 .39047 L
.02953 .38831 L
.03218 .37859 L
.03485 .36888 L
.03752 .35917 L
.03866 .35508 L
.04022 .34946 L
.04292 .33974 L
.04565 .33003 L
.04837 .32037 L
.04838 .32032 L
.05113 .31061 L
.0539 .30089 L
.05669 .29118 L
.05808 .28633 L
.05948 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25297 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18827 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15693 L
.09747 .15521 L
.10053 .14549 L
.1036 .13578 L
.10664 .12626 L
.1067 .12607 L
.10983 .11636 L
.11297 .10664 L
.11614 .09693 L
.11636 .09627 L
.11933 .08722 L
.12255 .07751 L
.12579 .06779 L
.12607 .06695 L
.12905 .05808 L
Mistroke
.13234 .04837 L
.13566 .03866 L
.13578 .03831 L
.13901 .02894 L
.14238 .01923 L
Mfstroke
.475 g
.01923 .36933 m
.01935 .36888 L
.02195 .35917 L
.02457 .34946 L
.02719 .33974 L
.02894 .33329 L
.02983 .33003 L
.03248 .32032 L
.03515 .31061 L
.03784 .30089 L
.03866 .29793 L
.04053 .29118 L
.04324 .28147 L
.04597 .27176 L
.04837 .26325 L
.04871 .26204 L
.05146 .25233 L
.05424 .24262 L
.05702 .23291 L
.05808 .22923 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .1959 L
.06834 .19406 L
.07121 .18434 L
.07409 .17463 L
.077 .16492 L
.07751 .16323 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06929 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03932 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
.01923 .01923 L
F
0 g
.01923 .36933 m
.01935 .36888 L
.02195 .35917 L
.02457 .34946 L
.02719 .33974 L
.02894 .33329 L
.02983 .33003 L
.03248 .32032 L
.03515 .31061 L
.03784 .30089 L
.03866 .29793 L
.04053 .29118 L
.04324 .28147 L
.04597 .27176 L
.04837 .26325 L
.04871 .26204 L
.05146 .25233 L
.05424 .24262 L
.05702 .23291 L
.05808 .22923 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .1959 L
.06834 .19406 L
.07121 .18434 L
.07409 .17463 L
.077 .16492 L
.07751 .16323 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06929 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03932 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
s
.4 g
.01923 .31641 m
.02078 .31061 L
.02339 .30089 L
.02602 .29118 L
.02865 .28147 L
.02894 .28039 L
.0313 .27176 L
.03396 .26204 L
.03664 .25233 L
.03866 .24505 L
.03933 .24262 L
.04204 .23291 L
.04476 .22319 L
.04749 .21348 L
.04837 .21039 L
.05024 .20377 L
.05301 .19406 L
.05579 .18434 L
.05808 .1764 L
.05859 .17463 L
.0614 .16492 L
.06424 .15521 L
.06708 .14549 L
.06779 .14308 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08158 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10579 .01923 L
.01923 .01923 L
F
0 g
.01923 .31641 m
.02078 .31061 L
.02339 .30089 L
.02602 .29118 L
.02865 .28147 L
.02894 .28039 L
.0313 .27176 L
.03396 .26204 L
.03664 .25233 L
.03866 .24505 L
.03933 .24262 L
.04204 .23291 L
.04476 .22319 L
.04749 .21348 L
.04837 .21039 L
.05024 .20377 L
.05301 .19406 L
.05579 .18434 L
.05808 .1764 L
.05859 .17463 L
.0614 .16492 L
.06424 .15521 L
.06708 .14549 L
.06779 .14308 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08158 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10579 .01923 L
s
.325 g
.01923 .26693 m
.02054 .26204 L
.02315 .25233 L
.02577 .24262 L
.02841 .23291 L
.02894 .23093 L
.03106 .22319 L
.03372 .21348 L
.0364 .20377 L
.03866 .19561 L
.03909 .19406 L
.04179 .18434 L
.04451 .17463 L
.04725 .16492 L
.04837 .16096 L
.05 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12699 L
.05835 .12607 L
.06116 .11636 L
.06399 .10664 L
.06684 .09693 L
.06779 .09369 L
.0697 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06106 L
.0784 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02911 L
.08727 .02894 L
.09026 .01923 L
.01923 .01923 L
F
0 g
.01923 .26693 m
.02054 .26204 L
.02315 .25233 L
.02577 .24262 L
.02841 .23291 L
.02894 .23093 L
.03106 .22319 L
.03372 .21348 L
.0364 .20377 L
.03866 .19561 L
.03909 .19406 L
.04179 .18434 L
.04451 .17463 L
.04725 .16492 L
.04837 .16096 L
.05 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12699 L
.05835 .12607 L
.06116 .11636 L
.06399 .10664 L
.06684 .09693 L
.06779 .09369 L
.0697 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06106 L
.0784 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02911 L
.08727 .02894 L
.09026 .01923 L
s
.25 g
.01923 .2203 m
.02106 .21348 L
.02367 .20377 L
.0263 .19406 L
.02894 .18434 L
.02894 .18432 L
.03159 .17463 L
.03426 .16492 L
.03694 .15521 L
.03866 .14901 L
.03963 .14549 L
.04234 .13578 L
.04507 .12607 L
.04781 .11636 L
.04837 .11438 L
.05056 .10664 L
.05333 .09693 L
.05612 .08722 L
.05808 .08042 L
.05892 .07751 L
.06174 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04713 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
.01923 .01923 L
F
0 g
.01923 .2203 m
.02106 .21348 L
.02367 .20377 L
.0263 .19406 L
.02894 .18434 L
.02894 .18432 L
.03159 .17463 L
.03426 .16492 L
.03694 .15521 L
.03866 .14901 L
.03963 .14549 L
.04234 .13578 L
.04507 .12607 L
.04781 .11636 L
.04837 .11438 L
.05056 .10664 L
.05333 .09693 L
.05612 .08722 L
.05808 .08042 L
.05892 .07751 L
.06174 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04713 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
s
.925 g
.96266 .98077 m
.96134 .97682 L
.95941 .97106 L
.95613 .96134 L
.95283 .95163 L
.95163 .94811 L
.94951 .94192 L
.94615 .93221 L
.94277 .92249 L
.94192 .92006 L
.93936 .91278 L
.93592 .90307 L
.93245 .89336 L
.93221 .89267 L
.92895 .88364 L
.92542 .87393 L
.92249 .86595 L
.92186 .86422 L
.91826 .85451 L
.91463 .84479 L
.91278 .83989 L
.91096 .83508 L
.90726 .82537 L
.90352 .81566 L
.90307 .81449 L
.89974 .80594 L
.89593 .79623 L
.89336 .78975 L
.89207 .78652 L
.88817 .77681 L
.88423 .76709 L
.88364 .76567 L
.88024 .75738 L
.8762 .74767 L
.87393 .74225 L
.87212 .73796 L
.86798 .72824 L
.86422 .7195 L
.8638 .71853 L
.85956 .70882 L
.85527 .69911 L
.85451 .6974 L
.85091 .68939 L
.8465 .67968 L
.84479 .67597 L
.84202 .66997 L
.83747 .66026 L
.83508 .6552 L
.83286 .65054 L
.82817 .64083 L
.82537 .63509 L
.82341 .63112 L
.81857 .62141 L
.81566 .61564 L
.81364 .61169 L
.80863 .60198 L
.80594 .59686 L
.80352 .59227 L
.79831 .58256 L
.79623 .57873 L
.793 .57284 L
.78757 .56313 L
.78652 .56127 L
.78203 .55342 L
.77681 .54446 L
.77636 .54371 L
.77055 .53399 L
.76709 .52832 L
.7646 .52428 L
.75849 .51457 L
.75738 .51284 L
.7522 .50486 L
.74767 .49802 L
.74573 .49514 L
.73905 .48543 L
.73796 .48387 L
.73215 .47572 L
.72824 .47037 L
.725 .46601 L
.71853 .45754 L
.71756 .45629 L
.70982 .44658 L
.70882 .44536 L
.70171 .43687 L
.69911 .43385 L
.69319 .42716 L
.68939 .423 L
.68418 .41744 L
.67968 .41281 L
.67459 .40773 L
.66997 .40328 L
.6643 .39802 L
.66026 .39441 L
.65311 .38831 L
.65054 .3862 L
.64083 .37865 L
.64075 .37859 L
.63112 .37177 L
.62675 .36888 L
.62141 .36554 L
.61169 .35998 L
.61018 .35917 L
.60198 .35507 L
.59227 .35083 L
.58877 .34946 L
.58256 .34725 L
.57284 .34432 L
.56313 .34206 L
.55342 .34046 L
.54673 .33974 L
.54371 .33952 L
.53399 .33924 L
.52428 .33962 L
.52204 .33974 L
.51457 .34066 L
.50486 .34236 L
.49514 .34472 L
.48543 .34774 L
.48067 .34946 L
.47572 .35142 L
.46601 .35576 L
.45925 .35917 L
.45629 .36076 L
.44658 .36642 L
.44268 .36888 L
.43687 .37274 L
.42866 .37859 L
.42716 .37972 L
.41744 .38736 L
.41629 .38831 L
.40773 .39565 L
.4051 .39802 L
.39802 .40461 L
.39479 .40773 L
.38831 .41423 L
.3852 .41744 L
.37859 .4245 L
.37618 .42716 L
.36888 .43544 L
.36765 .43687 L
.35953 .44658 L
.35917 .44703 L
.35178 .45629 L
.34946 .45928 L
.34433 .46601 L
.33974 .47219 L
.33717 .47572 L
.33026 .48543 L
.33003 .48576 L
.32358 .49514 L
.32032 .49999 L
.31709 .50486 L
.3108 .51457 L
.31061 .51487 L
.30468 .52428 L
.30089 .53042 L
.29872 .53399 L
.2929 .54371 L
.29118 .54662 L
.28722 .55342 L
.28166 .56313 L
.28147 .56348 L
.27623 .57284 L
.27176 .58099 L
.27091 .58256 L
.26569 .59227 L
.26204 .59917 L
.26057 .60198 L
.25555 .61169 L
.25233 .618 L
.25061 .62141 L
.24576 .63112 L
.24262 .63749 L
.24099 .64083 L
.23629 .65054 L
.23291 .65764 L
.23167 .66026 L
.22712 .66997 L
.22319 .67844 L
.22263 .67968 L
.2182 .68939 L
.21384 .69911 L
.21348 .6999 L
.20954 .70882 L
.20528 .71853 L
.20377 .72202 L
.20109 .72824 L
.19695 .73796 L
.19406 .7448 L
.19285 .74767 L
.18881 .75738 L
.18481 .76709 L
.18434 .76823 L
.18086 .77681 L
.17695 .78652 L
.17463 .79231 L
.17308 .79623 L
.16925 .80594 L
.16546 .81566 L
.16492 .81706 L
.16172 .82537 L
.158 .83508 L
.15521 .84245 L
.15433 .84479 L
.15069 .85451 L
.14708 .86422 L
.14549 .86851 L
.14351 .87393 L
.13997 .88364 L
.13645 .89336 L
.13578 .89522 L
.13298 .90307 L
.12953 .91278 L
.1261 .92249 L
.12607 .92258 L
.12272 .93221 L
.11935 .94192 L
.11636 .9506 L
.116 .95163 L
.1127 .96134 L
.10941 .97106 L
.10664 .97927 L
.10615 .98077 L
F
0 g
.96266 .98077 m
.96134 .97682 L
.95941 .97106 L
.95613 .96134 L
.95283 .95163 L
.95163 .94811 L
.94951 .94192 L
.94615 .93221 L
.94277 .92249 L
.94192 .92006 L
.93936 .91278 L
.93592 .90307 L
.93245 .89336 L
.93221 .89267 L
.92895 .88364 L
.92542 .87393 L
.92249 .86595 L
.92186 .86422 L
.91826 .85451 L
.91463 .84479 L
.91278 .83989 L
.91096 .83508 L
.90726 .82537 L
.90352 .81566 L
.90307 .81449 L
.89974 .80594 L
.89593 .79623 L
.89336 .78975 L
.89207 .78652 L
.88817 .77681 L
.88423 .76709 L
.88364 .76567 L
.88024 .75738 L
.8762 .74767 L
.87393 .74225 L
.87212 .73796 L
.86798 .72824 L
.86422 .7195 L
.8638 .71853 L
.85956 .70882 L
.85527 .69911 L
.85451 .6974 L
.85091 .68939 L
.8465 .67968 L
.84479 .67597 L
.84202 .66997 L
.83747 .66026 L
.83508 .6552 L
.83286 .65054 L
.82817 .64083 L
Mistroke
.82537 .63509 L
.82341 .63112 L
.81857 .62141 L
.81566 .61564 L
.81364 .61169 L
.80863 .60198 L
.80594 .59686 L
.80352 .59227 L
.79831 .58256 L
.79623 .57873 L
.793 .57284 L
.78757 .56313 L
.78652 .56127 L
.78203 .55342 L
.77681 .54446 L
.77636 .54371 L
.77055 .53399 L
.76709 .52832 L
.7646 .52428 L
.75849 .51457 L
.75738 .51284 L
.7522 .50486 L
.74767 .49802 L
.74573 .49514 L
.73905 .48543 L
.73796 .48387 L
.73215 .47572 L
.72824 .47037 L
.725 .46601 L
.71853 .45754 L
.71756 .45629 L
.70982 .44658 L
.70882 .44536 L
.70171 .43687 L
.69911 .43385 L
.69319 .42716 L
.68939 .423 L
.68418 .41744 L
.67968 .41281 L
.67459 .40773 L
.66997 .40328 L
.6643 .39802 L
.66026 .39441 L
.65311 .38831 L
.65054 .3862 L
.64083 .37865 L
.64075 .37859 L
.63112 .37177 L
.62675 .36888 L
.62141 .36554 L
Mistroke
.61169 .35998 L
.61018 .35917 L
.60198 .35507 L
.59227 .35083 L
.58877 .34946 L
.58256 .34725 L
.57284 .34432 L
.56313 .34206 L
.55342 .34046 L
.54673 .33974 L
.54371 .33952 L
.53399 .33924 L
.52428 .33962 L
.52204 .33974 L
.51457 .34066 L
.50486 .34236 L
.49514 .34472 L
.48543 .34774 L
.48067 .34946 L
.47572 .35142 L
.46601 .35576 L
.45925 .35917 L
.45629 .36076 L
.44658 .36642 L
.44268 .36888 L
.43687 .37274 L
.42866 .37859 L
.42716 .37972 L
.41744 .38736 L
.41629 .38831 L
.40773 .39565 L
.4051 .39802 L
.39802 .40461 L
.39479 .40773 L
.38831 .41423 L
.3852 .41744 L
.37859 .4245 L
.37618 .42716 L
.36888 .43544 L
.36765 .43687 L
.35953 .44658 L
.35917 .44703 L
.35178 .45629 L
.34946 .45928 L
.34433 .46601 L
.33974 .47219 L
.33717 .47572 L
.33026 .48543 L
.33003 .48576 L
.32358 .49514 L
Mistroke
.32032 .49999 L
.31709 .50486 L
.3108 .51457 L
.31061 .51487 L
.30468 .52428 L
.30089 .53042 L
.29872 .53399 L
.2929 .54371 L
.29118 .54662 L
.28722 .55342 L
.28166 .56313 L
.28147 .56348 L
.27623 .57284 L
.27176 .58099 L
.27091 .58256 L
.26569 .59227 L
.26204 .59917 L
.26057 .60198 L
.25555 .61169 L
.25233 .618 L
.25061 .62141 L
.24576 .63112 L
.24262 .63749 L
.24099 .64083 L
.23629 .65054 L
.23291 .65764 L
.23167 .66026 L
.22712 .66997 L
.22319 .67844 L
.22263 .67968 L
.2182 .68939 L
.21384 .69911 L
.21348 .6999 L
.20954 .70882 L
.20528 .71853 L
.20377 .72202 L
.20109 .72824 L
.19695 .73796 L
.19406 .7448 L
.19285 .74767 L
.18881 .75738 L
.18481 .76709 L
.18434 .76823 L
.18086 .77681 L
.17695 .78652 L
.17463 .79231 L
.17308 .79623 L
.16925 .80594 L
.16546 .81566 L
.16492 .81706 L
Mistroke
.16172 .82537 L
.158 .83508 L
.15521 .84245 L
.15433 .84479 L
.15069 .85451 L
.14708 .86422 L
.14549 .86851 L
.14351 .87393 L
.13997 .88364 L
.13645 .89336 L
.13578 .89522 L
.13298 .90307 L
.12953 .91278 L
.1261 .92249 L
.12607 .92258 L
.12272 .93221 L
.11935 .94192 L
.11636 .9506 L
.116 .95163 L
.1127 .96134 L
.10941 .97106 L
.10664 .97927 L
.10615 .98077 L
Mfstroke
.85 g
.91754 .98077 m
.9139 .97106 L
.91278 .96808 L
.91023 .96134 L
.90651 .95163 L
.90307 .9427 L
.90277 .94192 L
.89898 .93221 L
.89515 .92249 L
.89336 .91799 L
.89128 .91278 L
.88736 .90307 L
.88364 .89394 L
.8834 .89336 L
.8794 .88364 L
.87535 .87393 L
.87393 .87056 L
.87125 .86422 L
.8671 .85451 L
.86422 .84784 L
.8629 .84479 L
.85864 .83508 L
.85451 .82578 L
.85432 .82537 L
.84994 .81566 L
.84551 .80594 L
.84479 .8044 L
.841 .79623 L
.83643 .78652 L
.83508 .78367 L
.83179 .77681 L
.82708 .76709 L
.82537 .76361 L
.82229 .75738 L
.81741 .74767 L
.81566 .74422 L
.81245 .73796 L
.8074 .72824 L
.80594 .72549 L
.80225 .71853 L
.797 .70882 L
.79623 .70742 L
.79164 .69911 L
.78652 .69002 L
.78616 .68939 L
.78056 .67968 L
.77681 .67328 L
.77484 .66997 L
.76896 .66026 L
.76709 .65721 L
.76294 .65054 L
.75738 .64181 L
.75675 .64083 L
.75038 .63112 L
.74767 .62707 L
.74382 .62141 L
.73796 .61299 L
.73704 .61169 L
.73002 .60198 L
.72824 .59958 L
.72274 .59227 L
.71853 .58683 L
.71516 .58256 L
.70882 .57475 L
.70724 .57284 L
.69911 .56333 L
.69893 .56313 L
.69018 .55342 L
.68939 .55258 L
.68089 .54371 L
.67968 .54249 L
.67096 .53399 L
.66997 .53306 L
.66026 .5243 L
.66023 .52428 L
.65054 .51621 L
.64847 .51457 L
.64083 .50878 L
.63532 .50486 L
.63112 .50202 L
.62141 .49591 L
.6201 .49514 L
.61169 .49048 L
.60198 .48571 L
.60138 .48543 L
.59227 .4816 L
.58256 .47816 L
.57418 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47182 L
.54371 .47103 L
.53399 .47092 L
.52428 .47146 L
.51457 .47267 L
.50486 .47454 L
.49998 .47572 L
.49514 .47708 L
.48543 .48028 L
.47572 .48415 L
.47282 .48543 L
.46601 .48868 L
.45629 .49388 L
.4541 .49514 L
.44658 .49974 L
.43888 .50486 L
.43687 .50626 L
.42716 .51345 L
.42572 .51457 L
.41744 .52131 L
.41396 .52428 L
.40773 .52982 L
.40323 .53399 L
.39802 .53901 L
.3933 .54371 L
.38831 .54885 L
.38401 .55342 L
.37859 .55936 L
.37525 .56313 L
.36888 .57054 L
.36695 .57284 L
.35917 .58238 L
.35902 .58256 L
.35144 .59227 L
.34946 .59488 L
.34416 .60198 L
.33974 .60805 L
.33714 .61169 L
.33035 .62141 L
.33003 .62188 L
.32379 .63112 L
.32032 .63637 L
.31742 .64083 L
.31123 .65054 L
.31061 .65153 L
.3052 .66026 L
.30089 .66735 L
.29933 .66997 L
.2936 .67968 L
.29118 .68384 L
.288 .68939 L
.28252 .69911 L
.28147 .70099 L
.27716 .70882 L
.2719 .71853 L
.27176 .71881 L
.26675 .72824 L
.26204 .73729 L
.2617 .73796 L
.25673 .74767 L
.25233 .75643 L
.25186 .75738 L
.24706 .76709 L
.24262 .77624 L
.24234 .77681 L
.2377 .78652 L
.23313 .79623 L
.23291 .79671 L
.22862 .80594 L
.22418 .81566 L
.22319 .81784 L
.21981 .82537 L
.21549 .83508 L
.21348 .83964 L
.21123 .84479 L
.20702 .85451 L
.20377 .8621 L
.20287 .86422 L
.19877 .87393 L
.19471 .88364 L
.19406 .88523 L
.19071 .89336 L
.18675 .90307 L
.18434 .90902 L
.18283 .91278 L
.17896 .92249 L
.17513 .93221 L
.17463 .93347 L
.17134 .94192 L
.16758 .95163 L
.16492 .95859 L
.16387 .96134 L
.16019 .97106 L
.15655 .98077 L
F
0 g
.91754 .98077 m
.9139 .97106 L
.91278 .96808 L
.91023 .96134 L
.90651 .95163 L
.90307 .9427 L
.90277 .94192 L
.89898 .93221 L
.89515 .92249 L
.89336 .91799 L
.89128 .91278 L
.88736 .90307 L
.88364 .89394 L
.8834 .89336 L
.8794 .88364 L
.87535 .87393 L
.87393 .87056 L
.87125 .86422 L
.8671 .85451 L
.86422 .84784 L
.8629 .84479 L
.85864 .83508 L
.85451 .82578 L
.85432 .82537 L
.84994 .81566 L
.84551 .80594 L
.84479 .8044 L
.841 .79623 L
.83643 .78652 L
.83508 .78367 L
.83179 .77681 L
.82708 .76709 L
.82537 .76361 L
.82229 .75738 L
.81741 .74767 L
.81566 .74422 L
.81245 .73796 L
.8074 .72824 L
.80594 .72549 L
.80225 .71853 L
.797 .70882 L
.79623 .70742 L
.79164 .69911 L
.78652 .69002 L
.78616 .68939 L
.78056 .67968 L
.77681 .67328 L
.77484 .66997 L
.76896 .66026 L
.76709 .65721 L
Mistroke
.76294 .65054 L
.75738 .64181 L
.75675 .64083 L
.75038 .63112 L
.74767 .62707 L
.74382 .62141 L
.73796 .61299 L
.73704 .61169 L
.73002 .60198 L
.72824 .59958 L
.72274 .59227 L
.71853 .58683 L
.71516 .58256 L
.70882 .57475 L
.70724 .57284 L
.69911 .56333 L
.69893 .56313 L
.69018 .55342 L
.68939 .55258 L
.68089 .54371 L
.67968 .54249 L
.67096 .53399 L
.66997 .53306 L
.66026 .5243 L
.66023 .52428 L
.65054 .51621 L
.64847 .51457 L
.64083 .50878 L
.63532 .50486 L
.63112 .50202 L
.62141 .49591 L
.6201 .49514 L
.61169 .49048 L
.60198 .48571 L
.60138 .48543 L
.59227 .4816 L
.58256 .47816 L
.57418 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47182 L
.54371 .47103 L
.53399 .47092 L
.52428 .47146 L
.51457 .47267 L
.50486 .47454 L
.49998 .47572 L
.49514 .47708 L
.48543 .48028 L
.47572 .48415 L
Mistroke
.47282 .48543 L
.46601 .48868 L
.45629 .49388 L
.4541 .49514 L
.44658 .49974 L
.43888 .50486 L
.43687 .50626 L
.42716 .51345 L
.42572 .51457 L
.41744 .52131 L
.41396 .52428 L
.40773 .52982 L
.40323 .53399 L
.39802 .53901 L
.3933 .54371 L
.38831 .54885 L
.38401 .55342 L
.37859 .55936 L
.37525 .56313 L
.36888 .57054 L
.36695 .57284 L
.35917 .58238 L
.35902 .58256 L
.35144 .59227 L
.34946 .59488 L
.34416 .60198 L
.33974 .60805 L
.33714 .61169 L
.33035 .62141 L
.33003 .62188 L
.32379 .63112 L
.32032 .63637 L
.31742 .64083 L
.31123 .65054 L
.31061 .65153 L
.3052 .66026 L
.30089 .66735 L
.29933 .66997 L
.2936 .67968 L
.29118 .68384 L
.288 .68939 L
.28252 .69911 L
.28147 .70099 L
.27716 .70882 L
.2719 .71853 L
.27176 .71881 L
.26675 .72824 L
.26204 .73729 L
.2617 .73796 L
.25673 .74767 L
Mistroke
.25233 .75643 L
.25186 .75738 L
.24706 .76709 L
.24262 .77624 L
.24234 .77681 L
.2377 .78652 L
.23313 .79623 L
.23291 .79671 L
.22862 .80594 L
.22418 .81566 L
.22319 .81784 L
.21981 .82537 L
.21549 .83508 L
.21348 .83964 L
.21123 .84479 L
.20702 .85451 L
.20377 .8621 L
.20287 .86422 L
.19877 .87393 L
.19471 .88364 L
.19406 .88523 L
.19071 .89336 L
.18675 .90307 L
.18434 .90902 L
.18283 .91278 L
.17896 .92249 L
.17513 .93221 L
.17463 .93347 L
.17134 .94192 L
.16758 .95163 L
.16492 .95859 L
.16387 .96134 L
.16019 .97106 L
.15655 .98077 L
Mfstroke
.775 g
.88074 .98077 m
.8767 .97106 L
.87393 .96446 L
.87261 .96134 L
.86848 .95163 L
.86429 .94192 L
.86422 .94176 L
.86004 .93221 L
.85575 .92249 L
.85451 .91972 L
.85139 .91278 L
.84697 .90307 L
.84479 .89835 L
.84248 .89336 L
.83793 .88364 L
.83508 .87764 L
.83331 .87393 L
.82861 .86422 L
.82537 .8576 L
.82384 .85451 L
.81899 .84479 L
.81566 .83823 L
.81405 .83508 L
.80902 .82537 L
.80594 .81952 L
.8039 .81566 L
.79867 .80594 L
.79623 .80147 L
.79334 .79623 L
.7879 .78652 L
.78652 .7841 L
.78233 .77681 L
.77681 .76739 L
.77663 .76709 L
.7708 .75738 L
.76709 .75134 L
.76481 .74767 L
.75866 .73796 L
.75738 .73596 L
.75234 .72824 L
.74767 .72125 L
.74582 .71853 L
.7391 .70882 L
.73796 .7072 L
.73214 .69911 L
.72824 .69382 L
.72492 .68939 L
.71853 .68111 L
.71741 .67968 L
.70957 .66997 L
.70882 .66906 L
.70136 .66026 L
.69911 .65768 L
.69271 .65054 L
.68939 .64696 L
.68355 .64083 L
.67968 .63691 L
.67377 .63112 L
.66997 .62753 L
.66323 .62141 L
.66026 .61881 L
.65172 .61169 L
.65054 .61076 L
.64083 .60337 L
.6389 .60198 L
.63112 .59665 L
.6242 .59227 L
.62141 .5906 L
.61169 .58521 L
.60642 .58256 L
.60198 .58049 L
.59227 .57643 L
.58256 .57304 L
.58195 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56686 L
.54371 .56613 L
.53399 .56607 L
.52428 .56668 L
.51457 .56795 L
.50486 .56989 L
.49514 .57249 L
.49398 .57284 L
.48543 .57576 L
.47572 .57969 L
.4695 .58256 L
.46601 .58429 L
.45629 .58956 L
.45172 .59227 L
.44658 .59549 L
.43702 .60198 L
.43687 .60209 L
.42716 .60935 L
.4242 .61169 L
.41744 .61728 L
.41269 .62141 L
.40773 .62588 L
.40215 .63112 L
.39802 .63514 L
.39237 .64083 L
.38831 .64506 L
.3832 .65054 L
.37859 .65566 L
.37456 .66026 L
.36888 .66691 L
.36634 .66997 L
.35917 .67884 L
.3585 .67968 L
.35099 .68939 L
.34946 .69143 L
.34377 .69911 L
.33974 .70468 L
.33681 .70882 L
.33008 .71853 L
.33003 .71861 L
.32356 .72824 L
.32032 .73319 L
.31724 .73796 L
.31109 .74767 L
.31061 .74845 L
.3051 .75738 L
.30089 .76436 L
.29927 .76709 L
.29357 .77681 L
.29118 .78095 L
.288 .78652 L
.28256 .79623 L
.28147 .7982 L
.27722 .80594 L
.272 .81566 L
.27176 .81611 L
.26687 .82537 L
.26204 .83469 L
.26184 .83508 L
.2569 .84479 L
.25233 .85394 L
.25205 .85451 L
.24728 .86422 L
.24262 .87385 L
.24258 .87393 L
.23796 .88364 L
.2334 .89336 L
.23291 .89443 L
.22892 .90307 L
.2245 .91278 L
.22319 .91567 L
.22014 .92249 L
.21584 .93221 L
.21348 .93758 L
.21159 .94192 L
.2074 .95163 L
.20377 .96016 L
.20327 .96134 L
.19918 .97106 L
.19514 .98077 L
F
0 g
.88074 .98077 m
.8767 .97106 L
.87393 .96446 L
.87261 .96134 L
.86848 .95163 L
.86429 .94192 L
.86422 .94176 L
.86004 .93221 L
.85575 .92249 L
.85451 .91972 L
.85139 .91278 L
.84697 .90307 L
.84479 .89835 L
.84248 .89336 L
.83793 .88364 L
.83508 .87764 L
.83331 .87393 L
.82861 .86422 L
.82537 .8576 L
.82384 .85451 L
.81899 .84479 L
.81566 .83823 L
.81405 .83508 L
.80902 .82537 L
.80594 .81952 L
.8039 .81566 L
.79867 .80594 L
.79623 .80147 L
.79334 .79623 L
.7879 .78652 L
.78652 .7841 L
.78233 .77681 L
.77681 .76739 L
.77663 .76709 L
.7708 .75738 L
.76709 .75134 L
.76481 .74767 L
.75866 .73796 L
.75738 .73596 L
.75234 .72824 L
.74767 .72125 L
.74582 .71853 L
.7391 .70882 L
.73796 .7072 L
.73214 .69911 L
.72824 .69382 L
.72492 .68939 L
.71853 .68111 L
.71741 .67968 L
.70957 .66997 L
Mistroke
.70882 .66906 L
.70136 .66026 L
.69911 .65768 L
.69271 .65054 L
.68939 .64696 L
.68355 .64083 L
.67968 .63691 L
.67377 .63112 L
.66997 .62753 L
.66323 .62141 L
.66026 .61881 L
.65172 .61169 L
.65054 .61076 L
.64083 .60337 L
.6389 .60198 L
.63112 .59665 L
.6242 .59227 L
.62141 .5906 L
.61169 .58521 L
.60642 .58256 L
.60198 .58049 L
.59227 .57643 L
.58256 .57304 L
.58195 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56686 L
.54371 .56613 L
.53399 .56607 L
.52428 .56668 L
.51457 .56795 L
.50486 .56989 L
.49514 .57249 L
.49398 .57284 L
.48543 .57576 L
.47572 .57969 L
.4695 .58256 L
.46601 .58429 L
.45629 .58956 L
.45172 .59227 L
.44658 .59549 L
.43702 .60198 L
.43687 .60209 L
.42716 .60935 L
.4242 .61169 L
.41744 .61728 L
.41269 .62141 L
.40773 .62588 L
.40215 .63112 L
.39802 .63514 L
Mistroke
.39237 .64083 L
.38831 .64506 L
.3832 .65054 L
.37859 .65566 L
.37456 .66026 L
.36888 .66691 L
.36634 .66997 L
.35917 .67884 L
.3585 .67968 L
.35099 .68939 L
.34946 .69143 L
.34377 .69911 L
.33974 .70468 L
.33681 .70882 L
.33008 .71853 L
.33003 .71861 L
.32356 .72824 L
.32032 .73319 L
.31724 .73796 L
.31109 .74767 L
.31061 .74845 L
.3051 .75738 L
.30089 .76436 L
.29927 .76709 L
.29357 .77681 L
.29118 .78095 L
.288 .78652 L
.28256 .79623 L
.28147 .7982 L
.27722 .80594 L
.272 .81566 L
.27176 .81611 L
.26687 .82537 L
.26204 .83469 L
.26184 .83508 L
.2569 .84479 L
.25233 .85394 L
.25205 .85451 L
.24728 .86422 L
.24262 .87385 L
.24258 .87393 L
.23796 .88364 L
.2334 .89336 L
.23291 .89443 L
.22892 .90307 L
.2245 .91278 L
.22319 .91567 L
.22014 .92249 L
.21584 .93221 L
.21348 .93758 L
Mistroke
.21159 .94192 L
.2074 .95163 L
.20377 .96016 L
.20327 .96134 L
.19918 .97106 L
.19514 .98077 L
Mfstroke
.7 g
.84691 .98077 m
.84479 .97617 L
.84243 .97106 L
.83787 .96134 L
.83508 .95547 L
.83325 .95163 L
.82855 .94192 L
.82537 .93544 L
.82377 .93221 L
.81891 .92249 L
.81566 .91607 L
.81397 .91278 L
.80894 .90307 L
.80594 .89738 L
.80381 .89336 L
.79858 .88364 L
.79623 .87935 L
.79324 .87393 L
.78779 .86422 L
.78652 .86199 L
.78222 .85451 L
.77681 .84529 L
.77651 .84479 L
.77067 .83508 L
.76709 .82926 L
.76467 .82537 L
.75852 .81566 L
.75738 .8139 L
.75218 .80594 L
.74767 .7992 L
.74565 .79623 L
.73891 .78652 L
.73796 .78517 L
.73193 .77681 L
.72824 .77181 L
.7247 .76709 L
.71853 .75911 L
.71717 .75738 L
.7093 .74767 L
.70882 .74708 L
.70106 .73796 L
.69911 .73572 L
.69238 .72824 L
.68939 .72502 L
.68318 .71853 L
.67968 .715 L
.67335 .70882 L
.66997 .70563 L
.66275 .69911 L
.66026 .69694 L
.65115 .68939 L
.65054 .68891 L
.64083 .68155 L
.63822 .67968 L
.63112 .67485 L
.62334 .66997 L
.62141 .66882 L
.61169 .66346 L
.60522 .66026 L
.60198 .65877 L
.59227 .65474 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64665 L
.55342 .64529 L
.54371 .6446 L
.53399 .64457 L
.52428 .64521 L
.51457 .64651 L
.50486 .64848 L
.49704 .65054 L
.49514 .65112 L
.48543 .65443 L
.47572 .6584 L
.47165 .66026 L
.46601 .66304 L
.45629 .66834 L
.45353 .66997 L
.44658 .67431 L
.43865 .67968 L
.43687 .68095 L
.42716 .68826 L
.42572 .68939 L
.41744 .69623 L
.41412 .69911 L
.40773 .70487 L
.40352 .70882 L
.39802 .71417 L
.39369 .71853 L
.38831 .72414 L
.38449 .72824 L
.37859 .73478 L
.3758 .73796 L
.36888 .74608 L
.36756 .74767 L
.3597 .75738 L
.35917 .75805 L
.35217 .76709 L
.34946 .77069 L
.34493 .77681 L
.33974 .784 L
.33796 .78652 L
.33121 .79623 L
.33003 .79797 L
.32468 .80594 L
.32032 .8126 L
.31835 .81566 L
.31219 .82537 L
.31061 .82791 L
.30619 .83508 L
.30089 .84388 L
.30035 .84479 L
.29464 .85451 L
.29118 .86052 L
.28907 .86422 L
.28362 .87393 L
.28147 .87782 L
.27828 .88364 L
.27305 .89336 L
.27176 .89579 L
.26792 .90307 L
.26289 .91278 L
.26204 .91443 L
.25794 .92249 L
.25308 .93221 L
.25233 .93373 L
.24831 .94192 L
.24361 .95163 L
.24262 .9537 L
.23898 .96134 L
.23443 .97106 L
.23291 .97433 L
.22994 .98077 L
F
0 g
.84691 .98077 m
.84479 .97617 L
.84243 .97106 L
.83787 .96134 L
.83508 .95547 L
.83325 .95163 L
.82855 .94192 L
.82537 .93544 L
.82377 .93221 L
.81891 .92249 L
.81566 .91607 L
.81397 .91278 L
.80894 .90307 L
.80594 .89738 L
.80381 .89336 L
.79858 .88364 L
.79623 .87935 L
.79324 .87393 L
.78779 .86422 L
.78652 .86199 L
.78222 .85451 L
.77681 .84529 L
.77651 .84479 L
.77067 .83508 L
.76709 .82926 L
.76467 .82537 L
.75852 .81566 L
.75738 .8139 L
.75218 .80594 L
.74767 .7992 L
.74565 .79623 L
.73891 .78652 L
.73796 .78517 L
.73193 .77681 L
.72824 .77181 L
.7247 .76709 L
.71853 .75911 L
.71717 .75738 L
.7093 .74767 L
.70882 .74708 L
.70106 .73796 L
.69911 .73572 L
.69238 .72824 L
.68939 .72502 L
.68318 .71853 L
.67968 .715 L
.67335 .70882 L
.66997 .70563 L
.66275 .69911 L
.66026 .69694 L
Mistroke
.65115 .68939 L
.65054 .68891 L
.64083 .68155 L
.63822 .67968 L
.63112 .67485 L
.62334 .66997 L
.62141 .66882 L
.61169 .66346 L
.60522 .66026 L
.60198 .65877 L
.59227 .65474 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64665 L
.55342 .64529 L
.54371 .6446 L
.53399 .64457 L
.52428 .64521 L
.51457 .64651 L
.50486 .64848 L
.49704 .65054 L
.49514 .65112 L
.48543 .65443 L
.47572 .6584 L
.47165 .66026 L
.46601 .66304 L
.45629 .66834 L
.45353 .66997 L
.44658 .67431 L
.43865 .67968 L
.43687 .68095 L
.42716 .68826 L
.42572 .68939 L
.41744 .69623 L
.41412 .69911 L
.40773 .70487 L
.40352 .70882 L
.39802 .71417 L
.39369 .71853 L
.38831 .72414 L
.38449 .72824 L
.37859 .73478 L
.3758 .73796 L
.36888 .74608 L
.36756 .74767 L
.3597 .75738 L
.35917 .75805 L
.35217 .76709 L
.34946 .77069 L
Mistroke
.34493 .77681 L
.33974 .784 L
.33796 .78652 L
.33121 .79623 L
.33003 .79797 L
.32468 .80594 L
.32032 .8126 L
.31835 .81566 L
.31219 .82537 L
.31061 .82791 L
.30619 .83508 L
.30089 .84388 L
.30035 .84479 L
.29464 .85451 L
.29118 .86052 L
.28907 .86422 L
.28362 .87393 L
.28147 .87782 L
.27828 .88364 L
.27305 .89336 L
.27176 .89579 L
.26792 .90307 L
.26289 .91278 L
.26204 .91443 L
.25794 .92249 L
.25308 .93221 L
.25233 .93373 L
.24831 .94192 L
.24361 .95163 L
.24262 .9537 L
.23898 .96134 L
.23443 .97106 L
.23291 .97433 L
.22994 .98077 L
Mfstroke
.625 g
.81399 .98077 m
.80896 .97106 L
.80594 .96533 L
.80383 .96134 L
.7986 .95163 L
.79623 .94731 L
.79326 .94192 L
.7878 .93221 L
.78652 .92995 L
.78223 .92249 L
.77681 .91327 L
.77652 .91278 L
.77067 .90307 L
.76709 .89725 L
.76467 .89336 L
.75851 .88364 L
.75738 .88189 L
.75217 .87393 L
.74767 .86721 L
.74564 .86422 L
.73889 .85451 L
.73796 .85319 L
.73191 .84479 L
.72824 .83984 L
.72466 .83508 L
.71853 .82716 L
.71712 .82537 L
.70925 .81566 L
.70882 .81514 L
.70099 .80594 L
.69911 .80379 L
.6923 .79623 L
.68939 .79311 L
.68308 .78652 L
.67968 .78309 L
.67323 .77681 L
.66997 .77375 L
.6626 .76709 L
.66026 .76507 L
.65096 .75738 L
.65054 .75705 L
.64083 .74971 L
.63797 .74767 L
.63112 .74303 L
.623 .73796 L
.62141 .73702 L
.61169 .73167 L
.60472 .72824 L
.60198 .72699 L
.59227 .72298 L
.58256 .71964 L
.57886 .71853 L
.57284 .71697 L
.56313 .71496 L
.55342 .71362 L
.54371 .71294 L
.53399 .71294 L
.52428 .7136 L
.51457 .71492 L
.50486 .71692 L
.49864 .71853 L
.49514 .71958 L
.48543 .72291 L
.47572 .72691 L
.47278 .72824 L
.46601 .73157 L
.45629 .7369 L
.4545 .73796 L
.44658 .7429 L
.43953 .74767 L
.43687 .74956 L
.42716 .75689 L
.42654 .75738 L
.41744 .76489 L
.4149 .76709 L
.40773 .77356 L
.40427 .77681 L
.39802 .78289 L
.39442 .78652 L
.38831 .79289 L
.3852 .79623 L
.37859 .80356 L
.3765 .80594 L
.36888 .8149 L
.36825 .81566 L
.36038 .82537 L
.35917 .8269 L
.35284 .83508 L
.34946 .83957 L
.34559 .84479 L
.33974 .8529 L
.33861 .85451 L
.33186 .86422 L
.33003 .86691 L
.32532 .87393 L
.32032 .88158 L
.31898 .88364 L
.31282 .89336 L
.31061 .89691 L
.30682 .90307 L
.30097 .91278 L
.30089 .91292 L
.29527 .92249 L
.29118 .92959 L
.28969 .93221 L
.28424 .94192 L
.28147 .94693 L
.2789 .95163 L
.27366 .96134 L
.27176 .96493 L
.26853 .97106 L
.2635 .98077 L
F
0 g
.81399 .98077 m
.80896 .97106 L
.80594 .96533 L
.80383 .96134 L
.7986 .95163 L
.79623 .94731 L
.79326 .94192 L
.7878 .93221 L
.78652 .92995 L
.78223 .92249 L
.77681 .91327 L
.77652 .91278 L
.77067 .90307 L
.76709 .89725 L
.76467 .89336 L
.75851 .88364 L
.75738 .88189 L
.75217 .87393 L
.74767 .86721 L
.74564 .86422 L
.73889 .85451 L
.73796 .85319 L
.73191 .84479 L
.72824 .83984 L
.72466 .83508 L
.71853 .82716 L
.71712 .82537 L
.70925 .81566 L
.70882 .81514 L
.70099 .80594 L
.69911 .80379 L
.6923 .79623 L
.68939 .79311 L
.68308 .78652 L
.67968 .78309 L
.67323 .77681 L
.66997 .77375 L
.6626 .76709 L
.66026 .76507 L
.65096 .75738 L
.65054 .75705 L
.64083 .74971 L
.63797 .74767 L
.63112 .74303 L
.623 .73796 L
.62141 .73702 L
.61169 .73167 L
.60472 .72824 L
.60198 .72699 L
.59227 .72298 L
Mistroke
.58256 .71964 L
.57886 .71853 L
.57284 .71697 L
.56313 .71496 L
.55342 .71362 L
.54371 .71294 L
.53399 .71294 L
.52428 .7136 L
.51457 .71492 L
.50486 .71692 L
.49864 .71853 L
.49514 .71958 L
.48543 .72291 L
.47572 .72691 L
.47278 .72824 L
.46601 .73157 L
.45629 .7369 L
.4545 .73796 L
.44658 .7429 L
.43953 .74767 L
.43687 .74956 L
.42716 .75689 L
.42654 .75738 L
.41744 .76489 L
.4149 .76709 L
.40773 .77356 L
.40427 .77681 L
.39802 .78289 L
.39442 .78652 L
.38831 .79289 L
.3852 .79623 L
.37859 .80356 L
.3765 .80594 L
.36888 .8149 L
.36825 .81566 L
.36038 .82537 L
.35917 .8269 L
.35284 .83508 L
.34946 .83957 L
.34559 .84479 L
.33974 .8529 L
.33861 .85451 L
.33186 .86422 L
.33003 .86691 L
.32532 .87393 L
.32032 .88158 L
.31898 .88364 L
.31282 .89336 L
.31061 .89691 L
.30682 .90307 L
Mistroke
.30097 .91278 L
.30089 .91292 L
.29527 .92249 L
.29118 .92959 L
.28969 .93221 L
.28424 .94192 L
.28147 .94693 L
.2789 .95163 L
.27366 .96134 L
.27176 .96493 L
.26853 .97106 L
.2635 .98077 L
Mfstroke
.55 g
.78059 .98077 m
.77681 .97436 L
.77484 .97106 L
.76895 .96134 L
.76709 .95834 L
.7629 .95163 L
.75738 .943 L
.75668 .94192 L
.75028 .93221 L
.74767 .92832 L
.74369 .92249 L
.73796 .91431 L
.73687 .91278 L
.72981 .90307 L
.72824 .90097 L
.72247 .89336 L
.71853 .88829 L
.71483 .88364 L
.70882 .87629 L
.70685 .87393 L
.69911 .86495 L
.69846 .86422 L
.68961 .85451 L
.68939 .85428 L
.68021 .84479 L
.67968 .84427 L
.67013 .83508 L
.66997 .83493 L
.66026 .82627 L
.65921 .82537 L
.65054 .81826 L
.64719 .81566 L
.64083 .81093 L
.63367 .80594 L
.63112 .80426 L
.62141 .79826 L
.61785 .79623 L
.61169 .79293 L
.60198 .78827 L
.59794 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77828 L
.56612 .77681 L
.56313 .77629 L
.55342 .77496 L
.54371 .7743 L
.53399 .77431 L
.52428 .77499 L
.51457 .77633 L
.51185 .77681 L
.50486 .77834 L
.49514 .78102 L
.48543 .78437 L
.48001 .78652 L
.47572 .78838 L
.46601 .79306 L
.4601 .79623 L
.45629 .79841 L
.44658 .80443 L
.44429 .80594 L
.43687 .81111 L
.43076 .81566 L
.42716 .81846 L
.41874 .82537 L
.41744 .82648 L
.40782 .83508 L
.40773 .83517 L
.39802 .84452 L
.39775 .84479 L
.38834 .85451 L
.38831 .85454 L
.37949 .86422 L
.37859 .86523 L
.3711 .87393 L
.36888 .87659 L
.36312 .88364 L
.35917 .88861 L
.35548 .89336 L
.34946 .9013 L
.34814 .90307 L
.34108 .91278 L
.33974 .91466 L
.33426 .92249 L
.33003 .92869 L
.32767 .93221 L
.32127 .94192 L
.32032 .94338 L
.31505 .95163 L
.31061 .95874 L
.309 .96134 L
.30311 .97106 L
.30089 .97477 L
.29736 .98077 L
F
0 g
.78059 .98077 m
.77681 .97436 L
.77484 .97106 L
.76895 .96134 L
.76709 .95834 L
.7629 .95163 L
.75738 .943 L
.75668 .94192 L
.75028 .93221 L
.74767 .92832 L
.74369 .92249 L
.73796 .91431 L
.73687 .91278 L
.72981 .90307 L
.72824 .90097 L
.72247 .89336 L
.71853 .88829 L
.71483 .88364 L
.70882 .87629 L
.70685 .87393 L
.69911 .86495 L
.69846 .86422 L
.68961 .85451 L
.68939 .85428 L
.68021 .84479 L
.67968 .84427 L
.67013 .83508 L
.66997 .83493 L
.66026 .82627 L
.65921 .82537 L
.65054 .81826 L
.64719 .81566 L
.64083 .81093 L
.63367 .80594 L
.63112 .80426 L
.62141 .79826 L
.61785 .79623 L
.61169 .79293 L
.60198 .78827 L
.59794 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77828 L
.56612 .77681 L
.56313 .77629 L
.55342 .77496 L
.54371 .7743 L
.53399 .77431 L
.52428 .77499 L
.51457 .77633 L
Mistroke
.51185 .77681 L
.50486 .77834 L
.49514 .78102 L
.48543 .78437 L
.48001 .78652 L
.47572 .78838 L
.46601 .79306 L
.4601 .79623 L
.45629 .79841 L
.44658 .80443 L
.44429 .80594 L
.43687 .81111 L
.43076 .81566 L
.42716 .81846 L
.41874 .82537 L
.41744 .82648 L
.40782 .83508 L
.40773 .83517 L
.39802 .84452 L
.39775 .84479 L
.38834 .85451 L
.38831 .85454 L
.37949 .86422 L
.37859 .86523 L
.3711 .87393 L
.36888 .87659 L
.36312 .88364 L
.35917 .88861 L
.35548 .89336 L
.34946 .9013 L
.34814 .90307 L
.34108 .91278 L
.33974 .91466 L
.33426 .92249 L
.33003 .92869 L
.32767 .93221 L
.32127 .94192 L
.32032 .94338 L
.31505 .95163 L
.31061 .95874 L
.309 .96134 L
.30311 .97106 L
.30089 .97477 L
.29736 .98077 L
Mfstroke
.475 g
.74527 .98077 m
.7385 .97106 L
.73796 .97029 L
.7315 .96134 L
.72824 .95695 L
.72423 .95163 L
.71853 .94428 L
.71666 .94192 L
.70882 .93228 L
.70876 .93221 L
.70046 .92249 L
.69911 .92095 L
.69172 .91278 L
.68939 .91029 L
.68245 .90307 L
.67968 .90029 L
.67253 .89336 L
.66997 .89096 L
.66182 .88364 L
.66026 .8823 L
.65054 .87431 L
.65007 .87393 L
.64083 .86698 L
.63692 .86422 L
.63112 .86032 L
.6217 .85451 L
.62141 .85433 L
.61169 .84901 L
.60296 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57562 .83508 L
.57284 .8344 L
.56313 .83242 L
.55342 .8311 L
.54371 .83046 L
.53399 .83048 L
.52428 .83117 L
.51457 .83252 L
.50486 .83455 L
.50269 .83508 L
.49514 .83724 L
.48543 .8406 L
.47572 .84463 L
.47534 .84479 L
.46601 .84932 L
.4566 .85451 L
.45629 .85468 L
.44658 .86072 L
.44138 .86422 L
.43687 .86741 L
.42823 .87393 L
.42716 .87478 L
.41744 .88281 L
.41648 .88364 L
.40773 .89152 L
.40577 .89336 L
.39802 .90089 L
.39585 .90307 L
.38831 .91092 L
.38658 .91278 L
.37859 .92163 L
.37783 .92249 L
.36954 .93221 L
.36888 .933 L
.36164 .94192 L
.35917 .94504 L
.35407 .95163 L
.34946 .95775 L
.3468 .96134 L
.33979 .97106 L
.33974 .97113 L
.33303 .98077 L
F
0 g
.74527 .98077 m
.7385 .97106 L
.73796 .97029 L
.7315 .96134 L
.72824 .95695 L
.72423 .95163 L
.71853 .94428 L
.71666 .94192 L
.70882 .93228 L
.70876 .93221 L
.70046 .92249 L
.69911 .92095 L
.69172 .91278 L
.68939 .91029 L
.68245 .90307 L
.67968 .90029 L
.67253 .89336 L
.66997 .89096 L
.66182 .88364 L
.66026 .8823 L
.65054 .87431 L
.65007 .87393 L
.64083 .86698 L
.63692 .86422 L
.63112 .86032 L
.6217 .85451 L
.62141 .85433 L
.61169 .84901 L
.60296 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57562 .83508 L
.57284 .8344 L
.56313 .83242 L
.55342 .8311 L
.54371 .83046 L
.53399 .83048 L
.52428 .83117 L
.51457 .83252 L
.50486 .83455 L
.50269 .83508 L
.49514 .83724 L
.48543 .8406 L
.47572 .84463 L
.47534 .84479 L
.46601 .84932 L
.4566 .85451 L
.45629 .85468 L
.44658 .86072 L
Mistroke
.44138 .86422 L
.43687 .86741 L
.42823 .87393 L
.42716 .87478 L
.41744 .88281 L
.41648 .88364 L
.40773 .89152 L
.40577 .89336 L
.39802 .90089 L
.39585 .90307 L
.38831 .91092 L
.38658 .91278 L
.37859 .92163 L
.37783 .92249 L
.36954 .93221 L
.36888 .933 L
.36164 .94192 L
.35917 .94504 L
.35407 .95163 L
.34946 .95775 L
.3468 .96134 L
.33979 .97106 L
.33974 .97113 L
.33303 .98077 L
Mfstroke
.4 g
.7059 .98077 m
.69911 .97292 L
.69746 .97106 L
.68939 .96226 L
.68853 .96134 L
.67968 .95227 L
.67904 .95163 L
.66997 .94294 L
.66886 .94192 L
.66026 .93429 L
.6578 .93221 L
.65054 .9263 L
.6456 .92249 L
.64083 .91899 L
.6318 .91278 L
.63112 .91234 L
.62141 .90635 L
.61556 .90307 L
.61169 .90104 L
.60198 .89639 L
.59473 .89336 L
.59227 .89242 L
.58256 .88911 L
.57284 .88646 L
.56313 .88449 L
.55805 .88364 L
.55342 .88318 L
.54371 .88255 L
.53399 .88258 L
.52428 .88327 L
.52069 .88364 L
.51457 .88464 L
.50486 .88667 L
.49514 .88938 L
.48543 .89275 L
.48385 .89336 L
.47572 .89679 L
.46601 .90149 L
.46302 .90307 L
.45629 .90687 L
.44677 .91278 L
.44658 .91291 L
.43687 .91962 L
.43298 .92249 L
.42716 .927 L
.42077 .93221 L
.41744 .93504 L
.40972 .94192 L
.40773 .94376 L
.39953 .95163 L
.39802 .95314 L
.39004 .96134 L
.38831 .96319 L
.38112 .97106 L
.37859 .97391 L
.37267 .98077 L
F
0 g
.7059 .98077 m
.69911 .97292 L
.69746 .97106 L
.68939 .96226 L
.68853 .96134 L
.67968 .95227 L
.67904 .95163 L
.66997 .94294 L
.66886 .94192 L
.66026 .93429 L
.6578 .93221 L
.65054 .9263 L
.6456 .92249 L
.64083 .91899 L
.6318 .91278 L
.63112 .91234 L
.62141 .90635 L
.61556 .90307 L
.61169 .90104 L
.60198 .89639 L
.59473 .89336 L
.59227 .89242 L
.58256 .88911 L
.57284 .88646 L
.56313 .88449 L
.55805 .88364 L
.55342 .88318 L
.54371 .88255 L
.53399 .88258 L
.52428 .88327 L
.52069 .88364 L
.51457 .88464 L
.50486 .88667 L
.49514 .88938 L
.48543 .89275 L
.48385 .89336 L
.47572 .89679 L
.46601 .90149 L
.46302 .90307 L
.45629 .90687 L
.44677 .91278 L
.44658 .91291 L
.43687 .91962 L
.43298 .92249 L
.42716 .927 L
.42077 .93221 L
.41744 .93504 L
.40972 .94192 L
.40773 .94376 L
.39953 .95163 L
Mistroke
.39802 .95314 L
.39004 .96134 L
.38831 .96319 L
.38112 .97106 L
.37859 .97391 L
.37267 .98077 L
Mfstroke
.325 g
.65762 .98077 m
.65054 .97502 L
.64539 .97106 L
.64083 .96771 L
.63154 .96134 L
.63112 .96107 L
.62141 .95509 L
.61522 .95163 L
.61169 .94978 L
.60198 .94514 L
.59423 .94192 L
.59227 .94117 L
.58256 .93787 L
.57284 .93524 L
.56313 .93327 L
.55603 .93221 L
.55342 .93197 L
.54371 .93134 L
.53399 .93138 L
.52428 .93208 L
.523 .93221 L
.51457 .93346 L
.50486 .9355 L
.49514 .93821 L
.48543 .94159 L
.48457 .94192 L
.47572 .94564 L
.46601 .95035 L
.46358 .95163 L
.45629 .95574 L
.44726 .96134 L
.44658 .96179 L
.43687 .96851 L
.43342 .97106 L
.42716 .9759 L
.42118 .98077 L
F
0 g
.65762 .98077 m
.65054 .97502 L
.64539 .97106 L
.64083 .96771 L
.63154 .96134 L
.63112 .96107 L
.62141 .95509 L
.61522 .95163 L
.61169 .94978 L
.60198 .94514 L
.59423 .94192 L
.59227 .94117 L
.58256 .93787 L
.57284 .93524 L
.56313 .93327 L
.55603 .93221 L
.55342 .93197 L
.54371 .93134 L
.53399 .93138 L
.52428 .93208 L
.523 .93221 L
.51457 .93346 L
.50486 .9355 L
.49514 .93821 L
.48543 .94159 L
.48457 .94192 L
.47572 .94564 L
.46601 .95035 L
.46358 .95163 L
.45629 .95574 L
.44726 .96134 L
.44658 .96179 L
.43687 .96851 L
.43342 .97106 L
.42716 .9759 L
.42118 .98077 L
s
.25 g
.57075 .98077 m
.56313 .97931 L
.55342 .97802 L
.54371 .9774 L
.53399 .97744 L
.52428 .97815 L
.51457 .97953 L
.50823 .98077 L
F
0 g
.57075 .98077 m
.56313 .97931 L
.55342 .97802 L
.54371 .9774 L
.53399 .97744 L
.52428 .97815 L
.51457 .97953 L
.50823 .98077 L
s
.925 g
.98077 .55685 m
.97966 .55342 L
.97652 .54371 L
.97339 .53399 L
.97106 .52682 L
.97023 .52428 L
.96704 .51457 L
.96382 .50486 L
.96134 .49747 L
.96057 .49514 L
.9573 .48543 L
.954 .47572 L
.95163 .46879 L
.95068 .46601 L
.94733 .45629 L
.94395 .44658 L
.94192 .4408 L
.94054 .43687 L
.9371 .42716 L
.93363 .41744 L
.93221 .41349 L
.93013 .40773 L
.9266 .39802 L
.92303 .38831 L
.92249 .38686 L
.91943 .37859 L
.91579 .36888 L
.91278 .36092 L
.91212 .35917 L
.90841 .34946 L
.90466 .33974 L
.90307 .33565 L
.90088 .33003 L
.89705 .32032 L
.89336 .31106 L
.89318 .31061 L
.88927 .30089 L
.8853 .29118 L
.88364 .28715 L
.8813 .28147 L
.87724 .27176 L
.87393 .26392 L
.87313 .26204 L
.86898 .25233 L
.86476 .24262 L
.86422 .24138 L
.8605 .23291 L
.85617 .22319 L
.85451 .21951 L
.85178 .21348 L
.84732 .20377 L
.84479 .19832 L
.8428 .19406 L
.83821 .18434 L
.83508 .17782 L
.83354 .17463 L
.8288 .16492 L
.82537 .15799 L
.82398 .15521 L
.81907 .14549 L
.81566 .13885 L
.81407 .13578 L
.80898 .12607 L
.80594 .12038 L
.80378 .11636 L
.79847 .10664 L
.79623 .1026 L
.79306 .09693 L
.78751 .08722 L
.78652 .0855 L
.78185 .07751 L
.77681 .06908 L
.77603 .06779 L
.77007 .05808 L
.76709 .05333 L
.76394 .04837 L
.75763 .03866 L
.75738 .03827 L
.75114 .02894 L
.74767 .02389 L
.74442 .01923 L
.98077 .01923 L
F
0 g
.98077 .55685 m
.97966 .55342 L
.97652 .54371 L
.97339 .53399 L
.97106 .52682 L
.97023 .52428 L
.96704 .51457 L
.96382 .50486 L
.96134 .49747 L
.96057 .49514 L
.9573 .48543 L
.954 .47572 L
.95163 .46879 L
.95068 .46601 L
.94733 .45629 L
.94395 .44658 L
.94192 .4408 L
.94054 .43687 L
.9371 .42716 L
.93363 .41744 L
.93221 .41349 L
.93013 .40773 L
.9266 .39802 L
.92303 .38831 L
.92249 .38686 L
.91943 .37859 L
.91579 .36888 L
.91278 .36092 L
.91212 .35917 L
.90841 .34946 L
.90466 .33974 L
.90307 .33565 L
.90088 .33003 L
.89705 .32032 L
.89336 .31106 L
.89318 .31061 L
.88927 .30089 L
.8853 .29118 L
.88364 .28715 L
.8813 .28147 L
.87724 .27176 L
.87393 .26392 L
.87313 .26204 L
.86898 .25233 L
.86476 .24262 L
.86422 .24138 L
.8605 .23291 L
.85617 .22319 L
.85451 .21951 L
.85178 .21348 L
Mistroke
.84732 .20377 L
.84479 .19832 L
.8428 .19406 L
.83821 .18434 L
.83508 .17782 L
.83354 .17463 L
.8288 .16492 L
.82537 .15799 L
.82398 .15521 L
.81907 .14549 L
.81566 .13885 L
.81407 .13578 L
.80898 .12607 L
.80594 .12038 L
.80378 .11636 L
.79847 .10664 L
.79623 .1026 L
.79306 .09693 L
.78751 .08722 L
.78652 .0855 L
.78185 .07751 L
.77681 .06908 L
.77603 .06779 L
.77007 .05808 L
.76709 .05333 L
.76394 .04837 L
.75763 .03866 L
.75738 .03827 L
.75114 .02894 L
.74767 .02389 L
.74442 .01923 L
Mfstroke
.85 g
.98077 .42872 m
.98027 .42716 L
.97714 .41744 L
.974 .40773 L
.97106 .39869 L
.97084 .39802 L
.96765 .38831 L
.96443 .37859 L
.96134 .36934 L
.96119 .36888 L
.95793 .35917 L
.95464 .34946 L
.95163 .34066 L
.95132 .33974 L
.94797 .33003 L
.9446 .32032 L
.94192 .31266 L
.9412 .31061 L
.93777 .30089 L
.93431 .29118 L
.93221 .28534 L
.93081 .28147 L
.92729 .27176 L
.92373 .26204 L
.92249 .25869 L
.92014 .25233 L
.91651 .24262 L
.91285 .23291 L
.91278 .23272 L
.90915 .22319 L
.90542 .21348 L
.90307 .20743 L
.90164 .20377 L
.89783 .19406 L
.89397 .18434 L
.89336 .18282 L
.89007 .17463 L
.88612 .16492 L
.88364 .15888 L
.88213 .15521 L
.87809 .14549 L
.874 .13578 L
.87393 .13562 L
.86986 .12607 L
.86567 .11636 L
.86422 .11303 L
.86142 .10664 L
.85711 .09693 L
.85451 .09113 L
.85274 .08722 L
.84831 .07751 L
.84479 .0699 L
.84381 .06779 L
.83925 .05808 L
.83508 .04935 L
.83461 .04837 L
.8299 .03866 L
.82537 .02947 L
.82511 .02894 L
.82023 .01923 L
.98077 .01923 L
F
0 g
.98077 .42872 m
.98027 .42716 L
.97714 .41744 L
.974 .40773 L
.97106 .39869 L
.97084 .39802 L
.96765 .38831 L
.96443 .37859 L
.96134 .36934 L
.96119 .36888 L
.95793 .35917 L
.95464 .34946 L
.95163 .34066 L
.95132 .33974 L
.94797 .33003 L
.9446 .32032 L
.94192 .31266 L
.9412 .31061 L
.93777 .30089 L
.93431 .29118 L
.93221 .28534 L
.93081 .28147 L
.92729 .27176 L
.92373 .26204 L
.92249 .25869 L
.92014 .25233 L
.91651 .24262 L
.91285 .23291 L
.91278 .23272 L
.90915 .22319 L
.90542 .21348 L
.90307 .20743 L
.90164 .20377 L
.89783 .19406 L
.89397 .18434 L
.89336 .18282 L
.89007 .17463 L
.88612 .16492 L
.88364 .15888 L
.88213 .15521 L
.87809 .14549 L
.874 .13578 L
.87393 .13562 L
.86986 .12607 L
.86567 .11636 L
.86422 .11303 L
.86142 .10664 L
.85711 .09693 L
.85451 .09113 L
.85274 .08722 L
Mistroke
.84831 .07751 L
.84479 .0699 L
.84381 .06779 L
.83925 .05808 L
.83508 .04935 L
.83461 .04837 L
.8299 .03866 L
.82537 .02947 L
.82511 .02894 L
.82023 .01923 L
Mfstroke
.775 g
.98077 .33489 m
.97921 .33003 L
.97608 .32032 L
.97293 .31061 L
.97106 .30485 L
.96976 .30089 L
.96656 .29118 L
.96334 .28147 L
.96134 .2755 L
.96009 .27176 L
.95682 .26204 L
.95352 .25233 L
.95163 .24682 L
.95019 .24262 L
.94684 .23291 L
.94345 .22319 L
.94192 .21881 L
.94004 .21348 L
.9366 .20377 L
.93313 .19406 L
.93221 .19149 L
.92963 .18434 L
.92609 .17463 L
.92253 .16492 L
.92249 .16483 L
.91892 .15521 L
.91529 .14549 L
.91278 .13886 L
.91161 .13578 L
.90791 .12607 L
.90416 .11636 L
.90307 .11356 L
.90037 .10664 L
.89654 .09693 L
.89336 .08893 L
.89267 .08722 L
.88876 .07751 L
.8848 .06779 L
.88364 .06498 L
.88079 .05808 L
.87674 .04837 L
.87393 .04171 L
.87264 .03866 L
.86848 .02894 L
.86427 .01923 L
.98077 .01923 L
F
0 g
.98077 .33489 m
.97921 .33003 L
.97608 .32032 L
.97293 .31061 L
.97106 .30485 L
.96976 .30089 L
.96656 .29118 L
.96334 .28147 L
.96134 .2755 L
.96009 .27176 L
.95682 .26204 L
.95352 .25233 L
.95163 .24682 L
.95019 .24262 L
.94684 .23291 L
.94345 .22319 L
.94192 .21881 L
.94004 .21348 L
.9366 .20377 L
.93313 .19406 L
.93221 .19149 L
.92963 .18434 L
.92609 .17463 L
.92253 .16492 L
.92249 .16483 L
.91892 .15521 L
.91529 .14549 L
.91278 .13886 L
.91161 .13578 L
.90791 .12607 L
.90416 .11636 L
.90307 .11356 L
.90037 .10664 L
.89654 .09693 L
.89336 .08893 L
.89267 .08722 L
.88876 .07751 L
.8848 .06779 L
.88364 .06498 L
.88079 .05808 L
.87674 .04837 L
.87393 .04171 L
.87264 .03866 L
.86848 .02894 L
.86427 .01923 L
s
.7 g
.98077 .25713 m
.97923 .25233 L
.9761 .24262 L
.97295 .23291 L
.97106 .2271 L
.96978 .22319 L
.96658 .21348 L
.96336 .20377 L
.96134 .19774 L
.96011 .19406 L
.95684 .18434 L
.95354 .17463 L
.95163 .16906 L
.95021 .16492 L
.94686 .15521 L
.94347 .14549 L
.94192 .14106 L
.94006 .13578 L
.93662 .12607 L
.93315 .11636 L
.93221 .11373 L
.92965 .10664 L
.92612 .09693 L
.92255 .08722 L
.92249 .08707 L
.91895 .07751 L
.91531 .06779 L
.91278 .06109 L
.91164 .05808 L
.90793 .04837 L
.90418 .03866 L
.90307 .03578 L
.9004 .02894 L
.89657 .01923 L
.98077 .01923 L
F
0 g
.98077 .25713 m
.97923 .25233 L
.9761 .24262 L
.97295 .23291 L
.97106 .2271 L
.96978 .22319 L
.96658 .21348 L
.96336 .20377 L
.96134 .19774 L
.96011 .19406 L
.95684 .18434 L
.95354 .17463 L
.95163 .16906 L
.95021 .16492 L
.94686 .15521 L
.94347 .14549 L
.94192 .14106 L
.94006 .13578 L
.93662 .12607 L
.93315 .11636 L
.93221 .11373 L
.92965 .10664 L
.92612 .09693 L
.92255 .08722 L
.92249 .08707 L
.91895 .07751 L
.91531 .06779 L
.91278 .06109 L
.91164 .05808 L
.90793 .04837 L
.90418 .03866 L
.90307 .03578 L
.9004 .02894 L
.89657 .01923 L
s
.625 g
.98077 .18925 m
.97919 .18434 L
.97607 .17463 L
.97292 .16492 L
.97106 .15922 L
.96974 .15521 L
.96654 .14549 L
.96332 .13578 L
.96134 .12987 L
.96007 .12607 L
.9568 .11636 L
.9535 .10664 L
.95163 .10118 L
.95017 .09693 L
.94682 .08722 L
.94344 .07751 L
.94192 .07318 L
.94003 .06779 L
.93659 .05808 L
.93311 .04837 L
.93221 .04584 L
.92961 .03866 L
.92608 .02894 L
.92251 .01923 L
.98077 .01923 L
F
0 g
.98077 .18925 m
.97919 .18434 L
.97607 .17463 L
.97292 .16492 L
.97106 .15922 L
.96974 .15521 L
.96654 .14549 L
.96332 .13578 L
.96134 .12987 L
.96007 .12607 L
.9568 .11636 L
.9535 .10664 L
.95163 .10118 L
.95017 .09693 L
.94682 .08722 L
.94344 .07751 L
.94192 .07318 L
.94003 .06779 L
.93659 .05808 L
.93311 .04837 L
.93221 .04584 L
.92961 .03866 L
.92608 .02894 L
.92251 .01923 L
s
.55 g
.98077 .12823 m
.98008 .12607 L
.97695 .11636 L
.97381 .10664 L
.97106 .0982 L
.97064 .09693 L
.96745 .08722 L
.96423 .07751 L
.96134 .06885 L
.96099 .06779 L
.95773 .05808 L
.95443 .04837 L
.95163 .04016 L
.95112 .03866 L
.94777 .02894 L
.9444 .01923 L
.98077 .01923 L
F
0 g
.98077 .12823 m
.98008 .12607 L
.97695 .11636 L
.97381 .10664 L
.97106 .0982 L
.97064 .09693 L
.96745 .08722 L
.96423 .07751 L
.96134 .06885 L
.96099 .06779 L
.95773 .05808 L
.95443 .04837 L
.95163 .04016 L
.95112 .03866 L
.94777 .02894 L
.9444 .01923 L
s
.475 g
.98077 .07234 m
.97931 .06779 L
.97618 .05808 L
.97303 .04837 L
.97106 .04231 L
.96986 .03866 L
.96666 .02894 L
.96344 .01923 L
.98077 .01923 L
F
0 g
.98077 .07234 m
.97931 .06779 L
.97618 .05808 L
.97303 .04837 L
.97106 .04231 L
.96986 .03866 L
.96666 .02894 L
.96344 .01923 L
s
.4 g
.98077 .02046 m
.98038 .01923 L
.98077 .01923 L
F
0 g
.98077 .02046 m
.98038 .01923 L
s
0 0 0 r
.055 w
.97615 .78218 Mdot
1 0 0 r
.0325 w
.01923 .78218 Mdot
.33376 .98077 Mdot
.09569 .83046 Mdot
.09387 .82807 Mdot
.09362 .82644 Mdot
.09393 .82297 Mdot
.09632 .8104 Mdot
.10406 .77863 Mdot
.12415 .70608 Mdot
.15138 .61887 Mdot
.18885 .51574 Mdot
.23888 .40789 Mdot
.28612 .33284 Mdot
.43914 .01923 Mdot
.32316 .25693 Mdot
.3972 .14482 Mdot
.41216 .16272 Mdot
.4853 .09751 Mdot
.51903 .09174 Mdot
.55478 .1236 Mdot
.73328 .10879 Mdot
.60102 .11976 Mdot
.77977 .1353 Mdot
.62642 .12197 Mdot
.64436 .131 Mdot
.68691 .16706 Mdot
.71627 .21143 Mdot
.77675 .28393 Mdot
.74607 .24715 Mdot
.79814 .33134 Mdot
.81778 .38714 Mdot
.88192 .50422 Mdot
.84028 .42821 Mdot
.98077 .70079 Mdot
.86308 .47245 Mdot
.87973 .50865 Mdot
.89227 .54117 Mdot
.91278 .59902 Mdot
.94789 .689 Mdot
.92666 .6346 Mdot
.95084 .70243 Mdot
.95722 .72523 Mdot
.97033 .76336 Mdot
.97315 .77253 Mdot
.97559 .78038 Mdot
.97612 .78208 Mdot
.97614 .78213 Mdot
.97616 .78219 Mdot
.97615 .78217 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
0 1 0 r
.02 w
.01923 .78218 Mdot
.01923 .78218 Mdot
.01923 .78218 Mdot
.01923 .78218 Mdot
.33376 .98077 Mdot
.33376 .98077 Mdot
.33376 .98077 Mdot
.33376 .98077 Mdot
.09569 .83046 Mdot
.09569 .83046 Mdot
.09569 .83046 Mdot
.09569 .83046 Mdot
.09387 .82807 Mdot
.09387 .82807 Mdot
.09387 .82807 Mdot
.09387 .82807 Mdot
.09362 .82644 Mdot
.09362 .82644 Mdot
.09362 .82644 Mdot
.09362 .82644 Mdot
.09393 .82297 Mdot
.09393 .82297 Mdot
.09393 .82297 Mdot
.09393 .82297 Mdot
.09632 .8104 Mdot
.09632 .8104 Mdot
.09632 .8104 Mdot
.09632 .8104 Mdot
.10406 .77863 Mdot
.10406 .77863 Mdot
.10406 .77863 Mdot
.10406 .77863 Mdot
.12415 .70608 Mdot
.12415 .70608 Mdot
.12415 .70608 Mdot
.12415 .70608 Mdot
.15138 .61887 Mdot
.15138 .61887 Mdot
.15138 .61887 Mdot
.15138 .61887 Mdot
.18885 .51574 Mdot
.18885 .51574 Mdot
.18885 .51574 Mdot
.18885 .51574 Mdot
.23888 .40789 Mdot
.23888 .40789 Mdot
.23888 .40789 Mdot
.23888 .40789 Mdot
.28612 .33284 Mdot
.28612 .33284 Mdot
.28612 .33284 Mdot
.28612 .33284 Mdot
.43914 .01923 Mdot
.43914 .01923 Mdot
.43914 .01923 Mdot
.43914 .01923 Mdot
.32316 .25693 Mdot
.32316 .25693 Mdot
.32316 .25693 Mdot
.32316 .25693 Mdot
.3972 .14482 Mdot
.3972 .14482 Mdot
.3972 .14482 Mdot
.3972 .14482 Mdot
.41216 .16272 Mdot
.41216 .16272 Mdot
.41216 .16272 Mdot
.41216 .16272 Mdot
.4853 .09751 Mdot
.4853 .09751 Mdot
.4853 .09751 Mdot
.4853 .09751 Mdot
.51903 .09174 Mdot
.51903 .09174 Mdot
.51903 .09174 Mdot
.51903 .09174 Mdot
.55478 .1236 Mdot
.55478 .1236 Mdot
.55478 .1236 Mdot
.55478 .1236 Mdot
.73328 .10879 Mdot
.73328 .10879 Mdot
.73328 .10879 Mdot
.73328 .10879 Mdot
.60102 .11976 Mdot
.60102 .11976 Mdot
.60102 .11976 Mdot
.60102 .11976 Mdot
.77977 .1353 Mdot
.77977 .1353 Mdot
.77977 .1353 Mdot
.77977 .1353 Mdot
.62642 .12197 Mdot
.62642 .12197 Mdot
.62642 .12197 Mdot
.62642 .12197 Mdot
.64436 .131 Mdot
.64436 .131 Mdot
.64436 .131 Mdot
.64436 .131 Mdot
.68691 .16706 Mdot
.68691 .16706 Mdot
.68691 .16706 Mdot
.68691 .16706 Mdot
.71627 .21143 Mdot
.71627 .21143 Mdot
.71627 .21143 Mdot
.71627 .21143 Mdot
.77675 .28393 Mdot
.77675 .28393 Mdot
.77675 .28393 Mdot
.77675 .28393 Mdot
.74607 .24715 Mdot
.74607 .24715 Mdot
.74607 .24715 Mdot
.74607 .24715 Mdot
.79814 .33134 Mdot
.79814 .33134 Mdot
.79814 .33134 Mdot
.79814 .33134 Mdot
.81778 .38714 Mdot
.81778 .38714 Mdot
.81778 .38714 Mdot
.81778 .38714 Mdot
.88192 .50422 Mdot
.88192 .50422 Mdot
.88192 .50422 Mdot
.88192 .50422 Mdot
.84028 .42821 Mdot
.84028 .42821 Mdot
.84028 .42821 Mdot
.84028 .42821 Mdot
.98077 .70079 Mdot
.98077 .70079 Mdot
.98077 .70079 Mdot
.98077 .70079 Mdot
.86308 .47245 Mdot
.86308 .47245 Mdot
.86308 .47245 Mdot
.86308 .47245 Mdot
.87973 .50865 Mdot
.87973 .50865 Mdot
.87973 .50865 Mdot
.87973 .50865 Mdot
.89227 .54117 Mdot
.89227 .54117 Mdot
.89227 .54117 Mdot
.89227 .54117 Mdot
.91278 .59902 Mdot
.91278 .59902 Mdot
.91278 .59902 Mdot
.91278 .59902 Mdot
.94789 .689 Mdot
.94789 .689 Mdot
.94789 .689 Mdot
.94789 .689 Mdot
.92666 .6346 Mdot
.92666 .6346 Mdot
.92666 .6346 Mdot
.92666 .6346 Mdot
.95084 .70243 Mdot
.95084 .70243 Mdot
.95084 .70243 Mdot
.95084 .70243 Mdot
.95722 .72523 Mdot
.95722 .72523 Mdot
.95722 .72523 Mdot
.95722 .72523 Mdot
.97033 .76336 Mdot
.97033 .76336 Mdot
.97033 .76336 Mdot
.97033 .76336 Mdot
.97315 .77253 Mdot
.97315 .77253 Mdot
.97315 .77253 Mdot
.97315 .77253 Mdot
.97559 .78038 Mdot
.97559 .78038 Mdot
.97559 .78038 Mdot
.97559 .78038 Mdot
.97612 .78208 Mdot
.97612 .78208 Mdot
.97612 .78208 Mdot
.97612 .78208 Mdot
.97614 .78213 Mdot
.97614 .78213 Mdot
.97614 .78213 Mdot
.97614 .78213 Mdot
.97616 .78219 Mdot
.97616 .78219 Mdot
.97616 .78219 Mdot
.97616 .78219 Mdot
.97615 .78217 Mdot
.97615 .78217 Mdot
.97615 .78217 Mdot
.97615 .78217 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
0 0 1 r
.5 Mabswid
.01923 .78218 m
.01923 .78218 L
.09569 .83046 L
.09387 .82807 L
.09362 .82644 L
.09393 .82297 L
.09632 .8104 L
.10406 .77863 L
.12415 .70608 L
.15138 .61887 L
.18885 .51574 L
.23888 .40789 L
.28612 .33284 L
.32316 .25693 L
.3972 .14482 L
.41216 .16272 L
.4853 .09751 L
.51903 .09174 L
.55478 .1236 L
.60102 .11976 L
.62642 .12197 L
.64436 .131 L
.68691 .16706 L
.71627 .21143 L
.74607 .24715 L
.79814 .33134 L
.81778 .38714 L
.84028 .42821 L
.86308 .47245 L
.87973 .50865 L
.89227 .54117 L
.91278 .59902 L
.92666 .6346 L
.95084 .70243 L
.95722 .72523 L
.97033 .76336 L
.97315 .77253 L
.97559 .78038 L
.97612 .78208 L
.97614 .78213 L
.97616 .78219 L
.97615 .78217 L
.97615 .78218 L
s
.015 w
.01923 .78218 Mdot
.01923 .78218 Mdot
.09569 .83046 Mdot
.09387 .82807 Mdot
.09362 .82644 Mdot
.09393 .82297 Mdot
.09632 .8104 Mdot
.10406 .77863 Mdot
.12415 .70608 Mdot
.15138 .61887 Mdot
.18885 .51574 Mdot
.23888 .40789 Mdot
.28612 .33284 Mdot
.32316 .25693 Mdot
.3972 .14482 Mdot
.41216 .16272 Mdot
.4853 .09751 Mdot
.51903 .09174 Mdot
.55478 .1236 Mdot
.60102 .11976 Mdot
.62642 .12197 Mdot
.64436 .131 Mdot
.68691 .16706 Mdot
.71627 .21143 Mdot
.74607 .24715 Mdot
.79814 .33134 Mdot
.81778 .38714 Mdot
.84028 .42821 Mdot
.86308 .47245 Mdot
.87973 .50865 Mdot
.89227 .54117 Mdot
.91278 .59902 Mdot
.92666 .6346 Mdot
.95084 .70243 Mdot
.95722 .72523 Mdot
.97033 .76336 Mdot
.97315 .77253 Mdot
.97559 .78038 Mdot
.97612 .78208 Mdot
.97614 .78213 Mdot
.97616 .78219 Mdot
.97615 .78217 Mdot
.97615 .78218 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{288, 288},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00B`3oool7000004P0oooo1000
00060?ooo`8000001P3oool4000004D0oooo1000001:0?ooo`@000001P3oool2000000H0oooo1000
00180?ooo`L00000203oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool02@3oool004h0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool02@3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool02@3oool00480oooo1P0000060?ooo`030000
003oool0oooo03l0oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`090?ooo`00CP3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool4000004@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool4000004/0oooo00<000000?ooo`3oool02@3oool004h0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02@3oool0
04`0oooo0`00001:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0BP3oool30000
00/0oooo001>0?ooo`030000003oool0oooo04T0oooo1000000>0?ooo`D00000A03oool4000004X0
oooo1000000>0?ooo`D00000BP3oool00`000000oooo0?ooo`090?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`007`3ooooo0000094000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
:P3oool20?l002L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo00H0oooo0@0000010?ooo`007`3oool300000:T0oooo203o003J0?ooo`8000000@3o
ool001l0oooo00<000000?ooo`3oool0Z03oool:0?l00=X0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`2X0?ooo`<0o`000`00o`040?l00=X0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`2X0?ooo`80o`001@00o`030?l00=X0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01/0oooo0P3o0007003o00<0o`00L`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?oooaL0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001i
NGT0NGUi00@0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO09nOW`0609nOW`030000002c
/k<0/k>c00L0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/
k>`0k>c/01h0k>c/00<000000?ooo`3oool06`3oool20?l000L00?l00`3o001d0?ooo`030000003/
k>`0k>c/01/0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c
/k<0/k>c00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00508b<S0030000001i
NGT0NGUi00@0NGUi00<000000?ooo`3oool0103oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo5P0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00@0IVIV00<00000
07UiN@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<00000
0;>c/`2c/k<0202c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00h0fMWI00<00000
0>c/k03/k>`07@3/k>`00`000000oooo0?ooo`0M0?ooo`030?l00000o`000?l000D00?l00P3o001f
0?ooo`030000003/k>`0k>c/01/0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0:
0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil00`000000S8b<08b<S005
08b<S0030000001iNGT0NGUi00@0NGUi1`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo5P0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007Ui
N@1iNGT0101iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00H0WinO00<000000;>c
/`2c/k<01`2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/
k03/k>`07P3/k>`00`000000oooo0?ooo`0M0?ooo`80o`001@00o`030?l007H0oooo00<000000>c/
k03/k>`06`3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600X0a/K600<000000;>c
/`2c/k<01`2c/k<00`000000WinO09nOW`0609nOW`030000002<S8`0S8b<00D0S8b<00<0000007Ui
N@1iNGT00`1iNGT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3ooolF03lo?`03
0000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@03
0000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`070;>c/`03
00000036a/H0a/K600X0a/K600<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00M0>c/k003
0000003oool0oooo01h0oooo0`3o0003003o00@0o`00M`3oool00`000000k>c/0>c/k00K0>c/k003
0000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02P36a/H00`000000/k>c0;>c/`070;>c/`03
0000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000NGUi07UiN@0307UiN@L0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oooaH0?clo00<0000005=CD`1CDe<0
0P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0
1@2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00P0/k>c00<000000<K6aP36a/H0
2P36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/01`0k>c/00<000000?ooo`3oool0
803oool80?l007T0oooo00<000000>c/k03/k>`06P3/k>`00`000000fMWI0=WIf@0>0=WIf@030000
0036a/H0a/K600X0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`030000
002<S8`0S8b<00D0S8b<00<0000007UiN@1iNGT00`1iNGT70?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3ooolE03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1V
IVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01P2O
Wil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3IfMT03`3I
fMT00`000000k>c/0>c/k00M0>c/k0030000003oool0oooo02<0oooo0P3o001l0?ooo`030000003/
k>`0k>c/01X0k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c
/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00408b<S0030000001i
NGT0NGUi00<0NGUi1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo5@0o?cl0
0`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT0
0`000000S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<0202c/k<0
0`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`0703/k>`0
0`000000oooo0?ooo`2S0?ooo`030000003/k>`0k>c/01X0k>c/00<000000=WIf@3IfMT03P3IfMT0
0`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil0
0`000000S8b<08b<S00508b<S0030000001iNGT0NGUi0080NGUi1`3oool100000040oooo000O0?oo
o`030000003oool0oooo00D0oooo5@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV
00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO
00D0WinO00<000000;>c/`2c/k<0202c/k<00`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI
00h0fMWI00<000000>c/k03/k>`0703/k>`00`000000oooo0?ooo`2U0?ooo`030000003/k>`0k>c/
01T0k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c
00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00408b<S0030000001iNGT0NGUi
0080NGUi1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo5@0o?cl00`000000
De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000
S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c/k<00`000000
a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`06`3/k>`00`000000
oooo0?ooo`2V0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03`3IfMT00`000000
a/K60<K6aP090<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000
S8b<08b<S00408b<S0030000001iNGT0NGUi0080NGUi1`3oool100000040oooo000O0?ooo`<00000
1@3ooolD03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi
07UiN@0507UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c
0;>c/`080;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/
0>c/k00L0>c/k0030000003oool0oooo0:L0oooo00<000000>c/k03/k>`06@3/k>`00`000000fMWI
0=WIf@0>0=WIf@0300000036a/H0a/K600X0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO
09nOW`0509nOW`030000002<S8`0S8b<00D0S8b<00@0000007UiN@1iNGT0NGUi1P3oool200000040
oooo000O0?ooo`030000003oool0oooo00D0oooo500o?cl00`000000De=C05=CD`0205=CD`030000
001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000
002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP0;0<K6aP030000
003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`06`3/k>`00`000000oooo0?ooo`2X0?ooo`030000
003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP090<K6aP030000
002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00408b<S0040000
001iNGT0NGUi07UiN@L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oooa<0?clo
0P00000405=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`000000S8b<
08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K6
0<K6aP0:0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`06`3/k>`00`000000oooo
0?ooo`2Y0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K6
0<K6aP0:0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil00`000000S8b<
08b<S00508b<S0030000001iNGT0NGUi00L0oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?oooa<0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0306IVIP030000001i
NGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO09nOW`0609nOW`030000002c
/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/
k>`0k>c/01/0k>c/00<000000?ooo`3oool0ZP3oool00`000000k>c/0>c/k00J0>c/k0030000003I
fMT0fMWI00d0fMWI00<000000<K6aP36a/H02P36a/H00`000000/k>c0;>c/`070;>c/`030000002O
Wil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000NGUi07UiN@070?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3ooolB03lo?`030000001CDe<0De=C00<0De=C00<00000
06IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00@0S8b<00<00000
09nOW`2OWil01P2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600X0a/K600<00000
0=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00J0>c/k0030000003oool0oooo0:`0oooo00<00000
0>c/k03/k>`06@3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600T0a/K600<00000
0;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0S8b<00D0S8b<00<00000
07UiN@1iNGT01`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo4P0o?cl00`00
0000De=C05=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`00
0000S8b<08b<S00508b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c/k<00`00
0000a/K60<K6aP090<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`06`3/k>`00`00
0000oooo0?ooo`2]0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT03@3IfMT00`00
0000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil00`00
0000S8b<08b<S00508b<S0030000001iNGT0oooo00H0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?oooa80?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0306IVIP03
0000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO09nOW`0609nOW`03
0000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0?0=WIf@03
0000003/k>`0k>c/01X0k>c/00<000000?ooo`3oool0[`3oool00`000000k>c/0>c/k00H0>c/k003
0000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`070;>c/`03
0000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000NGUi0?ooo`060?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3ooolB03lo?`030000001CDe<0De=C0080De=C
00<0000006IVIP1VIVH0101VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00D0S8b<
00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600X0a/K6
00<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00J0>c/k0030000003oool0oooo0;00oooo
00<000000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600X0a/K6
00<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0S8b<00D0S8b<
00<0000007UiN@3oool01P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo4@0o
?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1i
NGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01`2c
/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`06P3/
k>`00`000000oooo0?ooo`2a0?ooo`030000003/k>`0k>c/01P0k>c/00<000000=WIf@3IfMT03P3I
fMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2O
Wil00`000000S8b<08b<S00408b<S0030000001iNGT0oooo00H0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?oooa40?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP03
06IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO09nOW`05
09nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@0>
0=WIf@030000003/k>`0k>c/01X0k>c/00<000000?ooo`3oool0/P3oool00`000000k>c/0>c/k00H
0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02P36a/H00`000000/k>c0;>c/`06
0;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000oooo0?ooo`05
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3ooolA03lo?`030000001CDe<0De=C
00<0De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<
00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K6
00X0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00J0>c/k0030000003oool0oooo
0;<0oooo00<000000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K6
00X0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0609nOW`030000002<S8`0S8b<
00@0S8b<00<000000?ooo`3oool01@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo4@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1i
NGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c
/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/
k>`06P3/k>`00`000000oooo0?ooo`2d0?ooo`030000003/k>`0k>c/01P0k>c/00<000000=WIf@3I
fMT03@3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2O
Wil01P2OWil00`000000S8b<08b<S00408b<S0030000003oool0oooo00D0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`050?oooa00?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV
06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`01@2<S8`00`000000WinO
09nOW`0609nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI
0=WIf@0>0=WIf@030000003/k>`0k>c/01T0k>c/00<000000?ooo`3oool0]P3oool00`000000k>c/
0>c/k00H0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c
0;>c/`070;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`01@2<S8`00`000000oooo
0?ooo`040?ooo`4000000@3oool001l0oooo0`0000050?oooa00?clo00<0000005=CD`1CDe<00P1C
De<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0102<
S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36
a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/01X0k>c/00<000000?ooo`3oool0]P3o
ool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02P36
a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00H0WinO00<0000008b<S02<S8`0102<
S8`60?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool@03lo?`030000001CDe<0
De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0
S8b<00@0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0
a/K600T0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00I0>c/k0030000003oool0
oooo04l0oooo0P3o001W0?ooo`030000003/k>`0k>c/01P0k>c/00<000000=WIf@3IfMT03@3IfMT0
0`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil0
0`000000S8b<08b<S00408b<S0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
oa00?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi
00@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c
00L0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/
01T0k>c/00<000000?ooo`3oool0C@3oool80?l006D0oooo00<000000>c/k03/k>`05`3/k>`00`00
0000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01`2c/k<00`00
0000WinO09nOW`0509nOW`030000002<S8`0S8b<00@0S8b<1`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo400o?cl01@000000De=C05=CD`1CDe<0000000D0IVIV00<0000007Ui
N@1iNGT0101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c
/`2c/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/
k03/k>`06@3/k>`00`000000oooo0?ooo`1<0?ooo`X0o`00I03oool00`000000k>c/0>c/k00H0>c/
k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`070;>c
/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`0102<S8`70?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool?03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1V
IVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2O
Wil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3I
fMT03@3IfMT00`000000k>c/0>c/k00I0>c/k0030000003oool0oooo04<0oooo0P3o00080?ooo`<0
o`000`00o`040?l006D0oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI0=WIf@0=0=WIf@03
00000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`03
0000002<S8`0S8b<00<0S8b<1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
3`0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0
101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<0
1`2c/k<00`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`0
6@3/k>`00`000000oooo0?ooo`100?ooo`P0o`001@3oool20?l00005003o00000?l0003o0000o`00
o`000`3o001V0?ooo`030000003/k>`0k>c/01L0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000
a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil00`000000
S8b<08b<S00308b<S0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`l0?clo
00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00@0NGUi
00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00L0/k>c
00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/01P0k>c/
00<000000?ooo`3oool0@03oool40?l000<00?l00`3o00030?ooo`80o`0000<00?l00000o`000?l0
0`000?l01000o`00o`000?l0003o001V0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3I
fMT03@3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2O
Wil01P2OWil00`000000S8b<08b<S00208b<S0L0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`h0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0206IVIP030000
001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000
002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@0=0=WIf@030000
003/k>`0k>c/01T0k>c/00<000000?ooo`3oool0@03oool30?l00005003o00000?l0003o0000o`00
o`000P3o00020?ooo`T0003o00@00?l00?l0003o0000o`00IP3oool00`000000k>c/0>c/k00F0>c/
k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`070;>c
/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`00P2<S8`70?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool>03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1V
IVH00`1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2O
Wil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3I
fMT03P3IfMT00`000000k>c/0>c/k00H0>c/k0030000003oool0oooo0440oooo0P3o00000`00o`00
003o0000o`070000o`80oooo00<0o`00003o00000?l010000?l00`00o`00o`000?l0001?0?ooo`80
o`005`3oool00`000000k>c/0>c/k00F0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36
a/H02@36a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00H0WinO00@0000008b<S02<
S8`0S8b<1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo3P0o?cl00`000000
De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000
S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01`2c/k<00`000000
a/K60<K6aP090<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`0603/k>`00`000000
oooo0?ooo`110?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l000030?ooo`80
o`0000D00?l00000o`000?l0003o003o00020000o`030?l0003oool0oooo04X0oooo203o000D0?oo
o`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP090<K6
aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil010000000S8b<08b<S02<S8`7
0?ooo`4000000@3oool001@0oooo100000070?ooo`030000003oool0oooo00D0oooo3@0o?cl00`00
0000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT0101iNGT00`00
0000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01P2c/k<00`00
0000a/K60<K6aP090<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`0603/k>`00`00
0000oooo0?ooo`110?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l000030?oo
o`<0o`000`00o`030?l000030000o`3oool0oooo04T0oooo2P3o000D0?ooo`030000003/k>`0k>c/
01H0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c
00L0/k>c00<0000009nOW`2OWil01@2OWil010000000S8b<08b<S02<S8`70?ooo`4000000@3oool0
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo3@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007Ui
N@1iNGT00`1iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<000000;>c
/`2c/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/
k03/k>`0603/k>`00`000000oooo0?ooo`130?ooo`<0o`0010000?l00`00o`00o`000?l000050?oo
o`P0o`0000<0oooo0000o`3oool0B@3oool40?l000<00?l00`3o000D0?ooo`030000003/k>`0k>c/
01H0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c
00H0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S0070?ooo`4000000@3oool001<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo3@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1i
NGT00`1iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c
/k<01`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/
k>`0603/k>`00`000000oooo0?ooo`130?ooo`80o`0000<0003o0?l00000o`000P00o`030?l000P0
oooo0P3o00050?ooo`030000o`3oool0oooo04L0oooo0`3o0005003o0080o`005@3oool00`000000
k>c/0>c/k00F0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02036a/H00`000000
/k>c0;>c/`070;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`01`3oool100000040
oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool4000000@0oooo
3@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1iNGT0
101iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<0
1P2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`0
603/k>`00`000000oooo0?ooo`140?ooo`80003o203o000@0?ooo`030000o`3oool0oooo01D0oooo
0P3o00080?ooo`80o`00903oool30?l000L00?l00P3o000D0?ooo`030000003/k>`0k>c/01H0k>c/
00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0/k>c
00<0000009nOW`2OWil01@2OWil00`000000S8b<08b<S0050?ooo`<000000@3oool001<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo300o
?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1i
NGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01`2c
/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`0603/
k>`00`000000oooo0?ooo`130?ooo`030000o`3oool0o`0000L0o`004P3oool00`000?l0oooo0?oo
o`020?ooo`80o`003@3oool80?l00080oooo203o000Q0?ooo`<0o`001`00o`020?l001D0oooo00<0
00000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600P0a/K600<0
00000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0S8b<00L0oooo0@00
00010?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool<03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH0
0`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01P2OWil0
0`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT0
0`000000k>c/0>c/k00H0>c/k0030000003oool0oooo04<0oooo00<0003o0?ooo`3oool00`3oool2
0?l001H0oooo00<0003o0?l0003o00001P3o00090?ooo`@0o`000`00o`0=0?l00240oooo0P3o0007
003o00030?l0003oool0oooo01@0oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0=
0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`05
09nOW`030000002<S8`0oooo00H0oooo0@0000010?ooo`004`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool<03lo?`030000001CDe<0De=C
0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<
00@0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K6
00T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00H0>c/k0030000003oool0oooo
0480oooo00<0003o0?ooo`3oool0703oool00`3o0000003o0000o`070?l000P0oooo0`3o00001@00
o`00003o0000o`000?l00?l000H0o`000`00o`030?l00240oooo0`3o0005003o0080o`005`3oool0
0`000000k>c/0>c/k00F0>c/k0030000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02@36a/H0
0`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00D0WinO00<0000008b<S03oool01P3oool1
00000040oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`/0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0306IV
IP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nO
W`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0=0=WI
f@030000003/k>`0k>c/01L0k>c/00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0M0?oo
o`<0o`0000<0003o003o0000o`00103o00080?ooo`80o`0000<00?l00000o`000?l00`000?l00`00
o`00o`000?l000020?l00005003o00000?l0003o0000o`00o`000P3o00020?ooo`80o`007@3oool4
0?l000<00?l00`3o000G0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT0303IfMT0
0`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01@2OWil0
0`000000S8b<0?ooo`060?ooo`4000000@3oool001@0oooo100000070?ooo`030000003oool0oooo
00D0oooo2`0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007Ui
N@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00H0WinO00<000000;>c
/`2c/k<01P2c/k<00`000000a/K60<K6aP0:0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/
k03/k>`05`3/k>`00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo01h0oooo0P3o00001@00
o`00003o0000o`000?l00?l000<0o`001@3ooolE0000o`03003o003o0000o`0000H0o`006`3oool8
0?l001T0oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0
a/K600P0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0
oooo00H0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`X0?clo00<0000005=C
D`1CDe<00`1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<
S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6
aP36a/H02@36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/01L0k>c/00<000000?oo
o`3oool0@@3oool00`000?l0oooo0?ooo`0N0?ooo`80o`0000<00?l00000o`000?l02`000?l20?oo
o`<0o`0000<00?l00000o`000?l00`000?l01@00o`00o`000?l0003o00000?l000D0003o00<00?l0
0?l0003o00001`3o000M0?ooo`80o`004@3oool20?l000T0oooo00<000000>c/k03/k>`05P3/k>`0
0`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<01P2c/k<0
0`000000WinO09nOW`0509nOW`030000003oool0oooo00D0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`X0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0306IV
IP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nO
W`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0<0=WI
f@030000003/k>`0k>c/01P0k>c/00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0O0?oo
o`80o`0000<00?l00000o`000?l00`000?l01000o`00o`000?l0003o00070?ooo`<0o`0000D00?l0
0000o`000?l0003o003o00040?l00003003o00000?l0003o00D0003o00@0o`00003o0000o`000?l0
103o000]0?ooo`P0o`001`3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI00d0fMWI
00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00D0WinO
00<000000?ooo`3oool01@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo2P0o
?cl00`000000De=C05=CD`0305=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1iNGT00`1i
NGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c
/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`05`3/
k>`00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo0240oooo00<0o`00003o00000?l01000
0?l00`00o`00o`000?l000080?ooo`@0o`000`00o`060?l00005003o00000?l0003o0000o`00o`00
0P3o00040000o`04003o003o0000o`000?l002`0oooo0`3o0003003o00@0o`001P3oool00`000000
k>c/0>c/k00E0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02036a/H00`000000
/k>c0;>c/`060;>c/`030000002OWil0WinO00H0WinO00<000000?ooo`3oool0103oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo2@0o?cl00`000000De=C05=CD`0305=CD`030000
001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000
002OWil0WinO00H0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP090<K6aP030000
003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`0603/k>`00`000000oooo0?ooo`0n0?ooo`80003o
903oool20?l00005003o00000?l0003o0000o`00o`000`3o00080?ooo`h0o`000`00o`020?l00003
003o00000?l0003o00<0003o00@00?l00?l0003o0000o`00:`3oool20?l000D00?l00`3o00070?oo
o`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6aP080<K6
aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil01@2OWil70?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool903lo?`030000001CDe<0De=C00<0De=C00<0000006IVIP1V
IVH00P1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2O
Wil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3I
fMT03@3IfMT00`000000k>c/0>c/k00G0>c/k0030000003oool0oooo02X0oooo0P3o000B0?ooo`03
0000o`3oool0oooo02@0oooo0`3o0003003o00@0o`002@3oool80?l00080oooo203o00000`00o`00
003o0000o`030000o`04003o003o0000o`000?l002/0oooo00<0o`00003o0000o`001@00o`020?l0
00L0oooo00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K6
00P0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0509nOW`L0oooo0@0000010?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`T0?clo00<0000005=CD`1CDe<00`1CDe<00`000000
IVIV06IVIP0206IVIP030000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`0102<S8`00`000000
WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000
fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/01L0k>c/00<000000?ooo`3oool09`3oool80?l000h0
oooo00<0003o0?ooo`3oool09P3oool80?l000d0oooo0P3o00080?ooo`80o`000P3oool00`3o0000
0?l00000o`050000o`80o`00:`3oool20?l000L00?l00`3o00070?ooo`030000003/k>`0k>c/01D0
k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0
/k>c00<0000009nOW`2OWil0102OWil70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool903lo?`030000001CDe<0De=C00<0De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi
07UiN@0407UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c
0;>c/`060;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/
0>c/k00F0>c/k0030000003oool0oooo02L0oooo0`3o0003003o00@0o`00303oool00`000?l0oooo
0?ooo`0Z0?ooo`80o`007P3oool20?l00008003o00000?l0003o0000o`00o`00o`000000o`3o000[
0?ooo`80o`001`00o`030?l000P0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0=
0=WIf@0300000036a/H0a/K600L0a/K600<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`04
09nOW`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`P0?clo00<0000005=C
D`1CDe<00`1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<
S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6
aP36a/H02036a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/01L0k>c/00<000000?oo
o`3oool09`3oool20?l00005003o00000?l0003o0000o`00o`000`3o000;0?ooo`030000o`3oool0
oooo04/0oooo0`3o0003003o00<0o`0000<0003o0?ooo`3oool0:P3oool20?l000D00?l00`3o0009
0?ooo`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6aP08
0<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil0102OWil70?ooo`4000000@3oool0
01l0oooo0`0000050?ooo`P0?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0306IV
IP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nO
W`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0=0=WI
f@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0:03oool00`3o00000?l00000o`040000
o`03003o003o0000o`0000X0oooo00<0003o0?ooo`3oool0C@3oool80?l000030?ooo`000?l0oooo
02X0oooo0`3o0003003o00@0o`002P3oool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI
00d0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`070;>c/`030000002OWil0WinO
00<0WinO1P3oool200000040oooo000O0?ooo`030000003oool0oooo00D0oooo200o?cl00`000000
De=C05=CD`0305=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1iNGT0101iNGT00`000000
S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000
a/K60<K6aP090<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`05`3/k>`00`000000
oooo0?ooo`0W0?ooo`80o`0000<00?l00000o`000?l00`000?l01000o`00o`000?l0003o00080?oo
o`030000o`3oool0oooo0540oooo0P3o00050?ooo`030000o`3oool0oooo02P0oooo2P3o000:0?oo
o`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6aP080<K6
aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil00`2OWil70?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool803lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1V
IVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2O
Wil01@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3I
fMT03@3IfMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo02P0oooo0P3o00000`00o`00
003o0000o`030000o`04003o003o0000o`000?l000L0oooo00<0003o0?ooo`3oool0FP3oool20000
obT0oooo203o000;0?ooo`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT0303IfMT00`00
0000a/K60<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil00`2OWil70?oo
o`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool803lo?`030000001CDe<0De=C0080
De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00@0
S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600T0
a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00G0>c/k0030000003oool0oooo02T0
oooo0P3o00001P00o`00003o0000o`000?l00?l00000o`@0o`001@3oool00`000?l0oooo0?ooo`1M
0?ooo`030000o`3oool0oooo02T0oooo0P3o000?0?ooo`030000003/k>`0k>c/01@0k>c/00<00000
0=WIf@3IfMT0303IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00<00000
09nOW`2OWil00`2OWil70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool703lo
?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307Ui
N@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`070;>c
/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00F0>c/
k0030000003oool0oooo02X0oooo0`3o00000`000?l00?l0003o00020?l000030000o`3o0000o`00
00@0o`000P000?mQ0?ooo`030000o`3oool0oooo00<0oooo0P3o000d0?ooo`030000003/k>`0k>c/
01D0k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c
00H0/k>c00<0000009nOW`2OWil00P2OWil70?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool703lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000
NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil00`000000
/k>c0;>c/`070;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT03@3IfMT00`000000
k>c/0>c/k00F0>c/k0030000003oool0oooo02X0oooo0P3o00000`000?l0o`000?l000030?l00004
0000o`00o`000?l0003o0080o`0000<0003o0?l0003oool0HP3oool00`000?l0oooo0?l000070?l0
0380oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K6
00P0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0209nOW`L0oooo0@0000010?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`L0?clo00<0000005=CD`1CDe<00P1CDe<00`000000
IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000
WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000
fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0;03oool00`3o0000
003o0?l000040?l00006003o00000?l0003o0000o`00o`00003o0P3o001T0?ooo`030000o`3o0000
o`0000L0o`00<P3oool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI00/0fMWI00<00000
0<K6aP36a/H02036a/H00`000000/k>c0;>c/`070;>c/`040000002OWil0WinO09nOW`L0oooo0@00
00010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0?clo00<0000005=CD`1CDe<00`1CDe<0
0`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`0
0`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H0
0`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0;03oool0
0`000?l0oooo0?ooo`030?l00003003o00000?l0003o00<0003o00<00?l00?l0003o0000I03oool0
0`3o0000003o0000o`03003o00@0o`00<P3oool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0
fMWI00/0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`070;>c/`040000002OWil0
WinO09nOW`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0?clo00<00000
05=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<00000
08b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<00000
0<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01H0k>c/00<00000
0?ooo`3oool0;03oool00`000?l0oooo0?ooo`020?ooo`80o`0000<00?l00000o`000?l00`000?l0
1000o`00o`000?l0003o001S0?ooo`80o`0000D00?l00000o`000?l0003o003o00030?l003<0oooo
00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0;0=WIf@8000002@36a/H00`000000/k>c
0;>c/`070;>c/`030000002OWil0WinO00L0oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`050?ooo`H0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001i
NGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c
/k<0/k>c00H0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0<0=WIf@030000003/
k>`0k>c/01H0k>c/00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`020?ooo`80o`0000<0
0?l00000o`000?l00`000?l01000o`00o`000?l0003o001R0?ooo`80o`0000<00?l00000o`000?l0
0`000?l01000o`00o`000?l0003o000b0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WIf@3I
fMT02`3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2O
Wil01`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P0o?cl00`000000De=C
05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<
08b<S00408b<S0030000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K6
0<K6aP080<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`05P3/k>`00`000000oooo
0?ooo`0/0?ooo`030000o`3oool0oooo00@0oooo0P3o00001@00o`00003o0000o`000?l00?l000<0
o`00H`3oool20?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000o`00<`3oool00`00
0000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H02036a/H00`00
0000/k>c0;>c/`060;>c/`030000002OWil0WinO00L0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`D0?clo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP03
0000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`03
0000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0=0=WIf@03
0000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`050?ooo`<0
o`000`00o`040?l006@0oooo00<0o`00003o00000?l010000?l00`00o`00o`000?l0000d0?ooo`03
0000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP080<K6aP03
0000002c/k<0/k>c00L0/k>c00<0000009nOW`3oool01P3oool100000040oooo000O0?ooo`030000
003oool0oooo00D0oooo1@0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV
00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00D0WinO
00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00`0fMWI
00<000000>c/k03/k>`05P3/k>`00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00H0oooo
2P3o001T0?ooo`80o`0000<00?l00000o`000?l00P000?l30?l003D0oooo00<000000>c/k03/k>`0
4`3/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<0
1P2c/k<00`000000WinO0?ooo`060?ooo`4000000@3oool001l0oooo0`0000050?ooo`D0?clo00<0
000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0
000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<0
00000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01D0k>c/00<0
00000?ooo`3oool0;03oool00`000?l0oooo0?ooo`070?ooo`P0o`00I@3oool30?l000<00?l000@0
o`000000o`3o0000o`00=@3oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00`0fMWI
00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0oooo00D0oooo
0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0?clo00<0000005=CD`1CDe<00P1C
De<00`000000IVIV06IVIP0406IVIP030000001iNGT0NGUi0080NGUi00<0000008b<S02<S8`0102<
S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036
a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool0:`3o
ool00`000?l0oooo0?ooo`0;0?ooo`80o`00J@3oool60?l000030000o`3o0000oooo03H0oooo00<0
00000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600P0a/K600<0
00000;>c/`2c/k<01P2c/k<00`000000WinO0?ooo`060?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool403lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH0
0`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil0
0`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT0303IfMT0
0`000000k>c/0>c/k00E0>c/k0030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0NP3oool2
0?l00080oooo00<0003o0?ooo`3oool0=@3oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0
fMWI00`0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`060;>c/`030000003oool0
oooo00D0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0?clo00<0000005=C
D`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<
S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6
aP36a/H02036a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01D0k>c/00<000000?oo
o`3oool0:`3oool00`000?l0oooo0?ooo`1o0?ooo`030000o`3oool0oooo03D0oooo00<000000>c/
k03/k>`04`3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c
/`2c/k<01P2c/k<00`000000oooo0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool403lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000
NGUi07UiN@0307UiN@030000002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil01@2OWil00`000000
/k>c0;>c/`060;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT0303IfMT00`000000
k>c/0>c/k00D0>c/k0030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0P03oool00`000?l0
oooo0?ooo`0e0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT02`3IfMT00`000000
a/K60<K6aP080<K6aP030000002c/k<0/k>c00H0/k>c00<000000?ooo`3oool01@3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo0`0o?cl00`000000De=C05=CD`0205=CD`030000
001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000
002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000
003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`05@3/k>`00`000000oooo0?ooo`0Z0?ooo`030000
o`3oool0oooo0880oooo00<0003o0?ooo`3oool0=@3oool00`000000k>c/0>c/k00C0>c/k0030000
003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`070;>c/`030000
003oool0oooo00@0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0?clo00<0
000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi00<0NGUi00<0
000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<0
00000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/01@0k>c/00<0
00000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`230?ooo`030000o`3oool0oooo03@0oooo00<0
00000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600P0a/K600<0
00000;>c/`2c/k<01P2c/k<70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool3
03lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@03
07UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`06
0;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00E
0>c/k0030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0Q03oool00`000?l0oooo0?ooo`0e
0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP07
0<K6aP030000002c/k<0/k>c00H0/k>c1`3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo0`0o?cl00`000000De=C05=CD`0205=CD`030000001VIVH0IVIV00<0IVIV00<0000007Ui
N@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00D0WinO00<000000;>c
/`2c/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/
k03/k>`0503/k>`00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo08H0oooo00<0003o0?oo
o`3oool0=03oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6
aP36a/H01`36a/H00`000000/k>c0;>c/`060;>c/`L0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`80?clo00<0000005=CD`1CDe<00`1CDe<00`000000IVIV06IVIP0206IVIP03
0000001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0409nOW`03
0000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@03
0000003/k>`0k>c/01D0k>c/00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`270?ooo`04
0000o`3oool0o`000?l00380oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0;0=WI
f@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01@2c/k<70?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool203lo?`030000001CDe<0De=C0080De=C00<0000006IVIP1V
IVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00<0S8b<00<0000009nOW`2O
Wil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3I
fMT0303IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo02X0oooo00<0003o0?ooo`3o
ool0Q`3oool00`3o0000003o0?l000050?l002l0oooo00<000000>c/k03/k>`0503/k>`00`000000
fMWI0=WIf@0;0=WIf@0300000036a/H0a/K600L0a/K600<000000;>c/`2c/k<01@2c/k<70?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3oool203lo?`030000001CDe<0De=C0080De=C
00<0000006IVIP1VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00<0S8b<
00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K6
00<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo02T0oooo
00<0003o0?ooo`3oool0Q`3oool30?l000030000o`3o0000o`0000@0o`00;`3oool00`000000k>c/
0>c/k00C0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c
0;>c/`040;>c/`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80?clo00<0
000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0NGUi0080NGUi00<0
000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<0
00000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01D0k>c/00<0
00000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`270?ooo`@0o`0000<0003o003o0000o`000`3o
000_0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6
aP080<K6aP030000002c/k<0/k>c00@0/k>c1`3oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo00<0?clo0000001CDe<00`1CDe<00`000000IVIV06IVIP0306IVIP030000001iNGT0
NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0
/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0
k>c/01@0k>c/00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`280?ooo`<0o`0000D00?l0
0000o`000?l0003o003o00020?l00300oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WI
f@0:0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<0102c/k<70?ooo`4000000@3o
ool001l0oooo0`0000050?ooo`0303lo?`000000De=C00<0De=C00<0000006IVIP1VIVH00`1VIVH0
0`000000NGUi07UiN@0207UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil01@2OWil0
0`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT02`3IfMT0
0`000000k>c/0>c/k00E0>c/k0030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0R03oool3
0?l00003003o00000?l0003o00<0003o00<00?l00?l0003o0000;`3oool00`000000k>c/0>c/k00C
0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`03
0;>c/`H0oooo0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`0303lo?`000000De=C
00<0De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<
00@0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K6
00P0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00E0>c/k0030000003oool0oooo
02P0oooo00<0003o0?ooo`3oool0R03oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0
003o0000<03oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6
aP36a/H02036a/H00`000000/k>c0;>c/`030;>c/`L0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`0303lo?`000000De=C00<0De=C00<0000006IVIP1VIVH00P1VIVH00`000000
NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000
/k>c0;>c/`070;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT02`3IfMT00`000000
k>c/0>c/k00D0>c/k0030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0RP3oool20?l00003
003o00000?l0003o00<0003o00<00?l00?l0003oool0<03oool00`000000k>c/0>c/k00C0>c/k003
0000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`030;>c/`L0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000001CDe<0De=C0080De=C
00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<
00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K6
00<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool0R`3oool30?l00007003o00000?l0003o0000o`00o`00003o0?l0000b0?oo
o`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP070<K6
aP030000002c/k<0/k>c00<0/k>c1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo00<0000005=CD`1CDe<00P1CDe<00`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0
NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0
/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01@0
k>c/00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`2;0?ooo`@0o`000`00o`000`3o0000
003o0?l0000b0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT02P3IfMT00`000000
a/K60<K6aP080<K6aP030000002c/k<0/k>c0080/k>c1`3oool100000040oooo000O0?ooo`030000
003oool0oooo00D0oooo1@1CDe<00`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi
00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c
00<000000<K6aP36a/H01`36a/H2000000d0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo
0?ooo`0W0?ooo`030000o`3oool0oooo08d0oooo203o00000`000?l0oooo0?ooo`0a0?ooo`030000
003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP070<K6aP030000
002c/k<0/k>c0080/k>c1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1@1C
De<00`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<
S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036
a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool09`3o
ool00`000?l0oooo0?ooo`2A0?ooo`80o`00103oool00`000?l0oooo0?ooo`0`0?ooo`030000003/
k>`0k>c/0180k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP080<K6aP040000002c
/k<0/k>c0;>c/`L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0De=C00<0
000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@0407UiN@030000002<S8`0S8b<00<0S8b<00<0
000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<0
00000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo02H0oooo00<0
003o0?ooo`3oool0V@3oool00`000?l0oooo0?ooo`0`0?ooo`030000003/k>`0k>c/0180k>c/00<0
00000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP080<K6aP040000002c/k<0/k>c0;>c/`L0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0De=C00<0000006IVIP1VIVH00P1V
IVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102O
Wil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT02`3I
fMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0VP3o
ool00`000?l0oooo0?ooo`0_0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT02`3I
fMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`@0De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@03
07UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`06
0;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00D
0>c/k0030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0W03oool00`000?l0oooo0?ooo`02
0?l002d0oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0
a/K600P0a/K600<000000;>c/`2c/k<01`3oool100000040oooo00020?ooo`@000001P3oool20000
00D0oooo1P0000060?ooo`030000003oool0oooo00D0oooo101CDe<00`000000IVIV06IVIP0206IV
IP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nO
W`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WI
f@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`2M0?oo
o`030?l000000?l0o`0000D0o`00:P3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI
00X0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`070?ooo`4000000@3oool00003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0`1CDe<00`000000
IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000
WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000
fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01@0k>c/00<000000?ooo`3oool09P3oool00`000?l0
oooo0?ooo`2L0?ooo`80o`0000<0003o0?l0003o00001@3o000Z0?ooo`030000003/k>`0k>c/0140
k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0
oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool305=CD`030000001VIVH0IVIV0080IVIV
00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO
00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00/0fMWI
00<000000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo09d0oooo
0`3o000010000?l00?l0003o0000o`030?l002X0oooo00<000000>c/k03/k>`04P3/k>`00`000000
fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`3oool01P3oool100000040
oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1`3oool4000000@0oooo0`1CDe<00`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi
00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c
00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/01<0k>c/
00<000000?ooo`3oool08@3oool20?l00080oooo00<0003o0?ooo`3oool0WP3oool30?l00005003o
00000?l0003o0000o`00o`000P3o000Z0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3I
fMT02P3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0oooo00@0oooo0`0000010?ooo`00
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool305=CD`030000001VIVH0IVIV0080IVIV00<0000007UiN@1iNGT0
0`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<0
1P2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`0
503/k>`00`000000oooo0?ooo`0N0?ooo`L0o`0000<0003o0?ooo`3oool0W@3oool30?l00003003o
00000?l0003o00<0003o00<00?l00?l0003o0000:P3oool00`000000k>c/0>c/k00A0>c/k0030000
003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0?ooo`060?ooo`400000
0@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo0P1CDe<00`000000IVIV06IVIP0206IVIP030000001i
NGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c
/k<0/k>c00H0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;0=WIf@030000003/
k>`0k>c/01<0k>c/00<000000?ooo`3oool07P3oool70?l000030000o`3o0000o`0009h0oooo0`3o
00000`00o`00003o0000o`030000o`03003o003o0000o`0002X0oooo00<000000>c/k03/k>`04P3/
k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600P0a/K600<000000?ooo`3oool01@3o
ool100000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0P1CDe<0
0`000000IVIV06IVIP0206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`0
0`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H2
000000`0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0N0?ooo`@0o`000P00o`00
10000?l0o`000?l0003o002O0?ooo`80o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?oo
o`0[0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT02`3IfMT00`000000a/K60<K6
aP070<K6aP030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`80De=C00<0000006IVIP1VIVH00P1VIVH00`000000NGUi07UiN@03
07UiN@030000002<S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`06
0;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00D
0>c/k0030000003oool0oooo01h0oooo0`3o00001@00o`00003o0000o`000?l00?l00080o`00W`3o
ool30?l00003003o00000?l0003o0080003o0P3o000/0?ooo`030000003/k>`0k>c/0140k>c/00<0
00000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP070<K6aP030000003oool0oooo00D0oooo0@00
00010?ooo`000P3oool4000000h0oooo100000070?ooo`030000003oool0oooo00D0oooo00<0De=C
0000001VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00@0S8b<00<00000
09nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<00000
0=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01h0oooo0`3o0000
0`00o`00003o0000o`030000o`03003o003o0000o`0009h0oooo103o0003003o00030000o`3o0000
o`0002d0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0
a/K600P0a/K600<000000?ooo`3oool0103oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo00<0De=C0000001VIVH00`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<
00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K6
00L0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo
01h0oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0009l0oooo1`3o00000`00
0?l0oooo0?ooo`0/0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT02`3IfMT00`00
0000a/K60<K6aP070<K6aPL0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`03
05=CD`000000IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S003
0000002OWil0WinO00D0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP070<K6aP03
0000003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0P0?ooo`80
o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?ooo`2R0?ooo`80o`000`3oool00`000?l0
oooo0?ooo`0/0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT02P3IfMT00`000000
a/K60<K6aP070<K6aPL0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000
001VIVH0IVIV00<0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000
002OWil0WinO00D0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP080<K6aP030000
003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0Q0?ooo`<0o`00
00D00?l00000o`000?l0003o003o00020?l00:P0oooo00<0003o0?ooo`3oool0;03oool00`000000
k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H01`36a/H70?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000IVIV06IVIP0206IVIP030000
001iNGT0NGUi00@0NGUi00<0000008b<S02<S8`00P2<S8`00`000000WinO09nOW`0509nOW`030000
002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;0=WIf@030000
003/k>`0k>c/01<0k>c/00<000000?ooo`3oool08@3oool30?l000040000o`00o`000?l0003o00<0
o`00Z@3oool00`000?l0oooo0?ooo`0[0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3I
fMT02P3IfMT00`000000a/K60<K6aP070<K6aPL0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`D0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000
002OWil0WinO00D0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP080<K6aP030000
003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0S0?ooo`80o`00
00<0003o0?l0003o00000`3o002[0?ooo`030000o`3oool0oooo02/0oooo00<000000>c/k03/k>`0
4@3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600H0a/K61`3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo1@1VIVH00`000000NGUi07UiN@0307UiN@030000002<
S8`0S8b<00<0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`050;>c/`0300000036
a/H0a/K600P0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00B0>c/k0030000003o
ool0oooo02@0oooo00@0003o0?ooo`3o0000o`00[P3oool00`000?l0oooo0?ooo`020?ooo`80o`00
9`3oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H0
1P36a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool506IVIP030000001i
NGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`030000002c
/k<0/k>c00D0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0:0=WIf@030000003/
k>`0k>c/01<0k>c/00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`2`0?ooo`030000o`3o
0000o`0000H0o`00903oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00X0fMWI00<0
00000<K6aP36a/H01P36a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool4
06IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`05
09nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@0;
0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`2a
0?ooo`030000o`3o0000o`0000L0o`00903oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0
fMWI00X0fMWI00<000000<K6aP36a/H01@36a/H70?ooo`4000000@3oool001l0oooo0`0000050?oo
o`@0IVIV00<0000007UiN@1iNGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO
00D0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI
00X0fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
0;40oooo00@0o`000000o`3o0000o`000`00o`030?l002@0oooo00<000000>c/k03/k>`04@3/k>`0
0`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600D0a/K61P3oool200000040oooo000O0?oo
o`030000003oool0oooo00D0oooo101VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<
00<0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K6
00P0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo
02<0oooo00<0003o0?ooo`3oool0/P3oool20?l000030000o`00o`000?l000<00?l00P3o000U0?oo
o`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP040<K6
aPL0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0IVIV00<0000007UiN@1i
NGT00`1iNGT00`000000S8b<08b<S00308b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c
/k<01P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/
k>`04`3/k>`00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0;40oooo0`3o00000`000?l0
0?l0003o0004003o0080o`00903oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00X0
fMWI00<000000<K6aP36a/H01036a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool306IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO
09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI
0=WIf@0:0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool0903oool00`000?l0oooo
0?ooo`2a0?ooo`<0o`0000<00?l00000o`00o`001000o`020?l002D0oooo00<000000>c/k03/k>`0
403/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600@0a/K61`3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo0`1VIVH00`000000NGUi07UiN@0307UiN@030000002<
S8`0S8b<00<0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036
a/H0a/K600L0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00C0>c/k0030000003o
ool0oooo02<0oooo00<0003o0?ooo`3oool0/`3oool20?l00003003o00000?l00?l000@00?l000<0
o`000?ooo`3oool0903oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00/0fMWI00<0
00000<K6aP36a/H00`36a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool3
06IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`04
09nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;
0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`2c
0?ooo`<0o`0000<00?l00000o`00o`000P00o`020?l002L0oooo00<000000>c/k03/k>`0403/k>`0
0`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600<0a/K61`3oool100000040oooo000O0?oo
o`030000003oool0oooo00D0oooo0`1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<
00<0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K6
00L0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo
02<0oooo00<0003o0?ooo`3oool0]03oool40?l00003003o00000?l00?l000<0o`009`3oool00`00
0000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H00`36a/H70?oo
o`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool206IVIP030000001iNGT0NGUi00<0
NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0
/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/0180
k>c/00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`2e0?ooo`@0o`0000@0003o0?l0003o
0000o`00:03oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6
aP36a/H00`36a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool206IVIP03
0000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0409nOW`03
0000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@03
0000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`2i0?ooo`80
o`0000<0003o0?ooo`3oool0:@3oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00X0
fMWI00<000000<K6aP36a/H00P36a/H70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool206IVIP030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO
09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI
0=WIf@0:0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool08`3oool00`000?l0oooo
0?ooo`2l0?ooo`030000o`3oool0oooo02P0oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI
0=WIf@0:0=WIf@0300000036a/H0a/K60080a/K61`3oool100000040oooo000O0?ooo`030000003o
ool0oooo00D0oooo0P1VIVH00`000000NGUi07UiN@0307UiN@030000002<S8`0S8b<00<0S8b<00<0
000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<0
00000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo02<0oooo00<0
003o0?ooo`3oool0_@3oool00`000?l0oooo0?ooo`0X0?ooo`030000003/k>`0k>c/0100k>c/00<0
00000=WIf@3IfMT02`3IfMT010000000a/K60<K6aP36a/H70?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool00`1VIVH0000007UiN@0407UiN@030000002<S8`0S8b<00<0S8b<00<0
000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<0
00000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo02<0oooo00<0
003o0?ooo`3oool0_P3oool00`000?l0oooo0?ooo`0X0?ooo`030000003/k>`0k>c/0100k>c/00<0
00000=WIf@3IfMT02P3IfMT010000000a/K60<K6aP36a/H70?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool00`1VIVH0000007UiN@0407UiN@030000002<S8`0S8b<00<0S8b<00<0
000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<0
00000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo02@0oooo00<0
003o0?ooo`3oool0_P3oool00`000?l0oooo0?ooo`0X0?ooo`030000003/k>`0k>c/0100k>c/00<0
00000=WIf@3IfMT02`3IfMT00`000000a/K60<K6aP070?ooo`4000000@3oool001l0oooo0`000005
0?ooo`0306IVIP000000NGUi00@0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`04
09nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:
0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`30
0?ooo`030000o`3oool0oooo02P0oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0:
0=WIf@0300000036a/H0a/K600H0oooo0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`030000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nO
W`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;0=WI
f@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`310?oo
o`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0:0=WI
f@0300000036a/H0a/K600L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`03
0000001iNGT0NGUi00<0NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0509nOW`03
0000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@03
0000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`320?ooo`03
0000o`3oool0oooo02L0oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0:0=WIf@03
00000036a/H0a/K600L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0NGUi
00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c
00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/0180k>c/
00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`330?ooo`040000o`3oool0o`000?l002H0
oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0oooo00H0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0NGUi00<0000008b<S02<S8`0
102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H0
1`36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0
7`3oool20?l000030?ooo`000?l0oooo0<@0oooo0P3o00000`000?l0o`000?l000030?l002<0oooo
00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0oooo00H0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0NGUi00<0000008b<S02<S8`0102<
S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36
a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07@3o
ool60?l000030000o`3o0000oooo0<80oooo0`3o00000`000?l00?l0003o00040?l002<0oooo00<0
00000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0oooo00H0oooo0@00
00010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0NGUi00<0000008b<S02<S8`0102<S8`0
0`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H0
0`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0703oool3
0?l000<00?l000@0003o0?l0003o0000o`00`P3oool20?l00005003o00000?l0003o0000o`00o`00
0`3o000S0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02P3IfMT00`000000oooo
0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool407UiN@030000002<
S8`0S8b<00@0S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`050;>c/`0300000036
a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00B0>c/k0030000003o
ool0oooo01d0oooo0P3o00000`00o`00003o0000o`020000o`<0o`00`P3oool00`3o00000?l00000
o`040000o`03003o003o0000o`0002@0oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WI
f@090=WIf@030000003oool0oooo00D0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`@0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0
/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0
k>c/0180k>c/00<000000?ooo`3oool07@3oool00`3o00000?l00000o`040000o`03003o003o0000
o`000<40oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l002<0oooo00<0
00000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@090=WIf@030000003oool0oooo00D0oooo0@00
00010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0NGUi00<0000008b<S02<S8`00`2<S8`0
0`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H0
0`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool0703oool2
0?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000o`00`03oool20?l00003003o0000
0?l0003o00<0003o00@00?l00?l0003o0000o`00903oool00`000000k>c/0>c/k00?0>c/k0030000
003IfMT0fMWI00X0fMWI00<000000?ooo`3oool0103oool100000040oooo000O0?ooo`030000003o
ool0oooo00D0oooo0`1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0WinO00@0WinO00<0
00000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00X0fMWI00<0
00000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0M0?ooo`80o`0000<00?l00000o`000?l00`00
0?l01000o`00o`000?l0003o00310?ooo`80o`0000<00?l00000o`000?l00P000?l30?l002D0oooo
00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@090=WIf@L0oooo0@0000010?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`<0NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO09nO
W`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WI
f@0:0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07P3oool20?l00005003o0000
0?l0003o0000o`00o`000`3o001H0?ooo``00000GP3oool30?l000<00?l000@0003o0?l0003o0000
o`009@3oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00T0fMWI1`3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo0`1iNGT00`000000S8b<08b<S00408b<S0030000
002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000
003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0O0?ooo`<0o`00
00<0003o003o0000o`00103o001A0?ooo`L00000303/k>`7000005L0oooo1P3o000010000?l0o`00
0?l0003o000U0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT02@3IfMT70?ooo`40
00000@3oool001l0oooo0`0000050?ooo`80NGUi00<0000008b<S02<S8`0102<S8`00`000000WinO
09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI
0=WIf@0:0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool07`3oool20?l000030000
o`3o0000o`0000D0o`00CP3oool3000001X0k>c/1000001D0?ooo`H0o`0000<0003o0?l0003oool0
9P3oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00T0fMWI1P3oool200000040oooo
000O0?ooo`030000003oool0oooo00D0oooo0P1iNGT00`000000S8b<08b<S00408b<S0030000002O
Wil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003I
fMT0fMWI00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0Q0?ooo`030?l00000
0?l0o`0000D0o`00C@3oool200000240k>c/0`00001D0?ooo`80o`0000<0oooo0000o`3oool09`3o
ool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00P0fMWI1`3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo0P1iNGT00`000000S8b<08b<S00408b<S0030000002OWil0
WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0
fMWI00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0
oooo0080o`00C03oool4000002H0k>c/0P00001F0?ooo`030000o`3oool0oooo02H0oooo00<00000
0>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@080=WIf@L0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`80NGUi00<0000008b<S02<S8`00`2<S8`00`000000WinO09nOW`0409nO
W`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@090=WI
f@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`1<0?oo
o`800000;03/k>`3000005<0oooo00<0003o0?ooo`3oool09P3oool00`000000k>c/0>c/k00?0>c/
k0030000003IfMT0fMWI00P0fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo00<0NGUi0000002<S8`01@2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0
/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140
k>c/00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`1;0?ooo`800000<@3/k>`300000500
oooo00<0003o0?ooo`3oool09P3oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00L0
fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0NGUi0000002<S8`0
102<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H0
1`36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0
803oool00`000?l0oooo0?ooo`1:0?ooo`800000=P3/k>`2000004l0oooo00<0003o0?ooo`3oool0
9P3oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00L0fMWI1`3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo00<0NGUi0000002<S8`0102<S8`00`000000WinO09nO
W`0409nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WI
f@090=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0803oool00`000?l0oooo0?oo
o`180?ooo`800000>P3/k>`00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo02H0oooo00<0
00000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@060=WIf@L0oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`0307UiN@000000S8b<00@0S8b<00<0000009nOW`2OWil0102OWil0
0`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT0
0`000000k>c/0>c/k00A0>c/k0030000003oool0oooo0200oooo00<0003o0?ooo`3oool0A`3oool2
000003d0k>c/00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0W0?ooo`030000003/k>`0
k>c/00l0k>c/00<000000=WIf@3IfMT01P3IfMT70?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool00`000000S8b<08b<S00308b<S0030000002OWil0WinO00@0WinO00<000000;>c
/`2c/k<01P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/
k03/k>`04P3/k>`00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo04H0oooo0P0000100>c/
k0800000C03oool00`000?l0oooo0?ooo`0V0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WI
f@3IfMT01P3IfMT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000
S8b<08b<S00308b<S0030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000
a/K60<K6aP070<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`04@3/k>`00`000000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo04D0oooo00<000000>c/k03/k>`0@P3/k>`00`000000
oooo0?ooo`190?ooo`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`03`3/k>`00`000000
fMWI0=WIf@050=WIf@L0oooo0@0000010?ooo`000P3oool4000000H0oooo0P0000070?ooo`@00000
1P3oool00`000000oooo0?ooo`050?ooo`030000002<S8`0S8b<00<0S8b<00<0000009nOW`2OWil0
102OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT0
2P3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0
A03oool2000004H0k>c/0P0000190?ooo`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`0
3`3/k>`00`000000fMWI0=WIf@050=WIf@L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo1P2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<0
00000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140k>c/00<0
00000?ooo`3oool07P3oool00`000?l0oooo0?ooo`130?ooo`800000BP3/k>`2000004P0oooo00<0
003o0?ooo`3oool09P3oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00D0fMWI1`3o
ool100000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`D0S8b<00<0000009nOW`2OWil0102OWil0
0`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT0
0`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0@P3oool0
0`000000k>c/0>c/k01<0>c/k0030000003oool0oooo04D0oooo00<0003o0?l0003o00009P3oool0
0`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00D0fMWI1`3oool100000040oooo00000`3o
ool000000?ooo`030?ooo`030000003oool0oooo00X0oooo1P0000060?ooo`030000003oool0oooo
00D0oooo1@2<S8`00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6
aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140k>c/00<000000?oo
o`3oool07P3oool00`000?l0oooo0?ooo`110?ooo`800000D03/k>`2000004<0oooo0`3o00000`00
0?l0o`000?l000020?l002@0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@040=WI
f@L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo000000L0oooo100000040?ooo`D0S8b<00<0000009nOW`2OWil0102OWil00`00
0000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT02P3IfMT00`00
0000k>c/0>c/k00A0>c/k0030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0@03oool00`00
0000k>c/0>c/k01B0>c/k0030000003oool0oooo03l0oooo103o00000`000?l0o`000?l000030?l0
02<0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@040=WIf@D0oooo0`0000010?oo
o`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool01@3oool508b<S0030000002OWil0WinO00@0WinO00<000000;>c
/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/
k03/k>`04@3/k>`00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0400oooo00<000000>c/
k03/k>`0E03/k>`00`000000oooo0?ooo`0n0?ooo`<0o`0000<00?l00000o`00o`00103o000S0?oo
o`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT0103IfMT70?ooo`4000000@3oool00003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo000000070?ooo`03
0000003oool0oooo00D0oooo102<S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00D0
/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0140
k>c/00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0o0?ooo`800000F03/k>`2000003h0
oooo0P3o00001@00o`00003o0000o`000?l00?l000<0o`00903oool00`000000k>c/0>c/k00>0>c/
k0030000003IfMT0fMWI00@0fMWI1`3oool100000040oooo00000`3oool000000?ooo`030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`@0
S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600H0
a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01h0
oooo00<0003o0?ooo`3oool0?P3oool00`000000k>c/0>c/k01J0>c/k0030000003oool0oooo03X0
oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l002<0oooo00<000000>c/
k03/k>`03`3/k>`00`000000fMWI0=WIf@030=WIf@L0oooo0@0000010?ooo`000P3oool400000100
oooo0P0000070?ooo`030000003oool0oooo00D0oooo102<S8`00`000000WinO09nOW`0409nOW`03
0000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@090=WIf@03
0000003/k>`0k>c/0140k>c/00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0o0?ooo`03
0000003/k>`0k>c/05/0k>c/00<000000?ooo`3oool0>@3oool20?l00003003o00000?l0003o00<0
003o00@00?l00?l0003o0000o`00903oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI
00<0fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo102<S8`00`000000
WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000
fMWI0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool0703oool00`000?l0
oooo0?ooo`0o0?ooo`030000003/k>`0k>c/05d0k>c/0P00000j0?ooo`030?l00000o`00003o00@0
003o00<00?l00?l0003o00009@3oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00<0
fMWI1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo102<S8`00`000000WinO
09nOW`0309nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI
0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool0603oool20?l000<0oooo
00<0003o0?ooo`3oool0?@3oool200000680k>c/00<000000?ooo`3oool0=`3oool20?l00006003o
00000?l0003o0000o`00o`00003o0P3o000U0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WI
f@3IfMT00P3IfMT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool308b<S003
0000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP03
0000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0E0?ooo`L0
o`0000<0003o0?ooo`3oool0?@3oool00`000000k>c/0>c/k01R0>c/k0030000003oool0oooo03L0
oooo0`3o0003003o00040?l000000?l0o`000?l002H0oooo00<000000>c/k03/k>`03P3/k>`00`00
0000fMWI0=WIf@020=WIf@L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0
S8b<00<0000009nOW`2OWil0102OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600L0
a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01@0
oooo203o00000`000?l0o`000?ooo`0l0?ooo`030000003/k>`0k>c/06@0k>c/00<000000?ooo`3o
ool0=`3oool70?l000030000o`3oool0oooo02D0oooo00<000000>c/k03/k>`03`3/k>`010000000
fMWI0=WIf@3IfMT70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool308b<S003
0000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP060<K6aP03
0000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0E0?ooo`<0
o`000`00o`00103o0000003o0?l0003o000k0?ooo`800000J03/k>`2000003X0oooo0P3o00020?oo
o`030000o`3oool0oooo02D0oooo00<000000>c/k03/k>`03`3/k>`010000000fMWI0=WIf@3IfMT7
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool208b<S0030000002OWil0WinO
00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI
00T0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0E0?ooo`80o`0000<00?l00000
o`000?l00P000?l30?l003X0oooo00<000000>c/k03/k>`0JP3/k>`00`000000oooo0?ooo`0l0?oo
o`030000o`3oool0oooo02D0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@070?oo
o`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool208b<S0030000002OWil0WinO00@0
WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00T0
fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0E0?ooo`80o`0000<00?l00000o`00
0?l00`000?l01000o`00o`000?l0003o000h0?ooo`030000003/k>`0k>c/06`0k>c/0P00000l0?oo
o`030000o`3oool0oooo02D0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@070?oo
o`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool208b<S0030000002OWil0WinO00@0
WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00X0
fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0E0?ooo`80o`0000<00?l00000o`00
0?l00`000?l01000o`00o`000?l0003o000g0?ooo`030000003/k>`0k>c/06l0k>c/00<000000?oo
o`3oool0>P3oool00`000?l0oooo0?ooo`0T0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WI
f@3IfMT01`3oool100000040oooo000O0?ooo`<000001@3oool00`2<S8`0000009nOW`0509nOW`03
0000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@0:0=WIf@03
0000003/k>`0k>c/0100k>c/00<000000?ooo`3oool05P3oool00`3o00000?l00000o`040000o`03
003o003o0000o`0003L0oooo00<000000>c/k03/k>`0L@3/k>`00`000000oooo0?ooo`0i0?ooo`03
0000o`3oool0oooo02D0oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@060?ooo`80
00000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`2<S8`0000009nOW`0509nOW`030000
002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@0:0=WIf@030000
003/k>`0k>c/0100k>c/00<000000?ooo`3oool05`3oool20?l00005003o00000?l0003o0000o`00
o`000`3o000f0?ooo`030000003/k>`0k>c/0780k>c/00<000000?ooo`3oool0>P3oool00`000?l0
oooo0?ooo`0T0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3oool01P3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo00<0S8b<0000002OWil01@2OWil00`000000/k>c
0;>c/`050;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/
0>c/k00@0>c/k0030000003oool0oooo01L0oooo0`3o00000`00o`00003o003o00040?l003D0oooo
00<000000>c/k03/k>`0M03/k>`00`000000oooo0?ooo`0i0?ooo`040000o`3oool0o`000?l002@0
oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0?ooo`060?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool01@3oool00`2<S8`0000009nOW`0509nOW`030000002c/k<0/k>c00D0/k>c
00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/
00<000000?ooo`3oool0603oool20?l000030000o`3o0000o`0000<0o`00=@3oool00`000000k>c/
0>c/k01f0>c/k0030000003oool0oooo03L0oooo0P3o00000`000?l0o`000?l000030?l00240oooo
00<000000>c/k03/k>`03P3/k>`00`000000fMWI0?ooo`060?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool00`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00H0/k>c00<0
00000<K6aP36a/H01@36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/0100k>c/00<0
00000?ooo`3oool06`3oool00`000?l0o`000?l0000g0?ooo`030000003/k>`0k>c/07L0k>c/00<0
00000?ooo`3oool0=P3oool30?l000030000o`00o`000?l000@0o`00803oool00`000000k>c/0>c/
k00>0>c/k0030000003IfMT0oooo00H0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`030000002OWil0WinO00@0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP06
0<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0J
0?ooo`030000o`3oool0oooo03L0oooo00<000000>c/k03/k>`0N@3/k>`00`000000oooo0?ooo`0e
0?ooo`80o`0000D00?l00000o`000?l0003o003o00030?l00240oooo00<000000>c/k03/k>`03P3/
k>`00`000000oooo0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool0
0`000000WinO09nOW`0409nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36a/H0
0`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`0g0?ooo`030000003/k>`0k>c/07X0k>c/0P00000e0?ooo`030?l00000o`00
003o00@0003o00<00?l00?l0003o00008@3oool00`000000k>c/0>c/k00>0>c/k0030000003oool0
oooo00D0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`L0WinO00<000000;>c
/`2c/k<01@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/
k03/k>`0403/k>`00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo03L0oooo00<000000>c/
k03/k>`0O@3/k>`00`000000oooo0?ooo`0a0?ooo`80o`0000<00?l00000o`000?l00`000?l01000
o`00o`000?l0003o000P0?ooo`030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0103oool1
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P2OWil00`000000/k>c0;>c/`050;>c
/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00A0>c/
k0030000003oool0oooo01X0oooo00<0003o0?ooo`3oool0=P3oool00`000000k>c/0>c/k01n0>c/
k0030000003oool0oooo0340oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`00
0?l00240oooo00<000000>c/k03/k>`03P3/k>`70?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool609nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36a/H00`00
0000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`0f0?ooo`030000003/k>`0k>c/0800k>c/00<000000?ooo`3oool0<@3oool20?l0
0003003o00000?l0003o0080003o0`3o000R0?ooo`030000003/k>`0k>c/00h0k>c/1`3oool10000
0040oooo000O0?ooo`030000003oool0oooo00D0oooo1P2OWil00`000000/k>c0;>c/`050;>c/`03
00000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k003
0000003oool0oooo01X0oooo00<0003o0?ooo`3oool0=@3oool00`000000k>c/0>c/k0220>c/k003
0000003oool0oooo0300oooo0`3o0003003o00040?l000000?l0o`000?l002<0oooo00<000000>c/
k03/k>`03@3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool609nOW`03
0000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@03
0000003/k>`0k>c/0100k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0e0?ooo`03
0000003/k>`0k>c/08@0k>c/00<000000?ooo`3oool0;`3oool70?l000030000o`3o0000o`0002<0
oooo00<000000>c/k03/k>`03@3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool509nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI
0=WIf@0:0=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`0d0?ooo`030000003/k>`0k>c/08H0k>c/00<000000?ooo`3oool0;`3oool70?l000030000
o`3oool0oooo0280oooo00<000000>c/k03/k>`03@3/k>`70?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool509nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36
a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`0e0?ooo`030000003/k>`0k>c/08L0k>c/00<000000?ooo`3oool0<@3o
ool20?l00080oooo00<0003o0?ooo`3oool08P3oool00`000000k>c/0>c/k00=0>c/k0L0oooo0@00
00010?ooo`007`3oool3000000D0oooo1@2OWil00`000000/k>c0;>c/`050;>c/`0300000036a/H0
a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0
oooo01T0oooo00<0003o0?ooo`3oool0=03oool00`000000k>c/0>c/k0290>c/k0030000003oool0
oooo03D0oooo00<0003o0?ooo`3oool08P3oool00`000000k>c/0>c/k00<0>c/k0H0oooo0P000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0WinO00<000000;>c/`2c/k<01@2c/k<00`00
0000a/K60<K6aP060<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0403/k>`00`00
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03<0oooo00<000000>c/k03/k>`0R`3/k>`00`00
0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0280oooo00<000000>c/k03/k>`0303/k>`70?oo
o`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool409nOW`030000002c/k<0/k>c00D0
/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0100
k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0c0?ooo`030000003/k>`0k>c/08`0
k>c/00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003/k>`0k>c/00`0
k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo102OWil00`000000/k>c
0;>c/`050;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/
0>c/k00@0>c/k0030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0<`3oool00`000000k>c/
0>c/k02=0>c/k0030000003oool0oooo03@0oooo00<0003o0?ooo`3oool08P3oool00`000000k>c/
0>c/k00;0>c/k0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0WinO00<0
00000;>c/`2c/k<0102c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<0
00000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo03<0oooo00<0
00000>c/k03/k>`0S`3/k>`00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0240oooo00<0
00000>c/k03/k>`02`3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool4
09nOW`030000002c/k<0/k>c00@0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@09
0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0b
0?ooo`030000003/k>`0k>c/0940k>c/00<000000?ooo`3oool0<`3oool010000?l0oooo0?l0003o
000P0?ooo`030000003/k>`0k>c/00/0k>c/1`3oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo0`2OWil00`000000/k>c0;>c/`040;>c/`0300000036a/H0a/K600L0a/K600<00000
0=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01P0oooo00<0003o
0?ooo`3oool0<P3oool00`000000k>c/0>c/k02B0>c/k0030000003oool0oooo0380oooo0P3o0000
0`000?l0o`000?l000030?l001h0oooo00<000000>c/k03/k>`02P3/k>`70?ooo`4000000@3oool0
01l0oooo00<000000?ooo`3oool01@3oool309nOW`030000002c/k<0/k>c00@0/k>c00<000000<K6
aP36a/H01`36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?oo
o`3oool0603oool00`000?l0oooo0?ooo`0b0?ooo`030000003/k>`0k>c/09<0k>c/00<000000?oo
o`3oool0<03oool30?l000030000o`3o0000o`0000@0o`007@3oool00`000000k>c/0>c/k00:0>c/
k0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0WinO00<000000;>c/`2c
/k<0102c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/
k>`03`3/k>`00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0380oooo00<000000>c/k03/
k>`0U@3/k>`00`000000oooo0?ooo`0_0?ooo`<0o`0000<00?l00000o`00o`00103o000N0?ooo`03
0000003/k>`0k>c/00T0k>c/1`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo
0`2OWil00`000000/k>c0;>c/`040;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0
2@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0
<@3oool00`000000k>c/0>c/k02G0>c/k0030000003oool0oooo02h0oooo0P3o00001@00o`00003o
0000o`000?l00?l000<0o`007P3oool00`000000k>c/0>c/k0090>c/k0L0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`050?ooo`80WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K6
0<K6aP070<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo0340oooo00<000000>c/k03/k>`0@P3/k>`B000004@0k>c/
00<000000?ooo`3oool0;@3oool20?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000
o`007@3oool00`000000k>c/0>c/k0090>c/k0L0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`80WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K60<K6aP060<K6aP030000
003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0H0?ooo`030000
o`3oool0oooo0300oooo00<000000>c/k03/k>`0@03/k>`300000180fMWI1`00000n0>c/k0030000
003oool0oooo02`0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l001h0
oooo00<000000>c/k03/k>`0203/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool209nOW`030000002c/k<0/k>c00@0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI
0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`0a0?ooo`030000003/k>`0k>c/03/0k>c/1@00000K0=WIf@800000?@3/k>`00`000000oooo
0?ooo`0]0?ooo`030?l00000o`00003o00@0003o00<00?l00?l0003o00007`3oool00`000000k>c/
0>c/k0080>c/k0L0oooo0@0000010?ooo`007`3oool3000000D0oooo0P2OWil00`000000/k>c0;>c
/`040;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/
k00@0>c/k0030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0<03oool00`000000k>c/0>c/
k00i0>c/k0<000008P3IfMT4000003X0k>c/00<000000?ooo`3oool0;03oool20?l00003003o0000
0?l0003o0080003o0`3o000O0?ooo`030000003/k>`0k>c/00P0k>c/1P3oool200000040oooo000O
0?ooo`030000003oool0oooo00D0oooo00<0WinO0000002c/k<01@2c/k<00`000000a/K60<K6aP06
0<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo02l0oooo00<000000>c/k03/k>`0>03/k>`2000002T0fMWI1000000g
0>c/k0030000003oool0oooo02/0oooo0`3o0003003o00040?l000000?l0o`000?l00200oooo00<0
00000>c/k03/k>`01`3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool0
0`2OWil000000;>c/`050;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT0
0`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0;`3oool0
0`000000k>c/0>c/k00f0>c/k0<00000;`3IfMT2000003H0k>c/00<000000?ooo`3oool0:`3oool6
0?l000030000o`3o0000oooo0200oooo00<000000>c/k03/k>`01`3/k>`70?ooo`4000000@3oool0
01l0oooo00<000000?ooo`3oool01@3oool00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K6
00H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo
01L0oooo00<0003o0?ooo`3oool0;`3oool00`000000k>c/0>c/k00d0>c/k0800000=03IfMT20000
03D0k>c/00<000000?ooo`3oool0;@3oool20?l000030?ooo`000?l0oooo0240oooo00<000000>c/
k03/k>`01`3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000
/k>c0;>c/`050;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT02@3IfMT00`000000
k>c/0>c/k00@0>c/k0030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0;`3oool00`000000
k>c/0>c/k00d0>c/k0030000003IfMT0fMWI03H0fMWI0P00000c0>c/k0030000003oool0oooo0340
oooo00<0003o0?ooo`3oool0803oool00`000000k>c/0>c/k0060>c/k0L0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`050?ooo`L0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI
0=WIf@090=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`0_0?ooo`030000003/k>`0k>c/0380k>c/0P00000k0=WIf@800000<P3/k>`00`000000oooo
0?ooo`0`0?ooo`030000o`3oool0oooo0080o`007P3oool00`000000k>c/0>c/k0060>c/k0L0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`L0/k>c00<000000<K6aP36a/H01P36
a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`0_0?ooo`030000003/k>`0k>c/0340k>c/0P00000o0=WIf@800000<@3/
k>`00`000000oooo0?ooo`0_0?ooo`030?l000000?l0o`0000D0o`00703oool00`000000k>c/0>c/
k0050>c/k0L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`L0/k>c00<00000
0<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/00l0k>c/00<00000
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0^0?ooo`030000003/k>`0k>c/0300k>c/0P000012
0=WIf@030000003/k>`0k>c/0300k>c/00<000000?ooo`3oool0;@3oool20?l000030000o`3o0000
0?l000800?l00`3o000K0?ooo`030000003/k>`0k>c/00D0k>c/1`3oool100000040oooo000O0?oo
o`030000003oool0oooo00D0oooo1P2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI
00P0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
02h0oooo00<000000>c/k03/k>`0<03/k>`00`000000fMWI0=WIf@130=WIf@800000<03/k>`00`00
0000oooo0?ooo`0]0?ooo`80o`0000<0003o003o0000o`000`00o`020?l001/0oooo00<000000>c/
k03/k>`01@3/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool60;>c/`03
00000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00?0>c/k003
0000003oool0oooo01<0oooo0P3o00020?ooo`030000o`3oool0oooo02d0oooo00<000000>c/k03/
k>`0;`3/k>`2000004P0fMWI0P00000_0>c/k0030000003oool0oooo02/0oooo0`3o00000`00o`00
003o003o0004003o00030?l0003oool0oooo01X0oooo00<000000>c/k03/k>`0103/k>`70?ooo`40
00000@3oool00080oooo100000060?ooo`8000001`3oool4000000H0oooo00<000000?ooo`3oool0
1@3oool60;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/
0>c/k00?0>c/k0030000003oool0oooo0100oooo1P3o00000`000?l0o`000?ooo`0^0?ooo`030000
003/k>`0k>c/02h0k>c/00<000000=WIf@3IfMT0BP3IfMT2000002d0k>c/00<000000?ooo`3oool0
:`3oool30?l00004003o00000?l0003o0000o`<00?l00P3o000K0?ooo`030000003/k>`0k>c/00@0
k>c/1`3oool100000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo
0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`H0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000
003/k>`0k>c/00l0k>c/00<000000?ooo`3oool03`3oool70?l000030000o`3o0000o`0002d0oooo
00<000000>c/k03/k>`0;P3/k>`00`000000fMWI0=WIf@1=0=WIf@030000003/k>`0k>c/02/0k>c/
00<000000?ooo`3oool0:P3oool20?l00003003o00000?l0003o00<0003o0P00o`020?l001/0oooo
00<000000>c/k03/k>`0103/k>`70?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool50;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3I
fMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo0100oooo0`3o0003003o00040000o`3o
0000o`000?l002`0oooo00<000000>c/k03/k>`0;P3/k>`00`000000fMWI0=WIf@1?0=WIf@030000
003/k>`0k>c/02/0k>c/00<000000?ooo`3oool0:03oool30?l00003003o00000?l0003o00<0003o
00<00?l00?l0003o0000703oool00`000000k>c/0>c/k0040>c/k0L0oooo0@0000010?ooo`0000<0
oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool00`000000oooo0?oo
o`030?ooo`@00000103oool50;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3I
fMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo0100oooo0P3o00000`00o`00003o0000
o`020000o`<0o`00;03oool00`000000k>c/0>c/k00/0>c/k0800000D`3IfMT2000002`0k>c/00<0
00000?ooo`3oool09`3oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0003o00007@3o
ool00`000000k>c/0>c/k0030>c/k0D0oooo0`0000010?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool00000008000001P3oool00`000000oooo0?ooo`05
0?ooo`D0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0
k>c/00l0k>c/00<000000?ooo`3oool03`3oool20?l00003003o00000?l0003o00<0003o00@00?l0
0?l0003o0000o`00:P3oool00`000000k>c/0>c/k00[0>c/k0800000E`3IfMT00`000000k>c/0>c/
k00Y0>c/k0030000003oool0oooo02P0oooo0`3o00001@00o`00003o0000o`000?l00?l000<0o`00
7@3oool00`000000k>c/0>c/k0030>c/k0L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool50;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/
k00@0>c/k0030000003oool0oooo00l0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o
0000o`000?l002T0oooo00<000000>c/k03/k>`0:`3/k>`00`000000fMWI0=WIf@1H0=WIf@030000
003/k>`0k>c/02P0k>c/00<000000?ooo`3oool0:03oool40?l000800?l000@0003o0?l0003o0000
o`007P3oool00`000000k>c/0>c/k0030>c/k0L0oooo0@0000010?ooo`0000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool40;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/
0>c/k00?0>c/k0030000003oool0oooo0140oooo00<0o`00003o00000?l010000?l00`00o`00o`00
0?l0000Z0?ooo`030000003/k>`0k>c/02X0k>c/00<000000=WIf@3IfMT0FP3IfMT00`000000k>c/
0>c/k00X0>c/k0030000003oool0oooo02L0oooo1`3o00000`000?l0o`000?l0000N0?ooo`030000
003/k>`0k>c/00<0k>c/1`3oool100000040oooo00000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`@0/k>c00<0
00000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/0100k>c/00<0
00000?ooo`3oool04@3oool20?l00005003o00000?l0003o0000o`00o`000`3o000Y0?ooo`030000
003/k>`0k>c/02X0k>c/00<000000=WIf@3IfMT0G03IfMT2000002P0k>c/00<000000?ooo`3oool0
:03oool60?l000030000o`3o0000oooo01l0oooo00<000000>c/k03/k>`00P3/k>`70?ooo`400000
0@3oool00080oooo1000000A0?ooo`<000001@3oool00`000000oooo0?ooo`050?ooo`@0/k>c00<0
00000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<0
00000?ooo`3oool04P3oool30?l00003003o00000?l00?l000@0o`00:@3oool00`000000k>c/0>c/
k00Y0>c/k0030000003IfMT0fMWI05l0fMWI00<000000>c/k03/k>`09P3/k>`00`000000oooo0?oo
o`0Z0?ooo`80o`0000<0oooo0000o`3oool0803oool00`000000k>c/0>c/k0020>c/k0L0oooo0@00
00010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0/k>c00<000000<K6aP36a/H01P36a/H0
0`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool04`3oool3
0?l000030000o`3o0000o`000080o`00:@3oool00`000000k>c/0>c/k00X0>c/k0800000H`3IfMT0
0`000000k>c/0>c/k00U0>c/k0030000003oool0oooo02h0oooo00<0003o0?ooo`3oool07`3oool0
10000000k>c/0>c/k03/k>`70?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool3
0;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00?
0>c/k0030000003oool0oooo01H0oooo00<0003o0?l0003o0000:`3oool00`000000k>c/0>c/k00X
0>c/k0030000003IfMT0fMWI06@0fMWI0P00000V0>c/k0030000003oool0oooo02d0oooo00<0003o
0?l0003o00007`3oool010000000k>c/0>c/k03/k>`70?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool30;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT0
0`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0:`3oool0
0`000000k>c/0>c/k00W0>c/k0030000003IfMT0fMWI06L0fMWI00<000000>c/k03/k>`0903/k>`0
0`000000oooo0?ooo`0Z0?ooo`80o`0000<0003o0?l0003o00000`3o000M0?ooo`030000003/k>`0
k>c/00L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0/k>c00<000000<K6
aP36a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003/k>`0k>c/02H0k>c/00<000000=WI
f@3IfMT0J03IfMT00`000000k>c/0>c/k00U0>c/k0030000003oool0oooo02P0oooo103o00000`00
0?l00?l0003o00030?l001`0oooo00<000000>c/k03/k>`01`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo0`2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00P0
fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo02/0
oooo00<000000>c/k03/k>`09P3/k>`00`000000fMWI0=WIf@1Z0=WIf@030000003/k>`0k>c/02@0
k>c/00<000000?ooo`3oool0:03oool30?l00005003o00000?l0003o0000o`00o`000P3o000L0?oo
o`030000003/k>`0k>c/00L0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80
/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0
k>c/00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003/k>`0k>c/02H0
k>c/00<000000=WIf@3IfMT0K03IfMT2000002D0k>c/00<000000?ooo`3oool09`3oool20?l00003
003o00000?l0003o00<0003o00<00?l00?l0003oool06`3oool00`000000k>c/0>c/k0070?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3oool20;>c/`0300000036a/H0a/K600H0a/K6
00<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01D0oooo
00<0003o0?ooo`3oool0:`3oool00`000000k>c/0>c/k00U0>c/k0030000003IfMT0fMWI06l0fMWI
00<000000>c/k03/k>`08P3/k>`00`000000oooo0?ooo`0V0?ooo`<0o`0000<00?l00000o`000?l0
0`000?l00`00o`00o`000?l0000L0?ooo`030000003/k>`0oooo00H0oooo0@0000010?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`80/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WI
f@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0Z0?ooo`030000003/k>`0k>c/02D0k>c/00<000000=WIf@3IfMT0L03IfMT00`000000k>c/0>c/
k00S0>c/k0030000003oool0oooo02D0oooo0`3o00000`00o`00003o0000o`030000o`03003o003o
0000o`0001`0oooo00<000000>c/k03oool01P3oool100000040oooo000O0?ooo`<000001@3oool2
0;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00?
0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0:P3oool00`000000k>c/0>c/k00T
0>c/k0030000003IfMT0fMWI0780fMWI00<000000>c/k03/k>`08P3/k>`00`000000oooo0?ooo`0V
0?ooo`<0o`0000D00?l00000o`000?l0003o003o00020?l001d0oooo00<000000>c/k03oool01@3o
ool200000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0/k>c00000036a/H01`36a/H0
0`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`0Z0?ooo`030000003/k>`0k>c/02@0k>c/00<000000=WIf@3IfMT0M03IfMT0
0`000000k>c/0>c/k00R0>c/k0030000003oool0oooo02D0oooo103o0002003o00040000o`3o0000
o`000?l001d0oooo00<000000>c/k03oool01P3oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo00<0/k>c00000036a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0
k>c/00l0k>c/00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003/k>`0
k>c/02<0k>c/00<000000=WIf@3IfMT0MP3IfMT00`000000k>c/0>c/k00Q0>c/k0030000003oool0
oooo02D0oooo1`3o00000`000?l0o`000?l0000N0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030;>c/`000000a/K600L0a/K600<000000=WI
f@3IfMT0203IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01D0oooo00<0003o0?oo
o`3oool0:@3oool00`000000k>c/0>c/k00T0>c/k0030000003IfMT0fMWI07L0fMWI00<000000>c/
k03/k>`08@3/k>`00`000000oooo0?ooo`0U0?ooo`H0o`0000<0003o0?l0003oool07P3oool00`00
0000oooo0?ooo`050?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000
a/K60<K6aP070<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`08`3/k>`2000007/0
fMWI00<000000>c/k03/k>`08@3/k>`00`000000oooo0?ooo`0W0?ooo`80o`0000<0oooo0000o`3o
ool0803oool00`000000oooo0?ooo`040?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`0
3`3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`0
8P3/k>`00`000000fMWI0=WIf@1l0=WIf@030000003/k>`0k>c/0200k>c/00<000000?ooo`3oool0
:`3oool00`000?l0oooo0?ooo`0U0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool90<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`08P3/k>`00`000000fMWI0=WI
f@1n0=WIf@030000003/k>`0k>c/0200k>c/0P00000[0?ooo`030000o`3oool0oooo02D0oooo0@00
00010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`T0a/K600<000000=WIf@3IfMT0203IfMT0
0`000000k>c/0>c/k00>0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0:@3oool0
0`000000k>c/0>c/k00Q0>c/k0030000003IfMT0fMWI0800fMWI00<000000>c/k03/k>`0803/k>`0
0`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo02@0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`P0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00=0>c/
k0030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0:03oool00`000000k>c/0>c/k00R0>c/
k0030000003IfMT0fMWI03D0fMWI5P00000f0=WIf@030000003/k>`0k>c/0200k>c/00<000000?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`0T0?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool80<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo00<000000>c/k03/k>`08@3/k>`00`000000
fMWI0=WIf@0b0=WIf@@000005P36a/H4000003<0fMWI00<000000>c/k03/k>`07`3/k>`00`000000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo02@0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`P0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000
003oool0oooo01D0oooo00<0003o0?ooo`3oool0:03oool00`000000k>c/0>c/k00Q0>c/k0030000
003IfMT0fMWI02h0fMWI1@00000N0<K6aP<00000<@3IfMT00`000000k>c/0>c/k00O0>c/k0030000
003oool0oooo02T0oooo00<0003o0?ooo`3oool08`3oool100000040oooo000O0?ooo`030000003o
ool0oooo00D0oooo1`36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/00h0k>c/00<0
00000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0W0?ooo`030000003/k>`0k>c/0240k>c/00<0
00000=WIf@3IfMT0;@3IfMT2000002H0a/K60P00000_0=WIf@030000003/k>`0k>c/01l0k>c/00<0
00000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0S0?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool01@3oool70<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`0
0`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo02P0oooo00<000000>c/k03/k>`0803/k>`0
0`000000fMWI0=WIf@0/0=WIf@800000:P36a/H3000002d0fMWI00<000000>c/k03/k>`07`3/k>`0
0`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo02<0oooo0@0000010?ooo`007`3oool30000
00D0oooo1P36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0k>c/00h0k>c/00<000000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`0W0?ooo`030000003/k>`0k>c/0240k>c/00<000000=WI
f@3IfMT0:P3IfMT2000002l0a/K60`00000[0=WIf@030000003/k>`0k>c/01h0k>c/00<000000?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`0Q0?ooo`8000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool60<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo02P0oooo00<000000>c/k03/k>`0803/k>`00`000000
fMWI0=WIf@0Y0=WIf@800000=036a/H00`000000fMWI0=WIf@0Y0=WIf@030000003/k>`0k>c/01h0
k>c/00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0R0?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool01@3oool60<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0
3P3/k>`00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo02L0oooo00<000000>c/k03/k>`0
803/k>`00`000000fMWI0=WIf@0X0=WIf@800000=`36a/H2000002T0fMWI00<000000>c/k03/k>`0
7P3/k>`00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0240oooo0@0000010?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`D0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/
k00>0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool09P3oool00`000000k>c/0>c/
k00P0>c/k0030000003IfMT0fMWI02L0fMWI0P00000k0<K6aP800000:03IfMT00`000000k>c/0>c/
k00N0>c/k0030000003oool0oooo02P0oooo00<0003o0?l0003o00008@3oool100000040oooo000O
0?ooo`030000003oool0oooo00D0oooo1@36a/H00`000000fMWI0=WIf@090=WIf@030000003/k>`0
k>c/00h0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0W0?ooo`030000003/k>`0
k>c/0200k>c/00<000000=WIf@3IfMT09@3IfMT2000003l0a/K60P00000W0=WIf@030000003/k>`0
k>c/01d0k>c/00<000000?ooo`3oool09P3oool20?l000030000o`3o0000o`0000<0o`007P3oool1
00000040oooo000O0?ooo`030000003oool0oooo00D0oooo1@36a/H00`000000fMWI0=WIf@090=WI
f@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0V0?oo
o`030000003/k>`0k>c/0200k>c/00<000000=WIf@3IfMT09@3IfMT00`000000a/K60<K6aP110<K6
aP030000003IfMT0fMWI02D0fMWI00<000000>c/k03/k>`07@3/k>`00`000000oooo0?ooo`0T0?oo
o`<0o`0000<00?l00000o`00o`00103o000M0?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool01@3oool50<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo02H0oooo00<000000>c/k03/k>`07`3/k>`00`000000
fMWI0=WIf@0T0=WIf@800000A@36a/H2000002H0fMWI00<000000>c/k03/k>`0703/k>`00`000000
oooo0?ooo`0T0?ooo`80o`0000D00?l00000o`000?l0003o003o00030?l001d0oooo0@0000010?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`@0a/K600<000000=WIf@3IfMT02@3IfMT00`000000
k>c/0>c/k00>0>c/k0030000003oool0oooo01@0oooo00<0003o0?ooo`3oool09P3oool00`000000
k>c/0>c/k00O0>c/k0030000003IfMT0fMWI02@0fMWI00<000000<K6aP36a/H0A`36a/H00`000000
fMWI0=WIf@0S0=WIf@030000003/k>`0k>c/01d0k>c/00<000000?ooo`3oool08`3oool00`3o0000
0?l00000o`040000o`03003o003o0000o`0001d0oooo0@0000010?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`@0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00>0>c/k0030000
003oool0oooo01@0oooo00<0003o0?ooo`3oool09P3oool00`000000k>c/0>c/k00O0>c/k0030000
003IfMT0fMWI0280fMWI0P00001;0<K6aP800000903IfMT00`000000k>c/0>c/k00L0>c/k0030000
003oool0oooo0280oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l001`0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0a/K600<000000=WIf@3IfMT0
203IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0
9@3oool00`000000k>c/0>c/k00O0>c/k0030000003IfMT0fMWI0280fMWI00<000000<K6aP36a/H0
C@36a/H2000002<0fMWI00<000000>c/k03/k>`0703/k>`00`000000oooo0?ooo`0Q0?ooo`80o`00
00<00?l00000o`000?l00`000?l01000o`00o`000?l0003o000L0?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool01@3oool40<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`0
3P3/k>`00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo02D0oooo00<000000>c/k03/k>`0
7`3/k>`00`000000fMWI0=WIf@0R0=WIf@0300000036a/H0a/K60500a/K600<000000=WIf@3IfMT0
803IfMT00`000000k>c/0>c/k00L0>c/k0030000003oool0oooo0280oooo0P3o00000`00o`00003o
0000o`020000o`<0o`007@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1036
a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool04@3o
ool20?l000030?ooo`000?l0oooo02H0oooo00<000000>c/k03/k>`07P3/k>`00`000000fMWI0=WI
f@0Q0=WIf@800000E036a/H200000240fMWI00<000000>c/k03/k>`0703/k>`00`000000oooo0?oo
o`0Q0?ooo`<0o`000`00o`0010000?l0o`000?l0003o000M0?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool30<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/
k>`00`000000oooo0?ooo`0?0?ooo`D0o`0000<0003o0?l0003o00009@3oool00`000000k>c/0>c/
k00N0>c/k0030000003IfMT0fMWI0240fMWI00<000000<K6aP36a/H0EP36a/H00`000000fMWI0=WI
f@0N0=WIf@030000003/k>`0k>c/01`0k>c/00<000000?ooo`3oool08@3oool60?l000040000o`3o
0000o`000?l001d0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0a/K600<0
00000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo00h0oooo0`3o
0003003o00040000o`3o0000o`000?l002@0oooo00<000000>c/k03/k>`07P3/k>`00`000000fMWI
0=WIf@0P0=WIf@0300000036a/H0a/K605L0a/K600<000000=WIf@3IfMT07`3IfMT2000001d0k>c/
00<000000?ooo`3oool08@3oool60?l000030000o`3o0000oooo01d0oooo0@0000010?ooo`007`3o
ool3000000D0oooo0`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00h0k>c/00<0
00000?ooo`3oool03P3oool20?l00003003o00000?l0003o0080003o0`3o000S0?ooo`030000003/
k>`0k>c/01h0k>c/00<000000=WIf@3IfMT07`3IfMT2000005/0a/K600<000000=WIf@3IfMT07`3I
fMT00`000000k>c/0>c/k00L0>c/k0030000003oool0oooo02<0oooo0P3o00000`3oool0003o0?oo
o`0M0?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool20<K6aP030000003IfMT0
fMWI00P0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0>0?ooo`030?l00000o`00
003o00@0003o00<00?l00?l0003o00008`3oool00`000000k>c/0>c/k00M0>c/k0030000003IfMT0
fMWI01l0fMWI00<000000<K6aP36a/H0G036a/H200000200fMWI00<000000>c/k03/k>`06`3/k>`0
0`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo01d0oooo0@0000010?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`80a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/
k0030000003oool0oooo00h0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`00
0?l00240oooo00<000000>c/k03/k>`07P3/k>`00`000000fMWI0=WIf@0N0=WIf@0300000036a/H0
a/K605l0a/K600<000000=WIf@3IfMT07@3IfMT00`000000k>c/0>c/k00L0>c/k0030000003oool0
oooo02H0oooo00<0003o0?ooo`3oool0703oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo0P36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00h0k>c/00<000000?oo
o`3oool03P3oool20?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000o`008@3oool0
0`000000k>c/0>c/k00M0>c/k0030000003IfMT0fMWI01h0fMWI00<000000<K6aP36a/H0H@36a/H0
0`000000fMWI0=WIf@0M0=WIf@030000003/k>`0k>c/01/0k>c/00<000000?ooo`3oool09P3oool0
0`000?l0o`000?l0000L0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool20<K6
aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0?0?oo
o`80o`0000D00?l00000o`000?l0003o003o00030?l00280oooo00<000000>c/k03/k>`0703/k>`0
0`000000fMWI0=WIf@0M0=WIf@800000I@36a/H2000001h0fMWI00<000000>c/k03/k>`06P3/k>`0
0`000000oooo0?ooo`0T0?ooo`<0o`0000<0003o0?l0003o00000P3o000I0?ooo`4000000@3oool0
01l0oooo00<000000?ooo`3oool01@3oool00`36a/H000000=WIf@090=WIf@030000003/k>`0k>c/
00h0k>c/00<000000?ooo`3oool0403oool30?l00003003o00000?l00?l000@0o`008@3oool00`00
0000k>c/0>c/k00M0>c/k0030000003IfMT0fMWI01`0fMWI00<000000<K6aP36a/H0I`36a/H00`00
0000fMWI0=WIf@0L0=WIf@030000003/k>`0k>c/01X0k>c/00<000000?ooo`3oool08P3oool40?l0
00030000o`00o`000?l000<0o`00603oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo00<0a/K60000003IfMT02@3IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo0100
oooo103o00000`000?l0o`000?l000030?l00240oooo00<000000>c/k03/k>`0703/k>`00`000000
fMWI0=WIf@0M0=WIf@0300000036a/H0a/K606L0a/K600<000000=WIf@3IfMT0703IfMT00`000000
k>c/0>c/k00J0>c/k0030000003oool0oooo0280oooo0`3o00001@00o`00003o0000o`000?l00?l0
0080o`00603oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<0a/K60000003I
fMT02@3IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo0140oooo0P3o00000`000?l0
o`000?l000030?l00280oooo00<000000>c/k03/k>`0703/k>`00`000000fMWI0=WIf@0L0=WIf@03
00000036a/H0a/K606T0a/K600<000000=WIf@3IfMT0703IfMT00`000000k>c/0>c/k00J0>c/k003
0000003oool0oooo0240oooo0P3o00000`00o`00003o0000o`030000o`03003o003o0000oooo01L0
oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030<K6aP000000fMWI00T0fMWI
00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3o0000o`0002@0oooo
00<000000>c/k03/k>`0703/k>`00`000000fMWI0=WIf@0K0=WIf@800000K@36a/H2000001d0fMWI
00<000000>c/k03/k>`06P3/k>`00`000000oooo0?ooo`0O0?ooo`<0o`0000<00?l00000o`000?l0
0`000?l00`00o`00o`000?l0000G0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3o
ool00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`0S0?ooo`030000003/k>`0k>c/01`0k>c/00<000000=WIf@3IfMT06`3I
fMT00`000000a/K60<K6aP1_0<K6aP030000003IfMT0fMWI01X0fMWI00<000000>c/k03/k>`06P3/
k>`00`000000oooo0?ooo`0O0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l0
000G0?ooo`4000000@3oool00080oooo100000060?ooo`8000001P3oool4000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00h0k>c/00<00000
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0T0?ooo`030000003/k>`0k>c/01/0k>c/00<00000
0=WIf@3IfMT06`3IfMT00`000000a/K60<K6aP1a0<K6aP030000003IfMT0fMWI01X0fMWI00<00000
0>c/k03/k>`06P3/k>`00`000000oooo0?ooo`0O0?ooo`<0o`0000D00?l00000o`000?l0003o003o
00020?l001P0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`03
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool;0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0S0?ooo`030000003/k>`0k>c/01/0k>c/00<000000=WIf@3IfMT06`3IfMT0
0`000000a/K60<K6aP1c0<K6aP030000003IfMT0fMWI01X0fMWI00<000000>c/k03/k>`06@3/k>`0
0`000000oooo0?ooo`0O0?ooo`@0o`000P00o`0010000?l0o`000?l0003o000H0?ooo`4000000@3o
ool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool:0=WIf@030000003/k>`0
k>c/00h0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0S0?ooo`030000003/k>`0
k>c/01/0k>c/00<000000=WIf@3IfMT06P3IfMT00`000000a/K60<K6aP0c0<K6aPh00000<`36a/H0
0`000000fMWI0=WIf@0K0=WIf@030000003/k>`0k>c/01T0k>c/00<000000?ooo`3oool07P3oool6
0?l000040000o`3o0000o`000?l001P0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool4
000000@0oooo2P3IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo01<0oooo00<0003o
0?ooo`3oool08`3oool00`000000k>c/0>c/k00K0>c/k0030000003IfMT0fMWI01X0fMWI00<00000
0<K6aP36a/H0;036a/H8000000h0/k>c1000000`0<K6aP030000003IfMT0fMWI01X0fMWI00<00000
0>c/k03/k>`06@3/k>`00`000000oooo0?ooo`0O0?ooo`H0o`0000<0003o0?l0003oool05P3oool3
00000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo100000070?oo
o`030000003oool0oooo00D0oooo2P3IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo
01<0oooo00<0003o0?ooo`3oool08`3oool00`000000k>c/0>c/k00K0>c/k0030000003IfMT0fMWI
01T0fMWI00<000000<K6aP36a/H0:`36a/H2000001X0/k>c1P00000[0<K6aP8000006`3IfMT00`00
0000k>c/0>c/k00I0>c/k0030000003oool0oooo0240oooo0P3o00000`3oool0003o0?ooo`0I0?oo
o`4000000@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool:0=WIf@03
0000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0R0?ooo`03
0000003/k>`0k>c/01/0k>c/00<000000=WIf@3IfMT06@3IfMT00`000000a/K60<K6aP0Z0<K6aP80
00008P2c/k<2000002/0a/K600<000000=WIf@3IfMT0603IfMT00`000000k>c/0>c/k00I0>c/k003
0000003oool0oooo02D0oooo00<0003o0?ooo`3oool05`3oool100000040oooo00000`3oool00000
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo2@3IfMT00`000000k>c/0>c/k00>0>c/k0030000
003oool0oooo01<0oooo00<0003o0?ooo`3oool08`3oool00`000000k>c/0>c/k00J0>c/k0030000
003IfMT0fMWI01T0fMWI00<000000<K6aP36a/H09`36a/H4000002H0/k>c0`00000X0<K6aP030000
003IfMT0fMWI01T0fMWI00<000000>c/k03/k>`06@3/k>`00`000000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo01L0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`T0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo0280oooo00<000000>c/k03/k>`06`3/k>`00`000000fMWI0=WIf@0H0=WIf@0300000036
a/H0a/K602D0a/K60`00000]0;>c/`8000009`36a/H00`000000fMWI0=WIf@0H0=WIf@030000003/
k>`0k>c/01T0k>c/00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`0G0?ooo`4000000@3o
ool00080oooo1000000>0?ooo`@000001`3oool00`000000oooo0?ooo`050?ooo`T0fMWI00<00000
0>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0280oooo00<00000
0>c/k03/k>`06P3/k>`00`000000fMWI0=WIf@0I0=WIf@0300000036a/H0a/K602<0a/K60P00000b
0;>c/`<000009@36a/H00`000000fMWI0=WIf@0H0=WIf@030000003/k>`0k>c/01P0k>c/00<00000
0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0F0?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool90=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`0R0?ooo`030000003/k>`0k>c/01X0k>c/00<000000=WIf@3IfMT06@3IfMT00`00
0000a/K60<K6aP0R0<K6aP800000=`2c/k<2000002@0a/K600<000000=WIf@3IfMT0603IfMT00`00
0000k>c/0>c/k00G0>c/k0030000003oool0oooo02D0oooo00<0003o0?ooo`3oool05P3oool10000
0040oooo000O0?ooo`030000003oool0oooo00D0oooo203IfMT00`000000k>c/0>c/k00>0>c/k003
0000003oool0oooo01<0oooo00<0003o0?ooo`3oool08P3oool00`000000k>c/0>c/k00J0>c/k003
0000003IfMT0fMWI01T0fMWI00<000000<K6aP36a/H08036a/H2000003/0/k>c00<000000<K6aP36
a/H08@36a/H00`000000fMWI0=WIf@0H0=WIf@030000003/k>`0k>c/01P0k>c/00<000000?ooo`3o
ool0903oool00`000?l0oooo0?ooo`0F0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0
1@3oool80=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo
0?ooo`0Q0?ooo`030000003/k>`0k>c/01X0k>c/00<000000=WIf@3IfMT06@3IfMT00`000000a/K6
0<K6aP0O0<K6aP800000?P2c/k<200000280a/K600<000000=WIf@3IfMT0603IfMT00`000000k>c/
0>c/k00G0>c/k0030000003oool0oooo02D0oooo00<0003o0?ooo`3oool05@3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo203IfMT00`000000k>c/0>c/k00=0>c/k0030000003o
ool0oooo01@0oooo00<0003o0?ooo`3oool08@3oool00`000000k>c/0>c/k00J0>c/k0030000003I
fMT0fMWI01P0fMWI00<000000<K6aP36a/H07`36a/H00`000000/k>c0;>c/`100;>c/`8000008@36
a/H00`000000fMWI0=WIf@0H0=WIf@030000003/k>`0k>c/01L0k>c/00<000000?ooo`3oool0903o
ool00`000?l0oooo0?ooo`0E0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool8
0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0R
0?ooo`030000003/k>`0k>c/01T0k>c/00<000000=WIf@3IfMT0603IfMT00`000000a/K60<K6aP0O
0<K6aP030000002c/k<0/k>c04<0/k>c0P00000P0<K6aP030000003IfMT0fMWI01L0fMWI00<00000
0>c/k03/k>`05`3/k>`00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01@0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`L0fMWI00<000000>c/k03/k>`03@3/k>`00`00
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0240oooo00<000000>c/k03/k>`06P3/k>`00`00
0000fMWI0=WIf@0G0=WIf@0300000036a/H0a/K601l0a/K600<000000;>c/`2c/k<0AP2c/k<00`00
0000a/K60<K6aP0N0<K6aP030000003IfMT0fMWI01L0fMWI00<000000>c/k03/k>`05`3/k>`00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01@0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`L0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo0240oooo00<000000>c/k03/k>`06@3/k>`00`000000fMWI0=WIf@0H0=WIf@03
00000036a/H0a/K601d0a/K60P00001:0;>c/`8000007`36a/H00`000000fMWI0=WIf@0F0=WIf@03
0000003/k>`0k>c/01L0k>c/00<000000?ooo`3oool0903oool010000?l0oooo0?l0003o000C0?oo
o`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool70=WIf@030000003/k>`0k>c/00d0
k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003/k>`0k>c/01X0
k>c/00<000000=WIf@3IfMT05P3IfMT2000001h0a/K60P00001>0;>c/`0300000036a/H0a/K601d0
a/K600<000000=WIf@3IfMT05P3IfMT00`000000k>c/0>c/k00G0>c/k0030000003oool0oooo0280
oooo0P3o00000`000?l0o`000?l000030?l00100oooo0@0000010?ooo`007`3oool3000000D0oooo
1`3IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0
8@3oool00`000000k>c/0>c/k00I0>c/k0030000003IfMT0fMWI01H0fMWI00<000000<K6aP36a/H0
7@36a/H00`000000/k>c0;>c/`1?0;>c/`0300000036a/H0a/K601d0a/K600<000000=WIf@3IfMT0
5@3IfMT00`000000k>c/0>c/k00G0>c/k0030000003oool0oooo0240oooo0`3o00000`000?l00?l0
003o00040?l000h0oooo0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0fMWI00<0
00000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0200oooo00<0
00000>c/k03/k>`06P3/k>`00`000000fMWI0=WIf@0E0=WIf@0300000036a/H0a/K601`0a/K60P00
001C0;>c/`0300000036a/H0a/K601`0a/K600<000000=WIf@3IfMT05P3IfMT00`000000k>c/0>c/
k00G0>c/k0030000003oool0oooo0200oooo0P3o00000`00o`00003o003o0002003o00<0o`003`3o
ool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P3IfMT00`000000k>c/0>c/k00=
0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool08@3oool00`000000k>c/0>c/k00I
0>c/k0030000003IfMT0fMWI01H0fMWI00<000000<K6aP36a/H06`36a/H00`000000/k>c0;>c/`1D
0;>c/`8000007@36a/H00`000000fMWI0=WIf@0E0=WIf@030000003/k>`0k>c/01L0k>c/00<00000
0?ooo`3oool0803oool01@3o00000?l0003o0000o`00003o00<00?l00P3o00070?ooo`80o`001P3o
ool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P3IfMT00`000000k>c/0>c/k00=
0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool08@3oool00`000000k>c/0>c/k00H
0>c/k0030000003IfMT0fMWI01H0fMWI00<000000<K6aP36a/H06`36a/H00`000000/k>c0;>c/`1G
0;>c/`0300000036a/H0a/K601/0a/K600<000000=WIf@3IfMT05@3IfMT00`000000k>c/0>c/k00G
0>c/k0030000003oool0oooo01h0oooo0P3o0003003o00040000o`00o`000?l0003o00<0o`000`3o
ool80?l000<0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`H0fMWI00<00000
0>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0@0?ooo`80o`0000<0oooo0000o`3oool08@3oool0
0`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01L0fMWI00<000000<K6aP36a/H06P36a/H0
0`000000/k>c0;>c/`1I0;>c/`0300000036a/H0a/K601X0a/K600<000000=WIf@3IfMT05@3IfMT0
0`000000k>c/0>c/k00G0>c/k0030000003oool0oooo01h0oooo0P3o0004003o00030000o`00o`00
0?l000<0o`000P3oool:0?l00080oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`D0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0>0?ooo`D0o`0000<0003o0?l0
003o00008@3oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01H0fMWI00<000000<K6
aP36a/H06P36a/H00`000000/k>c0;>c/`1K0;>c/`8000006`36a/H00`000000fMWI0=WIf@0E0=WI
f@030000003/k>`0k>c/01L0k>c/00<000000?ooo`3oool07P3oool20?l000<00?l000<0003o003o
003o00000`3o00020?ooo`<0o`000`00o`040?l00080oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`D0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0=0?ooo`H0
o`0000@0003o0?l0003o0000o`007`3oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI
01L0fMWI00<000000<K6aP36a/H06@36a/H00`000000/k>c0;>c/`1N0;>c/`0300000036a/H0a/K6
01P0a/K600<000000=WIf@3IfMT05@3IfMT00`000000k>c/0>c/k00G0>c/k0030000003oool0oooo
01h0oooo0`3o00001@00o`00003o0000o`000?l00?l000<0o`000P3oool20?l000D00?l00`3o0002
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool50=WIf@030000003/k>`0k>c/
00d0k>c/00<000000?ooo`3oool03@3oool40?l000800?l000@0003o0?l0003o0000o`007`3oool0
0`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01H0fMWI00<000000<K6aP36a/H06@36a/H0
0`000000/k>c0;>c/`1P0;>c/`0300000036a/H0a/K601P0a/K600<000000=WIf@3IfMT05@3IfMT0
0`000000k>c/0>c/k00G0>c/k0030000003oool0oooo01d0oooo0P3o00000`00o`00003o0000o`03
0000o`04003o003o0000o`000?ooo`80o`001`00o`030?l00040oooo0@0000010?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`@0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0=
0?ooo`<0o`0000D00?l00000o`000?l0003o003o00020?l001h0oooo00<000000>c/k03/k>`0603/
k>`00`000000fMWI0=WIf@0F0=WIf@0300000036a/H0a/K601P0a/K60P00001T0;>c/`8000006@36
a/H00`000000fMWI0=WIf@0E0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool07@3o
ool20?l00003003o00000?l0003o00<0003o00<00?l00?l0003o00000`3o0007003o00<0o`000@3o
ool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo103IfMT00`000000k>c/0>c/k00=
0>c/k0030000003oool0oooo00d0oooo0`3o00000`00o`00003o0000o`030000o`03003o003o0000
o`0001d0oooo00<000000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0E0=WIf@0300000036a/H0
a/K601P0a/K600<000000;>c/`2c/k<0IP2c/k<00`000000a/K60<K6aP0G0<K6aP030000003IfMT0
fMWI01@0fMWI00<000000>c/k03/k>`05P3/k>`00`000000oooo0?ooo`0M0?ooo`80o`0000<00?l0
0000o`000?l00`000?l01P00o`00o`000?l0003o0000oooo0?l000L00?l00P3o00020?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool01@3oool40=WIf@030000003/k>`0k>c/00d0k>c/00<0
00000?ooo`3oool03@3oool30?l00003003o00000?l0003o00<0003o00<00?l00?l0003o0000703o
ool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01D0fMWI00<000000<K6aP36a/H06036
a/H00`000000/k>c0;>c/`1W0;>c/`0300000036a/H0a/K601P0a/K600<000000=WIf@3IfMT0503I
fMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo01d0oooo0P3o00001@00o`00003o0000
o`000?l00?l000<0o`000P3oool20?l000D00?l00`3o00020?ooo`4000000@3oool001l0oooo00<0
00000?ooo`3oool01@3oool40=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool03P3o
ool20?l00003003o00000?l0003o00<0003o00<00?l00?l0003oool0703oool00`000000k>c/0>c/
k00H0>c/k0030000003IfMT0fMWI01D0fMWI00<000000<K6aP36a/H05`36a/H00`000000/k>c0;>c
/`1Y0;>c/`0300000036a/H0a/K601L0a/K600<000000=WIf@3IfMT0503IfMT00`000000k>c/0>c/
k00F0>c/k0030000003oool0oooo01d0oooo0`3o0003003o00040000o`3o0000o`000?l00080oooo
0`3o0003003o00@0o`000P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo103I
fMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo00h0oooo0`3o00001@00o`00003o0000
o`000?l00?l00080o`00703oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01D0fMWI
00<000000<K6aP36a/H05`36a/H00`000000/k>c0;>c/`0^0;>c/`h00000;`2c/k<2000001P0a/K6
00<000000=WIf@3IfMT0503IfMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo01`0oooo
1P3o000010000?l0o`000?l0003o00030?ooo`P0o`000`3oool100000040oooo000O0?ooo`<00000
1@3oool30=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool03`3oool40?l000030000
o`00o`000?l000<0o`00703oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI01@0fMWI
00<000000<K6aP36a/H05`36a/H00`000000/k>c0;>c/`0[0;>c/`@000003P2OWil4000002d0/k>c
00<000000<K6aP36a/H05P36a/H00`000000fMWI0=WIf@0C0=WIf@030000003/k>`0k>c/01H0k>c/
00<000000?ooo`3oool07@3oool50?l000030000o`3o0000o`000080o`001@3oool20?l000D0oooo
0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`<0fMWI00<000000>c/k03/k>`03@3/
k>`00`000000oooo0?ooo`0@0?ooo`<0o`0000<0003o0?l0003o00000P3o000L0?ooo`030000003/
k>`0k>c/01P0k>c/00<000000=WIf@3IfMT0503IfMT00`000000a/K60<K6aP0G0<K6aP030000002c
/k<0/k>c02H0/k>c1P00000F09nOW`D00000:@2c/k<00`000000a/K60<K6aP0F0<K6aP030000003I
fMT0fMWI01<0fMWI00<000000>c/k03/k>`05P3/k>`00`000000oooo0?ooo`0M0?ooo`@0o`0000<0
003o0?l0003o00000`3o000<0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool3
0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04P3oool00`000?l0o`000?l0000O
0?ooo`030000003/k>`0k>c/01P0k>c/00<000000=WIf@3IfMT04`3IfMT00`000000a/K60<K6aP0G
0<K6aP030000002c/k<0/k>c02D0/k>c0P00000Q09nOW`<000009`2c/k<00`000000a/K60<K6aP0F
0<K6aP030000003IfMT0fMWI01<0fMWI00<000000>c/k03/k>`05@3/k>`00`000000oooo0?ooo`0M
0?ooo`@0o`0000<00?l00000o`00o`000`3o000<0?ooo`4000000@3oool001l0oooo00<000000?oo
o`3oool01@3oool20=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`0O0?ooo`030000003/k>`0k>c/01L0k>c/00<000000=WIf@3IfMT0503IfMT00`00
0000a/K60<K6aP0F0<K6aP030000002c/k<0/k>c02<0/k>c0`00000V09nOW`<00000902c/k<00`00
0000a/K60<K6aP0G0<K6aP030000003IfMT0fMWI0180fMWI00<000000>c/k03/k>`05P3/k>`00`00
0000oooo0?ooo`0L0?ooo`<0o`0000D00?l00000o`000?l0003o003o00020?l000`0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80fMWI00<000000>c/k03/k>`03@3/k>`00`00
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01h0oooo00<000000>c/k03/k>`0603/k>`00`00
0000fMWI0=WIf@0C0=WIf@0300000036a/H0a/K601H0a/K600<000000;>c/`2c/k<08P2c/k<20000
02`0WinO0P00000S0;>c/`0300000036a/H0a/K601H0a/K600<000000=WIf@3IfMT04`3IfMT00`00
0000k>c/0>c/k00E0>c/k0030000003oool0oooo01/0oooo0`3o00000`00o`00003o0000o`030000
o`03003o003o0000o`0000/0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`80
fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01h0
oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI0=WIf@0D0=WIf@0300000036a/H0a/K601D0
a/K600<000000;>c/`2c/k<0802c/k<300000300WinO0`00000Q0;>c/`8000005`36a/H00`000000
fMWI0=WIf@0B0=WIf@030000003/k>`0k>c/01H0k>c/00<000000?ooo`3oool06P3oool30?l00003
003o00000?l0003o00<0003o00<00?l00?l0003o00002`3oool100000040oooo000O0?ooo`030000
003oool0oooo00D0oooo0P3IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo0180oooo
00<0003o0?ooo`3oool07P3oool00`000000k>c/0>c/k00G0>c/k0030000003IfMT0fMWI01@0fMWI
00<000000<K6aP36a/H05@36a/H00`000000/k>c0;>c/`0O0;>c/`800000=P2OWil00`000000/k>c
0;>c/`0P0;>c/`0300000036a/H0a/K601D0a/K600<000000=WIf@3IfMT04P3IfMT00`000000k>c/
0>c/k00E0>c/k0030000003oool0oooo01/0oooo0P3o00000`00o`00003o0000o`030000o`03003o
003o0000oooo00/0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030=WIf@00
0000k>c/00h0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0N0?ooo`030000003/
k>`0k>c/01L0k>c/00<000000=WIf@3IfMT04`3IfMT00`000000a/K60<K6aP0E0<K6aP030000002c
/k<0/k>c01l0/k>c00<0000009nOW`2OWil0=`2OWil00`000000/k>c0;>c/`0O0;>c/`0300000036
a/H0a/K601D0a/K600<000000=WIf@3IfMT04P3IfMT00`000000k>c/0>c/k00E0>c/k0030000003o
ool0oooo01/0oooo0`3o00001@00o`00003o0000o`000?l00?l00080o`00303oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo00<0fMWI0000003/k>`03P3/k>`00`000000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo01d0oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI0=WI
f@0C0=WIf@0300000036a/H0a/K601D0a/K600<000000;>c/`2c/k<07P2c/k<2000003/0WinO0P00
000P0;>c/`0300000036a/H0a/K601D0a/K600<000000=WIf@3IfMT04P3IfMT00`000000k>c/0>c/
k00E0>c/k0030000003oool0oooo01X0oooo103o0002003o00040000o`3o0000o`000?l000`0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030=WIf@000000k>c/00h0k>c/00<0
00000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0N0?ooo`030000003/k>`0k>c/01L0k>c/00<0
00000=WIf@3IfMT04`3IfMT00`000000a/K60<K6aP0D0<K6aP030000002c/k<0/k>c01d0/k>c0P00
000o09nOW`<000007P2c/k<00`000000a/K60<K6aP0D0<K6aP030000003IfMT0fMWI01<0fMWI00<0
00000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0K0?ooo`H0o`0000<0003o0?l0003oool0303o
ool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo00<000000>c/k03/k>`03P3/k>`0
0`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01h0oooo00<000000>c/k03/k>`05P3/k>`0
0`000000fMWI0=WIf@0C0=WIf@0300000036a/H0a/K601@0a/K600<000000;>c/`2c/k<0702c/k<2
000004@0WinO0P00000M0;>c/`0300000036a/H0a/K601@0a/K600<000000=WIf@3IfMT04P3IfMT0
0`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01h0oooo0P3o00000`3oool0003o0?ooo`0=
0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000k>c/0>c/k00=0>c/
k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool07@3oool00`000000k>c/0>c/k00G0>c/
k0030000003IfMT0fMWI01<0fMWI00<000000<K6aP36a/H05036a/H00`000000/k>c0;>c/`0K0;>c
/`030000002OWil0WinO04H0WinO00<000000;>c/`2c/k<06P2c/k<00`000000a/K60<K6aP0D0<K6
aP030000003IfMT0fMWI01<0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo00`0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oooa00
k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0M0?ooo`030000003/k>`0k>c/01H0
k>c/00<000000=WIf@3IfMT04`3IfMT00`000000a/K60<K6aP0D0<K6aP030000002c/k<0/k>c01X0
/k>c0P00001:09nOW`8000006`2c/k<00`000000a/K60<K6aP0D0<K6aP030000003IfMT0fMWI0180
fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00/0
oooo0@0000010?ooo`007`3oool3000000D0oooo3`3/k>`00`000000oooo0?ooo`0C0?ooo`030000
o`3oool0oooo01d0oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI0=WIf@0B0=WIf@800000
5@36a/H00`000000/k>c0;>c/`0J0;>c/`030000002OWil0WinO04`0WinO00<000000;>c/`2c/k<0
6@2c/k<00`000000a/K60<K6aP0D0<K6aP030000003IfMT0fMWI0140fMWI00<000000>c/k03/k>`0
5@3/k>`00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00X0oooo0P0000010?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`l0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0M0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT04P3IfMT00`000000a/K60<K6
aP0D0<K6aP030000002c/k<0/k>c01X0/k>c00<0000009nOW`2OWil0CP2OWil00`000000/k>c0;>c
/`0I0;>c/`0300000036a/H0a/K601<0a/K600<000000=WIf@3IfMT04@3IfMT00`000000k>c/0>c/
k00E0>c/k0030000003oool0oooo0200oooo00@0003o0?ooo`3o0000o`002P3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo3P3/k>`00`000000oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo01`0oooo00<000000>c/k03/k>`05`3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036
a/H0a/K601<0a/K600<000000;>c/`2c/k<06P2c/k<00`000000WinO09nOW`1@09nOW`030000002c
/k<0/k>c01T0/k>c00<000000<K6aP36a/H04`36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/
k>`0k>c/01D0k>c/00<000000?ooo`3oool07P3oool20?l000030000o`3o0000o`0000<0o`001`3o
ool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo3P3/k>`00`000000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo01d0oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0B
0=WIf@0300000036a/H0a/K601@0a/K600<000000;>c/`2c/k<0602c/k<2000005@0WinO0P00000J
0;>c/`0300000036a/H0a/K60180a/K600<000000=WIf@3IfMT04@3IfMT00`000000k>c/0>c/k00E
0>c/k0030000003oool0oooo01d0oooo0`3o00000`000?l0o`000?l000040?l000H0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`h0k>c/00<000000?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`0M0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT04P3IfMT00`00
0000a/K60<K6aP0C0<K6aP030000002c/k<0/k>c01P0/k>c00<0000009nOW`2OWil0EP2OWil00`00
0000/k>c0;>c/`0H0;>c/`0300000036a/H0a/K60180a/K600<000000=WIf@3IfMT04@3IfMT00`00
0000k>c/0>c/k00E0>c/k0030000003oool0oooo01`0oooo0`3o00000`000?l00?l0003o00040?l0
00H0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`h0k>c/00<000000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0L0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3I
fMT04P3IfMT00`000000a/K60<K6aP0C0<K6aP030000002c/k<0/k>c01P0/k>c00<0000009nOW`2O
Wil0F02OWil00`000000/k>c0;>c/`0G0;>c/`0300000036a/H0a/K60180a/K600<000000=WIf@3I
fMT04P3IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01`0oooo0P3o00001@00o`00
003o0000o`000?l00?l000<0o`0000<000000?ooo`3oool00`3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo3@3/k>`00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01`0
oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K60180
a/K600<000000;>c/`2c/k<05`2c/k<2000005`0WinO0P00000H0;>c/`0300000036a/H0a/K60180
a/K600<000000=WIf@3IfMT04P3IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01X0
oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l0008000000`3oool10000
0040oooo000O0?ooo`030000003oool0oooo00D0oooo3@3/k>`00`000000oooo0?ooo`0A0?ooo`80
o`0000<0003o0?ooo`3oool0703oool00`000000k>c/0>c/k00F0>c/k0030000003IfMT0fMWI0180
fMWI00<000000<K6aP36a/H04`36a/H00`000000/k>c0;>c/`0F0;>c/`030000002OWil0WinO05h0
WinO00<000000;>c/`2c/k<05P2c/k<00`000000a/K60<K6aP0A0<K6aP030000003IfMT0fMWI0180
fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0J0?ooo`80o`0000<00?l00000o`00
0?l00`000?l01000o`00o`000?l0003o000300000080oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`050?ooo`d0k>c/00<000000?ooo`3oool03P3oool50?l000030000o`3o0000o`0001`0
oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K60180
a/K600<000000;>c/`2c/k<05P2c/k<00`000000WinO09nOW`1P09nOW`030000002c/k<0/k>c01H0
/k>c00<000000<K6aP36a/H04@36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/01@0
k>c/00<000000?ooo`3oool06@3oool2000000030?l00000o`00003o00@0003o00@00?l00?l0003o
0000o`00100000010?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0103oool20?l000`0
k>c/00<000000?ooo`3oool03@3oool60?l000040000o`3o0000o`000?l001/0oooo00<000000>c/
k03/k>`05@3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K60180a/K600<000000;>c
/`2c/k<05@2c/k<2000006@0WinO0P00000F0;>c/`0300000036a/H0a/K60180a/K600<000000=WI
f@3IfMT0403IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01T0oooo0P0000020?l0
0003003o00000?l0003o00<0003o00<00?l00?l0003o0000100000010?ooo`4000000@3oool001<0
oooo1`0000050?ooo`040000003oool0oooo0?ooo`P0o`00203/k>`00`000000oooo0?ooo`0>0?oo
o`@0o`000P00o`0010000?l0o`000?l0003o000J0?ooo`030000003/k>`0k>c/01H0k>c/00<00000
0=WIf@3IfMT04P3IfMT00`000000a/K60<K6aP0A0<K6aP030000002c/k<0/k>c01D0/k>c00<00000
09nOW`2OWil0IP2OWil00`000000/k>c0;>c/`0D0;>c/`0300000036a/H0a/K60140a/K600<00000
0=WIf@3IfMT04@3IfMT00`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01L0oooo0`000002
0?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000o`001@0000010?ooo`005P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0o`000`00o`030?l000L0k>c/00<00000
0?ooo`3oool03P3oool30?l00005003o00000?l0003o0000o`00o`000P3o000J0?ooo`030000003/
k>`0k>c/01D0k>c/00<000000=WIf@3IfMT04P3IfMT00`000000a/K60<K6aP0B0<K6aP030000002c
/k<0/k>c01@0/k>c00<0000009nOW`2OWil0:@2OWilD000002X0WinO00<000000;>c/`2c/k<0502c
/k<00`000000a/K60<K6aP0B0<K6aP030000003IfMT0fMWI0100fMWI00<000000>c/k03/k>`0503/
k>`00`000000oooo0?ooo`0G0?ooo`<000000P3o00000`00o`00003o0000o`030000o`04003o003o
0000o`000?l000D000000@3oool001H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?l00005003o00000?l0003o0000o`00o`000P3o00070>c/k0030000003oool0oooo00d0oooo
0`3o00000`00o`00003o0000o`030000o`03003o003o0000o`0001T0oooo00<000000>c/k03/k>`0
5@3/k>`00`000000fMWI0=WIf@0B0=WIf@0300000036a/H0a/K60140a/K600<000000;>c/`2c/k<0
5@2c/k<00`000000WinO09nOW`0T09nOW`D00000502<S8`5000002H0WinO00<000000;>c/`2c/k<0
502c/k<00`000000a/K60<K6aP0B0<K6aP030000003IfMT0fMWI0100fMWI00<000000>c/k03/k>`0
503/k>`00`000000oooo0?ooo`0E0?ooo`D000000P3o00000`00o`00003o0000o`020000o`04003o
003o0000o`000?l000D000000@3oool001H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?l00003003o00000?l0003o00<0003o00<00?l00?l0003/k>`01P3/k>`00`000000oooo
0?ooo`0=0?ooo`<0o`0000<00?l00000o`000?l00`000?l00`00o`00o`000?l0000H0?ooo`030000
003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT04P3IfMT00`000000a/K60<K6aP0A0<K6aP030000
002c/k<0/k>c01@0/k>c0P00000T09nOW`<000007P2<S8`3000002@0WinO0P00000E0;>c/`030000
0036a/H0a/K60140a/K600<000000=WIf@3IfMT04@3IfMT00`000000k>c/0>c/k00C0>c/k0030000
003oool0oooo01D0oooo1@0000020?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000
o`00100000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`8000000`3o00000`00o`00003o
0000o`030000o`03003o003o0000o`0000H0k>c/00<000000?ooo`3oool03P3oool20?l00003003o
00000?l0003o00<0003o00<00?l00?l0003oool0603oool00`000000k>c/0>c/k00E0>c/k0030000
003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04P36a/H00`000000/k>c0;>c/`0C0;>c/`030000
002OWil0WinO0280WinO0P00000T08b<S0800000902OWil00`000000/k>c0;>c/`0C0;>c/`030000
0036a/H0a/K60140a/K600<000000=WIf@3IfMT04@3IfMT00`000000k>c/0>c/k00B0>c/k0030000
003oool0oooo01D0oooo1@0000020?l00003003o00000?l0003o00<0003o00@00?l00?l0003o0000
o`00100000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0o`000080o`00
00<00?l00000o`000?l00`000?l00`00o`00o`000?l000050>c/k0030000003oool0oooo00l0oooo
0`3o00001@00o`00003o0000o`000?l00?l00080o`00603oool00`000000k>c/0>c/k00E0>c/k003
0000003IfMT0fMWI0180fMWI00<000000<K6aP36a/H04@36a/H00`000000/k>c0;>c/`0C0;>c/`03
0000002OWil0WinO0240WinO0P00000X08b<S08000008P2OWil00`000000/k>c0;>c/`0D0;>c/`03
00000036a/H0a/K60100a/K600<000000=WIf@3IfMT04@3IfMT00`000000k>c/0>c/k00C0>c/k003
0000003oool0oooo01@0oooo1@0000020?l00003003o00000?l0003o00<0003o00@00?l00?l0003o
0000o`00100000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
o`0000D00?l00000o`000?l0003o003o00020000o`H0k>c/00<000000?ooo`3oool03`3oool40?l0
00030000o`00o`000?l000<0o`00603oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI
0140fMWI00<000000<K6aP36a/H04@36a/H00`000000/k>c0;>c/`0D0;>c/`030000002OWil0WinO
01d0WinO1000000/08b<S0@000007`2OWil00`000000/k>c0;>c/`0C0;>c/`0300000036a/H0a/K6
0140a/K600<000000=WIf@3IfMT0403IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo
01@0oooo1P0000020?l00005003o00000?l0003o0000o`00o`000`3o000500000040oooo000D0?oo
o`<00000203oool00`000000oooo0?ooo`040?l000<00?l00`3o00000`000?l0k>c/0>c/k0030>c/
k0030000003oool0oooo0100oooo0`3o00000`000?l0o`000?l000020?l001P0oooo00<000000>c/
k03/k>`05@3/k>`00`000000fMWI0=WIf@0A0=WIf@0300000036a/H0a/K60140a/K600<000000;>c
/`2c/k<04`2c/k<2000001h0WinO0P00000d08b<S08000007P2OWil00`000000/k>c0;>c/`0C0;>c
/`0300000036a/H0a/K60140a/K600<000000=WIf@3IfMT0403IfMT00`000000k>c/0>c/k00C0>c/
k0030000003oool0oooo01@0oooo1@0000030?l000<00?l0103o000500000040oooo000F0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o00000`3/k>`0003o0000o`020>c/k003
0000003oool0oooo01@0oooo00<0003o0?l0003oool06P3oool00`000000k>c/0>c/k00E0>c/k003
0000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04@36a/H00`000000/k>c0;>c/`0B0;>c/`03
0000002OWil0WinO01`0WinO0P00000h08b<S08000007@2OWil00`000000/k>c0;>c/`0C0;>c/`03
00000036a/H0a/K60100a/K600<000000=WIf@3IfMT0403IfMT00`000000k>c/0>c/k00C0>c/k003
0000003oool0oooo01@0oooo1@00000:0?l000D000000@3oool001l0oooo00@000000?ooo`3oool0
oooo203o00040>c/k0030000o`3/k>`0000001D0oooo00<0003o0?ooo`3oool06`3oool00`000000
k>c/0>c/k00D0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04@36a/H00`000000
/k>c0;>c/`0B0;>c/`030000002OWil0WinO01/0WinO0P00000l08b<S0800000702OWil2000001@0
/k>c00<000000<K6aP36a/H04036a/H00`000000fMWI0=WIf@0@0=WIf@030000003/k>`0k>c/01<0
k>c/00<000000?ooo`3oool0503oool5000000P0o`00100000010?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool0103oool20?l000P0k>c/0P000?lC0?ooo`80o`0000<0003o0?ooo`3oool0
6P3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H0
4036a/H00`000000/k>c0;>c/`0B0;>c/`030000002OWil0WinO01X0WinO0P00001008b<S0030000
002OWil0WinO01/0WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K60<K6aP0@0<K6aP030000
003IfMT0fMWI0100fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo0?ooo`0D0?ooo`P00000
0P3o000700000040oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`T0k>c/00@0
00000?ooo`000?l0003o3P3oool50?l000030000o`3o0000o`0001X0oooo00<000000>c/k03/k>`0
5@3/k>`00`000000fMWI0=WIf@0@0=WIf@0300000036a/H0a/K60100a/K600<000000;>c/`2c/k<0
4P2c/k<00`000000WinO09nOW`0J09nOW`030000002<S8`0S8b<0440S8b<00<0000009nOW`2OWil0
6P2OWil00`000000/k>c0;>c/`0B0;>c/`0300000036a/H0a/K60100a/K600<000000=WIf@3IfMT0
3`3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo01D0oooo3`0000020?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool01@3oool90>c/k0050000003oool0oooo0?ooo`000?l0
303oool30?l000<00?l000@0003o0?l0003o0000o`00603oool00`000000k>c/0>c/k00E0>c/k003
0000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H04036a/H00`000000/k>c0;>c/`0A0;>c/`03
0000002OWil0WinO01X0WinO00<0000008b<S02<S8`0@`2<S8`2000001/0WinO00<000000;>c/`2c
/k<04@2c/k<00`000000a/K60<K6aP0@0<K6aP030000003IfMT0fMWI0100fMWI00<000000>c/k03/
k>`04`3/k>`00`000000oooo0?ooo`0E0?ooo`d000000`3oool100000040oooo000O0?ooo`030000
003oool0oooo00D0oooo2@3/k>`00`000000oooo0?ooo`020?ooo`80003o2P3oool20?l00005003o
00000?l0003o0000o`00o`000`3o000H0?ooo`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3I
fMT0403IfMT00`000000a/K60<K6aP0@0<K6aP030000002c/k<0/k>c0180/k>c00<0000009nOW`2O
Wil0602OWil2000004P0S8b<0P00000J09nOW`030000002c/k<0/k>c0140/k>c00<000000<K6aP36
a/H04036a/H00`000000fMWI0=WIf@0?0=WIf@800000503/k>`00`000000oooo0?ooo`0G0?ooo`T0
00001@3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo2@3/k>`00`000000oooo
0?ooo`040?ooo`80003o203oool00`3o00000?l00000o`040000o`03003o003o0000o`0001L0oooo
00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0@0=WIf@0300000036a/H0a/K60100a/K6
00<000000;>c/`2c/k<04P2c/k<00`000000WinO09nOW`0G09nOW`800000C02<S8`2000001T0WinO
00<000000;>c/`2c/k<04@2c/k<00`000000a/K60<K6aP0?0<K6aP030000003IfMT0fMWI0100fMWI
00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0I0?ooo`D000001`3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo203/k>`00`000000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00@0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l001H0oooo
00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0@0=WIf@0300000036a/H0a/K60100a/K6
00<000000;>c/`2c/k<04@2c/k<00`000000WinO09nOW`0G09nOW`030000002<S8`0S8b<04h0S8b<
00<0000009nOW`2OWil05P2OWil00`000000/k>c0;>c/`0B0;>c/`0300000036a/H0a/K600l0a/K6
00<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00C0>c/k0030000003oool0oooo02@0oooo
0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`P0k>c/00<000000?ooo`3oool0203o
ool20000o`@0oooo0P3o00000`00o`00003o0000o`030000o`04003o003o0000o`000?l001D0oooo
00<000000>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@0@0=WIf@0300000036a/H0a/K60100a/K6
00<000000;>c/`2c/k<04P2c/k<00`000000WinO09nOW`0E09nOW`800000DP2<S8`2000001L0WinO
00<000000;>c/`2c/k<04P2c/k<00`000000a/K60<K6aP0>0<K6aP030000003IfMT0fMWI0100fMWI
00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0T0?ooo`4000000@3oool001l0oooo0`00
00050?ooo`P0k>c/00<000000?ooo`3oool02P3oool20000o`80oooo0`3o00001@00o`00003o0000
o`000?l00?l000<0o`005P3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI0100fMWI
00<000000<K6aP36a/H03`36a/H00`000000/k>c0;>c/`0A0;>c/`8000005`2OWil00`000000S8b<
08b<S01D08b<S0030000002OWil0WinO01D0WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K6
0<K6aP0?0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`04`3/k>`00`000000oooo
0?ooo`0R0?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool80>c/k0030000003o
ool0oooo00`0oooo00<0003o0?ooo`3o00000P3o00001@00o`00003o0000o`000?l00?l000<0o`00
5P3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI00l0fMWI00<000000<K6aP36a/H0
3`36a/H00`000000/k>c0;>c/`0A0;>c/`030000002OWil0WinO01H0WinO00<0000008b<S02<S8`0
EP2<S8`00`000000WinO09nOW`0E09nOW`030000002c/k<0/k>c0100/k>c00<000000<K6aP36a/H0
3`36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool0
8`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo203/k>`00`000000oooo0?oo
o`0=0?ooo`80003o00<0o`00003o00000?l010000?l00`00o`00o`000?l0000F0?ooo`030000003/
k>`0k>c/01@0k>c/00<000000=WIf@3IfMT0403IfMT00`000000a/K60<K6aP0?0<K6aP030000002c
/k<0/k>c0100/k>c00<0000009nOW`2OWil05P2OWil00`000000S8b<08b<S01H08b<S0030000002O
Wil0WinO01@0WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K60<K6aP0?0<K6aP030000003I
fMT0fMWI00l0fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0S0?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool70>c/k0030000003oool0oooo00h0oooo0P3o0000
0`000?l00?l00000o`040000o`03003o003o0000o`0001D0oooo00<000000>c/k03/k>`05@3/k>`0
0`000000fMWI0=WIf@0?0=WIf@0300000036a/H0a/K600l0a/K600<000000;>c/`2c/k<04@2c/k<0
0`000000WinO09nOW`0D09nOW`800000G02<S8`00`000000WinO09nOW`0D09nOW`030000002c/k<0
/k>c0100/k>c00<000000<K6aP36a/H03`36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0
k>c/01<0k>c/00<000000?ooo`3oool08P3oool100000040oooo000O0?ooo`030000003oool0oooo
00D0oooo1`3/k>`00`000000oooo0?ooo`0>0?ooo`80o`0000<00?l00000o`000?l010000?l00`00
o`00o`000?l0000E0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT0403IfMT00`00
0000a/K60<K6aP0?0<K6aP030000002c/k<0/k>c0100/k>c00<0000009nOW`2OWil0502OWil00`00
0000S8b<08b<S01M08b<S08000005@2OWil00`000000/k>c0;>c/`0@0;>c/`0300000036a/H0a/K6
00l0a/K600<000000=WIf@3IfMT03`3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo
0280oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`L0k>c/00<000000?ooo`3o
ool03P3oool20?l00003003o00000?l0003o00@0003o00<00?l00?l0003o00005@3oool00`000000
k>c/0>c/k00C0>c/k0030000003IfMT0fMWI0100fMWI00<000000<K6aP36a/H03`36a/H00`000000
/k>c0;>c/`0A0;>c/`030000002OWil0WinO01<0WinO00<0000008b<S02<S8`0H02<S8`00`000000
WinO09nOW`0C09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H03`36a/H00`000000
fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08P3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo1P3/k>`00`000000oooo0?ooo`0?0?ooo`80o`00
00<00?l00000o`000?l010000?l01000o`00o`000?l0003o000C0?ooo`030000003/k>`0k>c/01@0
k>c/00<000000=WIf@3IfMT0403IfMT00`000000a/K60<K6aP0?0<K6aP030000002c/k<0/k>c0100
/k>c00<0000009nOW`2OWil04`2OWil00`000000S8b<08b<S00Y08b<S0h00000:`2<S8`00`000000
WinO09nOW`0C09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H03`36a/H00`000000
fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool08@3oool100000040
oooo000O0?ooo`030000003oool0oooo00D0oooo1P3/k>`00`000000oooo0?ooo`0@0?ooo`030?l0
0000o`00003o00D0003o00@00?l00?l0003o0000o`004`3oool00`000000k>c/0>c/k00C0>c/k003
0000003IfMT0fMWI0100fMWI00<000000<K6aP36a/H03`36a/H00`000000/k>c0;>c/`0@0;>c/`03
0000002OWil0WinO01<0WinO00<0000008b<S02<S8`09P2<S8`4000000h0NGUi1000000X08b<S003
0000002OWil0WinO01<0WinO00<000000;>c/`2c/k<03`2c/k<00`000000a/K60<K6aP0>0<K6aP03
0000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0Q0?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool01@3oool60>c/k0030000003oool0oooo0100oooo
0P3o00000`00o`00003o0000o`020000o`04003o003o0000o`000?l001@0oooo00<000000>c/k03/
k>`04`3/k>`00`000000fMWI0=WIf@0@0=WIf@0300000036a/H0a/K600l0a/K600<000000;>c/`2c
/k<03`2c/k<00`000000WinO09nOW`0C09nOW`030000002<S8`0S8b<0280S8b<1@00000F07UiN@D0
0000902<S8`00`000000WinO09nOW`0C09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36
a/H03P36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3o
ool0803oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo1P3/k>`00`000000oooo
0?ooo`0@0?ooo`<0o`001000o`040?l001<0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI
0=WIf@0?0=WIf@0300000036a/H0a/K600l0a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO
09nOW`0C09nOW`030000002<S8`0S8b<0200S8b<0`00000P07UiN@<000008P2<S8`00`000000WinO
09nOW`0B09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H03`36a/H00`000000fMWI
0=WIf@0>0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0803oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo1@3/k>`00`000000oooo0?ooo`0B0?ooo`X0o`004`3o
ool00`000000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI00l0fMWI00<000000<K6aP36a/H03P36
a/H00`000000/k>c0;>c/`0@0;>c/`030000002OWil0WinO0180WinO00<0000008b<S02<S8`07P2<
S8`3000002H0NGUi0`00000P08b<S0030000002OWil0WinO0180WinO00<000000;>c/`2c/k<03`2c
/k<00`000000a/K60<K6aP0>0<K6aP030000003IfMT0fMWI00l0fMWI00<000000>c/k03/k>`04P3/
k>`00`000000oooo0?ooo`0O0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool5
0>c/k0030000003oool0oooo01<0oooo203o000C0?ooo`030000003/k>`0k>c/01@0k>c/00<00000
0=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c0100/k>c00<00000
09nOW`2OWil04P2OWil00`000000S8b<08b<S00M08b<S0800000;01iNGT2000001l0S8b<00<00000
09nOW`2OWil04@2OWil00`000000/k>c0;>c/`0?0;>c/`0300000036a/H0a/K600l0a/K600<00000
0=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo01l0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`D0k>c/00<000000?ooo`3oool05P3oool20?l0
01H0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0?0=WIf@0300000036a/H0a/K6
00h0a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO09nOW`0B09nOW`030000002<S8`0S8b<
01`0S8b<0P00000`07UiN@<000007@2<S8`00`000000WinO09nOW`0A09nOW`030000002c/k<0/k>c
00l0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/k>`0k>c/
0140k>c/00<000000?ooo`3oool07`3oool100000040oooo000O0?ooo`030000003oool0oooo00D0
oooo1@3/k>`00`000000oooo0?ooo`0^0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3I
fMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00l0/k>c00<0000009nOW`2O
Wil04P2OWil00`000000S8b<08b<S00K08b<S0800000=@1iNGT2000001`0S8b<00<0000009nOW`2O
Wil04@2OWil00`000000/k>c0;>c/`0>0;>c/`0300000036a/H0a/K600h0a/K600<000000=WIf@3I
fMT03`3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01l0oooo0@0000010?ooo`00
7`3oool3000000D0oooo103/k>`00`000000oooo0?ooo`0^0?ooo`030000003/k>`0k>c/01@0k>c/
00<000000=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00l0/k>c
00<0000009nOW`2OWil04@2OWil00`000000S8b<08b<S00J08b<S0800000>@1iNGT00`000000S8b<
08b<S00I08b<S0030000002OWil0WinO0180WinO00<000000;>c/`2c/k<03P2c/k<00`000000a/K6
0<K6aP0>0<K6aP030000003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo
0?ooo`0M0?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool01@3oool40>c/k0030000003o
ool0oooo02h0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0?0=WIf@0300000036
a/H0a/K600h0a/K600<000000;>c/`2c/k<03`2c/k<00`000000WinO09nOW`0A09nOW`030000002<
S8`0S8b<01T0S8b<0P00000l07UiN@8000006P2<S8`00`000000WinO09nOW`0B09nOW`030000002c
/k<0/k>c00d0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0?0=WIf@030000003/
k>`0k>c/0140k>c/00<000000?ooo`3oool07P3oool100000040oooo000O0?ooo`030000003oool0
oooo00D0oooo103/k>`00`000000oooo0?ooo`0^0?ooo`030000003/k>`0k>c/01<0k>c/00<00000
0=WIf@3IfMT03`3IfMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00l0/k>c00<00000
09nOW`2OWil0402OWil00`000000S8b<08b<S00H08b<S0800000@01iNGT00`000000S8b<08b<S00H
08b<S08000004P2OWil00`000000/k>c0;>c/`0>0;>c/`0300000036a/H0a/K600h0a/K600<00000
0=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo01d0oooo0@000001
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`@0k>c/00<000000?ooo`3oool0;@3oool00`00
0000k>c/0>c/k00D0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H03P36a/H00`00
0000/k>c0;>c/`0?0;>c/`030000002OWil0WinO0100WinO00<0000008b<S02<S8`05`2<S8`20000
04<0NGUi0P00000J08b<S0030000002OWil0WinO0100WinO00<000000;>c/`2c/k<03P2c/k<00`00
0000a/K60<K6aP0>0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`04P3/k>`00`00
0000oooo0?ooo`0M0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool30>c/k003
0000003oool0oooo02h0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0?0=WIf@03
00000036a/H0a/K600h0a/K600<000000;>c/`2c/k<03P2c/k<00`000000WinO09nOW`0@09nOW`03
0000002<S8`0S8b<01L0S8b<00<0000007UiN@1iNGT0A@1iNGT2000001P0S8b<00<0000009nOW`2O
Wil0402OWil00`000000/k>c0;>c/`0>0;>c/`0300000036a/H0a/K600h0a/K600<000000=WIf@3I
fMT03P3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01d0oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`050?ooo`<0k>c/00<000000?ooo`3oool0;@3oool00`000000k>c/
0>c/k00D0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H03P36a/H00`000000/k>c
0;>c/`0?0;>c/`030000002OWil0WinO0100WinO00<0000008b<S02<S8`05P2<S8`00`000000NGUi
07UiN@1807UiN@8000005`2<S8`00`000000WinO09nOW`0@09nOW`030000002c/k<0/k>c00h0/k>c
00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/0180k>c/
00<000000?ooo`3oool0703oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0`3/
k>`00`000000oooo0?ooo`0]0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT03`3I
fMT00`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c00h0/k>c00<0000009nOW`2OWil03`2O
Wil2000001P0S8b<00<0000007UiN@1iNGT0B`1iNGT00`000000S8b<08b<S00E08b<S0030000002O
Wil0WinO0100WinO00<000000;>c/`2c/k<03P2c/k<00`000000a/K60<K6aP0=0<K6aP030000003I
fMT0fMWI00h0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0L0?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool01@3oool30>c/k0030000003oool0oooo02d0oooo00<00000
0>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600h0a/K600<00000
0;>c/`2c/k<03P2c/k<00`000000WinO09nOW`0?09nOW`030000002<S8`0S8b<01H0S8b<0P00001?
07UiN@030000002<S8`0S8b<01D0S8b<00<0000009nOW`2OWil0402OWil00`000000/k>c0;>c/`0>
0;>c/`0300000036a/H0a/K600d0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00B
0>c/k0030000003oool0oooo01/0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`80k>c/00<000000?ooo`3oool0;@3oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI
00l0fMWI00<000000<K6aP36a/H03P36a/H00`000000/k>c0;>c/`0=0;>c/`030000002OWil0WinO
00l0WinO00<0000008b<S02<S8`05@2<S8`200000580NGUi0P00000F08b<S0030000002OWil0WinO
00l0WinO00<000000;>c/`2c/k<03P2c/k<00`000000a/K60<K6aP0=0<K6aP030000003IfMT0fMWI
00h0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0K0?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool01@3oool20>c/k0030000003oool0oooo02d0oooo00<000000>c/k03/
k>`04`3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600h0a/K600<000000;>c/`2c
/k<03@2c/k<00`000000WinO09nOW`0?09nOW`030000002<S8`0S8b<01@0S8b<0P00001F07UiN@80
00005@2<S8`00`000000WinO09nOW`0?09nOW`030000002c/k<0/k>c00h0/k>c00<000000<K6aP36
a/H03@36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3o
ool06P3oool100000040oooo000O0?ooo`030000003oool0oooo00D0oooo0P3/k>`00`000000oooo
0?ooo`0/0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K6
0<K6aP0>0<K6aP030000002c/k<0/k>c00d0/k>c00<0000009nOW`2OWil0402OWil00`000000S8b<
08b<S00D08b<S0030000001iNGT0NGUi05H0NGUi00<0000008b<S02<S8`0502<S8`00`000000WinO
09nOW`0?09nOW`030000002c/k<0/k>c00d0/k>c00<000000<K6aP36a/H03@36a/H00`000000fMWI
0=WIf@0>0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool06P3oool100000040oooo
000O0?ooo`030000003oool0oooo00D0oooo00<0k>c/0000003oool0;P3oool00`000000k>c/0>c/
k00C0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H03P36a/H00`000000/k>c0;>c
/`0=0;>c/`030000002OWil0WinO00l0WinO00<0000008b<S02<S8`0502<S8`00`000000NGUi07Ui
N@1H07UiN@030000002<S8`0S8b<01@0S8b<00<0000009nOW`2OWil03P2OWil00`000000/k>c0;>c
/`0>0;>c/`0300000036a/H0a/K600d0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/
k00A0>c/k0030000003oool0oooo01X0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`030>c/k0000000oooo02d0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0>
0=WIf@0300000036a/H0a/K600h0a/K600<000000;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0?
09nOW`030000002<S8`0S8b<01<0S8b<0P00001L07UiN@8000005@2<S8`00`000000WinO09nOW`0>
09nOW`030000002c/k<0/k>c00d0/k>c00<000000<K6aP36a/H03@36a/H00`000000fMWI0=WIf@0>
0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool06@3oool100000040oooo000O0?oo
o`<000001@3oool00`3/k>`000000?ooo`0]0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WI
f@3IfMT03P3IfMT00`000000a/K60<K6aP0=0<K6aP030000002c/k<0/k>c00h0/k>c00<0000009nO
W`2OWil03P2OWil00`000000S8b<08b<S00C08b<S0030000001iNGT0NGUi02H0NGUi4000000X07Ui
N@030000002<S8`0S8b<01<0S8b<00<0000009nOW`2OWil03P2OWil00`000000/k>c0;>c/`0=0;>c
/`0300000036a/H0a/K600d0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00A0>c/
k0030000003oool0oooo01P0oooo0P0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`03
0>c/k0000000oooo02d0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0>0=WIf@03
00000036a/H0a/K600`0a/K600<000000;>c/`2c/k<03P2c/k<00`000000WinO09nOW`0>09nOW`03
0000002<S8`0S8b<01<0S8b<00<0000007UiN@1iNGT08@1iNGT600000100IVIV1`00000R07UiN@03
0000002<S8`0S8b<0180S8b<00<0000009nOW`2OWil03P2OWil00`000000/k>c0;>c/`0=0;>c/`03
00000036a/H0a/K600d0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00A0>c/k003
0000003oool0oooo01T0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02`0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@0=0=WIf@030000
0036a/H0a/K600d0a/K600<000000;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0?09nOW`030000
002<S8`0S8b<0140S8b<0P00000R07UiN@8000007@1VIVH300000200NGUi0P00000C08b<S0030000
002OWil0WinO00h0WinO00<000000;>c/`2c/k<03@2c/k<00`000000a/K60<K6aP0<0<K6aP030000
003IfMT0fMWI00h0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0I0?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`030000003/
k>`0k>c/01<0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0<0<K6aP030000002c
/k<0/k>c00h0/k>c00<0000009nOW`2OWil03P2OWil00`000000S8b<08b<S00A08b<S0030000001i
NGT0NGUi01l0NGUi0`00000R06IVIP800000801iNGT00`000000S8b<08b<S00A08b<S0030000002O
Wil0WinO00d0WinO00<000000;>c/`2c/k<03@2c/k<00`000000a/K60<K6aP0=0<K6aP030000003I
fMT0fMWI00d0fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0H0?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool0=03oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0
fMWI00h0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0=0;>c/`030000002OWil0
WinO00h0WinO00<0000008b<S02<S8`04@2<S8`00`000000NGUi07UiN@0K07UiN@D000009`1VIVH4
000001d0NGUi00<0000008b<S02<S8`04@2<S8`00`000000WinO09nOW`0=09nOW`030000002c/k<0
/k>c00d0/k>c00<000000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0
k>c/0100k>c/00<000000?ooo`3oool0603oool100000040oooo000O0?ooo`030000003oool0oooo
03@0oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K6
00d0a/K600<000000;>c/`2c/k<0302c/k<00`000000WinO09nOW`0>09nOW`030000002<S8`0S8b<
0140S8b<00<0000007UiN@1iNGT06P1iNGT200000300IVIV0P00000L07UiN@030000002<S8`0S8b<
0140S8b<00<0000009nOW`2OWil0302OWil00`000000/k>c0;>c/`0=0;>c/`0300000036a/H0a/K6
00`0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo
01P0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0d0?ooo`030000003/k>`0k>c/0180
k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0<0<K6aP030000002c/k<0/k>c00d0
/k>c00<0000009nOW`2OWil03P2OWil00`000000S8b<08b<S00@08b<S0030000001iNGT0NGUi01T0
NGUi0P00000d06IVIP8000006`1iNGT00`000000S8b<08b<S00@08b<S0030000002OWil0WinO00d0
WinO00<000000;>c/`2c/k<03@2c/k<00`000000a/K60<K6aP0<0<K6aP030000003IfMT0fMWI00d0
fMWI00<000000>c/k03/k>`04@3/k>`00`000000oooo0?ooo`0G0?ooo`4000000@3oool001l0oooo
00<000000?ooo`3oool0<`3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI00h0fMWI
00<000000<K6aP36a/H03@36a/H00`000000/k>c0;>c/`0<0;>c/`030000002OWil0WinO00h0WinO
00<0000008b<S02<S8`0402<S8`00`000000NGUi07UiN@0H07UiN@800000>01VIVH00`000000NGUi
07UiN@0I07UiN@030000002<S8`0S8b<0100S8b<00<0000009nOW`2OWil03@2OWil00`000000/k>c
0;>c/`0<0;>c/`0300000036a/H0a/K600`0a/K600<000000=WIf@3IfMT03P3IfMT00`000000k>c/
0>c/k00@0>c/k0030000003oool0oooo01L0oooo0@0000010?ooo`007`3oool00`000000oooo0?oo
o`0c0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6
aP0<0<K6aP030000002c/k<0/k>c00d0/k>c00<0000009nOW`2OWil03@2OWil00`000000S8b<08b<
S00@08b<S0030000001iNGT0NGUi01P0NGUi00<0000006IVIP1VIVH0>@1VIVH2000001X0NGUi00<0
000008b<S02<S8`0402<S8`00`000000WinO09nOW`0=09nOW`030000002c/k<0/k>c00`0/k>c00<0
00000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/0140k>c/00<0
00000?ooo`3oool05P3oool100000040oooo000O0?ooo`030000003oool0oooo0380oooo00<00000
0>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600`0a/K600<00000
0;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0=09nOW`030000002<S8`0S8b<0100S8b<00<00000
07UiN@1iNGT05`1iNGT2000003h0IVIV0P00000I07UiN@030000002<S8`0S8b<00l0S8b<00<00000
09nOW`2OWil03@2OWil00`000000/k>c0;>c/`0<0;>c/`0300000036a/H0a/K600`0a/K600<00000
0=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01H0oooo0@000001
0?ooo`0000<0oooo0000000000001@0000040?ooo`8000001@3oool6000000H0oooo00<000000?oo
o`3oool0<P3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6
aP36a/H03036a/H00`000000/k>c0;>c/`0=0;>c/`030000002OWil0WinO00d0WinO00<0000008b<
S02<S8`03`2<S8`00`000000NGUi07UiN@0G07UiN@030000001VIVH0IVIV0400IVIV00<0000007Ui
N@1iNGT05P1iNGT00`000000S8b<08b<S00@08b<S0030000002OWil0WinO00d0WinO00<000000;>c
/`2c/k<0302c/k<00`000000a/K60<K6aP0<0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/
k03/k>`0403/k>`00`000000oooo0?ooo`0F0?ooo`4000000@3oool000@0oooo00<000000?ooo`3o
ool01@3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0340oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@03
00000036a/H0a/K600`0a/K600<000000;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0=09nOW`03
0000002<S8`0S8b<00l0S8b<00<0000007UiN@1iNGT05P1iNGT2000004@0IVIV0P00000G07UiN@03
0000002<S8`0S8b<00l0S8b<00<0000009nOW`2OWil03@2OWil00`000000/k>c0;>c/`0<0;>c/`03
00000036a/H0a/K600`0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00A0>c/k003
0000003oool0oooo01D0oooo0@0000010?ooo`00103oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0<@3oool00`000000k>c/0>c/k00B0>c/k0030000
003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0<0;>c/`800000
3`2OWil00`000000S8b<08b<S00?08b<S0030000001iNGT0NGUi01D0NGUi00<0000006IVIP1VIVH0
AP1VIVH00`000000NGUi07UiN@0E07UiN@030000002<S8`0S8b<00l0S8b<0P00000>09nOW`030000
002c/k<0/k>c00`0/k>c00<000000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0=0=WIf@030000
003/k>`0k>c/0100k>c/00<000000?ooo`3oool05@3oool100000040oooo00040?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool400000300oooo00<000000>c/k03/k>`04P3/
k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K600`0a/K600<000000;>c/`2c/k<02`2c
/k<00`000000WinO09nOW`0>09nOW`030000002<S8`0S8b<00l0S8b<00<0000007UiN@1iNGT05@1i
NGT00`000000IVIV06IVIP1806IVIP8000005P1iNGT00`000000S8b<08b<S00?08b<S0030000002O
Wil0WinO00`0WinO00<000000;>c/`2c/k<03@2c/k<00`000000a/K60<K6aP0;0<K6aP030000003I
fMT0fMWI00d0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0C0?ooo`<000000@3o
ool000@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0300oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0
a/K600`0a/K600<000000;>c/`2c/k<0302c/k<00`000000WinO09nOW`0=09nOW`030000002<S8`0
S8b<00h0S8b<0P00000F07UiN@800000C@1VIVH2000001D0NGUi00<0000008b<S02<S8`03`2<S8`0
0`000000WinO09nOW`0<09nOW`030000002c/k<0/k>c00`0/k>c00<000000<K6aP36a/H03036a/H0
0`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0503oool1
00000040oooo00040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0`0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03P3IfMT00`00
0000a/K60<K6aP0<0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil03P2OWil00`00
0000S8b<08b<S00=08b<S0030000001iNGT0NGUi01D0NGUi00<0000006IVIP1VIVH0C`1VIVH00`00
0000NGUi07UiN@0C07UiN@030000002<S8`0S8b<00h0S8b<00<0000009nOW`2OWil0302OWil00`00
0000/k>c0;>c/`0=0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT03@3IfMT00`00
0000k>c/0>c/k00@0>c/k0030000003oool0oooo01@0oooo0@0000010?ooo`00103oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0`0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03@3IfMT00`000000
a/K60<K6aP0<0<K6aP030000002c/k<0/k>c00`0/k>c00<0000009nOW`2OWil03@2OWil00`000000
S8b<08b<S00>08b<S0030000001iNGT0NGUi01<0NGUi0P00001C06IVIP030000001iNGT0NGUi01<0
NGUi00<0000008b<S02<S8`03P2<S8`00`000000WinO09nOW`0<09nOW`030000002c/k<0/k>c00`0
/k>c00<000000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/0100
k>c/00<000000?ooo`3oool0503oool100000040oooo00020?ooo`<000003P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool00`000000k>c/
0>c/k00B0>c/k0030000003IfMT0fMWI00h0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c
0;>c/`0=0;>c/`030000002OWil0WinO00`0WinO00<0000008b<S02<S8`03P2<S8`00`000000NGUi
07UiN@0C07UiN@030000001VIVH0IVIV05@0IVIV0P00000D07UiN@030000002<S8`0S8b<00h0S8b<
00<0000009nOW`2OWil0302OWil00`000000/k>c0;>c/`0;0;>c/`0300000036a/H0a/K600`0a/K6
00<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01@0oooo
0@0000010?ooo`00103oool00`000000oooo0?ooo`0=0?ooo`@000001`3oool00`000000oooo0?oo
o`0_0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6
aP0<0<K6aP030000002c/k<0/k>c00`0/k>c00<0000009nOW`2OWil0302OWil00`000000S8b<08b<
S00>08b<S0030000001iNGT0NGUi01<0NGUi00<0000006IVIP1VIVH0E`1VIVH00`000000NGUi07Ui
N@0A07UiN@030000002<S8`0S8b<00l0S8b<00<0000009nOW`2OWil02`2OWil00`000000/k>c0;>c
/`0<0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/
k00@0>c/k0030000003oool0oooo01<0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0^
0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0;
0<K6aP030000002c/k<0/k>c00d0/k>c00<0000009nOW`2OWil02`2OWil00`000000S8b<08b<S00?
08b<S0030000001iNGT0NGUi0140NGUi0P00000Y06IVIPL00000:`1VIVH00`000000NGUi07UiN@0A
07UiN@030000002<S8`0S8b<00h0S8b<00<0000009nOW`2OWil0302OWil00`000000/k>c0;>c/`0;
0;>c/`0300000036a/H0a/K600`0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00@
0>c/k0030000003oool0oooo01<0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0^0?oo
o`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K60<K6aP0;0<K6
aP030000002c/k<0/k>c00`0/k>c00<0000009nOW`2OWil0302OWil00`000000S8b<08b<S00>08b<
S0030000001iNGT0NGUi0140NGUi00<0000006IVIP1VIVH08P1VIVH7000000L0De=C2000000T06IV
IP8000004P1iNGT00`000000S8b<08b<S00>08b<S0030000002OWil0WinO00`0WinO00<000000;>c
/`2c/k<02`2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/
k03/k>`0403/k>`00`000000oooo0?ooo`0B0?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool0;P3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36
a/H03036a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO00`0WinO00<0000008b<S02<
S8`03P2<S8`00`000000NGUi07UiN@0A07UiN@030000001VIVH0IVIV01l0IVIV1000000F05=CD`@0
00008P1VIVH00`000000NGUi07UiN@0@07UiN@030000002<S8`0S8b<00h0S8b<00<0000009nOW`2O
Wil0302OWil00`000000/k>c0;>c/`0;0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3I
fMT03@3IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo0180oooo0@0000010?ooo`00
7`3oool00`000000oooo0?ooo`0]0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT0
3P3IfMT00`000000a/K60<K6aP0;0<K6aP030000002c/k<0/k>c00`0/k>c00<0000009nOW`2OWil0
302OWil00`000000S8b<08b<S00=08b<S0030000001iNGT0NGUi0100NGUi0P00000N06IVIP@00000
7P1CDe<4000001l0IVIV00<0000007UiN@1iNGT0401iNGT00`000000S8b<08b<S00=08b<S0030000
002OWil0WinO00`0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP0;0<K6aP030000
003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0A0?ooo`400000
0@3oool001l0oooo00<000000?ooo`3oool0;@3oool00`000000k>c/0>c/k00B0>c/k0030000003I
fMT0fMWI00d0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0;0;>c/`030000002O
Wil0WinO00`0WinO00<0000008b<S02<S8`03@2<S8`00`000000NGUi07UiN@0@07UiN@030000001V
IVH0IVIV01/0IVIV0`00000V05=CD`<000007@1VIVH00`000000NGUi07UiN@0@07UiN@030000002<
S8`0S8b<00d0S8b<00<0000009nOW`2OWil0302OWil00`000000/k>c0;>c/`0;0;>c/`0300000036
a/H0a/K600/0a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00?0>c/k0030000003o
ool0oooo0140oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0]0?ooo`030000003/k>`0
k>c/0140k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0<0<K6aP030000002c/k<0
/k>c00/0/k>c00<0000009nOW`2OWil0302OWil00`000000S8b<08b<S00=08b<S0030000001iNGT0
NGUi0100NGUi00<0000006IVIP1VIVH06P1VIVH2000002`0De=C0P00000L06IVIP030000001iNGT0
NGUi0100NGUi00<0000008b<S02<S8`03@2<S8`00`000000WinO09nOW`0;09nOW`030000002c/k<0
/k>c00/0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0=0=WIf@030000003/k>`0
k>c/00l0k>c/00<000000?ooo`3oool04@3oool100000040oooo000O0?ooo`030000003oool0oooo
02`0oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K6
00`0a/K600<000000;>c/`2c/k<02`2c/k<00`000000WinO09nOW`0;09nOW`030000002<S8`0S8b<
00h0S8b<00<0000007UiN@1iNGT03`1iNGT00`000000IVIV06IVIP0I06IVIP800000<01CDe<20000
01/0IVIV00<0000007UiN@1iNGT0401iNGT00`000000S8b<08b<S00=08b<S0030000002OWil0WinO
00/0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI
00`0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0@0?ooo`4000000@3oool001l0
oooo00<000000?ooo`3oool0;03oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00d0
fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO00`0
WinO00<0000008b<S02<S8`03@2<S8`00`000000NGUi07UiN@0?07UiN@030000001VIVH0IVIV01P0
IVIV0P00000d05=CD`8000006P1VIVH00`000000NGUi07UiN@0?07UiN@030000002<S8`0S8b<00d0
S8b<00<0000009nOW`2OWil02`2OWil00`000000/k>c0;>c/`0;0;>c/`0300000036a/H0a/K600/0
a/K600<000000=WIf@3IfMT03@3IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo0100
oooo0@0000010?ooo`007`3oool3000002`0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI
0=WIf@0=0=WIf@0300000036a/H0a/K600`0a/K600<000000;>c/`2c/k<02`2c/k<00`000000WinO
09nOW`0;09nOW`030000002<S8`0S8b<00d0S8b<00<0000007UiN@1iNGT03`1iNGT00`000000IVIV
06IVIP0F06IVIP<00000>01CDe<3000001P0IVIV00<0000007UiN@1iNGT03`1iNGT00`000000S8b<
08b<S00=08b<S0030000002OWil0WinO00/0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K6
0<K6aP0;0<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo
0?ooo`0?0?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool0:`3oool00`000000k>c/0>c/
k00B0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c0;>c
/`0;0;>c/`030000002OWil0WinO00/0WinO00<0000008b<S02<S8`03@2<S8`00`000000NGUi07Ui
N@0?07UiN@030000001VIVH0IVIV01D0IVIV0P00000n05=CD`030000001VIVH0IVIV01H0IVIV00<0
000007UiN@1iNGT03`1iNGT00`000000S8b<08b<S00<08b<S0030000002OWil0WinO00/0WinO00<0
00000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00`0fMWI00<0
00000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0@0?ooo`4000000@3oool001l0oooo00<00000
0?ooo`3oool0:`3oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI00d0fMWI00<00000
0<K6aP36a/H03036a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO00/0WinO00<00000
08b<S02<S8`03@2<S8`00`000000NGUi07UiN@0>07UiN@030000001VIVH0IVIV01D0IVIV00<00000
05=CD`1CDe<0?`1CDe<00`000000IVIV06IVIP0F06IVIP030000001iNGT0NGUi00l0NGUi00<00000
08b<S02<S8`0302<S8`00`000000WinO09nOW`0;09nOW`030000002c/k<0/k>c00/0/k>c00<00000
0<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/00l0k>c/00<00000
0?ooo`3oool03`3oool100000040oooo000O0?ooo`030000003oool0oooo02X0oooo00<000000>c/
k03/k>`04P3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c
/`2c/k<02`2c/k<00`000000WinO09nOW`0;09nOW`030000002<S8`0S8b<00d0S8b<00<0000007Ui
N@1iNGT03P1iNGT00`000000IVIV06IVIP0D06IVIP800000@`1CDe<2000001L0IVIV00<0000007Ui
N@1iNGT03P1iNGT00`000000S8b<08b<S00<08b<S0030000002OWil0WinO00/0WinO00<000000;>c
/`2c/k<02`2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/
k03/k>`03`3/k>`00`000000oooo0?ooo`0?0?ooo`4000000@3oool001l0oooo00<000000?ooo`3o
ool0:P3oool00`000000k>c/0>c/k00B0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36
a/H02`36a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO00/0WinO00<0000008b<S02<
S8`0302<S8`00`000000NGUi07UiN@0>07UiN@030000001VIVH0IVIV01@0IVIV00<0000005=CD`1C
De<0A@1CDe<2000001H0IVIV00<0000007UiN@1iNGT03P1iNGT00`000000S8b<08b<S00<08b<S003
0000002OWil0WinO00/0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP0;0<K6aP03
0000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0>0?ooo`40
00000@3oool001l0oooo00<000000?ooo`3oool0:P3oool00`000000k>c/0>c/k00A0>c/k0030000
003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c0;>c/`0;0;>c/`030000
002OWil0WinO00/0WinO00<0000008b<S02<S8`0302<S8`00`000000NGUi07UiN@0>07UiN@030000
001VIVH0IVIV01@0IVIV00<0000005=CD`1CDe<0B01CDe<00`000000IVIV06IVIP0C06IVIP030000
001iNGT0NGUi00l0NGUi00<0000008b<S02<S8`0302<S8`00`000000WinO09nOW`0:09nOW`030000
002c/k<0/k>c00/0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0<0=WIf@030000
003/k>`0k>c/00l0k>c/00<000000?ooo`3oool03P3oool100000040oooo000O0?ooo`030000003o
ool0oooo02T0oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036
a/H0a/K600/0a/K600<000000;>c/`2c/k<02`2c/k<00`000000WinO09nOW`0:09nOW`030000002<
S8`0S8b<00`0S8b<00<0000007UiN@1iNGT03P1iNGT00`000000IVIV06IVIP0C06IVIP800000C01C
De<2000001@0IVIV00<0000007UiN@1iNGT03P1iNGT00`000000S8b<08b<S00<08b<S0030000002O
Wil0WinO00/0WinO00<000000;>c/`2c/k<02P2c/k<00`000000a/K60<K6aP0;0<K6aP030000003I
fMT0fMWI00d0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0>0?ooo`4000000@3o
ool001l0oooo00<000000?ooo`3oool0:@3oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0
fMWI00d0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0
WinO00/0WinO00<0000008b<S02<S8`0202<S8`20?l00080S8b<00<0000007UiN@1iNGT03@1iNGT0
0`000000IVIV06IVIP0C06IVIP030000001CDe<0De=C04h0De=C00<0000006IVIP1VIVH04P1VIVH2
000000l0NGUi00<0000008b<S02<S8`0302<S8`00`000000WinO09nOW`0:09nOW`030000002c/k<0
/k>c00/0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0
k>c/00l0k>c/00<000000?ooo`3oool03@3oool100000040oooo000O0?ooo`030000003oool0oooo
02T0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K6
00/0a/K600<000000;>c/`2c/k<02`2c/k<00`000000WinO09nOW`0:09nOW`030000002<S8`0S8b<
00H0S8b<203o000>07UiN@030000001VIVH0IVIV0180IVIV0P00001B05=CD`800000501VIVH00`00
0000NGUi07UiN@0=07UiN@030000002<S8`0S8b<00`0S8b<00<0000009nOW`2OWil02P2OWil00`00
0000/k>c0;>c/`0:0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT0303IfMT00`00
0000k>c/0>c/k00?0>c/k0030000003oool0oooo00d0oooo0@0000010?ooo`007`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT0303IfMT00`000000
a/K60<K6aP0;0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil02P2OWil00`000000
S8b<08b<S00608b<S0<0o`000`00o`040?l000`0NGUi00<0000006IVIP1VIVH04P1VIVH00`000000
De=C05=CD`1D05=CD`030000001VIVH0IVIV0140IVIV00<0000007UiN@1iNGT03P1iNGT00`000000
S8b<08b<S00;08b<S0030000002OWil0WinO00X0WinO00<000000;>c/`2c/k<02P2c/k<00`000000
a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`03`3/k>`00`000000
oooo0?ooo`0=0?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool0:03oool00`000000k>c/
0>c/k00A0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c
0;>c/`0;0;>c/`030000002OWil0WinO00X0WinO00<0000008b<S02<S8`01P2<S8`20?l000D00?l0
0`3o000;07UiN@030000001VIVH0IVIV0180IVIV00<0000005=CD`1CDe<0EP1CDe<00`000000IVIV
06IVIP0A06IVIP030000001iNGT0NGUi00d0NGUi00<0000008b<S02<S8`0302<S8`00`000000WinO
09nOW`0:09nOW`030000002c/k<0/k>c00X0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI
0=WIf@0;0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0303oool100000040oooo
000O0?ooo`030000003oool0oooo02P0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WI
f@0<0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c/k<02`2c/k<00`000000WinO09nO
W`0:09nOW`030000002<S8`0S8b<00L0S8b<00<0o`00003o0000o`001@00o`020?l000/0NGUi00<0
000006IVIP1VIVH0401VIVH200000280De=C5P00000R05=CD`8000004P1VIVH00`000000NGUi07Ui
N@0=07UiN@030000002<S8`0S8b<00/0S8b<00<0000009nOW`2OWil02P2OWil00`000000/k>c0;>c
/`0:0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/
k00?0>c/k0030000003oool0oooo00`0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0X
0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6aP0;
0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil02P2OWil00`000000S8b<08b<S006
08b<S080o`001`00o`030?l000T0NGUi00<0000006IVIP1VIVH0401VIVH00`000000De=C05=CD`0P
05=CD`8000005P0o?cl200000280De=C00<0000006IVIP1VIVH0401VIVH00`000000NGUi07UiN@0=
07UiN@030000002<S8`0S8b<00/0S8b<00<0000009nOW`2OWil02P2OWil00`000000/k>c0;>c/`0:
0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00?
0>c/k0030000003oool0oooo00`0oooo0@0000010?ooo`007`3oool3000007d0oooo0P3o0007003o
00<0o`00o`3oool30?ooo`8000000@3oool001l0oooo00<000000?ooo`3oool0OP3oool20?l000D0
0?l00`3o003o0?ooo`D0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`1n0?ooo`<0o`00
0`00o`040?l00?l0oooo1@3oool100000040oooo000O0?ooo`030000003oool0oooo07h0oooo2P3o
003o0?ooo`D0oooo0@0000010?ooo`007`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo05@0oooo203o001>0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`060?ooo`4000000@3oool001l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080o`00303oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool100000040oooo000O0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`40
00000@3oool001l0ooooo`00002A00000040oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.42861, -0.256896, 0.00864682, \
0.00558979}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({2.002901521029204`*^-11, {X\_1 \[Rule] 0.9999955249004842`, 
            X\_2 \[Rule] 0.9999910448214613`}}\), 
        ",", \({"Steps" \[Rule] 41, "Function" \[Rule] 216, 
          "Gradient" \[Rule] 54}\), ",", 
        TagBox[\(\[SkeletonIndicator]  
            ContourGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[54]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Minimization",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Here is a summary showing all the plots together and all the \
information.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[\((pall\  = \ {p1, p2, p3, 
                p4})\)[\([All, \(-1\)]\)]]]\)], "Input",
  CellLabel->"In[55]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23256 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0055371 0.238095 [
[ 0 0 0 0 ]
[ 1 .23256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23256 L
0 .23256 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0055371 0.245293 0.227021 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.543706 0.437063 0.782104 0.198665 [
[.10664 -0.0125 -6 -9 ]
[.10664 -0.0125 6 0 ]
[.32517 -0.0125 -12 -9 ]
[.32517 -0.0125 12 0 ]
[.54371 -0.0125 -3 -9 ]
[.54371 -0.0125 3 0 ]
[.76224 -0.0125 -9 -9 ]
[.76224 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .18611 -12 -4.5 ]
[-0.0125 .18611 0 4.5 ]
[-0.0125 .38477 -12 -4.5 ]
[-0.0125 .38477 0 4.5 ]
[-0.0125 .58344 -12 -4.5 ]
[-0.0125 .58344 0 4.5 ]
[-0.0125 .7821 -6 -4.5 ]
[-0.0125 .7821 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10664 0 m
.10664 .00625 L
s
[(-1)] .10664 -0.0125 0 1 Mshowa
.32517 0 m
.32517 .00625 L
s
[(-0.5)] .32517 -0.0125 0 1 Mshowa
.54371 0 m
.54371 .00625 L
s
[(0)] .54371 -0.0125 0 1 Mshowa
.76224 0 m
.76224 .00625 L
s
[(0.5)] .76224 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.15035 0 m
.15035 .00375 L
s
.19406 0 m
.19406 .00375 L
s
.23776 0 m
.23776 .00375 L
s
.28147 0 m
.28147 .00375 L
s
.36888 0 m
.36888 .00375 L
s
.41259 0 m
.41259 .00375 L
s
.45629 0 m
.45629 .00375 L
s
.5 0 m
.5 .00375 L
s
.58741 0 m
.58741 .00375 L
s
.63112 0 m
.63112 .00375 L
s
.67483 0 m
.67483 .00375 L
s
.71853 0 m
.71853 .00375 L
s
.80594 0 m
.80594 .00375 L
s
.84965 0 m
.84965 .00375 L
s
.89336 0 m
.89336 .00375 L
s
.93706 0 m
.93706 .00375 L
s
.06294 0 m
.06294 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .18611 m
.00625 .18611 L
s
[(-3)] -0.0125 .18611 1 0 Mshowa
0 .38477 m
.00625 .38477 L
s
[(-2)] -0.0125 .38477 1 0 Mshowa
0 .58344 m
.00625 .58344 L
s
[(-1)] -0.0125 .58344 1 0 Mshowa
0 .7821 m
.00625 .7821 L
s
[(0)] -0.0125 .7821 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .22584 m
.00375 .22584 L
s
0 .26558 m
.00375 .26558 L
s
0 .30531 m
.00375 .30531 L
s
0 .34504 m
.00375 .34504 L
s
0 .42451 m
.00375 .42451 L
s
0 .46424 m
.00375 .46424 L
s
0 .50397 m
.00375 .50397 L
s
0 .54371 m
.00375 .54371 L
s
0 .62317 m
.00375 .62317 L
s
0 .66291 m
.00375 .66291 L
s
0 .70264 m
.00375 .70264 L
s
0 .74237 m
.00375 .74237 L
s
0 .82184 m
.00375 .82184 L
s
0 .86157 m
.00375 .86157 L
s
0 .9013 m
.00375 .9013 L
s
0 .94104 m
.00375 .94104 L
s
0 .14638 m
.00375 .14638 L
s
0 .10664 m
.00375 .10664 L
s
0 .06691 m
.00375 .06691 L
s
0 .02718 m
.00375 .02718 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10664 .99375 m
.10664 1 L
s
.32517 .99375 m
.32517 1 L
s
.54371 .99375 m
.54371 1 L
s
.76224 .99375 m
.76224 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.15035 .99625 m
.15035 1 L
s
.19406 .99625 m
.19406 1 L
s
.23776 .99625 m
.23776 1 L
s
.28147 .99625 m
.28147 1 L
s
.36888 .99625 m
.36888 1 L
s
.41259 .99625 m
.41259 1 L
s
.45629 .99625 m
.45629 1 L
s
.5 .99625 m
.5 1 L
s
.58741 .99625 m
.58741 1 L
s
.63112 .99625 m
.63112 1 L
s
.67483 .99625 m
.67483 1 L
s
.71853 .99625 m
.71853 1 L
s
.80594 .99625 m
.80594 1 L
s
.84965 .99625 m
.84965 1 L
s
.89336 .99625 m
.89336 1 L
s
.93706 .99625 m
.93706 1 L
s
.06294 .99625 m
.06294 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .18611 m
1 .18611 L
s
.99375 .38477 m
1 .38477 L
s
.99375 .58344 m
1 .58344 L
s
.99375 .7821 m
1 .7821 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .22584 m
1 .22584 L
s
.99625 .26558 m
1 .26558 L
s
.99625 .30531 m
1 .30531 L
s
.99625 .34504 m
1 .34504 L
s
.99625 .42451 m
1 .42451 L
s
.99625 .46424 m
1 .46424 L
s
.99625 .50397 m
1 .50397 L
s
.99625 .54371 m
1 .54371 L
s
.99625 .62317 m
1 .62317 L
s
.99625 .66291 m
1 .66291 L
s
.99625 .70264 m
1 .70264 L
s
.99625 .74237 m
1 .74237 L
s
.99625 .82184 m
1 .82184 L
s
.99625 .86157 m
1 .86157 L
s
.99625 .9013 m
1 .9013 L
s
.99625 .94104 m
1 .94104 L
s
.99625 .14638 m
1 .14638 L
s
.99625 .10664 m
1 .10664 L
s
.99625 .06691 m
1 .06691 L
s
.99625 .02718 m
1 .02718 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.625 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .36349 m
.0232 .35917 L
.02894 .35297 L
.03222 .34946 L
.03866 .34264 L
.04141 .33974 L
.04837 .33251 L
.05077 .33003 L
.05808 .32257 L
.06031 .32032 L
.06779 .31283 L
.07004 .31061 L
.07751 .30329 L
.07998 .30089 L
.08722 .29395 L
.09013 .29118 L
.09693 .2848 L
.10052 .28147 L
.10664 .27584 L
.11115 .27176 L
.11636 .26709 L
.12205 .26204 L
.12607 .25853 L
.13324 .25233 L
.13578 .25016 L
.14475 .24262 L
.14549 .242 L
.15521 .23403 L
.15659 .23291 L
.16492 .22625 L
.16881 .22319 L
.17463 .21868 L
.18144 .21348 L
.18434 .2113 L
.19406 .20411 L
.19453 .20377 L
.20377 .19712 L
.20812 .19406 L
.21348 .19033 L
.22229 .18434 L
.22319 .18374 L
.23291 .17734 L
.23711 .17463 L
.24262 .17114 L
.25233 .16513 L
.25268 .16492 L
.26204 .15932 L
.26914 .15521 L
.27176 .15371 L
.28147 .1483 L
.28664 .14549 L
.29118 .14308 L
.30089 .13805 L
.30542 .13578 L
.31061 .13323 L
.32032 .1286 L
.3258 .12607 L
.33003 .12416 L
.33974 .11993 L
.3483 .11636 L
.34946 .11589 L
.35917 .11204 L
.36888 .10839 L
.37374 .10664 L
.37859 .10494 L
.38831 .10169 L
.39802 .09863 L
.40371 .09693 L
.40773 .09577 L
.41744 .0931 L
.42716 .09064 L
.43687 .08836 L
.44211 .08722 L
.44658 .08629 L
.45629 .08441 L
.46601 .08273 L
.47572 .08124 L
.48543 .07995 L
.49514 .07886 L
.50486 .07796 L
.51077 .07751 L
.51457 .07726 L
.52428 .07676 L
.53399 .07645 L
.54371 .07634 L
.55342 .07643 L
.56313 .07671 L
.57284 .07719 L
.57789 .07751 L
.58256 .07786 L
.59227 .07873 L
.60198 .0798 L
.61169 .08107 L
.62141 .08253 L
.63112 .08419 L
.64083 .08604 L
.64653 .08722 L
.65054 .08809 L
.66026 .09034 L
.66997 .09278 L
.67968 .09542 L
.68494 .09693 L
.68939 .09826 L
.69911 .10129 L
.70882 .10452 L
.7149 .10664 L
.71853 .10795 L
.72824 .11157 L
.73796 .11539 L
.74034 .11636 L
.74767 .1194 L
.75738 .12362 L
.76284 .12607 L
.76709 .12802 L
.77681 .13263 L
.78323 .13578 L
.78652 .13743 L
.79623 .14243 L
.80201 .14549 L
.80594 .14762 L
.81566 .15301 L
.81951 .15521 L
.82537 .1586 L
.83508 .16439 L
.83596 .16492 L
.84479 .17037 L
.85153 .17463 L
.85451 .17654 L
.86422 .18292 L
.86635 .18434 L
.87393 .18949 L
.88052 .19406 L
.88364 .19625 L
.89336 .20322 L
.89412 .20377 L
.90307 .21038 L
.9072 .21348 L
.91278 .21773 L
.91983 .22319 L
.92249 .22528 L
.93205 .23291 L
.93221 .23303 L
.94192 .24098 L
.94389 .24262 L
.95163 .24912 L
.9554 .25233 L
.96134 .25746 L
.96659 .26204 L
.97106 .26599 L
.97749 .27176 L
.98077 .27472 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .36349 m
.0232 .35917 L
.02894 .35297 L
.03222 .34946 L
.03866 .34264 L
.04141 .33974 L
.04837 .33251 L
.05077 .33003 L
.05808 .32257 L
.06031 .32032 L
.06779 .31283 L
.07004 .31061 L
.07751 .30329 L
.07998 .30089 L
.08722 .29395 L
.09013 .29118 L
.09693 .2848 L
.10052 .28147 L
.10664 .27584 L
.11115 .27176 L
.11636 .26709 L
.12205 .26204 L
.12607 .25853 L
.13324 .25233 L
.13578 .25016 L
.14475 .24262 L
.14549 .242 L
.15521 .23403 L
.15659 .23291 L
.16492 .22625 L
.16881 .22319 L
.17463 .21868 L
.18144 .21348 L
.18434 .2113 L
.19406 .20411 L
.19453 .20377 L
.20377 .19712 L
.20812 .19406 L
.21348 .19033 L
.22229 .18434 L
.22319 .18374 L
.23291 .17734 L
.23711 .17463 L
.24262 .17114 L
.25233 .16513 L
.25268 .16492 L
.26204 .15932 L
.26914 .15521 L
.27176 .15371 L
.28147 .1483 L
Mistroke
.28664 .14549 L
.29118 .14308 L
.30089 .13805 L
.30542 .13578 L
.31061 .13323 L
.32032 .1286 L
.3258 .12607 L
.33003 .12416 L
.33974 .11993 L
.3483 .11636 L
.34946 .11589 L
.35917 .11204 L
.36888 .10839 L
.37374 .10664 L
.37859 .10494 L
.38831 .10169 L
.39802 .09863 L
.40371 .09693 L
.40773 .09577 L
.41744 .0931 L
.42716 .09064 L
.43687 .08836 L
.44211 .08722 L
.44658 .08629 L
.45629 .08441 L
.46601 .08273 L
.47572 .08124 L
.48543 .07995 L
.49514 .07886 L
.50486 .07796 L
.51077 .07751 L
.51457 .07726 L
.52428 .07676 L
.53399 .07645 L
.54371 .07634 L
.55342 .07643 L
.56313 .07671 L
.57284 .07719 L
.57789 .07751 L
.58256 .07786 L
.59227 .07873 L
.60198 .0798 L
.61169 .08107 L
.62141 .08253 L
.63112 .08419 L
.64083 .08604 L
.64653 .08722 L
.65054 .08809 L
.66026 .09034 L
.66997 .09278 L
Mistroke
.67968 .09542 L
.68494 .09693 L
.68939 .09826 L
.69911 .10129 L
.70882 .10452 L
.7149 .10664 L
.71853 .10795 L
.72824 .11157 L
.73796 .11539 L
.74034 .11636 L
.74767 .1194 L
.75738 .12362 L
.76284 .12607 L
.76709 .12802 L
.77681 .13263 L
.78323 .13578 L
.78652 .13743 L
.79623 .14243 L
.80201 .14549 L
.80594 .14762 L
.81566 .15301 L
.81951 .15521 L
.82537 .1586 L
.83508 .16439 L
.83596 .16492 L
.84479 .17037 L
.85153 .17463 L
.85451 .17654 L
.86422 .18292 L
.86635 .18434 L
.87393 .18949 L
.88052 .19406 L
.88364 .19625 L
.89336 .20322 L
.89412 .20377 L
.90307 .21038 L
.9072 .21348 L
.91278 .21773 L
.91983 .22319 L
.92249 .22528 L
.93205 .23291 L
.93221 .23303 L
.94192 .24098 L
.94389 .24262 L
.95163 .24912 L
.9554 .25233 L
.96134 .25746 L
.96659 .26204 L
.97106 .26599 L
.97749 .27176 L
Mistroke
.98077 .27472 L
Mfstroke
.775 g
.01923 .44258 m
.02448 .43687 L
.02894 .43205 L
.03352 .42716 L
.03866 .42172 L
.04273 .41744 L
.04837 .41159 L
.05211 .40773 L
.05808 .40165 L
.06168 .39802 L
.06779 .3919 L
.07143 .38831 L
.07751 .38236 L
.08139 .37859 L
.08722 .37301 L
.09157 .36888 L
.09693 .36386 L
.10199 .35917 L
.10664 .3549 L
.11266 .34946 L
.11636 .34614 L
.12359 .33974 L
.12607 .33758 L
.13482 .33003 L
.13578 .32921 L
.14549 .32104 L
.14637 .32032 L
.15521 .31307 L
.15826 .31061 L
.16492 .30529 L
.17053 .30089 L
.17463 .29771 L
.18321 .29118 L
.18434 .29033 L
.19406 .28314 L
.19636 .28147 L
.20377 .27615 L
.21002 .27176 L
.21348 .26936 L
.22319 .26276 L
.22427 .26204 L
.23291 .25636 L
.23918 .25233 L
.24262 .25016 L
.25233 .24415 L
.25485 .24262 L
.26204 .23834 L
.27143 .23291 L
.27176 .23272 L
.28147 .2273 L
.28908 .22319 L
.29118 .22208 L
.30089 .21706 L
.30804 .21348 L
.31061 .21223 L
.32032 .20759 L
.32867 .20377 L
.33003 .20316 L
.33974 .19892 L
.34946 .19488 L
.35149 .19406 L
.35917 .19103 L
.36888 .18738 L
.37739 .18434 L
.37859 .18393 L
.38831 .18067 L
.39802 .17761 L
.40773 .17475 L
.40814 .17463 L
.41744 .17208 L
.42716 .16961 L
.43687 .16734 L
.44658 .16526 L
.44826 .16492 L
.45629 .16338 L
.46601 .16169 L
.47572 .1602 L
.48543 .15891 L
.49514 .15782 L
.50486 .15692 L
.51457 .15622 L
.52428 .15571 L
.53399 .1554 L
.54371 .15529 L
.55342 .15538 L
.56313 .15566 L
.57284 .15613 L
.58256 .15681 L
.59227 .15768 L
.60198 .15875 L
.61169 .16001 L
.62141 .16147 L
.63112 .16313 L
.64053 .16492 L
.64083 .16498 L
.65054 .16703 L
.66026 .16927 L
.66997 .17172 L
.67968 .17436 L
.68066 .17463 L
.68939 .17719 L
.69911 .18022 L
.70882 .18345 L
.7114 .18434 L
.71853 .18688 L
.72824 .1905 L
.73731 .19406 L
.73796 .19432 L
.74767 .19833 L
.75738 .20254 L
.76013 .20377 L
.76709 .20695 L
.77681 .21156 L
.78075 .21348 L
.78652 .21636 L
.79623 .22135 L
.79972 .22319 L
.80594 .22655 L
.81566 .23194 L
.81736 .23291 L
.82537 .23752 L
.83394 .24262 L
.83508 .24331 L
.84479 .24929 L
.84962 .25233 L
.85451 .25546 L
.86422 .26184 L
.86453 .26204 L
.87393 .26841 L
.87877 .27176 L
.88364 .27517 L
.89244 .28147 L
.89336 .28214 L
.90307 .28929 L
.90558 .29118 L
.91278 .29665 L
.91827 .30089 L
.92249 .3042 L
.93054 .31061 L
.93221 .31195 L
.94192 .3199 L
.94243 .32032 L
.95163 .32804 L
.95397 .33003 L
.96134 .33638 L
.9652 .33974 L
.97106 .34491 L
.97614 .34946 L
.98077 .35364 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .44258 m
.02448 .43687 L
.02894 .43205 L
.03352 .42716 L
.03866 .42172 L
.04273 .41744 L
.04837 .41159 L
.05211 .40773 L
.05808 .40165 L
.06168 .39802 L
.06779 .3919 L
.07143 .38831 L
.07751 .38236 L
.08139 .37859 L
.08722 .37301 L
.09157 .36888 L
.09693 .36386 L
.10199 .35917 L
.10664 .3549 L
.11266 .34946 L
.11636 .34614 L
.12359 .33974 L
.12607 .33758 L
.13482 .33003 L
.13578 .32921 L
.14549 .32104 L
.14637 .32032 L
.15521 .31307 L
.15826 .31061 L
.16492 .30529 L
.17053 .30089 L
.17463 .29771 L
.18321 .29118 L
.18434 .29033 L
.19406 .28314 L
.19636 .28147 L
.20377 .27615 L
.21002 .27176 L
.21348 .26936 L
.22319 .26276 L
.22427 .26204 L
.23291 .25636 L
.23918 .25233 L
.24262 .25016 L
.25233 .24415 L
.25485 .24262 L
.26204 .23834 L
.27143 .23291 L
.27176 .23272 L
.28147 .2273 L
Mistroke
.28908 .22319 L
.29118 .22208 L
.30089 .21706 L
.30804 .21348 L
.31061 .21223 L
.32032 .20759 L
.32867 .20377 L
.33003 .20316 L
.33974 .19892 L
.34946 .19488 L
.35149 .19406 L
.35917 .19103 L
.36888 .18738 L
.37739 .18434 L
.37859 .18393 L
.38831 .18067 L
.39802 .17761 L
.40773 .17475 L
.40814 .17463 L
.41744 .17208 L
.42716 .16961 L
.43687 .16734 L
.44658 .16526 L
.44826 .16492 L
.45629 .16338 L
.46601 .16169 L
.47572 .1602 L
.48543 .15891 L
.49514 .15782 L
.50486 .15692 L
.51457 .15622 L
.52428 .15571 L
.53399 .1554 L
.54371 .15529 L
.55342 .15538 L
.56313 .15566 L
.57284 .15613 L
.58256 .15681 L
.59227 .15768 L
.60198 .15875 L
.61169 .16001 L
.62141 .16147 L
.63112 .16313 L
.64053 .16492 L
.64083 .16498 L
.65054 .16703 L
.66026 .16927 L
.66997 .17172 L
.67968 .17436 L
.68066 .17463 L
Mistroke
.68939 .17719 L
.69911 .18022 L
.70882 .18345 L
.7114 .18434 L
.71853 .18688 L
.72824 .1905 L
.73731 .19406 L
.73796 .19432 L
.74767 .19833 L
.75738 .20254 L
.76013 .20377 L
.76709 .20695 L
.77681 .21156 L
.78075 .21348 L
.78652 .21636 L
.79623 .22135 L
.79972 .22319 L
.80594 .22655 L
.81566 .23194 L
.81736 .23291 L
.82537 .23752 L
.83394 .24262 L
.83508 .24331 L
.84479 .24929 L
.84962 .25233 L
.85451 .25546 L
.86422 .26184 L
.86453 .26204 L
.87393 .26841 L
.87877 .27176 L
.88364 .27517 L
.89244 .28147 L
.89336 .28214 L
.90307 .28929 L
.90558 .29118 L
.91278 .29665 L
.91827 .30089 L
.92249 .3042 L
.93054 .31061 L
.93221 .31195 L
.94192 .3199 L
.94243 .32032 L
.95163 .32804 L
.95397 .33003 L
.96134 .33638 L
.9652 .33974 L
.97106 .34491 L
.97614 .34946 L
.98077 .35364 L
Mfstroke
.85 g
.01923 .53324 m
.02748 .52428 L
.02894 .5227 L
.03657 .51457 L
.03866 .51237 L
.04583 .50486 L
.04837 .50223 L
.05527 .49514 L
.05808 .49228 L
.06489 .48543 L
.06779 .48254 L
.07471 .47572 L
.07751 .47299 L
.08473 .46601 L
.08722 .46363 L
.09498 .45629 L
.09693 .45447 L
.10547 .44658 L
.10664 .44551 L
.11622 .43687 L
.11636 .43675 L
.12607 .42818 L
.12725 .42716 L
.13578 .41981 L
.13857 .41744 L
.14549 .41164 L
.15022 .40773 L
.15521 .40366 L
.16222 .39802 L
.16492 .39588 L
.17461 .38831 L
.17463 .38829 L
.18434 .38091 L
.18744 .37859 L
.19406 .37371 L
.20074 .36888 L
.20377 .36672 L
.21348 .35992 L
.21457 .35917 L
.22319 .35332 L
.22902 .34946 L
.23291 .34691 L
.24262 .34071 L
.24415 .33974 L
.25233 .33469 L
.26009 .33003 L
.26204 .32888 L
.27176 .32326 L
.27698 .32032 L
.28147 .31784 L
.29118 .31261 L
.29501 .31061 L
.30089 .30758 L
.31061 .30275 L
.31445 .30089 L
.32032 .29811 L
.33003 .29368 L
.33569 .29118 L
.33974 .28943 L
.34946 .28539 L
.35917 .28154 L
.35934 .28147 L
.36888 .27788 L
.37859 .27443 L
.38651 .27176 L
.38831 .27117 L
.39802 .2681 L
.40773 .26524 L
.41744 .26257 L
.41944 .26204 L
.42716 .26009 L
.43687 .25782 L
.44658 .25574 L
.45629 .25385 L
.465 .25233 L
.46601 .25217 L
.47572 .25067 L
.48543 .24938 L
.49514 .24828 L
.50486 .24738 L
.51457 .24668 L
.52428 .24617 L
.53399 .24586 L
.54371 .24574 L
.55342 .24583 L
.56313 .2461 L
.57284 .24658 L
.58256 .24725 L
.59227 .24812 L
.60198 .24918 L
.61169 .25045 L
.62141 .2519 L
.62403 .25233 L
.63112 .25356 L
.64083 .25541 L
.65054 .25746 L
.66026 .2597 L
.66959 .26204 L
.66997 .26214 L
.67968 .26478 L
.68939 .26761 L
.69911 .27064 L
.70252 .27176 L
.70882 .27387 L
.71853 .27729 L
.72824 .28092 L
.72968 .28147 L
.73796 .28473 L
.74767 .28875 L
.75334 .29118 L
.75738 .29296 L
.76709 .29736 L
.77458 .30089 L
.77681 .30197 L
.78652 .30676 L
.79402 .31061 L
.79623 .31176 L
.80594 .31695 L
.81205 .32032 L
.81566 .32234 L
.82537 .32793 L
.82894 .33003 L
.83508 .33371 L
.84479 .33969 L
.84488 .33974 L
.85451 .34587 L
.86001 .34946 L
.86422 .35224 L
.87393 .35881 L
.87446 .35917 L
.88364 .36557 L
.88829 .36888 L
.89336 .37254 L
.90159 .37859 L
.90307 .37969 L
.91278 .38705 L
.91441 .38831 L
.92249 .3946 L
.92681 .39802 L
.93221 .40235 L
.93881 .40773 L
.94192 .4103 L
.95046 .41744 L
.95163 .41844 L
.96134 .42678 L
.96178 .42716 L
.97106 .43531 L
.97281 .43687 L
.98077 .44404 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .53324 m
.02748 .52428 L
.02894 .5227 L
.03657 .51457 L
.03866 .51237 L
.04583 .50486 L
.04837 .50223 L
.05527 .49514 L
.05808 .49228 L
.06489 .48543 L
.06779 .48254 L
.07471 .47572 L
.07751 .47299 L
.08473 .46601 L
.08722 .46363 L
.09498 .45629 L
.09693 .45447 L
.10547 .44658 L
.10664 .44551 L
.11622 .43687 L
.11636 .43675 L
.12607 .42818 L
.12725 .42716 L
.13578 .41981 L
.13857 .41744 L
.14549 .41164 L
.15022 .40773 L
.15521 .40366 L
.16222 .39802 L
.16492 .39588 L
.17461 .38831 L
.17463 .38829 L
.18434 .38091 L
.18744 .37859 L
.19406 .37371 L
.20074 .36888 L
.20377 .36672 L
.21348 .35992 L
.21457 .35917 L
.22319 .35332 L
.22902 .34946 L
.23291 .34691 L
.24262 .34071 L
.24415 .33974 L
.25233 .33469 L
.26009 .33003 L
.26204 .32888 L
.27176 .32326 L
.27698 .32032 L
.28147 .31784 L
Mistroke
.29118 .31261 L
.29501 .31061 L
.30089 .30758 L
.31061 .30275 L
.31445 .30089 L
.32032 .29811 L
.33003 .29368 L
.33569 .29118 L
.33974 .28943 L
.34946 .28539 L
.35917 .28154 L
.35934 .28147 L
.36888 .27788 L
.37859 .27443 L
.38651 .27176 L
.38831 .27117 L
.39802 .2681 L
.40773 .26524 L
.41744 .26257 L
.41944 .26204 L
.42716 .26009 L
.43687 .25782 L
.44658 .25574 L
.45629 .25385 L
.465 .25233 L
.46601 .25217 L
.47572 .25067 L
.48543 .24938 L
.49514 .24828 L
.50486 .24738 L
.51457 .24668 L
.52428 .24617 L
.53399 .24586 L
.54371 .24574 L
.55342 .24583 L
.56313 .2461 L
.57284 .24658 L
.58256 .24725 L
.59227 .24812 L
.60198 .24918 L
.61169 .25045 L
.62141 .2519 L
.62403 .25233 L
.63112 .25356 L
.64083 .25541 L
.65054 .25746 L
.66026 .2597 L
.66959 .26204 L
.66997 .26214 L
.67968 .26478 L
Mistroke
.68939 .26761 L
.69911 .27064 L
.70252 .27176 L
.70882 .27387 L
.71853 .27729 L
.72824 .28092 L
.72968 .28147 L
.73796 .28473 L
.74767 .28875 L
.75334 .29118 L
.75738 .29296 L
.76709 .29736 L
.77458 .30089 L
.77681 .30197 L
.78652 .30676 L
.79402 .31061 L
.79623 .31176 L
.80594 .31695 L
.81205 .32032 L
.81566 .32234 L
.82537 .32793 L
.82894 .33003 L
.83508 .33371 L
.84479 .33969 L
.84488 .33974 L
.85451 .34587 L
.86001 .34946 L
.86422 .35224 L
.87393 .35881 L
.87446 .35917 L
.88364 .36557 L
.88829 .36888 L
.89336 .37254 L
.90159 .37859 L
.90307 .37969 L
.91278 .38705 L
.91441 .38831 L
.92249 .3946 L
.92681 .39802 L
.93221 .40235 L
.93881 .40773 L
.94192 .4103 L
.95046 .41744 L
.95163 .41844 L
.96134 .42678 L
.96178 .42716 L
.97106 .43531 L
.97281 .43687 L
.98077 .44404 L
Mfstroke
.925 g
.01923 .64279 m
.02102 .64083 L
.02894 .63225 L
.03 .63112 L
.03866 .6219 L
.03913 .62141 L
.04837 .61175 L
.04843 .61169 L
.0579 .60198 L
.05808 .6018 L
.06757 .59227 L
.06779 .59205 L
.07744 .58256 L
.07751 .58249 L
.08722 .57313 L
.08751 .57284 L
.09693 .56396 L
.09782 .56313 L
.10664 .55499 L
.10837 .55342 L
.11636 .54622 L
.11918 .54371 L
.12607 .53764 L
.13027 .53399 L
.13578 .52926 L
.14167 .52428 L
.14549 .52108 L
.1534 .51457 L
.15521 .51309 L
.16492 .50531 L
.16549 .50486 L
.17463 .49771 L
.17798 .49514 L
.18434 .49032 L
.19091 .48543 L
.19406 .48312 L
.20377 .47612 L
.20433 .47572 L
.21348 .46931 L
.2183 .46601 L
.22319 .4627 L
.2329 .45629 L
.23291 .45629 L
.24262 .45007 L
.24822 .44658 L
.25233 .44405 L
.26204 .43823 L
.26437 .43687 L
.27176 .43261 L
.28147 .42718 L
.28151 .42716 L
.29118 .42195 L
.29985 .41744 L
.30089 .41691 L
.31061 .41207 L
.31967 .40773 L
.32032 .40743 L
.33003 .40298 L
.33974 .39873 L
.34142 .39802 L
.34946 .39468 L
.35917 .39083 L
.3658 .38831 L
.36888 .38717 L
.37859 .3837 L
.38831 .38044 L
.39407 .37859 L
.39802 .37737 L
.40773 .3745 L
.41744 .37182 L
.42716 .36934 L
.42906 .36888 L
.43687 .36706 L
.44658 .36498 L
.45629 .36309 L
.46601 .36139 L
.47572 .3599 L
.48099 .35917 L
.48543 .3586 L
.49514 .3575 L
.50486 .35659 L
.51457 .35588 L
.52428 .35537 L
.53399 .35506 L
.54371 .35494 L
.55342 .35501 L
.56313 .35529 L
.57284 .35576 L
.58256 .35643 L
.59227 .35729 L
.60198 .35835 L
.60845 .35917 L
.61169 .35961 L
.62141 .36107 L
.63112 .36272 L
.64083 .36457 L
.65054 .36661 L
.66026 .36885 L
.66038 .36888 L
.66997 .37129 L
.67968 .37392 L
.68939 .37675 L
.69537 .37859 L
.69911 .37978 L
.70882 .38301 L
.71853 .38643 L
.72364 .38831 L
.72824 .39005 L
.73796 .39386 L
.74767 .39787 L
.74802 .39802 L
.75738 .40208 L
.76709 .40648 L
.76977 .40773 L
.77681 .41109 L
.78652 .41588 L
.7896 .41744 L
.79623 .42088 L
.80594 .42607 L
.80793 .42716 L
.81566 .43146 L
.82507 .43687 L
.82537 .43704 L
.83508 .44282 L
.84123 .44658 L
.84479 .4488 L
.85451 .45497 L
.85654 .45629 L
.86422 .46135 L
.87114 .46601 L
.87393 .46791 L
.88364 .47468 L
.88511 .47572 L
.89336 .48164 L
.89854 .48543 L
.90307 .4888 L
.91147 .49514 L
.91278 .49615 L
.92249 .5037 L
.92396 .50486 L
.93221 .51145 L
.93605 .51457 L
.94192 .5194 L
.94778 .52428 L
.95163 .52754 L
.95917 .53399 L
.96134 .53587 L
.97027 .54371 L
.97106 .54441 L
.98077 .55314 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .64279 m
.02102 .64083 L
.02894 .63225 L
.03 .63112 L
.03866 .6219 L
.03913 .62141 L
.04837 .61175 L
.04843 .61169 L
.0579 .60198 L
.05808 .6018 L
.06757 .59227 L
.06779 .59205 L
.07744 .58256 L
.07751 .58249 L
.08722 .57313 L
.08751 .57284 L
.09693 .56396 L
.09782 .56313 L
.10664 .55499 L
.10837 .55342 L
.11636 .54622 L
.11918 .54371 L
.12607 .53764 L
.13027 .53399 L
.13578 .52926 L
.14167 .52428 L
.14549 .52108 L
.1534 .51457 L
.15521 .51309 L
.16492 .50531 L
.16549 .50486 L
.17463 .49771 L
.17798 .49514 L
.18434 .49032 L
.19091 .48543 L
.19406 .48312 L
.20377 .47612 L
.20433 .47572 L
.21348 .46931 L
.2183 .46601 L
.22319 .4627 L
.2329 .45629 L
.23291 .45629 L
.24262 .45007 L
.24822 .44658 L
.25233 .44405 L
.26204 .43823 L
.26437 .43687 L
.27176 .43261 L
.28147 .42718 L
Mistroke
.28151 .42716 L
.29118 .42195 L
.29985 .41744 L
.30089 .41691 L
.31061 .41207 L
.31967 .40773 L
.32032 .40743 L
.33003 .40298 L
.33974 .39873 L
.34142 .39802 L
.34946 .39468 L
.35917 .39083 L
.3658 .38831 L
.36888 .38717 L
.37859 .3837 L
.38831 .38044 L
.39407 .37859 L
.39802 .37737 L
.40773 .3745 L
.41744 .37182 L
.42716 .36934 L
.42906 .36888 L
.43687 .36706 L
.44658 .36498 L
.45629 .36309 L
.46601 .36139 L
.47572 .3599 L
.48099 .35917 L
.48543 .3586 L
.49514 .3575 L
.50486 .35659 L
.51457 .35588 L
.52428 .35537 L
.53399 .35506 L
.54371 .35494 L
.55342 .35501 L
.56313 .35529 L
.57284 .35576 L
.58256 .35643 L
.59227 .35729 L
.60198 .35835 L
.60845 .35917 L
.61169 .35961 L
.62141 .36107 L
.63112 .36272 L
.64083 .36457 L
.65054 .36661 L
.66026 .36885 L
.66038 .36888 L
.66997 .37129 L
Mistroke
.67968 .37392 L
.68939 .37675 L
.69537 .37859 L
.69911 .37978 L
.70882 .38301 L
.71853 .38643 L
.72364 .38831 L
.72824 .39005 L
.73796 .39386 L
.74767 .39787 L
.74802 .39802 L
.75738 .40208 L
.76709 .40648 L
.76977 .40773 L
.77681 .41109 L
.78652 .41588 L
.7896 .41744 L
.79623 .42088 L
.80594 .42607 L
.80793 .42716 L
.81566 .43146 L
.82507 .43687 L
.82537 .43704 L
.83508 .44282 L
.84123 .44658 L
.84479 .4488 L
.85451 .45497 L
.85654 .45629 L
.86422 .46135 L
.87114 .46601 L
.87393 .46791 L
.88364 .47468 L
.88511 .47572 L
.89336 .48164 L
.89854 .48543 L
.90307 .4888 L
.91147 .49514 L
.91278 .49615 L
.92249 .5037 L
.92396 .50486 L
.93221 .51145 L
.93605 .51457 L
.94192 .5194 L
.94778 .52428 L
.95163 .52754 L
.95917 .53399 L
.96134 .53587 L
.97027 .54371 L
.97106 .54441 L
.98077 .55314 L
Mistroke
Mfstroke
1 g
.01923 .79296 m
.02513 .78652 L
.02894 .7824 L
.03415 .77681 L
.03866 .77203 L
.04334 .76709 L
.04837 .76185 L
.0527 .75738 L
.05808 .75188 L
.06224 .74767 L
.06779 .7421 L
.07197 .73796 L
.07751 .73251 L
.0819 .72824 L
.08722 .72313 L
.09205 .71853 L
.09693 .71394 L
.10244 .70882 L
.10664 .70495 L
.11307 .69911 L
.11636 .69615 L
.12397 .68939 L
.12607 .68756 L
.13517 .67968 L
.13578 .67916 L
.14549 .67095 L
.14667 .66997 L
.15521 .66294 L
.15852 .66026 L
.16492 .65513 L
.17074 .65054 L
.17463 .64752 L
.18338 .64083 L
.18434 .64011 L
.19406 .63289 L
.19647 .63112 L
.20377 .62586 L
.21008 .62141 L
.21348 .61904 L
.22319 .61241 L
.22426 .61169 L
.23291 .60598 L
.2391 .60198 L
.24262 .59974 L
.25233 .59371 L
.25469 .59227 L
.26204 .58787 L
.27117 .58256 L
.27176 .58222 L
.28147 .57677 L
.28871 .57284 L
.29118 .57152 L
.30089 .56647 L
.30753 .56313 L
.31061 .56162 L
.32032 .55696 L
.32798 .55342 L
.33003 .55249 L
.33974 .54823 L
.34946 .54416 L
.35057 .54371 L
.35917 .54029 L
.36888 .53661 L
.37615 .53399 L
.37859 .53314 L
.38831 .52986 L
.39802 .52677 L
.40636 .52428 L
.40773 .52389 L
.41744 .5212 L
.42716 .5187 L
.43687 .51641 L
.44532 .51457 L
.44658 .51431 L
.45629 .5124 L
.46601 .5107 L
.47572 .50919 L
.48543 .50788 L
.49514 .50676 L
.50486 .50585 L
.51457 .50513 L
.51891 .50486 L
.52428 .5046 L
.53399 .50428 L
.54371 .50415 L
.55342 .50421 L
.56313 .50448 L
.57158 .50486 L
.57284 .50494 L
.58256 .50559 L
.59227 .50645 L
.60198 .5075 L
.61169 .50875 L
.62141 .51019 L
.63112 .51184 L
.64083 .51368 L
.64521 .51457 L
.65054 .51571 L
.66026 .51794 L
.66997 .52037 L
.67968 .523 L
.68417 .52428 L
.68939 .52583 L
.69911 .52885 L
.70882 .53206 L
.71438 .53399 L
.71853 .53548 L
.72824 .53909 L
.73796 .5429 L
.73996 .54371 L
.74767 .5469 L
.75738 .55111 L
.76254 .55342 L
.76709 .5555 L
.77681 .5601 L
.783 .56313 L
.78652 .56489 L
.79623 .56988 L
.80182 .57284 L
.80594 .57507 L
.81566 .58045 L
.81936 .58256 L
.82537 .58603 L
.83508 .59181 L
.83584 .59227 L
.84479 .59779 L
.85143 .60198 L
.85451 .60396 L
.86422 .61032 L
.86627 .61169 L
.87393 .61689 L
.88045 .62141 L
.88364 .62365 L
.89336 .63061 L
.89406 .63112 L
.90307 .63777 L
.90715 .64083 L
.91278 .64512 L
.91979 .65054 L
.92249 .65267 L
.93201 .66026 L
.93221 .66042 L
.94192 .66836 L
.94386 .66997 L
.95163 .6765 L
.95537 .67968 L
.96134 .68484 L
.96656 .68939 L
.97106 .69337 L
.97746 .69911 L
.98077 .7021 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .79296 m
.02513 .78652 L
.02894 .7824 L
.03415 .77681 L
.03866 .77203 L
.04334 .76709 L
.04837 .76185 L
.0527 .75738 L
.05808 .75188 L
.06224 .74767 L
.06779 .7421 L
.07197 .73796 L
.07751 .73251 L
.0819 .72824 L
.08722 .72313 L
.09205 .71853 L
.09693 .71394 L
.10244 .70882 L
.10664 .70495 L
.11307 .69911 L
.11636 .69615 L
.12397 .68939 L
.12607 .68756 L
.13517 .67968 L
.13578 .67916 L
.14549 .67095 L
.14667 .66997 L
.15521 .66294 L
.15852 .66026 L
.16492 .65513 L
.17074 .65054 L
.17463 .64752 L
.18338 .64083 L
.18434 .64011 L
.19406 .63289 L
.19647 .63112 L
.20377 .62586 L
.21008 .62141 L
.21348 .61904 L
.22319 .61241 L
.22426 .61169 L
.23291 .60598 L
.2391 .60198 L
.24262 .59974 L
.25233 .59371 L
.25469 .59227 L
.26204 .58787 L
.27117 .58256 L
.27176 .58222 L
.28147 .57677 L
Mistroke
.28871 .57284 L
.29118 .57152 L
.30089 .56647 L
.30753 .56313 L
.31061 .56162 L
.32032 .55696 L
.32798 .55342 L
.33003 .55249 L
.33974 .54823 L
.34946 .54416 L
.35057 .54371 L
.35917 .54029 L
.36888 .53661 L
.37615 .53399 L
.37859 .53314 L
.38831 .52986 L
.39802 .52677 L
.40636 .52428 L
.40773 .52389 L
.41744 .5212 L
.42716 .5187 L
.43687 .51641 L
.44532 .51457 L
.44658 .51431 L
.45629 .5124 L
.46601 .5107 L
.47572 .50919 L
.48543 .50788 L
.49514 .50676 L
.50486 .50585 L
.51457 .50513 L
.51891 .50486 L
.52428 .5046 L
.53399 .50428 L
.54371 .50415 L
.55342 .50421 L
.56313 .50448 L
.57158 .50486 L
.57284 .50494 L
.58256 .50559 L
.59227 .50645 L
.60198 .5075 L
.61169 .50875 L
.62141 .51019 L
.63112 .51184 L
.64083 .51368 L
.64521 .51457 L
.65054 .51571 L
.66026 .51794 L
.66997 .52037 L
Mistroke
.67968 .523 L
.68417 .52428 L
.68939 .52583 L
.69911 .52885 L
.70882 .53206 L
.71438 .53399 L
.71853 .53548 L
.72824 .53909 L
.73796 .5429 L
.73996 .54371 L
.74767 .5469 L
.75738 .55111 L
.76254 .55342 L
.76709 .5555 L
.77681 .5601 L
.783 .56313 L
.78652 .56489 L
.79623 .56988 L
.80182 .57284 L
.80594 .57507 L
.81566 .58045 L
.81936 .58256 L
.82537 .58603 L
.83508 .59181 L
.83584 .59227 L
.84479 .59779 L
.85143 .60198 L
.85451 .60396 L
.86422 .61032 L
.86627 .61169 L
.87393 .61689 L
.88045 .62141 L
.88364 .62365 L
.89336 .63061 L
.89406 .63112 L
.90307 .63777 L
.90715 .64083 L
.91278 .64512 L
.91979 .65054 L
.92249 .65267 L
.93201 .66026 L
.93221 .66042 L
.94192 .66836 L
.94386 .66997 L
.95163 .6765 L
.95537 .67968 L
.96134 .68484 L
.96656 .68939 L
.97106 .69337 L
.97746 .69911 L
Mistroke
.98077 .7021 L
Mfstroke
.55 g
.01923 .29242 m
.02037 .29118 L
.02894 .2819 L
.02935 .28147 L
.03849 .27176 L
.03866 .27158 L
.04779 .26204 L
.04837 .26145 L
.05728 .25233 L
.05808 .25151 L
.06695 .24262 L
.06779 .24178 L
.07682 .23291 L
.07751 .23224 L
.08691 .22319 L
.08722 .2229 L
.09693 .21375 L
.09722 .21348 L
.10664 .2048 L
.10777 .20377 L
.11636 .19604 L
.11859 .19406 L
.12607 .18749 L
.12969 .18434 L
.13578 .17913 L
.1411 .17463 L
.14549 .17096 L
.15284 .16492 L
.15521 .16299 L
.16492 .15522 L
.16494 .15521 L
.17463 .14765 L
.17744 .14549 L
.18434 .14027 L
.19038 .13578 L
.19406 .13309 L
.20377 .1261 L
.20381 .12607 L
.21348 .11931 L
.2178 .11636 L
.22319 .11272 L
.23241 .10664 L
.23291 .10632 L
.24262 .10012 L
.24774 .09693 L
.25233 .09412 L
.26204 .08831 L
.26391 .08722 L
.27176 .0827 L
.28107 .07751 L
.28147 .07729 L
.29118 .07207 L
.29943 .06779 L
.30089 .06705 L
.31061 .06222 L
.31928 .05808 L
.32032 .0576 L
.33003 .05316 L
.33974 .04893 L
.34106 .04837 L
.34946 .04489 L
.35917 .04105 L
.36548 .03866 L
.36888 .0374 L
.37859 .03395 L
.38831 .0307 L
.39381 .02894 L
.39802 .02764 L
.40773 .02478 L
.41744 .02212 L
.42716 .01965 L
.42889 .01923 L
.01923 .01923 L
F
0 g
.01923 .29242 m
.02037 .29118 L
.02894 .2819 L
.02935 .28147 L
.03849 .27176 L
.03866 .27158 L
.04779 .26204 L
.04837 .26145 L
.05728 .25233 L
.05808 .25151 L
.06695 .24262 L
.06779 .24178 L
.07682 .23291 L
.07751 .23224 L
.08691 .22319 L
.08722 .2229 L
.09693 .21375 L
.09722 .21348 L
.10664 .2048 L
.10777 .20377 L
.11636 .19604 L
.11859 .19406 L
.12607 .18749 L
.12969 .18434 L
.13578 .17913 L
.1411 .17463 L
.14549 .17096 L
.15284 .16492 L
.15521 .16299 L
.16492 .15522 L
.16494 .15521 L
.17463 .14765 L
.17744 .14549 L
.18434 .14027 L
.19038 .13578 L
.19406 .13309 L
.20377 .1261 L
.20381 .12607 L
.21348 .11931 L
.2178 .11636 L
.22319 .11272 L
.23241 .10664 L
.23291 .10632 L
.24262 .10012 L
.24774 .09693 L
.25233 .09412 L
.26204 .08831 L
.26391 .08722 L
.27176 .0827 L
.28107 .07751 L
Mistroke
.28147 .07729 L
.29118 .07207 L
.29943 .06779 L
.30089 .06705 L
.31061 .06222 L
.31928 .05808 L
.32032 .0576 L
.33003 .05316 L
.33974 .04893 L
.34106 .04837 L
.34946 .04489 L
.35917 .04105 L
.36548 .03866 L
.36888 .0374 L
.37859 .03395 L
.38831 .0307 L
.39381 .02894 L
.39802 .02764 L
.40773 .02478 L
.41744 .02212 L
.42716 .01965 L
.42889 .01923 L
Mfstroke
.475 g
.01923 .22734 m
.02304 .22319 L
.02894 .21682 L
.03207 .21348 L
.03866 .2065 L
.04126 .20377 L
.04837 .19637 L
.05062 .19406 L
.05808 .18644 L
.06016 .18434 L
.06779 .17671 L
.06989 .17463 L
.07751 .16717 L
.07983 .16492 L
.08722 .15783 L
.08998 .15521 L
.09693 .14868 L
.10037 .14549 L
.10664 .13973 L
.111 .13578 L
.11636 .13098 L
.12191 .12607 L
.12607 .12243 L
.1331 .11636 L
.13578 .11407 L
.1446 .10664 L
.14549 .1059 L
.15521 .09794 L
.15645 .09693 L
.16492 .09017 L
.16867 .08722 L
.17463 .08259 L
.1813 .07751 L
.18434 .07522 L
.19406 .06804 L
.19439 .06779 L
.20377 .06105 L
.20798 .05808 L
.21348 .05426 L
.22215 .04837 L
.22319 .04767 L
.23291 .04128 L
.23698 .03866 L
.24262 .03508 L
.25233 .02908 L
.25255 .02894 L
.26204 .02327 L
.26901 .01923 L
.01923 .01923 L
F
0 g
.01923 .22734 m
.02304 .22319 L
.02894 .21682 L
.03207 .21348 L
.03866 .2065 L
.04126 .20377 L
.04837 .19637 L
.05062 .19406 L
.05808 .18644 L
.06016 .18434 L
.06779 .17671 L
.06989 .17463 L
.07751 .16717 L
.07983 .16492 L
.08722 .15783 L
.08998 .15521 L
.09693 .14868 L
.10037 .14549 L
.10664 .13973 L
.111 .13578 L
.11636 .13098 L
.12191 .12607 L
.12607 .12243 L
.1331 .11636 L
.13578 .11407 L
.1446 .10664 L
.14549 .1059 L
.15521 .09794 L
.15645 .09693 L
.16492 .09017 L
.16867 .08722 L
.17463 .08259 L
.1813 .07751 L
.18434 .07522 L
.19406 .06804 L
.19439 .06779 L
.20377 .06105 L
.20798 .05808 L
.21348 .05426 L
.22215 .04837 L
.22319 .04767 L
.23291 .04128 L
.23698 .03866 L
.24262 .03508 L
.25233 .02908 L
.25255 .02894 L
.26204 .02327 L
.26901 .01923 L
s
.4 g
.01923 .16695 m
.02109 .16492 L
.02894 .15643 L
.03009 .15521 L
.03866 .14611 L
.03924 .14549 L
.04837 .13598 L
.04856 .13578 L
.05807 .12607 L
.05808 .12605 L
.06776 .11636 L
.06779 .11632 L
.07751 .10678 L
.07765 .10664 L
.08722 .09744 L
.08776 .09693 L
.09693 .0883 L
.09809 .08722 L
.10664 .07935 L
.10867 .07751 L
.11636 .0706 L
.11952 .06779 L
.12607 .06205 L
.13065 .05808 L
.13578 .05369 L
.14209 .04837 L
.14549 .04553 L
.15386 .03866 L
.15521 .03756 L
.16492 .02979 L
.166 .02894 L
.17463 .02222 L
.17854 .01923 L
.01923 .01923 L
F
0 g
.01923 .16695 m
.02109 .16492 L
.02894 .15643 L
.03009 .15521 L
.03866 .14611 L
.03924 .14549 L
.04837 .13598 L
.04856 .13578 L
.05807 .12607 L
.05808 .12605 L
.06776 .11636 L
.06779 .11632 L
.07751 .10678 L
.07765 .10664 L
.08722 .09744 L
.08776 .09693 L
.09693 .0883 L
.09809 .08722 L
.10664 .07935 L
.10867 .07751 L
.11636 .0706 L
.11952 .06779 L
.12607 .06205 L
.13065 .05808 L
.13578 .05369 L
.14209 .04837 L
.14549 .04553 L
.15386 .03866 L
.15521 .03756 L
.16492 .02979 L
.166 .02894 L
.17463 .02222 L
.17854 .01923 L
s
.325 g
.01923 .11036 m
.02264 .10664 L
.02894 .09984 L
.03166 .09693 L
.03866 .08952 L
.04084 .08722 L
.04837 .07939 L
.0502 .07751 L
.05808 .06946 L
.05973 .06779 L
.06779 .05973 L
.06946 .05808 L
.07751 .0502 L
.07939 .04837 L
.08722 .04086 L
.08954 .03866 L
.09693 .03172 L
.09992 .02894 L
.10664 .02277 L
.11055 .01923 L
.01923 .01923 L
F
0 g
.01923 .11036 m
.02264 .10664 L
.02894 .09984 L
.03166 .09693 L
.03866 .08952 L
.04084 .08722 L
.04837 .07939 L
.0502 .07751 L
.05808 .06946 L
.05973 .06779 L
.06779 .05973 L
.06946 .05808 L
.07751 .0502 L
.07939 .04837 L
.08722 .04086 L
.08954 .03866 L
.09693 .03172 L
.09992 .02894 L
.10664 .02277 L
.11055 .01923 L
s
.25 g
.01923 .05692 m
.02712 .04837 L
.02894 .04641 L
.03622 .03866 L
.03866 .03609 L
.04549 .02894 L
.04837 .02596 L
.05493 .01923 L
.01923 .01923 L
F
0 g
.01923 .05692 m
.02712 .04837 L
.02894 .04641 L
.03622 .03866 L
.03866 .03609 L
.04549 .02894 L
.04837 .02596 L
.05493 .01923 L
s
.55 g
.98077 .20378 m
.98075 .20377 L
.97106 .19505 L
.96994 .19406 L
.96134 .18652 L
.95884 .18434 L
.95163 .17818 L
.94743 .17463 L
.94192 .17004 L
.93569 .16492 L
.93221 .16209 L
.92359 .15521 L
.92249 .15434 L
.91278 .14679 L
.91109 .14549 L
.90307 .13943 L
.89815 .13578 L
.89336 .13227 L
.88472 .12607 L
.88364 .12531 L
.87393 .11854 L
.87073 .11636 L
.86422 .11197 L
.85612 .10664 L
.85451 .1056 L
.84479 .09942 L
.84079 .09693 L
.83508 .09344 L
.82537 .08766 L
.82462 .08722 L
.81566 .08207 L
.80746 .07751 L
.80594 .07668 L
.79623 .07148 L
.7891 .06779 L
.78652 .06648 L
.77681 .06168 L
.76925 .05808 L
.76709 .05708 L
.75738 .05267 L
.74767 .04845 L
.74747 .04837 L
.73796 .04444 L
.72824 .04062 L
.72305 .03866 L
.71853 .03699 L
.70882 .03357 L
.69911 .03034 L
.69472 .02894 L
.68939 .0273 L
.67968 .02447 L
.66997 .02183 L
.66026 .01938 L
.65964 .01923 L
.98077 .01923 L
F
0 g
.98077 .20378 m
.98075 .20377 L
.97106 .19505 L
.96994 .19406 L
.96134 .18652 L
.95884 .18434 L
.95163 .17818 L
.94743 .17463 L
.94192 .17004 L
.93569 .16492 L
.93221 .16209 L
.92359 .15521 L
.92249 .15434 L
.91278 .14679 L
.91109 .14549 L
.90307 .13943 L
.89815 .13578 L
.89336 .13227 L
.88472 .12607 L
.88364 .12531 L
.87393 .11854 L
.87073 .11636 L
.86422 .11197 L
.85612 .10664 L
.85451 .1056 L
.84479 .09942 L
.84079 .09693 L
.83508 .09344 L
.82537 .08766 L
.82462 .08722 L
.81566 .08207 L
.80746 .07751 L
.80594 .07668 L
.79623 .07148 L
.7891 .06779 L
.78652 .06648 L
.77681 .06168 L
.76925 .05808 L
.76709 .05708 L
.75738 .05267 L
.74767 .04845 L
.74747 .04837 L
.73796 .04444 L
.72824 .04062 L
.72305 .03866 L
.71853 .03699 L
.70882 .03357 L
.69911 .03034 L
.69472 .02894 L
.68939 .0273 L
Mistroke
.67968 .02447 L
.66997 .02183 L
.66026 .01938 L
.65964 .01923 L
Mfstroke
.475 g
.98077 .1388 m
.97744 .13578 L
.97106 .13006 L
.96654 .12607 L
.96134 .12153 L
.95535 .11636 L
.95163 .11319 L
.94384 .10664 L
.94192 .10505 L
.93221 .0971 L
.93199 .09693 L
.92249 .08935 L
.91977 .08722 L
.91278 .0818 L
.90714 .07751 L
.90307 .07444 L
.89406 .06779 L
.89336 .06729 L
.88364 .06032 L
.88046 .05808 L
.87393 .05355 L
.86629 .04837 L
.86422 .04698 L
.85451 .04061 L
.85147 .03866 L
.84479 .03443 L
.83589 .02894 L
.83508 .02845 L
.82537 .02267 L
.81944 .01923 L
.98077 .01923 L
F
0 g
.98077 .1388 m
.97744 .13578 L
.97106 .13006 L
.96654 .12607 L
.96134 .12153 L
.95535 .11636 L
.95163 .11319 L
.94384 .10664 L
.94192 .10505 L
.93221 .0971 L
.93199 .09693 L
.92249 .08935 L
.91977 .08722 L
.91278 .0818 L
.90714 .07751 L
.90307 .07444 L
.89406 .06779 L
.89336 .06729 L
.88364 .06032 L
.88046 .05808 L
.87393 .05355 L
.86629 .04837 L
.86422 .04698 L
.85451 .04061 L
.85147 .03866 L
.84479 .03443 L
.83589 .02894 L
.83508 .02845 L
.82537 .02267 L
.81944 .01923 L
s
.4 g
.98077 .07848 m
.9797 .07751 L
.97106 .06975 L
.96885 .06779 L
.96134 .06121 L
.95773 .05808 L
.95163 .05287 L
.94629 .04837 L
.94192 .04473 L
.93452 .03866 L
.93221 .03678 L
.92249 .02904 L
.92238 .02894 L
.91278 .02148 L
.90984 .01923 L
.98077 .01923 L
F
0 g
.98077 .07848 m
.9797 .07751 L
.97106 .06975 L
.96885 .06779 L
.96134 .06121 L
.95773 .05808 L
.95163 .05287 L
.94629 .04837 L
.94192 .04473 L
.93452 .03866 L
.93221 .03678 L
.92249 .02904 L
.92238 .02894 L
.91278 .02148 L
.90984 .01923 L
s
.325 g
.98077 .02195 m
.97777 .01923 L
.98077 .01923 L
F
0 g
.98077 .02195 m
.97777 .01923 L
s
0 0 0 r
.055 w
.98077 .98077 Mdot
.5 0 .5 r
.04 w
.01923 .98077 Mdot
.15147 .92436 Mdot
.20412 .89963 Mdot
.29231 .84032 Mdot
.33586 .82539 Mdot
.42134 .79042 Mdot
.46058 .78775 Mdot
.53846 .77594 Mdot
.5766 .78161 Mdot
.65332 .78843 Mdot
.72742 .81137 Mdot
.79835 .84418 Mdot
.86567 .8851 Mdot
.9293 .93248 Mdot
.98077 .97801 Mdot
.98077 .98077 Mdot
1 1 0 r
.025 w
.01923 .98077 Mdot
.98077 .01923 Mdot
.15147 .92436 Mdot
.38674 .75066 Mdot
.20412 .89963 Mdot
.29231 .84032 Mdot
.48189 .74905 Mdot
.33586 .82539 Mdot
.42134 .79042 Mdot
.60056 .7522 Mdot
.46058 .78775 Mdot
.53846 .77594 Mdot
.69571 .7804 Mdot
.5766 .78161 Mdot
.65332 .78843 Mdot
.72742 .81137 Mdot
.79835 .84418 Mdot
.86567 .8851 Mdot
.9293 .93248 Mdot
.98077 .97801 Mdot
.98077 .98077 Mdot
0 0 1 r
.5 Mabswid
.01923 .98077 m
.01923 .98077 L
.15147 .92436 L
.20412 .89963 L
.29231 .84032 L
.33586 .82539 L
.42134 .79042 L
.46058 .78775 L
.53846 .77594 L
.5766 .78161 L
.65332 .78843 L
.72742 .81137 L
.79835 .84418 L
.86567 .8851 L
.9293 .93248 L
.98077 .97801 L
.98077 .98077 L
s
.015 w
.01923 .98077 Mdot
.01923 .98077 Mdot
.15147 .92436 Mdot
.20412 .89963 Mdot
.29231 .84032 Mdot
.33586 .82539 Mdot
.42134 .79042 Mdot
.46058 .78775 Mdot
.53846 .77594 Mdot
.5766 .78161 Mdot
.65332 .78843 Mdot
.72742 .81137 Mdot
.79835 .84418 Mdot
.86567 .8851 Mdot
.9293 .93248 Mdot
.98077 .97801 Mdot
.98077 .98077 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0055371 0.488926 0.227021 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.543706 0.437063 0.689361 0.211062 [
[.10664 -0.0125 -6 -9 ]
[.10664 -0.0125 6 0 ]
[.32517 -0.0125 -12 -9 ]
[.32517 -0.0125 12 0 ]
[.54371 -0.0125 -3 -9 ]
[.54371 -0.0125 3 0 ]
[.76224 -0.0125 -9 -9 ]
[.76224 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05617 -12 -4.5 ]
[-0.0125 .05617 0 4.5 ]
[-0.0125 .26724 -12 -4.5 ]
[-0.0125 .26724 0 4.5 ]
[-0.0125 .4783 -12 -4.5 ]
[-0.0125 .4783 0 4.5 ]
[-0.0125 .68936 -6 -4.5 ]
[-0.0125 .68936 0 4.5 ]
[-0.0125 .90042 -6 -4.5 ]
[-0.0125 .90042 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10664 0 m
.10664 .00625 L
s
[(-1)] .10664 -0.0125 0 1 Mshowa
.32517 0 m
.32517 .00625 L
s
[(-0.5)] .32517 -0.0125 0 1 Mshowa
.54371 0 m
.54371 .00625 L
s
[(0)] .54371 -0.0125 0 1 Mshowa
.76224 0 m
.76224 .00625 L
s
[(0.5)] .76224 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.15035 0 m
.15035 .00375 L
s
.19406 0 m
.19406 .00375 L
s
.23776 0 m
.23776 .00375 L
s
.28147 0 m
.28147 .00375 L
s
.36888 0 m
.36888 .00375 L
s
.41259 0 m
.41259 .00375 L
s
.45629 0 m
.45629 .00375 L
s
.5 0 m
.5 .00375 L
s
.58741 0 m
.58741 .00375 L
s
.63112 0 m
.63112 .00375 L
s
.67483 0 m
.67483 .00375 L
s
.71853 0 m
.71853 .00375 L
s
.80594 0 m
.80594 .00375 L
s
.84965 0 m
.84965 .00375 L
s
.89336 0 m
.89336 .00375 L
s
.93706 0 m
.93706 .00375 L
s
.06294 0 m
.06294 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05617 m
.00625 .05617 L
s
[(-3)] -0.0125 .05617 1 0 Mshowa
0 .26724 m
.00625 .26724 L
s
[(-2)] -0.0125 .26724 1 0 Mshowa
0 .4783 m
.00625 .4783 L
s
[(-1)] -0.0125 .4783 1 0 Mshowa
0 .68936 m
.00625 .68936 L
s
[(0)] -0.0125 .68936 1 0 Mshowa
0 .90042 m
.00625 .90042 L
s
[(1)] -0.0125 .90042 1 0 Mshowa
.125 Mabswid
0 .09839 m
.00375 .09839 L
s
0 .1406 m
.00375 .1406 L
s
0 .18281 m
.00375 .18281 L
s
0 .22502 m
.00375 .22502 L
s
0 .30945 m
.00375 .30945 L
s
0 .35166 m
.00375 .35166 L
s
0 .39387 m
.00375 .39387 L
s
0 .43609 m
.00375 .43609 L
s
0 .52051 m
.00375 .52051 L
s
0 .56272 m
.00375 .56272 L
s
0 .60494 m
.00375 .60494 L
s
0 .64715 m
.00375 .64715 L
s
0 .73157 m
.00375 .73157 L
s
0 .77379 m
.00375 .77379 L
s
0 .816 m
.00375 .816 L
s
0 .85821 m
.00375 .85821 L
s
0 .01396 m
.00375 .01396 L
s
0 .94264 m
.00375 .94264 L
s
0 .98485 m
.00375 .98485 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10664 .99375 m
.10664 1 L
s
.32517 .99375 m
.32517 1 L
s
.54371 .99375 m
.54371 1 L
s
.76224 .99375 m
.76224 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.15035 .99625 m
.15035 1 L
s
.19406 .99625 m
.19406 1 L
s
.23776 .99625 m
.23776 1 L
s
.28147 .99625 m
.28147 1 L
s
.36888 .99625 m
.36888 1 L
s
.41259 .99625 m
.41259 1 L
s
.45629 .99625 m
.45629 1 L
s
.5 .99625 m
.5 1 L
s
.58741 .99625 m
.58741 1 L
s
.63112 .99625 m
.63112 1 L
s
.67483 .99625 m
.67483 1 L
s
.71853 .99625 m
.71853 1 L
s
.80594 .99625 m
.80594 1 L
s
.84965 .99625 m
.84965 1 L
s
.89336 .99625 m
.89336 1 L
s
.93706 .99625 m
.93706 1 L
s
.06294 .99625 m
.06294 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .05617 m
1 .05617 L
s
.99375 .26724 m
1 .26724 L
s
.99375 .4783 m
1 .4783 L
s
.99375 .68936 m
1 .68936 L
s
.99375 .90042 m
1 .90042 L
s
.125 Mabswid
.99625 .09839 m
1 .09839 L
s
.99625 .1406 m
1 .1406 L
s
.99625 .18281 m
1 .18281 L
s
.99625 .22502 m
1 .22502 L
s
.99625 .30945 m
1 .30945 L
s
.99625 .35166 m
1 .35166 L
s
.99625 .39387 m
1 .39387 L
s
.99625 .43609 m
1 .43609 L
s
.99625 .52051 m
1 .52051 L
s
.99625 .56272 m
1 .56272 L
s
.99625 .60494 m
1 .60494 L
s
.99625 .64715 m
1 .64715 L
s
.99625 .73157 m
1 .73157 L
s
.99625 .77379 m
1 .77379 L
s
.99625 .816 m
1 .816 L
s
.99625 .85821 m
1 .85821 L
s
.99625 .01396 m
1 .01396 L
s
.99625 .94264 m
1 .94264 L
s
.99625 .98485 m
1 .98485 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.625 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .33913 m
.02711 .33003 L
.02894 .32794 L
.03567 .32032 L
.03866 .31696 L
.04437 .31061 L
.04837 .3062 L
.05322 .30089 L
.05808 .29564 L
.06224 .29118 L
.06779 .28529 L
.07143 .28147 L
.07751 .27514 L
.0808 .27176 L
.08722 .26521 L
.09036 .26204 L
.09693 .25549 L
.10013 .25233 L
.10664 .24597 L
.11012 .24262 L
.11636 .23667 L
.12034 .23291 L
.12607 .22757 L
.13082 .22319 L
.13578 .21868 L
.14157 .21348 L
.14549 .21 L
.15261 .20377 L
.15521 .20153 L
.16398 .19406 L
.16492 .19327 L
.17463 .18521 L
.17569 .18434 L
.18434 .17737 L
.18779 .17463 L
.19406 .16973 L
.20032 .16492 L
.20377 .1623 L
.21332 .15521 L
.21348 .15509 L
.22319 .14808 L
.22685 .14549 L
.23291 .14127 L
.24098 .13578 L
.24262 .13468 L
.25233 .1283 L
.2558 .12607 L
.26204 .12212 L
.27143 .11636 L
.27176 .11616 L
.28147 .1104 L
.28801 .10664 L
.29118 .10485 L
.30089 .09951 L
.30574 .09693 L
.31061 .09438 L
.32032 .08946 L
.32489 .08722 L
.33003 .08475 L
.33974 .08025 L
.34588 .07751 L
.34946 .07595 L
.35917 .07186 L
.36888 .06799 L
.36938 .06779 L
.37859 .06432 L
.38831 .06086 L
.39656 .05808 L
.39802 .05761 L
.40773 .05456 L
.41744 .05173 L
.42716 .0491 L
.43002 .04837 L
.43687 .04669 L
.44658 .04448 L
.45629 .04248 L
.46601 .04069 L
.47572 .03911 L
.47877 .03866 L
.48543 .03774 L
.49514 .03657 L
.50486 .03562 L
.51457 .03487 L
.52428 .03434 L
.53399 .03401 L
.54371 .03389 L
.55342 .03398 L
.56313 .03428 L
.57284 .03478 L
.58256 .0355 L
.59227 .03642 L
.60198 .03756 L
.61005 .03866 L
.61169 .0389 L
.62141 .04045 L
.63112 .04221 L
.64083 .04418 L
.65054 .04636 L
.65879 .04837 L
.66026 .04874 L
.66997 .05134 L
.67968 .05414 L
.68939 .05715 L
.69226 .05808 L
.69911 .06037 L
.70882 .0638 L
.71853 .06744 L
.71944 .06779 L
.72824 .07129 L
.73796 .07535 L
.74293 .07751 L
.74767 .07961 L
.75738 .08409 L
.76393 .08722 L
.76709 .08877 L
.77681 .09366 L
.78308 .09693 L
.78652 .09876 L
.79623 .10407 L
.80081 .10664 L
.80594 .10959 L
.81566 .11531 L
.81739 .11636 L
.82537 .12125 L
.83302 .12607 L
.83508 .12739 L
.84479 .13375 L
.84784 .13578 L
.85451 .14031 L
.86197 .14549 L
.86422 .14708 L
.87393 .15406 L
.8755 .15521 L
.88364 .16125 L
.8885 .16492 L
.89336 .16864 L
.90103 .17463 L
.90307 .17625 L
.91278 .18406 L
.91312 .18434 L
.92249 .19209 L
.92484 .19406 L
.93221 .20032 L
.9362 .20377 L
.94192 .20876 L
.94725 .21348 L
.95163 .21741 L
.958 .22319 L
.96134 .22627 L
.96848 .23291 L
.97106 .23534 L
.9787 .24262 L
.98077 .24461 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .33913 m
.02711 .33003 L
.02894 .32794 L
.03567 .32032 L
.03866 .31696 L
.04437 .31061 L
.04837 .3062 L
.05322 .30089 L
.05808 .29564 L
.06224 .29118 L
.06779 .28529 L
.07143 .28147 L
.07751 .27514 L
.0808 .27176 L
.08722 .26521 L
.09036 .26204 L
.09693 .25549 L
.10013 .25233 L
.10664 .24597 L
.11012 .24262 L
.11636 .23667 L
.12034 .23291 L
.12607 .22757 L
.13082 .22319 L
.13578 .21868 L
.14157 .21348 L
.14549 .21 L
.15261 .20377 L
.15521 .20153 L
.16398 .19406 L
.16492 .19327 L
.17463 .18521 L
.17569 .18434 L
.18434 .17737 L
.18779 .17463 L
.19406 .16973 L
.20032 .16492 L
.20377 .1623 L
.21332 .15521 L
.21348 .15509 L
.22319 .14808 L
.22685 .14549 L
.23291 .14127 L
.24098 .13578 L
.24262 .13468 L
.25233 .1283 L
.2558 .12607 L
.26204 .12212 L
.27143 .11636 L
.27176 .11616 L
Mistroke
.28147 .1104 L
.28801 .10664 L
.29118 .10485 L
.30089 .09951 L
.30574 .09693 L
.31061 .09438 L
.32032 .08946 L
.32489 .08722 L
.33003 .08475 L
.33974 .08025 L
.34588 .07751 L
.34946 .07595 L
.35917 .07186 L
.36888 .06799 L
.36938 .06779 L
.37859 .06432 L
.38831 .06086 L
.39656 .05808 L
.39802 .05761 L
.40773 .05456 L
.41744 .05173 L
.42716 .0491 L
.43002 .04837 L
.43687 .04669 L
.44658 .04448 L
.45629 .04248 L
.46601 .04069 L
.47572 .03911 L
.47877 .03866 L
.48543 .03774 L
.49514 .03657 L
.50486 .03562 L
.51457 .03487 L
.52428 .03434 L
.53399 .03401 L
.54371 .03389 L
.55342 .03398 L
.56313 .03428 L
.57284 .03478 L
.58256 .0355 L
.59227 .03642 L
.60198 .03756 L
.61005 .03866 L
.61169 .0389 L
.62141 .04045 L
.63112 .04221 L
.64083 .04418 L
.65054 .04636 L
.65879 .04837 L
.66026 .04874 L
Mistroke
.66997 .05134 L
.67968 .05414 L
.68939 .05715 L
.69226 .05808 L
.69911 .06037 L
.70882 .0638 L
.71853 .06744 L
.71944 .06779 L
.72824 .07129 L
.73796 .07535 L
.74293 .07751 L
.74767 .07961 L
.75738 .08409 L
.76393 .08722 L
.76709 .08877 L
.77681 .09366 L
.78308 .09693 L
.78652 .09876 L
.79623 .10407 L
.80081 .10664 L
.80594 .10959 L
.81566 .11531 L
.81739 .11636 L
.82537 .12125 L
.83302 .12607 L
.83508 .12739 L
.84479 .13375 L
.84784 .13578 L
.85451 .14031 L
.86197 .14549 L
.86422 .14708 L
.87393 .15406 L
.8755 .15521 L
.88364 .16125 L
.8885 .16492 L
.89336 .16864 L
.90103 .17463 L
.90307 .17625 L
.91278 .18406 L
.91312 .18434 L
.92249 .19209 L
.92484 .19406 L
.93221 .20032 L
.9362 .20377 L
.94192 .20876 L
.94725 .21348 L
.95163 .21741 L
.958 .22319 L
.96134 .22627 L
.96848 .23291 L
Mistroke
.97106 .23534 L
.9787 .24262 L
.98077 .24461 L
Mfstroke
.775 g
.01923 .41264 m
.02347 .40773 L
.02894 .40145 L
.03196 .39802 L
.03866 .39047 L
.04059 .38831 L
.04837 .37969 L
.04937 .37859 L
.05808 .36913 L
.05831 .36888 L
.06742 .35917 L
.06779 .35878 L
.07671 .34946 L
.07751 .34863 L
.08618 .33974 L
.08722 .33869 L
.09586 .33003 L
.09693 .32897 L
.10574 .32032 L
.10664 .31945 L
.11586 .31061 L
.11636 .31014 L
.12607 .30103 L
.12622 .30089 L
.13578 .29214 L
.13684 .29118 L
.14549 .28346 L
.14775 .28147 L
.15521 .27498 L
.15897 .27176 L
.16492 .26672 L
.17052 .26204 L
.17463 .25866 L
.18244 .25233 L
.18434 .25081 L
.19406 .24317 L
.19477 .24262 L
.20377 .23574 L
.20755 .23291 L
.21348 .22852 L
.22083 .22319 L
.22319 .22151 L
.23291 .2147 L
.23468 .21348 L
.24262 .20811 L
.24918 .20377 L
.25233 .20172 L
.26204 .19554 L
.26443 .19406 L
.27176 .18957 L
.28056 .18434 L
.28147 .18381 L
.29118 .17826 L
.29774 .17463 L
.30089 .17292 L
.31061 .16779 L
.31621 .16492 L
.32032 .16286 L
.33003 .15815 L
.33632 .15521 L
.33974 .15364 L
.34946 .14934 L
.35858 .14549 L
.35917 .14525 L
.36888 .14137 L
.37859 .1377 L
.38391 .13578 L
.38831 .13424 L
.39802 .13098 L
.40773 .12794 L
.41405 .12607 L
.41744 .1251 L
.42716 .12248 L
.43687 .12006 L
.44658 .11785 L
.45372 .11636 L
.45629 .11585 L
.46601 .11405 L
.47572 .11247 L
.48543 .1111 L
.49514 .10993 L
.50486 .10897 L
.51457 .10823 L
.52428 .10769 L
.53399 .10736 L
.54371 .10724 L
.55342 .10732 L
.56313 .10762 L
.57284 .10812 L
.58256 .10884 L
.59227 .10976 L
.60198 .11089 L
.61169 .11223 L
.62141 .11378 L
.63112 .11554 L
.63528 .11636 L
.64083 .11751 L
.65054 .11968 L
.66026 .12207 L
.66997 .12466 L
.67494 .12607 L
.67968 .12746 L
.68939 .13047 L
.69911 .13369 L
.70509 .13578 L
.70882 .13712 L
.71853 .14076 L
.72824 .14461 L
.73041 .14549 L
.73796 .14866 L
.74767 .15293 L
.75268 .15521 L
.75738 .1574 L
.76709 .16208 L
.77278 .16492 L
.77681 .16697 L
.78652 .17207 L
.79125 .17463 L
.79623 .17738 L
.80594 .1829 L
.80843 .18434 L
.81566 .18862 L
.82456 .19406 L
.82537 .19456 L
.83508 .2007 L
.83981 .20377 L
.84479 .20705 L
.85431 .21348 L
.85451 .21361 L
.86422 .22038 L
.86816 .22319 L
.87393 .22736 L
.88145 .23291 L
.88364 .23455 L
.89336 .24195 L
.89422 .24262 L
.90307 .24955 L
.90655 .25233 L
.91278 .25737 L
.91847 .26204 L
.92249 .26539 L
.93003 .27176 L
.93221 .27362 L
.94124 .28147 L
.94192 .28206 L
.95163 .29071 L
.95215 .29118 L
.96134 .29957 L
.96277 .30089 L
.97106 .30864 L
.97313 .31061 L
.98077 .31792 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .41264 m
.02347 .40773 L
.02894 .40145 L
.03196 .39802 L
.03866 .39047 L
.04059 .38831 L
.04837 .37969 L
.04937 .37859 L
.05808 .36913 L
.05831 .36888 L
.06742 .35917 L
.06779 .35878 L
.07671 .34946 L
.07751 .34863 L
.08618 .33974 L
.08722 .33869 L
.09586 .33003 L
.09693 .32897 L
.10574 .32032 L
.10664 .31945 L
.11586 .31061 L
.11636 .31014 L
.12607 .30103 L
.12622 .30089 L
.13578 .29214 L
.13684 .29118 L
.14549 .28346 L
.14775 .28147 L
.15521 .27498 L
.15897 .27176 L
.16492 .26672 L
.17052 .26204 L
.17463 .25866 L
.18244 .25233 L
.18434 .25081 L
.19406 .24317 L
.19477 .24262 L
.20377 .23574 L
.20755 .23291 L
.21348 .22852 L
.22083 .22319 L
.22319 .22151 L
.23291 .2147 L
.23468 .21348 L
.24262 .20811 L
.24918 .20377 L
.25233 .20172 L
.26204 .19554 L
.26443 .19406 L
.27176 .18957 L
Mistroke
.28056 .18434 L
.28147 .18381 L
.29118 .17826 L
.29774 .17463 L
.30089 .17292 L
.31061 .16779 L
.31621 .16492 L
.32032 .16286 L
.33003 .15815 L
.33632 .15521 L
.33974 .15364 L
.34946 .14934 L
.35858 .14549 L
.35917 .14525 L
.36888 .14137 L
.37859 .1377 L
.38391 .13578 L
.38831 .13424 L
.39802 .13098 L
.40773 .12794 L
.41405 .12607 L
.41744 .1251 L
.42716 .12248 L
.43687 .12006 L
.44658 .11785 L
.45372 .11636 L
.45629 .11585 L
.46601 .11405 L
.47572 .11247 L
.48543 .1111 L
.49514 .10993 L
.50486 .10897 L
.51457 .10823 L
.52428 .10769 L
.53399 .10736 L
.54371 .10724 L
.55342 .10732 L
.56313 .10762 L
.57284 .10812 L
.58256 .10884 L
.59227 .10976 L
.60198 .11089 L
.61169 .11223 L
.62141 .11378 L
.63112 .11554 L
.63528 .11636 L
.64083 .11751 L
.65054 .11968 L
.66026 .12207 L
.66997 .12466 L
Mistroke
.67494 .12607 L
.67968 .12746 L
.68939 .13047 L
.69911 .13369 L
.70509 .13578 L
.70882 .13712 L
.71853 .14076 L
.72824 .14461 L
.73041 .14549 L
.73796 .14866 L
.74767 .15293 L
.75268 .15521 L
.75738 .1574 L
.76709 .16208 L
.77278 .16492 L
.77681 .16697 L
.78652 .17207 L
.79125 .17463 L
.79623 .17738 L
.80594 .1829 L
.80843 .18434 L
.81566 .18862 L
.82456 .19406 L
.82537 .19456 L
.83508 .2007 L
.83981 .20377 L
.84479 .20705 L
.85431 .21348 L
.85451 .21361 L
.86422 .22038 L
.86816 .22319 L
.87393 .22736 L
.88145 .23291 L
.88364 .23455 L
.89336 .24195 L
.89422 .24262 L
.90307 .24955 L
.90655 .25233 L
.91278 .25737 L
.91847 .26204 L
.92249 .26539 L
.93003 .27176 L
.93221 .27362 L
.94124 .28147 L
.94192 .28206 L
.95163 .29071 L
.95215 .29118 L
.96134 .29957 L
.96277 .30089 L
.97106 .30864 L
Mistroke
.97313 .31061 L
.98077 .31792 L
Mfstroke
.85 g
.01923 .49692 m
.02076 .49514 L
.02894 .48572 L
.0292 .48543 L
.03778 .47572 L
.03866 .47473 L
.04651 .46601 L
.04837 .46395 L
.05539 .45629 L
.05808 .45339 L
.06444 .44658 L
.06779 .44303 L
.07366 .43687 L
.07751 .43287 L
.08307 .42716 L
.08722 .42293 L
.09267 .41744 L
.09693 .4132 L
.10248 .40773 L
.10664 .40367 L
.11251 .39802 L
.11636 .39436 L
.12278 .38831 L
.12607 .38525 L
.13331 .37859 L
.13578 .37635 L
.14412 .36888 L
.14549 .36766 L
.15521 .35918 L
.15522 .35917 L
.16492 .35091 L
.16665 .34946 L
.17463 .34285 L
.17844 .33974 L
.18434 .33499 L
.19062 .33003 L
.19406 .32735 L
.20323 .32032 L
.20377 .31991 L
.21348 .31269 L
.21633 .31061 L
.22319 .30567 L
.22997 .30089 L
.23291 .29886 L
.24262 .29226 L
.24423 .29118 L
.25233 .28587 L
.25921 .28147 L
.26204 .27969 L
.27176 .27371 L
.27501 .27176 L
.28147 .26795 L
.29118 .26239 L
.2918 .26204 L
.30089 .25704 L
.30979 .25233 L
.31061 .25191 L
.32032 .24698 L
.32927 .24262 L
.33003 .24226 L
.33974 .23775 L
.34946 .23344 L
.3507 .23291 L
.35917 .22935 L
.36888 .22547 L
.37482 .22319 L
.37859 .22179 L
.38831 .21832 L
.39802 .21507 L
.40298 .21348 L
.40773 .21202 L
.41744 .20918 L
.42716 .20655 L
.43687 .20412 L
.43837 .20377 L
.44658 .20191 L
.45629 .19991 L
.46601 .19811 L
.47572 .19652 L
.48543 .19515 L
.49443 .19406 L
.49514 .19398 L
.50486 .19302 L
.51457 .19227 L
.52428 .19172 L
.53399 .19139 L
.54371 .19127 L
.55342 .19135 L
.56313 .19164 L
.57284 .19215 L
.58256 .19286 L
.59227 .19378 L
.59485 .19406 L
.60198 .19491 L
.61169 .19625 L
.62141 .19779 L
.63112 .19955 L
.64083 .20151 L
.65054 .20369 L
.65089 .20377 L
.66026 .20607 L
.66997 .20866 L
.67968 .21146 L
.68628 .21348 L
.68939 .21447 L
.69911 .21769 L
.70882 .22111 L
.71444 .22319 L
.71853 .22475 L
.72824 .2286 L
.73796 .23265 L
.73856 .23291 L
.74767 .23691 L
.75738 .24138 L
.75999 .24262 L
.76709 .24606 L
.77681 .25095 L
.77947 .25233 L
.78652 .25605 L
.79623 .26136 L
.79746 .26204 L
.80594 .26687 L
.81425 .27176 L
.81566 .2726 L
.82537 .27853 L
.83005 .28147 L
.83508 .28467 L
.84479 .29103 L
.84503 .29118 L
.85451 .29759 L
.85929 .30089 L
.86422 .30436 L
.87293 .31061 L
.87393 .31133 L
.88364 .31852 L
.88603 .32032 L
.89336 .32592 L
.89864 .33003 L
.90307 .33352 L
.91082 .33974 L
.91278 .34134 L
.92249 .34936 L
.92261 .34946 L
.93221 .35759 L
.93404 .35917 L
.94192 .36603 L
.94515 .36888 L
.95163 .37468 L
.95595 .37859 L
.96134 .38354 L
.96648 .38831 L
.97106 .39261 L
.97675 .39802 L
.98077 .40188 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .49692 m
.02076 .49514 L
.02894 .48572 L
.0292 .48543 L
.03778 .47572 L
.03866 .47473 L
.04651 .46601 L
.04837 .46395 L
.05539 .45629 L
.05808 .45339 L
.06444 .44658 L
.06779 .44303 L
.07366 .43687 L
.07751 .43287 L
.08307 .42716 L
.08722 .42293 L
.09267 .41744 L
.09693 .4132 L
.10248 .40773 L
.10664 .40367 L
.11251 .39802 L
.11636 .39436 L
.12278 .38831 L
.12607 .38525 L
.13331 .37859 L
.13578 .37635 L
.14412 .36888 L
.14549 .36766 L
.15521 .35918 L
.15522 .35917 L
.16492 .35091 L
.16665 .34946 L
.17463 .34285 L
.17844 .33974 L
.18434 .33499 L
.19062 .33003 L
.19406 .32735 L
.20323 .32032 L
.20377 .31991 L
.21348 .31269 L
.21633 .31061 L
.22319 .30567 L
.22997 .30089 L
.23291 .29886 L
.24262 .29226 L
.24423 .29118 L
.25233 .28587 L
.25921 .28147 L
.26204 .27969 L
.27176 .27371 L
Mistroke
.27501 .27176 L
.28147 .26795 L
.29118 .26239 L
.2918 .26204 L
.30089 .25704 L
.30979 .25233 L
.31061 .25191 L
.32032 .24698 L
.32927 .24262 L
.33003 .24226 L
.33974 .23775 L
.34946 .23344 L
.3507 .23291 L
.35917 .22935 L
.36888 .22547 L
.37482 .22319 L
.37859 .22179 L
.38831 .21832 L
.39802 .21507 L
.40298 .21348 L
.40773 .21202 L
.41744 .20918 L
.42716 .20655 L
.43687 .20412 L
.43837 .20377 L
.44658 .20191 L
.45629 .19991 L
.46601 .19811 L
.47572 .19652 L
.48543 .19515 L
.49443 .19406 L
.49514 .19398 L
.50486 .19302 L
.51457 .19227 L
.52428 .19172 L
.53399 .19139 L
.54371 .19127 L
.55342 .19135 L
.56313 .19164 L
.57284 .19215 L
.58256 .19286 L
.59227 .19378 L
.59485 .19406 L
.60198 .19491 L
.61169 .19625 L
.62141 .19779 L
.63112 .19955 L
.64083 .20151 L
.65054 .20369 L
.65089 .20377 L
Mistroke
.66026 .20607 L
.66997 .20866 L
.67968 .21146 L
.68628 .21348 L
.68939 .21447 L
.69911 .21769 L
.70882 .22111 L
.71444 .22319 L
.71853 .22475 L
.72824 .2286 L
.73796 .23265 L
.73856 .23291 L
.74767 .23691 L
.75738 .24138 L
.75999 .24262 L
.76709 .24606 L
.77681 .25095 L
.77947 .25233 L
.78652 .25605 L
.79623 .26136 L
.79746 .26204 L
.80594 .26687 L
.81425 .27176 L
.81566 .2726 L
.82537 .27853 L
.83005 .28147 L
.83508 .28467 L
.84479 .29103 L
.84503 .29118 L
.85451 .29759 L
.85929 .30089 L
.86422 .30436 L
.87293 .31061 L
.87393 .31133 L
.88364 .31852 L
.88603 .32032 L
.89336 .32592 L
.89864 .33003 L
.90307 .33352 L
.91082 .33974 L
.91278 .34134 L
.92249 .34936 L
.92261 .34946 L
.93221 .35759 L
.93404 .35917 L
.94192 .36603 L
.94515 .36888 L
.95163 .37468 L
.95595 .37859 L
.96134 .38354 L
Mistroke
.96648 .38831 L
.97106 .39261 L
.97675 .39802 L
.98077 .40188 L
Mfstroke
.925 g
.01923 .59881 m
.02488 .59227 L
.02894 .5876 L
.03338 .58256 L
.03866 .5766 L
.04202 .57284 L
.04837 .56582 L
.05081 .56313 L
.05808 .55523 L
.05977 .55342 L
.06779 .54486 L
.06889 .54371 L
.07751 .5347 L
.07819 .53399 L
.08722 .52475 L
.08768 .52428 L
.09693 .515 L
.09737 .51457 L
.10664 .50547 L
.10727 .50486 L
.11636 .49614 L
.11741 .49514 L
.12607 .48703 L
.12779 .48543 L
.13578 .47812 L
.13844 .47572 L
.14549 .46942 L
.14937 .46601 L
.15521 .46093 L
.16061 .45629 L
.16492 .45265 L
.17219 .44658 L
.17463 .44457 L
.18415 .43687 L
.18434 .43671 L
.19406 .42906 L
.19651 .42716 L
.20377 .42161 L
.20933 .41744 L
.21348 .41438 L
.22266 .40773 L
.22319 .40735 L
.23291 .40053 L
.23656 .39802 L
.24262 .39392 L
.25113 .38831 L
.25233 .38752 L
.26204 .38133 L
.26645 .37859 L
.27176 .37535 L
.28147 .36958 L
.28266 .36888 L
.29118 .36401 L
.29995 .35917 L
.30089 .35866 L
.31061 .35351 L
.31856 .34946 L
.32032 .34858 L
.33003 .34385 L
.33883 .33974 L
.33974 .33933 L
.34946 .33502 L
.35917 .33092 L
.36134 .33003 L
.36888 .32703 L
.37859 .32334 L
.38702 .32032 L
.38831 .31987 L
.39802 .31661 L
.40773 .31355 L
.41744 .3107 L
.41779 .31061 L
.42716 .30807 L
.43687 .30564 L
.44658 .30342 L
.45629 .30141 L
.45895 .30089 L
.46601 .29961 L
.47572 .29801 L
.48543 .29663 L
.49514 .29546 L
.50486 .29449 L
.51457 .29373 L
.52428 .29319 L
.53399 .29285 L
.54371 .29272 L
.55342 .2928 L
.56313 .29309 L
.57284 .29358 L
.58256 .29429 L
.59227 .29521 L
.60198 .29633 L
.61169 .29766 L
.62141 .29921 L
.63078 .30089 L
.63112 .30096 L
.64083 .30292 L
.65054 .30509 L
.66026 .30747 L
.66997 .31006 L
.67194 .31061 L
.67968 .31285 L
.68939 .31586 L
.69911 .31907 L
.70271 .32032 L
.70882 .3225 L
.71853 .32613 L
.72824 .32997 L
.72839 .33003 L
.73796 .33402 L
.74767 .33828 L
.7509 .33974 L
.75738 .34275 L
.76709 .34743 L
.77118 .34946 L
.77681 .35231 L
.78652 .35741 L
.78978 .35917 L
.79623 .36272 L
.80594 .36823 L
.80707 .36888 L
.81566 .37395 L
.82329 .37859 L
.82537 .37988 L
.83508 .38602 L
.83861 .38831 L
.84479 .39237 L
.85317 .39802 L
.85451 .39893 L
.86422 .4057 L
.86708 .40773 L
.87393 .41268 L
.8804 .41744 L
.88364 .41986 L
.89322 .42716 L
.89336 .42726 L
.90307 .43486 L
.90559 .43687 L
.91278 .44268 L
.91754 .44658 L
.92249 .4507 L
.92912 .45629 L
.93221 .45893 L
.94037 .46601 L
.94192 .46737 L
.9513 .47572 L
.95163 .47602 L
.96134 .48488 L
.96195 .48543 L
.97106 .49394 L
.97233 .49514 L
.98077 .50322 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .59881 m
.02488 .59227 L
.02894 .5876 L
.03338 .58256 L
.03866 .5766 L
.04202 .57284 L
.04837 .56582 L
.05081 .56313 L
.05808 .55523 L
.05977 .55342 L
.06779 .54486 L
.06889 .54371 L
.07751 .5347 L
.07819 .53399 L
.08722 .52475 L
.08768 .52428 L
.09693 .515 L
.09737 .51457 L
.10664 .50547 L
.10727 .50486 L
.11636 .49614 L
.11741 .49514 L
.12607 .48703 L
.12779 .48543 L
.13578 .47812 L
.13844 .47572 L
.14549 .46942 L
.14937 .46601 L
.15521 .46093 L
.16061 .45629 L
.16492 .45265 L
.17219 .44658 L
.17463 .44457 L
.18415 .43687 L
.18434 .43671 L
.19406 .42906 L
.19651 .42716 L
.20377 .42161 L
.20933 .41744 L
.21348 .41438 L
.22266 .40773 L
.22319 .40735 L
.23291 .40053 L
.23656 .39802 L
.24262 .39392 L
.25113 .38831 L
.25233 .38752 L
.26204 .38133 L
.26645 .37859 L
.27176 .37535 L
Mistroke
.28147 .36958 L
.28266 .36888 L
.29118 .36401 L
.29995 .35917 L
.30089 .35866 L
.31061 .35351 L
.31856 .34946 L
.32032 .34858 L
.33003 .34385 L
.33883 .33974 L
.33974 .33933 L
.34946 .33502 L
.35917 .33092 L
.36134 .33003 L
.36888 .32703 L
.37859 .32334 L
.38702 .32032 L
.38831 .31987 L
.39802 .31661 L
.40773 .31355 L
.41744 .3107 L
.41779 .31061 L
.42716 .30807 L
.43687 .30564 L
.44658 .30342 L
.45629 .30141 L
.45895 .30089 L
.46601 .29961 L
.47572 .29801 L
.48543 .29663 L
.49514 .29546 L
.50486 .29449 L
.51457 .29373 L
.52428 .29319 L
.53399 .29285 L
.54371 .29272 L
.55342 .2928 L
.56313 .29309 L
.57284 .29358 L
.58256 .29429 L
.59227 .29521 L
.60198 .29633 L
.61169 .29766 L
.62141 .29921 L
.63078 .30089 L
.63112 .30096 L
.64083 .30292 L
.65054 .30509 L
.66026 .30747 L
.66997 .31006 L
Mistroke
.67194 .31061 L
.67968 .31285 L
.68939 .31586 L
.69911 .31907 L
.70271 .32032 L
.70882 .3225 L
.71853 .32613 L
.72824 .32997 L
.72839 .33003 L
.73796 .33402 L
.74767 .33828 L
.7509 .33974 L
.75738 .34275 L
.76709 .34743 L
.77118 .34946 L
.77681 .35231 L
.78652 .35741 L
.78978 .35917 L
.79623 .36272 L
.80594 .36823 L
.80707 .36888 L
.81566 .37395 L
.82329 .37859 L
.82537 .37988 L
.83508 .38602 L
.83861 .38831 L
.84479 .39237 L
.85317 .39802 L
.85451 .39893 L
.86422 .4057 L
.86708 .40773 L
.87393 .41268 L
.8804 .41744 L
.88364 .41986 L
.89322 .42716 L
.89336 .42726 L
.90307 .43486 L
.90559 .43687 L
.91278 .44268 L
.91754 .44658 L
.92249 .4507 L
.92912 .45629 L
.93221 .45893 L
.94037 .46601 L
.94192 .46737 L
.9513 .47572 L
.95163 .47602 L
.96134 .48488 L
.96195 .48543 L
.97106 .49394 L
Mistroke
.97233 .49514 L
.98077 .50322 L
Mfstroke
1 g
.01923 .73865 m
.01982 .73796 L
.02822 .72824 L
.02894 .72741 L
.03675 .71853 L
.03866 .71638 L
.04543 .70882 L
.04837 .70556 L
.05426 .69911 L
.05808 .69495 L
.06325 .68939 L
.06779 .68455 L
.07241 .67968 L
.07751 .67436 L
.08176 .66997 L
.08722 .66438 L
.09129 .66026 L
.09693 .65461 L
.10103 .65054 L
.10664 .64505 L
.11099 .64083 L
.11636 .63569 L
.12119 .63112 L
.12607 .62655 L
.13163 .62141 L
.13578 .61762 L
.14235 .61169 L
.14549 .60889 L
.15335 .60198 L
.15521 .60037 L
.16468 .59227 L
.16492 .59207 L
.17463 .58397 L
.17635 .58256 L
.18434 .57608 L
.18841 .57284 L
.19406 .5684 L
.20088 .56313 L
.20377 .56093 L
.21348 .55367 L
.21383 .55342 L
.22319 .54662 L
.2273 .54371 L
.23291 .53978 L
.24136 .53399 L
.24262 .53315 L
.25233 .52673 L
.25611 .52428 L
.26204 .52051 L
.27166 .51457 L
.27176 .51451 L
.28147 .50871 L
.28814 .50486 L
.29118 .50313 L
.30089 .49775 L
.30575 .49514 L
.31061 .49259 L
.32032 .48763 L
.32476 .48543 L
.33003 .48288 L
.33974 .47834 L
.34557 .47572 L
.34946 .47401 L
.35917 .46989 L
.36882 .46601 L
.36888 .46598 L
.37859 .46228 L
.38831 .45879 L
.39563 .45629 L
.39802 .45551 L
.40773 .45243 L
.41744 .44957 L
.42716 .44691 L
.42843 .44658 L
.43687 .44447 L
.44658 .44223 L
.45629 .4402 L
.46601 .43839 L
.47514 .43687 L
.47572 .43678 L
.48543 .43538 L
.49514 .43419 L
.50486 .43321 L
.51457 .43244 L
.52428 .43188 L
.53399 .43152 L
.54371 .43138 L
.55342 .43145 L
.56313 .43172 L
.57284 .43221 L
.58256 .4329 L
.59227 .43381 L
.60198 .43492 L
.61169 .43624 L
.61584 .43687 L
.62141 .43777 L
.63112 .43951 L
.64083 .44146 L
.65054 .44362 L
.66026 .44599 L
.66255 .44658 L
.66997 .44857 L
.67968 .45136 L
.68939 .45435 L
.69535 .45629 L
.69911 .45756 L
.70882 .46098 L
.71853 .4646 L
.72216 .46601 L
.72824 .46843 L
.73796 .47248 L
.7454 .47572 L
.74767 .47673 L
.75738 .48119 L
.76622 .48543 L
.76709 .48586 L
.77681 .49074 L
.78523 .49514 L
.78652 .49583 L
.79623 .50113 L
.80284 .50486 L
.80594 .50664 L
.81566 .51236 L
.81932 .51457 L
.82537 .51828 L
.83486 .52428 L
.83508 .52442 L
.84479 .53077 L
.84961 .53399 L
.85451 .53732 L
.86368 .54371 L
.86422 .54409 L
.87393 .55106 L
.87715 .55342 L
.88364 .55824 L
.8901 .56313 L
.89336 .56563 L
.90258 .57284 L
.90307 .57324 L
.91278 .58105 L
.91463 .58256 L
.92249 .58907 L
.9263 .59227 L
.93221 .5973 L
.93763 .60198 L
.94192 .60573 L
.94864 .61169 L
.95163 .61438 L
.95935 .62141 L
.96134 .62324 L
.9698 .63112 L
.97106 .63231 L
.97999 .64083 L
.98077 .64158 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .73865 m
.01982 .73796 L
.02822 .72824 L
.02894 .72741 L
.03675 .71853 L
.03866 .71638 L
.04543 .70882 L
.04837 .70556 L
.05426 .69911 L
.05808 .69495 L
.06325 .68939 L
.06779 .68455 L
.07241 .67968 L
.07751 .67436 L
.08176 .66997 L
.08722 .66438 L
.09129 .66026 L
.09693 .65461 L
.10103 .65054 L
.10664 .64505 L
.11099 .64083 L
.11636 .63569 L
.12119 .63112 L
.12607 .62655 L
.13163 .62141 L
.13578 .61762 L
.14235 .61169 L
.14549 .60889 L
.15335 .60198 L
.15521 .60037 L
.16468 .59227 L
.16492 .59207 L
.17463 .58397 L
.17635 .58256 L
.18434 .57608 L
.18841 .57284 L
.19406 .5684 L
.20088 .56313 L
.20377 .56093 L
.21348 .55367 L
.21383 .55342 L
.22319 .54662 L
.2273 .54371 L
.23291 .53978 L
.24136 .53399 L
.24262 .53315 L
.25233 .52673 L
.25611 .52428 L
.26204 .52051 L
.27166 .51457 L
Mistroke
.27176 .51451 L
.28147 .50871 L
.28814 .50486 L
.29118 .50313 L
.30089 .49775 L
.30575 .49514 L
.31061 .49259 L
.32032 .48763 L
.32476 .48543 L
.33003 .48288 L
.33974 .47834 L
.34557 .47572 L
.34946 .47401 L
.35917 .46989 L
.36882 .46601 L
.36888 .46598 L
.37859 .46228 L
.38831 .45879 L
.39563 .45629 L
.39802 .45551 L
.40773 .45243 L
.41744 .44957 L
.42716 .44691 L
.42843 .44658 L
.43687 .44447 L
.44658 .44223 L
.45629 .4402 L
.46601 .43839 L
.47514 .43687 L
.47572 .43678 L
.48543 .43538 L
.49514 .43419 L
.50486 .43321 L
.51457 .43244 L
.52428 .43188 L
.53399 .43152 L
.54371 .43138 L
.55342 .43145 L
.56313 .43172 L
.57284 .43221 L
.58256 .4329 L
.59227 .43381 L
.60198 .43492 L
.61169 .43624 L
.61584 .43687 L
.62141 .43777 L
.63112 .43951 L
.64083 .44146 L
.65054 .44362 L
.66026 .44599 L
Mistroke
.66255 .44658 L
.66997 .44857 L
.67968 .45136 L
.68939 .45435 L
.69535 .45629 L
.69911 .45756 L
.70882 .46098 L
.71853 .4646 L
.72216 .46601 L
.72824 .46843 L
.73796 .47248 L
.7454 .47572 L
.74767 .47673 L
.75738 .48119 L
.76622 .48543 L
.76709 .48586 L
.77681 .49074 L
.78523 .49514 L
.78652 .49583 L
.79623 .50113 L
.80284 .50486 L
.80594 .50664 L
.81566 .51236 L
.81932 .51457 L
.82537 .51828 L
.83486 .52428 L
.83508 .52442 L
.84479 .53077 L
.84961 .53399 L
.85451 .53732 L
.86368 .54371 L
.86422 .54409 L
.87393 .55106 L
.87715 .55342 L
.88364 .55824 L
.8901 .56313 L
.89336 .56563 L
.90258 .57284 L
.90307 .57324 L
.91278 .58105 L
.91463 .58256 L
.92249 .58907 L
.9263 .59227 L
.93221 .5973 L
.93763 .60198 L
.94192 .60573 L
.94864 .61169 L
.95163 .61438 L
.95935 .62141 L
.96134 .62324 L
Mistroke
.9698 .63112 L
.97106 .63231 L
.97999 .64083 L
.98077 .64158 L
Mfstroke
.55 g
.01923 .27308 m
.02037 .27176 L
.02881 .26204 L
.02894 .2619 L
.0374 .25233 L
.03866 .25092 L
.04613 .24262 L
.04837 .24016 L
.05502 .23291 L
.05808 .2296 L
.06407 .22319 L
.06779 .21925 L
.0733 .21348 L
.07751 .20912 L
.08271 .20377 L
.08722 .19919 L
.09232 .19406 L
.09693 .18946 L
.10213 .18434 L
.10664 .17995 L
.11217 .17463 L
.11636 .17065 L
.12245 .16492 L
.12607 .16155 L
.13298 .15521 L
.13578 .15267 L
.14379 .14549 L
.14549 .14399 L
.1549 .13578 L
.15521 .13552 L
.16492 .12726 L
.16634 .12607 L
.17463 .11921 L
.17814 .11636 L
.18434 .11137 L
.19032 .10664 L
.19406 .10373 L
.20295 .09693 L
.20377 .09631 L
.21348 .08909 L
.21605 .08722 L
.22319 .08209 L
.2297 .07751 L
.23291 .07529 L
.24262 .0687 L
.24398 .06779 L
.25233 .06232 L
.25896 .05808 L
.26204 .05615 L
.27176 .05018 L
.27478 .04837 L
.28147 .04443 L
.29118 .03888 L
.29158 .03866 L
.30089 .03354 L
.30959 .02894 L
.31061 .02842 L
.32032 .0235 L
.32909 .01923 L
.01923 .01923 L
F
0 g
.01923 .27308 m
.02037 .27176 L
.02881 .26204 L
.02894 .2619 L
.0374 .25233 L
.03866 .25092 L
.04613 .24262 L
.04837 .24016 L
.05502 .23291 L
.05808 .2296 L
.06407 .22319 L
.06779 .21925 L
.0733 .21348 L
.07751 .20912 L
.08271 .20377 L
.08722 .19919 L
.09232 .19406 L
.09693 .18946 L
.10213 .18434 L
.10664 .17995 L
.11217 .17463 L
.11636 .17065 L
.12245 .16492 L
.12607 .16155 L
.13298 .15521 L
.13578 .15267 L
.14379 .14549 L
.14549 .14399 L
.1549 .13578 L
.15521 .13552 L
.16492 .12726 L
.16634 .12607 L
.17463 .11921 L
.17814 .11636 L
.18434 .11137 L
.19032 .10664 L
.19406 .10373 L
.20295 .09693 L
.20377 .09631 L
.21348 .08909 L
.21605 .08722 L
.22319 .08209 L
.2297 .07751 L
.23291 .07529 L
.24262 .0687 L
.24398 .06779 L
.25233 .06232 L
.25896 .05808 L
.26204 .05615 L
.27176 .05018 L
Mistroke
.27478 .04837 L
.28147 .04443 L
.29118 .03888 L
.29158 .03866 L
.30089 .03354 L
.30959 .02894 L
.31061 .02842 L
.32032 .0235 L
.32909 .01923 L
Mfstroke
.475 g
.01923 .2126 m
.02689 .20377 L
.02894 .20142 L
.03544 .19406 L
.03866 .19045 L
.04414 .18434 L
.04837 .17969 L
.053 .17463 L
.05808 .16913 L
.06201 .16492 L
.06779 .15879 L
.0712 .15521 L
.07751 .14865 L
.08057 .14549 L
.08722 .13872 L
.09014 .13578 L
.09693 .129 L
.09991 .12607 L
.10664 .11949 L
.1099 .11636 L
.11636 .11019 L
.12012 .10664 L
.12607 .1011 L
.1306 .09693 L
.13578 .09222 L
.14135 .08722 L
.14549 .08354 L
.15239 .07751 L
.15521 .07507 L
.16376 .06779 L
.16492 .06682 L
.17463 .05877 L
.17547 .05808 L
.18434 .05093 L
.18757 .04837 L
.19406 .04329 L
.20009 .03866 L
.20377 .03587 L
.21309 .02894 L
.21348 .02866 L
.22319 .02165 L
.22662 .01923 L
.01923 .01923 L
F
0 g
.01923 .2126 m
.02689 .20377 L
.02894 .20142 L
.03544 .19406 L
.03866 .19045 L
.04414 .18434 L
.04837 .17969 L
.053 .17463 L
.05808 .16913 L
.06201 .16492 L
.06779 .15879 L
.0712 .15521 L
.07751 .14865 L
.08057 .14549 L
.08722 .13872 L
.09014 .13578 L
.09693 .129 L
.09991 .12607 L
.10664 .11949 L
.1099 .11636 L
.11636 .11019 L
.12012 .10664 L
.12607 .1011 L
.1306 .09693 L
.13578 .09222 L
.14135 .08722 L
.14549 .08354 L
.15239 .07751 L
.15521 .07507 L
.16376 .06779 L
.16492 .06682 L
.17463 .05877 L
.17547 .05808 L
.18434 .05093 L
.18757 .04837 L
.19406 .04329 L
.20009 .03866 L
.20377 .03587 L
.21309 .02894 L
.21348 .02866 L
.22319 .02165 L
.22662 .01923 L
s
.4 g
.01923 .15648 m
.02033 .15521 L
.02878 .14549 L
.02894 .1453 L
.03736 .13578 L
.03866 .13433 L
.0461 .12607 L
.04837 .12357 L
.05499 .11636 L
.05808 .11302 L
.06405 .10664 L
.06779 .10268 L
.07328 .09693 L
.07751 .09254 L
.08269 .08722 L
.08722 .08262 L
.0923 .07751 L
.09693 .0729 L
.10212 .06779 L
.10664 .06339 L
.11216 .05808 L
.11636 .05409 L
.12244 .04837 L
.12607 .045 L
.13298 .03866 L
.13578 .03612 L
.1438 .02894 L
.14549 .02744 L
.15491 .01923 L
.01923 .01923 L
F
0 g
.01923 .15648 m
.02033 .15521 L
.02878 .14549 L
.02894 .1453 L
.03736 .13578 L
.03866 .13433 L
.0461 .12607 L
.04837 .12357 L
.05499 .11636 L
.05808 .11302 L
.06405 .10664 L
.06779 .10268 L
.07328 .09693 L
.07751 .09254 L
.08269 .08722 L
.08722 .08262 L
.0923 .07751 L
.09693 .0729 L
.10212 .06779 L
.10664 .06339 L
.11216 .05808 L
.11636 .05409 L
.12244 .04837 L
.12607 .045 L
.13298 .03866 L
.13578 .03612 L
.1438 .02894 L
.14549 .02744 L
.15491 .01923 L
s
.325 g
.01923 .1039 m
.02526 .09693 L
.02894 .09272 L
.03379 .08722 L
.03866 .08175 L
.04247 .07751 L
.04837 .07099 L
.05129 .06779 L
.05808 .06044 L
.06028 .05808 L
.06779 .0501 L
.06944 .04837 L
.07751 .03997 L
.07878 .03866 L
.08722 .03004 L
.08831 .02894 L
.09693 .02033 L
.09804 .01923 L
.01923 .01923 L
F
0 g
.01923 .1039 m
.02526 .09693 L
.02894 .09272 L
.03379 .08722 L
.03866 .08175 L
.04247 .07751 L
.04837 .07099 L
.05129 .06779 L
.05808 .06044 L
.06028 .05808 L
.06779 .0501 L
.06944 .04837 L
.07751 .03997 L
.07878 .03866 L
.08722 .03004 L
.08831 .02894 L
.09693 .02033 L
.09804 .01923 L
s
.25 g
.01923 .05425 m
.02432 .04837 L
.02894 .04308 L
.03284 .03866 L
.03866 .03211 L
.04149 .02894 L
.04837 .02135 L
.05031 .01923 L
.01923 .01923 L
F
0 g
.01923 .05425 m
.02432 .04837 L
.02894 .04308 L
.03284 .03866 L
.03866 .03211 L
.04149 .02894 L
.04837 .02135 L
.05031 .01923 L
s
.925 g
.71622 .98077 m
.70882 .97799 L
.69911 .97453 L
.68939 .97127 L
.68873 .97106 L
.67968 .96822 L
.66997 .96538 L
.66026 .96275 L
.65474 .96134 L
.65054 .96032 L
.64083 .9581 L
.63112 .95609 L
.62141 .95429 L
.61169 .95269 L
.6044 .95163 L
.60198 .95131 L
.59227 .95013 L
.58256 .94915 L
.57284 .94839 L
.56313 .94783 L
.55342 .94748 L
.54371 .94734 L
.53399 .94741 L
.52428 .94768 L
.51457 .94816 L
.50486 .94885 L
.49514 .94974 L
.48543 .95085 L
.47942 .95163 L
.47572 .95216 L
.46601 .95368 L
.45629 .9554 L
.44658 .95734 L
.43687 .95948 L
.42908 .96134 L
.42716 .96183 L
.41744 .96438 L
.40773 .96715 L
.39802 .97012 L
.39509 .97106 L
.38831 .9733 L
.37859 .97668 L
.36888 .98028 L
.3676 .98077 L
F
0 g
.71622 .98077 m
.70882 .97799 L
.69911 .97453 L
.68939 .97127 L
.68873 .97106 L
.67968 .96822 L
.66997 .96538 L
.66026 .96275 L
.65474 .96134 L
.65054 .96032 L
.64083 .9581 L
.63112 .95609 L
.62141 .95429 L
.61169 .95269 L
.6044 .95163 L
.60198 .95131 L
.59227 .95013 L
.58256 .94915 L
.57284 .94839 L
.56313 .94783 L
.55342 .94748 L
.54371 .94734 L
.53399 .94741 L
.52428 .94768 L
.51457 .94816 L
.50486 .94885 L
.49514 .94974 L
.48543 .95085 L
.47942 .95163 L
.47572 .95216 L
.46601 .95368 L
.45629 .9554 L
.44658 .95734 L
.43687 .95948 L
.42908 .96134 L
.42716 .96183 L
.41744 .96438 L
.40773 .96715 L
.39802 .97012 L
.39509 .97106 L
.38831 .9733 L
.37859 .97668 L
.36888 .98028 L
.3676 .98077 L
s
.55 g
.98077 .17872 m
.97652 .17463 L
.97106 .16944 L
.96624 .16492 L
.96134 .16037 L
.95571 .15521 L
.95163 .15151 L
.9449 .14549 L
.94192 .14286 L
.93379 .13578 L
.93221 .13442 L
.92249 .12619 L
.92235 .12607 L
.91278 .11817 L
.91055 .11636 L
.90307 .11035 L
.89837 .10664 L
.89336 .10275 L
.88574 .09693 L
.88364 .09535 L
.87393 .08816 L
.87264 .08722 L
.86422 .08118 L
.85899 .07751 L
.85451 .07441 L
.84479 .06785 L
.84471 .06779 L
.83508 .06149 L
.82973 .05808 L
.82537 .05535 L
.81566 .04941 L
.81391 .04837 L
.80594 .04369 L
.79711 .03866 L
.79623 .03817 L
.78652 .03286 L
.7791 .02894 L
.77681 .02776 L
.76709 .02286 L
.7596 .01923 L
.98077 .01923 L
F
0 g
.98077 .17872 m
.97652 .17463 L
.97106 .16944 L
.96624 .16492 L
.96134 .16037 L
.95571 .15521 L
.95163 .15151 L
.9449 .14549 L
.94192 .14286 L
.93379 .13578 L
.93221 .13442 L
.92249 .12619 L
.92235 .12607 L
.91278 .11817 L
.91055 .11636 L
.90307 .11035 L
.89837 .10664 L
.89336 .10275 L
.88574 .09693 L
.88364 .09535 L
.87393 .08816 L
.87264 .08722 L
.86422 .08118 L
.85899 .07751 L
.85451 .07441 L
.84479 .06785 L
.84471 .06779 L
.83508 .06149 L
.82973 .05808 L
.82537 .05535 L
.81566 .04941 L
.81391 .04837 L
.80594 .04369 L
.79711 .03866 L
.79623 .03817 L
.78652 .03286 L
.7791 .02894 L
.77681 .02776 L
.76709 .02286 L
.7596 .01923 L
s
.475 g
.98077 .11835 m
.9787 .11636 L
.97106 .10908 L
.96847 .10664 L
.96134 .10001 L
.95799 .09693 L
.95163 .09115 L
.94724 .08722 L
.94192 .0825 L
.9362 .07751 L
.93221 .07406 L
.92484 .06779 L
.92249 .06583 L
.91312 .05808 L
.91278 .0578 L
.90307 .04999 L
.90102 .04837 L
.89336 .04238 L
.8885 .03866 L
.88364 .03498 L
.8755 .02894 L
.87393 .0278 L
.86422 .02082 L
.86197 .01923 L
.98077 .01923 L
F
0 g
.98077 .11835 m
.9787 .11636 L
.97106 .10908 L
.96847 .10664 L
.96134 .10001 L
.95799 .09693 L
.95163 .09115 L
.94724 .08722 L
.94192 .0825 L
.9362 .07751 L
.93221 .07406 L
.92484 .06779 L
.92249 .06583 L
.91312 .05808 L
.91278 .0578 L
.90307 .04999 L
.90102 .04837 L
.89336 .04238 L
.8885 .03866 L
.88364 .03498 L
.8755 .02894 L
.87393 .0278 L
.86422 .02082 L
.86197 .01923 L
s
.4 g
.98077 .06233 m
.97635 .05808 L
.97106 .05305 L
.96607 .04837 L
.96134 .04398 L
.95553 .03866 L
.95163 .03512 L
.94472 .02894 L
.94192 .02647 L
.9336 .01923 L
.98077 .01923 L
F
0 g
.98077 .06233 m
.97635 .05808 L
.97106 .05305 L
.96607 .04837 L
.96134 .04398 L
.95553 .03866 L
.95163 .03512 L
.94472 .02894 L
.94192 .02647 L
.9336 .01923 L
s
0 0 0 r
.055 w
.98077 .90042 Mdot
0 1 1 r
.045 w
.01923 .90042 Mdot
.03003 .98077 Mdot
.07211 .93302 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
1 0 0 r
.0325 w
.01923 .90042 Mdot
.03003 .98077 Mdot
.87724 .01923 Mdot
.17336 .81811 Mdot
.07211 .93302 Mdot
.37811 .6162 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.50814 .64425 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.65504 .67874 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.90361 .81949 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
0 1 0 r
.02 w
.01923 .90042 Mdot
.03003 .98077 Mdot
.87724 .01923 Mdot
.17336 .81811 Mdot
.07211 .93302 Mdot
.37811 .6162 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.50814 .64425 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.65504 .67874 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.90361 .81949 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
0 0 1 r
.5 Mabswid
.01923 .90042 m
.01923 .90042 L
.03003 .98077 L
.07211 .93302 L
.13859 .86419 L
.25607 .76553 L
.30297 .75096 L
.36146 .72054 L
.4609 .68601 L
.50669 .68856 L
.56182 .68491 L
.63714 .69274 L
.68666 .70923 L
.76911 .73799 L
.79519 .75849 L
.83361 .7801 L
.88258 .81359 L
.91054 .83718 L
.94916 .86935 L
.9615 .88205 L
.97812 .89757 L
.98017 .89984 L
.98077 .90042 L
.98077 .90042 L
s
.015 w
.01923 .90042 Mdot
.01923 .90042 Mdot
.03003 .98077 Mdot
.07211 .93302 Mdot
.13859 .86419 Mdot
.25607 .76553 Mdot
.30297 .75096 Mdot
.36146 .72054 Mdot
.4609 .68601 Mdot
.50669 .68856 Mdot
.56182 .68491 Mdot
.63714 .69274 Mdot
.68666 .70923 Mdot
.76911 .73799 Mdot
.79519 .75849 Mdot
.83361 .7801 Mdot
.88258 .81359 Mdot
.91054 .83718 Mdot
.94916 .86935 Mdot
.9615 .88205 Mdot
.97812 .89757 Mdot
.98017 .89984 Mdot
.98077 .90042 Mdot
.98077 .90042 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0055371 0.732558 0.227021 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.541113 0.434902 0.109336 0.672845 [
[.10621 -0.0125 -6 -9 ]
[.10621 -0.0125 6 0 ]
[.32366 -0.0125 -12 -9 ]
[.32366 -0.0125 12 0 ]
[.54111 -0.0125 -3 -9 ]
[.54111 -0.0125 3 0 ]
[.75856 -0.0125 -9 -9 ]
[.75856 -0.0125 9 0 ]
[.97602 -0.0125 -3 -9 ]
[.97602 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10934 -6 -4.5 ]
[-0.0125 .10934 0 4.5 ]
[-0.0125 .24391 -18 -4.5 ]
[-0.0125 .24391 0 4.5 ]
[-0.0125 .37847 -18 -4.5 ]
[-0.0125 .37847 0 4.5 ]
[-0.0125 .51304 -18 -4.5 ]
[-0.0125 .51304 0 4.5 ]
[-0.0125 .64761 -18 -4.5 ]
[-0.0125 .64761 0 4.5 ]
[-0.0125 .78218 -6 -4.5 ]
[-0.0125 .78218 0 4.5 ]
[-0.0125 .91675 -18 -4.5 ]
[-0.0125 .91675 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10621 0 m
.10621 .00625 L
s
[(-1)] .10621 -0.0125 0 1 Mshowa
.32366 0 m
.32366 .00625 L
s
[(-0.5)] .32366 -0.0125 0 1 Mshowa
.54111 0 m
.54111 .00625 L
s
[(0)] .54111 -0.0125 0 1 Mshowa
.75856 0 m
.75856 .00625 L
s
[(0.5)] .75856 -0.0125 0 1 Mshowa
.97602 0 m
.97602 .00625 L
s
[(1)] .97602 -0.0125 0 1 Mshowa
.125 Mabswid
.1497 0 m
.1497 .00375 L
s
.19319 0 m
.19319 .00375 L
s
.23668 0 m
.23668 .00375 L
s
.28017 0 m
.28017 .00375 L
s
.36715 0 m
.36715 .00375 L
s
.41064 0 m
.41064 .00375 L
s
.45413 0 m
.45413 .00375 L
s
.49762 0 m
.49762 .00375 L
s
.5846 0 m
.5846 .00375 L
s
.62809 0 m
.62809 .00375 L
s
.67158 0 m
.67158 .00375 L
s
.71507 0 m
.71507 .00375 L
s
.80205 0 m
.80205 .00375 L
s
.84554 0 m
.84554 .00375 L
s
.88903 0 m
.88903 .00375 L
s
.93253 0 m
.93253 .00375 L
s
.06272 0 m
.06272 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10934 m
.00625 .10934 L
s
[(0)] -0.0125 .10934 1 0 Mshowa
0 .24391 m
.00625 .24391 L
s
[(0.2)] -0.0125 .24391 1 0 Mshowa
0 .37847 m
.00625 .37847 L
s
[(0.4)] -0.0125 .37847 1 0 Mshowa
0 .51304 m
.00625 .51304 L
s
[(0.6)] -0.0125 .51304 1 0 Mshowa
0 .64761 m
.00625 .64761 L
s
[(0.8)] -0.0125 .64761 1 0 Mshowa
0 .78218 m
.00625 .78218 L
s
[(1)] -0.0125 .78218 1 0 Mshowa
0 .91675 m
.00625 .91675 L
s
[(1.2)] -0.0125 .91675 1 0 Mshowa
.125 Mabswid
0 .14298 m
.00375 .14298 L
s
0 .17662 m
.00375 .17662 L
s
0 .21026 m
.00375 .21026 L
s
0 .27755 m
.00375 .27755 L
s
0 .31119 m
.00375 .31119 L
s
0 .34483 m
.00375 .34483 L
s
0 .41212 m
.00375 .41212 L
s
0 .44576 m
.00375 .44576 L
s
0 .4794 m
.00375 .4794 L
s
0 .54669 m
.00375 .54669 L
s
0 .58033 m
.00375 .58033 L
s
0 .61397 m
.00375 .61397 L
s
0 .68125 m
.00375 .68125 L
s
0 .7149 m
.00375 .7149 L
s
0 .74854 m
.00375 .74854 L
s
0 .81582 m
.00375 .81582 L
s
0 .84947 m
.00375 .84947 L
s
0 .88311 m
.00375 .88311 L
s
0 .07569 m
.00375 .07569 L
s
0 .04205 m
.00375 .04205 L
s
0 .00841 m
.00375 .00841 L
s
0 .95039 m
.00375 .95039 L
s
0 .98403 m
.00375 .98403 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10621 .99375 m
.10621 1 L
s
.32366 .99375 m
.32366 1 L
s
.54111 .99375 m
.54111 1 L
s
.75856 .99375 m
.75856 1 L
s
.97602 .99375 m
.97602 1 L
s
.125 Mabswid
.1497 .99625 m
.1497 1 L
s
.19319 .99625 m
.19319 1 L
s
.23668 .99625 m
.23668 1 L
s
.28017 .99625 m
.28017 1 L
s
.36715 .99625 m
.36715 1 L
s
.41064 .99625 m
.41064 1 L
s
.45413 .99625 m
.45413 1 L
s
.49762 .99625 m
.49762 1 L
s
.5846 .99625 m
.5846 1 L
s
.62809 .99625 m
.62809 1 L
s
.67158 .99625 m
.67158 1 L
s
.71507 .99625 m
.71507 1 L
s
.80205 .99625 m
.80205 1 L
s
.84554 .99625 m
.84554 1 L
s
.88903 .99625 m
.88903 1 L
s
.93253 .99625 m
.93253 1 L
s
.06272 .99625 m
.06272 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .10934 m
1 .10934 L
s
.99375 .24391 m
1 .24391 L
s
.99375 .37847 m
1 .37847 L
s
.99375 .51304 m
1 .51304 L
s
.99375 .64761 m
1 .64761 L
s
.99375 .78218 m
1 .78218 L
s
.99375 .91675 m
1 .91675 L
s
.125 Mabswid
.99625 .14298 m
1 .14298 L
s
.99625 .17662 m
1 .17662 L
s
.99625 .21026 m
1 .21026 L
s
.99625 .27755 m
1 .27755 L
s
.99625 .31119 m
1 .31119 L
s
.99625 .34483 m
1 .34483 L
s
.99625 .41212 m
1 .41212 L
s
.99625 .44576 m
1 .44576 L
s
.99625 .4794 m
1 .4794 L
s
.99625 .54669 m
1 .54669 L
s
.99625 .58033 m
1 .58033 L
s
.99625 .61397 m
1 .61397 L
s
.99625 .68125 m
1 .68125 L
s
.99625 .7149 m
1 .7149 L
s
.99625 .74854 m
1 .74854 L
s
.99625 .81582 m
1 .81582 L
s
.99625 .84947 m
1 .84947 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .07569 m
1 .07569 L
s
.99625 .04205 m
1 .04205 L
s
.99625 .00841 m
1 .00841 L
s
.99625 .95039 m
1 .95039 L
s
.99625 .98403 m
1 .98403 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.925 g
.01923 .88973 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85283 L
.03107 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81663 L
.03892 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74628 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71214 L
.06874 .70882 L
.07154 .69911 L
.07436 .68939 L
.07721 .67968 L
.07751 .67869 L
.08006 .66997 L
.08293 .66026 L
.08583 .65054 L
.08722 .64593 L
.08874 .64083 L
.09166 .63112 L
.09462 .62141 L
.09693 .61385 L
.09759 .61169 L
.10057 .60198 L
.10358 .59227 L
.10662 .58256 L
.10664 .58247 L
.10965 .57284 L
.11272 .56313 L
.11583 .55342 L
.11636 .55177 L
.11893 .54371 L
.12207 .53399 L
.12524 .52428 L
.12607 .52176 L
.12842 .51457 L
.13163 .50486 L
.13487 .49514 L
.13578 .49244 L
.13813 .48543 L
.14141 .47572 L
.14473 .46601 L
.14549 .4638 L
.14807 .45629 L
.15144 .44658 L
.15485 .43687 L
.15521 .43585 L
.15827 .42716 L
.16173 .41744 L
.16492 .40859 L
.16523 .40773 L
.16874 .39802 L
.1723 .38831 L
.17463 .38201 L
.17589 .37859 L
.17952 .36888 L
.18318 .35917 L
.18434 .35612 L
.18688 .34946 L
.19062 .33974 L
.19406 .33092 L
.1944 .33003 L
.19822 .32032 L
.20208 .31061 L
.20377 .3064 L
.20598 .30089 L
.20993 .29118 L
.21348 .28257 L
.21393 .28147 L
.21798 .27176 L
.22208 .26204 L
.22319 .25942 L
.22622 .25233 L
.23043 .24262 L
.23291 .23696 L
.23469 .23291 L
.23901 .22319 L
.24262 .21518 L
.24339 .21348 L
.24783 .20377 L
.25233 .19409 L
.25235 .19406 L
.25692 .18434 L
.26158 .17463 L
.26204 .17368 L
.26631 .16492 L
.27113 .15521 L
.27176 .15396 L
.27603 .14549 L
.28102 .13578 L
.28147 .13492 L
.28611 .12607 L
.29118 .11657 L
.2913 .11636 L
.29659 .10664 L
.30089 .0989 L
.302 .09693 L
.30753 .08722 L
.31061 .08191 L
.31319 .07751 L
.31899 .06779 L
.32032 .06561 L
.32495 .05808 L
.33003 .04999 L
.33107 .04837 L
.33736 .03866 L
.33974 .03506 L
.34385 .02894 L
.34946 .02081 L
.35056 .01923 L
.01923 .01923 L
F
0 g
.01923 .88973 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85283 L
.03107 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81663 L
.03892 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74628 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71214 L
.06874 .70882 L
.07154 .69911 L
.07436 .68939 L
.07721 .67968 L
.07751 .67869 L
.08006 .66997 L
.08293 .66026 L
.08583 .65054 L
.08722 .64593 L
.08874 .64083 L
.09166 .63112 L
.09462 .62141 L
.09693 .61385 L
.09759 .61169 L
.10057 .60198 L
.10358 .59227 L
.10662 .58256 L
.10664 .58247 L
.10965 .57284 L
.11272 .56313 L
.11583 .55342 L
.11636 .55177 L
.11893 .54371 L
.12207 .53399 L
.12524 .52428 L
.12607 .52176 L
Mistroke
.12842 .51457 L
.13163 .50486 L
.13487 .49514 L
.13578 .49244 L
.13813 .48543 L
.14141 .47572 L
.14473 .46601 L
.14549 .4638 L
.14807 .45629 L
.15144 .44658 L
.15485 .43687 L
.15521 .43585 L
.15827 .42716 L
.16173 .41744 L
.16492 .40859 L
.16523 .40773 L
.16874 .39802 L
.1723 .38831 L
.17463 .38201 L
.17589 .37859 L
.17952 .36888 L
.18318 .35917 L
.18434 .35612 L
.18688 .34946 L
.19062 .33974 L
.19406 .33092 L
.1944 .33003 L
.19822 .32032 L
.20208 .31061 L
.20377 .3064 L
.20598 .30089 L
.20993 .29118 L
.21348 .28257 L
.21393 .28147 L
.21798 .27176 L
.22208 .26204 L
.22319 .25942 L
.22622 .25233 L
.23043 .24262 L
.23291 .23696 L
.23469 .23291 L
.23901 .22319 L
.24262 .21518 L
.24339 .21348 L
.24783 .20377 L
.25233 .19409 L
.25235 .19406 L
.25692 .18434 L
.26158 .17463 L
.26204 .17368 L
Mistroke
.26631 .16492 L
.27113 .15521 L
.27176 .15396 L
.27603 .14549 L
.28102 .13578 L
.28147 .13492 L
.28611 .12607 L
.29118 .11657 L
.2913 .11636 L
.29659 .10664 L
.30089 .0989 L
.302 .09693 L
.30753 .08722 L
.31061 .08191 L
.31319 .07751 L
.31899 .06779 L
.32032 .06561 L
.32495 .05808 L
.33003 .04999 L
.33107 .04837 L
.33736 .03866 L
.33974 .03506 L
.34385 .02894 L
.34946 .02081 L
.35056 .01923 L
Mfstroke
.85 g
.01923 .74154 m
.02019 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70516 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66945 L
.04118 .66026 L
.04387 .65054 L
.04658 .64083 L
.04837 .63443 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56641 L
.06875 .56313 L
.07159 .55342 L
.07445 .54371 L
.07734 .53399 L
.07751 .53342 L
.08023 .52428 L
.08314 .51457 L
.08608 .50486 L
.08722 .50111 L
.08903 .49514 L
.092 .48543 L
.095 .47572 L
.09693 .46948 L
.09801 .46601 L
.10104 .45629 L
.10409 .44658 L
.10664 .43853 L
.10717 .43687 L
.11026 .42716 L
.11338 .41744 L
.11636 .40825 L
.11652 .40773 L
.11969 .39802 L
.12288 .38831 L
.12607 .37866 L
.12609 .37859 L
.12932 .36888 L
.13259 .35917 L
.13578 .34974 L
.13588 .34946 L
.13919 .33974 L
.14253 .33003 L
.14549 .3215 L
.14591 .32032 L
.1493 .31061 L
.15273 .30089 L
.15521 .29394 L
.15619 .29118 L
.15968 .28147 L
.1632 .27176 L
.16492 .26706 L
.16676 .26204 L
.17035 .25233 L
.17397 .24262 L
.17463 .24086 L
.17763 .23291 L
.18132 .22319 L
.18434 .21534 L
.18506 .21348 L
.18883 .20377 L
.19265 .19406 L
.19406 .19049 L
.1965 .18434 L
.2004 .17463 L
.20377 .16633 L
.20434 .16492 L
.20833 .15521 L
.21237 .14549 L
.21348 .14284 L
.21645 .13578 L
.22059 .12607 L
.22319 .12003 L
.22478 .11636 L
.22903 .10664 L
.23291 .0979 L
.23334 .09693 L
.2377 .08722 L
.24213 .07751 L
.24262 .07644 L
.24662 .06779 L
.25119 .05808 L
.25233 .05567 L
.25582 .04837 L
.26053 .03866 L
.26204 .03557 L
.26532 .02894 L
.27019 .01923 L
.01923 .01923 L
F
0 g
.01923 .74154 m
.02019 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70516 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66945 L
.04118 .66026 L
.04387 .65054 L
.04658 .64083 L
.04837 .63443 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56641 L
.06875 .56313 L
.07159 .55342 L
.07445 .54371 L
.07734 .53399 L
.07751 .53342 L
.08023 .52428 L
.08314 .51457 L
.08608 .50486 L
.08722 .50111 L
.08903 .49514 L
.092 .48543 L
.095 .47572 L
.09693 .46948 L
.09801 .46601 L
.10104 .45629 L
.10409 .44658 L
.10664 .43853 L
.10717 .43687 L
.11026 .42716 L
.11338 .41744 L
.11636 .40825 L
.11652 .40773 L
.11969 .39802 L
.12288 .38831 L
.12607 .37866 L
.12609 .37859 L
Mistroke
.12932 .36888 L
.13259 .35917 L
.13578 .34974 L
.13588 .34946 L
.13919 .33974 L
.14253 .33003 L
.14549 .3215 L
.14591 .32032 L
.1493 .31061 L
.15273 .30089 L
.15521 .29394 L
.15619 .29118 L
.15968 .28147 L
.1632 .27176 L
.16492 .26706 L
.16676 .26204 L
.17035 .25233 L
.17397 .24262 L
.17463 .24086 L
.17763 .23291 L
.18132 .22319 L
.18434 .21534 L
.18506 .21348 L
.18883 .20377 L
.19265 .19406 L
.19406 .19049 L
.1965 .18434 L
.2004 .17463 L
.20377 .16633 L
.20434 .16492 L
.20833 .15521 L
.21237 .14549 L
.21348 .14284 L
.21645 .13578 L
.22059 .12607 L
.22319 .12003 L
.22478 .11636 L
.22903 .10664 L
.23291 .0979 L
.23334 .09693 L
.2377 .08722 L
.24213 .07751 L
.24262 .07644 L
.24662 .06779 L
.25119 .05808 L
.25233 .05567 L
.25582 .04837 L
.26053 .03866 L
.26204 .03557 L
.26532 .02894 L
Mistroke
.27019 .01923 L
Mfstroke
.775 g
.01923 .64098 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02707 .61169 L
.02894 .60475 L
.02969 .60198 L
.03233 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56919 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46658 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43373 L
.07947 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40156 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37006 L
.0973 .36888 L
.10034 .35917 L
.1034 .34946 L
.10648 .33974 L
.10664 .33925 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .3091 L
.11904 .30089 L
.12224 .29118 L
.12546 .28147 L
.12607 .27964 L
.1287 .27176 L
.13198 .26204 L
.13528 .25233 L
.13578 .25085 L
.1386 .24262 L
.14195 .23291 L
.14533 .22319 L
.14549 .22274 L
.14874 .21348 L
.15218 .20377 L
.15521 .1953 L
.15565 .19406 L
.15915 .18434 L
.16269 .17463 L
.16492 .16854 L
.16625 .16492 L
.16985 .15521 L
.17349 .14549 L
.17463 .14246 L
.17716 .13578 L
.18087 .12607 L
.18434 .11706 L
.18461 .11636 L
.1884 .10664 L
.19223 .09693 L
.19406 .09233 L
.1961 .08722 L
.20001 .07751 L
.20377 .06827 L
.20397 .06779 L
.20797 .05808 L
.21202 .04837 L
.21348 .0449 L
.21612 .03866 L
.22028 .02894 L
.22319 .0222 L
.22449 .01923 L
.01923 .01923 L
F
0 g
.01923 .64098 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02707 .61169 L
.02894 .60475 L
.02969 .60198 L
.03233 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56919 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46658 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43373 L
.07947 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40156 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37006 L
.0973 .36888 L
.10034 .35917 L
.1034 .34946 L
.10648 .33974 L
.10664 .33925 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .3091 L
.11904 .30089 L
.12224 .29118 L
.12546 .28147 L
.12607 .27964 L
Mistroke
.1287 .27176 L
.13198 .26204 L
.13528 .25233 L
.13578 .25085 L
.1386 .24262 L
.14195 .23291 L
.14533 .22319 L
.14549 .22274 L
.14874 .21348 L
.15218 .20377 L
.15521 .1953 L
.15565 .19406 L
.15915 .18434 L
.16269 .17463 L
.16492 .16854 L
.16625 .16492 L
.16985 .15521 L
.17349 .14549 L
.17463 .14246 L
.17716 .13578 L
.18087 .12607 L
.18434 .11706 L
.18461 .11636 L
.1884 .10664 L
.19223 .09693 L
.19406 .09233 L
.1961 .08722 L
.20001 .07751 L
.20377 .06827 L
.20397 .06779 L
.20797 .05808 L
.21202 .04837 L
.21348 .0449 L
.21612 .03866 L
.22028 .02894 L
.22319 .0222 L
.22449 .01923 L
Mfstroke
.7 g
.01923 .55956 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.02871 .52428 L
.02894 .52341 L
.03135 .51457 L
.034 .50486 L
.03667 .49514 L
.03866 .48793 L
.03935 .48543 L
.04204 .47572 L
.04475 .46601 L
.04748 .45629 L
.04837 .45313 L
.05022 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08142 .33974 L
.08437 .33003 L
.08722 .32068 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28925 L
.09937 .28147 L
.10243 .27176 L
.10551 .26204 L
.10664 .25851 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22843 L
.11807 .22319 L
.12127 .21348 L
.12449 .20377 L
.12607 .19904 L
.12774 .19406 L
.13101 .18434 L
.13431 .17463 L
.13578 .17032 L
.13763 .16492 L
.14098 .15521 L
.14437 .14549 L
.14549 .14227 L
.14777 .13578 L
.15121 .12607 L
.15468 .11636 L
.15521 .1149 L
.15818 .10664 L
.16172 .09693 L
.16492 .08821 L
.16528 .08722 L
.16888 .07751 L
.17252 .06779 L
.17463 .06219 L
.17619 .05808 L
.1799 .04837 L
.18364 .03866 L
.18434 .03685 L
.18743 .02894 L
.19125 .01923 L
.01923 .01923 L
F
0 g
.01923 .55956 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.02871 .52428 L
.02894 .52341 L
.03135 .51457 L
.034 .50486 L
.03667 .49514 L
.03866 .48793 L
.03935 .48543 L
.04204 .47572 L
.04475 .46601 L
.04748 .45629 L
.04837 .45313 L
.05022 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08142 .33974 L
.08437 .33003 L
.08722 .32068 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28925 L
.09937 .28147 L
.10243 .27176 L
.10551 .26204 L
.10664 .25851 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22843 L
.11807 .22319 L
.12127 .21348 L
.12449 .20377 L
.12607 .19904 L
.12774 .19406 L
Mistroke
.13101 .18434 L
.13431 .17463 L
.13578 .17032 L
.13763 .16492 L
.14098 .15521 L
.14437 .14549 L
.14549 .14227 L
.14777 .13578 L
.15121 .12607 L
.15468 .11636 L
.15521 .1149 L
.15818 .10664 L
.16172 .09693 L
.16492 .08821 L
.16528 .08722 L
.16888 .07751 L
.17252 .06779 L
.17463 .06219 L
.17619 .05808 L
.1799 .04837 L
.18364 .03866 L
.18434 .03685 L
.18743 .02894 L
.19125 .01923 L
Mfstroke
.625 g
.01923 .4893 m
.02026 .48543 L
.02286 .47572 L
.02548 .46601 L
.0281 .45629 L
.02894 .45319 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41777 L
.03875 .41744 L
.04144 .40773 L
.04415 .39802 L
.04688 .38831 L
.04837 .38301 L
.04962 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34894 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25075 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21938 L
.09878 .21348 L
.10184 .20377 L
.10492 .19406 L
.10664 .18867 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15865 L
.11748 .15521 L
.12068 .14549 L
.1239 .13578 L
.12607 .1293 L
.12715 .12607 L
.13042 .11636 L
.13372 .10664 L
.13578 .10062 L
.13705 .09693 L
.1404 .08722 L
.14378 .07751 L
.14549 .07262 L
.14719 .06779 L
.15063 .05808 L
.1541 .04837 L
.15521 .04529 L
.1576 .03866 L
.16113 .02894 L
.1647 .01923 L
.01923 .01923 L
F
0 g
.01923 .4893 m
.02026 .48543 L
.02286 .47572 L
.02548 .46601 L
.0281 .45629 L
.02894 .45319 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41777 L
.03875 .41744 L
.04144 .40773 L
.04415 .39802 L
.04688 .38831 L
.04837 .38301 L
.04962 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34894 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25075 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21938 L
.09878 .21348 L
.10184 .20377 L
.10492 .19406 L
.10664 .18867 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15865 L
.11748 .15521 L
.12068 .14549 L
.1239 .13578 L
.12607 .1293 L
.12715 .12607 L
Mistroke
.13042 .11636 L
.13372 .10664 L
.13578 .10062 L
.13705 .09693 L
.1404 .08722 L
.14378 .07751 L
.14549 .07262 L
.14719 .06779 L
.15063 .05808 L
.1541 .04837 L
.15521 .04529 L
.1576 .03866 L
.16113 .02894 L
.1647 .01923 L
Mfstroke
.55 g
.01923 .42656 m
.02167 .41744 L
.02428 .40773 L
.0269 .39802 L
.02894 .3905 L
.02954 .38831 L
.03219 .37859 L
.03485 .36888 L
.03753 .35917 L
.03866 .3551 L
.04022 .34946 L
.04293 .33974 L
.04565 .33003 L
.04837 .32039 L
.04839 .32032 L
.05114 .31061 L
.05391 .30089 L
.05669 .29118 L
.05808 .28634 L
.05949 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25298 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18826 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15692 L
.09747 .15521 L
.10052 .14549 L
.1036 .13578 L
.10664 .12625 L
.1067 .12607 L
.10982 .11636 L
.11297 .10664 L
.11613 .09693 L
.11636 .09626 L
.11933 .08722 L
.12254 .07751 L
.12578 .06779 L
.12607 .06694 L
.12905 .05808 L
.13234 .04837 L
.13566 .03866 L
.13578 .03829 L
.139 .02894 L
.14237 .01923 L
.01923 .01923 L
F
0 g
.01923 .42656 m
.02167 .41744 L
.02428 .40773 L
.0269 .39802 L
.02894 .3905 L
.02954 .38831 L
.03219 .37859 L
.03485 .36888 L
.03753 .35917 L
.03866 .3551 L
.04022 .34946 L
.04293 .33974 L
.04565 .33003 L
.04837 .32039 L
.04839 .32032 L
.05114 .31061 L
.05391 .30089 L
.05669 .29118 L
.05808 .28634 L
.05949 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25298 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18826 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15692 L
.09747 .15521 L
.10052 .14549 L
.1036 .13578 L
.10664 .12625 L
.1067 .12607 L
.10982 .11636 L
.11297 .10664 L
.11613 .09693 L
.11636 .09626 L
.11933 .08722 L
.12254 .07751 L
.12578 .06779 L
.12607 .06694 L
.12905 .05808 L
Mistroke
.13234 .04837 L
.13566 .03866 L
.13578 .03829 L
.139 .02894 L
.14237 .01923 L
Mfstroke
.475 g
.01923 .36936 m
.01936 .36888 L
.02196 .35917 L
.02457 .34946 L
.0272 .33974 L
.02894 .33332 L
.02984 .33003 L
.03249 .32032 L
.03516 .31061 L
.03784 .30089 L
.03866 .29795 L
.04054 .29118 L
.04325 .28147 L
.04597 .27176 L
.04837 .26326 L
.04871 .26204 L
.05147 .25233 L
.05424 .24262 L
.05703 .23291 L
.05808 .22925 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .19591 L
.06834 .19406 L
.07121 .18434 L
.0741 .17463 L
.077 .16492 L
.07751 .16324 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06928 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03931 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
.01923 .01923 L
F
0 g
.01923 .36936 m
.01936 .36888 L
.02196 .35917 L
.02457 .34946 L
.0272 .33974 L
.02894 .33332 L
.02984 .33003 L
.03249 .32032 L
.03516 .31061 L
.03784 .30089 L
.03866 .29795 L
.04054 .29118 L
.04325 .28147 L
.04597 .27176 L
.04837 .26326 L
.04871 .26204 L
.05147 .25233 L
.05424 .24262 L
.05703 .23291 L
.05808 .22925 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .19591 L
.06834 .19406 L
.07121 .18434 L
.0741 .17463 L
.077 .16492 L
.07751 .16324 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06928 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03931 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
s
.4 g
.01923 .31644 m
.02079 .31061 L
.0234 .30089 L
.02602 .29118 L
.02866 .28147 L
.02894 .28042 L
.03131 .27176 L
.03397 .26204 L
.03665 .25233 L
.03866 .24508 L
.03934 .24262 L
.04204 .23291 L
.04476 .22319 L
.0475 .21348 L
.04837 .21041 L
.05025 .20377 L
.05302 .19406 L
.0558 .18434 L
.05808 .17641 L
.0586 .17463 L
.06141 .16492 L
.06424 .15521 L
.06709 .14549 L
.06779 .14309 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08159 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10578 .01923 L
.01923 .01923 L
F
0 g
.01923 .31644 m
.02079 .31061 L
.0234 .30089 L
.02602 .29118 L
.02866 .28147 L
.02894 .28042 L
.03131 .27176 L
.03397 .26204 L
.03665 .25233 L
.03866 .24508 L
.03934 .24262 L
.04204 .23291 L
.04476 .22319 L
.0475 .21348 L
.04837 .21041 L
.05025 .20377 L
.05302 .19406 L
.0558 .18434 L
.05808 .17641 L
.0586 .17463 L
.06141 .16492 L
.06424 .15521 L
.06709 .14549 L
.06779 .14309 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08159 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10578 .01923 L
s
.325 g
.01923 .26696 m
.02055 .26204 L
.02316 .25233 L
.02578 .24262 L
.02841 .23291 L
.02894 .23096 L
.03106 .22319 L
.03373 .21348 L
.0364 .20377 L
.03866 .19564 L
.03909 .19406 L
.0418 .18434 L
.04452 .17463 L
.04726 .16492 L
.04837 .16099 L
.05001 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12701 L
.05835 .12607 L
.06117 .11636 L
.064 .10664 L
.06684 .09693 L
.06779 .0937 L
.06971 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06107 L
.07841 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02912 L
.08727 .02894 L
.09026 .01923 L
.01923 .01923 L
F
0 g
.01923 .26696 m
.02055 .26204 L
.02316 .25233 L
.02578 .24262 L
.02841 .23291 L
.02894 .23096 L
.03106 .22319 L
.03373 .21348 L
.0364 .20377 L
.03866 .19564 L
.03909 .19406 L
.0418 .18434 L
.04452 .17463 L
.04726 .16492 L
.04837 .16099 L
.05001 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12701 L
.05835 .12607 L
.06117 .11636 L
.064 .10664 L
.06684 .09693 L
.06779 .0937 L
.06971 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06107 L
.07841 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02912 L
.08727 .02894 L
.09026 .01923 L
s
.25 g
.01923 .22034 m
.02107 .21348 L
.02368 .20377 L
.02631 .19406 L
.02894 .18435 L
.02895 .18434 L
.0316 .17463 L
.03427 .16492 L
.03695 .15521 L
.03866 .14904 L
.03964 .14549 L
.04235 .13578 L
.04508 .12607 L
.04782 .11636 L
.04837 .1144 L
.05057 .10664 L
.05334 .09693 L
.05613 .08722 L
.05808 .08044 L
.05893 .07751 L
.06175 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04715 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
.01923 .01923 L
F
0 g
.01923 .22034 m
.02107 .21348 L
.02368 .20377 L
.02631 .19406 L
.02894 .18435 L
.02895 .18434 L
.0316 .17463 L
.03427 .16492 L
.03695 .15521 L
.03866 .14904 L
.03964 .14549 L
.04235 .13578 L
.04508 .12607 L
.04782 .11636 L
.04837 .1144 L
.05057 .10664 L
.05334 .09693 L
.05613 .08722 L
.05808 .08044 L
.05893 .07751 L
.06175 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04715 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
s
.925 g
.96253 .98077 m
.96134 .97722 L
.95928 .97106 L
.956 .96134 L
.9527 .95163 L
.95163 .94849 L
.94937 .94192 L
.94602 .93221 L
.94264 .92249 L
.94192 .92043 L
.93923 .91278 L
.93579 .90307 L
.93232 .89336 L
.93221 .89303 L
.92882 .88364 L
.92529 .87393 L
.92249 .8663 L
.92173 .86422 L
.91813 .85451 L
.9145 .84479 L
.91278 .84022 L
.91084 .83508 L
.90713 .82537 L
.9034 .81566 L
.90307 .81481 L
.89962 .80594 L
.8958 .79623 L
.89336 .79006 L
.89195 .78652 L
.88805 .77681 L
.8841 .76709 L
.88364 .76597 L
.88012 .75738 L
.87608 .74767 L
.87393 .74254 L
.872 .73796 L
.86787 .72824 L
.86422 .71977 L
.86368 .71853 L
.85944 .70882 L
.85515 .69911 L
.85451 .69766 L
.85079 .68939 L
.84638 .67968 L
.84479 .67622 L
.8419 .66997 L
.83736 .66026 L
.83508 .65544 L
.83275 .65054 L
.82806 .64083 L
.82537 .63532 L
.8233 .63112 L
.81846 .62141 L
.81566 .61586 L
.81353 .61169 L
.80852 .60198 L
.80594 .59706 L
.80341 .59227 L
.7982 .58256 L
.79623 .57893 L
.79289 .57284 L
.78747 .56313 L
.78652 .56145 L
.78192 .55342 L
.77681 .54464 L
.77626 .54371 L
.77045 .53399 L
.76709 .52849 L
.7645 .52428 L
.75838 .51457 L
.75738 .513 L
.7521 .50486 L
.74767 .49817 L
.74563 .49514 L
.73896 .48543 L
.73796 .484 L
.73205 .47572 L
.72824 .4705 L
.7249 .46601 L
.71853 .45766 L
.71747 .45629 L
.70972 .44658 L
.70882 .44547 L
.70162 .43687 L
.69911 .43395 L
.6931 .42716 L
.68939 .42309 L
.68409 .41744 L
.67968 .41289 L
.67451 .40773 L
.66997 .40336 L
.66422 .39802 L
.66026 .39448 L
.65303 .38831 L
.65054 .38626 L
.64083 .37871 L
.64068 .37859 L
.63112 .37182 L
.62668 .36888 L
.62141 .36558 L
.61169 .36001 L
.61012 .35917 L
.60198 .3551 L
.59227 .35085 L
.58872 .34946 L
.58256 .34726 L
.57284 .34434 L
.56313 .34207 L
.55342 .34046 L
.54679 .33974 L
.54371 .33951 L
.53399 .33923 L
.52428 .3396 L
.52173 .33974 L
.51457 .34064 L
.50486 .34234 L
.49514 .34469 L
.48543 .34771 L
.48057 .34946 L
.47572 .35138 L
.46601 .35572 L
.45916 .35917 L
.45629 .36072 L
.44658 .36637 L
.4426 .36888 L
.43687 .37269 L
.42859 .37859 L
.42716 .37966 L
.41744 .3873 L
.41622 .38831 L
.40773 .39559 L
.40503 .39802 L
.39802 .40455 L
.39473 .40773 L
.38831 .41416 L
.38513 .41744 L
.37859 .42443 L
.37612 .42716 L
.36888 .43537 L
.36759 .43687 L
.35947 .44658 L
.35917 .44696 L
.35172 .45629 L
.34946 .45921 L
.34428 .46601 L
.33974 .47212 L
.33712 .47572 L
.33021 .48543 L
.33003 .48568 L
.32352 .49514 L
.32032 .49991 L
.31704 .50486 L
.31075 .51457 L
.31061 .51479 L
.30463 .52428 L
.30089 .53034 L
.29867 .53399 L
.29285 .54371 L
.29118 .54654 L
.28717 .55342 L
.28162 .56313 L
.28147 .5634 L
.27619 .57284 L
.27176 .58092 L
.27086 .58256 L
.26565 .59227 L
.26204 .59909 L
.26053 .60198 L
.25551 .61169 L
.25233 .61792 L
.25057 .62141 L
.24572 .63112 L
.24262 .63741 L
.24095 .64083 L
.23626 .65054 L
.23291 .65756 L
.23163 .66026 L
.22708 .66997 L
.22319 .67837 L
.22259 .67968 L
.21817 .68939 L
.2138 .69911 L
.21348 .69983 L
.2095 .70882 L
.20525 .71853 L
.20377 .72195 L
.20106 .72824 L
.19692 .73796 L
.19406 .74472 L
.19282 .74767 L
.18878 .75738 L
.18478 .76709 L
.18434 .76815 L
.18083 .77681 L
.17692 .78652 L
.17463 .79224 L
.17305 .79623 L
.16923 .80594 L
.16544 .81566 L
.16492 .81699 L
.16169 .82537 L
.15798 .83508 L
.15521 .84239 L
.1543 .84479 L
.15067 .85451 L
.14706 .86422 L
.14549 .86844 L
.14348 .87393 L
.13995 .88364 L
.13643 .89336 L
.13578 .89516 L
.13296 .90307 L
.12951 .91278 L
.12608 .92249 L
.12607 .92252 L
.1227 .93221 L
.11933 .94192 L
.11636 .95055 L
.11599 .95163 L
.11268 .96134 L
.10939 .97106 L
.10664 .97922 L
.10613 .98077 L
F
0 g
.96253 .98077 m
.96134 .97722 L
.95928 .97106 L
.956 .96134 L
.9527 .95163 L
.95163 .94849 L
.94937 .94192 L
.94602 .93221 L
.94264 .92249 L
.94192 .92043 L
.93923 .91278 L
.93579 .90307 L
.93232 .89336 L
.93221 .89303 L
.92882 .88364 L
.92529 .87393 L
.92249 .8663 L
.92173 .86422 L
.91813 .85451 L
.9145 .84479 L
.91278 .84022 L
.91084 .83508 L
.90713 .82537 L
.9034 .81566 L
.90307 .81481 L
.89962 .80594 L
.8958 .79623 L
.89336 .79006 L
.89195 .78652 L
.88805 .77681 L
.8841 .76709 L
.88364 .76597 L
.88012 .75738 L
.87608 .74767 L
.87393 .74254 L
.872 .73796 L
.86787 .72824 L
.86422 .71977 L
.86368 .71853 L
.85944 .70882 L
.85515 .69911 L
.85451 .69766 L
.85079 .68939 L
.84638 .67968 L
.84479 .67622 L
.8419 .66997 L
.83736 .66026 L
.83508 .65544 L
.83275 .65054 L
.82806 .64083 L
Mistroke
.82537 .63532 L
.8233 .63112 L
.81846 .62141 L
.81566 .61586 L
.81353 .61169 L
.80852 .60198 L
.80594 .59706 L
.80341 .59227 L
.7982 .58256 L
.79623 .57893 L
.79289 .57284 L
.78747 .56313 L
.78652 .56145 L
.78192 .55342 L
.77681 .54464 L
.77626 .54371 L
.77045 .53399 L
.76709 .52849 L
.7645 .52428 L
.75838 .51457 L
.75738 .513 L
.7521 .50486 L
.74767 .49817 L
.74563 .49514 L
.73896 .48543 L
.73796 .484 L
.73205 .47572 L
.72824 .4705 L
.7249 .46601 L
.71853 .45766 L
.71747 .45629 L
.70972 .44658 L
.70882 .44547 L
.70162 .43687 L
.69911 .43395 L
.6931 .42716 L
.68939 .42309 L
.68409 .41744 L
.67968 .41289 L
.67451 .40773 L
.66997 .40336 L
.66422 .39802 L
.66026 .39448 L
.65303 .38831 L
.65054 .38626 L
.64083 .37871 L
.64068 .37859 L
.63112 .37182 L
.62668 .36888 L
.62141 .36558 L
Mistroke
.61169 .36001 L
.61012 .35917 L
.60198 .3551 L
.59227 .35085 L
.58872 .34946 L
.58256 .34726 L
.57284 .34434 L
.56313 .34207 L
.55342 .34046 L
.54679 .33974 L
.54371 .33951 L
.53399 .33923 L
.52428 .3396 L
.52173 .33974 L
.51457 .34064 L
.50486 .34234 L
.49514 .34469 L
.48543 .34771 L
.48057 .34946 L
.47572 .35138 L
.46601 .35572 L
.45916 .35917 L
.45629 .36072 L
.44658 .36637 L
.4426 .36888 L
.43687 .37269 L
.42859 .37859 L
.42716 .37966 L
.41744 .3873 L
.41622 .38831 L
.40773 .39559 L
.40503 .39802 L
.39802 .40455 L
.39473 .40773 L
.38831 .41416 L
.38513 .41744 L
.37859 .42443 L
.37612 .42716 L
.36888 .43537 L
.36759 .43687 L
.35947 .44658 L
.35917 .44696 L
.35172 .45629 L
.34946 .45921 L
.34428 .46601 L
.33974 .47212 L
.33712 .47572 L
.33021 .48543 L
.33003 .48568 L
.32352 .49514 L
Mistroke
.32032 .49991 L
.31704 .50486 L
.31075 .51457 L
.31061 .51479 L
.30463 .52428 L
.30089 .53034 L
.29867 .53399 L
.29285 .54371 L
.29118 .54654 L
.28717 .55342 L
.28162 .56313 L
.28147 .5634 L
.27619 .57284 L
.27176 .58092 L
.27086 .58256 L
.26565 .59227 L
.26204 .59909 L
.26053 .60198 L
.25551 .61169 L
.25233 .61792 L
.25057 .62141 L
.24572 .63112 L
.24262 .63741 L
.24095 .64083 L
.23626 .65054 L
.23291 .65756 L
.23163 .66026 L
.22708 .66997 L
.22319 .67837 L
.22259 .67968 L
.21817 .68939 L
.2138 .69911 L
.21348 .69983 L
.2095 .70882 L
.20525 .71853 L
.20377 .72195 L
.20106 .72824 L
.19692 .73796 L
.19406 .74472 L
.19282 .74767 L
.18878 .75738 L
.18478 .76709 L
.18434 .76815 L
.18083 .77681 L
.17692 .78652 L
.17463 .79224 L
.17305 .79623 L
.16923 .80594 L
.16544 .81566 L
.16492 .81699 L
Mistroke
.16169 .82537 L
.15798 .83508 L
.15521 .84239 L
.1543 .84479 L
.15067 .85451 L
.14706 .86422 L
.14549 .86844 L
.14348 .87393 L
.13995 .88364 L
.13643 .89336 L
.13578 .89516 L
.13296 .90307 L
.12951 .91278 L
.12608 .92249 L
.12607 .92252 L
.1227 .93221 L
.11933 .94192 L
.11636 .95055 L
.11599 .95163 L
.11268 .96134 L
.10939 .97106 L
.10664 .97922 L
.10613 .98077 L
Mfstroke
.85 g
.91742 .98077 m
.91378 .97106 L
.91278 .96841 L
.9101 .96134 L
.90639 .95163 L
.90307 .94302 L
.90264 .94192 L
.89885 .93221 L
.89502 .92249 L
.89336 .91829 L
.89115 .91278 L
.88724 .90307 L
.88364 .89423 L
.88329 .89336 L
.87928 .88364 L
.87523 .87393 L
.87393 .87084 L
.87113 .86422 L
.86698 .85451 L
.86422 .84811 L
.86278 .84479 L
.85852 .83508 L
.85451 .82604 L
.85421 .82537 L
.84983 .81566 L
.84539 .80594 L
.84479 .80464 L
.84089 .79623 L
.83632 .78652 L
.83508 .7839 L
.83168 .77681 L
.82697 .76709 L
.82537 .76383 L
.82218 .75738 L
.8173 .74767 L
.81566 .74443 L
.81234 .73796 L
.80729 .72824 L
.80594 .72569 L
.80214 .71853 L
.79689 .70882 L
.79623 .70761 L
.79153 .69911 L
.78652 .6902 L
.78606 .68939 L
.78046 .67968 L
.77681 .67345 L
.77473 .66997 L
.76886 .66026 L
.76709 .65737 L
.76284 .65054 L
.75738 .64196 L
.75665 .64083 L
.75029 .63112 L
.74767 .62721 L
.74372 .62141 L
.73796 .61312 L
.73695 .61169 L
.72993 .60198 L
.72824 .5997 L
.72265 .59227 L
.71853 .58694 L
.71507 .58256 L
.70882 .57485 L
.70715 .57284 L
.69911 .56343 L
.69885 .56313 L
.69009 .55342 L
.68939 .55266 L
.68081 .54371 L
.67968 .54257 L
.67088 .53399 L
.66997 .53314 L
.66026 .52437 L
.66016 .52428 L
.65054 .51627 L
.6484 .51457 L
.64083 .50883 L
.63525 .50486 L
.63112 .50206 L
.62141 .49595 L
.62004 .49514 L
.61169 .49051 L
.60198 .48573 L
.60133 .48543 L
.59227 .48162 L
.58256 .47817 L
.57417 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47181 L
.54371 .47102 L
.53399 .4709 L
.52428 .47144 L
.51457 .47264 L
.50486 .47451 L
.49984 .47572 L
.49514 .47704 L
.48543 .48024 L
.47572 .48411 L
.47272 .48543 L
.46601 .48863 L
.45629 .49383 L
.45401 .49514 L
.44658 .49968 L
.4388 .50486 L
.43687 .5062 L
.42716 .51339 L
.42564 .51457 L
.41744 .52124 L
.41389 .52428 L
.40773 .52976 L
.40316 .53399 L
.39802 .53894 L
.39323 .54371 L
.38831 .54878 L
.38394 .55342 L
.37859 .55929 L
.37519 .56313 L
.36888 .57046 L
.36688 .57284 L
.35917 .5823 L
.35896 .58256 L
.35138 .59227 L
.34946 .5948 L
.3441 .60198 L
.33974 .60796 L
.33708 .61169 L
.3303 .62141 L
.33003 .62179 L
.32373 .63112 L
.32032 .63629 L
.31736 .64083 L
.31117 .65054 L
.31061 .65145 L
.30515 .66026 L
.30089 .66727 L
.29928 .66997 L
.29355 .67968 L
.29118 .68376 L
.28795 .68939 L
.28247 .69911 L
.28147 .70091 L
.27711 .70882 L
.27186 .71853 L
.27176 .71872 L
.26671 .72824 L
.26204 .7372 L
.26165 .73796 L
.25669 .74767 L
.25233 .75634 L
.25181 .75738 L
.24702 .76709 L
.24262 .77615 L
.2423 .77681 L
.23766 .78652 L
.23309 .79623 L
.23291 .79662 L
.22859 .80594 L
.22415 .81566 L
.22319 .81776 L
.21977 .82537 L
.21545 .83508 L
.21348 .83956 L
.21119 .84479 L
.20699 .85451 L
.20377 .86202 L
.20283 .86422 L
.19873 .87393 L
.19468 .88364 L
.19406 .88515 L
.19067 .89336 L
.18672 .90307 L
.18434 .90894 L
.1828 .91278 L
.17893 .92249 L
.1751 .93221 L
.17463 .93339 L
.17131 .94192 L
.16755 .95163 L
.16492 .95851 L
.16384 .96134 L
.16016 .97106 L
.15652 .98077 L
F
0 g
.91742 .98077 m
.91378 .97106 L
.91278 .96841 L
.9101 .96134 L
.90639 .95163 L
.90307 .94302 L
.90264 .94192 L
.89885 .93221 L
.89502 .92249 L
.89336 .91829 L
.89115 .91278 L
.88724 .90307 L
.88364 .89423 L
.88329 .89336 L
.87928 .88364 L
.87523 .87393 L
.87393 .87084 L
.87113 .86422 L
.86698 .85451 L
.86422 .84811 L
.86278 .84479 L
.85852 .83508 L
.85451 .82604 L
.85421 .82537 L
.84983 .81566 L
.84539 .80594 L
.84479 .80464 L
.84089 .79623 L
.83632 .78652 L
.83508 .7839 L
.83168 .77681 L
.82697 .76709 L
.82537 .76383 L
.82218 .75738 L
.8173 .74767 L
.81566 .74443 L
.81234 .73796 L
.80729 .72824 L
.80594 .72569 L
.80214 .71853 L
.79689 .70882 L
.79623 .70761 L
.79153 .69911 L
.78652 .6902 L
.78606 .68939 L
.78046 .67968 L
.77681 .67345 L
.77473 .66997 L
.76886 .66026 L
.76709 .65737 L
Mistroke
.76284 .65054 L
.75738 .64196 L
.75665 .64083 L
.75029 .63112 L
.74767 .62721 L
.74372 .62141 L
.73796 .61312 L
.73695 .61169 L
.72993 .60198 L
.72824 .5997 L
.72265 .59227 L
.71853 .58694 L
.71507 .58256 L
.70882 .57485 L
.70715 .57284 L
.69911 .56343 L
.69885 .56313 L
.69009 .55342 L
.68939 .55266 L
.68081 .54371 L
.67968 .54257 L
.67088 .53399 L
.66997 .53314 L
.66026 .52437 L
.66016 .52428 L
.65054 .51627 L
.6484 .51457 L
.64083 .50883 L
.63525 .50486 L
.63112 .50206 L
.62141 .49595 L
.62004 .49514 L
.61169 .49051 L
.60198 .48573 L
.60133 .48543 L
.59227 .48162 L
.58256 .47817 L
.57417 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47181 L
.54371 .47102 L
.53399 .4709 L
.52428 .47144 L
.51457 .47264 L
.50486 .47451 L
.49984 .47572 L
.49514 .47704 L
.48543 .48024 L
.47572 .48411 L
Mistroke
.47272 .48543 L
.46601 .48863 L
.45629 .49383 L
.45401 .49514 L
.44658 .49968 L
.4388 .50486 L
.43687 .5062 L
.42716 .51339 L
.42564 .51457 L
.41744 .52124 L
.41389 .52428 L
.40773 .52976 L
.40316 .53399 L
.39802 .53894 L
.39323 .54371 L
.38831 .54878 L
.38394 .55342 L
.37859 .55929 L
.37519 .56313 L
.36888 .57046 L
.36688 .57284 L
.35917 .5823 L
.35896 .58256 L
.35138 .59227 L
.34946 .5948 L
.3441 .60198 L
.33974 .60796 L
.33708 .61169 L
.3303 .62141 L
.33003 .62179 L
.32373 .63112 L
.32032 .63629 L
.31736 .64083 L
.31117 .65054 L
.31061 .65145 L
.30515 .66026 L
.30089 .66727 L
.29928 .66997 L
.29355 .67968 L
.29118 .68376 L
.28795 .68939 L
.28247 .69911 L
.28147 .70091 L
.27711 .70882 L
.27186 .71853 L
.27176 .71872 L
.26671 .72824 L
.26204 .7372 L
.26165 .73796 L
.25669 .74767 L
Mistroke
.25233 .75634 L
.25181 .75738 L
.24702 .76709 L
.24262 .77615 L
.2423 .77681 L
.23766 .78652 L
.23309 .79623 L
.23291 .79662 L
.22859 .80594 L
.22415 .81566 L
.22319 .81776 L
.21977 .82537 L
.21545 .83508 L
.21348 .83956 L
.21119 .84479 L
.20699 .85451 L
.20377 .86202 L
.20283 .86422 L
.19873 .87393 L
.19468 .88364 L
.19406 .88515 L
.19067 .89336 L
.18672 .90307 L
.18434 .90894 L
.1828 .91278 L
.17893 .92249 L
.1751 .93221 L
.17463 .93339 L
.17131 .94192 L
.16755 .95163 L
.16492 .95851 L
.16384 .96134 L
.16016 .97106 L
.15652 .98077 L
Mfstroke
.775 g
.88062 .98077 m
.87658 .97106 L
.87393 .96474 L
.8725 .96134 L
.86836 .95163 L
.86422 .94202 L
.86417 .94192 L
.85993 .93221 L
.85563 .92249 L
.85451 .91997 L
.85127 .91278 L
.84685 .90307 L
.84479 .89859 L
.84237 .89336 L
.83782 .88364 L
.83508 .87787 L
.8332 .87393 L
.8285 .86422 L
.82537 .85782 L
.82373 .85451 L
.81888 .84479 L
.81566 .83843 L
.81394 .83508 L
.80892 .82537 L
.80594 .81971 L
.80379 .81566 L
.79857 .80594 L
.79623 .80166 L
.79324 .79623 L
.78779 .78652 L
.78652 .78427 L
.78223 .77681 L
.77681 .76755 L
.77653 .76709 L
.7707 .75738 L
.76709 .7515 L
.76472 .74767 L
.75857 .73796 L
.75738 .73611 L
.75225 .72824 L
.74767 .72139 L
.74573 .71853 L
.73901 .70882 L
.73796 .70733 L
.73205 .69911 L
.72824 .69394 L
.72483 .68939 L
.71853 .68122 L
.71732 .67968 L
.70949 .66997 L
.70882 .66916 L
.70127 .66026 L
.69911 .65777 L
.69263 .65054 L
.68939 .64705 L
.68347 .64083 L
.67968 .63699 L
.67369 .63112 L
.66997 .6276 L
.66316 .62141 L
.66026 .61887 L
.65165 .61169 L
.65054 .61081 L
.64083 .60342 L
.63884 .60198 L
.63112 .59669 L
.62415 .59227 L
.62141 .59063 L
.61169 .58523 L
.60638 .58256 L
.60198 .5805 L
.59227 .57644 L
.58256 .57304 L
.58193 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56685 L
.54371 .56612 L
.53399 .56605 L
.52428 .56665 L
.51457 .56792 L
.50486 .56985 L
.49514 .57245 L
.49384 .57284 L
.48543 .57571 L
.47572 .57964 L
.46939 .58256 L
.46601 .58424 L
.45629 .5895 L
.45162 .59227 L
.44658 .59543 L
.43693 .60198 L
.43687 .60202 L
.42716 .60928 L
.42411 .61169 L
.41744 .61721 L
.41261 .62141 L
.40773 .6258 L
.40207 .63112 L
.39802 .63506 L
.39229 .64083 L
.38831 .64499 L
.38313 .65054 L
.37859 .65558 L
.37449 .66026 L
.36888 .66683 L
.36627 .66997 L
.35917 .67876 L
.35844 .67968 L
.35093 .68939 L
.34946 .69134 L
.34371 .69911 L
.33974 .7046 L
.33675 .70882 L
.33003 .71852 L
.33002 .71853 L
.32351 .72824 L
.32032 .7331 L
.31718 .73796 L
.31103 .74767 L
.31061 .74836 L
.30505 .75738 L
.30089 .76427 L
.29921 .76709 L
.29352 .77681 L
.29118 .78086 L
.28795 .78652 L
.28251 .79623 L
.28147 .79811 L
.27718 .80594 L
.27195 .81566 L
.27176 .81602 L
.26683 .82537 L
.26204 .8346 L
.2618 .83508 L
.25686 .84479 L
.25233 .85385 L
.25201 .85451 L
.24723 .86422 L
.24262 .87376 L
.24254 .87393 L
.23792 .88364 L
.23336 .89336 L
.23291 .89434 L
.22888 .90307 L
.22446 .91278 L
.22319 .91559 L
.2201 .92249 L
.2158 .93221 L
.21348 .9375 L
.21156 .94192 L
.20737 .95163 L
.20377 .96007 L
.20323 .96134 L
.19914 .97106 L
.19511 .98077 L
F
0 g
.88062 .98077 m
.87658 .97106 L
.87393 .96474 L
.8725 .96134 L
.86836 .95163 L
.86422 .94202 L
.86417 .94192 L
.85993 .93221 L
.85563 .92249 L
.85451 .91997 L
.85127 .91278 L
.84685 .90307 L
.84479 .89859 L
.84237 .89336 L
.83782 .88364 L
.83508 .87787 L
.8332 .87393 L
.8285 .86422 L
.82537 .85782 L
.82373 .85451 L
.81888 .84479 L
.81566 .83843 L
.81394 .83508 L
.80892 .82537 L
.80594 .81971 L
.80379 .81566 L
.79857 .80594 L
.79623 .80166 L
.79324 .79623 L
.78779 .78652 L
.78652 .78427 L
.78223 .77681 L
.77681 .76755 L
.77653 .76709 L
.7707 .75738 L
.76709 .7515 L
.76472 .74767 L
.75857 .73796 L
.75738 .73611 L
.75225 .72824 L
.74767 .72139 L
.74573 .71853 L
.73901 .70882 L
.73796 .70733 L
.73205 .69911 L
.72824 .69394 L
.72483 .68939 L
.71853 .68122 L
.71732 .67968 L
.70949 .66997 L
Mistroke
.70882 .66916 L
.70127 .66026 L
.69911 .65777 L
.69263 .65054 L
.68939 .64705 L
.68347 .64083 L
.67968 .63699 L
.67369 .63112 L
.66997 .6276 L
.66316 .62141 L
.66026 .61887 L
.65165 .61169 L
.65054 .61081 L
.64083 .60342 L
.63884 .60198 L
.63112 .59669 L
.62415 .59227 L
.62141 .59063 L
.61169 .58523 L
.60638 .58256 L
.60198 .5805 L
.59227 .57644 L
.58256 .57304 L
.58193 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56685 L
.54371 .56612 L
.53399 .56605 L
.52428 .56665 L
.51457 .56792 L
.50486 .56985 L
.49514 .57245 L
.49384 .57284 L
.48543 .57571 L
.47572 .57964 L
.46939 .58256 L
.46601 .58424 L
.45629 .5895 L
.45162 .59227 L
.44658 .59543 L
.43693 .60198 L
.43687 .60202 L
.42716 .60928 L
.42411 .61169 L
.41744 .61721 L
.41261 .62141 L
.40773 .6258 L
.40207 .63112 L
.39802 .63506 L
Mistroke
.39229 .64083 L
.38831 .64499 L
.38313 .65054 L
.37859 .65558 L
.37449 .66026 L
.36888 .66683 L
.36627 .66997 L
.35917 .67876 L
.35844 .67968 L
.35093 .68939 L
.34946 .69134 L
.34371 .69911 L
.33974 .7046 L
.33675 .70882 L
.33003 .71852 L
.33002 .71853 L
.32351 .72824 L
.32032 .7331 L
.31718 .73796 L
.31103 .74767 L
.31061 .74836 L
.30505 .75738 L
.30089 .76427 L
.29921 .76709 L
.29352 .77681 L
.29118 .78086 L
.28795 .78652 L
.28251 .79623 L
.28147 .79811 L
.27718 .80594 L
.27195 .81566 L
.27176 .81602 L
.26683 .82537 L
.26204 .8346 L
.2618 .83508 L
.25686 .84479 L
.25233 .85385 L
.25201 .85451 L
.24723 .86422 L
.24262 .87376 L
.24254 .87393 L
.23792 .88364 L
.23336 .89336 L
.23291 .89434 L
.22888 .90307 L
.22446 .91278 L
.22319 .91559 L
.2201 .92249 L
.2158 .93221 L
.21348 .9375 L
Mistroke
.21156 .94192 L
.20737 .95163 L
.20377 .96007 L
.20323 .96134 L
.19914 .97106 L
.19511 .98077 L
Mfstroke
.7 g
.8468 .98077 m
.84479 .9764 L
.84232 .97106 L
.83776 .96134 L
.83508 .95569 L
.83314 .95163 L
.82844 .94192 L
.82537 .93565 L
.82367 .93221 L
.81881 .92249 L
.81566 .91628 L
.81387 .91278 L
.80883 .90307 L
.80594 .89757 L
.80371 .89336 L
.79848 .88364 L
.79623 .87953 L
.79314 .87393 L
.78769 .86422 L
.78652 .86216 L
.78212 .85451 L
.77681 .84545 L
.77642 .84479 L
.77057 .83508 L
.76709 .82941 L
.76458 .82537 L
.75842 .81566 L
.75738 .81404 L
.75209 .80594 L
.74767 .79933 L
.74556 .79623 L
.73882 .78652 L
.73796 .78529 L
.73185 .77681 L
.72824 .77192 L
.72461 .76709 L
.71853 .75922 L
.71708 .75738 L
.70922 .74767 L
.70882 .74718 L
.70099 .73796 L
.69911 .73581 L
.69231 .72824 L
.68939 .72511 L
.68311 .71853 L
.67968 .71507 L
.67328 .70882 L
.66997 .7057 L
.66268 .69911 L
.66026 .69699 L
.65109 .68939 L
.65054 .68896 L
.64083 .68159 L
.63817 .67968 L
.63112 .67489 L
.62329 .66997 L
.62141 .66885 L
.61169 .66348 L
.60519 .66026 L
.60198 .65878 L
.59227 .65475 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64664 L
.55342 .64528 L
.54371 .64458 L
.53399 .64454 L
.52428 .64518 L
.51457 .64648 L
.50486 .64844 L
.49689 .65054 L
.49514 .65108 L
.48543 .65438 L
.47572 .65834 L
.47153 .66026 L
.46601 .66298 L
.45629 .66828 L
.45343 .66997 L
.44658 .67425 L
.43856 .67968 L
.43687 .68088 L
.42716 .68819 L
.42563 .68939 L
.41744 .69615 L
.41404 .69911 L
.40773 .70479 L
.40344 .70882 L
.39802 .71409 L
.39361 .71853 L
.38831 .72406 L
.38441 .72824 L
.37859 .7347 L
.37573 .73796 L
.36888 .746 L
.36749 .74767 L
.35963 .75738 L
.35917 .75797 L
.3521 .76709 L
.34946 .7706 L
.34487 .77681 L
.33974 .78391 L
.33789 .78652 L
.33115 .79623 L
.33003 .79788 L
.32462 .80594 L
.32032 .81251 L
.31829 .81566 L
.31213 .82537 L
.31061 .82782 L
.30614 .83508 L
.30089 .84379 L
.30029 .84479 L
.29459 .85451 L
.29118 .86042 L
.28902 .86422 L
.28357 .87393 L
.28147 .87773 L
.27823 .88364 L
.273 .89336 L
.27176 .8957 L
.26787 .90307 L
.26284 .91278 L
.26204 .91433 L
.2579 .92249 L
.25304 .93221 L
.25233 .93364 L
.24826 .94192 L
.24356 .95163 L
.24262 .95361 L
.23894 .96134 L
.23438 .97106 L
.23291 .97424 L
.2299 .98077 L
F
0 g
.8468 .98077 m
.84479 .9764 L
.84232 .97106 L
.83776 .96134 L
.83508 .95569 L
.83314 .95163 L
.82844 .94192 L
.82537 .93565 L
.82367 .93221 L
.81881 .92249 L
.81566 .91628 L
.81387 .91278 L
.80883 .90307 L
.80594 .89757 L
.80371 .89336 L
.79848 .88364 L
.79623 .87953 L
.79314 .87393 L
.78769 .86422 L
.78652 .86216 L
.78212 .85451 L
.77681 .84545 L
.77642 .84479 L
.77057 .83508 L
.76709 .82941 L
.76458 .82537 L
.75842 .81566 L
.75738 .81404 L
.75209 .80594 L
.74767 .79933 L
.74556 .79623 L
.73882 .78652 L
.73796 .78529 L
.73185 .77681 L
.72824 .77192 L
.72461 .76709 L
.71853 .75922 L
.71708 .75738 L
.70922 .74767 L
.70882 .74718 L
.70099 .73796 L
.69911 .73581 L
.69231 .72824 L
.68939 .72511 L
.68311 .71853 L
.67968 .71507 L
.67328 .70882 L
.66997 .7057 L
.66268 .69911 L
.66026 .69699 L
Mistroke
.65109 .68939 L
.65054 .68896 L
.64083 .68159 L
.63817 .67968 L
.63112 .67489 L
.62329 .66997 L
.62141 .66885 L
.61169 .66348 L
.60519 .66026 L
.60198 .65878 L
.59227 .65475 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64664 L
.55342 .64528 L
.54371 .64458 L
.53399 .64454 L
.52428 .64518 L
.51457 .64648 L
.50486 .64844 L
.49689 .65054 L
.49514 .65108 L
.48543 .65438 L
.47572 .65834 L
.47153 .66026 L
.46601 .66298 L
.45629 .66828 L
.45343 .66997 L
.44658 .67425 L
.43856 .67968 L
.43687 .68088 L
.42716 .68819 L
.42563 .68939 L
.41744 .69615 L
.41404 .69911 L
.40773 .70479 L
.40344 .70882 L
.39802 .71409 L
.39361 .71853 L
.38831 .72406 L
.38441 .72824 L
.37859 .7347 L
.37573 .73796 L
.36888 .746 L
.36749 .74767 L
.35963 .75738 L
.35917 .75797 L
.3521 .76709 L
.34946 .7706 L
Mistroke
.34487 .77681 L
.33974 .78391 L
.33789 .78652 L
.33115 .79623 L
.33003 .79788 L
.32462 .80594 L
.32032 .81251 L
.31829 .81566 L
.31213 .82537 L
.31061 .82782 L
.30614 .83508 L
.30089 .84379 L
.30029 .84479 L
.29459 .85451 L
.29118 .86042 L
.28902 .86422 L
.28357 .87393 L
.28147 .87773 L
.27823 .88364 L
.273 .89336 L
.27176 .8957 L
.26787 .90307 L
.26284 .91278 L
.26204 .91433 L
.2579 .92249 L
.25304 .93221 L
.25233 .93364 L
.24826 .94192 L
.24356 .95163 L
.24262 .95361 L
.23894 .96134 L
.23438 .97106 L
.23291 .97424 L
.2299 .98077 L
Mfstroke
.625 g
.81389 .98077 m
.80886 .97106 L
.80594 .96552 L
.80373 .96134 L
.7985 .95163 L
.79623 .94749 L
.79316 .94192 L
.78771 .93221 L
.78652 .93012 L
.78213 .92249 L
.77681 .91342 L
.77642 .91278 L
.77058 .90307 L
.76709 .8974 L
.76458 .89336 L
.75842 .88364 L
.75738 .88203 L
.75208 .87393 L
.74767 .86734 L
.74555 .86422 L
.7388 .85451 L
.73796 .85331 L
.73182 .84479 L
.72824 .83995 L
.72458 .83508 L
.71853 .82726 L
.71704 .82537 L
.70917 .81566 L
.70882 .81523 L
.70092 .80594 L
.69911 .80388 L
.69222 .79623 L
.68939 .79319 L
.68301 .78652 L
.67968 .78316 L
.67316 .77681 L
.66997 .77381 L
.66253 .76709 L
.66026 .76512 L
.6509 .75738 L
.65054 .7571 L
.64083 .74974 L
.63792 .74767 L
.63112 .74306 L
.62296 .73796 L
.62141 .73704 L
.61169 .73169 L
.6047 .72824 L
.60198 .72701 L
.59227 .72299 L
.58256 .71964 L
.57888 .71853 L
.57284 .71696 L
.56313 .71495 L
.55342 .7136 L
.54371 .71292 L
.53399 .71291 L
.52428 .71356 L
.51457 .71488 L
.50486 .71688 L
.49847 .71853 L
.49514 .71953 L
.48543 .72286 L
.47572 .72685 L
.47265 .72824 L
.46601 .73151 L
.45629 .73684 L
.45439 .73796 L
.44658 .74283 L
.43943 .74767 L
.43687 .74949 L
.42716 .75682 L
.42645 .75738 L
.41744 .76482 L
.41482 .76709 L
.40773 .77348 L
.40419 .77681 L
.39802 .78281 L
.39434 .78652 L
.38831 .79281 L
.38512 .79623 L
.37859 .80347 L
.37643 .80594 L
.36888 .81481 L
.36818 .81566 L
.3603 .82537 L
.35917 .82681 L
.35277 .83508 L
.34946 .83947 L
.34552 .84479 L
.33974 .85281 L
.33854 .85451 L
.33179 .86422 L
.33003 .86681 L
.32526 .87393 L
.32032 .88148 L
.31892 .88364 L
.31276 .89336 L
.31061 .89682 L
.30676 .90307 L
.30092 .91278 L
.30089 .91282 L
.29521 .92249 L
.29118 .92949 L
.28963 .93221 L
.28418 .94192 L
.28147 .94683 L
.27884 .95163 L
.27361 .96134 L
.27176 .96484 L
.26848 .97106 L
.26345 .98077 L
F
0 g
.81389 .98077 m
.80886 .97106 L
.80594 .96552 L
.80373 .96134 L
.7985 .95163 L
.79623 .94749 L
.79316 .94192 L
.78771 .93221 L
.78652 .93012 L
.78213 .92249 L
.77681 .91342 L
.77642 .91278 L
.77058 .90307 L
.76709 .8974 L
.76458 .89336 L
.75842 .88364 L
.75738 .88203 L
.75208 .87393 L
.74767 .86734 L
.74555 .86422 L
.7388 .85451 L
.73796 .85331 L
.73182 .84479 L
.72824 .83995 L
.72458 .83508 L
.71853 .82726 L
.71704 .82537 L
.70917 .81566 L
.70882 .81523 L
.70092 .80594 L
.69911 .80388 L
.69222 .79623 L
.68939 .79319 L
.68301 .78652 L
.67968 .78316 L
.67316 .77681 L
.66997 .77381 L
.66253 .76709 L
.66026 .76512 L
.6509 .75738 L
.65054 .7571 L
.64083 .74974 L
.63792 .74767 L
.63112 .74306 L
.62296 .73796 L
.62141 .73704 L
.61169 .73169 L
.6047 .72824 L
.60198 .72701 L
.59227 .72299 L
Mistroke
.58256 .71964 L
.57888 .71853 L
.57284 .71696 L
.56313 .71495 L
.55342 .7136 L
.54371 .71292 L
.53399 .71291 L
.52428 .71356 L
.51457 .71488 L
.50486 .71688 L
.49847 .71853 L
.49514 .71953 L
.48543 .72286 L
.47572 .72685 L
.47265 .72824 L
.46601 .73151 L
.45629 .73684 L
.45439 .73796 L
.44658 .74283 L
.43943 .74767 L
.43687 .74949 L
.42716 .75682 L
.42645 .75738 L
.41744 .76482 L
.41482 .76709 L
.40773 .77348 L
.40419 .77681 L
.39802 .78281 L
.39434 .78652 L
.38831 .79281 L
.38512 .79623 L
.37859 .80347 L
.37643 .80594 L
.36888 .81481 L
.36818 .81566 L
.3603 .82537 L
.35917 .82681 L
.35277 .83508 L
.34946 .83947 L
.34552 .84479 L
.33974 .85281 L
.33854 .85451 L
.33179 .86422 L
.33003 .86681 L
.32526 .87393 L
.32032 .88148 L
.31892 .88364 L
.31276 .89336 L
.31061 .89682 L
.30676 .90307 L
Mistroke
.30092 .91278 L
.30089 .91282 L
.29521 .92249 L
.29118 .92949 L
.28963 .93221 L
.28418 .94192 L
.28147 .94683 L
.27884 .95163 L
.27361 .96134 L
.27176 .96484 L
.26848 .97106 L
.26345 .98077 L
Mfstroke
.55 g
.78049 .98077 m
.77681 .97451 L
.77475 .97106 L
.76885 .96134 L
.76709 .95849 L
.76281 .95163 L
.75738 .94314 L
.75659 .94192 L
.7502 .93221 L
.74767 .92845 L
.7436 .92249 L
.73796 .91443 L
.73678 .91278 L
.72972 .90307 L
.72824 .90108 L
.72239 .89336 L
.71853 .88839 L
.71476 .88364 L
.70882 .87638 L
.70677 .87393 L
.69911 .86503 L
.69839 .86422 L
.68954 .85451 L
.68939 .85435 L
.68014 .84479 L
.67968 .84434 L
.67006 .83508 L
.66997 .83499 L
.66026 .82632 L
.65915 .82537 L
.65054 .81831 L
.64714 .81566 L
.64083 .81096 L
.63362 .80594 L
.63112 .80429 L
.62141 .79828 L
.61782 .79623 L
.61169 .79295 L
.60198 .78828 L
.59793 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77827 L
.56619 .77681 L
.56313 .77627 L
.55342 .77494 L
.54371 .77427 L
.53399 .77428 L
.52428 .77495 L
.51457 .77629 L
.51162 .77681 L
.50486 .77829 L
.49514 .78097 L
.48543 .78431 L
.47987 .78652 L
.47572 .78832 L
.46601 .793 L
.45998 .79623 L
.45629 .79834 L
.44658 .80436 L
.44418 .80594 L
.43687 .81104 L
.43066 .81566 L
.42716 .81839 L
.41865 .82537 L
.41744 .8264 L
.40774 .83508 L
.40773 .83509 L
.39802 .84444 L
.39766 .84479 L
.38831 .85446 L
.38826 .85451 L
.37941 .86422 L
.37859 .86514 L
.37103 .87393 L
.36888 .8765 L
.36304 .88364 L
.35917 .88852 L
.35541 .89336 L
.34946 .90121 L
.34807 .90307 L
.34101 .91278 L
.33974 .91457 L
.3342 .92249 L
.33003 .92859 L
.3276 .93221 L
.3212 .94192 L
.32032 .94329 L
.31499 .95163 L
.31061 .95865 L
.30894 .96134 L
.30305 .97106 L
.30089 .97467 L
.2973 .98077 L
F
0 g
.78049 .98077 m
.77681 .97451 L
.77475 .97106 L
.76885 .96134 L
.76709 .95849 L
.76281 .95163 L
.75738 .94314 L
.75659 .94192 L
.7502 .93221 L
.74767 .92845 L
.7436 .92249 L
.73796 .91443 L
.73678 .91278 L
.72972 .90307 L
.72824 .90108 L
.72239 .89336 L
.71853 .88839 L
.71476 .88364 L
.70882 .87638 L
.70677 .87393 L
.69911 .86503 L
.69839 .86422 L
.68954 .85451 L
.68939 .85435 L
.68014 .84479 L
.67968 .84434 L
.67006 .83508 L
.66997 .83499 L
.66026 .82632 L
.65915 .82537 L
.65054 .81831 L
.64714 .81566 L
.64083 .81096 L
.63362 .80594 L
.63112 .80429 L
.62141 .79828 L
.61782 .79623 L
.61169 .79295 L
.60198 .78828 L
.59793 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77827 L
.56619 .77681 L
.56313 .77627 L
.55342 .77494 L
.54371 .77427 L
.53399 .77428 L
.52428 .77495 L
.51457 .77629 L
Mistroke
.51162 .77681 L
.50486 .77829 L
.49514 .78097 L
.48543 .78431 L
.47987 .78652 L
.47572 .78832 L
.46601 .793 L
.45998 .79623 L
.45629 .79834 L
.44658 .80436 L
.44418 .80594 L
.43687 .81104 L
.43066 .81566 L
.42716 .81839 L
.41865 .82537 L
.41744 .8264 L
.40774 .83508 L
.40773 .83509 L
.39802 .84444 L
.39766 .84479 L
.38831 .85446 L
.38826 .85451 L
.37941 .86422 L
.37859 .86514 L
.37103 .87393 L
.36888 .8765 L
.36304 .88364 L
.35917 .88852 L
.35541 .89336 L
.34946 .90121 L
.34807 .90307 L
.34101 .91278 L
.33974 .91457 L
.3342 .92249 L
.33003 .92859 L
.3276 .93221 L
.3212 .94192 L
.32032 .94329 L
.31499 .95163 L
.31061 .95865 L
.30894 .96134 L
.30305 .97106 L
.30089 .97467 L
.2973 .98077 L
Mfstroke
.475 g
.74519 .98077 m
.73842 .97106 L
.73796 .9704 L
.73142 .96134 L
.72824 .95706 L
.72415 .95163 L
.71853 .94438 L
.71658 .94192 L
.70882 .93237 L
.70868 .93221 L
.70039 .92249 L
.69911 .92103 L
.69165 .91278 L
.68939 .91036 L
.68238 .90307 L
.67968 .90035 L
.67247 .89336 L
.66997 .89102 L
.66176 .88364 L
.66026 .88235 L
.65054 .87435 L
.65002 .87393 L
.64083 .86701 L
.63688 .86422 L
.63112 .86035 L
.62167 .85451 L
.62141 .85435 L
.61169 .84902 L
.60294 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57567 .83508 L
.57284 .83439 L
.56313 .8324 L
.55342 .83108 L
.54371 .83043 L
.53399 .83044 L
.52428 .83113 L
.51457 .83248 L
.50486 .8345 L
.50249 .83508 L
.49514 .83719 L
.48543 .84054 L
.47572 .84456 L
.47521 .84479 L
.46601 .84926 L
.45648 .85451 L
.45629 .85461 L
.44658 .86064 L
.44127 .86422 L
.43687 .86734 L
.42813 .87393 L
.42716 .8747 L
.41744 .88273 L
.41639 .88364 L
.40773 .89143 L
.40568 .89336 L
.39802 .9008 L
.39576 .90307 L
.38831 .91083 L
.38649 .91278 L
.37859 .92154 L
.37775 .92249 L
.36946 .93221 L
.36888 .93291 L
.36156 .94192 L
.35917 .94495 L
.354 .95163 L
.34946 .95765 L
.34673 .96134 L
.33974 .97103 L
.33972 .97106 L
.33296 .98077 L
F
0 g
.74519 .98077 m
.73842 .97106 L
.73796 .9704 L
.73142 .96134 L
.72824 .95706 L
.72415 .95163 L
.71853 .94438 L
.71658 .94192 L
.70882 .93237 L
.70868 .93221 L
.70039 .92249 L
.69911 .92103 L
.69165 .91278 L
.68939 .91036 L
.68238 .90307 L
.67968 .90035 L
.67247 .89336 L
.66997 .89102 L
.66176 .88364 L
.66026 .88235 L
.65054 .87435 L
.65002 .87393 L
.64083 .86701 L
.63688 .86422 L
.63112 .86035 L
.62167 .85451 L
.62141 .85435 L
.61169 .84902 L
.60294 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57567 .83508 L
.57284 .83439 L
.56313 .8324 L
.55342 .83108 L
.54371 .83043 L
.53399 .83044 L
.52428 .83113 L
.51457 .83248 L
.50486 .8345 L
.50249 .83508 L
.49514 .83719 L
.48543 .84054 L
.47572 .84456 L
.47521 .84479 L
.46601 .84926 L
.45648 .85451 L
.45629 .85461 L
.44658 .86064 L
Mistroke
.44127 .86422 L
.43687 .86734 L
.42813 .87393 L
.42716 .8747 L
.41744 .88273 L
.41639 .88364 L
.40773 .89143 L
.40568 .89336 L
.39802 .9008 L
.39576 .90307 L
.38831 .91083 L
.38649 .91278 L
.37859 .92154 L
.37775 .92249 L
.36946 .93221 L
.36888 .93291 L
.36156 .94192 L
.35917 .94495 L
.354 .95163 L
.34946 .95765 L
.34673 .96134 L
.33974 .97103 L
.33972 .97106 L
.33296 .98077 L
Mfstroke
.4 g
.70583 .98077 m
.69911 .97299 L
.69739 .97106 L
.68939 .96233 L
.68847 .96134 L
.67968 .95233 L
.67898 .95163 L
.66997 .943 L
.6688 .94192 L
.66026 .93434 L
.65775 .93221 L
.65054 .92634 L
.64555 .92249 L
.64083 .91902 L
.63177 .91278 L
.63112 .91236 L
.62141 .90637 L
.61553 .90307 L
.61169 .90105 L
.60198 .8964 L
.59474 .89336 L
.59227 .89241 L
.58256 .8891 L
.57284 .88645 L
.56313 .88447 L
.55824 .88364 L
.55342 .88316 L
.54371 .88251 L
.53399 .88254 L
.52428 .88323 L
.52032 .88364 L
.51457 .88459 L
.50486 .88662 L
.49514 .88932 L
.48543 .89269 L
.48369 .89336 L
.47572 .89672 L
.46601 .90142 L
.46289 .90307 L
.45629 .90679 L
.44666 .91278 L
.44658 .91283 L
.43687 .91954 L
.43287 .92249 L
.42716 .92692 L
.42068 .93221 L
.41744 .93496 L
.40962 .94192 L
.40773 .94367 L
.39944 .95163 L
.39802 .95305 L
.38996 .96134 L
.38831 .9631 L
.38104 .97106 L
.37859 .97381 L
.37259 .98077 L
F
0 g
.70583 .98077 m
.69911 .97299 L
.69739 .97106 L
.68939 .96233 L
.68847 .96134 L
.67968 .95233 L
.67898 .95163 L
.66997 .943 L
.6688 .94192 L
.66026 .93434 L
.65775 .93221 L
.65054 .92634 L
.64555 .92249 L
.64083 .91902 L
.63177 .91278 L
.63112 .91236 L
.62141 .90637 L
.61553 .90307 L
.61169 .90105 L
.60198 .8964 L
.59474 .89336 L
.59227 .89241 L
.58256 .8891 L
.57284 .88645 L
.56313 .88447 L
.55824 .88364 L
.55342 .88316 L
.54371 .88251 L
.53399 .88254 L
.52428 .88323 L
.52032 .88364 L
.51457 .88459 L
.50486 .88662 L
.49514 .88932 L
.48543 .89269 L
.48369 .89336 L
.47572 .89672 L
.46601 .90142 L
.46289 .90307 L
.45629 .90679 L
.44666 .91278 L
.44658 .91283 L
.43687 .91954 L
.43287 .92249 L
.42716 .92692 L
.42068 .93221 L
.41744 .93496 L
.40962 .94192 L
.40773 .94367 L
.39944 .95163 L
Mistroke
.39802 .95305 L
.38996 .96134 L
.38831 .9631 L
.38104 .97106 L
.37859 .97381 L
.37259 .98077 L
Mfstroke
.325 g
.65757 .98077 m
.65054 .97506 L
.64534 .97106 L
.64083 .96774 L
.63151 .96134 L
.63112 .96109 L
.62141 .95511 L
.6152 .95163 L
.61169 .94979 L
.60198 .94515 L
.59424 .94192 L
.59227 .94117 L
.58256 .93786 L
.57284 .93522 L
.56313 .93325 L
.5563 .93221 L
.55342 .93194 L
.54371 .93131 L
.53399 .93134 L
.52428 .93204 L
.52255 .93221 L
.51457 .93341 L
.50486 .93545 L
.49514 .93815 L
.48543 .94153 L
.48441 .94192 L
.47572 .94557 L
.46601 .95028 L
.46345 .95163 L
.45629 .95566 L
.44714 .96134 L
.44658 .96171 L
.43687 .96843 L
.43331 .97106 L
.42716 .97581 L
.42108 .98077 L
F
0 g
.65757 .98077 m
.65054 .97506 L
.64534 .97106 L
.64083 .96774 L
.63151 .96134 L
.63112 .96109 L
.62141 .95511 L
.6152 .95163 L
.61169 .94979 L
.60198 .94515 L
.59424 .94192 L
.59227 .94117 L
.58256 .93786 L
.57284 .93522 L
.56313 .93325 L
.5563 .93221 L
.55342 .93194 L
.54371 .93131 L
.53399 .93134 L
.52428 .93204 L
.52255 .93221 L
.51457 .93341 L
.50486 .93545 L
.49514 .93815 L
.48543 .94153 L
.48441 .94192 L
.47572 .94557 L
.46601 .95028 L
.46345 .95163 L
.45629 .95566 L
.44714 .96134 L
.44658 .96171 L
.43687 .96843 L
.43331 .97106 L
.42716 .97581 L
.42108 .98077 L
s
.25 g
.57084 .98077 m
.56313 .97929 L
.55342 .97799 L
.54371 .97736 L
.53399 .9774 L
.52428 .97811 L
.51457 .97948 L
.50798 .98077 L
F
0 g
.57084 .98077 m
.56313 .97929 L
.55342 .97799 L
.54371 .97736 L
.53399 .9774 L
.52428 .97811 L
.51457 .97948 L
.50798 .98077 L
s
.925 g
.98077 .5573 m
.97951 .55342 L
.97638 .54371 L
.97325 .53399 L
.97106 .52725 L
.97009 .52428 L
.9669 .51457 L
.96367 .50486 L
.96134 .49789 L
.96043 .49514 L
.95716 .48543 L
.95386 .47572 L
.95163 .4692 L
.95054 .46601 L
.94719 .45629 L
.94381 .44658 L
.94192 .4412 L
.9404 .43687 L
.93696 .42716 L
.93349 .41744 L
.93221 .41387 L
.92999 .40773 L
.92646 .39802 L
.92289 .38831 L
.92249 .38723 L
.9193 .37859 L
.91566 .36888 L
.91278 .36127 L
.91199 .35917 L
.90828 .34946 L
.90453 .33974 L
.90307 .33599 L
.90075 .33003 L
.89692 .32032 L
.89336 .31139 L
.89304 .31061 L
.88913 .30089 L
.88517 .29118 L
.88364 .28747 L
.88117 .28147 L
.87711 .27176 L
.87393 .26423 L
.87301 .26204 L
.86885 .25233 L
.86463 .24262 L
.86422 .24167 L
.86037 .23291 L
.85604 .22319 L
.85451 .21979 L
.85165 .21348 L
.8472 .20377 L
.84479 .19859 L
.84268 .19406 L
.83809 .18434 L
.83508 .17808 L
.83342 .17463 L
.82868 .16492 L
.82537 .15824 L
.82386 .15521 L
.81895 .14549 L
.81566 .13908 L
.81395 .13578 L
.80885 .12607 L
.80594 .12061 L
.80366 .11636 L
.79835 .10664 L
.79623 .10281 L
.79294 .09693 L
.7874 .08722 L
.78652 .0857 L
.78173 .07751 L
.77681 .06927 L
.77592 .06779 L
.76995 .05808 L
.76709 .05352 L
.76383 .04837 L
.75752 .03866 L
.75738 .03845 L
.75102 .02894 L
.74767 .02406 L
.74431 .01923 L
.98077 .01923 L
F
0 g
.98077 .5573 m
.97951 .55342 L
.97638 .54371 L
.97325 .53399 L
.97106 .52725 L
.97009 .52428 L
.9669 .51457 L
.96367 .50486 L
.96134 .49789 L
.96043 .49514 L
.95716 .48543 L
.95386 .47572 L
.95163 .4692 L
.95054 .46601 L
.94719 .45629 L
.94381 .44658 L
.94192 .4412 L
.9404 .43687 L
.93696 .42716 L
.93349 .41744 L
.93221 .41387 L
.92999 .40773 L
.92646 .39802 L
.92289 .38831 L
.92249 .38723 L
.9193 .37859 L
.91566 .36888 L
.91278 .36127 L
.91199 .35917 L
.90828 .34946 L
.90453 .33974 L
.90307 .33599 L
.90075 .33003 L
.89692 .32032 L
.89336 .31139 L
.89304 .31061 L
.88913 .30089 L
.88517 .29118 L
.88364 .28747 L
.88117 .28147 L
.87711 .27176 L
.87393 .26423 L
.87301 .26204 L
.86885 .25233 L
.86463 .24262 L
.86422 .24167 L
.86037 .23291 L
.85604 .22319 L
.85451 .21979 L
.85165 .21348 L
Mistroke
.8472 .20377 L
.84479 .19859 L
.84268 .19406 L
.83809 .18434 L
.83508 .17808 L
.83342 .17463 L
.82868 .16492 L
.82537 .15824 L
.82386 .15521 L
.81895 .14549 L
.81566 .13908 L
.81395 .13578 L
.80885 .12607 L
.80594 .12061 L
.80366 .11636 L
.79835 .10664 L
.79623 .10281 L
.79294 .09693 L
.7874 .08722 L
.78652 .0857 L
.78173 .07751 L
.77681 .06927 L
.77592 .06779 L
.76995 .05808 L
.76709 .05352 L
.76383 .04837 L
.75752 .03866 L
.75738 .03845 L
.75102 .02894 L
.74767 .02406 L
.74431 .01923 L
Mfstroke
.85 g
.98077 .42918 m
.98012 .42716 L
.977 .41744 L
.97386 .40773 L
.97106 .39913 L
.97069 .39802 L
.9675 .38831 L
.96429 .37859 L
.96134 .36976 L
.96105 .36888 L
.95779 .35917 L
.9545 .34946 L
.95163 .34107 L
.95118 .33974 L
.94783 .33003 L
.94446 .32032 L
.94192 .31306 L
.94106 .31061 L
.93763 .30089 L
.93417 .29118 L
.93221 .28572 L
.93067 .28147 L
.92715 .27176 L
.92359 .26204 L
.92249 .25906 L
.92 .25233 L
.91638 .24262 L
.91278 .23308 L
.91272 .23291 L
.90902 .22319 L
.90528 .21348 L
.90307 .20778 L
.90151 .20377 L
.89769 .19406 L
.89383 .18434 L
.89336 .18315 L
.88993 .17463 L
.88599 .16492 L
.88364 .1592 L
.882 .15521 L
.87796 .14549 L
.87393 .13593 L
.87387 .13578 L
.86973 .12607 L
.86554 .11636 L
.86422 .11333 L
.86129 .10664 L
.85698 .09693 L
.85451 .09141 L
.85261 .08722 L
.84818 .07751 L
.84479 .07017 L
.84369 .06779 L
.83912 .05808 L
.83508 .04961 L
.83448 .04837 L
.82977 .03866 L
.82537 .02972 L
.82498 .02894 L
.82011 .01923 L
.98077 .01923 L
F
0 g
.98077 .42918 m
.98012 .42716 L
.977 .41744 L
.97386 .40773 L
.97106 .39913 L
.97069 .39802 L
.9675 .38831 L
.96429 .37859 L
.96134 .36976 L
.96105 .36888 L
.95779 .35917 L
.9545 .34946 L
.95163 .34107 L
.95118 .33974 L
.94783 .33003 L
.94446 .32032 L
.94192 .31306 L
.94106 .31061 L
.93763 .30089 L
.93417 .29118 L
.93221 .28572 L
.93067 .28147 L
.92715 .27176 L
.92359 .26204 L
.92249 .25906 L
.92 .25233 L
.91638 .24262 L
.91278 .23308 L
.91272 .23291 L
.90902 .22319 L
.90528 .21348 L
.90307 .20778 L
.90151 .20377 L
.89769 .19406 L
.89383 .18434 L
.89336 .18315 L
.88993 .17463 L
.88599 .16492 L
.88364 .1592 L
.882 .15521 L
.87796 .14549 L
.87393 .13593 L
.87387 .13578 L
.86973 .12607 L
.86554 .11636 L
.86422 .11333 L
.86129 .10664 L
.85698 .09693 L
.85451 .09141 L
.85261 .08722 L
Mistroke
.84818 .07751 L
.84479 .07017 L
.84369 .06779 L
.83912 .05808 L
.83508 .04961 L
.83448 .04837 L
.82977 .03866 L
.82537 .02972 L
.82498 .02894 L
.82011 .01923 L
Mfstroke
.775 g
.98077 .33534 m
.97906 .33003 L
.97594 .32032 L
.97279 .31061 L
.97106 .3053 L
.96961 .30089 L
.96642 .29118 L
.96319 .28147 L
.96134 .27593 L
.95995 .27176 L
.95667 .26204 L
.95337 .25233 L
.95163 .24724 L
.95005 .24262 L
.94669 .23291 L
.94331 .22319 L
.94192 .21922 L
.9399 .21348 L
.93646 .20377 L
.93299 .19406 L
.93221 .19188 L
.92949 .18434 L
.92595 .17463 L
.92249 .16521 L
.92239 .16492 L
.91879 .15521 L
.91515 .14549 L
.91278 .13922 L
.91148 .13578 L
.90777 .12607 L
.90402 .11636 L
.90307 .11391 L
.90023 .10664 L
.89641 .09693 L
.89336 .08927 L
.89254 .08722 L
.88862 .07751 L
.88466 .06779 L
.88364 .06531 L
.88066 .05808 L
.87661 .04837 L
.87393 .04202 L
.8725 .03866 L
.86835 .02894 L
.86422 .01942 L
.86414 .01923 L
.98077 .01923 L
F
0 g
.98077 .33534 m
.97906 .33003 L
.97594 .32032 L
.97279 .31061 L
.97106 .3053 L
.96961 .30089 L
.96642 .29118 L
.96319 .28147 L
.96134 .27593 L
.95995 .27176 L
.95667 .26204 L
.95337 .25233 L
.95163 .24724 L
.95005 .24262 L
.94669 .23291 L
.94331 .22319 L
.94192 .21922 L
.9399 .21348 L
.93646 .20377 L
.93299 .19406 L
.93221 .19188 L
.92949 .18434 L
.92595 .17463 L
.92249 .16521 L
.92239 .16492 L
.91879 .15521 L
.91515 .14549 L
.91278 .13922 L
.91148 .13578 L
.90777 .12607 L
.90402 .11636 L
.90307 .11391 L
.90023 .10664 L
.89641 .09693 L
.89336 .08927 L
.89254 .08722 L
.88862 .07751 L
.88466 .06779 L
.88364 .06531 L
.88066 .05808 L
.87661 .04837 L
.87393 .04202 L
.8725 .03866 L
.86835 .02894 L
.86422 .01942 L
.86414 .01923 L
s
.7 g
.98077 .25759 m
.97908 .25233 L
.97595 .24262 L
.9728 .23291 L
.97106 .22755 L
.96963 .22319 L
.96643 .21348 L
.96321 .20377 L
.96134 .19818 L
.95996 .19406 L
.95669 .18434 L
.95339 .17463 L
.95163 .16948 L
.95007 .16492 L
.94671 .15521 L
.94333 .14549 L
.94192 .14146 L
.93992 .13578 L
.93648 .12607 L
.93301 .11636 L
.93221 .11412 L
.92951 .10664 L
.92598 .09693 L
.92249 .08745 L
.92241 .08722 L
.91881 .07751 L
.91517 .06779 L
.91278 .06146 L
.9115 .05808 L
.90779 .04837 L
.90405 .03866 L
.90307 .03614 L
.90026 .02894 L
.89643 .01923 L
.98077 .01923 L
F
0 g
.98077 .25759 m
.97908 .25233 L
.97595 .24262 L
.9728 .23291 L
.97106 .22755 L
.96963 .22319 L
.96643 .21348 L
.96321 .20377 L
.96134 .19818 L
.95996 .19406 L
.95669 .18434 L
.95339 .17463 L
.95163 .16948 L
.95007 .16492 L
.94671 .15521 L
.94333 .14549 L
.94192 .14146 L
.93992 .13578 L
.93648 .12607 L
.93301 .11636 L
.93221 .11412 L
.92951 .10664 L
.92598 .09693 L
.92249 .08745 L
.92241 .08722 L
.91881 .07751 L
.91517 .06779 L
.91278 .06146 L
.9115 .05808 L
.90779 .04837 L
.90405 .03866 L
.90307 .03614 L
.90026 .02894 L
.89643 .01923 L
s
.625 g
.98077 .18972 m
.97905 .18434 L
.97592 .17463 L
.97277 .16492 L
.97106 .15967 L
.96959 .15521 L
.9664 .14549 L
.96317 .13578 L
.96134 .1303 L
.95993 .12607 L
.95665 .11636 L
.95335 .10664 L
.95163 .10161 L
.95003 .09693 L
.94667 .08722 L
.94329 .07751 L
.94192 .07359 L
.93988 .06779 L
.93644 .05808 L
.93297 .04837 L
.93221 .04624 L
.92947 .03866 L
.92594 .02894 L
.92249 .01957 L
.92237 .01923 L
.98077 .01923 L
F
0 g
.98077 .18972 m
.97905 .18434 L
.97592 .17463 L
.97277 .16492 L
.97106 .15967 L
.96959 .15521 L
.9664 .14549 L
.96317 .13578 L
.96134 .1303 L
.95993 .12607 L
.95665 .11636 L
.95335 .10664 L
.95163 .10161 L
.95003 .09693 L
.94667 .08722 L
.94329 .07751 L
.94192 .07359 L
.93988 .06779 L
.93644 .05808 L
.93297 .04837 L
.93221 .04624 L
.92947 .03866 L
.92594 .02894 L
.92249 .01957 L
.92237 .01923 L
s
.55 g
.98077 .1287 m
.97993 .12607 L
.9768 .11636 L
.97366 .10664 L
.97106 .09866 L
.97049 .09693 L
.9673 .08722 L
.96409 .07751 L
.96134 .06929 L
.96084 .06779 L
.95758 .05808 L
.95429 .04837 L
.95163 .04059 L
.95097 .03866 L
.94762 .02894 L
.94425 .01923 L
.98077 .01923 L
F
0 g
.98077 .1287 m
.97993 .12607 L
.9768 .11636 L
.97366 .10664 L
.97106 .09866 L
.97049 .09693 L
.9673 .08722 L
.96409 .07751 L
.96134 .06929 L
.96084 .06779 L
.95758 .05808 L
.95429 .04837 L
.95163 .04059 L
.95097 .03866 L
.94762 .02894 L
.94425 .01923 L
s
.475 g
.98077 .07281 m
.97916 .06779 L
.97603 .05808 L
.97288 .04837 L
.97106 .04276 L
.96971 .03866 L
.96651 .02894 L
.96329 .01923 L
.98077 .01923 L
F
0 g
.98077 .07281 m
.97916 .06779 L
.97603 .05808 L
.97288 .04837 L
.97106 .04276 L
.96971 .03866 L
.96651 .02894 L
.96329 .01923 L
s
.4 g
.98077 .02093 m
.98023 .01923 L
.98077 .01923 L
F
0 g
.98077 .02093 m
.98023 .01923 L
s
0 0 0 r
.055 w
.97602 .78218 Mdot
1 0 0 r
.0325 w
.01923 .78218 Mdot
.33371 .98077 Mdot
.09568 .83046 Mdot
.09386 .82807 Mdot
.0936 .82644 Mdot
.09392 .82297 Mdot
.09631 .8104 Mdot
.10405 .77863 Mdot
.12414 .70608 Mdot
.15136 .61887 Mdot
.18883 .51573 Mdot
.23885 .40789 Mdot
.28608 .33284 Mdot
.43908 .01923 Mdot
.32312 .25693 Mdot
.39714 .14482 Mdot
.41211 .16272 Mdot
.48523 .09751 Mdot
.51896 .09174 Mdot
.5547 .1236 Mdot
.73319 .10878 Mdot
.60093 .11976 Mdot
.77963 .1353 Mdot
.62632 .12197 Mdot
.64427 .131 Mdot
.68681 .16705 Mdot
.71616 .21142 Mdot
.77663 .28392 Mdot
.74596 .24715 Mdot
.79803 .33134 Mdot
.81766 .38714 Mdot
.88181 .50424 Mdot
.84016 .42821 Mdot
.98077 .70105 Mdot
.86297 .47246 Mdot
.8796 .50863 Mdot
.89216 .54121 Mdot
.91265 .59904 Mdot
.94777 .68904 Mdot
.92654 .63463 Mdot
.95072 .70244 Mdot
.95708 .72522 Mdot
.97018 .76332 Mdot
.97303 .77257 Mdot
.97544 .78036 Mdot
.976 .78211 Mdot
.976 .78213 Mdot
.97602 .78219 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
0 1 0 r
.02 w
.01923 .78218 Mdot
.33371 .98077 Mdot
.09568 .83046 Mdot
.09386 .82807 Mdot
.0936 .82644 Mdot
.09392 .82297 Mdot
.09631 .8104 Mdot
.10405 .77863 Mdot
.12414 .70608 Mdot
.15136 .61887 Mdot
.18883 .51573 Mdot
.23885 .40789 Mdot
.28608 .33284 Mdot
.43908 .01923 Mdot
.32312 .25693 Mdot
.39714 .14482 Mdot
.41211 .16272 Mdot
.48523 .09751 Mdot
.51896 .09174 Mdot
.5547 .1236 Mdot
.73319 .10878 Mdot
.60093 .11976 Mdot
.77963 .1353 Mdot
.62632 .12197 Mdot
.64427 .131 Mdot
.68681 .16705 Mdot
.71616 .21142 Mdot
.77663 .28392 Mdot
.74596 .24715 Mdot
.79803 .33134 Mdot
.81766 .38714 Mdot
.88181 .50424 Mdot
.84016 .42821 Mdot
.98077 .70105 Mdot
.86297 .47246 Mdot
.8796 .50863 Mdot
.89216 .54121 Mdot
.91265 .59904 Mdot
.94777 .68904 Mdot
.92654 .63463 Mdot
.95072 .70244 Mdot
.95708 .72522 Mdot
.97018 .76332 Mdot
.97303 .77257 Mdot
.97544 .78036 Mdot
.976 .78211 Mdot
.976 .78213 Mdot
.97602 .78219 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
0 0 1 r
.5 Mabswid
.01923 .78218 m
.01923 .78218 L
.09568 .83046 L
.09386 .82807 L
.0936 .82644 L
.09392 .82297 L
.09631 .8104 L
.10405 .77863 L
.12414 .70608 L
.15136 .61887 L
.18883 .51573 L
.23885 .40789 L
.28608 .33284 L
.32312 .25693 L
.39714 .14482 L
.41211 .16272 L
.48523 .09751 L
.51896 .09174 L
.5547 .1236 L
.60093 .11976 L
.62632 .12197 L
.64427 .131 L
.68681 .16705 L
.71616 .21142 L
.74596 .24715 L
.79803 .33134 L
.81766 .38714 L
.84016 .42821 L
.86297 .47246 L
.8796 .50863 L
.89216 .54121 L
.91265 .59904 L
.92654 .63463 L
.95072 .70244 L
.95708 .72522 L
.97018 .76332 L
.97303 .77257 L
.97544 .78036 L
.976 .78211 L
.976 .78213 L
.97602 .78219 L
.97602 .78218 L
.97602 .78218 L
.97602 .78218 L
s
.015 w
.01923 .78218 Mdot
.01923 .78218 Mdot
.09568 .83046 Mdot
.09386 .82807 Mdot
.0936 .82644 Mdot
.09392 .82297 Mdot
.09631 .8104 Mdot
.10405 .77863 Mdot
.12414 .70608 Mdot
.15136 .61887 Mdot
.18883 .51573 Mdot
.23885 .40789 Mdot
.28608 .33284 Mdot
.32312 .25693 Mdot
.39714 .14482 Mdot
.41211 .16272 Mdot
.48523 .09751 Mdot
.51896 .09174 Mdot
.5547 .1236 Mdot
.60093 .11976 Mdot
.62632 .12197 Mdot
.64427 .131 Mdot
.68681 .16705 Mdot
.71616 .21142 Mdot
.74596 .24715 Mdot
.79803 .33134 Mdot
.81766 .38714 Mdot
.84016 .42821 Mdot
.86297 .47246 Mdot
.8796 .50863 Mdot
.89216 .54121 Mdot
.91265 .59904 Mdot
.92654 .63463 Mdot
.95072 .70244 Mdot
.95708 .72522 Mdot
.97018 .76332 Mdot
.97303 .77257 Mdot
.97544 .78036 Mdot
.976 .78211 Mdot
.976 .78213 Mdot
.97602 .78219 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
.97602 .78218 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0055371 0.97619 0.227021 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.541189 0.434965 0.109337 0.672845 [
[.10622 -0.0125 -6 -9 ]
[.10622 -0.0125 6 0 ]
[.32371 -0.0125 -12 -9 ]
[.32371 -0.0125 12 0 ]
[.54119 -0.0125 -3 -9 ]
[.54119 -0.0125 3 0 ]
[.75867 -0.0125 -9 -9 ]
[.75867 -0.0125 9 0 ]
[.97615 -0.0125 -3 -9 ]
[.97615 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10934 -6 -4.5 ]
[-0.0125 .10934 0 4.5 ]
[-0.0125 .24391 -18 -4.5 ]
[-0.0125 .24391 0 4.5 ]
[-0.0125 .37847 -18 -4.5 ]
[-0.0125 .37847 0 4.5 ]
[-0.0125 .51304 -18 -4.5 ]
[-0.0125 .51304 0 4.5 ]
[-0.0125 .64761 -18 -4.5 ]
[-0.0125 .64761 0 4.5 ]
[-0.0125 .78218 -6 -4.5 ]
[-0.0125 .78218 0 4.5 ]
[-0.0125 .91675 -18 -4.5 ]
[-0.0125 .91675 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10622 0 m
.10622 .00625 L
s
[(-1)] .10622 -0.0125 0 1 Mshowa
.32371 0 m
.32371 .00625 L
s
[(-0.5)] .32371 -0.0125 0 1 Mshowa
.54119 0 m
.54119 .00625 L
s
[(0)] .54119 -0.0125 0 1 Mshowa
.75867 0 m
.75867 .00625 L
s
[(0.5)] .75867 -0.0125 0 1 Mshowa
.97615 0 m
.97615 .00625 L
s
[(1)] .97615 -0.0125 0 1 Mshowa
.125 Mabswid
.14972 0 m
.14972 .00375 L
s
.19322 0 m
.19322 .00375 L
s
.23671 0 m
.23671 .00375 L
s
.28021 0 m
.28021 .00375 L
s
.3672 0 m
.3672 .00375 L
s
.4107 0 m
.4107 .00375 L
s
.4542 0 m
.4542 .00375 L
s
.49769 0 m
.49769 .00375 L
s
.58469 0 m
.58469 .00375 L
s
.62818 0 m
.62818 .00375 L
s
.67168 0 m
.67168 .00375 L
s
.71518 0 m
.71518 .00375 L
s
.80217 0 m
.80217 .00375 L
s
.84567 0 m
.84567 .00375 L
s
.88916 0 m
.88916 .00375 L
s
.93266 0 m
.93266 .00375 L
s
.06273 0 m
.06273 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10934 m
.00625 .10934 L
s
[(0)] -0.0125 .10934 1 0 Mshowa
0 .24391 m
.00625 .24391 L
s
[(0.2)] -0.0125 .24391 1 0 Mshowa
0 .37847 m
.00625 .37847 L
s
[(0.4)] -0.0125 .37847 1 0 Mshowa
0 .51304 m
.00625 .51304 L
s
[(0.6)] -0.0125 .51304 1 0 Mshowa
0 .64761 m
.00625 .64761 L
s
[(0.8)] -0.0125 .64761 1 0 Mshowa
0 .78218 m
.00625 .78218 L
s
[(1)] -0.0125 .78218 1 0 Mshowa
0 .91675 m
.00625 .91675 L
s
[(1.2)] -0.0125 .91675 1 0 Mshowa
.125 Mabswid
0 .14298 m
.00375 .14298 L
s
0 .17662 m
.00375 .17662 L
s
0 .21026 m
.00375 .21026 L
s
0 .27755 m
.00375 .27755 L
s
0 .31119 m
.00375 .31119 L
s
0 .34483 m
.00375 .34483 L
s
0 .41212 m
.00375 .41212 L
s
0 .44576 m
.00375 .44576 L
s
0 .4794 m
.00375 .4794 L
s
0 .54669 m
.00375 .54669 L
s
0 .58033 m
.00375 .58033 L
s
0 .61397 m
.00375 .61397 L
s
0 .68125 m
.00375 .68125 L
s
0 .7149 m
.00375 .7149 L
s
0 .74854 m
.00375 .74854 L
s
0 .81582 m
.00375 .81582 L
s
0 .84947 m
.00375 .84947 L
s
0 .88311 m
.00375 .88311 L
s
0 .07569 m
.00375 .07569 L
s
0 .04205 m
.00375 .04205 L
s
0 .00841 m
.00375 .00841 L
s
0 .95039 m
.00375 .95039 L
s
0 .98403 m
.00375 .98403 L
s
.25 Mabswid
0 0 m
0 1 L
s
.10622 .99375 m
.10622 1 L
s
.32371 .99375 m
.32371 1 L
s
.54119 .99375 m
.54119 1 L
s
.75867 .99375 m
.75867 1 L
s
.97615 .99375 m
.97615 1 L
s
.125 Mabswid
.14972 .99625 m
.14972 1 L
s
.19322 .99625 m
.19322 1 L
s
.23671 .99625 m
.23671 1 L
s
.28021 .99625 m
.28021 1 L
s
.3672 .99625 m
.3672 1 L
s
.4107 .99625 m
.4107 1 L
s
.4542 .99625 m
.4542 1 L
s
.49769 .99625 m
.49769 1 L
s
.58469 .99625 m
.58469 1 L
s
.62818 .99625 m
.62818 1 L
s
.67168 .99625 m
.67168 1 L
s
.71518 .99625 m
.71518 1 L
s
.80217 .99625 m
.80217 1 L
s
.84567 .99625 m
.84567 1 L
s
.88916 .99625 m
.88916 1 L
s
.93266 .99625 m
.93266 1 L
s
.06273 .99625 m
.06273 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .10934 m
1 .10934 L
s
.99375 .24391 m
1 .24391 L
s
.99375 .37847 m
1 .37847 L
s
.99375 .51304 m
1 .51304 L
s
.99375 .64761 m
1 .64761 L
s
.99375 .78218 m
1 .78218 L
s
.99375 .91675 m
1 .91675 L
s
.125 Mabswid
.99625 .14298 m
1 .14298 L
s
.99625 .17662 m
1 .17662 L
s
.99625 .21026 m
1 .21026 L
s
.99625 .27755 m
1 .27755 L
s
.99625 .31119 m
1 .31119 L
s
.99625 .34483 m
1 .34483 L
s
.99625 .41212 m
1 .41212 L
s
.99625 .44576 m
1 .44576 L
s
.99625 .4794 m
1 .4794 L
s
.99625 .54669 m
1 .54669 L
s
.99625 .58033 m
1 .58033 L
s
.99625 .61397 m
1 .61397 L
s
.99625 .68125 m
1 .68125 L
s
.99625 .7149 m
1 .7149 L
s
.99625 .74854 m
1 .74854 L
s
.99625 .81582 m
1 .81582 L
s
.99625 .84947 m
1 .84947 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .07569 m
1 .07569 L
s
.99625 .04205 m
1 .04205 L
s
.99625 .00841 m
1 .00841 L
s
.99625 .95039 m
1 .95039 L
s
.99625 .98403 m
1 .98403 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.925 g
.01923 .88972 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85282 L
.03106 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81662 L
.03891 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74629 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71215 L
.06874 .70882 L
.07154 .69911 L
.07437 .68939 L
.07722 .67968 L
.07751 .6787 L
.08006 .66997 L
.08294 .66026 L
.08584 .65054 L
.08722 .64595 L
.08874 .64083 L
.09167 .63112 L
.09462 .62141 L
.09693 .61388 L
.0976 .61169 L
.10057 .60198 L
.10359 .59227 L
.10662 .58256 L
.10664 .5825 L
.10966 .57284 L
.11273 .56313 L
.11584 .55342 L
.11636 .5518 L
.11894 .54371 L
.12208 .53399 L
.12525 .52428 L
.12607 .52179 L
.12843 .51457 L
.13164 .50486 L
.13488 .49514 L
.13578 .49247 L
.13814 .48543 L
.14143 .47572 L
.14475 .46601 L
.14549 .46384 L
.14809 .45629 L
.15146 .44658 L
.15486 .43687 L
.15521 .43589 L
.15828 .42716 L
.16175 .41744 L
.16492 .40863 L
.16524 .40773 L
.16876 .39802 L
.17232 .38831 L
.17463 .38206 L
.17591 .37859 L
.17954 .36888 L
.1832 .35917 L
.18434 .35617 L
.1869 .34946 L
.19064 .33974 L
.19406 .33097 L
.19442 .33003 L
.19824 .32032 L
.2021 .31061 L
.20377 .30645 L
.20601 .30089 L
.20996 .29118 L
.21348 .28262 L
.21396 .28147 L
.218 .27176 L
.2221 .26204 L
.22319 .25948 L
.22625 .25233 L
.23045 .24262 L
.23291 .23702 L
.23471 .23291 L
.23903 .22319 L
.24262 .21524 L
.24342 .21348 L
.24786 .20377 L
.25233 .19415 L
.25237 .19406 L
.25695 .18434 L
.26161 .17463 L
.26204 .17374 L
.26634 .16492 L
.27116 .15521 L
.27176 .15402 L
.27606 .14549 L
.28105 .13578 L
.28147 .13498 L
.28614 .12607 L
.29118 .11663 L
.29133 .11636 L
.29662 .10664 L
.30089 .09896 L
.30203 .09693 L
.30756 .08722 L
.31061 .08197 L
.31323 .07751 L
.31903 .06779 L
.32032 .06567 L
.32498 .05808 L
.33003 .05005 L
.3311 .04837 L
.3374 .03866 L
.33974 .03512 L
.34389 .02894 L
.34946 .02087 L
.3506 .01923 L
.01923 .01923 L
F
0 g
.01923 .88972 m
.0209 .88364 L
.02346 .87393 L
.02597 .86422 L
.0285 .85451 L
.02894 .85282 L
.03106 .84479 L
.03366 .83508 L
.03628 .82537 L
.03866 .81662 L
.03891 .81566 L
.04154 .80594 L
.04419 .79623 L
.04687 .78652 L
.04837 .78111 L
.04955 .77681 L
.05223 .76709 L
.05495 .75738 L
.05769 .74767 L
.05808 .74629 L
.06042 .73796 L
.06317 .72824 L
.06595 .71853 L
.06779 .71215 L
.06874 .70882 L
.07154 .69911 L
.07437 .68939 L
.07722 .67968 L
.07751 .6787 L
.08006 .66997 L
.08294 .66026 L
.08584 .65054 L
.08722 .64595 L
.08874 .64083 L
.09167 .63112 L
.09462 .62141 L
.09693 .61388 L
.0976 .61169 L
.10057 .60198 L
.10359 .59227 L
.10662 .58256 L
.10664 .5825 L
.10966 .57284 L
.11273 .56313 L
.11584 .55342 L
.11636 .5518 L
.11894 .54371 L
.12208 .53399 L
.12525 .52428 L
.12607 .52179 L
Mistroke
.12843 .51457 L
.13164 .50486 L
.13488 .49514 L
.13578 .49247 L
.13814 .48543 L
.14143 .47572 L
.14475 .46601 L
.14549 .46384 L
.14809 .45629 L
.15146 .44658 L
.15486 .43687 L
.15521 .43589 L
.15828 .42716 L
.16175 .41744 L
.16492 .40863 L
.16524 .40773 L
.16876 .39802 L
.17232 .38831 L
.17463 .38206 L
.17591 .37859 L
.17954 .36888 L
.1832 .35917 L
.18434 .35617 L
.1869 .34946 L
.19064 .33974 L
.19406 .33097 L
.19442 .33003 L
.19824 .32032 L
.2021 .31061 L
.20377 .30645 L
.20601 .30089 L
.20996 .29118 L
.21348 .28262 L
.21396 .28147 L
.218 .27176 L
.2221 .26204 L
.22319 .25948 L
.22625 .25233 L
.23045 .24262 L
.23291 .23702 L
.23471 .23291 L
.23903 .22319 L
.24262 .21524 L
.24342 .21348 L
.24786 .20377 L
.25233 .19415 L
.25237 .19406 L
.25695 .18434 L
.26161 .17463 L
.26204 .17374 L
Mistroke
.26634 .16492 L
.27116 .15521 L
.27176 .15402 L
.27606 .14549 L
.28105 .13578 L
.28147 .13498 L
.28614 .12607 L
.29118 .11663 L
.29133 .11636 L
.29662 .10664 L
.30089 .09896 L
.30203 .09693 L
.30756 .08722 L
.31061 .08197 L
.31323 .07751 L
.31903 .06779 L
.32032 .06567 L
.32498 .05808 L
.33003 .05005 L
.3311 .04837 L
.3374 .03866 L
.33974 .03512 L
.34389 .02894 L
.34946 .02087 L
.3506 .01923 L
Mfstroke
.85 g
.01923 .74152 m
.02018 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70515 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66944 L
.04118 .66026 L
.04387 .65054 L
.04657 .64083 L
.04837 .63442 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56642 L
.06875 .56313 L
.07159 .55342 L
.07446 .54371 L
.07734 .53399 L
.07751 .53343 L
.08023 .52428 L
.08315 .51457 L
.08609 .50486 L
.08722 .50113 L
.08904 .49514 L
.09201 .48543 L
.095 .47572 L
.09693 .4695 L
.09801 .46601 L
.10105 .45629 L
.1041 .44658 L
.10664 .43855 L
.10718 .43687 L
.11027 .42716 L
.11339 .41744 L
.11636 .40828 L
.11653 .40773 L
.1197 .39802 L
.12288 .38831 L
.12607 .37869 L
.1261 .37859 L
.12933 .36888 L
.1326 .35917 L
.13578 .34977 L
.13589 .34946 L
.1392 .33974 L
.14255 .33003 L
.14549 .32154 L
.14592 .32032 L
.14932 .31061 L
.15275 .30089 L
.15521 .29398 L
.15621 .29118 L
.1597 .28147 L
.16322 .27176 L
.16492 .2671 L
.16677 .26204 L
.17036 .25233 L
.17399 .24262 L
.17463 .2409 L
.17765 .23291 L
.18134 .22319 L
.18434 .21538 L
.18508 .21348 L
.18885 .20377 L
.19266 .19406 L
.19406 .19054 L
.19652 .18434 L
.20042 .17463 L
.20377 .16637 L
.20436 .16492 L
.20835 .15521 L
.21239 .14549 L
.21348 .14289 L
.21648 .13578 L
.22061 .12607 L
.22319 .12008 L
.22481 .11636 L
.22905 .10664 L
.23291 .09795 L
.23336 .09693 L
.23772 .08722 L
.24215 .07751 L
.24262 .0765 L
.24665 .06779 L
.25121 .05808 L
.25233 .05572 L
.25585 .04837 L
.26056 .03866 L
.26204 .03563 L
.26535 .02894 L
.27022 .01923 L
.01923 .01923 L
F
0 g
.01923 .74152 m
.02018 .73796 L
.02277 .72824 L
.02536 .71853 L
.02796 .70882 L
.02894 .70515 L
.03057 .69911 L
.0332 .68939 L
.03585 .67968 L
.03851 .66997 L
.03866 .66944 L
.04118 .66026 L
.04387 .65054 L
.04657 .64083 L
.04837 .63442 L
.04929 .63112 L
.05202 .62141 L
.05477 .61169 L
.05754 .60198 L
.05808 .60008 L
.06031 .59227 L
.06311 .58256 L
.06592 .57284 L
.06779 .56642 L
.06875 .56313 L
.07159 .55342 L
.07446 .54371 L
.07734 .53399 L
.07751 .53343 L
.08023 .52428 L
.08315 .51457 L
.08609 .50486 L
.08722 .50113 L
.08904 .49514 L
.09201 .48543 L
.095 .47572 L
.09693 .4695 L
.09801 .46601 L
.10105 .45629 L
.1041 .44658 L
.10664 .43855 L
.10718 .43687 L
.11027 .42716 L
.11339 .41744 L
.11636 .40828 L
.11653 .40773 L
.1197 .39802 L
.12288 .38831 L
.12607 .37869 L
.1261 .37859 L
Mistroke
.12933 .36888 L
.1326 .35917 L
.13578 .34977 L
.13589 .34946 L
.1392 .33974 L
.14255 .33003 L
.14549 .32154 L
.14592 .32032 L
.14932 .31061 L
.15275 .30089 L
.15521 .29398 L
.15621 .29118 L
.1597 .28147 L
.16322 .27176 L
.16492 .2671 L
.16677 .26204 L
.17036 .25233 L
.17399 .24262 L
.17463 .2409 L
.17765 .23291 L
.18134 .22319 L
.18434 .21538 L
.18508 .21348 L
.18885 .20377 L
.19266 .19406 L
.19406 .19054 L
.19652 .18434 L
.20042 .17463 L
.20377 .16637 L
.20436 .16492 L
.20835 .15521 L
.21239 .14549 L
.21348 .14289 L
.21648 .13578 L
.22061 .12607 L
.22319 .12008 L
.22481 .11636 L
.22905 .10664 L
.23291 .09795 L
.23336 .09693 L
.23772 .08722 L
.24215 .07751 L
.24262 .0765 L
.24665 .06779 L
.25121 .05808 L
.25233 .05572 L
.25585 .04837 L
.26056 .03866 L
.26204 .03563 L
.26535 .02894 L
Mistroke
.27022 .01923 L
Mfstroke
.775 g
.01923 .64096 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02706 .61169 L
.02894 .60473 L
.02969 .60198 L
.03232 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56918 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46659 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43374 L
.07948 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40157 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37008 L
.0973 .36888 L
.10034 .35917 L
.10341 .34946 L
.10649 .33974 L
.10664 .33926 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .30913 L
.11905 .30089 L
.12224 .29118 L
.12547 .28147 L
.12607 .27966 L
.12871 .27176 L
.13199 .26204 L
.13528 .25233 L
.13578 .25088 L
.13861 .24262 L
.14196 .23291 L
.14534 .22319 L
.14549 .22277 L
.14875 .21348 L
.15219 .20377 L
.15521 .19534 L
.15566 .19406 L
.15917 .18434 L
.1627 .17463 L
.16492 .16858 L
.16627 .16492 L
.16987 .15521 L
.1735 .14549 L
.17463 .1425 L
.17717 .13578 L
.18088 .12607 L
.18434 .1171 L
.18463 .11636 L
.18842 .10664 L
.19224 .09693 L
.19406 .09237 L
.19611 .08722 L
.20003 .07751 L
.20377 .06832 L
.20398 .06779 L
.20799 .05808 L
.21204 .04837 L
.21348 .04494 L
.21614 .03866 L
.2203 .02894 L
.22319 .02225 L
.22451 .01923 L
.01923 .01923 L
F
0 g
.01923 .64096 m
.01927 .64083 L
.02186 .63112 L
.02446 .62141 L
.02706 .61169 L
.02894 .60473 L
.02969 .60198 L
.03232 .59227 L
.03498 .58256 L
.03765 .57284 L
.03866 .56918 L
.04033 .56313 L
.04302 .55342 L
.04573 .54371 L
.04837 .53431 L
.04846 .53399 L
.05119 .52428 L
.05395 .51457 L
.05672 .50486 L
.05808 .50011 L
.05951 .49514 L
.06231 .48543 L
.06513 .47572 L
.06779 .46659 L
.06796 .46601 L
.07081 .45629 L
.07368 .44658 L
.07657 .43687 L
.07751 .43374 L
.07948 .42716 L
.0824 .41744 L
.08534 .40773 L
.08722 .40157 L
.0883 .39802 L
.09128 .38831 L
.09428 .37859 L
.09693 .37008 L
.0973 .36888 L
.10034 .35917 L
.10341 .34946 L
.10649 .33974 L
.10664 .33926 L
.10959 .33003 L
.11272 .32032 L
.11587 .31061 L
.11636 .30913 L
.11905 .30089 L
.12224 .29118 L
.12547 .28147 L
.12607 .27966 L
Mistroke
.12871 .27176 L
.13199 .26204 L
.13528 .25233 L
.13578 .25088 L
.13861 .24262 L
.14196 .23291 L
.14534 .22319 L
.14549 .22277 L
.14875 .21348 L
.15219 .20377 L
.15521 .19534 L
.15566 .19406 L
.15917 .18434 L
.1627 .17463 L
.16492 .16858 L
.16627 .16492 L
.16987 .15521 L
.1735 .14549 L
.17463 .1425 L
.17717 .13578 L
.18088 .12607 L
.18434 .1171 L
.18463 .11636 L
.18842 .10664 L
.19224 .09693 L
.19406 .09237 L
.19611 .08722 L
.20003 .07751 L
.20377 .06832 L
.20398 .06779 L
.20799 .05808 L
.21204 .04837 L
.21348 .04494 L
.21614 .03866 L
.2203 .02894 L
.22319 .02225 L
.22451 .01923 L
Mfstroke
.7 g
.01923 .55954 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.0287 .52428 L
.02894 .52339 L
.03134 .51457 L
.03399 .50486 L
.03666 .49514 L
.03866 .48792 L
.03934 .48543 L
.04204 .47572 L
.04475 .46601 L
.04747 .45629 L
.04837 .45312 L
.05021 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08143 .33974 L
.08437 .33003 L
.08722 .32069 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28927 L
.09937 .28147 L
.10244 .27176 L
.10552 .26204 L
.10664 .25852 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22845 L
.11808 .22319 L
.12127 .21348 L
.1245 .20377 L
.12607 .19906 L
.12774 .19406 L
.13102 .18434 L
.13432 .17463 L
.13578 .17034 L
.13764 .16492 L
.14099 .15521 L
.14438 .14549 L
.14549 .1423 L
.14779 .13578 L
.15122 .12607 L
.1547 .11636 L
.15521 .11493 L
.1582 .10664 L
.16173 .09693 L
.16492 .08824 L
.1653 .08722 L
.1689 .07751 L
.17253 .06779 L
.17463 .06223 L
.1762 .05808 L
.17991 .04837 L
.18366 .03866 L
.18434 .03689 L
.18744 .02894 L
.19127 .01923 L
.01923 .01923 L
F
0 g
.01923 .55954 m
.02087 .55342 L
.02347 .54371 L
.02608 .53399 L
.0287 .52428 L
.02894 .52339 L
.03134 .51457 L
.03399 .50486 L
.03666 .49514 L
.03866 .48792 L
.03934 .48543 L
.04204 .47572 L
.04475 .46601 L
.04747 .45629 L
.04837 .45312 L
.05021 .44658 L
.05297 .43687 L
.05574 .42716 L
.05808 .419 L
.05853 .41744 L
.06133 .40773 L
.06415 .39802 L
.06699 .38831 L
.06779 .38555 L
.06984 .37859 L
.07271 .36888 L
.0756 .35917 L
.07751 .35278 L
.0785 .34946 L
.08143 .33974 L
.08437 .33003 L
.08722 .32069 L
.08733 .32032 L
.09031 .31061 L
.09331 .30089 L
.09633 .29118 L
.09693 .28927 L
.09937 .28147 L
.10244 .27176 L
.10552 .26204 L
.10664 .25852 L
.10862 .25233 L
.11175 .24262 L
.1149 .23291 L
.11636 .22845 L
.11808 .22319 L
.12127 .21348 L
.1245 .20377 L
.12607 .19906 L
.12774 .19406 L
Mistroke
.13102 .18434 L
.13432 .17463 L
.13578 .17034 L
.13764 .16492 L
.14099 .15521 L
.14438 .14549 L
.14549 .1423 L
.14779 .13578 L
.15122 .12607 L
.1547 .11636 L
.15521 .11493 L
.1582 .10664 L
.16173 .09693 L
.16492 .08824 L
.1653 .08722 L
.1689 .07751 L
.17253 .06779 L
.17463 .06223 L
.1762 .05808 L
.17991 .04837 L
.18366 .03866 L
.18434 .03689 L
.18744 .02894 L
.19127 .01923 L
Mfstroke
.625 g
.01923 .48927 m
.02026 .48543 L
.02286 .47572 L
.02547 .46601 L
.0281 .45629 L
.02894 .45317 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41775 L
.03874 .41744 L
.04144 .40773 L
.04415 .39802 L
.04687 .38831 L
.04837 .383 L
.04961 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34893 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25076 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21939 L
.09878 .21348 L
.10184 .20377 L
.10493 .19406 L
.10664 .18869 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15866 L
.11749 .15521 L
.12069 .14549 L
.12391 .13578 L
.12607 .12932 L
.12716 .12607 L
.13043 .11636 L
.13373 .10664 L
.13578 .10064 L
.13705 .09693 L
.14041 .08722 L
.14379 .07751 L
.14549 .07264 L
.1472 .06779 L
.15064 .05808 L
.15411 .04837 L
.15521 .04532 L
.15761 .03866 L
.16115 .02894 L
.16471 .01923 L
.01923 .01923 L
F
0 g
.01923 .48927 m
.02026 .48543 L
.02286 .47572 L
.02547 .46601 L
.0281 .45629 L
.02894 .45317 L
.03074 .44658 L
.03339 .43687 L
.03606 .42716 L
.03866 .41775 L
.03874 .41744 L
.04144 .40773 L
.04415 .39802 L
.04687 .38831 L
.04837 .383 L
.04961 .37859 L
.05237 .36888 L
.05514 .35917 L
.05793 .34946 L
.05808 .34893 L
.06073 .33974 L
.06355 .33003 L
.06639 .32032 L
.06779 .31553 L
.06924 .31061 L
.07211 .30089 L
.075 .29118 L
.07751 .28281 L
.07791 .28147 L
.08083 .27176 L
.08377 .26204 L
.08674 .25233 L
.08722 .25076 L
.08972 .24262 L
.09272 .23291 L
.09574 .22319 L
.09693 .21939 L
.09878 .21348 L
.10184 .20377 L
.10493 .19406 L
.10664 .18869 L
.10803 .18434 L
.11116 .17463 L
.11431 .16492 L
.11636 .15866 L
.11749 .15521 L
.12069 .14549 L
.12391 .13578 L
.12607 .12932 L
.12716 .12607 L
Mistroke
.13043 .11636 L
.13373 .10664 L
.13578 .10064 L
.13705 .09693 L
.14041 .08722 L
.14379 .07751 L
.14549 .07264 L
.1472 .06779 L
.15064 .05808 L
.15411 .04837 L
.15521 .04532 L
.15761 .03866 L
.16115 .02894 L
.16471 .01923 L
Mfstroke
.55 g
.01923 .42653 m
.02166 .41744 L
.02427 .40773 L
.0269 .39802 L
.02894 .39047 L
.02953 .38831 L
.03218 .37859 L
.03485 .36888 L
.03752 .35917 L
.03866 .35508 L
.04022 .34946 L
.04292 .33974 L
.04565 .33003 L
.04837 .32037 L
.04838 .32032 L
.05113 .31061 L
.0539 .30089 L
.05669 .29118 L
.05808 .28633 L
.05948 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25297 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18827 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15693 L
.09747 .15521 L
.10053 .14549 L
.1036 .13578 L
.10664 .12626 L
.1067 .12607 L
.10983 .11636 L
.11297 .10664 L
.11614 .09693 L
.11636 .09627 L
.11933 .08722 L
.12255 .07751 L
.12579 .06779 L
.12607 .06695 L
.12905 .05808 L
.13234 .04837 L
.13566 .03866 L
.13578 .03831 L
.13901 .02894 L
.14238 .01923 L
.01923 .01923 L
F
0 g
.01923 .42653 m
.02166 .41744 L
.02427 .40773 L
.0269 .39802 L
.02894 .39047 L
.02953 .38831 L
.03218 .37859 L
.03485 .36888 L
.03752 .35917 L
.03866 .35508 L
.04022 .34946 L
.04292 .33974 L
.04565 .33003 L
.04837 .32037 L
.04838 .32032 L
.05113 .31061 L
.0539 .30089 L
.05669 .29118 L
.05808 .28633 L
.05948 .28147 L
.0623 .27176 L
.06513 .26204 L
.06779 .25297 L
.06798 .25233 L
.07085 .24262 L
.07373 .23291 L
.07663 .22319 L
.07751 .22028 L
.07955 .21348 L
.08249 .20377 L
.08545 .19406 L
.08722 .18827 L
.08842 .18434 L
.09142 .17463 L
.09443 .16492 L
.09693 .15693 L
.09747 .15521 L
.10053 .14549 L
.1036 .13578 L
.10664 .12626 L
.1067 .12607 L
.10983 .11636 L
.11297 .10664 L
.11614 .09693 L
.11636 .09627 L
.11933 .08722 L
.12255 .07751 L
.12579 .06779 L
.12607 .06695 L
.12905 .05808 L
Mistroke
.13234 .04837 L
.13566 .03866 L
.13578 .03831 L
.13901 .02894 L
.14238 .01923 L
Mfstroke
.475 g
.01923 .36933 m
.01935 .36888 L
.02195 .35917 L
.02457 .34946 L
.02719 .33974 L
.02894 .33329 L
.02983 .33003 L
.03248 .32032 L
.03515 .31061 L
.03784 .30089 L
.03866 .29793 L
.04053 .29118 L
.04324 .28147 L
.04597 .27176 L
.04837 .26325 L
.04871 .26204 L
.05146 .25233 L
.05424 .24262 L
.05702 .23291 L
.05808 .22923 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .1959 L
.06834 .19406 L
.07121 .18434 L
.07409 .17463 L
.077 .16492 L
.07751 .16323 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06929 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03932 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
.01923 .01923 L
F
0 g
.01923 .36933 m
.01935 .36888 L
.02195 .35917 L
.02457 .34946 L
.02719 .33974 L
.02894 .33329 L
.02983 .33003 L
.03248 .32032 L
.03515 .31061 L
.03784 .30089 L
.03866 .29793 L
.04053 .29118 L
.04324 .28147 L
.04597 .27176 L
.04837 .26325 L
.04871 .26204 L
.05146 .25233 L
.05424 .24262 L
.05702 .23291 L
.05808 .22923 L
.05983 .22319 L
.06265 .21348 L
.06548 .20377 L
.06779 .1959 L
.06834 .19406 L
.07121 .18434 L
.07409 .17463 L
.077 .16492 L
.07751 .16323 L
.07992 .15521 L
.08287 .14549 L
.08583 .13578 L
.08722 .13124 L
.08881 .12607 L
.09181 .11636 L
.09483 .10664 L
.09693 .09993 L
.09787 .09693 L
.10093 .08722 L
.10402 .07751 L
.10664 .06929 L
.10712 .06779 L
.11025 .05808 L
.1134 .04837 L
.11636 .03932 L
.11657 .03866 L
.11977 .02894 L
.12299 .01923 L
s
.4 g
.01923 .31641 m
.02078 .31061 L
.02339 .30089 L
.02602 .29118 L
.02865 .28147 L
.02894 .28039 L
.0313 .27176 L
.03396 .26204 L
.03664 .25233 L
.03866 .24505 L
.03933 .24262 L
.04204 .23291 L
.04476 .22319 L
.04749 .21348 L
.04837 .21039 L
.05024 .20377 L
.05301 .19406 L
.05579 .18434 L
.05808 .1764 L
.05859 .17463 L
.0614 .16492 L
.06424 .15521 L
.06708 .14549 L
.06779 .14308 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08158 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10579 .01923 L
.01923 .01923 L
F
0 g
.01923 .31641 m
.02078 .31061 L
.02339 .30089 L
.02602 .29118 L
.02865 .28147 L
.02894 .28039 L
.0313 .27176 L
.03396 .26204 L
.03664 .25233 L
.03866 .24505 L
.03933 .24262 L
.04204 .23291 L
.04476 .22319 L
.04749 .21348 L
.04837 .21039 L
.05024 .20377 L
.05301 .19406 L
.05579 .18434 L
.05808 .1764 L
.05859 .17463 L
.0614 .16492 L
.06424 .15521 L
.06708 .14549 L
.06779 .14308 L
.06995 .13578 L
.07283 .12607 L
.07573 .11636 L
.07751 .11044 L
.07865 .10664 L
.08158 .09693 L
.08454 .08722 L
.08722 .07847 L
.08751 .07751 L
.09051 .06779 L
.09352 .05808 L
.09656 .04837 L
.09693 .04717 L
.09961 .03866 L
.10269 .02894 L
.10579 .01923 L
s
.325 g
.01923 .26693 m
.02054 .26204 L
.02315 .25233 L
.02577 .24262 L
.02841 .23291 L
.02894 .23093 L
.03106 .22319 L
.03372 .21348 L
.0364 .20377 L
.03866 .19561 L
.03909 .19406 L
.04179 .18434 L
.04451 .17463 L
.04725 .16492 L
.04837 .16096 L
.05 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12699 L
.05835 .12607 L
.06116 .11636 L
.06399 .10664 L
.06684 .09693 L
.06779 .09369 L
.0697 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06106 L
.0784 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02911 L
.08727 .02894 L
.09026 .01923 L
.01923 .01923 L
F
0 g
.01923 .26693 m
.02054 .26204 L
.02315 .25233 L
.02577 .24262 L
.02841 .23291 L
.02894 .23093 L
.03106 .22319 L
.03372 .21348 L
.0364 .20377 L
.03866 .19561 L
.03909 .19406 L
.04179 .18434 L
.04451 .17463 L
.04725 .16492 L
.04837 .16096 L
.05 .15521 L
.05277 .14549 L
.05555 .13578 L
.05808 .12699 L
.05835 .12607 L
.06116 .11636 L
.06399 .10664 L
.06684 .09693 L
.06779 .09369 L
.0697 .08722 L
.07259 .07751 L
.07549 .06779 L
.07751 .06106 L
.0784 .05808 L
.08134 .04837 L
.0843 .03866 L
.08722 .02911 L
.08727 .02894 L
.09026 .01923 L
s
.25 g
.01923 .2203 m
.02106 .21348 L
.02367 .20377 L
.0263 .19406 L
.02894 .18434 L
.02894 .18432 L
.03159 .17463 L
.03426 .16492 L
.03694 .15521 L
.03866 .14901 L
.03963 .14549 L
.04234 .13578 L
.04507 .12607 L
.04781 .11636 L
.04837 .11438 L
.05056 .10664 L
.05333 .09693 L
.05612 .08722 L
.05808 .08042 L
.05892 .07751 L
.06174 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04713 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
.01923 .01923 L
F
0 g
.01923 .2203 m
.02106 .21348 L
.02367 .20377 L
.0263 .19406 L
.02894 .18434 L
.02894 .18432 L
.03159 .17463 L
.03426 .16492 L
.03694 .15521 L
.03866 .14901 L
.03963 .14549 L
.04234 .13578 L
.04507 .12607 L
.04781 .11636 L
.04837 .11438 L
.05056 .10664 L
.05333 .09693 L
.05612 .08722 L
.05808 .08042 L
.05892 .07751 L
.06174 .06779 L
.06458 .05808 L
.06743 .04837 L
.06779 .04713 L
.0703 .03866 L
.07319 .02894 L
.07609 .01923 L
s
.925 g
.96266 .98077 m
.96134 .97682 L
.95941 .97106 L
.95613 .96134 L
.95283 .95163 L
.95163 .94811 L
.94951 .94192 L
.94615 .93221 L
.94277 .92249 L
.94192 .92006 L
.93936 .91278 L
.93592 .90307 L
.93245 .89336 L
.93221 .89267 L
.92895 .88364 L
.92542 .87393 L
.92249 .86595 L
.92186 .86422 L
.91826 .85451 L
.91463 .84479 L
.91278 .83989 L
.91096 .83508 L
.90726 .82537 L
.90352 .81566 L
.90307 .81449 L
.89974 .80594 L
.89593 .79623 L
.89336 .78975 L
.89207 .78652 L
.88817 .77681 L
.88423 .76709 L
.88364 .76567 L
.88024 .75738 L
.8762 .74767 L
.87393 .74225 L
.87212 .73796 L
.86798 .72824 L
.86422 .7195 L
.8638 .71853 L
.85956 .70882 L
.85527 .69911 L
.85451 .6974 L
.85091 .68939 L
.8465 .67968 L
.84479 .67597 L
.84202 .66997 L
.83747 .66026 L
.83508 .6552 L
.83286 .65054 L
.82817 .64083 L
.82537 .63509 L
.82341 .63112 L
.81857 .62141 L
.81566 .61564 L
.81364 .61169 L
.80863 .60198 L
.80594 .59686 L
.80352 .59227 L
.79831 .58256 L
.79623 .57873 L
.793 .57284 L
.78757 .56313 L
.78652 .56127 L
.78203 .55342 L
.77681 .54446 L
.77636 .54371 L
.77055 .53399 L
.76709 .52832 L
.7646 .52428 L
.75849 .51457 L
.75738 .51284 L
.7522 .50486 L
.74767 .49802 L
.74573 .49514 L
.73905 .48543 L
.73796 .48387 L
.73215 .47572 L
.72824 .47037 L
.725 .46601 L
.71853 .45754 L
.71756 .45629 L
.70982 .44658 L
.70882 .44536 L
.70171 .43687 L
.69911 .43385 L
.69319 .42716 L
.68939 .423 L
.68418 .41744 L
.67968 .41281 L
.67459 .40773 L
.66997 .40328 L
.6643 .39802 L
.66026 .39441 L
.65311 .38831 L
.65054 .3862 L
.64083 .37865 L
.64075 .37859 L
.63112 .37177 L
.62675 .36888 L
.62141 .36554 L
.61169 .35998 L
.61018 .35917 L
.60198 .35507 L
.59227 .35083 L
.58877 .34946 L
.58256 .34725 L
.57284 .34432 L
.56313 .34206 L
.55342 .34046 L
.54673 .33974 L
.54371 .33952 L
.53399 .33924 L
.52428 .33962 L
.52204 .33974 L
.51457 .34066 L
.50486 .34236 L
.49514 .34472 L
.48543 .34774 L
.48067 .34946 L
.47572 .35142 L
.46601 .35576 L
.45925 .35917 L
.45629 .36076 L
.44658 .36642 L
.44268 .36888 L
.43687 .37274 L
.42866 .37859 L
.42716 .37972 L
.41744 .38736 L
.41629 .38831 L
.40773 .39565 L
.4051 .39802 L
.39802 .40461 L
.39479 .40773 L
.38831 .41423 L
.3852 .41744 L
.37859 .4245 L
.37618 .42716 L
.36888 .43544 L
.36765 .43687 L
.35953 .44658 L
.35917 .44703 L
.35178 .45629 L
.34946 .45928 L
.34433 .46601 L
.33974 .47219 L
.33717 .47572 L
.33026 .48543 L
.33003 .48576 L
.32358 .49514 L
.32032 .49999 L
.31709 .50486 L
.3108 .51457 L
.31061 .51487 L
.30468 .52428 L
.30089 .53042 L
.29872 .53399 L
.2929 .54371 L
.29118 .54662 L
.28722 .55342 L
.28166 .56313 L
.28147 .56348 L
.27623 .57284 L
.27176 .58099 L
.27091 .58256 L
.26569 .59227 L
.26204 .59917 L
.26057 .60198 L
.25555 .61169 L
.25233 .618 L
.25061 .62141 L
.24576 .63112 L
.24262 .63749 L
.24099 .64083 L
.23629 .65054 L
.23291 .65764 L
.23167 .66026 L
.22712 .66997 L
.22319 .67844 L
.22263 .67968 L
.2182 .68939 L
.21384 .69911 L
.21348 .6999 L
.20954 .70882 L
.20528 .71853 L
.20377 .72202 L
.20109 .72824 L
.19695 .73796 L
.19406 .7448 L
.19285 .74767 L
.18881 .75738 L
.18481 .76709 L
.18434 .76823 L
.18086 .77681 L
.17695 .78652 L
.17463 .79231 L
.17308 .79623 L
.16925 .80594 L
.16546 .81566 L
.16492 .81706 L
.16172 .82537 L
.158 .83508 L
.15521 .84245 L
.15433 .84479 L
.15069 .85451 L
.14708 .86422 L
.14549 .86851 L
.14351 .87393 L
.13997 .88364 L
.13645 .89336 L
.13578 .89522 L
.13298 .90307 L
.12953 .91278 L
.1261 .92249 L
.12607 .92258 L
.12272 .93221 L
.11935 .94192 L
.11636 .9506 L
.116 .95163 L
.1127 .96134 L
.10941 .97106 L
.10664 .97927 L
.10615 .98077 L
F
0 g
.96266 .98077 m
.96134 .97682 L
.95941 .97106 L
.95613 .96134 L
.95283 .95163 L
.95163 .94811 L
.94951 .94192 L
.94615 .93221 L
.94277 .92249 L
.94192 .92006 L
.93936 .91278 L
.93592 .90307 L
.93245 .89336 L
.93221 .89267 L
.92895 .88364 L
.92542 .87393 L
.92249 .86595 L
.92186 .86422 L
.91826 .85451 L
.91463 .84479 L
.91278 .83989 L
.91096 .83508 L
.90726 .82537 L
.90352 .81566 L
.90307 .81449 L
.89974 .80594 L
.89593 .79623 L
.89336 .78975 L
.89207 .78652 L
.88817 .77681 L
.88423 .76709 L
.88364 .76567 L
.88024 .75738 L
.8762 .74767 L
.87393 .74225 L
.87212 .73796 L
.86798 .72824 L
.86422 .7195 L
.8638 .71853 L
.85956 .70882 L
.85527 .69911 L
.85451 .6974 L
.85091 .68939 L
.8465 .67968 L
.84479 .67597 L
.84202 .66997 L
.83747 .66026 L
.83508 .6552 L
.83286 .65054 L
.82817 .64083 L
Mistroke
.82537 .63509 L
.82341 .63112 L
.81857 .62141 L
.81566 .61564 L
.81364 .61169 L
.80863 .60198 L
.80594 .59686 L
.80352 .59227 L
.79831 .58256 L
.79623 .57873 L
.793 .57284 L
.78757 .56313 L
.78652 .56127 L
.78203 .55342 L
.77681 .54446 L
.77636 .54371 L
.77055 .53399 L
.76709 .52832 L
.7646 .52428 L
.75849 .51457 L
.75738 .51284 L
.7522 .50486 L
.74767 .49802 L
.74573 .49514 L
.73905 .48543 L
.73796 .48387 L
.73215 .47572 L
.72824 .47037 L
.725 .46601 L
.71853 .45754 L
.71756 .45629 L
.70982 .44658 L
.70882 .44536 L
.70171 .43687 L
.69911 .43385 L
.69319 .42716 L
.68939 .423 L
.68418 .41744 L
.67968 .41281 L
.67459 .40773 L
.66997 .40328 L
.6643 .39802 L
.66026 .39441 L
.65311 .38831 L
.65054 .3862 L
.64083 .37865 L
.64075 .37859 L
.63112 .37177 L
.62675 .36888 L
.62141 .36554 L
Mistroke
.61169 .35998 L
.61018 .35917 L
.60198 .35507 L
.59227 .35083 L
.58877 .34946 L
.58256 .34725 L
.57284 .34432 L
.56313 .34206 L
.55342 .34046 L
.54673 .33974 L
.54371 .33952 L
.53399 .33924 L
.52428 .33962 L
.52204 .33974 L
.51457 .34066 L
.50486 .34236 L
.49514 .34472 L
.48543 .34774 L
.48067 .34946 L
.47572 .35142 L
.46601 .35576 L
.45925 .35917 L
.45629 .36076 L
.44658 .36642 L
.44268 .36888 L
.43687 .37274 L
.42866 .37859 L
.42716 .37972 L
.41744 .38736 L
.41629 .38831 L
.40773 .39565 L
.4051 .39802 L
.39802 .40461 L
.39479 .40773 L
.38831 .41423 L
.3852 .41744 L
.37859 .4245 L
.37618 .42716 L
.36888 .43544 L
.36765 .43687 L
.35953 .44658 L
.35917 .44703 L
.35178 .45629 L
.34946 .45928 L
.34433 .46601 L
.33974 .47219 L
.33717 .47572 L
.33026 .48543 L
.33003 .48576 L
.32358 .49514 L
Mistroke
.32032 .49999 L
.31709 .50486 L
.3108 .51457 L
.31061 .51487 L
.30468 .52428 L
.30089 .53042 L
.29872 .53399 L
.2929 .54371 L
.29118 .54662 L
.28722 .55342 L
.28166 .56313 L
.28147 .56348 L
.27623 .57284 L
.27176 .58099 L
.27091 .58256 L
.26569 .59227 L
.26204 .59917 L
.26057 .60198 L
.25555 .61169 L
.25233 .618 L
.25061 .62141 L
.24576 .63112 L
.24262 .63749 L
.24099 .64083 L
.23629 .65054 L
.23291 .65764 L
.23167 .66026 L
.22712 .66997 L
.22319 .67844 L
.22263 .67968 L
.2182 .68939 L
.21384 .69911 L
.21348 .6999 L
.20954 .70882 L
.20528 .71853 L
.20377 .72202 L
.20109 .72824 L
.19695 .73796 L
.19406 .7448 L
.19285 .74767 L
.18881 .75738 L
.18481 .76709 L
.18434 .76823 L
.18086 .77681 L
.17695 .78652 L
.17463 .79231 L
.17308 .79623 L
.16925 .80594 L
.16546 .81566 L
.16492 .81706 L
Mistroke
.16172 .82537 L
.158 .83508 L
.15521 .84245 L
.15433 .84479 L
.15069 .85451 L
.14708 .86422 L
.14549 .86851 L
.14351 .87393 L
.13997 .88364 L
.13645 .89336 L
.13578 .89522 L
.13298 .90307 L
.12953 .91278 L
.1261 .92249 L
.12607 .92258 L
.12272 .93221 L
.11935 .94192 L
.11636 .9506 L
.116 .95163 L
.1127 .96134 L
.10941 .97106 L
.10664 .97927 L
.10615 .98077 L
Mfstroke
.85 g
.91754 .98077 m
.9139 .97106 L
.91278 .96808 L
.91023 .96134 L
.90651 .95163 L
.90307 .9427 L
.90277 .94192 L
.89898 .93221 L
.89515 .92249 L
.89336 .91799 L
.89128 .91278 L
.88736 .90307 L
.88364 .89394 L
.8834 .89336 L
.8794 .88364 L
.87535 .87393 L
.87393 .87056 L
.87125 .86422 L
.8671 .85451 L
.86422 .84784 L
.8629 .84479 L
.85864 .83508 L
.85451 .82578 L
.85432 .82537 L
.84994 .81566 L
.84551 .80594 L
.84479 .8044 L
.841 .79623 L
.83643 .78652 L
.83508 .78367 L
.83179 .77681 L
.82708 .76709 L
.82537 .76361 L
.82229 .75738 L
.81741 .74767 L
.81566 .74422 L
.81245 .73796 L
.8074 .72824 L
.80594 .72549 L
.80225 .71853 L
.797 .70882 L
.79623 .70742 L
.79164 .69911 L
.78652 .69002 L
.78616 .68939 L
.78056 .67968 L
.77681 .67328 L
.77484 .66997 L
.76896 .66026 L
.76709 .65721 L
.76294 .65054 L
.75738 .64181 L
.75675 .64083 L
.75038 .63112 L
.74767 .62707 L
.74382 .62141 L
.73796 .61299 L
.73704 .61169 L
.73002 .60198 L
.72824 .59958 L
.72274 .59227 L
.71853 .58683 L
.71516 .58256 L
.70882 .57475 L
.70724 .57284 L
.69911 .56333 L
.69893 .56313 L
.69018 .55342 L
.68939 .55258 L
.68089 .54371 L
.67968 .54249 L
.67096 .53399 L
.66997 .53306 L
.66026 .5243 L
.66023 .52428 L
.65054 .51621 L
.64847 .51457 L
.64083 .50878 L
.63532 .50486 L
.63112 .50202 L
.62141 .49591 L
.6201 .49514 L
.61169 .49048 L
.60198 .48571 L
.60138 .48543 L
.59227 .4816 L
.58256 .47816 L
.57418 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47182 L
.54371 .47103 L
.53399 .47092 L
.52428 .47146 L
.51457 .47267 L
.50486 .47454 L
.49998 .47572 L
.49514 .47708 L
.48543 .48028 L
.47572 .48415 L
.47282 .48543 L
.46601 .48868 L
.45629 .49388 L
.4541 .49514 L
.44658 .49974 L
.43888 .50486 L
.43687 .50626 L
.42716 .51345 L
.42572 .51457 L
.41744 .52131 L
.41396 .52428 L
.40773 .52982 L
.40323 .53399 L
.39802 .53901 L
.3933 .54371 L
.38831 .54885 L
.38401 .55342 L
.37859 .55936 L
.37525 .56313 L
.36888 .57054 L
.36695 .57284 L
.35917 .58238 L
.35902 .58256 L
.35144 .59227 L
.34946 .59488 L
.34416 .60198 L
.33974 .60805 L
.33714 .61169 L
.33035 .62141 L
.33003 .62188 L
.32379 .63112 L
.32032 .63637 L
.31742 .64083 L
.31123 .65054 L
.31061 .65153 L
.3052 .66026 L
.30089 .66735 L
.29933 .66997 L
.2936 .67968 L
.29118 .68384 L
.288 .68939 L
.28252 .69911 L
.28147 .70099 L
.27716 .70882 L
.2719 .71853 L
.27176 .71881 L
.26675 .72824 L
.26204 .73729 L
.2617 .73796 L
.25673 .74767 L
.25233 .75643 L
.25186 .75738 L
.24706 .76709 L
.24262 .77624 L
.24234 .77681 L
.2377 .78652 L
.23313 .79623 L
.23291 .79671 L
.22862 .80594 L
.22418 .81566 L
.22319 .81784 L
.21981 .82537 L
.21549 .83508 L
.21348 .83964 L
.21123 .84479 L
.20702 .85451 L
.20377 .8621 L
.20287 .86422 L
.19877 .87393 L
.19471 .88364 L
.19406 .88523 L
.19071 .89336 L
.18675 .90307 L
.18434 .90902 L
.18283 .91278 L
.17896 .92249 L
.17513 .93221 L
.17463 .93347 L
.17134 .94192 L
.16758 .95163 L
.16492 .95859 L
.16387 .96134 L
.16019 .97106 L
.15655 .98077 L
F
0 g
.91754 .98077 m
.9139 .97106 L
.91278 .96808 L
.91023 .96134 L
.90651 .95163 L
.90307 .9427 L
.90277 .94192 L
.89898 .93221 L
.89515 .92249 L
.89336 .91799 L
.89128 .91278 L
.88736 .90307 L
.88364 .89394 L
.8834 .89336 L
.8794 .88364 L
.87535 .87393 L
.87393 .87056 L
.87125 .86422 L
.8671 .85451 L
.86422 .84784 L
.8629 .84479 L
.85864 .83508 L
.85451 .82578 L
.85432 .82537 L
.84994 .81566 L
.84551 .80594 L
.84479 .8044 L
.841 .79623 L
.83643 .78652 L
.83508 .78367 L
.83179 .77681 L
.82708 .76709 L
.82537 .76361 L
.82229 .75738 L
.81741 .74767 L
.81566 .74422 L
.81245 .73796 L
.8074 .72824 L
.80594 .72549 L
.80225 .71853 L
.797 .70882 L
.79623 .70742 L
.79164 .69911 L
.78652 .69002 L
.78616 .68939 L
.78056 .67968 L
.77681 .67328 L
.77484 .66997 L
.76896 .66026 L
.76709 .65721 L
Mistroke
.76294 .65054 L
.75738 .64181 L
.75675 .64083 L
.75038 .63112 L
.74767 .62707 L
.74382 .62141 L
.73796 .61299 L
.73704 .61169 L
.73002 .60198 L
.72824 .59958 L
.72274 .59227 L
.71853 .58683 L
.71516 .58256 L
.70882 .57475 L
.70724 .57284 L
.69911 .56333 L
.69893 .56313 L
.69018 .55342 L
.68939 .55258 L
.68089 .54371 L
.67968 .54249 L
.67096 .53399 L
.66997 .53306 L
.66026 .5243 L
.66023 .52428 L
.65054 .51621 L
.64847 .51457 L
.64083 .50878 L
.63532 .50486 L
.63112 .50202 L
.62141 .49591 L
.6201 .49514 L
.61169 .49048 L
.60198 .48571 L
.60138 .48543 L
.59227 .4816 L
.58256 .47816 L
.57418 .47572 L
.57284 .47538 L
.56313 .47327 L
.55342 .47182 L
.54371 .47103 L
.53399 .47092 L
.52428 .47146 L
.51457 .47267 L
.50486 .47454 L
.49998 .47572 L
.49514 .47708 L
.48543 .48028 L
.47572 .48415 L
Mistroke
.47282 .48543 L
.46601 .48868 L
.45629 .49388 L
.4541 .49514 L
.44658 .49974 L
.43888 .50486 L
.43687 .50626 L
.42716 .51345 L
.42572 .51457 L
.41744 .52131 L
.41396 .52428 L
.40773 .52982 L
.40323 .53399 L
.39802 .53901 L
.3933 .54371 L
.38831 .54885 L
.38401 .55342 L
.37859 .55936 L
.37525 .56313 L
.36888 .57054 L
.36695 .57284 L
.35917 .58238 L
.35902 .58256 L
.35144 .59227 L
.34946 .59488 L
.34416 .60198 L
.33974 .60805 L
.33714 .61169 L
.33035 .62141 L
.33003 .62188 L
.32379 .63112 L
.32032 .63637 L
.31742 .64083 L
.31123 .65054 L
.31061 .65153 L
.3052 .66026 L
.30089 .66735 L
.29933 .66997 L
.2936 .67968 L
.29118 .68384 L
.288 .68939 L
.28252 .69911 L
.28147 .70099 L
.27716 .70882 L
.2719 .71853 L
.27176 .71881 L
.26675 .72824 L
.26204 .73729 L
.2617 .73796 L
.25673 .74767 L
Mistroke
.25233 .75643 L
.25186 .75738 L
.24706 .76709 L
.24262 .77624 L
.24234 .77681 L
.2377 .78652 L
.23313 .79623 L
.23291 .79671 L
.22862 .80594 L
.22418 .81566 L
.22319 .81784 L
.21981 .82537 L
.21549 .83508 L
.21348 .83964 L
.21123 .84479 L
.20702 .85451 L
.20377 .8621 L
.20287 .86422 L
.19877 .87393 L
.19471 .88364 L
.19406 .88523 L
.19071 .89336 L
.18675 .90307 L
.18434 .90902 L
.18283 .91278 L
.17896 .92249 L
.17513 .93221 L
.17463 .93347 L
.17134 .94192 L
.16758 .95163 L
.16492 .95859 L
.16387 .96134 L
.16019 .97106 L
.15655 .98077 L
Mfstroke
.775 g
.88074 .98077 m
.8767 .97106 L
.87393 .96446 L
.87261 .96134 L
.86848 .95163 L
.86429 .94192 L
.86422 .94176 L
.86004 .93221 L
.85575 .92249 L
.85451 .91972 L
.85139 .91278 L
.84697 .90307 L
.84479 .89835 L
.84248 .89336 L
.83793 .88364 L
.83508 .87764 L
.83331 .87393 L
.82861 .86422 L
.82537 .8576 L
.82384 .85451 L
.81899 .84479 L
.81566 .83823 L
.81405 .83508 L
.80902 .82537 L
.80594 .81952 L
.8039 .81566 L
.79867 .80594 L
.79623 .80147 L
.79334 .79623 L
.7879 .78652 L
.78652 .7841 L
.78233 .77681 L
.77681 .76739 L
.77663 .76709 L
.7708 .75738 L
.76709 .75134 L
.76481 .74767 L
.75866 .73796 L
.75738 .73596 L
.75234 .72824 L
.74767 .72125 L
.74582 .71853 L
.7391 .70882 L
.73796 .7072 L
.73214 .69911 L
.72824 .69382 L
.72492 .68939 L
.71853 .68111 L
.71741 .67968 L
.70957 .66997 L
.70882 .66906 L
.70136 .66026 L
.69911 .65768 L
.69271 .65054 L
.68939 .64696 L
.68355 .64083 L
.67968 .63691 L
.67377 .63112 L
.66997 .62753 L
.66323 .62141 L
.66026 .61881 L
.65172 .61169 L
.65054 .61076 L
.64083 .60337 L
.6389 .60198 L
.63112 .59665 L
.6242 .59227 L
.62141 .5906 L
.61169 .58521 L
.60642 .58256 L
.60198 .58049 L
.59227 .57643 L
.58256 .57304 L
.58195 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56686 L
.54371 .56613 L
.53399 .56607 L
.52428 .56668 L
.51457 .56795 L
.50486 .56989 L
.49514 .57249 L
.49398 .57284 L
.48543 .57576 L
.47572 .57969 L
.4695 .58256 L
.46601 .58429 L
.45629 .58956 L
.45172 .59227 L
.44658 .59549 L
.43702 .60198 L
.43687 .60209 L
.42716 .60935 L
.4242 .61169 L
.41744 .61728 L
.41269 .62141 L
.40773 .62588 L
.40215 .63112 L
.39802 .63514 L
.39237 .64083 L
.38831 .64506 L
.3832 .65054 L
.37859 .65566 L
.37456 .66026 L
.36888 .66691 L
.36634 .66997 L
.35917 .67884 L
.3585 .67968 L
.35099 .68939 L
.34946 .69143 L
.34377 .69911 L
.33974 .70468 L
.33681 .70882 L
.33008 .71853 L
.33003 .71861 L
.32356 .72824 L
.32032 .73319 L
.31724 .73796 L
.31109 .74767 L
.31061 .74845 L
.3051 .75738 L
.30089 .76436 L
.29927 .76709 L
.29357 .77681 L
.29118 .78095 L
.288 .78652 L
.28256 .79623 L
.28147 .7982 L
.27722 .80594 L
.272 .81566 L
.27176 .81611 L
.26687 .82537 L
.26204 .83469 L
.26184 .83508 L
.2569 .84479 L
.25233 .85394 L
.25205 .85451 L
.24728 .86422 L
.24262 .87385 L
.24258 .87393 L
.23796 .88364 L
.2334 .89336 L
.23291 .89443 L
.22892 .90307 L
.2245 .91278 L
.22319 .91567 L
.22014 .92249 L
.21584 .93221 L
.21348 .93758 L
.21159 .94192 L
.2074 .95163 L
.20377 .96016 L
.20327 .96134 L
.19918 .97106 L
.19514 .98077 L
F
0 g
.88074 .98077 m
.8767 .97106 L
.87393 .96446 L
.87261 .96134 L
.86848 .95163 L
.86429 .94192 L
.86422 .94176 L
.86004 .93221 L
.85575 .92249 L
.85451 .91972 L
.85139 .91278 L
.84697 .90307 L
.84479 .89835 L
.84248 .89336 L
.83793 .88364 L
.83508 .87764 L
.83331 .87393 L
.82861 .86422 L
.82537 .8576 L
.82384 .85451 L
.81899 .84479 L
.81566 .83823 L
.81405 .83508 L
.80902 .82537 L
.80594 .81952 L
.8039 .81566 L
.79867 .80594 L
.79623 .80147 L
.79334 .79623 L
.7879 .78652 L
.78652 .7841 L
.78233 .77681 L
.77681 .76739 L
.77663 .76709 L
.7708 .75738 L
.76709 .75134 L
.76481 .74767 L
.75866 .73796 L
.75738 .73596 L
.75234 .72824 L
.74767 .72125 L
.74582 .71853 L
.7391 .70882 L
.73796 .7072 L
.73214 .69911 L
.72824 .69382 L
.72492 .68939 L
.71853 .68111 L
.71741 .67968 L
.70957 .66997 L
Mistroke
.70882 .66906 L
.70136 .66026 L
.69911 .65768 L
.69271 .65054 L
.68939 .64696 L
.68355 .64083 L
.67968 .63691 L
.67377 .63112 L
.66997 .62753 L
.66323 .62141 L
.66026 .61881 L
.65172 .61169 L
.65054 .61076 L
.64083 .60337 L
.6389 .60198 L
.63112 .59665 L
.6242 .59227 L
.62141 .5906 L
.61169 .58521 L
.60642 .58256 L
.60198 .58049 L
.59227 .57643 L
.58256 .57304 L
.58195 .57284 L
.57284 .57031 L
.56313 .56825 L
.55342 .56686 L
.54371 .56613 L
.53399 .56607 L
.52428 .56668 L
.51457 .56795 L
.50486 .56989 L
.49514 .57249 L
.49398 .57284 L
.48543 .57576 L
.47572 .57969 L
.4695 .58256 L
.46601 .58429 L
.45629 .58956 L
.45172 .59227 L
.44658 .59549 L
.43702 .60198 L
.43687 .60209 L
.42716 .60935 L
.4242 .61169 L
.41744 .61728 L
.41269 .62141 L
.40773 .62588 L
.40215 .63112 L
.39802 .63514 L
Mistroke
.39237 .64083 L
.38831 .64506 L
.3832 .65054 L
.37859 .65566 L
.37456 .66026 L
.36888 .66691 L
.36634 .66997 L
.35917 .67884 L
.3585 .67968 L
.35099 .68939 L
.34946 .69143 L
.34377 .69911 L
.33974 .70468 L
.33681 .70882 L
.33008 .71853 L
.33003 .71861 L
.32356 .72824 L
.32032 .73319 L
.31724 .73796 L
.31109 .74767 L
.31061 .74845 L
.3051 .75738 L
.30089 .76436 L
.29927 .76709 L
.29357 .77681 L
.29118 .78095 L
.288 .78652 L
.28256 .79623 L
.28147 .7982 L
.27722 .80594 L
.272 .81566 L
.27176 .81611 L
.26687 .82537 L
.26204 .83469 L
.26184 .83508 L
.2569 .84479 L
.25233 .85394 L
.25205 .85451 L
.24728 .86422 L
.24262 .87385 L
.24258 .87393 L
.23796 .88364 L
.2334 .89336 L
.23291 .89443 L
.22892 .90307 L
.2245 .91278 L
.22319 .91567 L
.22014 .92249 L
.21584 .93221 L
.21348 .93758 L
Mistroke
.21159 .94192 L
.2074 .95163 L
.20377 .96016 L
.20327 .96134 L
.19918 .97106 L
.19514 .98077 L
Mfstroke
.7 g
.84691 .98077 m
.84479 .97617 L
.84243 .97106 L
.83787 .96134 L
.83508 .95547 L
.83325 .95163 L
.82855 .94192 L
.82537 .93544 L
.82377 .93221 L
.81891 .92249 L
.81566 .91607 L
.81397 .91278 L
.80894 .90307 L
.80594 .89738 L
.80381 .89336 L
.79858 .88364 L
.79623 .87935 L
.79324 .87393 L
.78779 .86422 L
.78652 .86199 L
.78222 .85451 L
.77681 .84529 L
.77651 .84479 L
.77067 .83508 L
.76709 .82926 L
.76467 .82537 L
.75852 .81566 L
.75738 .8139 L
.75218 .80594 L
.74767 .7992 L
.74565 .79623 L
.73891 .78652 L
.73796 .78517 L
.73193 .77681 L
.72824 .77181 L
.7247 .76709 L
.71853 .75911 L
.71717 .75738 L
.7093 .74767 L
.70882 .74708 L
.70106 .73796 L
.69911 .73572 L
.69238 .72824 L
.68939 .72502 L
.68318 .71853 L
.67968 .715 L
.67335 .70882 L
.66997 .70563 L
.66275 .69911 L
.66026 .69694 L
.65115 .68939 L
.65054 .68891 L
.64083 .68155 L
.63822 .67968 L
.63112 .67485 L
.62334 .66997 L
.62141 .66882 L
.61169 .66346 L
.60522 .66026 L
.60198 .65877 L
.59227 .65474 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64665 L
.55342 .64529 L
.54371 .6446 L
.53399 .64457 L
.52428 .64521 L
.51457 .64651 L
.50486 .64848 L
.49704 .65054 L
.49514 .65112 L
.48543 .65443 L
.47572 .6584 L
.47165 .66026 L
.46601 .66304 L
.45629 .66834 L
.45353 .66997 L
.44658 .67431 L
.43865 .67968 L
.43687 .68095 L
.42716 .68826 L
.42572 .68939 L
.41744 .69623 L
.41412 .69911 L
.40773 .70487 L
.40352 .70882 L
.39802 .71417 L
.39369 .71853 L
.38831 .72414 L
.38449 .72824 L
.37859 .73478 L
.3758 .73796 L
.36888 .74608 L
.36756 .74767 L
.3597 .75738 L
.35917 .75805 L
.35217 .76709 L
.34946 .77069 L
.34493 .77681 L
.33974 .784 L
.33796 .78652 L
.33121 .79623 L
.33003 .79797 L
.32468 .80594 L
.32032 .8126 L
.31835 .81566 L
.31219 .82537 L
.31061 .82791 L
.30619 .83508 L
.30089 .84388 L
.30035 .84479 L
.29464 .85451 L
.29118 .86052 L
.28907 .86422 L
.28362 .87393 L
.28147 .87782 L
.27828 .88364 L
.27305 .89336 L
.27176 .89579 L
.26792 .90307 L
.26289 .91278 L
.26204 .91443 L
.25794 .92249 L
.25308 .93221 L
.25233 .93373 L
.24831 .94192 L
.24361 .95163 L
.24262 .9537 L
.23898 .96134 L
.23443 .97106 L
.23291 .97433 L
.22994 .98077 L
F
0 g
.84691 .98077 m
.84479 .97617 L
.84243 .97106 L
.83787 .96134 L
.83508 .95547 L
.83325 .95163 L
.82855 .94192 L
.82537 .93544 L
.82377 .93221 L
.81891 .92249 L
.81566 .91607 L
.81397 .91278 L
.80894 .90307 L
.80594 .89738 L
.80381 .89336 L
.79858 .88364 L
.79623 .87935 L
.79324 .87393 L
.78779 .86422 L
.78652 .86199 L
.78222 .85451 L
.77681 .84529 L
.77651 .84479 L
.77067 .83508 L
.76709 .82926 L
.76467 .82537 L
.75852 .81566 L
.75738 .8139 L
.75218 .80594 L
.74767 .7992 L
.74565 .79623 L
.73891 .78652 L
.73796 .78517 L
.73193 .77681 L
.72824 .77181 L
.7247 .76709 L
.71853 .75911 L
.71717 .75738 L
.7093 .74767 L
.70882 .74708 L
.70106 .73796 L
.69911 .73572 L
.69238 .72824 L
.68939 .72502 L
.68318 .71853 L
.67968 .715 L
.67335 .70882 L
.66997 .70563 L
.66275 .69911 L
.66026 .69694 L
Mistroke
.65115 .68939 L
.65054 .68891 L
.64083 .68155 L
.63822 .67968 L
.63112 .67485 L
.62334 .66997 L
.62141 .66882 L
.61169 .66346 L
.60522 .66026 L
.60198 .65877 L
.59227 .65474 L
.58256 .65138 L
.57984 .65054 L
.57284 .64868 L
.56313 .64665 L
.55342 .64529 L
.54371 .6446 L
.53399 .64457 L
.52428 .64521 L
.51457 .64651 L
.50486 .64848 L
.49704 .65054 L
.49514 .65112 L
.48543 .65443 L
.47572 .6584 L
.47165 .66026 L
.46601 .66304 L
.45629 .66834 L
.45353 .66997 L
.44658 .67431 L
.43865 .67968 L
.43687 .68095 L
.42716 .68826 L
.42572 .68939 L
.41744 .69623 L
.41412 .69911 L
.40773 .70487 L
.40352 .70882 L
.39802 .71417 L
.39369 .71853 L
.38831 .72414 L
.38449 .72824 L
.37859 .73478 L
.3758 .73796 L
.36888 .74608 L
.36756 .74767 L
.3597 .75738 L
.35917 .75805 L
.35217 .76709 L
.34946 .77069 L
Mistroke
.34493 .77681 L
.33974 .784 L
.33796 .78652 L
.33121 .79623 L
.33003 .79797 L
.32468 .80594 L
.32032 .8126 L
.31835 .81566 L
.31219 .82537 L
.31061 .82791 L
.30619 .83508 L
.30089 .84388 L
.30035 .84479 L
.29464 .85451 L
.29118 .86052 L
.28907 .86422 L
.28362 .87393 L
.28147 .87782 L
.27828 .88364 L
.27305 .89336 L
.27176 .89579 L
.26792 .90307 L
.26289 .91278 L
.26204 .91443 L
.25794 .92249 L
.25308 .93221 L
.25233 .93373 L
.24831 .94192 L
.24361 .95163 L
.24262 .9537 L
.23898 .96134 L
.23443 .97106 L
.23291 .97433 L
.22994 .98077 L
Mfstroke
.625 g
.81399 .98077 m
.80896 .97106 L
.80594 .96533 L
.80383 .96134 L
.7986 .95163 L
.79623 .94731 L
.79326 .94192 L
.7878 .93221 L
.78652 .92995 L
.78223 .92249 L
.77681 .91327 L
.77652 .91278 L
.77067 .90307 L
.76709 .89725 L
.76467 .89336 L
.75851 .88364 L
.75738 .88189 L
.75217 .87393 L
.74767 .86721 L
.74564 .86422 L
.73889 .85451 L
.73796 .85319 L
.73191 .84479 L
.72824 .83984 L
.72466 .83508 L
.71853 .82716 L
.71712 .82537 L
.70925 .81566 L
.70882 .81514 L
.70099 .80594 L
.69911 .80379 L
.6923 .79623 L
.68939 .79311 L
.68308 .78652 L
.67968 .78309 L
.67323 .77681 L
.66997 .77375 L
.6626 .76709 L
.66026 .76507 L
.65096 .75738 L
.65054 .75705 L
.64083 .74971 L
.63797 .74767 L
.63112 .74303 L
.623 .73796 L
.62141 .73702 L
.61169 .73167 L
.60472 .72824 L
.60198 .72699 L
.59227 .72298 L
.58256 .71964 L
.57886 .71853 L
.57284 .71697 L
.56313 .71496 L
.55342 .71362 L
.54371 .71294 L
.53399 .71294 L
.52428 .7136 L
.51457 .71492 L
.50486 .71692 L
.49864 .71853 L
.49514 .71958 L
.48543 .72291 L
.47572 .72691 L
.47278 .72824 L
.46601 .73157 L
.45629 .7369 L
.4545 .73796 L
.44658 .7429 L
.43953 .74767 L
.43687 .74956 L
.42716 .75689 L
.42654 .75738 L
.41744 .76489 L
.4149 .76709 L
.40773 .77356 L
.40427 .77681 L
.39802 .78289 L
.39442 .78652 L
.38831 .79289 L
.3852 .79623 L
.37859 .80356 L
.3765 .80594 L
.36888 .8149 L
.36825 .81566 L
.36038 .82537 L
.35917 .8269 L
.35284 .83508 L
.34946 .83957 L
.34559 .84479 L
.33974 .8529 L
.33861 .85451 L
.33186 .86422 L
.33003 .86691 L
.32532 .87393 L
.32032 .88158 L
.31898 .88364 L
.31282 .89336 L
.31061 .89691 L
.30682 .90307 L
.30097 .91278 L
.30089 .91292 L
.29527 .92249 L
.29118 .92959 L
.28969 .93221 L
.28424 .94192 L
.28147 .94693 L
.2789 .95163 L
.27366 .96134 L
.27176 .96493 L
.26853 .97106 L
.2635 .98077 L
F
0 g
.81399 .98077 m
.80896 .97106 L
.80594 .96533 L
.80383 .96134 L
.7986 .95163 L
.79623 .94731 L
.79326 .94192 L
.7878 .93221 L
.78652 .92995 L
.78223 .92249 L
.77681 .91327 L
.77652 .91278 L
.77067 .90307 L
.76709 .89725 L
.76467 .89336 L
.75851 .88364 L
.75738 .88189 L
.75217 .87393 L
.74767 .86721 L
.74564 .86422 L
.73889 .85451 L
.73796 .85319 L
.73191 .84479 L
.72824 .83984 L
.72466 .83508 L
.71853 .82716 L
.71712 .82537 L
.70925 .81566 L
.70882 .81514 L
.70099 .80594 L
.69911 .80379 L
.6923 .79623 L
.68939 .79311 L
.68308 .78652 L
.67968 .78309 L
.67323 .77681 L
.66997 .77375 L
.6626 .76709 L
.66026 .76507 L
.65096 .75738 L
.65054 .75705 L
.64083 .74971 L
.63797 .74767 L
.63112 .74303 L
.623 .73796 L
.62141 .73702 L
.61169 .73167 L
.60472 .72824 L
.60198 .72699 L
.59227 .72298 L
Mistroke
.58256 .71964 L
.57886 .71853 L
.57284 .71697 L
.56313 .71496 L
.55342 .71362 L
.54371 .71294 L
.53399 .71294 L
.52428 .7136 L
.51457 .71492 L
.50486 .71692 L
.49864 .71853 L
.49514 .71958 L
.48543 .72291 L
.47572 .72691 L
.47278 .72824 L
.46601 .73157 L
.45629 .7369 L
.4545 .73796 L
.44658 .7429 L
.43953 .74767 L
.43687 .74956 L
.42716 .75689 L
.42654 .75738 L
.41744 .76489 L
.4149 .76709 L
.40773 .77356 L
.40427 .77681 L
.39802 .78289 L
.39442 .78652 L
.38831 .79289 L
.3852 .79623 L
.37859 .80356 L
.3765 .80594 L
.36888 .8149 L
.36825 .81566 L
.36038 .82537 L
.35917 .8269 L
.35284 .83508 L
.34946 .83957 L
.34559 .84479 L
.33974 .8529 L
.33861 .85451 L
.33186 .86422 L
.33003 .86691 L
.32532 .87393 L
.32032 .88158 L
.31898 .88364 L
.31282 .89336 L
.31061 .89691 L
.30682 .90307 L
Mistroke
.30097 .91278 L
.30089 .91292 L
.29527 .92249 L
.29118 .92959 L
.28969 .93221 L
.28424 .94192 L
.28147 .94693 L
.2789 .95163 L
.27366 .96134 L
.27176 .96493 L
.26853 .97106 L
.2635 .98077 L
Mfstroke
.55 g
.78059 .98077 m
.77681 .97436 L
.77484 .97106 L
.76895 .96134 L
.76709 .95834 L
.7629 .95163 L
.75738 .943 L
.75668 .94192 L
.75028 .93221 L
.74767 .92832 L
.74369 .92249 L
.73796 .91431 L
.73687 .91278 L
.72981 .90307 L
.72824 .90097 L
.72247 .89336 L
.71853 .88829 L
.71483 .88364 L
.70882 .87629 L
.70685 .87393 L
.69911 .86495 L
.69846 .86422 L
.68961 .85451 L
.68939 .85428 L
.68021 .84479 L
.67968 .84427 L
.67013 .83508 L
.66997 .83493 L
.66026 .82627 L
.65921 .82537 L
.65054 .81826 L
.64719 .81566 L
.64083 .81093 L
.63367 .80594 L
.63112 .80426 L
.62141 .79826 L
.61785 .79623 L
.61169 .79293 L
.60198 .78827 L
.59794 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77828 L
.56612 .77681 L
.56313 .77629 L
.55342 .77496 L
.54371 .7743 L
.53399 .77431 L
.52428 .77499 L
.51457 .77633 L
.51185 .77681 L
.50486 .77834 L
.49514 .78102 L
.48543 .78437 L
.48001 .78652 L
.47572 .78838 L
.46601 .79306 L
.4601 .79623 L
.45629 .79841 L
.44658 .80443 L
.44429 .80594 L
.43687 .81111 L
.43076 .81566 L
.42716 .81846 L
.41874 .82537 L
.41744 .82648 L
.40782 .83508 L
.40773 .83517 L
.39802 .84452 L
.39775 .84479 L
.38834 .85451 L
.38831 .85454 L
.37949 .86422 L
.37859 .86523 L
.3711 .87393 L
.36888 .87659 L
.36312 .88364 L
.35917 .88861 L
.35548 .89336 L
.34946 .9013 L
.34814 .90307 L
.34108 .91278 L
.33974 .91466 L
.33426 .92249 L
.33003 .92869 L
.32767 .93221 L
.32127 .94192 L
.32032 .94338 L
.31505 .95163 L
.31061 .95874 L
.309 .96134 L
.30311 .97106 L
.30089 .97477 L
.29736 .98077 L
F
0 g
.78059 .98077 m
.77681 .97436 L
.77484 .97106 L
.76895 .96134 L
.76709 .95834 L
.7629 .95163 L
.75738 .943 L
.75668 .94192 L
.75028 .93221 L
.74767 .92832 L
.74369 .92249 L
.73796 .91431 L
.73687 .91278 L
.72981 .90307 L
.72824 .90097 L
.72247 .89336 L
.71853 .88829 L
.71483 .88364 L
.70882 .87629 L
.70685 .87393 L
.69911 .86495 L
.69846 .86422 L
.68961 .85451 L
.68939 .85428 L
.68021 .84479 L
.67968 .84427 L
.67013 .83508 L
.66997 .83493 L
.66026 .82627 L
.65921 .82537 L
.65054 .81826 L
.64719 .81566 L
.64083 .81093 L
.63367 .80594 L
.63112 .80426 L
.62141 .79826 L
.61785 .79623 L
.61169 .79293 L
.60198 .78827 L
.59794 .78652 L
.59227 .78427 L
.58256 .78094 L
.57284 .77828 L
.56612 .77681 L
.56313 .77629 L
.55342 .77496 L
.54371 .7743 L
.53399 .77431 L
.52428 .77499 L
.51457 .77633 L
Mistroke
.51185 .77681 L
.50486 .77834 L
.49514 .78102 L
.48543 .78437 L
.48001 .78652 L
.47572 .78838 L
.46601 .79306 L
.4601 .79623 L
.45629 .79841 L
.44658 .80443 L
.44429 .80594 L
.43687 .81111 L
.43076 .81566 L
.42716 .81846 L
.41874 .82537 L
.41744 .82648 L
.40782 .83508 L
.40773 .83517 L
.39802 .84452 L
.39775 .84479 L
.38834 .85451 L
.38831 .85454 L
.37949 .86422 L
.37859 .86523 L
.3711 .87393 L
.36888 .87659 L
.36312 .88364 L
.35917 .88861 L
.35548 .89336 L
.34946 .9013 L
.34814 .90307 L
.34108 .91278 L
.33974 .91466 L
.33426 .92249 L
.33003 .92869 L
.32767 .93221 L
.32127 .94192 L
.32032 .94338 L
.31505 .95163 L
.31061 .95874 L
.309 .96134 L
.30311 .97106 L
.30089 .97477 L
.29736 .98077 L
Mfstroke
.475 g
.74527 .98077 m
.7385 .97106 L
.73796 .97029 L
.7315 .96134 L
.72824 .95695 L
.72423 .95163 L
.71853 .94428 L
.71666 .94192 L
.70882 .93228 L
.70876 .93221 L
.70046 .92249 L
.69911 .92095 L
.69172 .91278 L
.68939 .91029 L
.68245 .90307 L
.67968 .90029 L
.67253 .89336 L
.66997 .89096 L
.66182 .88364 L
.66026 .8823 L
.65054 .87431 L
.65007 .87393 L
.64083 .86698 L
.63692 .86422 L
.63112 .86032 L
.6217 .85451 L
.62141 .85433 L
.61169 .84901 L
.60296 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57562 .83508 L
.57284 .8344 L
.56313 .83242 L
.55342 .8311 L
.54371 .83046 L
.53399 .83048 L
.52428 .83117 L
.51457 .83252 L
.50486 .83455 L
.50269 .83508 L
.49514 .83724 L
.48543 .8406 L
.47572 .84463 L
.47534 .84479 L
.46601 .84932 L
.4566 .85451 L
.45629 .85468 L
.44658 .86072 L
.44138 .86422 L
.43687 .86741 L
.42823 .87393 L
.42716 .87478 L
.41744 .88281 L
.41648 .88364 L
.40773 .89152 L
.40577 .89336 L
.39802 .90089 L
.39585 .90307 L
.38831 .91092 L
.38658 .91278 L
.37859 .92163 L
.37783 .92249 L
.36954 .93221 L
.36888 .933 L
.36164 .94192 L
.35917 .94504 L
.35407 .95163 L
.34946 .95775 L
.3468 .96134 L
.33979 .97106 L
.33974 .97113 L
.33303 .98077 L
F
0 g
.74527 .98077 m
.7385 .97106 L
.73796 .97029 L
.7315 .96134 L
.72824 .95695 L
.72423 .95163 L
.71853 .94428 L
.71666 .94192 L
.70882 .93228 L
.70876 .93221 L
.70046 .92249 L
.69911 .92095 L
.69172 .91278 L
.68939 .91029 L
.68245 .90307 L
.67968 .90029 L
.67253 .89336 L
.66997 .89096 L
.66182 .88364 L
.66026 .8823 L
.65054 .87431 L
.65007 .87393 L
.64083 .86698 L
.63692 .86422 L
.63112 .86032 L
.6217 .85451 L
.62141 .85433 L
.61169 .84901 L
.60296 .84479 L
.60198 .84436 L
.59227 .84037 L
.58256 .83705 L
.57562 .83508 L
.57284 .8344 L
.56313 .83242 L
.55342 .8311 L
.54371 .83046 L
.53399 .83048 L
.52428 .83117 L
.51457 .83252 L
.50486 .83455 L
.50269 .83508 L
.49514 .83724 L
.48543 .8406 L
.47572 .84463 L
.47534 .84479 L
.46601 .84932 L
.4566 .85451 L
.45629 .85468 L
.44658 .86072 L
Mistroke
.44138 .86422 L
.43687 .86741 L
.42823 .87393 L
.42716 .87478 L
.41744 .88281 L
.41648 .88364 L
.40773 .89152 L
.40577 .89336 L
.39802 .90089 L
.39585 .90307 L
.38831 .91092 L
.38658 .91278 L
.37859 .92163 L
.37783 .92249 L
.36954 .93221 L
.36888 .933 L
.36164 .94192 L
.35917 .94504 L
.35407 .95163 L
.34946 .95775 L
.3468 .96134 L
.33979 .97106 L
.33974 .97113 L
.33303 .98077 L
Mfstroke
.4 g
.7059 .98077 m
.69911 .97292 L
.69746 .97106 L
.68939 .96226 L
.68853 .96134 L
.67968 .95227 L
.67904 .95163 L
.66997 .94294 L
.66886 .94192 L
.66026 .93429 L
.6578 .93221 L
.65054 .9263 L
.6456 .92249 L
.64083 .91899 L
.6318 .91278 L
.63112 .91234 L
.62141 .90635 L
.61556 .90307 L
.61169 .90104 L
.60198 .89639 L
.59473 .89336 L
.59227 .89242 L
.58256 .88911 L
.57284 .88646 L
.56313 .88449 L
.55805 .88364 L
.55342 .88318 L
.54371 .88255 L
.53399 .88258 L
.52428 .88327 L
.52069 .88364 L
.51457 .88464 L
.50486 .88667 L
.49514 .88938 L
.48543 .89275 L
.48385 .89336 L
.47572 .89679 L
.46601 .90149 L
.46302 .90307 L
.45629 .90687 L
.44677 .91278 L
.44658 .91291 L
.43687 .91962 L
.43298 .92249 L
.42716 .927 L
.42077 .93221 L
.41744 .93504 L
.40972 .94192 L
.40773 .94376 L
.39953 .95163 L
.39802 .95314 L
.39004 .96134 L
.38831 .96319 L
.38112 .97106 L
.37859 .97391 L
.37267 .98077 L
F
0 g
.7059 .98077 m
.69911 .97292 L
.69746 .97106 L
.68939 .96226 L
.68853 .96134 L
.67968 .95227 L
.67904 .95163 L
.66997 .94294 L
.66886 .94192 L
.66026 .93429 L
.6578 .93221 L
.65054 .9263 L
.6456 .92249 L
.64083 .91899 L
.6318 .91278 L
.63112 .91234 L
.62141 .90635 L
.61556 .90307 L
.61169 .90104 L
.60198 .89639 L
.59473 .89336 L
.59227 .89242 L
.58256 .88911 L
.57284 .88646 L
.56313 .88449 L
.55805 .88364 L
.55342 .88318 L
.54371 .88255 L
.53399 .88258 L
.52428 .88327 L
.52069 .88364 L
.51457 .88464 L
.50486 .88667 L
.49514 .88938 L
.48543 .89275 L
.48385 .89336 L
.47572 .89679 L
.46601 .90149 L
.46302 .90307 L
.45629 .90687 L
.44677 .91278 L
.44658 .91291 L
.43687 .91962 L
.43298 .92249 L
.42716 .927 L
.42077 .93221 L
.41744 .93504 L
.40972 .94192 L
.40773 .94376 L
.39953 .95163 L
Mistroke
.39802 .95314 L
.39004 .96134 L
.38831 .96319 L
.38112 .97106 L
.37859 .97391 L
.37267 .98077 L
Mfstroke
.325 g
.65762 .98077 m
.65054 .97502 L
.64539 .97106 L
.64083 .96771 L
.63154 .96134 L
.63112 .96107 L
.62141 .95509 L
.61522 .95163 L
.61169 .94978 L
.60198 .94514 L
.59423 .94192 L
.59227 .94117 L
.58256 .93787 L
.57284 .93524 L
.56313 .93327 L
.55603 .93221 L
.55342 .93197 L
.54371 .93134 L
.53399 .93138 L
.52428 .93208 L
.523 .93221 L
.51457 .93346 L
.50486 .9355 L
.49514 .93821 L
.48543 .94159 L
.48457 .94192 L
.47572 .94564 L
.46601 .95035 L
.46358 .95163 L
.45629 .95574 L
.44726 .96134 L
.44658 .96179 L
.43687 .96851 L
.43342 .97106 L
.42716 .9759 L
.42118 .98077 L
F
0 g
.65762 .98077 m
.65054 .97502 L
.64539 .97106 L
.64083 .96771 L
.63154 .96134 L
.63112 .96107 L
.62141 .95509 L
.61522 .95163 L
.61169 .94978 L
.60198 .94514 L
.59423 .94192 L
.59227 .94117 L
.58256 .93787 L
.57284 .93524 L
.56313 .93327 L
.55603 .93221 L
.55342 .93197 L
.54371 .93134 L
.53399 .93138 L
.52428 .93208 L
.523 .93221 L
.51457 .93346 L
.50486 .9355 L
.49514 .93821 L
.48543 .94159 L
.48457 .94192 L
.47572 .94564 L
.46601 .95035 L
.46358 .95163 L
.45629 .95574 L
.44726 .96134 L
.44658 .96179 L
.43687 .96851 L
.43342 .97106 L
.42716 .9759 L
.42118 .98077 L
s
.25 g
.57075 .98077 m
.56313 .97931 L
.55342 .97802 L
.54371 .9774 L
.53399 .97744 L
.52428 .97815 L
.51457 .97953 L
.50823 .98077 L
F
0 g
.57075 .98077 m
.56313 .97931 L
.55342 .97802 L
.54371 .9774 L
.53399 .97744 L
.52428 .97815 L
.51457 .97953 L
.50823 .98077 L
s
.925 g
.98077 .55685 m
.97966 .55342 L
.97652 .54371 L
.97339 .53399 L
.97106 .52682 L
.97023 .52428 L
.96704 .51457 L
.96382 .50486 L
.96134 .49747 L
.96057 .49514 L
.9573 .48543 L
.954 .47572 L
.95163 .46879 L
.95068 .46601 L
.94733 .45629 L
.94395 .44658 L
.94192 .4408 L
.94054 .43687 L
.9371 .42716 L
.93363 .41744 L
.93221 .41349 L
.93013 .40773 L
.9266 .39802 L
.92303 .38831 L
.92249 .38686 L
.91943 .37859 L
.91579 .36888 L
.91278 .36092 L
.91212 .35917 L
.90841 .34946 L
.90466 .33974 L
.90307 .33565 L
.90088 .33003 L
.89705 .32032 L
.89336 .31106 L
.89318 .31061 L
.88927 .30089 L
.8853 .29118 L
.88364 .28715 L
.8813 .28147 L
.87724 .27176 L
.87393 .26392 L
.87313 .26204 L
.86898 .25233 L
.86476 .24262 L
.86422 .24138 L
.8605 .23291 L
.85617 .22319 L
.85451 .21951 L
.85178 .21348 L
.84732 .20377 L
.84479 .19832 L
.8428 .19406 L
.83821 .18434 L
.83508 .17782 L
.83354 .17463 L
.8288 .16492 L
.82537 .15799 L
.82398 .15521 L
.81907 .14549 L
.81566 .13885 L
.81407 .13578 L
.80898 .12607 L
.80594 .12038 L
.80378 .11636 L
.79847 .10664 L
.79623 .1026 L
.79306 .09693 L
.78751 .08722 L
.78652 .0855 L
.78185 .07751 L
.77681 .06908 L
.77603 .06779 L
.77007 .05808 L
.76709 .05333 L
.76394 .04837 L
.75763 .03866 L
.75738 .03827 L
.75114 .02894 L
.74767 .02389 L
.74442 .01923 L
.98077 .01923 L
F
0 g
.98077 .55685 m
.97966 .55342 L
.97652 .54371 L
.97339 .53399 L
.97106 .52682 L
.97023 .52428 L
.96704 .51457 L
.96382 .50486 L
.96134 .49747 L
.96057 .49514 L
.9573 .48543 L
.954 .47572 L
.95163 .46879 L
.95068 .46601 L
.94733 .45629 L
.94395 .44658 L
.94192 .4408 L
.94054 .43687 L
.9371 .42716 L
.93363 .41744 L
.93221 .41349 L
.93013 .40773 L
.9266 .39802 L
.92303 .38831 L
.92249 .38686 L
.91943 .37859 L
.91579 .36888 L
.91278 .36092 L
.91212 .35917 L
.90841 .34946 L
.90466 .33974 L
.90307 .33565 L
.90088 .33003 L
.89705 .32032 L
.89336 .31106 L
.89318 .31061 L
.88927 .30089 L
.8853 .29118 L
.88364 .28715 L
.8813 .28147 L
.87724 .27176 L
.87393 .26392 L
.87313 .26204 L
.86898 .25233 L
.86476 .24262 L
.86422 .24138 L
.8605 .23291 L
.85617 .22319 L
.85451 .21951 L
.85178 .21348 L
Mistroke
.84732 .20377 L
.84479 .19832 L
.8428 .19406 L
.83821 .18434 L
.83508 .17782 L
.83354 .17463 L
.8288 .16492 L
.82537 .15799 L
.82398 .15521 L
.81907 .14549 L
.81566 .13885 L
.81407 .13578 L
.80898 .12607 L
.80594 .12038 L
.80378 .11636 L
.79847 .10664 L
.79623 .1026 L
.79306 .09693 L
.78751 .08722 L
.78652 .0855 L
.78185 .07751 L
.77681 .06908 L
.77603 .06779 L
.77007 .05808 L
.76709 .05333 L
.76394 .04837 L
.75763 .03866 L
.75738 .03827 L
.75114 .02894 L
.74767 .02389 L
.74442 .01923 L
Mfstroke
.85 g
.98077 .42872 m
.98027 .42716 L
.97714 .41744 L
.974 .40773 L
.97106 .39869 L
.97084 .39802 L
.96765 .38831 L
.96443 .37859 L
.96134 .36934 L
.96119 .36888 L
.95793 .35917 L
.95464 .34946 L
.95163 .34066 L
.95132 .33974 L
.94797 .33003 L
.9446 .32032 L
.94192 .31266 L
.9412 .31061 L
.93777 .30089 L
.93431 .29118 L
.93221 .28534 L
.93081 .28147 L
.92729 .27176 L
.92373 .26204 L
.92249 .25869 L
.92014 .25233 L
.91651 .24262 L
.91285 .23291 L
.91278 .23272 L
.90915 .22319 L
.90542 .21348 L
.90307 .20743 L
.90164 .20377 L
.89783 .19406 L
.89397 .18434 L
.89336 .18282 L
.89007 .17463 L
.88612 .16492 L
.88364 .15888 L
.88213 .15521 L
.87809 .14549 L
.874 .13578 L
.87393 .13562 L
.86986 .12607 L
.86567 .11636 L
.86422 .11303 L
.86142 .10664 L
.85711 .09693 L
.85451 .09113 L
.85274 .08722 L
.84831 .07751 L
.84479 .0699 L
.84381 .06779 L
.83925 .05808 L
.83508 .04935 L
.83461 .04837 L
.8299 .03866 L
.82537 .02947 L
.82511 .02894 L
.82023 .01923 L
.98077 .01923 L
F
0 g
.98077 .42872 m
.98027 .42716 L
.97714 .41744 L
.974 .40773 L
.97106 .39869 L
.97084 .39802 L
.96765 .38831 L
.96443 .37859 L
.96134 .36934 L
.96119 .36888 L
.95793 .35917 L
.95464 .34946 L
.95163 .34066 L
.95132 .33974 L
.94797 .33003 L
.9446 .32032 L
.94192 .31266 L
.9412 .31061 L
.93777 .30089 L
.93431 .29118 L
.93221 .28534 L
.93081 .28147 L
.92729 .27176 L
.92373 .26204 L
.92249 .25869 L
.92014 .25233 L
.91651 .24262 L
.91285 .23291 L
.91278 .23272 L
.90915 .22319 L
.90542 .21348 L
.90307 .20743 L
.90164 .20377 L
.89783 .19406 L
.89397 .18434 L
.89336 .18282 L
.89007 .17463 L
.88612 .16492 L
.88364 .15888 L
.88213 .15521 L
.87809 .14549 L
.874 .13578 L
.87393 .13562 L
.86986 .12607 L
.86567 .11636 L
.86422 .11303 L
.86142 .10664 L
.85711 .09693 L
.85451 .09113 L
.85274 .08722 L
Mistroke
.84831 .07751 L
.84479 .0699 L
.84381 .06779 L
.83925 .05808 L
.83508 .04935 L
.83461 .04837 L
.8299 .03866 L
.82537 .02947 L
.82511 .02894 L
.82023 .01923 L
Mfstroke
.775 g
.98077 .33489 m
.97921 .33003 L
.97608 .32032 L
.97293 .31061 L
.97106 .30485 L
.96976 .30089 L
.96656 .29118 L
.96334 .28147 L
.96134 .2755 L
.96009 .27176 L
.95682 .26204 L
.95352 .25233 L
.95163 .24682 L
.95019 .24262 L
.94684 .23291 L
.94345 .22319 L
.94192 .21881 L
.94004 .21348 L
.9366 .20377 L
.93313 .19406 L
.93221 .19149 L
.92963 .18434 L
.92609 .17463 L
.92253 .16492 L
.92249 .16483 L
.91892 .15521 L
.91529 .14549 L
.91278 .13886 L
.91161 .13578 L
.90791 .12607 L
.90416 .11636 L
.90307 .11356 L
.90037 .10664 L
.89654 .09693 L
.89336 .08893 L
.89267 .08722 L
.88876 .07751 L
.8848 .06779 L
.88364 .06498 L
.88079 .05808 L
.87674 .04837 L
.87393 .04171 L
.87264 .03866 L
.86848 .02894 L
.86427 .01923 L
.98077 .01923 L
F
0 g
.98077 .33489 m
.97921 .33003 L
.97608 .32032 L
.97293 .31061 L
.97106 .30485 L
.96976 .30089 L
.96656 .29118 L
.96334 .28147 L
.96134 .2755 L
.96009 .27176 L
.95682 .26204 L
.95352 .25233 L
.95163 .24682 L
.95019 .24262 L
.94684 .23291 L
.94345 .22319 L
.94192 .21881 L
.94004 .21348 L
.9366 .20377 L
.93313 .19406 L
.93221 .19149 L
.92963 .18434 L
.92609 .17463 L
.92253 .16492 L
.92249 .16483 L
.91892 .15521 L
.91529 .14549 L
.91278 .13886 L
.91161 .13578 L
.90791 .12607 L
.90416 .11636 L
.90307 .11356 L
.90037 .10664 L
.89654 .09693 L
.89336 .08893 L
.89267 .08722 L
.88876 .07751 L
.8848 .06779 L
.88364 .06498 L
.88079 .05808 L
.87674 .04837 L
.87393 .04171 L
.87264 .03866 L
.86848 .02894 L
.86427 .01923 L
s
.7 g
.98077 .25713 m
.97923 .25233 L
.9761 .24262 L
.97295 .23291 L
.97106 .2271 L
.96978 .22319 L
.96658 .21348 L
.96336 .20377 L
.96134 .19774 L
.96011 .19406 L
.95684 .18434 L
.95354 .17463 L
.95163 .16906 L
.95021 .16492 L
.94686 .15521 L
.94347 .14549 L
.94192 .14106 L
.94006 .13578 L
.93662 .12607 L
.93315 .11636 L
.93221 .11373 L
.92965 .10664 L
.92612 .09693 L
.92255 .08722 L
.92249 .08707 L
.91895 .07751 L
.91531 .06779 L
.91278 .06109 L
.91164 .05808 L
.90793 .04837 L
.90418 .03866 L
.90307 .03578 L
.9004 .02894 L
.89657 .01923 L
.98077 .01923 L
F
0 g
.98077 .25713 m
.97923 .25233 L
.9761 .24262 L
.97295 .23291 L
.97106 .2271 L
.96978 .22319 L
.96658 .21348 L
.96336 .20377 L
.96134 .19774 L
.96011 .19406 L
.95684 .18434 L
.95354 .17463 L
.95163 .16906 L
.95021 .16492 L
.94686 .15521 L
.94347 .14549 L
.94192 .14106 L
.94006 .13578 L
.93662 .12607 L
.93315 .11636 L
.93221 .11373 L
.92965 .10664 L
.92612 .09693 L
.92255 .08722 L
.92249 .08707 L
.91895 .07751 L
.91531 .06779 L
.91278 .06109 L
.91164 .05808 L
.90793 .04837 L
.90418 .03866 L
.90307 .03578 L
.9004 .02894 L
.89657 .01923 L
s
.625 g
.98077 .18925 m
.97919 .18434 L
.97607 .17463 L
.97292 .16492 L
.97106 .15922 L
.96974 .15521 L
.96654 .14549 L
.96332 .13578 L
.96134 .12987 L
.96007 .12607 L
.9568 .11636 L
.9535 .10664 L
.95163 .10118 L
.95017 .09693 L
.94682 .08722 L
.94344 .07751 L
.94192 .07318 L
.94003 .06779 L
.93659 .05808 L
.93311 .04837 L
.93221 .04584 L
.92961 .03866 L
.92608 .02894 L
.92251 .01923 L
.98077 .01923 L
F
0 g
.98077 .18925 m
.97919 .18434 L
.97607 .17463 L
.97292 .16492 L
.97106 .15922 L
.96974 .15521 L
.96654 .14549 L
.96332 .13578 L
.96134 .12987 L
.96007 .12607 L
.9568 .11636 L
.9535 .10664 L
.95163 .10118 L
.95017 .09693 L
.94682 .08722 L
.94344 .07751 L
.94192 .07318 L
.94003 .06779 L
.93659 .05808 L
.93311 .04837 L
.93221 .04584 L
.92961 .03866 L
.92608 .02894 L
.92251 .01923 L
s
.55 g
.98077 .12823 m
.98008 .12607 L
.97695 .11636 L
.97381 .10664 L
.97106 .0982 L
.97064 .09693 L
.96745 .08722 L
.96423 .07751 L
.96134 .06885 L
.96099 .06779 L
.95773 .05808 L
.95443 .04837 L
.95163 .04016 L
.95112 .03866 L
.94777 .02894 L
.9444 .01923 L
.98077 .01923 L
F
0 g
.98077 .12823 m
.98008 .12607 L
.97695 .11636 L
.97381 .10664 L
.97106 .0982 L
.97064 .09693 L
.96745 .08722 L
.96423 .07751 L
.96134 .06885 L
.96099 .06779 L
.95773 .05808 L
.95443 .04837 L
.95163 .04016 L
.95112 .03866 L
.94777 .02894 L
.9444 .01923 L
s
.475 g
.98077 .07234 m
.97931 .06779 L
.97618 .05808 L
.97303 .04837 L
.97106 .04231 L
.96986 .03866 L
.96666 .02894 L
.96344 .01923 L
.98077 .01923 L
F
0 g
.98077 .07234 m
.97931 .06779 L
.97618 .05808 L
.97303 .04837 L
.97106 .04231 L
.96986 .03866 L
.96666 .02894 L
.96344 .01923 L
s
.4 g
.98077 .02046 m
.98038 .01923 L
.98077 .01923 L
F
0 g
.98077 .02046 m
.98038 .01923 L
s
0 0 0 r
.055 w
.97615 .78218 Mdot
1 0 0 r
.0325 w
.01923 .78218 Mdot
.33376 .98077 Mdot
.09569 .83046 Mdot
.09387 .82807 Mdot
.09362 .82644 Mdot
.09393 .82297 Mdot
.09632 .8104 Mdot
.10406 .77863 Mdot
.12415 .70608 Mdot
.15138 .61887 Mdot
.18885 .51574 Mdot
.23888 .40789 Mdot
.28612 .33284 Mdot
.43914 .01923 Mdot
.32316 .25693 Mdot
.3972 .14482 Mdot
.41216 .16272 Mdot
.4853 .09751 Mdot
.51903 .09174 Mdot
.55478 .1236 Mdot
.73328 .10879 Mdot
.60102 .11976 Mdot
.77977 .1353 Mdot
.62642 .12197 Mdot
.64436 .131 Mdot
.68691 .16706 Mdot
.71627 .21143 Mdot
.77675 .28393 Mdot
.74607 .24715 Mdot
.79814 .33134 Mdot
.81778 .38714 Mdot
.88192 .50422 Mdot
.84028 .42821 Mdot
.98077 .70079 Mdot
.86308 .47245 Mdot
.87973 .50865 Mdot
.89227 .54117 Mdot
.91278 .59902 Mdot
.94789 .689 Mdot
.92666 .6346 Mdot
.95084 .70243 Mdot
.95722 .72523 Mdot
.97033 .76336 Mdot
.97315 .77253 Mdot
.97559 .78038 Mdot
.97612 .78208 Mdot
.97614 .78213 Mdot
.97616 .78219 Mdot
.97615 .78217 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
0 1 0 r
.02 w
.01923 .78218 Mdot
.01923 .78218 Mdot
.01923 .78218 Mdot
.01923 .78218 Mdot
.33376 .98077 Mdot
.33376 .98077 Mdot
.33376 .98077 Mdot
.33376 .98077 Mdot
.09569 .83046 Mdot
.09569 .83046 Mdot
.09569 .83046 Mdot
.09569 .83046 Mdot
.09387 .82807 Mdot
.09387 .82807 Mdot
.09387 .82807 Mdot
.09387 .82807 Mdot
.09362 .82644 Mdot
.09362 .82644 Mdot
.09362 .82644 Mdot
.09362 .82644 Mdot
.09393 .82297 Mdot
.09393 .82297 Mdot
.09393 .82297 Mdot
.09393 .82297 Mdot
.09632 .8104 Mdot
.09632 .8104 Mdot
.09632 .8104 Mdot
.09632 .8104 Mdot
.10406 .77863 Mdot
.10406 .77863 Mdot
.10406 .77863 Mdot
.10406 .77863 Mdot
.12415 .70608 Mdot
.12415 .70608 Mdot
.12415 .70608 Mdot
.12415 .70608 Mdot
.15138 .61887 Mdot
.15138 .61887 Mdot
.15138 .61887 Mdot
.15138 .61887 Mdot
.18885 .51574 Mdot
.18885 .51574 Mdot
.18885 .51574 Mdot
.18885 .51574 Mdot
.23888 .40789 Mdot
.23888 .40789 Mdot
.23888 .40789 Mdot
.23888 .40789 Mdot
.28612 .33284 Mdot
.28612 .33284 Mdot
.28612 .33284 Mdot
.28612 .33284 Mdot
.43914 .01923 Mdot
.43914 .01923 Mdot
.43914 .01923 Mdot
.43914 .01923 Mdot
.32316 .25693 Mdot
.32316 .25693 Mdot
.32316 .25693 Mdot
.32316 .25693 Mdot
.3972 .14482 Mdot
.3972 .14482 Mdot
.3972 .14482 Mdot
.3972 .14482 Mdot
.41216 .16272 Mdot
.41216 .16272 Mdot
.41216 .16272 Mdot
.41216 .16272 Mdot
.4853 .09751 Mdot
.4853 .09751 Mdot
.4853 .09751 Mdot
.4853 .09751 Mdot
.51903 .09174 Mdot
.51903 .09174 Mdot
.51903 .09174 Mdot
.51903 .09174 Mdot
.55478 .1236 Mdot
.55478 .1236 Mdot
.55478 .1236 Mdot
.55478 .1236 Mdot
.73328 .10879 Mdot
.73328 .10879 Mdot
.73328 .10879 Mdot
.73328 .10879 Mdot
.60102 .11976 Mdot
.60102 .11976 Mdot
.60102 .11976 Mdot
.60102 .11976 Mdot
.77977 .1353 Mdot
.77977 .1353 Mdot
.77977 .1353 Mdot
.77977 .1353 Mdot
.62642 .12197 Mdot
.62642 .12197 Mdot
.62642 .12197 Mdot
.62642 .12197 Mdot
.64436 .131 Mdot
.64436 .131 Mdot
.64436 .131 Mdot
.64436 .131 Mdot
.68691 .16706 Mdot
.68691 .16706 Mdot
.68691 .16706 Mdot
.68691 .16706 Mdot
.71627 .21143 Mdot
.71627 .21143 Mdot
.71627 .21143 Mdot
.71627 .21143 Mdot
.77675 .28393 Mdot
.77675 .28393 Mdot
.77675 .28393 Mdot
.77675 .28393 Mdot
.74607 .24715 Mdot
.74607 .24715 Mdot
.74607 .24715 Mdot
.74607 .24715 Mdot
.79814 .33134 Mdot
.79814 .33134 Mdot
.79814 .33134 Mdot
.79814 .33134 Mdot
.81778 .38714 Mdot
.81778 .38714 Mdot
.81778 .38714 Mdot
.81778 .38714 Mdot
.88192 .50422 Mdot
.88192 .50422 Mdot
.88192 .50422 Mdot
.88192 .50422 Mdot
.84028 .42821 Mdot
.84028 .42821 Mdot
.84028 .42821 Mdot
.84028 .42821 Mdot
.98077 .70079 Mdot
.98077 .70079 Mdot
.98077 .70079 Mdot
.98077 .70079 Mdot
.86308 .47245 Mdot
.86308 .47245 Mdot
.86308 .47245 Mdot
.86308 .47245 Mdot
.87973 .50865 Mdot
.87973 .50865 Mdot
.87973 .50865 Mdot
.87973 .50865 Mdot
.89227 .54117 Mdot
.89227 .54117 Mdot
.89227 .54117 Mdot
.89227 .54117 Mdot
.91278 .59902 Mdot
.91278 .59902 Mdot
.91278 .59902 Mdot
.91278 .59902 Mdot
.94789 .689 Mdot
.94789 .689 Mdot
.94789 .689 Mdot
.94789 .689 Mdot
.92666 .6346 Mdot
.92666 .6346 Mdot
.92666 .6346 Mdot
.92666 .6346 Mdot
.95084 .70243 Mdot
.95084 .70243 Mdot
.95084 .70243 Mdot
.95084 .70243 Mdot
.95722 .72523 Mdot
.95722 .72523 Mdot
.95722 .72523 Mdot
.95722 .72523 Mdot
.97033 .76336 Mdot
.97033 .76336 Mdot
.97033 .76336 Mdot
.97033 .76336 Mdot
.97315 .77253 Mdot
.97315 .77253 Mdot
.97315 .77253 Mdot
.97315 .77253 Mdot
.97559 .78038 Mdot
.97559 .78038 Mdot
.97559 .78038 Mdot
.97559 .78038 Mdot
.97612 .78208 Mdot
.97612 .78208 Mdot
.97612 .78208 Mdot
.97612 .78208 Mdot
.97614 .78213 Mdot
.97614 .78213 Mdot
.97614 .78213 Mdot
.97614 .78213 Mdot
.97616 .78219 Mdot
.97616 .78219 Mdot
.97616 .78219 Mdot
.97616 .78219 Mdot
.97615 .78217 Mdot
.97615 .78217 Mdot
.97615 .78217 Mdot
.97615 .78217 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
.97615 .78218 Mdot
0 0 1 r
.5 Mabswid
.01923 .78218 m
.01923 .78218 L
.09569 .83046 L
.09387 .82807 L
.09362 .82644 L
.09393 .82297 L
.09632 .8104 L
.10406 .77863 L
.12415 .70608 L
.15138 .61887 L
.18885 .51574 L
.23888 .40789 L
.28612 .33284 L
.32316 .25693 L
.3972 .14482 L
.41216 .16272 L
.4853 .09751 L
.51903 .09174 L
.55478 .1236 L
.60102 .11976 L
.62642 .12197 L
.64436 .131 L
.68691 .16706 L
.71627 .21143 L
.74607 .24715 L
.79814 .33134 L
.81778 .38714 L
.84028 .42821 L
.86308 .47245 L
.87973 .50865 L
.89227 .54117 L
.91278 .59902 L
.92666 .6346 L
.95084 .70243 L
.95722 .72523 L
.97033 .76336 L
.97315 .77253 L
.97559 .78038 L
.97612 .78208 L
.97614 .78213 L
.97616 .78219 L
.97615 .78217 L
.97615 .78218 L
s
.015 w
.01923 .78218 Mdot
.01923 .78218 Mdot
.09569 .83046 Mdot
.09387 .82807 Mdot
.09362 .82644 Mdot
.09393 .82297 Mdot
.09632 .8104 Mdot
.10406 .77863 Mdot
.12415 .70608 Mdot
.15138 .61887 Mdot
.18885 .51574 Mdot
.23888 .40789 Mdot
.28612 .33284 Mdot
.32316 .25693 Mdot
.3972 .14482 Mdot
.41216 .16272 Mdot
.4853 .09751 Mdot
.51903 .09174 Mdot
.55478 .1236 Mdot
.60102 .11976 Mdot
.62642 .12197 Mdot
.64436 .131 Mdot
.68691 .16706 Mdot
.71627 .21143 Mdot
.74607 .24715 Mdot
.79814 .33134 Mdot
.81778 .38714 Mdot
.84028 .42821 Mdot
.86308 .47245 Mdot
.87973 .50865 Mdot
.89227 .54117 Mdot
.91278 .59902 Mdot
.92666 .6346 Mdot
.95084 .70243 Mdot
.95722 .72523 Mdot
.97033 .76336 Mdot
.97315 .77253 Mdot
.97559 .78038 Mdot
.97612 .78208 Mdot
.97614 .78213 Mdot
.97616 .78219 Mdot
.97615 .78217 Mdot
.97615 .78218 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[55]:=",
  ImageSize->{834.625, 193.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000CS00018R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooooW0?ooo`00o`3ooooo0?ooool0ooooo`3ooooW0?ooo`00o`3ooooo0?ooool0
ooooo`3ooooW0?ooo`00o`3ooooo0?ooool0ooooo`3ooooW0?ooo`00o`3ooooo0?ooool0ooooo`3o
oooW0?ooo`00o`3ooooo0?ooool0ooooo`3ooooW0?ooo`00o`3ooooo0?ooool0ooooo`3ooooW0?oo
o`00o`3ooooo0?ooool0ooooo`3ooooW0?ooo`00o`3ooooo0?ooool0ooooo`3ooooW0?ooo`00o`3o
oooo0?ooool0ooooo`3ooooW0?ooo`00D@3oool7000002P0oooo100000060?ooo`8000001P3oool4
000002L0oooo1000000Z0?ooo`@000001P3oool2000000H0oooo1000000Z0?ooo`L00000CP3oool7
000002T0oooo100000060?ooo`8000001P3oool4000002H0oooo1000000[0?ooo`@000001P3oool2
000000H0oooo1000000Z0?ooo`L00000o`3ooooo0?oooh<0oooo001D0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0o`3ooooo0?oooh@0oooo001D0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0o`3ooooo0?oooh@0oooo001D0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0o`3ooooo0?oooh@0oooo00180?ooo`H000001P3oool00`000000oooo0?oo
o`0O0?ooo`H000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0AP3oool6000000H0oooo00<000000?ooo`3oool0803oool6000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooo`3o
oon40?ooo`00E03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool4000002H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4000002d0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool4000002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4000002d0oooo00<00000
0?ooo`3oool0E`3oool7000002H0oooo100000060?ooo`8000001P3oool4000002@0oooo1000000Y
0?ooo`@000001P3oool2000000H0oooo1000000W0?ooo`L00000F03oool7000002H0oooo10000006
0?ooo`8000001P3oool4000002@0oooo1000000X0?ooo`@000001P3oool2000000H0oooo1000000X
0?ooo`L000008`3oool005@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0903oool00580oooo0`00000Z0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0;03oool300000580oooo0`00000[0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0;03oool3000005`0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0T0?ooo`00E03oool00`000000oooo0?ooo`0Y0?ooo`@00000
3P3oool5000002H0oooo1000000Z0?ooo`@000003P3oool5000002`0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0Z0?ooo`@000003P3oool5000002D0oooo1000000[0?ooo`@00000
3P3oool5000002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02@0oooo003o0?ooool0oooo/@3oool6000000H0oooo00<000000?ooo`3oool07@3o
ool6000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0500oooo1P0000060?ooo`030000003oool0oooo01d0oooo1P0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0T0?ooo`00o`3ooooo
0?oookd0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo1000000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000000Z0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo1000000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000000[0?ooo`030000003oool0
oooo02@0oooo003o0?ooool0oooo_@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
02@0oooo003o0?ooool0oooo^`3oool3000002P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0Y0?ooo`<00000G03oool3000002P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0Z0?ooo`<000009P3oool00?l0ooooo`3ooonm0?ooo`030000003oool0oooo02L0oooo
1000000>0?ooo`D000008`3oool4000002T0oooo1000000>0?ooo`D00000:@3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo02L0oooo1000000>0?ooo`D000008`3oool4000002P0oooo
1000000>0?ooo`D00000:P3oool00`000000oooo0?ooo`0T0?ooo`00o`3ooooo0?ooool0ooooo`3o
oooW0?ooo`00=@3ooooo00000?l0ooooo`3ooooo0?oook80oooo000e0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02h0ooooo`00000100000?l0ooooo`3ooon10?ooo`00=@3oool00`000000oooo0?ooo`3f0?ooo`80
ool00`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`80o`000`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooool0
ooooO`3oool003D0oooo00<000000?ooo`3oool0m@3oool40?oo0080oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`3J0?ooo`H0o`00703oool00`000000oooo0?ooo`3o0?ooool0oooo
O`3oool003D0oooo00<000000?ooo`3oool0m03oool60?oo00030?ooo`000000oooo02l0oooo0P00
003K0?ooo`80o`000`00o`000`3o0000oooo0?ooo`0I0?ooo`800000o`3ooooo0?oooh40oooo000e
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=
0?ooo`8000005P3oool00`000000oooo0?ooo`0S0?ooo`@00000>P3oool4000002@0oooo0`00000D
0?ooo`8000003P3oool60?oo00030?ooo`000000oooo02l0oooo00<000000?ooo`3oool0f@3oool2
0?l000D00?l000<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0g0?ooooL00000>03oooog
00000200oooo000e0?ooo`030000003oool0oooo0080oooo1`0o?cl2000000d0De=C00<0000006IV
IP1VIVH03@1VIVH00`000000NGUi07UiN@0D07UiN@8000008`2<S8`300000480WinO0P00000U08b<
S0030000001iNGT0NGUi01<0NGUi0P00000=06IVIP@0ool00P3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00h0oooo0P00000I0?ooo`030000003oool0oooo06/0oooo0`00000G0?oo
o`80o`001@00o`000`3o0000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo000e0?ooo`80
00000`3oool603lo?`030000001CDe<0De=C00/0De=C0P00000?06IVIP030000001iNGT0NGUi01<0
NGUi0P00000R08b<S0<00000A`2OWil500000240S8b<0P00000E07UiN@030000001VIVH0IVIV00/0
IVIV0P3oo`020?ooo`800000<03oool00`000000oooo0?ooo`020?ooo`L0?clo00<0000005=CD`1C
De<02@1CDe<00`000000IVIV06IVIP0;06IVIP800000401iNGT00`000000S8b<08b<S00F08b<S0<0
0000L@2OWil00`000000S8b<08b<S00E08b<S0030?l00000o`000?l000<00?l0301iNGT2000000T0
IVIV1@3oool00`000000oooo0?ooo`0g0?ooo`800000603oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo01P0oooo0`3o000H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`020?ooo`800000>03oool2000001T0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0H0?ooo`<0o`005`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool200000200oooo000e0?ooo`030000
003oool0oooo0080oooo1@0o?cl00`000000De=C05=CD`0;05=CD`030000001VIVH0IVIV00d0IVIV
0P00000D07UiN@800000802<S8`4000004l0WinO0`00000P08b<S0800000501iNGT00`000000IVIV
06IVIP0:06IVIPD0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`H0?clo
00<0000005=CD`1CDe<02@1CDe<00`000000IVIV06IVIP0;06IVIP030000001iNGT0NGUi00l0NGUi
00<0000008b<S02<S8`05@2<S8`2000007D0WinO0P00000E08b<S080o`000`00o`000`3o0000NGUi
07UiN@0<07UiN@030000001VIVH0IVIV00H0IVIV1@3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo06H0oooo1@3o00280?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
I`3oool50?l008L0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3o
ool503lo?`030000001CDe<0De=C00X0De=C00<0000006IVIP1VIVH03@1VIVH00`000000NGUi07Ui
N@0C07UiN@030000002<S8`0S8b<01h0S8b<0P00001F09nOW`8000007`2<S8`00`000000NGUi07Ui
N@0C07UiN@030000001VIVH0IVIV00T0IVIV1@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0080oooo1@0o?cl00`000000De=C05=CD`0805=CD`8000003@1VIVH00`000000NGUi07Ui
N@0>07UiN@8000005P2<S8`2000003H0WinO3000000g09nOW`8000005@2<S8`20?l00140NGUi00<0
000006IVIP1VIVH01@1VIVH50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0I@3o
ool30?l000800?l00P3o00270?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0IP3o
ool20?l000800?l00`3o00260?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0
oooo0080oooo100o?cl00`000000De=C05=CD`0:05=CD`030000001VIVH0IVIV00h0IVIV00<00000
07UiN@1iNGT04@1iNGT2000001h0S8b<0`00001J09nOW`<000007@2<S8`2000001@0NGUi00<00000
06IVIP1VIVH0201VIVH50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool4
03lo?`030000001CDe<0De=C00P0De=C00<0000006IVIP1VIVH02`1VIVH2000000l0NGUi0P00000F
08b<S0800000;@2OWil;000000`0/k>c3000000]09nOW`8000005@2<S8`3000000l0NGUi0P000005
06IVIPD0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`80o`001000o`000`3o0000oooo
0?ooo`160?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0403oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool200000140oooo00<0o`00
003o0000o`000P00o`020?l004L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo0`0o?cl00`000000De=C05=CD`0:
05=CD`030000001VIVH0IVIV00d0IVIV0P00000C07UiN@030000002<S8`0S8b<01`0S8b<0P00001P
09nOW`8000007@2<S8`2000001<0NGUi0P00000806IVIPD0oooo00<000000?ooo`3oool0903oool4
000000H0oooo00<000000?ooo`3oool00P3oool303lo?`030000001CDe<0De=C00T0De=C00<00000
06IVIP1VIVH02P1VIVH00`000000NGUi07UiN@0>07UiN@030000002<S8`0S8b<01D0S8b<00<00000
09nOW`2OWil09`2OWil600000280/k>c1P00000Z09nOW`8000005P2<S8`00`000000NGUi07UiN@0=
07UiN@030000001VIVH0IVIV00<0IVIV1@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0080oooo3@0o?cl010000000De=C05=CD`00000306IVIP050000001iNGT0NGUi07UiN@000000
102<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c00@0/k>c00<000000<K6aP36a/H0
1@36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool0
403oool20?l000@00?l000<0o`000?ooo`3oool0A`3oool00`000000k>c/0>c/k00?0>c/k0030000
003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01@36a/H00`000000/k>c0;>c/`040;>c/`030000
002OWil0WinO0080WinO00<0000008b<S02<S8`00P2<S8`010000000NGUi07UiN@1iNGT50?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool=03lo?`050000001CDe<0De=C05=C
D`0000000`1VIVH01@000000NGUi07UiN@1iNGT0000000@0S8b<00<0000009nOW`2OWil00P2OWil0
0`000000/k>c0;>c/`040;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT0203IfMT0
0`000000k>c/0>c/k00@0>c/k0030000003oool0oooo0140oooo00<0o`00003o0000o`000P00o`02
0?l004P0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0
a/K600D0a/K600<000000;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0309nOW`050000002<S8`0
S8b<08b<S00000000`1iNGT50?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0
oooo0080oooo0P0o?cl00`000000De=C05=CD`0:05=CD`030000001VIVH0IVIV00d0IVIV00<00000
07UiN@1iNGT04@1iNGT2000001`0S8b<0`00001T09nOW`<00000702<S8`00`000000NGUi07UiN@0B
07UiN@030000001VIVH0IVIV00D0IVIV1@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<0?clo00<00000
05=CD`1CDe<0201CDe<00`000000IVIV06IVIP0:06IVIP030000001iNGT0NGUi00l0NGUi00<00000
08b<S02<S8`04`2<S8`2000002P0WinO0P00000^0;>c/`D000009`2OWil00`000000S8b<08b<S00D
08b<S0030000001iNGT0NGUi00d0NGUi00<0000006IVIP1VIVH00P1VIVH50?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool00P3oool=03lo?`040000001CDe<0De=C000000<0IVIV00D0
000007UiN@1iNGT0NGUi0000000408b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<0
102c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`0
403/k>`00`000000oooo0?ooo`0B0?ooo`80o`000P00o`000`3o0000oooo0?ooo`180?ooo`030000
003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP050<K6aP030000
002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00`2OWil01@000000S8b<08b<S02<S8`0000000<0
NGUi1@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo3@0o?cl01@000000
De=C05=CD`1CDe<0000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000408b<S0030000002OWil0
WinO0080WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0
fMWI00P0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0B0?ooo`030?l00000o`00
0?l00080o`00BP3oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00P0fMWI00<00000
0<K6aP36a/H01@36a/H00`000000/k>c0;>c/`030;>c/`030000002OWil0WinO0080WinO00<00000
08b<S02<S8`00P2<S8`00`000000NGUi07UiN@050?ooo`030000003oool0oooo01h0oooo000e0?oo
o`030000003oool0oooo0080oooo00<0?clo0000001CDe<02`1CDe<00`000000IVIV06IVIP0<06IV
IP8000004`1iNGT00`000000S8b<08b<S00I08b<S0<00000JP2OWil2000001/0S8b<0P00000C07Ui
N@030000001VIVH0IVIV00@0IVIV1@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool203lo?`030000001CDe<0De=C00P0De=C00<0000006IV
IP1VIVH02P1VIVH00`000000NGUi07UiN@0>07UiN@800000502<S8`2000002D0WinO1@00000e0;>c
/`<000009@2OWil2000001D0S8b<00<0000007UiN@1iNGT03@1iNGT010000000IVIV06IVIP1VIVH5
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool=03lo?`040000001CDe<0
De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO00<0WinO
00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00L0fMWI
00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`0D0?ooo`<0o`00C03oool00`000000k>c/
0>c/k00?0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01@36a/H00`000000/k>c
0;>c/`030;>c/`030000002OWil0WinO00<0WinO00D0000008b<S02<S8`0S8b<0000000307UiN@D0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`d0?clo00D0000005=CD`1C
De<0De=C0000000306IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`03
09nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@07
0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0503oool30?l004`0oooo00<00000
0>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0a/K600D0a/K600<00000
0;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0209nOW`030000002<S8`0S8b<0080S8b<00<00000
07UiN@1iNGT01@3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?oo
o`030000001CDe<0De=C00X0De=C00<0000006IVIP1VIVH0301VIVH00`000000NGUi07UiN@0B07Ui
N@030000002<S8`0S8b<01P0S8b<0P00001_09nOW`8000006`2<S8`00`000000NGUi07UiN@0A07Ui
N@030000001VIVH0IVIV00<0IVIV1@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool2000000X0De=C00<0000006IVIP1VIVH02P1VIVH00`00
0000NGUi07UiN@0>07UiN@030000002<S8`0S8b<0180S8b<0P00000T09nOW`<00000?@2c/k<50000
0280WinO00<0000008b<S02<S8`04`2<S8`2000000h0NGUi0P0000000`1VIVH0oooo0?ooo`030?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool<03lo?`050000001CDe<0De=C
05=CD`0000000P1VIVH01@000000NGUi07UiN@1iNGT0000000@0S8b<00<0000009nOW`2OWil00`2O
Wil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT0203I
fMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo06@0oooo00<000000>c/k03/k>`03`3/
k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600D0a/K600<000000;>c/`2c/k<00`2c
/k<00`000000WinO09nOW`0309nOW`050000002<S8`0S8b<08b<S00000000P1iNGT50?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool=03lo?`040000001CDe<0De=C000000<0
IVIV00D0000007UiN@1iNGT0NGUi0000000408b<S0030000002OWil0WinO0080WinO00<000000;>c
/`2c/k<0102c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/
k03/k>`0403/k>`00`000000oooo0?ooo`1T0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WI
f@3IfMT0203IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00@0/k>c00<0000009nO
W`2OWil00P2OWil00`000000S8b<08b<S00208b<S0030000001iNGT0oooo00@0oooo00<000000?oo
o`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool<05=CD`030000001VIVH0IVIV00d0
IVIV00<0000007UiN@1iNGT0401iNGT2000001/0S8b<00<0000009nOW`2OWil0L02OWil2000001X0
S8b<0P00000B07UiN@030000001VIVH0IVIV0080IVIV1@3oool00`000000oooo0?ooo`0J0?ooo`H0
00001P3oool2000000H0oooo0`0000020?ooo`/0De=C00<0000006IVIP1VIVH02P1VIVH00`000000
NGUi07UiN@0=07UiN@8000004`2<S8`200000240WinO1@0000150;>c/`<00000802OWil3000001@0
S8b<00<0000007UiN@1iNGT03@1iNGT010000000oooo0?ooo`3oool3000003T0oooo0P0000030?oo
o``0?clo00D0000005=CD`1CDe<0De=C0000000206IVIP050000001iNGT0NGUi07UiN@000000102<
S8`00`000000WinO09nOW`0309nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01@36
a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool0I03o
ool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00L0fMWI0P0000060<K6aP030000002c
/k<0/k>c00<0/k>c00<0000009nOW`2OWil00`2OWil01@000000S8b<08b<S02<S8`000000080NGUi
103oool2000003P0oooo0P0000030?ooo`d0?clo00@0000005=CD`1CDe<000000`1VIVH01@000000
NGUi07UiN@1iNGT0000000@0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`040;>c
/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k00@0>c/
k0030000003oool0oooo06D0oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@080=WI
f@0300000036a/H0a/K600D0a/K600<000000;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0209nO
W`030000002<S8`0S8b<0080S8b<00<0000007UiN@3oool00`3oool200000200oooo000e0?ooo`03
0000003oool0oooo0080oooo2`1CDe<00`000000IVIV06IVIP0=06IVIP030000001iNGT0NGUi00l0
NGUi0P00000J08b<S0<00000M@2OWil2000001X0S8b<00<0000007UiN@1iNGT0401iNGT010000000
IVIV06IVIP1VIVH50?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`X0De=C00<0000006IVIP1VIVH02P1VIVH00`000000NGUi07UiN@0>07Ui
N@030000002<S8`0S8b<0140S8b<00<0000009nOW`2OWil07`2OWil2000004d0/k>c0P00000Q09nO
W`030000002<S8`0S8b<0180S8b<00<0000007UiN@1iNGT0301iNGT00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool;03lo?`050000001CDe<0De=C
05=CD`0000000`1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00<0000009nOW`2OWil00`2O
Wil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT0203I
fMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo06H0oooo00<000000>c/k03/k>`03P3/
k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<0102c
/k<00`000000WinO09nOW`0209nOW`050000002<S8`0S8b<08b<S00000000P1iNGT50?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool<03lo?`040000001CDe<0De=C000000<0
IVIV00D0000007UiN@1iNGT0NGUi0000000408b<S0030000002OWil0WinO00<0WinO00<000000;>c
/`2c/k<00`2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/
k03/k>`0403/k>`00`000000oooo0?ooo`1V0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WI
f@3IfMT01`3IfMT00`000000a/K60<K6aP050<K6aP030000002c/k<0/k>c00@0/k>c00D0000009nO
W`2OWil0WinO0000000408b<S0030000001iNGT0oooo00@0oooo00<000000?ooo`3oool07P3oool0
03D0oooo0P0000030?ooo`T0De=C0P00000>06IVIP8000004@1iNGT00`000000S8b<08b<S00H08b<
S0800000NP2OWil2000001T0S8b<00<0000007UiN@1iNGT0401iNGT20000000306IVIP3oool0oooo
0080oooo0P00000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool905=C
D`030000001VIVH0IVIV00X0IVIV00<0000007UiN@1iNGT03@1iNGT2000001<0S8b<0P00000N09nO
W`<00000D@2c/k<200000200WinO00<0000008b<S02<S8`04P2<S8`00`000000NGUi07UiN@0<07Ui
N@030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?oo
o`/0?clo00D0000005=CD`1CDe<0De=C0000000306IVIP050000001iNGT0NGUi07UiN@0000000`2<
S8`00`000000WinO09nOW`0309nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01@36
a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0J03o
ool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01@36
a/H00`000000/k>c0;>c/`030;>c/`030000002OWil0WinO0080WinO00<0000008b<S02<S8`00P2<
S8`00`000000NGUi0?ooo`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3o
ool<03lo?`040000001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000408b<S003
0000002OWil0WinO0080WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K60<K6aP050<K6aP03
0000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?ooo`1W0?ooo`03
0000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP050<K6aP03
0000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2OWil00`000000S8b<08b<S00208b<S003
0000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool0
0P3oool805=CD`030000001VIVH0IVIV00d0IVIV00<0000007UiN@1iNGT0401iNGT00`000000S8b<
08b<S00F08b<S0<00000OP2OWil2000001P0S8b<0P00000B07UiN@030000003oool0oooo00<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool805=CD`030000001VIVH0IVIV00X0IVIV00<0000007UiN@1iNGT0
3@1iNGT00`000000S8b<08b<S00A08b<S08000007P2OWil2000005H0/k>c0`00000N09nOW`800000
4`2<S8`00`000000NGUi07UiN@0;07UiN@D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`020?ooo`/0?clo00@0000005=CD`1CDe<000000`1VIVH01@000000NGUi07UiN@1iNGT00000
00@0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K6
00D0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo
06T0oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K6
00D0a/K600<000000;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0209nOW`030000002<S8`0S8b<
0080S8b<00<0000007UiN@3oool0103oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
0080oooo2`0o?cl01@000000De=C05=CD`1CDe<000000080IVIV00<0000007UiN@1iNGT00P1iNGT0
1@000000S8b<08b<S02<S8`0000000@0WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K60<K6
aP050<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`0403/k>`00`000000oooo0?oo
o`1Y0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6
aP050<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2OWil00`000000S8b<08b<
S00208b<S0030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool003D0oooo00<00000
0?ooo`3oool00P3oool705=CD`030000001VIVH0IVIV00`0IVIV0P00000A07UiN@8000005`2<S8`2
000003T0WinO4P00000h09nOW`800000602<S8`200000140NGUi00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0T0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`P0De=C00<00000
06IVIP1VIVH02@1VIVH00`000000NGUi07UiN@0=07UiN@030000002<S8`0S8b<0140S8b<00<00000
09nOW`2OWil06`2OWil3000005/0/k>c0P00000M09nOW`8000004`2<S8`00`000000NGUi07UiN@0:
07UiN@D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`/0?clo00@00000
05=CD`1CDe<000000`1VIVH01@000000NGUi07UiN@1iNGT0000000@0S8b<00<0000009nOW`2OWil0
0P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT0
203IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo06X0oooo00<000000>c/k03/k>`0
3P3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600D0a/K600<000000;>c/`2c/k<0
0`2c/k<00`000000WinO09nOW`0209nOW`030000002<S8`0S8b<0080S8b<00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo2`0o?cl01@000000De=C
05=CD`1CDe<000000080IVIV00<0000007UiN@1iNGT00P1iNGT01@000000S8b<08b<S02<S8`00000
00@0WinO00<000000;>c/`2c/k<0102c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI
00L0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`1[0?ooo`030000003/k>`0k>c/
00h0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c
00@0/k>c00<0000009nOW`2OWil00P2OWil01@000000S8b<08b<S02<S8`0000000D0oooo00<00000
0?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool705=CD`030000001VIVH0IVIV
00`0IVIV00<0000007UiN@1iNGT03`1iNGT00`000000S8b<08b<S00F08b<S0030000002OWil0WinO
02l0WinO2P00000B0;>c/`T00000<@2OWil00`000000S8b<08b<S00F08b<S0030000001iNGT0NGUi
00l0NGUi00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0080oooo1P1CDe<2000000/0IVIV00<0000007UiN@1iNGT0301iNGT200000180S8b<0P00000K09nO
W`<00000H02c/k<3000001`0WinO0P00000B08b<S08000002P1iNGT50?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool00P3oool;03lo?`040000001CDe<0De=C000000<0IVIV00D00000
07UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO00<0WinO00<000000;>c/`2c/k<00`2c
/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03`3/
k>`00`000000oooo0?ooo`1[0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT01`3I
fMT00`000000a/K60<K6aP050<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2O
Wil00`000000S8b<08b<S00208b<S0030000003oool0oooo00<0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`020?ooo`/0?clo00@0000005=CD`1CDe<000000`1VIVH00`000000NGUi
07UiN@0207UiN@040000002<S8`0S8b<000000D0WinO00<000000;>c/`2c/k<00`2c/k<00`000000
a/K60<K6aP060<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03P3/k>`00`000000
oooo0?ooo`1/0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000
a/K60<K6aP050<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2OWil01@000000
S8b<08b<S02<S8`0000000D0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3o
ool00P3oool605=CD`030000001VIVH0IVIV00`0IVIV00<0000007UiN@1iNGT03`1iNGT00`000000
S8b<08b<S00F08b<S0030000002OWil0WinO02/0WinO1@00000U0;>c/`D00000;@2OWil2000001L0
S8b<00<0000007UiN@1iNGT03P1iNGT50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool00P3oool505=CD`030000001VIVH0IVIV00X0IVIV00<0000007UiN@1iNGT0301iNGT00`000000
S8b<08b<S00A08b<S0030000002OWil0WinO01T0WinO0P00001V0;>c/`800000702OWil00`000000
S8b<08b<S00@08b<S0030000001iNGT0NGUi00P0NGUi1@3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0080oooo2P0o?cl010000000De=C05=CD`00000306IVIP050000001iNGT0NGUi
07UiN@000000102<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<00000
0<K6aP36a/H01@36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00l0k>c/00<00000
0?ooo`3oool0K03oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00L0fMWI00<00000
0<K6aP36a/H01036a/H00`000000/k>c0;>c/`040;>c/`030000002OWil0WinO0080WinO00D00000
08b<S02<S8`0S8b<000000050?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3o
ool;03lo?`040000001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S003
0000002OWil0WinO00<0WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP050<K6aP03
0000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`1]0?ooo`03
0000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP040<K6aP03
0000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00`2OWil01@000000S8b<08b<S02<S8`00000
00@0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool505=CD`03
0000001VIVH0IVIV00/0IVIV0P00000A07UiN@030000002<S8`0S8b<01@0S8b<0`00000Y09nOW`D0
0000;`2c/k<5000002X0WinO0P00000F08b<S0<000003@1iNGT50?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool00P3oool405=CD`030000001VIVH0IVIV00/0IVIV00<0000007UiN@1i
NGT02`1iNGT00`000000S8b<08b<S00A08b<S0030000002OWil0WinO01P0WinO0P00001Z0;>c/`80
00006`2OWil200000140S8b<00<0000007UiN@1iNGT01`1iNGT50?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool00P3oool:03lo?`040000001CDe<0De=C000000<0IVIV00D0000007Ui
N@1iNGT0NGUi0000000408b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<0
0`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03`3/k>`0
0`000000oooo0?ooo`1]0?ooo`8000003`3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0
a/K600D0a/K600<000000;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0209nOW`050000002<S8`0
S8b<08b<S00000001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo2`0o
?cl010000000De=C05=CD`00000306IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000
WinO09nOW`0309nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01@36a/H00`000000
fMWI0=WIf@070=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0K@3oool00`000000
k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01036a/H00`000000
/k>c0;>c/`030;>c/`030000002OWil0WinO00<0WinO00D0000008b<S02<S8`0S8b<000000040?oo
o`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo1@1CDe<00`000000
IVIV06IVIP0:06IVIP030000001iNGT0NGUi0100NGUi00<0000008b<S02<S8`0502<S8`00`000000
WinO09nOW`0V09nOW`@00000>@2c/k<5000002L0WinO00<0000008b<S02<S8`05P2<S8`00`000000
NGUi07UiN@0:07UiN@D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`@0
De=C00<0000006IVIP1VIVH02@1VIVH2000000d0NGUi00<0000008b<S02<S8`0402<S8`2000001T0
WinO0P00001^0;>c/`<000006P2OWil00`000000S8b<08b<S00?08b<S08000001`1iNGT50?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool903lo?`050000001CDe<0De=C05=C
D`0000000P1VIVH01@000000NGUi07UiN@1iNGT0000000@0S8b<00<0000009nOW`2OWil00`2OWil0
0`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT01`3IfMT0
0`000000k>c/0>c/k00?0>c/k0030000003oool0oooo06l0oooo00<000000>c/k03/k>`03@3/k>`0
0`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600D0a/K600<000000;>c/`2c/k<00`2c/k<0
0`000000WinO09nOW`0209nOW`030000002<S8`0S8b<0080S8b<00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo2P0o?cl010000000De=C05=CD`00
000306IVIP050000001iNGT0NGUi07UiN@000000102<S8`00`000000WinO09nOW`0209nOW`030000
002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01@36a/H00`000000fMWI0=WIf@070=WIf@030000
003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0K`3oool00`000000k>c/0>c/k00=0>c/k0030000
003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`040;>c/`030000
002OWil0WinO0080WinO00D0000008b<S02<S8`0S8b<000000040?ooo`030000003oool0oooo01h0
oooo000e0?ooo`030000003oool0oooo0080oooo0`1CDe<2000000`0IVIV00<0000007UiN@1iNGT0
3`1iNGT2000001D0S8b<0P00000U09nOW`@00000@P2c/k<3000002D0WinO0`00000F08b<S0030000
001iNGT0NGUi00T0NGUi1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo
0`1CDe<00`000000IVIV06IVIP0906IVIP030000001iNGT0NGUi00`0NGUi00<0000008b<S02<S8`0
3`2<S8`2000001T0WinO0P00001c0;>c/`8000006@2OWil00`000000S8b<08b<S00@08b<S0030000
001iNGT0NGUi00@0NGUi1@3oool00`000000oooo0?ooo`0g0?ooo`8000000`3oool903lo?`050000
001CDe<0De=C05=CD`0000000P1VIVH01@000000NGUi07UiN@1iNGT0000000@0S8b<00<0000009nO
W`2OWil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600D0a/K600<000000=WI
f@3IfMT01`3IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo0700oooo00<000000>c/
k03/k>`03@3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600D0a/K600<000000;>c
/`2c/k<00`2c/k<00`000000WinO09nOW`0209nOW`040000002<S8`0S8b<08b<S0@0oooo0P00000h
0?ooo`8000000`3oool:03lo?`040000001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi
0000000408b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K6
0<K6aP050<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo
0?ooo`1a0?ooo`030000003/k>`0k>c/00d0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K6
0<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2OWil010000000S8b<
08b<S02<S8`40?ooo`800000803oool003D0oooo00<000000?ooo`3oool00P3oool205=CD`030000
001VIVH0IVIV00`0IVIV00<0000007UiN@1iNGT03P1iNGT00`000000S8b<08b<S00C08b<S0800000
9P2OWil00`000000/k>c0;>c/`170;>c/`8000009P2OWil00`000000S8b<08b<S00D08b<S0800000
2@1iNGT50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool205=CD`030000
001VIVH0IVIV00T0IVIV00<0000007UiN@1iNGT0301iNGT00`000000S8b<08b<S00?08b<S0030000
002OWil0WinO01L0WinO0P00001g0;>c/`800000602OWil200000140S8b<00<0000007UiN@1iNGT0
0`1iNGT50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool903lo?`040000
001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO
0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI
00L0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0_0?ooo`<0o`00?`3oool00`00
0000k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01@36a/H00`00
0000/k>c0;>c/`030;>c/`030000002OWil0WinO0080WinO00@0000008b<S02<S8`0S8b<1@3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo2P0o?cl010000000De=C05=CD`00
000206IVIP050000001iNGT0NGUi07UiN@000000102<S8`00`000000WinO09nOW`0209nOW`030000
002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01@36a/H00`000000fMWI0=WIf@070=WIf@030000
003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0;`3oool30?l003l0oooo00<000000>c/k03/k>`0
3@3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<0
0`2c/k<00`000000WinO09nOW`0209nOW`040000002<S8`0S8b<08b<S0D0oooo00<000000?ooo`3o
ool07P3oool003D0oooo00<000000?ooo`3oool00P3oool00`1CDe<0000006IVIP0<06IVIP800000
401iNGT00`000000S8b<08b<S00C08b<S0030000002OWil0WinO0240WinO1@00001<0;>c/`@00000
8`2OWil00`000000S8b<08b<S00E08b<S0030000001iNGT0NGUi00H0NGUi1@3oool00`000000oooo
0?ooo`0^0?ooo`8000000`3oool00`1CDe<0000006IVIP0:06IVIP030000001iNGT0NGUi00/0NGUi
0P00000A08b<S0030000002OWil0WinO01H0WinO0P00001k0;>c/`030000002OWil0WinO01L0WinO
00<0000008b<S02<S8`03`2<S8`00`000000NGUi07UiN@0207UiN@@0oooo0P00000i0?ooo`030000
003oool0oooo0080oooo2@0o?cl010000000De=C05=CD`00000306IVIP050000001iNGT0NGUi07Ui
N@0000000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6
aP36a/H01@36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00h0k>c/00<000000?oo
o`3oool0:03oool30?l000@0oooo1@3o000o0?ooo`030000003/k>`0k>c/00d0k>c/00<000000=WI
f@3IfMT01`3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nO
W`2OWil00`2OWil00`000000S8b<08b<S0050?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool00P3oool903lo?`050000001CDe<0De=C05=CD`0000000P1VIVH01@000000NGUi07UiN@1i
NGT0000000@0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036
a/H0a/K600D0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k00>0>c/k0030000003o
ool0oooo02L0oooo0`3o00050?ooo`D0o`00?`3oool00`000000k>c/0>c/k00=0>c/k0030000003I
fMT0fMWI00L0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`030;>c/`030000002O
Wil0WinO0080WinO00<0000008b<S02<S8`01@3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool2
000000<0oooo00<0000006IVIP1VIVH02`1VIVH00`000000NGUi07UiN@0?07UiN@030000002<S8`0
S8b<01<0S8b<00<0000009nOW`2OWil07`2OWil3000005D0/k>c0`00000Q09nOW`8000005@2<S8`0
0`000000NGUi07UiN@0607UiN@@0oooo0P00000`0?ooo`030000003oool0oooo0080oooo00<00000
06IVIP1VIVH02P1VIVH00`000000NGUi07UiN@0:07UiN@030000002<S8`0S8b<0100S8b<00<00000
09nOW`2OWil05@2OWil2000007h0/k>c0P00000H09nOW`030000002<S8`0S8b<00l0S8b<00@00000
07UiN@1iNGT0NGUi1@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo2@0o
?cl00`000000De=C0000000406IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO
09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01@36a/H00`000000fMWI
0=WIf@070=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool09`3oool50?l00080oooo
0P3o00000`00o`00003o0?l000020?l003l0oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI
0=WIf@070=WIf@0300000036a/H0a/K600D0a/K600<000000;>c/`2c/k<00P2c/k<00`000000WinO
09nOW`0309nOW`030000002<S8`0S8b<00D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`020?ooo`T0?clo00@0000005=CD`1CDe<000000`1VIVH01@000000NGUi07UiN@1iNGT00000
00@0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K6
00@0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo
02H0oooo1@3o00030?ooo`80o`0000<00?l00000o`3o00000P3o000n0?ooo`030000003/k>`0k>c/
00d0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c
00<0/k>c00<0000009nOW`2OWil00P2OWil00`000000S8b<08b<S0050?ooo`030000003oool0oooo
01h0oooo000e0?ooo`030000003oool0oooo0080oooo00<0000006IVIP1VIVH02P1VIVH00`000000
NGUi07UiN@0>07UiN@800000502<S8`200000200WinO0P00001K0;>c/`<00000802OWil2000001@0
S8b<00<0000007UiN@1iNGT01@1iNGT50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool00P3oool<06IVIP030000001iNGT0NGUi00/0NGUi00<0000008b<S02<S8`03`2<S8`00`000000
WinO09nOW`0F09nOW`030000002c/k<0/k>c03<0/k>c5P00000f0;>c/`030000002OWil0WinO01H0
WinO00<0000008b<S02<S8`03`2<S8`20000000307UiN@3oool0oooo00<0oooo00<000000?ooo`3o
ool0;@3oool4000000H0oooo00<000000?ooo`3oool00P3oool803lo?`040000001CDe<0De=C0000
00<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO00<0WinO00<00000
0;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00H0fMWI00<00000
0>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0W0?ooo`80o`0000<00?l00000o`3o00000P3o0000
0`3oool0003o0000o`030000o`80o`00?`3oool00`000000k>c/0>c/k00=0>c/k0030000003IfMT0
fMWI00H0fMWI00<000000<K6aP36a/H01@36a/H00`000000/k>c0;>c/`030;>c/`030000002OWil0
WinO0080WinO00<0000008b<S02<S8`01@3oool00`000000oooo0?ooo`0/0?ooo`@000001P3oool0
0`000000oooo0?ooo`020?ooo`T0?clo00@0000005=CD`1CDe<000000P1VIVH00`000000NGUi07Ui
N@0207UiN@050000002<S8`0S8b<08b<S0000000102OWil00`000000/k>c0;>c/`030;>c/`030000
0036a/H0a/K600D0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k00>0>c/k0030000
003oool0oooo02H0oooo0`3o000010000?l00?l00?l0003o00020?ooo`D0003o0P3o000o0?ooo`03
0000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP050<K6aP03
0000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2OWil00`000000S8b<0?ooo`040?ooo`03
0000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo301VIVH00`000000NGUi
07UiN@0>07UiN@030000002<S8`0S8b<0180S8b<0P00000O09nOW`<00000H02c/k<200000200WinO
00<0000008b<S02<S8`04P2<S8`2000000D0NGUi1@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0080oooo2P1VIVH2000000d0NGUi00<0000008b<S02<S8`03P2<S8`2000001L0WinO
0P00000_0;>c/`L000005P36a/H8000002l0/k>c0P00000G09nOW`030000002<S8`0S8b<0100S8b<
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`P0?clo00@0000005=CD`1CDe<0
00000`1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00<0000009nOW`2OWil00`2OWil00`00
0000/k>c0;>c/`030;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01`3IfMT00`00
0000k>c/0>c/k00>0>c/k0030000003oool0oooo02L0oooo00<0o`00003o00000?l01@000?l00`3o
00000?l0003o00020000o`80o`00<03oool30?l000d0oooo00<000000>c/k03/k>`0303/k>`00`00
0000fMWI0=WIf@070=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c/k<00`00
0000WinO09nOW`0209nOW`030000002<S8`0S8b<00D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool903lo
?`040000001CDe<0De=C00000080IVIV00<0000007UiN@1iNGT00P1iNGT01@000000S8b<08b<S02<
S8`0000000@0WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP050<K6aP030000003I
fMT0fMWI00L0fMWI00<000000>c/k03/k>`03@3/k>`2000002P0oooo0P3o00070000o`030?l00000
o`000?l00080003o0P3o000_0?ooo`<0o`003@3oool00`000000k>c/0>c/k00=0>c/k0030000003I
fMT0fMWI00L0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`030;>c/`030000002O
Wil0WinO0080WinO00<0000008b<S03oool0103oool00`000000oooo0?ooo`0N0?ooo`00=@3oool0
0`000000oooo0?ooo`020?ooo`/0IVIV00<0000007UiN@1iNGT03P1iNGT00`000000S8b<08b<S00B
08b<S0030000002OWil0WinO01d0WinO0P00001U0;>c/`<000007P2OWil00`000000S8b<08b<S00B
08b<S0030000001iNGT0NGUi00<0NGUi1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0080oooo2@1VIVH00`000000NGUi07UiN@0;07UiN@800000402<S8`00`000000WinO09nOW`0D
09nOW`<00000;02c/k<5000002D0a/K61@00000/0;>c/`8000005P2OWil200000140S8b<00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`L0?clo00D0000005=CD`1CDe<0De=C0000
000206IVIP030000001iNGT0NGUi0080NGUi00D0000008b<S02<S8`0S8b<0000000409nOW`030000
002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@070=WIf@030000
003/k>`0k>c/00h0k>c/00<000000?ooo`3oool0:03oool01@3o00000?l00000o`000?l00?l00080
o`000P3oool0103o00000?l0003o003o00020000obl0oooo1@3o000<0?ooo`030000003/k>`0k>c/
00`0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c
00@0/k>c00D0000009nOW`2OWil0WinO0000000208b<S0D0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool8
03lo?`040000001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000
002OWil0WinO00<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP050<K6aP030000
003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0X0?ooo`80o`00
00D00?l00000o`00o`000?l00?l000030?ooo`040?l00000o`000?l00?l00080003o;P3oool50?l0
00d0oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K6
00@0a/K600<000000;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0209nOW`030000002<S8`0oooo
00@0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool:06IVIP03
0000001iNGT0NGUi00h0NGUi00<0000008b<S02<S8`04P2<S8`00`000000WinO09nOW`0L09nOW`80
0000JP2c/k<2000001d0WinO0P00000C08b<S0030000001iNGT0NGUi0080NGUi1@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo201VIVH00`000000NGUi07UiN@0;07UiN@03
0000002<S8`0S8b<00l0S8b<00<0000009nOW`2OWil0502OWil00`000000/k>c0;>c/`0X0;>c/`D0
0000;`36a/H4000002X0/k>c00<0000009nOW`2OWil05@2OWil00`000000S8b<08b<S00>08b<S003
0000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool703lo?`050000001CDe<0De=C05=C
D`0000000P1VIVH01@000000NGUi07UiN@1iNGT0000000@0S8b<00<0000009nOW`2OWil00P2OWil0
0`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01`3IfMT0
0`000000k>c/0>c/k00>0>c/k0030000003oool0oooo02T0oooo00<0003o003o0000o`000P3o0004
0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`0[0?ooo`80o`000P00o`030?l000`0oooo00<00000
0>c/k03/k>`0303/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600@0a/K600<00000
0;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0209nOW`030000002<S8`0oooo00@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool803lo?`040000001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi
0000000308b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K6
0<K6aP050<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo
0?ooo`0Y0?ooo`050?l000000?l00?l0003o003o00001@3oool30?l00080oooo00<0003o0?ooo`3o
ool0:P3oool30?l000800?l00P3o000=0?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3I
fMT01`3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`2O
Wil00P2OWil00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000
003oool0oooo0080oooo2@1VIVH2000000l0NGUi00<0000008b<S02<S8`04P2<S8`00`000000WinO
09nOW`0J09nOW`<00000KP2c/k<2000001d0WinO00<0000008b<S02<S8`04@2<S8`200000080NGUi
1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo201VIVH00`000000NGUi
07UiN@0:07UiN@030000002<S8`0S8b<00l0S8b<00<0000009nOW`2OWil0502OWil00`000000/k>c
0;>c/`0W0;>c/`800000>036a/H5000002H0/k>c00<0000009nOW`2OWil05@2OWil00`000000S8b<
08b<S00=08b<S0D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo0P0000030?ooo`L0?clo00D0000005=CD`1CDe<0De=C0000000206IVIP05
0000001iNGT0NGUi07UiN@000000102<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c
0080/k>c00<000000<K6aP36a/H01@36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/
00d0k>c/00<000000?ooo`3oool0:@3oool00`000?l0oooo0?l000020?l000/0oooo00<0003o0?oo
o`3oool02`3oool30?l000<0oooo0`3o000F0?ooo`030?l00000o`000?l000800?l00P3o000<0?oo
o`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP040<K6
aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2OWil00`000000S8b<0?ooo`020?oo
o`<00000;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000020?oo
o`L0?clo00D0000005=CD`1CDe<0De=C0000000206IVIP030000001iNGT0NGUi0080NGUi00D00000
08b<S02<S8`0S8b<0000000409nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01@36
a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool0:@3o
ool010000?l0o`000?l0003o000<0?ooo`030000o`3oool0oooo00/0oooo0`3o00030?ooo`<0o`00
5@3oool20?l000@00?l000<0o`000?ooo`3oool02`3oool00`000000k>c/0>c/k00<0>c/k0030000
003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`030;>c/`030000
002OWil0WinO0080WinO00<000000?ooo`3oool00P3oool200000200oooo000e0?ooo`030000003o
ool0oooo0080oooo201VIVH00`000000NGUi07UiN@0=07UiN@8000004`2<S8`2000001`0WinO00<0
00000;>c/`2c/k<0L@2c/k<2000001`0WinO0P00000C08b<S0030000001iNGT0oooo00@0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`L0IVIV00<0000007UiN@1iNGT02P1i
NGT2000000l0S8b<0P00000E09nOW`8000009@2c/k<5000003l0a/K60`00000T0;>c/`<000005@2O
Wil00`000000S8b<08b<S00<08b<S0D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool703lo?`040000001C
De<0De=C00000080IVIV00D0000007UiN@1iNGT0NGUi0000000408b<S0030000002OWil0WinO0080
WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00L0
fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0W0?ooo`80003o4@3oool20000o`<0
o`001`3oool20?l000800?l000<0o`000?ooo`3o0000103o000E0?ooo`030?l00000o`000?l00080
0?l00P3o000=0?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000
a/K60<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil00P2OWil00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1`0o?cl010000000De=C05=CD`00000306IV
IP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`0309nOW`030000002c/k<0
/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0
k>c/00d0k>c/00<000000?ooo`3oool0:03oool20000oa40oooo0P000?l20?l000P0oooo00<0o`00
003o0000o`000P3o00000`3oool0o`000?l000030?l001@0oooo0P3o0004003o00030?l0003oool0
oooo00`0oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0
a/K600D0a/K600<000000;>c/`2c/k<00`2c/k<00`000000WinO09nOW`0209nOW`030000003oool0
oooo0080oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool706IV
IP030000001iNGT0NGUi00d0NGUi00<0000008b<S02<S8`04@2<S8`2000001/0WinO0`00001f0;>c
/`800000702OWil00`000000S8b<08b<S00A08b<S0800000103oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0080oooo1P1VIVH00`000000NGUi07UiN@0:07UiN@030000002<S8`0S8b<
00h0S8b<00<0000009nOW`2OWil04`2OWil2000002@0/k>c0`0000170<K6aP8000009@2c/k<00`00
0000WinO09nOW`0C09nOW`800000302<S8`50?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1`0o?cl01000
0000De=C05=CD`00000206IVIP050000001iNGT0NGUi07UiN@000000102<S8`00`000000WinO09nO
W`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WI
f@070=WIf@030000003/k>`0k>c/00d0k>c/0P00000X0?ooo`030000o`3oool0oooo0180oooo00<0
o`000000o`00o`000P3o00030?ooo`T0003o0P3o000010000?l00?l00?l0003o000E0?ooo`030?l0
0000o`000?l00080o`003P3oool00`000000k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00H0fMWI
00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`030;>c/`030000002OWil0WinO0080WinO
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`L0?clo00@0000005=CD`1CDe<0
00000`1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00<0000009nOW`2OWil00`2OWil00`00
0000/k>c0;>c/`020;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT01`3IfMT00`00
0000k>c/0>c/k00=0>c/k0030000003oool0oooo02L0oooo00<0003o0?ooo`3oool04@3oool20?l0
00030000o`00o`00o`0000@0oooo20000?l20?l00003003o00000?l0o`000080o`00503oool20?l0
00800?l000<0o`000?ooo`3oool03@3oool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI
00L0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`030;>c/`030000002OWil0WinO
0080WinO00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000
oooo0?ooo`020?ooo`H0IVIV00<0000007UiN@1iNGT03@1iNGT00`000000S8b<08b<S00A08b<S003
0000002OWil0WinO01X0WinO00<000000;>c/`2c/k<0N@2c/k<00`000000WinO09nOW`0J09nOW`80
00004P2<S8`00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool00P3oool506IVIP030000001iNGT0NGUi00X0NGUi00<0000008b<S02<S8`03P2<S8`00`000000
WinO09nOW`0C09nOW`030000002c/k<0/k>c0240/k>c0`00001<0<K6aP@000008P2c/k<2000001D0
WinO00<0000008b<S02<S8`02@2<S8`50?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1P0o?cl010000000
De=C05=CD`00000306IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`02
09nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@08
0=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0B
0?ooo`030?l00000o`000?l000H0003o0P3oool20?l000<0003o00<00?l00?l000000?l00`000?l0
0`00o`00o`000?l000020?l001<0oooo0`3o000@0?ooo`030000003/k>`0k>c/00`0k>c/00<00000
0=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c00<00000
09nOW`2OWil00P2OWil00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1`0o?cl0
10000000De=C05=CD`00000206IVIP050000001iNGT0NGUi07UiN@000000102<S8`00`000000WinO
09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI
0=WIf@070=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`0A0?ooo`80o`0000<00?l00000o`000?l01@000?l20?ooo`030?l00000o`00003o0080003o
00<0o`000000o`000?l00`000?l40?l001<0oooo0`3o000A0?ooo`030000003/k>`0k>c/00/0k>c/
00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c
00<0000009nOW`2OWil00P2OWil00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo
000e0?ooo`030000003oool0oooo0080oooo1P1VIVH00`000000NGUi07UiN@0<07UiN@030000002<
S8`0S8b<0140S8b<00<0000009nOW`2OWil06@2OWil2000007d0/k>c0P00000L09nOW`030000002<
S8`0S8b<00l0S8b<1@3oool00`000000oooo0?ooo`0^0?ooo`8000000`3oool406IVIP030000001i
NGT0NGUi00/0NGUi00<0000008b<S02<S8`0302<S8`2000001D0WinO00<000000;>c/`2c/k<0802c
/k<2000005<0a/K61000000P0;>c/`800000502OWil00`000000S8b<08b<S00808b<S0@0oooo0P00
000_0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`H0?clo00@0000005=CD`1CDe<00000
0`1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00<0000009nOW`2OWil00P2OWil00`000000
/k>c0;>c/`030;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01`3IfMT00`000000
k>c/0>c/k00=0>c/k0030000003oool0oooo02H0oooo00<0003o0?ooo`3oool04`3oool00`3o0000
0?l00000o`020000o`80o`00103oool30?l000030000o`00o`00o`000080o`0000<00?l00000o`00
o`000P000?l2003o0080o`007@3oool30?l000H0oooo00<000000>c/k03/k>`0303/k>`00`000000
fMWI0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c/k<00`000000
WinO09nOW`0209nOW`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool4000000H0
oooo00<000000?ooo`3oool00P3oool703lo?`040000001CDe<0De=C00000080IVIV00D0000007Ui
N@1iNGT0NGUi0000000408b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<0
0`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03@3/k>`0
0`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0180oooo0P3o00030000o`03003o003o0000
oooo00@0oooo0P3o00000`00o`00003o0?l000020?l000800?l000@0003o003o00000?l0003o0P00
o`000`3o0000oooo0?ooo`0L0?ooo`<0o`001@3oool00`000000k>c/0>c/k00<0>c/k0030000003I
fMT0fMWI00L0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`020;>c/`030000002O
Wil0WinO0080WinO00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool2
000000<0oooo1@1VIVH00`000000NGUi07UiN@0<07UiN@030000002<S8`0S8b<0100S8b<0P00000I
09nOW`<00000P@2c/k<3000001X0WinO00<0000008b<S02<S8`03P2<S8`40?ooo`800000<03oool0
0`000000oooo0?ooo`020?ooo`@0IVIV00<0000007UiN@1iNGT02P1iNGT00`000000S8b<08b<S00<
08b<S0030000002OWil0WinO01@0WinO00<000000;>c/`2c/k<07`2c/k<2000005T0a/K60P00000P
0;>c/`030000002OWil0WinO0180WinO00<0000008b<S02<S8`01`2<S8`50?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool00P3oool503lo?`040000001CDe<0De=C000000<0IVIV00D0
000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO00<0WinO00<000000;>c/`2c/k<0
0P2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`0
3@3/k>`00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo01@0oooo0P3o00000`00o`00003o
0?l000020?l000D0oooo1@3o00000`3oool0o`000?l00002003o00050?l00000o`00003o0000o`00
o`000P3o000K0?ooo`030?l00000o`000?l00080o`001@3oool00`000000k>c/0>c/k00<0>c/k003
0000003IfMT0fMWI00H0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`030;>c/`03
0000002OWil0WinO0080WinO00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0080oooo1P0o?cl010000000De=C05=CD`00000306IVIP050000001iNGT0NGUi
07UiN@0000000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<00000
0<K6aP36a/H01036a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00d0k>c/00<00000
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0C0?ooo`<0o`0000@0003o003o003o0000o`001P3o
ool50?l000040?ooo`3o00000?l0003o0080o`0000D00?l00000o`000?l00?l00?l0000L0?ooo`03
0?l00000o`000?l00080o`00103oool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00L0
fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`030;>c/`050000002OWil0WinO09nO
W`000000103oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`<0
IVIV0P00000>07UiN@030000002<S8`0S8b<0100S8b<00<0000009nOW`2OWil0602OWil00`000000
/k>c0;>c/`250;>c/`030000002OWil0WinO01P0WinO0P00000>08b<S0D0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`020?ooo`<0IVIV00<0000007UiN@1iNGT02P1iNGT00`000000
S8b<08b<S00=08b<S0030000002OWil0WinO0140WinO0`00000O0;>c/`<00000G036a/H00`000000
/k>c0;>c/`0O0;>c/`030000002OWil0WinO0180WinO00<0000008b<S02<S8`01P2<S8`50?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool503lo?`040000001CDe<0De=C0000
00<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO0080WinO00<00000
0;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00L0fMWI00<00000
0>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0H0?ooo`<0o`002P3oool00`000?l0oooo0?ooo`0F
0?ooo`D0o`001`3oool30?l000<0oooo103o00001000o`00003o0000o`000?l20?l001X0oooo00<0
o`00003o0000o`000P00o`020?l000D0oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WI
f@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c/k<010000000WinO09nO
W`2OWil50?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool603lo?`040000
001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO
0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI
00L0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0H0?ooo`<0o`002P3oool00`00
0?l0oooo0?ooo`0E0?ooo`D0o`00203oool30?l000<0oooo103o00040000o`030?l0003oool0oooo
01T0oooo00<0o`00003o0000o`000P00o`020?l000@0oooo00<000000>c/k03/k>`0303/k>`00`00
0000fMWI0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c/k<01000
0000WinO09nOW`2OWil50?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo
0080oooo0P1VIVH00`000000NGUi07UiN@0=07UiN@030000002<S8`0S8b<0100S8b<00<0000009nO
W`2OWil05`2OWil2000003l0/k>c3P00000l0;>c/`8000006P2OWil00`000000S8b<08b<S00;08b<
S0D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`0306IVIP0000000000
00`0NGUi00<0000008b<S02<S8`03@2<S8`00`000000WinO09nOW`0A09nOW`030000002c/k<0/k>c
01h0/k>c0P00001P0<K6aP<000007`2c/k<2000001<0WinO0P00000608b<S0D0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`020?ooo`D0?clo00@0000005=CD`1CDe<000000P1VIVH0
0`000000NGUi07UiN@0207UiN@050000002<S8`0S8b<08b<S0000000102OWil00`000000/k>c0;>c
/`030;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/
k00>0>c/k0030000003oool0oooo01L0oooo1@3o00080?ooo`030000o`3oool0oooo01P0oooo0`3o
000A0?ooo`80o`0000<00?l00000o`3o00000P000?lJ0?ooo`030?l00000o`000?l000800?l00P3o
00050?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6
aP040<K6aP030000002c/k<0/k>c00<0/k>c00@0000009nOW`2OWil0WinO1@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo0080oooo1P0o?cl010000000De=C05=CD`00000206IVIP03
0000001iNGT0NGUi0080NGUi00D0000008b<S02<S8`0S8b<0000000409nOW`030000002c/k<0/k>c
0080/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/
00d0k>c/00<000000?ooo`3oool0603oool50?l000P0oooo00<0003o0?ooo`3oool05`3oool30?l0
0140oooo0`3o000010000?l00?l00?l000000?lK0?ooo`030?l00000o`000?l000800?l00P3o0005
0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP03
0<K6aP030000002c/k<0/k>c00<0/k>c00@0000009nOW`2OWil0WinO1@3oool00`000000oooo0?oo
o`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`80IVIV00<0000007UiN@1iNGT0301iNGT0
0`000000S8b<08b<S00?08b<S0800000602OWil2000003L0/k>c2P00000>0<K6aPX00000=02c/k<2
000001T0WinO00<0000008b<S02<S8`02P2<S8`50?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool00P3oool00`000000NGUi07UiN@0:07UiN@8000003P2<S8`2000001<0WinO00<00000
0;>c/`2c/k<0702c/k<3000006D0a/K60`00000N0;>c/`030000002OWil0WinO0180WinO00<00000
08b<S02<S8`00`2<S8`50?ooo`030000003oool0oooo03L0oooo0P0000030?ooo`D0?clo00@00000
05=CD`1CDe<000000P1VIVH01@000000NGUi07UiN@1iNGT0000000@0S8b<00D0000009nOW`2OWil0
WinO000000060;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01P3IfMT00`000000
k>c/0>c/k00=0>c/k0030000003oool0oooo01L0oooo0P3o00000`00o`00003o0?l000020?l000H0
oooo00<0003o0?ooo`3oool0;P3oool50?l000030?ooo`000?l0oooo01P0oooo0P3o0002003o00<0
o`001@3oool00`000000k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP36
a/H01036a/H00`000000/k>c0;>c/`030;>c/`040000002OWil0WinO09nOW`@0oooo0P00000h0?oo
o`8000000`3oool503lo?`040000001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000
000308b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6
aP040<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?oo
o`0G0?ooo`80o`0000<00?l00000o`3o00000P3o00060?ooo`030000o`3oool0oooo02d0oooo1@3o
00000`3oool0003o0?ooo`0I0?ooo`80o`000P00o`030?l000D0oooo00<000000>c/k03/k>`0303/
k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c
/k<00`000000WinO09nOW`040?ooo`800000803oool003D0oooo00<000000?ooo`3oool00P3oool0
0`1VIVH0000007UiN@0=07UiN@030000002<S8`0S8b<00l0S8b<00<0000009nOW`2OWil05`2OWil0
0`000000/k>c0;>c/`0`0;>c/`L000008P36a/H500000340/k>c00<0000009nOW`2OWil05`2OWil0
0`000000S8b<08b<S00908b<S0D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`02
0?ooo`d0NGUi00<0000008b<S02<S8`0302<S8`00`000000WinO09nOW`0A09nOW`8000007@2c/k<2
000006/0a/K60P00000M0;>c/`030000002OWil0WinO0180WinO00<0000008b<S02<S8`00P2<S8`5
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool503lo?`040000001CDe<0
De=C00000080IVIV00D0000007UiN@1iNGT0NGUi0000000408b<S0050000002OWil0WinO09nOW`00
00001@2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/
k>`03@3/k>`00`000000oooo0?ooo`0G0?ooo`030?l00000o`00003o0080003o0P3o00040?ooo`80
003o<P3oool30?l000<0oooo00<0003o0?ooo`3oool05`3oool50?l000L0oooo00<000000>c/k03/
k>`0303/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c
/k<00P2c/k<010000000WinO09nOW`2OWil50?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool00P3oool503lo?`040000001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000
000308b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6
aP040<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`0303/k>`00`000000oooo0?oo
o`0H0?ooo`030?l00000o`00003o0080003o0P3o00040?ooo`80003o<@3oool30?l000<0oooo00<0
003o0?ooo`3oool0603oool50?l000L0oooo00<000000>c/k03/k>`02`3/k>`00`000000fMWI0=WI
f@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c/k<00`000000WinO09nO
W`050?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo00<00000
07UiN@1iNGT02`1iNGT200000180S8b<00<0000009nOW`2OWil05@2OWil2000002d0/k>c1P00000^
0<K6aPD00000;@2c/k<2000001P0WinO00<0000008b<S02<S8`0202<S8`50?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool00P3oool<07UiN@030000002<S8`0S8b<00`0S8b<00<00000
09nOW`2OWil04@2OWil00`000000/k>c0;>c/`0K0;>c/`800000K`36a/H2000001`0/k>c00<00000
09nOW`2OWil04@2OWil00`000000S8b<08b<S00208b<S0D0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`020?ooo`@0?clo00@0000005=CD`1CDe<000000`1VIVH010000000NGUi07Ui
N@00000408b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K6
0<K6aP050<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo
0?ooo`0H0?ooo`030?l00000o`00003o0080003o103o00000`3oool0003o0?ooo`0j0?ooo`030000
o`3oool0oooo01L0oooo0`3o00080?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT0
1P3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c0080/k>c00@0000009nOW`2OWil0
WinO1@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo1@0o?cl010000000
De=C05=CD`00000206IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`02
09nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@07
0=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool06@3oool00`3o00000?l00000o`02
0000o`<0o`000P3oool00`000?l0oooo0?ooo`0h0?ooo`80003o6@3oool30?l000P0oooo00<00000
0>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600<00000
0;>c/`2c/k<00`2c/k<00`000000WinO09nOW`050?ooo`030000003oool0oooo01h0oooo000e0?oo
o`030000003oool0oooo0080oooo3@1iNGT00`000000S8b<08b<S00@08b<S08000005P2OWil20000
02d0/k>c0P00000i0<K6aPD00000:P2c/k<2000001L0WinO0P00000808b<S0D0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`020?ooo`/0NGUi00<0000008b<S02<S8`0302<S8`00`00
0000WinO09nOW`0A09nOW`030000002c/k<0/k>c01T0/k>c0`00001c0<K6aP<000006P2c/k<20000
0180WinO00@0000008b<S02<S8`0S8b<1@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0080oooo100o?cl010000000De=C05=CD`00000306IVIP040000001iNGT0NGUi000000@0S8b<
00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600D0a/K6
00<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00<0>c/k08000006`3oool01@3o0000003o
003o003o0000003o00<0o`0000<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0R0?ooo`03
0000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP030<K6aP03
0000002c/k<0/k>c00<0/k>c00<0000009nOW`2OWil01@3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0080oooo1@0o?cl010000000De=C05=CD`00000206IVIP050000001iNGT0NGUi
07UiN@0000000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<00000
0<K6aP36a/H01036a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00`0k>c/00<00000
0?ooo`3oool06P3oool01@3o0000003o003o003o0000003o00<0o`0000<0003o0?ooo`3oool0>`3o
ool00`000?l0oooo0?ooo`0R0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT01P3I
fMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`3oool0103o
ool00`000000oooo0?ooo`0N0?ooo`00:`3oool4000000H0oooo00<000000?ooo`3oool00P3oool<
07UiN@030000002<S8`0S8b<0100S8b<00<0000009nOW`2OWil05@2OWil00`000000/k>c0;>c/`0X
0;>c/`D00000@036a/H2000002X0/k>c0P00000G09nOW`030000002<S8`0S8b<00D0S8b<1@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo2P1iNGT00`000000S8b<08b<S00<
08b<S0030000002OWil0WinO0140WinO00<000000;>c/`2c/k<06@2c/k<00`000000a/K60<K6aP1g
0<K6aP8000006P2c/k<00`000000WinO09nOW`0@09nOW`80000000<0S8b<0?ooo`3oool00`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo100o?cl010000000De=C05=CD`00
000306IVIP040000001iNGT0NGUi000000@0S8b<00D0000009nOW`2OWil0WinO000000050;>c/`03
00000036a/H0a/K600D0a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00<0>c/k003
0000003oool0oooo01X0oooo00<0003o0?l0003o00000P3o00030000o`80o`00?@3oool20000o`80
o`008@3oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00H0fMWI00<000000<K6aP36
a/H00`36a/H00`000000/k>c0;>c/`030;>c/`030000002OWil0WinO00D0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`020?ooo`D0?clo00<0000005=CD`0000000`1VIVH010000000
NGUi07UiN@00000408b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`00
0000a/K60<K6aP040<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`0303/k>`00`00
0000oooo0?ooo`0J0?ooo`030000o`3o0000o`000080o`0000@0003o003o00000?l0o`00?P3oool0
10000?l0o`000?l0003o000P0?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT01@3I
fMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`3oool0103o
ool00`000000oooo0?ooo`0N0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool<07UiN@030000002<S8`0S8b<00h0S8b<0P00000G
09nOW`030000002c/k<0/k>c02L0/k>c0P0000170<K6aP<00000:02c/k<2000001L0WinO00<00000
08b<S02<S8`0102<S8`50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool9
07UiN@030000002<S8`0S8b<00`0S8b<00<0000009nOW`2OWil0402OWil2000001X0/k>c0P00001l
0<K6aP030000002c/k<0/k>c01P0/k>c0P00000B09nOW`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`<0?clo00D0000005=CD`1CDe<0De=C0000
000206IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`0209nOW`030000
002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@060=WIf@030000
003/k>`0k>c/00`0k>c/00<000000?ooo`3oool06P3oool01P000?l0oooo0?ooo`3oool0o`00003o
00<0003o0P3o000m0?ooo`80o`0000<0003o003o003o0000803oool00`000000k>c/0>c/k00;0>c/
k0030000003IfMT0fMWI00H0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`020;>c
/`030000002OWil0WinO00D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?oo
o`@0?clo00@0000005=CD`1CDe<000000`1VIVH010000000NGUi07UiN@00000408b<S0030000002O
Wil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003I
fMT0fMWI00L0fMWI00<000000>c/k03/k>`0303/k>`00`000000oooo0?ooo`0J0?ooo`030000o`3o
ool0oooo0080o`000`000?l00`00o`00o`000?ooo`0m0?ooo`030?l000000?l0003o0080o`007`3o
ool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00H0fMWI00<000000<K6aP36a/H01036
a/H00`000000/k>c0;>c/`020;>c/`030000002OWil0oooo00@0oooo00<000000?ooo`3oool07P3o
ool002l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`/0NGUi00<00000
08b<S02<S8`03P2<S8`00`000000WinO09nOW`0F09nOW`030000002c/k<0/k>c02D0/k>c0`00001<
0<K6aP@000009P2c/k<2000001H0WinO00<0000008b<S02<S8`00`2<S8`50?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool00P3oool807UiN@030000002<S8`0S8b<00/0S8b<0P00000B
09nOW`030000002c/k<0/k>c01P0/k>c0P00001o0<K6aP8000006@2c/k<00`000000WinO09nOW`0A
09nOW`030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`02
0?ooo`<0?clo00@0000005=CD`1CDe<000000`1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<
00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600<0a/K6
0P0000080=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool06P3oool01@000?l0oooo
0?ooo`3oool0o`0000800?l000@0003o003o003o0000o`00?03oool20?l000<0003o00<00?l00?l0
003oool07P3oool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00D0fMWI0P0000050<K6
aP030000002c/k<0/k>c00<0/k>c00<0000009nOW`3oool0103oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0080oooo100o?cl010000000De=C05=CD`00000306IVIP040000001iNGT0
NGUi000000@0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`020;>c/`0300000036
a/H0a/K600@0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k00<0>c/k0030000003o
ool0oooo01X0oooo00<0003o0?ooo`3oool00P3o00001@00o`00003o003o0000o`00o`0003d0oooo
00<0o`00003o00000?l00P000?l20?l001l0oooo00<000000>c/k03/k>`02`3/k>`00`000000fMWI
0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c/k<00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo00<0oooo0P00
00030?ooo`T0NGUi0P00000@08b<S08000005P2OWil2000002<0/k>c1@00001C0<K6aP<00000902c
/k<00`000000WinO09nOW`0E09nOW`030000002<S8`0S8b<0080S8b<103oool200000300oooo0P00
00030?ooo`L0NGUi00<0000008b<S02<S8`02`2<S8`00`000000WinO09nOW`0A09nOW`030000002c
/k<0/k>c01L0/k>c0P0000230<K6aP800000602c/k<200000140WinO103oool2000003T0oooo00<0
00000?ooo`3oool00P3oool303lo?`040000001CDe<0De=C00000080IVIV00D0000007UiN@1iNGT0
NGUi0000000308b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000
a/K60<K6aP040<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`0303/k>`00`000000
oooo0?ooo`0J0?ooo`030000o`3oool0oooo00<0oooo00<0o`00003o0000o`000P3o000m0?ooo`80
o`0000D00?l00000o`00o`00003o0?l0000P0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WI
f@3IfMT01P3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c0080/k>c00<0000009nO
W`3oool0103oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0`0o?cl01000
0000De=C05=CD`00000306IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nO
W`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WI
f@070=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool06P3oool00`000?l0oooo0?oo
o`020?ooo`80o`000P00o`000`3o0000oooo0?ooo`0l0?ooo`030?l00000o`000?l00080003o0P3o
000O0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6
aP040<K6aP030000002c/k<0/k>c00<0/k>c00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0N0?ooo`008@3oool6000000H0oooo0P0000060?ooo`030000003oool0oooo0080oooo201iNGT0
0`000000S8b<08b<S00?08b<S0030000002OWil0WinO01@0WinO0P00000S0;>c/`800000F`36a/H2
000002<0/k>c0P00000F09nOW`8000000P2<S8`50?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool00P3oool707UiN@030000002<S8`0S8b<00/0S8b<00<0000009nOW`2OWil0402OWil0
0`000000/k>c0;>c/`0H0;>c/`0300000036a/H0a/K608<0a/K600<000000;>c/`2c/k<0602c/k<0
0`000000WinO09nOW`0>09nOW`D0oooo00<000000?ooo`3oool0=`3oool2000000<0oooo0`0o?cl0
10000000De=C05=CD`00000206IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO
09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI
0=WIf@060=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo
0?ooo`050?ooo`<0o`00?P3oool30?l000800?l000<0003o0?l0003oool0803oool00`000000k>c/
0>c/k00;0>c/k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c
0;>c/`030;>c/`030000003oool0oooo0080oooo0P00000h0?ooo`8000000`3oool303lo?`040000
001CDe<0De=C000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO
0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI
00L0fMWI00<000000>c/k03/k>`0303/k>`00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo
00@0oooo0`3o000o0?ooo`80o`000P00o`000`000?l0o`000?l0000P0?ooo`030000003/k>`0k>c/
00/0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c
0080/k>c00<000000?ooo`3oool00P3oool200000200oooo000_0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool807UiN@030000002<S8`0S8b<00h0S8b<00<0000009nOW`2O
Wil0502OWil00`000000/k>c0;>c/`0P0;>c/`<00000G`36a/H300000280/k>c0P00000F09nOW`03
0000002<S8`0oooo00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`D0
NGUi0P00000=08b<S0030000002OWil0WinO00l0WinO0P00000I0;>c/`800000?@36a/H<000003h0
a/K60P00000I0;>c/`030000002OWil0WinO00d0WinO1@3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0080oooo0P0o?cl010000000De=C05=CD`00000306IVIP040000001iNGT0NGUi
000000@0S8b<00D0000009nOW`2OWil0WinO000000050;>c/`0300000036a/H0a/K600@0a/K600<0
00000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo01X0oooo00<0
003o0?ooo`3oool0A`3oool50?l000030000o`3oool0oooo01l0oooo00<000000>c/k03/k>`02`3/
k>`00`000000fMWI0=WIf@050=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00`2c
/k<00`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3o
ool303lo?`040000001CDe<0De=C00000080IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S003
0000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP040<K6aP03
0000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`0303/k>`00`000000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo04L0oooo103o00000`000?l0oooo0?ooo`0P0?ooo`030000003/k>`0k>c/00X0
k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c0080
/k>c00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo1`1iNGT00`000000S8b<08b<S00>08b<S0030000
002OWil0WinO01@0WinO00<000000;>c/`2c/k<07`2c/k<2000006D0a/K60`00000Q0;>c/`030000
002OWil0WinO01@0WinO00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0080oooo101iNGT00`000000S8b<08b<S00<08b<S0030000002OWil0WinO00l0WinO
00<000000;>c/`2c/k<05P2c/k<3000003D0a/K62P00000<0=WIf@X00000=P36a/H2000001P0/k>c
0P00000=09nOW`D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`80?clo
00@0000005=CD`1CDe<000000`1VIVH010000000NGUi07UiN@00000408b<S0050000002OWil0WinO
09nOW`0000001@2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00H0fMWI00<00000
0>c/k03/k>`0303/k>`00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo04T0oooo0`3o0002
0?ooo`030000o`3oool0oooo01l0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@06
0=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00P2c/k<00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool303lo?`040000001CDe<0
De=C00000080IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO0080WinO
00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00H0fMWI
00<000000>c/k03/k>`0303/k>`00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo04T0oooo
0`3o00000`3oool0003o0?ooo`0P0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT0
1P3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c0080/k>c00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0N0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool607UiN@030000002<S8`0S8b<00h0S8b<00<0
000009nOW`2OWil04`2OWil200000200/k>c0P00001Z0<K6aP800000802c/k<2000001@0WinO00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo0`1i
NGT00`000000S8b<08b<S00<08b<S0030000002OWil0WinO00l0WinO00<000000;>c/`2c/k<05P2c
/k<00`000000a/K60<K6aP0a0<K6aPD00000803IfMT700000340a/K60P00000H0;>c/`030000002O
Wil0WinO00X0WinO1@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo0P0o
?cl010000000De=C05=CD`00000306IVIP040000001iNGT0NGUi000000<0S8b<00<0000009nOW`2O
Wil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3I
fMT01P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo01P0oooo00<0003o0?ooo`3o
ool0C`3oool00`000?l0oooo0?ooo`0O0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3I
fMT01P3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c0080/k>c00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0`0o?cl010000000
De=C05=CD`00000206IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`02
09nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@05
0=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`1>
0?ooo`030000o`3oool0oooo0200oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@06
0=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c/k<00P2c/k<00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01h0oooo000[0?ooo`@000001P3oool00`000000oooo0?ooo`020?oo
o`D0NGUi00<0000008b<S02<S8`03P2<S8`00`000000WinO09nOW`0C09nOW`030000002c/k<0/k>c
01l0/k>c00<000000<K6aP36a/H0J`36a/H3000001l0/k>c0P00000D09nOW`030000003oool0oooo
0080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`<0NGUi00<0000008b<
S02<S8`02`2<S8`00`000000WinO09nOW`0?09nOW`030000002c/k<0/k>c01H0/k>c00<000000<K6
aP36a/H0;P36a/H4000002`0fMWI0`00000`0<K6aP030000002c/k<0/k>c01H0/k>c00<0000009nO
W`2OWil02@2OWil50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool01@0o
?cl0000005=CD`1CDe<0000000<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002O
Wil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003I
fMT0fMWI00L0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo0500oooo00<0003o0?ooo`3oool07`3oool00`000000k>c/0>c/k00:0>c/k0030000003I
fMT0fMWI00H0fMWI00<000000<K6aP36a/H01036a/H00`000000/k>c0;>c/`020;>c/`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`80?clo00@0
000005=CD`1CDe<000000P1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00<0000009nOW`2O
Wil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3I
fMT01P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo01T0oooo00<0003o0?ooo`3o
ool0C`3oool00`000?l0oooo0?ooo`0O0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3I
fMT01P3IfMT00`000000a/K60<K6aP030<K6aP030000002c/k<0/k>c0080/k>c00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`@0NGUi
00<0000008b<S02<S8`03@2<S8`2000001D0WinO00<000000;>c/`2c/k<07P2c/k<200000740a/K6
00<000000;>c/`2c/k<07P2c/k<200000180WinO1@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0080oooo0P1iNGT00`000000S8b<08b<S00;08b<S0030000002OWil0WinO00l0WinO
00<000000;>c/`2c/k<05P2c/k<00`000000a/K60<K6aP0Z0<K6aPD00000<`3IfMT5000002`0a/K6
0P00000G0;>c/`030000002OWil0WinO00P0WinO1@3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0080oooo00D0?clo0000001CDe<0De=C0000000306IVIP030000001iNGT0NGUi0080
00000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36
a/H01036a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo01l0oooo00<000000>c/k03/
k>`02P3/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600<000000;>c/`2c
/k<00P2c/k<50?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool203lo?`04
0000001CDe<0De=C00000080IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S0030000002OWil0
WinO0080WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0
fMWI00H0fMWI00<000000>c/k03/k>`02`3/k>`2000001X0oooo00<0003o0?ooo`3oool0D03oool0
0`000?l0oooo0?ooo`0P0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01P3IfMT0
0`000000a/K60<K6aP030<K6aP030000002c/k<0/k>c0080/k>c1@3oool00`000000oooo0?ooo`0N
0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`<0NGUi00<0000008b<S02<S8`03@2<S8`00`00
0000WinO09nOW`0C09nOW`8000007P2c/k<3000007@0a/K60P00000P0;>c/`030000002OWil0WinO
00l0WinO1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<0NGUi0000
002<S8`0302<S8`00`000000WinO09nOW`0>09nOW`8000005`2c/k<2000002X0a/K60`00000m0=WI
f@@00000:P36a/H2000001H0/k>c00<0000009nOW`2OWil01`2OWil50?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool00P3oool01@0o?cl0000005=CD`1CDe<000000080IVIV00D00000
07UiN@1iNGT0NGUi0000000308b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00`2c
/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`0303/
k>`00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo05<0oooo00<0003o0?l0003o00007P3o
ool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00H0fMWI00<000000<K6aP36a/H01036
a/H00`000000/k>c0;>c/`020;>c/`D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`020?ooo`0503lo?`000000De=C05=CD`0000000`1VIVH01@000000NGUi07UiN@1iNGT0000000<0
S8b<00D0000009nOW`2OWil0WinO000000050;>c/`0300000036a/H0a/K600@0a/K600<000000=WI
f@3IfMT01P3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo01T0oooo00<0003o0?oo
o`3oool0DP3oool010000?l0o`000?l0003o000N0?ooo`030000003/k>`0k>c/00X0k>c/00<00000
0=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP040<K6aP040000002c/k<0/k>c0;>c/`D0oooo00<0
00000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool207UiN@030000002<S8`0
S8b<00d0S8b<00<0000009nOW`2OWil04P2OWil2000001h0/k>c0P00001i0<K6aP8000007`2c/k<0
0`000000WinO09nOW`0>09nOW`D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`02
0?ooo`030000002<S8`0S8b<00/0S8b<00<0000009nOW`2OWil03P2OWil00`000000/k>c0;>c/`0E
0;>c/`8000009`36a/H5000004@0fMWI0`00000Y0<K6aP030000002c/k<0/k>c01@0/k>c0P000007
09nOW`D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`0503lo?`000000
De=C05=CD`0000000P1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00<0000009nOW`2OWil0
0P2OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT0
1P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0
DP3oool20?l000030000o`3o0000o`0001h0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI
0=WIf@060=WIf@0300000036a/H0a/K600@0a/K600@000000;>c/`2c/k<0/k>c1@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00D0?clo0000001CDe<0De=C0000000306IV
IP050000001iNGT0NGUi07UiN@0000000`2<S8`01@000000WinO09nOW`2OWil0000000D0/k>c00<0
00000<K6aP36a/H01036a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00/0k>c/00<0
00000?ooo`3oool06@3oool00`000?l0oooo0?ooo`1B0?ooo`030?l000000?l0o`000080o`007P3o
ool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00H0fMWI00<000000<K6aP36a/H00`36
a/H010000000/k>c0;>c/`2c/k<50?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003o
ool0oooo0080oooo00<0NGUi0000002<S8`03P2<S8`00`000000WinO09nOW`0B09nOW`030000002c
/k<0/k>c01`0/k>c0P00001m0<K6aP8000007P2c/k<00`000000WinO09nOW`0=09nOW`D0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`d0S8b<00<0000009nOW`2OWil03P2O
Wil00`000000/k>c0;>c/`0D0;>c/`8000009`36a/H2000004`0fMWI0`00000W0<K6aP030000002c
/k<0/k>c01D0/k>c00<0000009nOW`2OWil0102OWil50?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool00P3oool010000000De=C05=CD`00000306IVIP040000001iNGT0NGUi000000<0
S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600<0
a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo01P0
oooo00<0003o0?ooo`3oool0DP3oool30?l00080003o0P3o000M0?ooo`030000003/k>`0k>c/00/0
k>c/00<000000=WIf@3IfMT01@3IfMT00`000000a/K60<K6aP040<K6aP040000002c/k<0/k>c0;>c
/`D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`0503lo?`000000De=C
05=CD`0000000P1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00<0000009nOW`2OWil00P2O
Wil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01P3I
fMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0DP3o
ool20?l00080003o00<00?l00?l0003o00007@3oool00`000000k>c/0>c/k00:0>c/k0030000003I
fMT0fMWI00H0fMWI00<000000<K6aP36a/H00`36a/H010000000/k>c0;>c/`2c/k<50?ooo`030000
003oool0oooo01h0oooo000e0?ooo`8000000`3oool00`1iNGT0000008b<S00>08b<S0030000002O
Wil0WinO0140WinO0P00000M0;>c/`0300000036a/H0a/K607l0a/K60`00000L0;>c/`8000003@2O
Wil40?ooo`800000<03oool00`000000oooo0?ooo`020?ooo``0S8b<00<0000009nOW`2OWil03P2O
Wil00`000000/k>c0;>c/`0D0;>c/`0300000036a/H0a/K602@0a/K60`00001A0=WIf@<000009@36
a/H2000001H0/k>c00<0000009nOW`2OWil00`2OWil50?ooo`030000003oool0oooo03L0oooo0P00
00030?ooo`040000001CDe<0De=C00000080IVIV0P00000207UiN@050000002<S8`0S8b<08b<S000
0000102OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3I
fMT01P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo01L0oooo00<0003o0?ooo`3o
ool0D`3oool20?l00005003o00000?l0003o0000o`3o00007P3oool00`000000k>c/0>c/k00:0>c/
k0030000003IfMT0fMWI00H0fMWI00<000000<K6aP36a/H00`36a/H010000000/k>c0;>c/`2c/k<4
0?ooo`800000>03oool2000000<0oooo00D0?clo0000001CDe<0De=C0000000206IVIP050000001i
NGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c0080/k>c
00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00/0k>c/
00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`1C0?ooo`80o`000`000?l00`00o`00o`00
0?ooo`0M0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000a/K6
0<K6aP040<K6aP030000002c/k<0/k>c00@0oooo0P00000P0?ooo`00=@3oool00`000000oooo0?oo
o`020?ooo`030000002<S8`0S8b<00`0S8b<0P00000C09nOW`030000002c/k<0/k>c01/0/k>c0P00
00250<K6aP030000002c/k<0/k>c01/0/k>c00<0000009nOW`2OWil02P2OWil50?ooo`030000003o
ool0oooo02h0oooo0P0000030?ooo`/0S8b<00<0000009nOW`2OWil03P2OWil00`000000/k>c0;>c
/`0D0;>c/`0300000036a/H0a/K602<0a/K60P00001G0=WIf@8000009@36a/H00`000000/k>c0;>c
/`0D0;>c/`030000002OWil0WinO0080WinO103oool2000003T0oooo00<000000?ooo`3oool00P3o
ool010000000De=C05=CD`00000206IVIP050000001iNGT0NGUi07UiN@0000000`2<S8`00`000000
WinO09nOW`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H00`36a/H00`000000
fMWI0=WIf@060=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool0603oool00`000?l0
oooo0?ooo`1C0?ooo`80o`000P00o`020000o`030?l0003oool0oooo01`0oooo00<000000>c/k03/
k>`02P3/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600<0a/K600@000000;>c/`2c
/k<0/k>c1@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00D0000005=C
D`1CDe<0De=C0000000206IVIP050000001iNGT0NGUi07UiN@0000000P2<S8`00`000000WinO09nO
W`0209nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WI
f@060=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool0603oool00`000?l0oooo0?oo
o`1C0?ooo`80o`0000D00?l00000o`000?l00?l00?l0000N0?ooo`030000003/k>`0k>c/00X0k>c/
00<000000=WIf@3IfMT01@3IfMT00`000000a/K60<K6aP040<K6aP030000002c/k<0/k>c00D0oooo
00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool>08b<S0030000002O
Wil0WinO0140WinO0P00000K0;>c/`<00000R036a/H2000001`0/k>c00<0000009nOW`2OWil02@2O
Wil50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool:08b<S0030000002O
Wil0WinO00h0WinO00<000000;>c/`2c/k<0502c/k<00`000000a/K60<K6aP0R0<K6aP800000F`3I
fMT2000002@0a/K600<000000;>c/`2c/k<0502c/k<010000000WinO09nOW`2OWil50?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`000000De=C0000000306IVIP050000
001iNGT0NGUi07UiN@0000000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c0080
/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00`0
k>c/00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1E0?ooo`80o`000P00o`000`3o0000
003o0?ooo`0N0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000
a/K60<K6aP040<K6aP030000002c/k<0/k>c00D0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`020?ooo`040000001CDe<0De=C00000080IVIV00D0000007UiN@1iNGT0NGUi00000003
08b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP04
0<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo05D0oooo0P3o0002003o00030000o`3oool0oooo01d0oooo00<00000
0>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@050=WIf@0300000036a/H0a/K600@0a/K600<00000
0;>c/`3oool0103oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?oo
o`d0S8b<00<0000009nOW`2OWil04@2OWil00`000000/k>c0;>c/`0I0;>c/`800000S@36a/H20000
01/0/k>c0P00000909nOW`D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`T0S8b<00<0000009nOW`2OWil03P2OWil00`000000/k>c0;>c/`0C0;>c/`8000008P36a/H30000
05l0fMWI0`00000R0<K6aP8000005@2c/k<00`000000WinO09nOW`050?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool00P3oool205=CD`050000001VIVH0IVIV06IVIP0000000`1iNGT0
1@000000S8b<08b<S02<S8`0000000<0WinO00<000000;>c/`2c/k<00`2c/k<00`000000a/K60<K6
aP040<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`0303/k>`00`000000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo05L0oooo0`3o00000`3oool0003o0?ooo`0N0?ooo`030000003/
k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP030<K6aP030000002c
/k<0/k>c00D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`<0De=C00@0
000006IVIP1VIVH000000`1iNGT01@000000S8b<08b<S02<S8`0000000@0WinO00<000000;>c/`2c
/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/
k>`02`3/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo05L0oooo0`3o00000`3oool0
003o0?ooo`0N0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000
a/K60<K6aP040<K6aP030000002c/k<0oooo00@0oooo00<000000?ooo`3oool07P3oool003D0oooo
00<000000?ooo`3oool00P3oool<08b<S0030000002OWil0WinO0140WinO00<000000;>c/`2c/k<0
6@2c/k<00`000000a/K60<K6aP2?0<K6aP030000002c/k<0/k>c01X0/k>c00<0000009nOW`2OWil0
1P2OWil50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool808b<S0030000
002OWil0WinO00h0WinO00<000000;>c/`2c/k<04`2c/k<00`000000a/K60<K6aP0O0<K6aP<00000
I@3IfMT200000280a/K60P00000D0;>c/`030000002OWil0oooo00@0oooo00<000000?ooo`3oool0
6`3oool4000000H0oooo0P0000050?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`80De=C
00@0000006IVIP1VIVH000000`1iNGT01@000000S8b<08b<S02<S8`0000000@0WinO00<000000;>c
/`2c/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/
k03/k>`0303/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo05`0oooo00<0003o0?oo
o`3oool0703oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00H0fMWI00<000000<K6
aP36a/H00`36a/H00`000000/k>c0;>c/`050?ooo`030000003oool0oooo01X0oooo100000060?oo
o`8000001@3oool6000000D0oooo00<000000?ooo`3oool00P3oool305=CD`040000001VIVH0IVIV
000000<0NGUi00D0000008b<S02<S8`0S8b<0000000309nOW`030000002c/k<0/k>c00<0/k>c00<0
00000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00/0k>c/00<0
00000?ooo`3oool0603oool00`000?l0oooo0?ooo`1L0?ooo`030000o`3oool0oooo01`0oooo00<0
00000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@050=WIf@0300000036a/H0a/K600@0a/K600<0
00000;>c/`3oool0103oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`02
0?ooo``0S8b<00<0000009nOW`2OWil0402OWil2000001T0/k>c0`0000130<K6aP`00000@`36a/H2
000001X0/k>c00<0000009nOW`2OWil01P2OWil50?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool00P3oool708b<S08000003P2OWil2000001@0/k>c0P00000P0<K6aP800000JP3IfMT3
00000240a/K600<000000;>c/`2c/k<04P2c/k<2000000@0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`80De=C00@00000
06IVIP1VIVH000000`1iNGT01@000000S8b<08b<S02<S8`0000000@0WinO00<000000;>c/`2c/k<0
0P2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`0
2`3/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo05h0oooo00<0003o0?ooo`3oool0
703oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H0
1036a/H00`000000/k>c0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool205=CD`8000000P1VIVH010000000NGUi
07UiN@00000408b<S0050000002OWil0WinO09nOW`0000001@2c/k<00`000000a/K60<K6aP030<K6
aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0G0?oo
o`030000o`3oool0oooo05d0oooo00<0003o0?ooo`3oool07@3oool00`000000k>c/0>c/k00:0>c/
k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H01036a/H00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo2P2<S8`200000140
WinO0P00000I0;>c/`800000?036a/H:000000`0fMWI3000000i0<K6aP8000006@2c/k<2000000H0
WinO1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo1P2<S8`00`000000
WinO09nOW`0=09nOW`030000002c/k<0/k>c01@0/k>c00<000000<K6aP36a/H07P36a/H00`000000
fMWI0=WIf@1]0=WIf@8000008036a/H00`000000/k>c0;>c/`0B0;>c/`030000003oool0oooo0080
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`80De=C00@0000006IVIP1V
IVH000000`1iNGT01@000000S8b<08b<S02<S8`0000000@0WinO00<000000;>c/`2c/k<00P2c/k<0
0`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02`3/k>`0
0`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0600oooo00@0003o0?l0003o0000o`006P3o
ool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H01036
a/H00`000000/k>c0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool205=CD`050000001VIVH0IVIV06IVIP0000000P1iNGT00`000000S8b<08b<S00208b<S0050000
002OWil0WinO09nOW`0000001@2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00D0
fMWI00<000000>c/k03/k>`0303/k>`00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo05l0
oooo00@0003o0?l0003o0000o`006`3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI
00D0fMWI00<000000<K6aP36a/H01036a/H00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01h0oooo000e0?ooo`030000003oool0oooo0080oooo2@2<S8`00`000000WinO09nOW`0A09nOW`03
0000002c/k<0/k>c01P0/k>c00<000000<K6aP36a/H0<`36a/H800000280fMWI1@00000f0<K6aP03
0000002c/k<0/k>c01P0/k>c00<0000009nOW`2OWil00`2OWil50?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool00P3oool608b<S0030000002OWil0WinO00`0WinO00<000000;>c/`2c
/k<04`2c/k<2000001l0a/K60P00001b0=WIf@0300000036a/H0a/K601h0a/K600<000000;>c/`2c
/k<04@2c/k<50?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@1CDe<0
000006IVIP1VIVH0000000<0NGUi00D0000008b<S02<S8`0S8b<0000000409nOW`030000002c/k<0
/k>c0080/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0
k>c/00X0k>c/00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1P0?ooo`030000o`3o0000
o`000080o`006P3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00D0fMWI00<00000
0<K6aP36a/H01036a/H00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool205=CD`040000001VIVH0IVIV000000<0NGUi00D0000008b<S02<S8`0S8b<
0000000309nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI
0=WIf@050=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`1O0?ooo`030?l000000?l0o`000080o`006`3oool00`000000k>c/0>c/k00:0>c/k0030000
003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H00`36a/H00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo202<S8`00`000000WinO09nO
W`0A09nOW`030000002c/k<0/k>c01L0/k>c0P00000a0<K6aPD00000;`3IfMT500000380a/K60P00
000I0;>c/`030000002OWil0WinO0080WinO1@3oool00`000000oooo0?ooo`0S0?ooo`H000001@3o
ool00`000000oooo0?ooo`020?ooo`D0S8b<00<0000009nOW`2OWil03@2OWil00`000000/k>c0;>c
/`0B0;>c/`0300000036a/H0a/K601d0a/K60P00001e0=WIf@8000007`36a/H00`000000/k>c0;>c
/`0@0;>c/`D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00D0De=C0000001VIVH0IVIV
0000000307UiN@050000002<S8`0S8b<08b<S0000000102OWil00`000000/k>c0;>c/`020;>c/`03
00000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00:0>c/k003
0000003oool0oooo01H0oooo00<0003o0?ooo`3oool0H03oool20?l00080003o0`3o000I0?ooo`03
0000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000a/K60<K6aP040<K6aP04
0000003oool0oooo0?ooo`<000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool300000080oooo0P1CDe<010000000IVIV06IVIP000003
07UiN@050000002<S8`0S8b<08b<S00000000`2OWil00`000000/k>c0;>c/`030;>c/`0300000036
a/H0a/K600@0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003o
ool0oooo01H0oooo00<0003o0?ooo`3oool0G`3oool30?l000040000o`00o`00o`000?l001X0oooo
00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@050=WIf@0300000036a/H0a/K600<0a/K6
00<000000?ooo`3oool00P3oool200000200oooo000e0?ooo`030000003oool0oooo0080oooo1`2<
S8`00`000000WinO09nOW`0@09nOW`800000602c/k<2000002l0a/K61000000i0=WIf@D00000;`36
a/H2000001P0/k>c0P00000209nOW`D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool408b<S0030000002O
Wil0WinO00d0WinO00<000000;>c/`2c/k<04P2c/k<00`000000a/K60<K6aP0L0<K6aP800000N@3I
fMT2000001h0a/K60P00000@0;>c/`D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`0505=CD`000000IVIV06IVIP0000000P1iNGT00`000000S8b<08b<S00208b<S0050000
002OWil0WinO09nOW`0000001@2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00H0
fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0D0?ooo`80o`0000<0003o0?ooo`3o
ool0H@3oool00`3o00000?l00000o`020000o`80o`006@3oool00`000000k>c/0>c/k00:0>c/k003
0000003IfMT0fMWI00H0fMWI00<000000<K6aP36a/H00`36a/H00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@1CDe<0000006IVIP1VIVH00000
00<0NGUi00D0000008b<S02<S8`0S8b<0000000409nOW`030000002c/k<0/k>c0080/k>c00<00000
0<K6aP36a/H01036a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00/0k>c/00<00000
0?ooo`3oool04`3oool30?l000030000o`3oool0oooo0600oooo0P3o00030000o`03003o003o0000
oooo01T0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@050=WIf@0300000036a/H0
a/K600<0a/K600<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool20000
00<0oooo1P2<S8`00`000000WinO09nOW`0@09nOW`030000002c/k<0/k>c01L0/k>c0P00000]0<K6
aP@00000@@3IfMT2000002l0a/K600<000000;>c/`2c/k<05`2c/k<00`000000WinO0?ooo`030?oo
o`8000009P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0`2<S8`00`00
0000WinO09nOW`0<09nOW`8000004`2c/k<2000001`0a/K60`00001m0=WIf@8000007P36a/H00`00
0000/k>c0;>c/`0=0;>c/`D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00D0De=C0000001VIVH0IVIV0000000207UiN@040000002<S8`0
S8b<08b<S08000000`2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600<0a/K600<0
00000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo01<0oooo00D0
o`00003o00000?l0003o0?l0001R0?ooo`030?l00000o`000?l00080003o0P3o000J0?ooo`030000
003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000a/K60<K6aP030<K6aP030000
003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00D0De=C0000001VIVH0IVIV0000000307UiN@050000002<S8`0S8b<08b<
S0000000102OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600@0a/K600<000000=WI
f@3IfMT01@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo0180oooo0P3o00000`00
o`00003o0000o`1R0?ooo`80o`0000D00?l00000o`00o`00003o0?l0000K0?ooo`030000003/k>`0
k>c/00X0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000a/K60<K6aP030<K6aP030000003oool0
oooo0080oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool608b<
S0030000002OWil0WinO00l0WinO00<000000;>c/`2c/k<05P2c/k<2000002d0a/K60P0000170=WI
f@<00000;@36a/H00`000000/k>c0;>c/`0G0;>c/`030000003oool0oooo00<0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P2<S8`00`00
0000WinO09nOW`0=09nOW`030000002c/k<0/k>c0140/k>c00<000000<K6aP36a/H06`36a/H00`00
0000fMWI0=WIf@200=WIf@8000007@36a/H00`000000/k>c0;>c/`0<0;>c/`D0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0000006IV
IP1VIVH000000`1iNGT01@000000S8b<08b<S02<S8`0000000<0WinO00<000000;>c/`2c/k<00`2c
/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02`3/
k>`00`000000oooo0?ooo`0B0?ooo`030?l00000o`00003o0080003o0P3o001R0?ooo`050?l00000
o`000?l00000o`3o00006`3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00D0fMWI
00<000000<K6aP36a/H01036a/H00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000001VIVH0IVIV06IVIP00
00000P1iNGT01@000000S8b<08b<S02<S8`0000000@0WinO00<000000;>c/`2c/k<00`2c/k<00`00
0000a/K60<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02`3/k>`00`00
0000oooo0?ooo`0B0?ooo`80o`0000D00?l00000o`000?l0003o0?l0001R0?ooo`80o`000P00o`00
0`000?l0oooo0?ooo`0J0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01@3IfMT0
0`000000a/K60<K6aP030<K6aP030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool0
03D0oooo00<000000?ooo`3oool00P3oool408b<S08000004@2OWil00`000000/k>c0;>c/`0F0;>c
/`0300000036a/H0a/K602X0a/K60`00001<0=WIf@D00000:@36a/H00`000000/k>c0;>c/`0G0;>c
/`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool6000000H0oooo00<000000?oo
o`3oool01@3oool300000080oooo00<0S8b<0000002OWil03P2OWil00`000000/k>c0;>c/`0A0;>c
/`0300000036a/H0a/K601/0a/K600<000000=WIf@3IfMT0P`3IfMT00`000000a/K60<K6aP0K0<K6
aP030000002c/k<0/k>c00/0/k>c0`3oool3000001d0oooo1000000>0?ooo`@000001P3oool00`00
0000oooo0?ooo`020?ooo`040000001VIVH0IVIV000000<0NGUi00D0000008b<S02<S8`0S8b<0000
000309nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WI
f@060=WIf@030000003/k>`0k>c/00X0k>c/0P00000D0?ooo`050?l00000o`000?l00000o`00o`00
0P3o001S0?ooo`<0o`0000<0003o0?ooo`3oool06P3oool00`000000k>c/0>c/k00:0>c/k0030000
003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H00`36a/H50?ooo`030000003oool0oooo01X0oooo
1000000>0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`050000001VIVH0IVIV06IVIP00
00000P1iNGT01@000000S8b<08b<S02<S8`0000000@0WinO00<000000;>c/`2c/k<00P2c/k<20000
00D0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo
0180oooo0P3o0002003o00030000o`00o`00o`0006<0oooo0`3o00000`3oool0003o0?ooo`0K0?oo
o`030000003/k>`0k>c/00T0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP020<K6
aPD0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool308b<S003
0000002OWil0WinO0100WinO00<000000;>c/`2c/k<05P2c/k<00`000000a/K60<K6aP0V0<K6aPD0
0000E03IfMT2000002P0a/K60P00000G0;>c/`030000003oool0oooo0080oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0000009nOW`2O
Wil03@2OWil00`000000/k>c0;>c/`0A0;>c/`0300000036a/H0a/K601X0a/K60P0000270=WIf@80
00007036a/H2000000/0/k>c1@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080
oooo00@0000006IVIP1VIVH000000`1iNGT01@000000S8b<08b<S02<S8`0000000<0WinO00<00000
0;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI00<00000
0>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0C0?ooo`80o`0000<0003o003o003o00000P3o001W
0?ooo`030000o`3oool0oooo01X0oooo00<000000>c/k03/k>`02@3/k>`00`000000fMWI0=WIf@05
0=WIf@0300000036a/H0a/K600<0a/K61@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0080oooo00D0000006IVIP1VIVH0IVIV0000000207UiN@050000002<S8`0S8b<08b<S0000000
102OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT0
1@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo0180oooo0`3o000010000?l00?l0
0?l0003o001X0?ooo`030000o`3oool0oooo01T0oooo00<000000>c/k03/k>`02@3/k>`00`000000
fMWI0=WIf@060=WIf@0300000036a/H0a/K60080a/K61@3oool00`000000oooo0?ooo`0N0?ooo`00
=@3oool00`000000oooo0?ooo`020?ooo`80S8b<00<0000009nOW`2OWil03`2OWil2000001L0/k>c
0P00000W0<K6aP800000F`3IfMT3000002L0a/K60P00000E0;>c/`D0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool?09nOW`030000002c/k<0/k>c0140/k>c00<000000<K6aP36a/H06@36a/H2000008/0fMWI
00<000000<K6aP36a/H06`36a/H00`000000/k>c0;>c/`080;>c/`D0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`020?ooo`040000001VIVH0IVIV00000080NGUi00D0000008b<S02<
S8`0S8b<0000000409nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36a/H00`00
0000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool05@3oool00`3o
0000003o0?l000020?l006P0oooo00<0003o0?ooo`3oool06P3oool00`000000k>c/0>c/k00:0>c/
k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H00P36a/H50?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000IVIV06IVIP00000307UiN@050000002<S8`0
S8b<08b<S00000000`2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600<0a/K600<0
00000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo01@0oooo0P3o
00000`000?l0o`000?l0001Y0?ooo`030000o`3oool0oooo01T0oooo00<000000>c/k03/k>`02P3/
k>`00`000000fMWI0=WIf@050=WIf@0300000036a/H0a/K60080a/K61@3oool00`000000oooo0?oo
o`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`80S8b<00<0000009nOW`2OWil03P2OWil0
0`000000/k>c0;>c/`0F0;>c/`0300000036a/H0a/K602@0a/K60`00001P0=WIf@8000009P36a/H2
000001@0/k>c1@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`d0WinO0P00000B0;>c/`8000006P36a/H2
000008h0fMWI0`00000K0<K6aP030000002c/k<0/k>c00L0/k>c1@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0080oooo0`1VIVH010000000NGUi07UiN@00000308b<S0030000002O
Wil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003I
fMT0fMWI00H0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E0?ooo`040000o`3o
0000o`000?l006X0oooo00<0003o0?ooo`3o00000P3o000G0?ooo`030000003/k>`0k>c/00X0k>c/
00<000000=WIf@3IfMT01@3IfMT00`000000a/K60<K6aP020<K6aPD0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`020?ooo`<0IVIV00D0000007UiN@1iNGT0NGUi0000000308b<S005
0000002OWil0WinO09nOW`0000001@2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI
00H0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3o0000o`00
06/0oooo00<0003o0?ooo`3o00000P3o000G0?ooo`030000003/k>`0k>c/00T0k>c/00<000000=WI
f@3IfMT01@3IfMT00`000000a/K60<K6aP020<K6aPD0oooo00<000000?ooo`3oool07P3oool003D0
oooo00<000000?ooo`3oool00P3oool00`2<S8`0000009nOW`0?09nOW`030000002c/k<0/k>c01H0
/k>c00<000000<K6aP36a/H08`36a/H2000006D0fMWI0P00000V0<K6aP8000004P2c/k<50?ooo`03
0000003oool0oooo02@0oooo100000060?ooo`030000003oool0oooo0080oooo3@2OWil00`000000
/k>c0;>c/`0@0;>c/`0300000036a/H0a/K601T0a/K600<000000=WIf@3IfMT0T@3IfMT00`000000
a/K60<K6aP0I0<K6aP030000002c/k<0/k>c00H0/k>c1@3oool00`000000oooo0?ooo`0g0?ooo`80
00000`3oool206IVIP040000001iNGT0NGUi000000<0S8b<00<0000009nOW`2OWil00P2OWil00`00
0000/k>c0;>c/`020;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01@3IfMT00`00
0000k>c/0>c/k00:0>c/k0030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0K03oool00`00
0?l0o`000?l000020?l001H0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@050=WI
f@0300000036a/H0a/K60080a/K6103oool2000003P0oooo0P0000030?ooo`<0IVIV00@0000007Ui
N@1iNGT000000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c0080/k>c00<00000
0<K6aP36a/H00`36a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00X0k>c/00<00000
0?ooo`3oool05P3oool00`000?l0oooo0?ooo`1/0?ooo`030000o`3o0000o`000080o`005P3oool0
0`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00H0fMWI00@000000<K6aP36a/H0a/K6103o
ool200000200oooo000e0?ooo`030000003oool0oooo0080oooo00<0000009nOW`2OWil03`2OWil0
0`000000/k>c0;>c/`0D0;>c/`8000009@36a/H00`000000fMWI0=WIf@1W0=WIf@<000009036a/H0
0`000000/k>c0;>c/`0@0;>c/`D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`02
0?ooo``0WinO00<000000;>c/`2c/k<0402c/k<00`000000a/K60<K6aP0H0<K6aP800000U@3IfMT0
0`000000a/K60<K6aP0I0<K6aP030000002c/k<0/k>c00D0/k>c1@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0080oooo0P1VIVH010000000NGUi07UiN@00000308b<S0030000002O
Wil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003I
fMT0fMWI00D0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo06`0oooo00<0o`000000o`3o00000P00o`020?l001H0oooo00<000000>c/k03/k>`02P3/
k>`00`000000fMWI0=WIf@050=WIf@0400000036a/H0a/K60<K6aPD0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`020?ooo`80IVIV0P00000207UiN@050000002<S8`0S8b<08b<S000
0000102OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3I
fMT01P3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3o
ool0K03oool0103o0000003o003o0000o`030?l001H0oooo00<000000>c/k03/k>`02@3/k>`00`00
0000fMWI0=WIf@050=WIf@0400000036a/H0a/K60<K6aPD0oooo00<000000?ooo`3oool07P3oool0
03D0oooo00<000000?ooo`3oool00P3ooolA09nOW`030000002c/k<0/k>c01@0/k>c00<000000<K6
aP36a/H08`36a/H2000006d0fMWI0P00000S0<K6aP800000402c/k<50?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool00P3oool;09nOW`030000002c/k<0/k>c0100/k>c00<000000<K6
aP36a/H06036a/H00`000000fMWI0=WIf@120=WIfA400000@`3IfMT2000001X0a/K600<000000;>c
/`2c/k<0102c/k<50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool206IV
IP040000001iNGT0NGUi000000<0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`02
0;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00:
0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0K03oool20?l000050000o`00o`00
0?l0003o003o00005P3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00D0fMWI00@0
00000<K6aP36a/H0a/K61@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo
0P1VIVH01@000000NGUi07UiN@1iNGT0000000<0S8b<00D0000009nOW`2OWil0WinO000000040;>c
/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00:0>c/
k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0K03oool00`3o00000?l00000o`02003o
0080o`005P3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00@0fMWI00@000000<K6
aP36a/H0a/K61@3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?oo
o`l0WinO0P00000E0;>c/`8000008`36a/H300000740fMWI0P00000S0<K6aP8000003P2c/k<50?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool:09nOW`030000002c/k<0/k>c
00l0/k>c0P00000J0<K6aP030000003IfMT0fMWI03/0fMWI2000000A0>c/k0X00000>`3IfMT20000
01T0a/K600<000000;>c/`2c/k<00`2c/k<50?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool00P3oool00`1VIVH0000007UiN@0207UiN@050000002<S8`0S8b<08b<S00000000`2OWil0
0`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT01@3IfMT0
0`000000k>c/0>c/k00:0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0K@3oool2
0?l000050000o`00o`000?l0003o003o00005`3oool00`000000k>c/0>c/k0090>c/k0030000003I
fMT0fMWI00D0fMWI00@000000<K6aP36a/H0a/K61@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0080oooo0P1VIVH010000000NGUi07UiN@00000308b<S0030000002OWil0WinO0080
WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00H0
fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo06d0
oooo00<0o`00003o00000?l00P00o`020?l001L0oooo00<000000>c/k03/k>`02@3/k>`00`000000
fMWI0=WIf@050=WIf@0300000036a/H0a/K600D0oooo00<000000?ooo`3oool07P3oool003D0oooo
0P0000030?ooo`h0WinO00<000000;>c/`2c/k<0502c/k<00`000000a/K60<K6aP0Q0<K6aP800000
M@3IfMT2000002@0a/K600<000000;>c/`2c/k<02`2c/k<40?ooo`800000<03oool00`000000oooo
0?ooo`020?ooo`T0WinO00<000000;>c/`2c/k<03`2c/k<00`000000a/K60<K6aP0H0<K6aP800000
=`3IfMT7000002<0k>c/1000000i0=WIf@0300000036a/H0a/K601L0a/K600<000000;>c/`2c/k<0
0P2c/k<50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`1VIVH00000
07UiN@0207UiN@050000002<S8`0S8b<08b<S00000000`2OWil00`000000/k>c0;>c/`020;>c/`03
00000036a/H0a/K600@0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00:0>c/k003
0000003oool0oooo01D0oooo00<0003o0?ooo`3oool0KP3oool20?l000030000o`00o`00o`0001P0
oooo00<000000>c/k03/k>`02@3/k>`00`000000fMWI0=WIf@050=WIf@0400000036a/H0a/K60<K6
aPD0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`80IVIV00@0000007Ui
N@1iNGT000000`2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c0080/k>c00<00000
0<K6aP36a/H00`36a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00X0k>c/00<00000
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`1^0?ooo`030?l00000o`00003o0080o`00603oool0
0`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H01@3oool0
0`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`d0WinO00<000000;>c
/`2c/k<0502c/k<00`000000a/K60<K6aP0P0<K6aP800000N@3IfMT2000002<0a/K600<000000;>c
/`2c/k<02P2c/k<50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool809nO
W`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H05`36a/H2000003@0fMWI1@00000^0>c/
k0D00000=@3IfMT00`000000a/K60<K6aP0G0<K6aP8000000P2c/k<50?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool00P3oool01@1VIVH0000007UiN@1iNGT0000000<0S8b<00<00000
09nOW`2OWil00P2OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600<0a/K600<00000
0=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo01D0oooo00<0003o
0?ooo`3oool0L03oool20?l000030000o`3oool0oooo01L0oooo00<000000>c/k03/k>`02@3/k>`0
0`000000fMWI0=WIf@050=WIf@0400000036a/H0a/K60<K6aPD0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`020?ooo`0306IVIP000000NGUi0080NGUi00D0000008b<S02<S8`0S8b<
0000000309nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI
0=WIf@050=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`1`0?ooo`80o`0000<0003o0?ooo`3oool05`3oool00`000000k>c/0>c/k0090>c/k0030000
003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H01@3oool00`000000oooo0?ooo`0N0?ooo`00=@3o
ool00`000000oooo0?ooo`020?ooo``0WinO0P00000D0;>c/`8000008@36a/H2000007d0fMWI0`00
000Q0<K6aP030000002c/k<0/k>c00T0/k>c1@3oool00`000000oooo0?ooo`0^0?ooo`8000000`3o
ool809nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H05P36a/H00`000000fMWI0=WI
f@0b0=WIf@800000>03/k>`3000003<0fMWI0P00000I0<K6aP030000002c/k<0oooo00<0oooo0P00
000i0?ooo`030000003oool0oooo0080oooo00D0IVIV0000001iNGT0NGUi0000000308b<S0030000
002OWil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000
003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo0780oooo00<0003o0?ooo`3oool0603oool00`000000k>c/0>c/k0090>c/k0030000
003IfMT0fMWI00D0fMWI00<000000<K6aP36a/H01@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0080oooo00<0IVIV0000001iNGT00P1iNGT01@000000S8b<08b<S02<S8`0000000<0
WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0fMWI00D0
fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0780
oooo00<0003o0?ooo`3oool0603oool00`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00D0
fMWI00<000000<K6aP3oool0103oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo
0?ooo`020?ooo`/0WinO00<000000;>c/`2c/k<04`2c/k<00`000000a/K60<K6aP0O0<K6aP800000
PP3IfMT200000200a/K60P0000090;>c/`D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`L0WinO00<000000;>c/`2c/k<03`2c/k<00`000000a/K60<K6aP0F0<K6aP030000
003IfMT0fMWI02h0fMWI1@00000m0>c/k0D00000<03IfMT00`000000a/K60<K6aP0F0<K6aP030000
002c/k<0oooo00@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`040000
001iNGT0NGUi000000<0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`020;>c/`03
00000036a/H0a/K600<0a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k00:0>c/k003
0000003oool0oooo01@0oooo00<0003o0?ooo`3oool0M03oool00`000?l0oooo0?ooo`0G0?ooo`03
0000003/k>`0k>c/00T0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000a/K60<K6aP050?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool01@1VIVH0000007UiN@1iNGT00000
00<0S8b<00D0000009nOW`2OWil0WinO000000050;>c/`0300000036a/H0a/K600<0a/K600<00000
0=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo01@0oooo00<0003o
0?ooo`3oool0M03oool00`000?l0oooo0?ooo`0G0?ooo`030000003/k>`0k>c/00T0k>c/00<00000
0=WIf@3IfMT01@3IfMT00`000000a/K60?ooo`040?ooo`030000003oool0oooo01h0oooo000e0?oo
o`030000003oool0oooo0080oooo2P2OWil00`000000/k>c0;>c/`0C0;>c/`0300000036a/H0a/K6
01h0a/K60P0000260=WIf@0300000036a/H0a/K601l0a/K600<000000;>c/`2c/k<01P2c/k<50?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool509nOW`800000402c/k<20000
01L0a/K60P00000^0=WIf@<00000A`3/k>`2000002l0fMWI00<000000<K6aP36a/H05P36a/H00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool01000
0000NGUi07UiN@00000308b<S0030000002OWil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<0
0`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02@3/k>`0
0`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo07D0oooo00<0003o0?ooo`3oool05`3oool0
0`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00D0fMWI00<000000<K6aP3oool0103oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00D0IVIV0000001iNGT0NGUi0000
000308b<S0050000002OWil0WinO09nOW`0000001@2c/k<00`000000a/K60<K6aP030<K6aP030000
003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo07D0oooo00<0003o0?ooo`3oool05`3oool00`000000k>c/0>c/k0090>c/k0030000
003IfMT0fMWI00D0fMWI00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`00=@3o
ool00`000000oooo0?ooo`020?ooo`T0WinO00<000000;>c/`2c/k<04`2c/k<00`000000a/K60<K6
aP0M0<K6aP800000R@3IfMT200000200a/K600<000000;>c/`2c/k<01@2c/k<50?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool00P3oool409nOW`030000002c/k<0/k>c00l0/k>c00<0
00000<K6aP36a/H05P36a/H00`000000fMWI0=WIf@0/0=WIf@800000C03/k>`3000002d0fMWI0P00
000G0<K6aP030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool2000000<0oooo00@0
000007UiN@1iNGT000000`2<S8`01@000000WinO09nOW`2OWil0000000D0/k>c00<000000<K6aP36
a/H00`36a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`1f0?ooo`030000o`3oool0oooo01L0oooo00<000000>c/k03/
k>`02@3/k>`00`000000fMWI0=WIf@050=WIf@0300000036a/H0oooo00<0oooo0P00000h0?ooo`80
00000`3oool01@000000NGUi07UiN@1iNGT0000000<0S8b<00D0000009nOW`2OWil0WinO00000005
0;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00:
0>c/k0030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0MP3oool00`000?l0oooo0?ooo`0G
0?ooo`030000003/k>`0k>c/00T0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000oooo0?ooo`02
0?ooo`800000803oool003D0oooo00<000000?ooo`3oool00P3oool809nOW`030000002c/k<0/k>c
01<0/k>c00<000000<K6aP36a/H07036a/H2000008d0fMWI0P00000O0<K6aP030000002c/k<0/k>c
00@0/k>c1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo0`2OWil00`00
0000/k>c0;>c/`0?0;>c/`0300000036a/H0a/K601H0a/K600<000000=WIf@3IfMT0:P3IfMT30000
0540k>c/0P00000]0=WIf@0300000036a/H0a/K601@0a/K61@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0080oooo00@0000007UiN@1iNGT000000`2<S8`01@000000WinO09nOW`2O
Wil0000000@0/k>c00<000000<K6aP36a/H01036a/H00`000000fMWI0=WIf@050=WIf@030000003/
k>`0k>c/00X0k>c/00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`1g0?ooo`030000o`3o
ool0oooo01H0oooo00<000000>c/k03/k>`02@3/k>`00`000000fMWI0=WIf@060=WIf@030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`040000001i
NGT0NGUi000000<0S8b<00<0000009nOW`2OWil00P2OWil00`000000/k>c0;>c/`020;>c/`030000
0036a/H0a/K600<0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00:0>c/k0030000
003oool0oooo01D0oooo00<0003o0?ooo`3oool0M`3oool00`000?l0oooo0?ooo`0G0?ooo`030000
003/k>`0k>c/00P0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo1`2OWil2000001@0/k>c00<0
00000<K6aP36a/H07@36a/H00`000000fMWI0=WIf@2>0=WIf@0300000036a/H0a/K601d0a/K600<0
00000;>c/`2c/k<00`2c/k<50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3o
ool309nOW`030000002c/k<0/k>c00h0/k>c00<000000<K6aP36a/H05P36a/H00`000000fMWI0=WI
f@0Y0=WIf@800000EP3/k>`3000002/0fMWI00<000000<K6aP36a/H04`36a/H50?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool00P3oool307UiN@050000002<S8`0S8b<08b<S0000000
0`2OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT0
1@3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo0140oooo0P3o00000`000?l0oooo
0?ooo`1h0?ooo`030?l000000?l0o`0001L0oooo00<000000>c/k03/k>`02@3/k>`00`000000fMWI
0=WIf@050=WIf@030000003oool0oooo00<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`020?ooo`<0NGUi00D0000008b<S02<S8`0S8b<0000000409nOW`030000002c/k<0/k>c0080
/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00X0
k>c/00<000000?ooo`3oool04@3oool30?l000030000o`3oool0oooo07P0oooo00<0o`000000o`3o
00005`3oool00`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00@0fMWI00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`H0WinO
00<000000;>c/`2c/k<04`2c/k<00`000000a/K60<K6aP0L0<K6aP800000TP3IfMT2000001h0a/K6
00<000000;>c/`2c/k<00P2c/k<50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
0P3oool209nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H05@36a/H00`000000fMWI
0=WIf@0W0=WIf@<00000F`3/k>`2000002X0fMWI00<000000<K6aP36a/H04P36a/H50?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool207UiN@050000002<S8`0S8b<08b<S000
00000`2OWil00`000000/k>c0;>c/`030;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3I
fMT01@3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo0140oooo0`3o00000`000?l0
o`000?ooo`1g0?ooo`80o`0000<0003o003o003o00005P3oool00`000000k>c/0>c/k0090>c/k003
0000003IfMT0fMWI00D0fMWI00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0080oooo0`1iNGT01@000000S8b<08b<S02<S8`0000000<0WinO00<000000;>c
/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/
k03/k>`02P3/k>`00`000000oooo0?ooo`0A0?ooo`@0o`0000<0003o0?ooo`3oool0M`3oool20?l0
00030000o`00o`00o`0001H0oooo00<000000>c/k03/k>`02@3/k>`00`000000fMWI0=WIf@040=WI
f@030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3o
ool00P3oool509nOW`030000002c/k<0/k>c0180/k>c0P00000L0<K6aP<00000UP3IfMT2000001d0
a/K600@000000;>c/`2c/k<0/k>c1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0080oooo00<0WinO0000002c/k<0402c/k<00`000000a/K60<K6aP0D0<K6aP800000:03IfMT20000
0600k>c/0`00000X0=WIf@0300000036a/H0a/K60140a/K61@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0080oooo0P1iNGT01@000000S8b<08b<S02<S8`0000000<0WinO00<00000
0;>c/`2c/k<00`2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI00<00000
0>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0@0?ooo`80o`0000<00?l00000o`3o00000P3o001f
0?ooo`80o`000P00o`000`000?l00?l00?l0000F0?ooo`030000003/k>`0k>c/00T0k>c/00<00000
0=WIf@3IfMT0103IfMT00`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool00P3oool307UiN@050000002<S8`0S8b<08b<S00000000`2OWil00`000000/k>c0;>c
/`020;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/
k00:0>c/k0030000003oool0oooo0100oooo0`3o00020000o`80o`00M`3oool20?l00005003o0000
0?l0003o003o003o00005P3oool00`000000k>c/0>c/k0080>c/k0030000003IfMT0fMWI00D0fMWI
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?oo
o`020?ooo`D0WinO00<000000;>c/`2c/k<04@2c/k<00`000000a/K60<K6aP0K0<K6aP030000003I
fMT0fMWI09T0fMWI00<000000<K6aP36a/H06`36a/H00`000000/k>c0;>c/`050?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`000000/k>c0;>c/`0>0;>c/`8000005P36
a/H00`000000fMWI0=WIf@0U0=WIf@<00000I@3/k>`3000002H0fMWI0P00000A0<K6aPD0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`80NGUi00D0000008b<S02<S8`0S8b<
0000000309nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H00P36a/H00`000000fMWI
0=WIf@060=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool0403oool00`3o00000?l0
0000o`020000o`80o`00MP3oool20?l00005003o00000?l0003o0000o`3o00005P3oool00`000000
k>c/0>c/k0090>c/k0030000003IfMT0fMWI00D0fMWI00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0`1iNGT01@000000S8b<08b<S02<S8`00000
00<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI
00D0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0@0?ooo`80o`000`000?l00`00
o`00o`000?ooo`1f0?ooo`80o`000`000?l00`00o`00o`000?ooo`0E0?ooo`030000003/k>`0k>c/
00P0k>c/00<000000=WIf@3IfMT01@3IfMT00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01h0oooo000e0?ooo`8000000`3oool409nOW`030000002c/k<0/k>c0140/k>c00<000000<K6aP36
a/H06`36a/H00`000000fMWI0=WIf@2K0=WIf@0300000036a/H0a/K601/0a/K600<000000;>c/`3o
ool00`3oool200000300oooo00<000000?ooo`3oool00P3oool@0;>c/`0300000036a/H0a/K601D0
a/K600<000000=WIf@3IfMT0903IfMT2000006/0k>c/0P00000V0=WIf@0300000036a/H0a/K600h0
a/K61@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo0P1iNGT010000000
S8b<08b<S000000409nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36a/H00`00
0000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool04@3oool01@3o
00000?l00000o`000?l00?l00080o`00=`3oool5000003X0oooo0`3o00001000o`00003o0000o`3o
000G0?ooo`030000003/k>`0k>c/00T0k>c/00<000000=WIf@3IfMT0103IfMT50?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool00P3oool207UiN@050000002<S8`0S8b<08b<S0000000
0`2OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600@0a/K600<000000=WIf@3IfMT0
1@3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo0140oooo0P3o00001@00o`00003o
003o0000o`00o`0003L0oooo1P00000j0?ooo`<0o`0000@0003o003o00000?l0o`005P3oool00`00
0000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00@0fMWI1@3oool00`000000oooo0?ooo`0N0?oo
o`00=@3oool00`000000oooo0?ooo`020?ooo`<0WinO00<000000;>c/`2c/k<04@2c/k<00`000000
a/K60<K6aP0K0<K6aP030000003IfMT0fMWI09d0fMWI0`00000K0<K6aP030000003oool0oooo00<0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`l0/k>c00<000000<K6aP36
a/H05@36a/H00`000000fMWI0=WIf@0S0=WIf@800000K`3/k>`2000002D0fMWI00<000000<K6aP36
a/H03@36a/H50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool207UiN@04
0000002<S8`0S8b<000000@0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6
aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0B0?oo
o`030?l000000?l00?l00080o`00<P3oool6000000D0k>c/1P00000e0?ooo`@0o`0000<0003o0?oo
o`3oool05P3oool00`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00@0fMWI1@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0P1iNGT01@000000S8b<08b<S02<S8`0
000000<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP040<K6aP030000003IfMT0
fMWI00D0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0B0?ooo`80o`0000<0003o
003o003o0000<`3oool6000000D0k>c/1@00000f0?ooo`@0o`0000<0003o0?ooo`3oool05P3oool0
0`000000k>c/0>c/k0080>c/k0030000003IfMT0fMWI00@0fMWI1@3oool00`000000oooo0?ooo`0N
0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`80WinO00<000000;>c/`2c/k<04@2c/k<00`00
0000a/K60<K6aP0J0<K6aP800000B03IfMTC000004P0fMWI00<000000<K6aP36a/H06@36a/H00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo0P0000030?ooo`l0/k>c00<000000<K6
aP36a/H04`36a/H2000002D0fMWI00<000000>c/k03/k>`0L@3/k>`2000002@0fMWI00<000000<K6
aP36a/H03036a/H40?ooo`800000>@3oool2000000<0oooo00<0NGUi0000002<S8`00P2<S8`01@00
0000WinO09nOW`2OWil0000000@0/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@05
0=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool04`3oool010000?l0o`000?l0003o
000_0?ooo`@000004@3/k>`400000380oooo0`3o00000`000?l0oooo0?ooo`0F0?ooo`030000003/
k>`0k>c/00T0k>c/00<000000=WIf@3IfMT0103IfMT40?ooo`800000>03oool2000000<0oooo00<0
NGUi0000002<S8`00P2<S8`00`000000WinO09nOW`0209nOW`030000002c/k<0/k>c0080/k>c00<0
00000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/00<0
00000?ooo`3oool0503oool00`000?l0o`000?l0000`0?ooo`@00000403/k>`500000380oooo0`3o
00000`000?l0oooo0?ooo`0F0?ooo`030000003/k>`0k>c/00P0k>c/00<000000=WIf@3IfMT0103I
fMT40?ooo`800000803oool003D0oooo00<000000?ooo`3oool00P3oool00`2OWil000000;>c/`0B
0;>c/`0300000036a/H0a/K601T0a/K60P0000100=WIf@X000004`3/k>`800000440fMWI00<00000
0<K6aP36a/H06036a/H50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool>
0;>c/`0300000036a/H0a/K601<0a/K600<000000=WIf@3IfMT08`3IfMT2000007H0k>c/0P00000S
0=WIf@8000003036a/H50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool0
0`1iNGT0000008b<S00208b<S0050000002OWil0WinO09nOW`000000102c/k<00`000000a/K60<K6
aP030<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo02d0oooo0`00000I0>c/k0<00000<`3oool00`000?l0oooo0?oo
o`0F0?ooo`030000003/k>`0k>c/00P0k>c/00<000000=WIf@3IfMT0103IfMT50?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`1iNGT0000008b<S00208b<S0030000002O
Wil0WinO0080WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003I
fMT0fMWI00D0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo02h0oooo0`00000I0>c/k0800000<`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003/
k>`0k>c/00P0k>c/00<000000=WIf@3IfMT00`3IfMT50?ooo`030000003oool0oooo01h0oooo000e
0?ooo`030000003oool0oooo0080oooo00<000000;>c/`2c/k<0402c/k<2000001/0a/K600<00000
0=WIf@3IfMT0>`3IfMT5000002D0k>c/1@00000m0=WIf@8000006036a/H50?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool00P3oool<0;>c/`8000005@36a/H00`000000fMWI0=WIf@0Q
0=WIf@<00000NP3/k>`00`000000fMWI0=WIf@0R0=WIf@0300000036a/H0a/K600T0a/K61@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo00D0000008b<S02<S8`0S8b<0000
000309nOW`030000002c/k<0/k>c00<0/k>c00<000000<K6aP36a/H00P36a/H00`000000fMWI0=WI
f@050=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0/0?ooo`8000007`3/k>`200000340oooo00<0003o0?ooo`3oool05P3oool00`000000k>c/0>c/
k0080>c/k0030000003IfMT0fMWI00@0fMWI1@3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0080oooo00<0NGUi0000002<S8`00P2<S8`01@000000WinO09nOW`2OWil0000000@0/k>c
00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00X0k>c/
00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0/0?ooo`8000007P3/k>`200000380oooo
00<0003o0?ooo`3oool05P3oool00`000000k>c/0>c/k0080>c/k0030000003IfMT0fMWI00<0fMWI
1@3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?oooa80/k>c00<0
00000<K6aP36a/H06P36a/H00`000000fMWI0=WIf@0h0=WIf@@00000;`3/k>`5000003X0fMWI00<0
00000<K6aP36a/H05@36a/H50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3o
ool;0;>c/`0300000036a/H0a/K601<0a/K60P00000R0=WIf@800000OP3/k>`300000280fMWI00<0
00000<K6aP36a/H02036a/H50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3o
ool01@000000S8b<08b<S02<S8`0000000<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K6
0<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo02`0oooo00<000000>c/k03/k>`08@3/k>`2000002l0oooo
00<0003o0?ooo`3oool05`3oool00`000000k>c/0>c/k0080>c/k0030000003IfMT0fMWI00<0fMWI
1@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<0NGUi0000002<S8`0
0P2<S8`01@000000WinO09nOW`2OWil0000000@0/k>c00<000000<K6aP36a/H00`36a/H00`000000
fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/0P00000D0?ooo`030000o`3oool0oooo02/0
oooo0P00000R0>c/k0800000<03oool00`000?l0oooo0?ooo`0G0?ooo`030000003/k>`0k>c/00P0
k>c/00<000000=WIf@3IfMT00P3IfMT50?ooo`030000003oool0oooo01h0oooo000Z0?ooo`H00000
1@3oool00`000000oooo0?ooo`020?oooa80/k>c00<000000<K6aP36a/H06@36a/H00`000000fMWI
0=WIf@0d0=WIf@D00000>03/k>`5000003H0fMWI00<000000<K6aP36a/H05036a/H50?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool;0;>c/`0300000036a/H0a/K60180a/K6
00<000000=WIf@3IfMT08@3IfMT00`000000k>c/0>c/k0210>c/k08000008@3IfMT00`000000a/K6
0<K6aP070<K6aPD0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`050000
002<S8`0S8b<08b<S00000000`2OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600<0
a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo0180
oooo00<0003o0?ooo`3oool0:`3oool00`000000k>c/0>c/k00S0>c/k0800000;`3oool00`000?l0
oooo0?ooo`0F0?ooo`030000003/k>`0k>c/00P0k>c/00<000000=WIf@3IfMT00`3IfMT50?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`1iNGT0000008b<S00208b<S005
0000002OWil0WinO09nOW`000000102c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI
00D0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
02/0oooo0P00000U0>c/k0030000003oool0oooo02d0oooo00<0003o0?ooo`3oool05`3oool00`00
0000k>c/0>c/k0080>c/k0030000003IfMT0fMWI0080fMWI1@3oool00`000000oooo0?ooo`0N0?oo
o`00:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3ooolA0;>c/`0300000036a/H0a/K601P0a/K60P00000d0=WIf@<00000@P3/k>`2000003D0
fMWI00<000000<K6aP36a/H04`36a/H50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool00P3oool:0;>c/`0300000036a/H0a/K601<0a/K600<000000=WIf@3IfMT0803IfMT00`000000
k>c/0>c/k0230>c/k0030000003IfMT0fMWI0200fMWI00<000000<K6aP36a/H01P36a/H50?ooo`03
0000003oool0oooo01/0oooo100000060?ooo`8000001`3oool4000000D0oooo00<000000?ooo`3o
ool00P3oool010000000S8b<08b<S000000409nOW`030000002c/k<0/k>c0080/k>c00<000000<K6
aP36a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/00<000000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0Z0?ooo`800000:03/k>`2000002d0oooo00<0003o0?oo
o`3oool05P3oool00`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI0080fMWI1@3oool00`00
0000oooo0?ooo`0J0?ooo`@000001P3oool2000000L0oooo100000050?ooo`030000003oool0oooo
0080oooo00D0000008b<S02<S8`0S8b<0000000309nOW`030000002c/k<0/k>c0080/k>c00<00000
0<K6aP36a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00X0k>c/00<00000
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0Y0?ooo`800000:03/k>`2000002h0oooo00<0003o
0?ooo`3oool05P3oool00`000000k>c/0>c/k0090>c/k0040000003IfMT0fMWI0=WIf@D0oooo00<0
00000?ooo`3oool07P3oool002/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`l0/k>c0P00000I0<K6aP800000<`3IfMT3000004L0k>c/1@00000a0=WIf@<000004P36a/H5
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool90;>c/`0300000036a/H0
a/K60180a/K60P00000Q0=WIf@800000Q`3/k>`200000240fMWI0P0000060<K6aPD0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000S8b<08b<S000
000409nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WI
f@050=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0Z0?ooo`030000003/k>`0k>c/02X0k>c/0P00000/0?ooo`030000o`3oool0oooo01H0oooo00<0
00000>c/k03/k>`0203/k>`00`000000fMWI0=WIf@020=WIf@D0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000S8b<08b<S02<S8`0000000<0WinO
00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI
00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02T0oooo
00<000000>c/k03/k>`0:P3/k>`3000002/0oooo00<0003o0?ooo`3oool05P3oool00`000000k>c/
0>c/k0090>c/k0040000003IfMT0fMWI0=WIf@D0oooo00<000000?ooo`3oool07P3oool002`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`h0/k>c00<000000<K6aP36a/H0
6@36a/H00`000000fMWI0=WIf@0^0=WIf@@00000C`3/k>`300000340fMWI00<000000<K6aP36a/H0
3`36a/H50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool80;>c/`030000
0036a/H0a/K60180a/K600<000000=WIf@3IfMT07`3IfMT2000008/0k>c/0P00000Q0=WIf@030000
0036a/H0a/K600<0a/K61@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
0`2<S8`01@000000WinO09nOW`2OWil0000000@0/k>c00<000000<K6aP36a/H00`36a/H00`000000
fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0X0?ooo`800000;`3/k>`00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo01H0
oooo00<000000>c/k03/k>`0203/k>`00`000000fMWI0=WIf@020=WIf@D0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`<0S8b<00<0000009nOW`2OWil00P2OWil00`000000
/k>c0;>c/`020;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0103IfMT00`000000
k>c/0>c/k00:0>c/k0030000003oool0oooo0140oooo00<0003o0?ooo`3oool0:@3oool00`000000
k>c/0>c/k00^0>c/k0030000003oool0oooo02P0oooo00<0003o0?ooo`3oool05P3oool00`000000
k>c/0>c/k0090>c/k0040000003IfMT0fMWI0=WIf@D0oooo00<000000?ooo`3oool07P3oool00240
oooo1P0000060?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`d0/k>c00<000000<K6aP36
a/H05`36a/H3000002l0fMWI0P00001F0>c/k0800000<03IfMT00`000000a/K60<K6aP0>0<K6aP@0
oooo0P00000`0?ooo`030000003oool0oooo0080oooo1`2c/k<00`000000a/K60<K6aP0B0<K6aP03
0000003IfMT0fMWI01l0fMWI00<000000>c/k03/k>`0S@3/k>`200000200fMWI00<000000<K6aP36
a/H00P36a/H50?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`H000001@3oool2000000<0oooo0`2<S8`01@000000WinO09nOW`2OWil00000
00@0/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/
00T0k>c/00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0W0?ooo`800000<P3/k>`00`00
0000oooo0?ooo`0W0?ooo`030?l000000?l0o`0001P0oooo00<000000>c/k03/k>`0203/k>`01000
0000fMWI0=WIf@3IfMT30?ooo`<000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo1P0000050?ooo`<000000P3oool308b<S0030000002OWil0WinO0080WinO00<00000
0;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00@0fMWI00<00000
0>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02H0oooo0`00000b
0>c/k0030000003oool0oooo02L0oooo00<0003o0?l0003o00005`3oool00`000000k>c/0>c/k008
0>c/k0040000003IfMT0fMWI0=WIf@@0oooo0P00000P0?ooo`00;P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo3@2c/k<00`000000a/K60<K6aP0G0<K6aP030000003IfMT0
fMWI02`0fMWI0`00001J0>c/k0<00000;P3IfMT00`000000a/K60<K6aP0=0<K6aPD0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`L0/k>c00<000000<K6aP36a/H04@36a/H0
0`000000fMWI0=WIf@0N0=WIf@800000TP3/k>`00`000000fMWI0=WIf@0M0=WIf@0300000036a/H0
a/K60080a/K61@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0080oooo0P2<
S8`00`000000WinO09nOW`0209nOW`050000002c/k<0/k>c0;>c/`0000001@36a/H00`000000fMWI
0=WIf@050=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0U0?ooo`800000=@3/k>`2000002H0oooo0P3o00020000o`030?l0003oool0oooo01D0oooo
00<000000>c/k03/k>`0203/k>`010000000fMWI0=WIf@3IfMT50?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool00P3oool308b<S0050000002OWil0WinO09nOW`000000102c/k<0
0`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02@3/k>`0
0`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02H0oooo00<000000>c/k03/k>`0=03/k>`0
0`000000oooo0?ooo`0U0?ooo`030?l00000o`00003o0080o`005P3oool00`000000k>c/0>c/k008
0>c/k0040000003IfMT0fMWI0=WIf@D0oooo00<000000?ooo`3oool07P3oool002X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo302c/k<0
0`000000a/K60<K6aP0G0<K6aP030000003IfMT0fMWI02/0fMWI0P00001P0>c/k0800000;@3IfMT2
000000d0a/K61@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo1@2c/k<2
000001@0a/K600<000000=WIf@3IfMT07@3IfMT00`000000k>c/0>c/k02C0>c/k0030000003IfMT0
fMWI01d0fMWI00@000000<K6aP36a/H0a/K61@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo0080oooo0P2<S8`01@000000WinO09nOW`2OWil0000000@0/k>c00<000000<K6aP36
a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0U0?ooo`030000003/k>`0k>c/03L0k>c/00<000000?ooo`3o
ool08P3oool20?l000<0003o00<00?l00?l0003oool05P3oool00`000000k>c/0>c/k0080>c/k003
0000003IfMT0fMWI00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`020?oo
o`<0S8b<00D0000009nOW`2OWil0WinO000000040;>c/`0300000036a/H0a/K600<0a/K600<00000
0=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo0100oooo00<0003o
0?ooo`3oool09P3oool00`000000k>c/0>c/k00f0>c/k0800000903oool00`3o00000?l00000o`02
0000o`80o`005P3oool00`000000k>c/0>c/k0080>c/k0030000003IfMT0fMWI00D0oooo00<00000
0?ooo`3oool07P3oool002X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo2P2c/k<2000001P0a/K60P00000[0=WIf@<00000I03/k>`30000
02`0fMWI00<000000<K6aP36a/H02P36a/H50?ooo`030000003oool0oooo02h0oooo0P0000030?oo
o`@0/k>c00<000000<K6aP36a/H04P36a/H2000001h0fMWI0P00002G0>c/k08000007P3IfMT20000
00030<K6aP3oool0oooo0080oooo0P00000L0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo000000060?ooo`030000003oool0oooo0080oooo0P2<S8`01@00
0000WinO09nOW`2OWil0000000@0/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@05
0=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`0U
0?ooo`030000003/k>`0k>c/03T0k>c/00<000000?ooo`3oool08@3oool20?l00005003o00000?l0
003o003o003o00005`3oool00`000000k>c/0>c/k0080>c/k0030000003IfMT0fMWI00D0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`<0S8b<00D0000009nOW`2OWil0WinO
000000040;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/
0>c/k0090>c/k0030000003oool0oooo0100oooo00<0003o0?ooo`3oool09@3oool00`000000k>c/
0>c/k00i0>c/k0030000003oool0oooo0240oooo00<0o`00003o0000o`000P000?l20?l001H0oooo
00<000000>c/k03/k>`0203/k>`00`000000fMWI0=WIf@050?ooo`030000003oool0oooo01h0oooo
000[0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`T0/k>c00<000000<K6aP36a/H05`36
a/H00`000000fMWI0=WIf@0X0=WIf@<00000JP3/k>`2000002/0fMWI00<000000<K6aP36a/H02@36
a/H50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool30;>c/`0300000036
a/H0a/K60180a/K600<000000=WIf@3IfMT07@3IfMT00`000000k>c/0>c/k02I0>c/k08000007P3I
fMT00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00P3o
ool00`2<S8`0000009nOW`0309nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36
a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0T0?ooo`030000003/k>`0k>c/03/0k>c/00<000000?ooo`3oool0803o
ool30?l000800?l000<0003o0?l0003oool05P3oool00`000000k>c/0>c/k0080>c/k0030000003I
fMT0fMWI00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`80S8b<00D0
000009nOW`2OWil0WinO000000040;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0
1@3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo0100oooo00<0003o0?ooo`3oool0
9@3oool00`000000k>c/0>c/k00k0>c/k0030000003oool0oooo0200oooo0P3o0002003o00030000
o`3o0000o`0001L0oooo00<000000>c/k03/k>`0203/k>`00`000000fMWI0?ooo`040?ooo`030000
003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo202c/k<00`000000a/K60<K6
aP0G0<K6aP030000003IfMT0fMWI02L0fMWI0P00001_0>c/k0800000:P3IfMT00`000000a/K60<K6
aP080<K6aPD0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`<0/k>c00<0
00000<K6aP36a/H04036a/H2000001h0fMWI0P00002N0>c/k0030000003IfMT0fMWI01`0fMWI00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`@00000403oool2000000H0oooo00<0
00000?ooo`3oool00P3oool00`2<S8`0000009nOW`0309nOW`030000002c/k<0/k>c0080/k>c00<0
00000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<0
00000?ooo`3oool03@3oool30?l000030000o`3oool0oooo02@0oooo00<000000>c/k03/k>`0?@3/
k>`00`000000oooo0?ooo`0P0?ooo`@0o`0000<0003o0?ooo`3oool05P3oool00`000000k>c/0>c/
k0080>c/k0030000003IfMT0fMWI00D0oooo00<000000?ooo`3oool06P3oool400000100oooo0P00
00060?ooo`030000003oool0oooo0080oooo0P2<S8`01@000000WinO09nOW`2OWil0000000@0/k>c
00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/
00<000000?ooo`3oool03@3oool20?l000030000o`3oool0oooo02D0oooo00<000000>c/k03/k>`0
?@3/k>`00`000000oooo0?ooo`0P0?ooo`@0o`0000<0003o0?ooo`3oool05P3oool00`000000k>c/
0>c/k0080>c/k0030000003IfMT0oooo00@0oooo00<000000?ooo`3oool07P3oool003D0oooo00<0
00000?ooo`3oool00P3oool80;>c/`0300000036a/H0a/K601H0a/K600<000000=WIf@3IfMT0:03I
fMT00`000000k>c/0>c/k01`0>c/k0800000:@3IfMT2000000P0a/K61@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0080oooo00<0/k>c0000000000004P36a/H00`000000fMWI0=WI
f@0L0=WIf@800000X@3/k>`2000001`0fMWI1@3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0080oooo00<0S8b<0000002OWil00P2OWil00`000000/k>c0;>c/`020;>c/`0300000036
a/H0a/K600<0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0090>c/k0030000003o
ool0oooo00d0oooo0P3o0002003o00030000o`3oool0oooo02<0oooo00<000000>c/k03/k>`0?`3/
k>`00`000000oooo0?ooo`0P0?ooo`<0o`0000<0oooo0000o`3oool05P3oool00`000000k>c/0>c/
k0080>c/k0030000003IfMT0fMWI00D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`020?ooo`0308b<S0000000WinO00<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6
aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?oo
o`0=0?ooo`050?l00000o`000?l00000o`3o0000903oool200000440k>c/00<000000?ooo`3oool0
803oool30?l000030000o`3oool0oooo01H0oooo00<000000>c/k03/k>`0203/k>`00`000000fMWI
0?ooo`040?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo1`2c
/k<00`000000a/K60<K6aP0F0<K6aP030000003IfMT0fMWI02H0fMWI0`00001e0>c/k0800000:@3I
fMT00`000000a/K60<K6aP050<K6aPD0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`020?ooo`0300000036a/H0a/K60140a/K600<000000=WIf@3IfMT0703IfMT00`000000k>c/0>c/
k02S0>c/k0030000003IfMT0fMWI01T0fMWI1@3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0080oooo00<0S8b<0000002OWil00P2OWil00`000000/k>c0;>c/`020;>c/`0300000036
a/H0a/K600<0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0090>c/k0030000003o
ool0oooo00`0oooo0P3o00001@00o`00003o0000o`00o`00o`0002<0oooo00<000000>c/k03/k>`0
@@3/k>`2000002@0oooo00<0003o0?ooo`3oool05P3oool00`000000k>c/0>c/k0080>c/k0030000
003IfMT0oooo00@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`0308b<
S0000000WinO00<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP020<K6aP030000
003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0<0?ooo`050?l0
0000o`000?l00000o`00o`000P3o000R0?ooo`030000003/k>`0k>c/0480k>c/00<000000?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`0F0?ooo`030000003/k>`0k>c/00P0k>c/00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`H0/k>c
00<000000<K6aP36a/H05@36a/H2000002L0fMWI0P00001j0>c/k0800000:03IfMT00`000000a/K6
0<K6aP040<K6aPD0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000
0036a/H0a/K60140a/K600<000000=WIf@3IfMT06`3IfMT00`000000k>c/0>c/k02U0>c/k0030000
003IfMT0fMWI01P0fMWI1@3oool00`000000oooo0?ooo`0g0?ooo`8000000`3oool00`2<S8`00000
09nOW`0209nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI
0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool0303oool20?l000<0003o
00<00?l00?l0003oool08@3oool00`000000k>c/0>c/k0130>c/k0030000003oool0oooo02<0oooo
00<0003o0?ooo`3oool05@3oool00`000000k>c/0>c/k0080>c/k0030000003IfMT0oooo00<0oooo
0P00000h0?ooo`8000000`3oool00`2<S8`0000009nOW`0309nOW`030000002c/k<0/k>c0080/k>c
00<000000<K6aP36a/H00P36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/
00<000000?ooo`3oool0303oool00`3o00000?l00000o`020000o`80o`008@3oool00`000000k>c/
0>c/k0140>c/k0030000003oool0oooo02<0oooo00<0003o0?ooo`3oool05@3oool00`000000k>c/
0>c/k0080>c/k0030000003oool0oooo0080oooo0P00000P0?ooo`00=@3oool00`000000oooo0?oo
o`020?ooo`D0/k>c00<000000<K6aP36a/H05@36a/H00`000000fMWI0=WIf@0T0=WIf@<00000OP3/
k>`2000002L0fMWI00<000000<K6aP36a/H00`36a/H50?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool00P3ooolC0<K6aP030000003IfMT0fMWI01/0fMWI00<000000>c/k03/k>`0Y`3/
k>`00`000000fMWI0=WIf@0G0=WIf@D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`020?ooo`050000002OWil0WinO09nOW`000000102c/k<00`000000a/K60<K6aP030<K6aP030000
003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0<0?ooo`<0o`00
00@0003o003o003o0000o`008@3oool00`000000k>c/0>c/k0150>c/k0030000003oool0oooo0280
oooo00<0003o0?ooo`3oool05P3oool00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00<0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`0308b<S0000000WinO0080
WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00@0
fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0=0?ooo`80o`000P000?l30?l00240
oooo00<000000>c/k03/k>`0A@3/k>`00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo01H0
oooo00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0
oooo000e0?ooo`8000000`3oool30;>c/`8000005P36a/H2000002D0fMWI0P0000230>c/k0800000
9P3IfMT2000000<0a/K6103oool200000300oooo00<000000?ooo`3oool00P3ooolB0<K6aP030000
003IfMT0fMWI01X0fMWI0P00002[0>c/k08000005`3IfMT50?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool00P3oool01@000000WinO09nOW`2OWil0000000@0/k>c00<000000<K6aP36
a/H00`36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3o
ool03@3oool20?l000030000o`3o0000o`000240oooo00<000000>c/k03/k>`0A`3/k>`00`000000
oooo0?ooo`0R0?ooo`030000o`3o0000o`0001D0oooo00<000000>c/k03/k>`0203/k>`00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`2<S8`0
000009nOW`0209nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36a/H00`000000
fMWI0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool03P3oool00`3o0000
003o0?l000020?l00240oooo00<000000>c/k03/k>`0A`3/k>`00`000000oooo0?ooo`0R0?ooo`03
0000o`3o0000o`0001D0oooo00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo0P2c/k<00`000000a/K6
0<K6aP0F0<K6aP030000003IfMT0fMWI02<0fMWI00<000000>c/k03/k>`0Q@3/k>`00`000000fMWI
0=WIf@0U0=WIf@0300000036a/H0a/K600D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?oooa00a/K60P00000K0=WIf@800000[`3/k>`2000001D0fMWI1@3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0080oooo00D0000009nOW`2OWil0WinO000000040;>c/`03
00000036a/H0a/K60080a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k0090>c/k003
0000003oool0oooo00l0oooo00<0003o0?l0003o00008@3oool00`000000k>c/0>c/k0190>c/k003
0000003oool0oooo0200oooo00<0o`000000o`00o`000P3o000D0?ooo`030000003/k>`0k>c/00P0
k>c/00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080
oooo00D0000009nOW`2OWil0WinO000000040;>c/`0300000036a/H0a/K600<0a/K600<000000=WI
f@3IfMT01@3IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00l0oooo00@0003o0?l0
003o0000o`00803oool2000004/0k>c/00<000000?ooo`3oool0803oool00`3o0000003o003o0002
0?l001@0oooo00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo0P2c/k<00`000000a/K60<K6aP0D0<K6
aP8000009@3IfMT00`000000k>c/0>c/k0270>c/k08000009@3IfMT00`000000a/K60<K6aP050?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool?0<K6aP030000003IfMT0fMWI
01/0fMWI00<000000>c/k03/k>`0E@3/k>`2000005T0k>c/00<000000=WIf@3IfMT04P3IfMT50?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool01@000000WinO09nOW`2OWil0
000000@0/k>c00<000000<K6aP36a/H00P36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0
k>c/00T0k>c/00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0P0?ooo`030000003/k>`0
k>c/04/0k>c/00<000000?ooo`3oool07P3oool01@3o00000?l0003o00000?l00?l00080o`00503o
ool00`000000k>c/0>c/k0080>c/k0030000003oool0oooo0080oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`020?ooo`050000002OWil0WinO09nOW`000000102c/k<00`000000a/K6
0<K6aP030<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0240oooo00<000000>c/k03/k>`0B`3/k>`00`000000oooo
0?ooo`0N0?ooo`050?l00000o`000?l00000o`00o`000P3o000D0?ooo`030000003/k>`0k>c/00L0
k>c/00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo
0?ooo`020?ooo`030;>c/`000000a/K601D0a/K600<000000=WIf@3IfMT08P3IfMT3000008`0k>c/
0P00000T0=WIf@0300000036a/H0oooo00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`l0a/K600<000000=WIf@3IfMT06@3IfMT2000004`0k>c/300000020?ooo`l00000
B`3/k>`00`000000fMWI0=WIf@0A0=WIf@D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`020?ooo`<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000
003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo0200oooo00<000000>c/k03/k>`0C@3/k>`00`000000oooo0?ooo`0M0?ooo`030?l0
0000o`00003o0080003o0P3o000D0?ooo`030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo102OWil01@000000/k>c
0;>c/`2c/k<0000000D0a/K600<000000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k0090>c/k003
0000003oool0oooo00h0oooo00<0003o0?ooo`3oool08@3oool00`000000k>c/0>c/k01<0>c/k003
0000003oool0oooo01h0oooo00<0o`00003o00000?l00P000?l20?l001@0oooo00<000000>c/k03/
k>`01`3/k>`50?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo
00<000000<K6aP36a/H05036a/H00`000000fMWI0=WIf@0R0=WIf@030000003/k>`0k>c/08l0k>c/
0P00000S0=WIf@030000003oool0oooo00<0oooo00<000000?ooo`3oool0;P3oool2000000<0oooo
3P36a/H00`000000fMWI0=WIf@0I0=WIf@030000003/k>`0k>c/04@0k>c/2000000M0?ooo`D00000
A`3/k>`00`000000fMWI0=WIf@0@0=WIf@@0oooo0P00000i0?ooo`030000003oool0oooo0080oooo
0`2OWil00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0
103IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0
7`3oool00`000000k>c/0>c/k01?0>c/k0030000003oool0oooo01`0oooo0P3o00000`00o`00003o
0000o`020?l001D0oooo00<000000>c/k03/k>`01`3/k>`50?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool00P3oool409nOW`050000002c/k<0/k>c0;>c/`0000001@36a/H00`000000
fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0P0?ooo`030000003/k>`0k>c/04h0k>c/0P00000N0?ooo`80o`0000<00?l00000o`00
0?l00P3o000E0?ooo`030000003/k>`0k>c/00H0k>c/1@3oool00`000000oooo0?ooo`0N0?ooo`00
=@3oool00`000000oooo0?ooo`020?oooaH0a/K600<000000=WIf@3IfMT08@3IfMT2000009@0k>c/
0P00000R0=WIf@030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`d0a/K600<000000=WIf@3IfMT06@3IfMT00`000000k>c/0>c/k0110>c/k0@00000
:P3oool5000004<0k>c/0P00000@0=WIf@D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`020?ooo`<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000
003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo01l0oooo00<000000>c/k03/k>`0D@3/k>`00`000000oooo0?ooo`0L0?ooo`@0o`00
00<0003o0?ooo`3oool0503oool00`000000k>c/0>c/k0070>c/k0D0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`020?ooo`@0WinO00D000000;>c/`2c/k<0/k>c000000050<K6aP03
0000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo0200oooo00<000000>c/k03/k>`0D@3/k>`00`000000oooo0?ooo`0L0?ooo`@0
o`0000<0003o0?ooo`3oool0503oool00`000000k>c/0>c/k0060>c/k0D0oooo00<000000?ooo`3o
ool07P3oool003D0oooo00<000000?ooo`3oool00P3ooolD0<K6aP8000008P3IfMT2000009P0k>c/
00<000000=WIf@3IfMT07`3IfMT50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
0P3oool<0<K6aP030000003IfMT0fMWI01P0fMWI0P00000o0>c/k0D00000<`3oool500000400k>c/
00<000000=WIf@3IfMT03@3IfMT50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
0P3oool209nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI
0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0O0?ooo`030000003/k>`0k>c/0540k>c/00<000000?ooo`3oool07@3oool30?l000030000
o`3oool0oooo01@0oooo00<000000>c/k03/k>`01`3/k>`50?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool00P3oool309nOW`030000002c/k<0/k>c0080/k>c00<000000<K6aP36a/H0
0`36a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0P0?ooo`030000003/k>`0k>c/0580k>c/00<000000?ooo`3oool0
703oool30?l000030000o`3oool0oooo01@0oooo00<000000>c/k03/k>`01P3/k>`50?ooo`030000
003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo4`36a/H00`000000fMWI0=WI
f@0Q0=WIf@030000003/k>`0k>c/09T0k>c/00<000000=WIf@3IfMT07P3IfMT50?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool00P3oool;0<K6aP030000003IfMT0fMWI01P0fMWI00<0
00000>c/k03/k>`0?03/k>`3000003d0oooo0P00000o0>c/k0030000003IfMT0fMWI00`0fMWI1@3o
ool00`000000oooo0?ooo`0g0?ooo`8000000`3oool209nOW`030000002c/k<0/k>c0080/k>c00<0
00000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<0
00000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0O0?ooo`030000003/k>`0k>c/05<0k>c/00<0
00000?ooo`3oool0803oool00`000?l0oooo0?ooo`0D0?ooo`030000003/k>`0k>c/00H0k>c/103o
ool2000003P0oooo0P0000030?ooo`<0WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6
aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo01l0oooo00<000000>c/k03/k>`0D`3/k>`00`000000oooo0?oo
o`0P0?ooo`030000o`3oool0oooo01<0oooo00<000000>c/k03/k>`01P3/k>`40?ooo`800000803o
ool003D0oooo00<000000?ooo`3oool00P3ooolC0<K6aP030000003IfMT0fMWI0200fMWI00<00000
0>c/k03/k>`0V`3/k>`2000001h0fMWI1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0080oooo2P36a/H00`000000fMWI0=WIf@0H0=WIf@030000003/k>`0k>c/03/0k>c/0P000012
0?ooo`D00000>`3/k>`00`000000fMWI0=WIf@0;0=WIf@D0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`020?ooo`80WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP02
0<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo01h0oooo00<000000>c/k03/k>`0E@3/k>`00`000000oooo0?ooo`0O
0?ooo`030000o`3oool0oooo01@0oooo00<000000>c/k03/k>`01P3/k>`50?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool00P3oool309nOW`050000002c/k<0/k>c0;>c/`0000001@36
a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0O0?ooo`030000003/k>`0k>c/05D0k>c/00<000000?ooo`3oool07`3o
ool00`000?l0oooo0?ooo`0C0?ooo`030000003/k>`0k>c/00H0k>c/1@3oool00`000000oooo0?oo
o`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?oooa80a/K600<000000=WIf@3IfMT0803IfMT0
0`000000k>c/0>c/k02N0>c/k0800000703IfMT50?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool00P3oool90<K6aP030000003IfMT0fMWI01P0fMWI00<000000>c/k03/k>`0=`3/k>`5
000004T0oooo0`00000i0>c/k0030000003IfMT0fMWI00X0fMWI1@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0080oooo0P2OWil01@000000/k>c0;>c/`2c/k<0000000D0a/K600<0
00000=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00h0oooo00<0
003o0?ooo`3oool07P3oool00`000000k>c/0>c/k01G0>c/k0030000003oool0oooo01l0oooo00<0
003o0?ooo`3oool0503oool00`000000k>c/0>c/k0050>c/k0D0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`020?ooo`80WinO00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6
aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo01h0oooo00<000000>c/k03/k>`0E`3/k>`00`000000oooo0?oo
o`0O0?ooo`030000o`3oool0oooo01<0oooo00<000000>c/k03/k>`01@3/k>`50?ooo`030000003o
ool0oooo01h0oooo000e0?ooo`8000000`3oool@0<K6aP800000803IfMT300000:<0k>c/0P00000J
0=WIf@@0oooo0P00000`0?ooo`030000003oool0oooo0080oooo2036a/H00`000000fMWI0=WIf@0H
0=WIf@030000003/k>`0k>c/03D0k>c/0`00001A0?ooo`800000>03/k>`00`000000fMWI0=WIf@09
0=WIf@D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`80WinO00D00000
0;>c/`2c/k<0/k>c000000050<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`0203/
k>`00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01h0oooo00<000000>c/k03/k>`0E`3/
k>`00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo01@0oooo00<000000>c/k03/k>`01@3/
k>`50?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool209nOW`030000002c
/k<0/k>c0080/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@040=WIf@030000003/
k>`0k>c/00P0k>c/00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0N0?ooo`030000003/
k>`0k>c/05T0k>c/00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0C0?ooo`030000003/
k>`0k>c/00D0k>c/1@3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`02
0?ooo`l0a/K600<000000=WIf@3IfMT07`3IfMT00`000000k>c/0>c/k02U0>c/k0030000003IfMT0
fMWI01P0fMWI1@3oool00`000000oooo0?ooo`0S0?ooo`L00000103oool00`000000oooo0?ooo`02
0?ooo`L0a/K60P00000H0=WIf@800000=P3/k>`2000005H0oooo0`00000f0>c/k08000002@3IfMT5
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`2OWil000000;>c/`03
0;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k009
0>c/k0030000003oool0oooo00d0oooo00<0003o0?ooo`3oool07P3oool00`000000k>c/0>c/k01I
0>c/k0030000003oool0oooo01h0oooo00<0o`000000o`3o0000503oool00`000000k>c/0>c/k005
0>c/k0D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`80WinO00D00000
0;>c/`2c/k<0/k>c000000050<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`0203/
k>`00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01d0oooo00<000000>c/k03/k>`0FP3/
k>`00`000000oooo0?ooo`0N0?ooo`030?l000000?l0o`0001@0oooo00<000000>c/k03/k>`0103/
k>`50?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo3P36a/H0
0`000000fMWI0=WIf@0O0=WIf@030000003/k>`0k>c/0:L0k>c/0P00000H0=WIf@D0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo1P36a/H0
0`000000fMWI0=WIf@0G0=WIf@030000003/k>`0k>c/03<0k>c/0`00001K0?ooo`800000=@3/k>`0
0`000000fMWI0=WIf@070=WIf@D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`02
0?ooo`0309nOW`000000/k>c00<0/k>c00<000000<K6aP36a/H00P36a/H2000000H0fMWI00<00000
0>c/k03/k>`0203/k>`00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01d0oooo00<00000
0>c/k03/k>`0F`3/k>`00`000000oooo0?ooo`0L0?ooo`80o`000P000?l00`3o0000oooo0?ooo`0A
0?ooo`8000001P3/k>`50?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool2
09nOW`050000002c/k<0/k>c0;>c/`0000001@36a/H00`000000fMWI0=WIf@040=WIf@8000002P3/
k>`00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01h0oooo00<000000>c/k03/k>`0F`3/
k>`00`000000oooo0?ooo`0L0?ooo`80o`0000<0003o003o003o00004`3oool00`000000k>c/0>c/
k0040>c/k0D0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool>
0<K6aP030000003IfMT0fMWI01h0fMWI00<000000>c/k03/k>`0ZP3/k>`00`000000fMWI0=WIf@0E
0=WIf@D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo1P36a/H00`000000fMWI0=WIf@0F0=WIf@030000003/k>`0k>c/0380k>c/0P00001P
0?ooo`800000=03/k>`2000000L0fMWI1@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0080oooo00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0
fMWI00@0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo01d0oooo00<000000>c/k03/k>`0:03/k>`>000002L0k>c/00<000000?ooo`3oool06P3oool2
0?l00005003o00000?l0003o0000o`3o00004`3oool00`000000k>c/0>c/k0040>c/k0D0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`0309nOW`000000/k>c00<0/k>c00<0
00000<K6aP36a/H00P36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00P0k>c/00<0
00000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0M0?ooo`030000003/k>`0k>c/02P0k>c/3@00
000W0>c/k0030000003oool0oooo01/0oooo0P3o00030000o`03003o003o0000oooo0140oooo00<0
00000>c/k03/k>`0103/k>`50?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0
oooo0080oooo3@36a/H00`000000fMWI0=WIf@0M0=WIf@800000[P3/k>`2000001D0fMWI1@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo0`0000020?ooo`D0a/K600<00000
0=WIf@3IfMT05P3IfMT200000380k>c/0P00001T0?ooo`<00000<`3/k>`00`000000fMWI0=WIf@04
0=WIf@<0oooo0`00000i0?ooo`030000003oool0oooo0080oooo00<000000;>c/`2c/k<00P2c/k<0
0`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`02@3/k>`0
0`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01d0oooo00<000000>c/k03/k>`08`3/k>`5
000000h0fMWI0P00000V0>c/k0030000003oool0oooo01T0oooo0P3o0002003o00030000o`00o`00
o`0001<0oooo00<000000>c/k03/k>`0103/k>`50?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool00P3oool00`2OWil000000;>c/`030;>c/`0300000036a/H0a/K60080a/K600<00000
0=WIf@3IfMT01@3IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00d0oooo00<0003o
0?ooo`3oool07@3oool00`000000k>c/0>c/k00T0>c/k0D000003@3IfMT3000002D0k>c/00<00000
0?ooo`3oool06P3oool20?l00005003o00000?l0003o003o003o00004`3oool00`000000k>c/0>c/
k0030>c/k0D0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool;
0<K6aP8000007P3IfMT200000;80k>c/00<000000=WIf@3IfMT04P3IfMT50?ooo`030000003oool0
oooo01X0oooo1P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool4
0<K6aP030000003IfMT0fMWI01H0fMWI00<000000>c/k03/k>`0<03/k>`2000006T0oooo0P00000b
0>c/k0030000003IfMT0fMWI00<0fMWI1@3oool00`000000oooo0?ooo`0g0?ooo`8000000`3oool0
1@000000/k>c0;>c/`2c/k<0000000D0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/
k0090>c/k0030000003oool0oooo00d0oooo00<0003o0?ooo`3oool07@3oool00`000000k>c/0>c/
k00R0>c/k08000005@3IfMT500000240k>c/00<000000?ooo`3oool06@3oool30?l000800?l000<0
003o0?l0003oool04P3oool00`000000k>c/0>c/k0040>c/k0@0oooo0P00000h0?ooo`8000000`3o
ool00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0103I
fMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0703o
ool00`000000k>c/0>c/k00R0>c/k0<000005@3IfMT400000280k>c/00<000000?ooo`3oool06@3o
ool30?l000800?l000<0003o0?l0003oool04P3oool00`000000k>c/0>c/k0030>c/k0@0oooo0P00
000P0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`X0a/K600<000000=WIf@3IfMT07@3IfMT0
0`000000k>c/0>c/k02c0>c/k08000004P3IfMT50?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`<0a/K600<000000=WIf@3IfMT05P3IfMT0
0`000000k>c/0>c/k00_0>c/k0800000K@3oool300000300k>c/00<000000=WIf@3IfMT00P3IfMT5
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool01@000000/k>c0;>c/`2c
/k<0000000D0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0090>c/k0030000003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0703oool00`000000k>c/0>c/k00P0>c/k0<00000703I
fMT200000200k>c/00<000000?ooo`3oool06@3oool40?l000030000o`3oool0oooo01<0oooo00<0
00000>c/k03/k>`00`3/k>`50?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3o
ool00`000000/k>c0;>c/`020;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0103I
fMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0703o
ool00`000000k>c/0>c/k00P0>c/k0800000703IfMT200000240k>c/00<000000?ooo`3oool06@3o
ool40?l000030000o`3oool0oooo01<0oooo00<000000>c/k03/k>`00P3/k>`50?ooo`030000003o
ool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo2@36a/H00`000000fMWI0=WIf@0N
0=WIf@030000003/k>`0k>c/0;D0k>c/00<000000=WIf@3IfMT03`3IfMT50?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80a/K600<00000
0=WIf@3IfMT05P3IfMT00`000000k>c/0>c/k00^0>c/k0800000LP3oool00`000000k>c/0>c/k00^
0>c/k08000000P3IfMT50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool0
1@000000/k>c0;>c/`2c/k<0000000D0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/
k0080>c/k0030000003oool0oooo00d0oooo00<0003o0?ooo`3oool0703oool00`000000k>c/0>c/
k00O0>c/k08000008@3IfMT00`000000k>c/0>c/k00N0>c/k0030000003oool0oooo01T0oooo0`3o
00000`3oool0003o0?ooo`0C0?ooo`030000003/k>`0k>c/00<0k>c/1@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo0080oooo00<000000;>c/`2c/k<00P2c/k<00`000000a/K60<K6
aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo01`0oooo00<000000>c/k03/k>`07`3/k>`200000200fMWI0P00
000P0>c/k0030000003oool0oooo01T0oooo0`3o00000`3oool0003o0?ooo`0C0?ooo`030000003/
k>`0k>c/0080k>c/1@3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`02
0?ooo`T0a/K600<000000=WIf@3IfMT06`3IfMT300000;T0k>c/00<000000=WIf@3IfMT03P3IfMT5
0?ooo`030000003oool0oooo02@0oooo0`0000070?ooo`030000003oool0oooo0080oooo0P36a/H0
0`000000fMWI0=WIf@0E0=WIf@030000003/k>`0k>c/02d0k>c/0P00001e0?ooo`030000003/k>`0
k>c/02l0k>c/00<000000=WIf@3oool0103oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0080oooo102c/k<00`000000a/K60<K6aP020<K6aP030000003IfMT0fMWI00D0fMWI00<00000
0>c/k03/k>`0203/k>`00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01`0oooo00<00000
0>c/k03/k>`07@3/k>`2000002@0fMWI00<000000>c/k03/k>`07@3/k>`00`000000oooo0?ooo`0M
0?ooo`040000o`3o0000o`000?l00180oooo00<000000>c/k03/k>`00P3/k>`50?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool00P3oool40;>c/`0300000036a/H0a/K600<0a/K600<0
00000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00d0oooo00<0
003o0?ooo`3oool0703oool00`000000k>c/0>c/k00M0>c/k0800000903IfMT00`000000k>c/0>c/
k00M0>c/k0030000003oool0oooo01d0oooo00@0003o0?l0003o0000o`004@3oool00`000000k>c/
0>c/k0020>c/k0D0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3o
ool80<K6aP030000003IfMT0fMWI01/0fMWI00<000000>c/k03/k>`0^`3/k>`2000000h0fMWI1@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool2000001L0fMWI00<000000>c/k03/k>`0;03/k>`2000007P0oooo0`00000^0>c/k0030000003I
fMT0oooo00@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`@0/k>c00<0
00000<K6aP36a/H00P36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00P0k>c/00<0
00000?ooo`3oool0303oool00`000?l0oooo0?ooo`0L0?ooo`030000003/k>`0k>c/01d0k>c/00<0
00000=WIf@3IfMT09@3IfMT3000001d0k>c/0P00000M0?ooo`030?l000000?l0o`000080o`004@3o
ool00`000000k>c/0>c/k0020>c/k0D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`020?ooo`@0/k>c00<000000<K6aP36a/H00`36a/H00`000000fMWI0=WIf@040=WIf@030000003/
k>`0k>c/00T0k>c/00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0L0?ooo`030000003/
k>`0k>c/01d0k>c/00<000000=WIf@3IfMT09@3IfMT3000001d0k>c/00<000000?ooo`3oool0703o
ool00`3o0000003o0?l000020?l00100oooo0P0000030>c/k0D0oooo00<000000?ooo`3oool07P3o
ool003D0oooo0P0000030?ooo`H0a/K60P00000M0=WIf@030000003/k>`0k>c/05D0k>c/4`00001F
0>c/k0030000003IfMT0fMWI00/0fMWI103oool200000300oooo00<000000?ooo`3oool00P3ooolH
0=WIf@030000003/k>`0k>c/02/0k>c/0P00001m0?ooo`800000;@3/k>`00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01/0oooo100000060?ooo`8000001`3oool4000000D0oooo00<00000
0?ooo`3oool00P3oool30;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0103IfMT0
0`000000k>c/0>c/k0080>c/k0030000003oool0oooo00d0oooo00<0003o0?ooo`3oool0703oool0
0`000000k>c/0>c/k00L0>c/k0030000003IfMT0fMWI02T0fMWI0P00000L0>c/k0030000003oool0
oooo01X0oooo0P3o00000`000?l00?l0003o00020?l00100oooo00<000000>c/k03/k>`00P3/k>`5
0?ooo`030000003oool0oooo01X0oooo100000060?ooo`8000001`3oool4000000D0oooo00<00000
0?ooo`3oool00P3oool40;>c/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0103IfMT0
0`000000k>c/0>c/k0080>c/k0030000003oool0oooo00d0oooo00<0003o0?ooo`3oool06`3oool0
0`000000k>c/0>c/k00L0>c/k0800000:`3IfMT2000001/0k>c/00<000000?ooo`3oool06`3oool2
0?l000030000o`00o`00o`000080o`00403oool010000000k>c/0>c/k03/k>`50?ooo`030000003o
ool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo1@36a/H00`000000fMWI0=WIf@0K
0=WIf@800000CP3/k>`:000001<0oooo2000001?0>c/k0030000003IfMT0fMWI00X0fMWI1@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo5P3IfMT2000002d0k>c/00<00000
0?ooo`3oool0O`3oool2000002`0k>c/00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`2c/k<0
0`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`0
0`000000oooo0?ooo`0:0?ooo`80o`0000<0003o0?ooo`3oool0703oool00`000000k>c/0>c/k00J
0>c/k0<00000;P3IfMT00`000000k>c/0>c/k00J0>c/k0030000003oool0oooo01T0oooo0P3o0000
1@00o`00003o003o0000o`00o`000140oooo00@000000>c/k03/k>`0k>c/1@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
102c/k<00`000000a/K60<K6aP020<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/k03/k>`0
203/k>`00`000000oooo0?ooo`090?ooo`<0o`0000<0003o0?ooo`3oool06`3oool00`000000k>c/
0>c/k00K0>c/k0800000;`3IfMT00`000000k>c/0>c/k00I0>c/k0030000003oool0oooo01T0oooo
0P3o00001000o`00003o0000o`00o`020?l00100oooo00@000000>c/k03/k>`0k>c/1@3oool00`00
0000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`D0a/K600<000000=WIf@3I
fMT06P3IfMT00`000000k>c/0>c/k0190>c/k0D000009@3oool5000004/0k>c/00<000000=WIf@3I
fMT02@3IfMT50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3ooolE0=WIf@03
0000003/k>`0k>c/02/0k>c/0P0000240?ooo`030000003/k>`0k>c/02T0k>c/1@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool30;>c/`03
00000036a/H0a/K60080a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k003
0000003oool0oooo00X0oooo0`3o00000`000?l0o`000?ooo`0K0?ooo`030000003/k>`0k>c/01X0
k>c/00<000000=WIf@3IfMT0<03IfMT00`000000k>c/0>c/k00I0>c/k0030000003oool0oooo01T0
oooo00<0o`00003o00000?l00P000?l00`00o`00o`000?ooo`0@0?ooo`040000003/k>`0k>c/0>c/
k0D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo0`2c/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/
k03/k>`0203/k>`00`000000oooo0?ooo`090?ooo`@0o`0000<0003o0?ooo`3oool06P3oool00`00
0000k>c/0>c/k00J0>c/k0800000<P3IfMT00`000000k>c/0>c/k00I0>c/k0030000003oool0oooo
01P0oooo0P3o00030000o`03003o003o0000o`000100oooo00@000000>c/k03/k>`0k>c/1@3oool0
0`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`@0a/K600<000000=WI
f@3IfMT06`3IfMT00`000000k>c/0>c/k0140>c/k0D00000;`3oool5000004L0k>c/00<000000=WI
f@3IfMT0203IfMT50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3ooolE0=WI
f@030000003/k>`0k>c/02X0k>c/00<000000?ooo`3oool0Q@3oool2000002T0k>c/1@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool20000
00<0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0`2c/k<00`000000a/K60<K6aP020<K6
aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`090?oo
o`80o`0000<00?l00000o`3o00000P3o000J0?ooo`030000003/k>`0k>c/01T0k>c/0P00000d0=WI
f@8000006P3/k>`00`000000oooo0?ooo`0H0?ooo`050?l00000o`000?l00000o`00o`000P3o000A
0?ooo`040000003/k>`0k>c/0>c/k0<0oooo0`00000K0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3oool00P3oool300000080oooo0`2c
/k<00`000000a/K60<K6aP030<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/
k>`00`000000oooo0?ooo`080?ooo`<0o`0000@00?l00000o`3o0000o`006`3oool00`000000k>c/
0>c/k00I0>c/k0030000003IfMT0fMWI03<0fMWI0P00000J0>c/k0030000003oool0oooo01L0oooo
0P3o00001@00o`00003o0000o`00o`00o`000180oooo00<000000>c/k03/k>`0103oool200000200
oooo000e0?ooo`030000003oool0oooo0080oooo0`36a/H00`000000fMWI0=WIf@0J0=WIf@800000
@`3/k>`4000003T0oooo1@0000130>c/k0800000203IfMT50?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool00P3ooolD0=WIf@030000003/k>`0k>c/02T0k>c/0P00002:0?ooo`030000
003/k>`0k>c/02H0k>c/1@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool0
0P3oool30;>c/`0300000036a/H0a/K60080a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/
0>c/k0080>c/k0030000003oool0oooo00T0oooo00<0o`00003o00000?l00P000?l20?l001X0oooo
00<000000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0f0=WIf@030000003/k>`0k>c/01P0k>c/
00<000000?ooo`3oool0603oool01@3o00000?l0003o00000?l0o`000180oooo00@000000>c/k03/
k>`0k>c/1@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool00P3oool30;>c
/`0300000036a/H0a/K600<0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0070>c/
k0030000003oool0oooo00T0oooo0P3o00001@00o`00003o0000o`000?l0o`0001/0oooo00<00000
0>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0e0=WIf@030000003/k>`0k>c/01P0k>c/00<00000
0?ooo`3oool0603oool20?l000800?l000<0003o0?ooo`3oool04@3oool00`000000k>c/0>c/k005
0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo0P36a/H00`00
0000fMWI0=WIf@0J0=WIf@030000003/k>`0k>c/0400k>c/0`0000120?ooo`<00000@P3/k>`00`00
0000fMWI0=WIf@050=WIf@D0oooo00<000000?ooo`3oool0;P3oool2000000<0oooo4`3IfMT00`00
0000k>c/0>c/k00X0>c/k0800000S@3oool2000002H0k>c/103oool2000001`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool20;>c/`0300000036a/H0a/K60080a/K600<000000=WIf@3IfMT01@3IfMT00`00
0000k>c/0>c/k0080>c/k0030000003oool0oooo00T0oooo00D0o`00003o0000o`00003o003o0002
0?l001T0oooo00<000000>c/k03/k>`0603/k>`00`000000fMWI0=WIf@0h0=WIf@030000003/k>`0
k>c/01L0k>c/00<000000?ooo`3oool06@3oool20?l000030000o`3oool0oooo0180oooo00<00000
0>c/k03/k>`01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0`2c/k<0
0`000000a/K60<K6aP020<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`0
0`000000oooo0?ooo`090?ooo`80o`000P00o`000`000?l00?l00?l0000J0?ooo`030000003/k>`0
k>c/01P0k>c/00<000000=WIf@3IfMT0=`3IfMT2000001T0k>c/00<000000?ooo`3oool0603oool3
0?l000030000o`3oool0oooo0180oooo00<000000>c/k03oool0103oool00`000000oooo0?ooo`0N
0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`030<K6aP000000fMWI01X0fMWI0P0000110>c/
k0800000B03oool4000003l0k>c/00<000000=WIf@3IfMT0103IfMT50?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool00P3ooolB0=WIf@030000003/k>`0k>c/02P0k>c/00<000000?oo
o`3oool0S`3oool2000002@0k>c/1@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo0P2c/k<00`000000a/K60<K6aP020<K6aP030000003IfMT0fMWI00D0fMWI00<000000>c/
k03/k>`0203/k>`00`000000oooo0?ooo`0:0?ooo`030?l000000?l00?l00080o`006P3oool00`00
0000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI03T0fMWI00<000000>c/k03/k>`05`3/k>`00`00
0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo0180oooo00<000000>c/k03/k>`01@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0`2c/k<00`000000a/K60<K6aP020<K6
aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0:0?oo
o`80o`0000<0003o003o003o00006P3oool00`000000k>c/0>c/k00H0>c/k0030000003IfMT0fMWI
03X0fMWI00<000000>c/k03/k>`05P3/k>`00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo
0180oooo00<000000>c/k03oool0103oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000
oooo0?ooo`020?ooo`030<K6aP000000fMWI01T0fMWI00<000000>c/k03/k>`0?03/k>`5000004h0
oooo0P00000n0>c/k0030000003IfMT0fMWI00<0fMWI1@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0080oooo4@3IfMT00`000000k>c/0>c/k00W0>c/k0800000U03oool00`000000
k>c/0>c/k00Q0>c/k0D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0;>c/`000000a/K600@0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k003
0000003oool0oooo00`0oooo00<0003o0?l0003o00006P3oool00`000000k>c/0>c/k00G0>c/k080
0000?@3IfMT00`000000k>c/0>c/k00F0>c/k0030000003oool0oooo01/0oooo00<0003o0?l0003o
00004@3oool00`000000k>c/0>c/k0050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool20;>c/`0300000036a/H0a/K60080a/K600<000000=WIf@3IfMT0103IfMT00`000000
k>c/0>c/k0080>c/k0030000003oool0oooo00`0oooo00<0o`000000o`3o00006P3oool00`000000
k>c/0>c/k00H0>c/k0030000003IfMT0fMWI03`0fMWI00<000000>c/k03/k>`05P3/k>`00`000000
oooo0?ooo`0J0?ooo`030?l000000?l0o`000180oooo00<000000>c/k03oool0103oool00`000000
oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`030000003IfMT0fMWI01T0fMWI
00<000000>c/k03/k>`0>@3/k>`3000005D0oooo0`00000l0>c/k0030000003IfMT0fMWI0080fMWI
1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo403IfMT00`000000k>c/
0>c/k00V0>c/k0800000U`3oool00`000000k>c/0>c/k00P0>c/k0D0oooo00<000000?ooo`3oool0
6`3oool400000140oooo0`0000040?ooo`030000003oool0oooo0080oooo00<0/k>c00000036a/H0
1036a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0I0?ooo`030000003/k>`0k>c/01L0k>c/00<000000=WIf@3IfMT0
?P3IfMT2000001L0k>c/00<000000?ooo`3oool06@3oool00`3o0000003o0?l000020?l00140oooo
00<000000>c/k03oool0103oool00`000000oooo0?ooo`0J0?ooo`@000004@3oool3000000@0oooo
00<000000?ooo`3oool00P3oool20;>c/`0300000036a/H0a/K60080a/K600<000000=WIf@3IfMT0
103IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00d0oooo00<0003o0?ooo`3oool0
6@3oool00`000000k>c/0>c/k00G0>c/k0030000003IfMT0fMWI03h0fMWI00<000000>c/k03/k>`0
5P3/k>`00`000000oooo0?ooo`0H0?ooo`80o`0000<0003o0?l0003o00004P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo6`3I
fMT00`000000k>c/0>c/k00h0>c/k0800000F`3oool3000003X0k>c/0P0000020=WIf@D0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`l0fMWI00<000000>c/k03/k>`09`3/
k>`00`000000oooo0?ooo`2G0?ooo`<000007`3/k>`50?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool00P3oool00`2c/k<000000<K6aP040<K6aP030000003IfMT0fMWI00@0fMWI00<0
00000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01X0oooo00<0
00000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@110=WIf@030000003/k>`0k>c/01D0k>c/00<0
00000?ooo`3oool05`3oool20?l00003003o00000?l0o`000080o`00403oool00`000000k>c/0?oo
o`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool20;>c/`0300000036
a/H0a/K60080a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k0030000003o
ool0oooo00`0oooo00<0003o0?ooo`3oool06@3oool00`000000k>c/0>c/k00F0>c/k0800000@P3I
fMT00`000000k>c/0>c/k00E0>c/k0030000003oool0oooo01L0oooo0`3o00020000o`80o`004@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo000e0?ooo`8000000`3ooolI
0=WIf@800000>03/k>`300000600oooo0P00000j0>c/k0030000003IfMT0oooo00<0oooo0P00000`
0?ooo`030000003oool0oooo0080oooo3P3IfMT00`000000k>c/0>c/k00V0>c/k0800000W@3oool0
0`000000k>c/0>c/k00L0>c/k0D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`02
0?ooo`030;>c/`000000a/K600<0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k008
0>c/k0030000003oool0oooo00`0oooo00<0003o0?ooo`3oool06@3oool00`000000k>c/0>c/k00F
0>c/k0030000003IfMT0fMWI04<0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0G
0?ooo`030?l00000o`00003o0080003o0P3o000A0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030;>c/`000000a/K600@0a/K600<00000
0=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00`0oooo00<0003o
0?ooo`3oool06@3oool00`000000k>c/0>c/k00E0>c/k0030000003IfMT0fMWI04<0fMWI00<00000
0>c/k03/k>`05@3/k>`00`000000oooo0?ooo`0F0?ooo`80o`000`000?l00`00o`00o`000?ooo`0@
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?oo
o`3oool00P3ooolH0=WIf@030000003/k>`0k>c/03H0k>c/0P00001U0?ooo`<00000>03/k>`00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool=0=WI
f@030000003/k>`0k>c/02D0k>c/0P00002P0?ooo`030000003/k>`0k>c/01/0k>c/1@3oool00`00
0000oooo0?ooo`0g0?ooo`8000000`3oool00`2c/k<000000<K6aP030<K6aP030000003IfMT0fMWI
00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
01T0oooo0P00000G0>c/k0030000003IfMT0fMWI04@0fMWI00<000000>c/k03/k>`05@3/k>`00`00
0000oooo0?ooo`0F0?ooo`050?l00000o`000?l00000o`00o`000P3o000A0?ooo`030000003oool0
oooo0080oooo0P00000h0?ooo`8000000`3oool00`2c/k<000000<K6aP040<K6aP030000003IfMT0
fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo01T0oooo00<000000>c/k03/k>`05P3/k>`00`000000fMWI0=WIf@140=WIf@030000003/k>`0
k>c/01@0k>c/00<000000?ooo`3oool05P3oool20?l00005003o00000?l0003o003o003o00004@3o
ool00`000000oooo0?ooo`020?ooo`800000803oool003D0oooo00<000000?ooo`3oool00P3ooolG
0=WIf@030000003/k>`0k>c/03D0k>c/0P00001Z0?ooo`800000=P3/k>`00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool<0=WIf@030000003/k>`0
k>c/02D0k>c/00<000000?ooo`3oool0X@3oool2000001/0k>c/1@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0080oooo00<000000<K6aP36a/H00P36a/H00`000000fMWI0=WIf@04
0=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0H
0?ooo`030000003/k>`0k>c/01H0k>c/00<000000=WIf@3IfMT0AP3IfMT00`000000k>c/0>c/k00D
0>c/k0030000003oool0oooo01L0oooo00D0o`00003o0000o`00003o0?l0000B0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030;>c/`00
0000a/K600<0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k0030000003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0603oool00`000000k>c/0>c/k00F0>c/k0030000003I
fMT0fMWI04H0fMWI00<000000>c/k03/k>`0503/k>`00`000000oooo0?ooo`0F0?ooo`80o`000P00
o`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3o
ool003D0oooo00<000000?ooo`3oool00P3ooolF0=WIf@030000003/k>`0k>c/03D0k>c/00<00000
0?ooo`3oool0K03oool2000003D0k>c/00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0080oooo303IfMT00`000000k>c/0>c/k00T0>c/k0030000003oool0
oooo0:@0oooo00<000000>c/k03/k>`0603/k>`50?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool00P3oool00`000000a/K60<K6aP020<K6aP030000003IfMT0fMWI00@0fMWI00<00000
0>c/k03/k>`0203/k>`00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01P0oooo00<00000
0>c/k03/k>`05@3/k>`00`000000fMWI0=WIf@180=WIf@030000003/k>`0k>c/01@0k>c/00<00000
0?ooo`3oool05`3oool20?l000030000o`3oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<0/k>c00000036a/H00`36a/H0
0`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0H0?ooo`030000003/k>`0k>c/01D0k>c/00<000000=WIf@3IfMT0B03IfMT0
0`000000k>c/0>c/k00D0>c/k0030000003oool0oooo01H0oooo0`3o00000`000?l0oooo0?ooo`0A
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?oo
o`3oool00P3ooolE0=WIf@030000003/k>`0k>c/03@0k>c/0P00001a0?ooo`800000<`3/k>`50?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool:0=WIf@8000009@3/k>`20000
0:P0oooo00<000000>c/k03/k>`05`3/k>`50?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool00P3oool00`000000a/K60<K6aP020<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/
k03/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01P0oooo00<000000>c/
k03/k>`05@3/k>`00`000000fMWI0=WIf@1:0=WIf@800000503/k>`00`000000oooo0?ooo`0I0?oo
o`030000o`3oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0080oooo00<000000<K6aP36a/H00P36a/H00`000000fMWI0=WIf@040=WI
f@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0H0?oo
o`030000003/k>`0k>c/01@0k>c/0P00001<0=WIf@030000003/k>`0k>c/01<0k>c/00<000000?oo
o`3oool06@3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3ooolC0=WIf@800000=03/k>`3000007D0
oooo0P00000a0>c/k0D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`T0
fMWI00<000000>c/k03/k>`08`3/k>`200000:/0oooo00<000000>c/k03/k>`05P3/k>`50?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`000000a/K60<K6aP020<K6aP03
0000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo01P0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@1=0=WIf@03
0000003/k>`0k>c/0180k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0F0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`000000a/K60<K6aP020<K6aP03
0000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo01P0oooo00<000000>c/k03/k>`0503/k>`00`000000fMWI0=WIf@1<0=WIf@03
0000003/k>`0k>c/01<0k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0E0?ooo`03
0000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo4P3IfMT00`000000k>c/
0>c/k00b0>c/k0800000NP3oool00`000000k>c/0>c/k00^0>c/k0D0oooo00<000000?ooo`3oool0
;P3oool2000000<0oooo203IfMT00`000000k>c/0>c/k00S0>c/k0030000003oool0oooo0:`0oooo
0P00000F0>c/k0@0oooo0P00000i0?ooo`030000003oool0oooo0080oooo1036a/H00`000000fMWI
0=WIf@040=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0H0?ooo`030000003/k>`0k>c/01<0k>c/00<000000=WIf@3IfMT08P3IfMT9000002@0fMWI
00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01H0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`D0a/K600<000000=WIf@3IfMT0
103IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0
603oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI0280fMWI2@00000S0=WIf@030000
003/k>`0k>c/0180k>c/00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0E0?ooo`030000
003oool0oooo01h0oooo000Z0?ooo`L00000103oool00`000000oooo0?ooo`020?oooa80fMWI00<0
00000>c/k03/k>`0<03/k>`2000007d0oooo0P00000^0>c/k0D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`P0fMWI00<000000>c/k03/k>`08P3/k>`00`000000oooo0?oo
o`2_0?ooo`030000003/k>`0k>c/01<0k>c/1@3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0080oooo1036a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00P0k>c/00<0
00000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0H0?ooo`030000003/k>`0k>c/01<0k>c/00<0
00000=WIf@3IfMT07P3IfMT5000000T0a/K61@00000O0=WIf@030000003/k>`0k>c/0180k>c/00<0
00000?ooo`3oool0603oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool00P3oool50<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`01`3/
k>`00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01P0oooo00<000000>c/k03/k>`04`3/
k>`00`000000fMWI0=WIf@0N0=WIf@D000002@36a/H4000001l0fMWI00<000000>c/k03/k>`04`3/
k>`00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool07P3o
ool002d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oooa40fMWI00<00000
0>c/k03/k>`0<03/k>`00`000000oooo0?ooo`1o0?ooo`<00000:`3/k>`50?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool00P3oool70=WIf@030000003/k>`0k>c/0280k>c/00<00000
0?ooo`3oool0/@3oool00`000000k>c/0>c/k00B0>c/k0D0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`020?ooo`@0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k008
0>c/k0030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0603oool00`000000k>c/0>c/k00C
0>c/k0030000003IfMT0fMWI01`0fMWI0P00000C0<K6aP8000007P3IfMT00`000000k>c/0>c/k00B
0>c/k0030000003oool0oooo01P0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0080oooo1@36a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0
k>c/00L0k>c/00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0G0?ooo`030000003/k>`0
k>c/01@0k>c/00<000000=WIf@3IfMT0703IfMT200000180a/K60`00000M0=WIf@8000004`3/k>`0
0`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool07P3oool0
02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`l0fMWI0P00000a0>c/
k0800000Q@3oool00`000000k>c/0>c/k00X0>c/k0D0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`020?ooo`D0fMWI0P00000S0>c/k0800000]@3oool00`000000k>c/0>c/k00A0>c/
k0D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`<0a/K600<000000=WI
f@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00`0oooo00<0003o0?oo
o`3oool05`3oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI01T0fMWI1000000G0<K6
aP<00000703IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01P0oooo00<0003o0?oo
o`3oool05@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo1036a/H00`00
0000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0F0?ooo`030000003/k>`0k>c/01@0k>c/00<000000=WIf@3IfMT0603IfMT50000
01L0a/K60P00000L0=WIf@030000003/k>`0k>c/0180k>c/00<000000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo000]0?ooo`030000003oool0oooo00D0
oooo0P0000030?ooo`h0fMWI0P00000_0>c/k0<00000R03oool2000002P0k>c/103oool200000300
oooo00<000000?ooo`3oool00P3oool40=WIf@030000003/k>`0k>c/0280k>c/00<000000?ooo`3o
ool0]P3oool200000140k>c/1@3oool00`000000oooo0?ooo`0g0?ooo`8000000`3oool30<K6aP03
0000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo01L0oooo0P00000D0>c/k0030000003IfMT0fMWI01P0fMWI0P00000N0<K6aP<0
00006P3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01P0oooo00<0003o0?ooo`3o
ool04`3oool2000003P0oooo0P0000030?ooo`@0a/K600<000000=WIf@3IfMT0103IfMT00`000000
k>c/0>c/k0080>c/k0030000003oool0oooo00/0oooo00<0003o0?ooo`3oool05`3oool00`000000
k>c/0>c/k00C0>c/k0030000003IfMT0fMWI01P0fMWI00<000000<K6aP36a/H07036a/H3000001X0
fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0180
oooo0P00000P0?ooo`008@3oool6000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`d0fMWI00<000000>c/k03/k>`0;@3/k>`2000008d0oooo0P00000V0>c/k0D0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`@0fMWI00<000000>c/k03/k>`0
8@3/k>`00`000000oooo0?ooo`2i0?ooo`030000003/k>`0k>c/00h0k>c/1@3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0080oooo0`36a/H00`000000fMWI0=WIf@040=WIf@030000
003/k>`0k>c/00P0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0G0?ooo`030000
003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT0603IfMT00`000000a/K60<K6aP0Q0<K6aP800000
603IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0
503oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo1036a/H00`000000fMWI
0=WIf@040=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0G0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT0603IfMT00`000000a/K6
0<K6aP0P0<K6aP8000006@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0oooo01P0oooo
00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`00;@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo303IfMT00`000000k>c/0>c/k00]0>c/k0030000003o
ool0oooo08l0oooo0P00000T0>c/k0D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`020?ooo`<0fMWI00<000000>c/k03/k>`0803/k>`200000;d0oooo00<000000>c/k03/k>`03@3/
k>`50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool30<K6aP030000003I
fMT0fMWI00@0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo01H0oooo00<000000>c/k03/k>`04`3/k>`00`000000fMWI0=WIf@0F0=WIf@8000009P36
a/H2000001H0fMWI00<000000>c/k03/k>`04P3/k>`00`000000oooo0?ooo`0G0?ooo`030000o`3o
0000o`0001@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`<0a/K600<0
00000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00`0oooo00<0
003o0?ooo`3oool05P3oool00`000000k>c/0>c/k00C0>c/k0030000003IfMT0fMWI01H0fMWI0P00
000U0<K6aP8000005`3IfMT00`000000k>c/0>c/k00B0>c/k0030000003oool0oooo01H0oooo00<0
o`000000o`3o0000503oool00`000000oooo0?ooo`0N0?ooo`00;@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo303IfMT00`000000k>c/0>c/k00[0>c/k0<00000T`3oool0
0`000000k>c/0>c/k00Q0>c/k0D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`02
0?ooo`80fMWI00<000000>c/k03/k>`0803/k>`00`000000oooo0?ooo`2n0?ooo`8000003@3/k>`5
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool30<K6aP030000003IfMT0
fMWI00@0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo01L0oooo00<000000>c/k03/k>`04P3/k>`00`000000fMWI0=WIf@0E0=WIf@800000:@36a/H0
0`000000fMWI0=WIf@0E0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool05P3oool0
0`3o00000?l00000o`020?l001<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`02
0?ooo`<0a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0
oooo00/0oooo00<0003o0?ooo`3oool05`3oool00`000000k>c/0>c/k00A0>c/k08000005P3IfMT3
000002T0a/K600<000000=WIf@3IfMT05@3IfMT00`000000k>c/0>c/k00A0>c/k0030000003oool0
oooo01D0oooo0P3o00000`00o`00003o0?l0000C0?ooo`030000003oool0oooo01h0oooo000[0?oo
o`<000001`3oool00`000000oooo0?ooo`020?ooo`X0fMWI0P00000/0>c/k0800000U`3oool20000
0240k>c/1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<0fMWI0000
003/k>`08@3/k>`00`000000oooo0?ooo`310?ooo`030000003/k>`0k>c/00X0k>c/1@3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo0P36a/H00`000000fMWI0=WIf@040=WI
f@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0F0?oo
o`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT0503IfMT2000002`0a/K60P00000F0=WI
f@8000004P3/k>`00`000000oooo0?ooo`0D0?ooo`050?l00000o`000?l00000o`00o`000P3o000B
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool30<K6aP030000003IfMT0
fMWI00@0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01H0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0E0=WIf@0300000036a/H0
a/K602/0a/K60P00000F0=WIf@030000003/k>`0k>c/0140k>c/00<000000?ooo`3oool04`3oool2
0?l00005003o00000?l0003o003o003o00004P3oool00`000000oooo0?ooo`0N0?ooo`00;@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo2@3IfMT00`000000k>c/0>c/k00/
0>c/k0030000003oool0oooo09P0oooo00<000000>c/k03/k>`07P3/k>`50?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool00P3oool00`000000k>c/0>c/k00Q0>c/k0030000003oool0
oooo0<80oooo00<000000>c/k03/k>`02@3/k>`50?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool00P3oool20<K6aP030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`0203/k>`0
0`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo01L0oooo00<000000>c/k03/k>`04@3/k>`0
0`000000fMWI0=WIf@0D0=WIf@0300000036a/H0a/K602h0a/K60P00000E0=WIf@030000003/k>`0
k>c/0140k>c/00<000000?ooo`3oool04`3oool00`3o00000?l00000o`020000o`80o`004P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0`36a/H00`000000fMWI0=WIf@04
0=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0F
0?ooo`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT0503IfMT00`000000a/K60<K6aP0^
0<K6aP8000005@3IfMT00`000000k>c/0>c/k00@0>c/k0030000003oool0oooo01<0oooo0P3o0003
0000o`03003o003o0000oooo0140oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?oo
o`3oool00P3oool80=WIf@030000003/k>`0k>c/02/0k>c/0P00002L0?ooo`8000007P3/k>`50?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3ooolR0>c/k0800000=`3oool20?l0
08d0oooo00<000000>c/k03/k>`0203/k>`50?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool00P3oool20<K6aP030000003IfMT0fMWI00<0fMWI00<000000>c/k03/k>`0203/k>`00`00
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01H0oooo00<000000>c/k03/k>`04@3/k>`00`00
0000fMWI0=WIf@0D0=WIf@0300000036a/H0a/K60340a/K60P00000D0=WIf@030000003/k>`0k>c/
0100k>c/00<000000?ooo`3oool04`3oool20?l00003003o00000?l0003o0080o`004P3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0`36a/H00`000000fMWI0=WIf@030=WI
f@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0E0?oo
o`030000003/k>`0k>c/0180k>c/00<000000=WIf@3IfMT04`3IfMT2000003<0a/K600<000000=WI
f@3IfMT04`3IfMT00`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01<0oooo0`3o00001000
0?l00?l00000o`3o000B0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo
0080oooo1`3IfMT00`000000k>c/0>c/k00Z0>c/k0800000X03oool2000001`0k>c/1@3oool00`00
0000oooo0?ooo`0^0?ooo`8000000`3ooolQ0>c/k0030000003oool0oooo03D0oooo1P3o002<0?oo
o`030000003/k>`0k>c/00L0k>c/103oool2000003T0oooo00<000000?ooo`3oool00P3oool00`36
a/H000000=WIf@050=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool02@3oool20?l0
00030000o`3oool0oooo01H0oooo00<000000>c/k03/k>`04@3/k>`00`000000fMWI0=WIf@0B0=WI
f@800000=P36a/H00`000000fMWI0=WIf@0B0=WIf@030000003/k>`0k>c/0100k>c/00<000000?oo
o`3oool04`3oool30?l000030000o`3o0000oooo0180oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`020?ooo`80a/K600<000000=WIf@3IfMT0103IfMT00`000000k>c/0>c/k0070>c/
k0030000003oool0oooo00T0oooo0`3o00000`000?l0oooo0?ooo`0E0?ooo`030000003/k>`0k>c/
0140k>c/00<000000=WIf@3IfMT04`3IfMT00`000000a/K60<K6aP0d0<K6aP800000503IfMT00`00
0000k>c/0>c/k00?0>c/k0030000003oool0oooo01<0oooo103o00000`000?l0oooo0?ooo`0A0?oo
o`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo1P3IfMT00`000000
k>c/0>c/k00Z0>c/k0800000X`3oool00`000000k>c/0>c/k00I0>c/k0D0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`020?ooob00k>c/00<000000?ooo`3oool0=P3oool20?l000<0
0?l000<0o`000?ooo`3oool0R`3oool2000000L0k>c/1@3oool00`000000oooo0?ooo`0g0?ooo`80
00000`3oool00`36a/H000000=WIf@050=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3o
ool0203oool00`3o00000?l00000o`020?l001H0oooo00<000000>c/k03/k>`04@3/k>`00`000000
fMWI0=WIf@0B0=WIf@0300000036a/H0a/K603L0a/K600<000000=WIf@3IfMT04@3IfMT00`000000
k>c/0>c/k00@0>c/k0030000003oool0oooo01@0oooo0`3o00000`000?l0oooo0?ooo`0@0?ooo`80
0000>03oool2000000<0oooo0P36a/H00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00L0
k>c/00<000000?ooo`3oool0203oool20?l00080003o00<0o`000?ooo`3oool0503oool00`000000
k>c/0>c/k00B0>c/k0030000003IfMT0fMWI0180fMWI00<000000<K6aP36a/H0=`36a/H00`000000
fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3oool04`3oool30?l00003
0000o`3oool0oooo0100oooo0P00000P0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`H0fMWI
00<000000>c/k03/k>`0:03/k>`200000:H0oooo00<000000>c/k03/k>`0603/k>`50?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool00P3ooolO0>c/k0030000003oool0oooo03H0oooo
0P3o0005003o00030?l0003oool0oooo08`0oooo00<000000>c/k03/k>`0103/k>`50?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`36a/H000000=WIf@050=WIf@030000
003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0203oool00`3o00000?l00000o`020000o`80o`00
5@3oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H0
>@36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
0P3oool00`36a/H000000=WIf@050=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0
1`3oool20?l000<0003o00<00?l00?l0003oool0503oool00`000000k>c/0>c/k00A0>c/k0030000
003IfMT0fMWI0180fMWI00<000000<K6aP36a/H0>@36a/H00`000000fMWI0=WIf@0@0=WIf@030000
003/k>`0k>c/0100k>c/00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0@0?ooo`030000
003oool0oooo01h0oooo000e0?ooo`8000000`3oool50=WIf@030000003/k>`0k>c/02P0k>c/00<0
00000?ooo`3oool0Y`3oool2000001P0k>c/103oool200000300oooo00<000000?ooo`3oool00P3o
oolN0>c/k0030000003oool0oooo03L0oooo0P3o0005003o00030?l0003oool0oooo08d0oooo00<0
00000>c/k03/k>`00`3/k>`50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3o
ool00`36a/H000000=WIf@050=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0203o
ool01@3o00000?l0003o00000?l00?l00080o`00503oool00`000000k>c/0>c/k00A0>c/k0030000
003IfMT0fMWI0140fMWI00<000000<K6aP36a/H0>`36a/H00`000000fMWI0=WIf@0A0=WIf@030000
003/k>`0k>c/00l0k>c/00<000000?ooo`3oool05P3oool00`3o0000003o0?l0000A0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`36a/H000000=WIf@050=WIf@030000
003/k>`0k>c/00P0k>c/00<000000?ooo`3oool01`3oool20?l00005003o00000?l0003o003o003o
00005@3oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36
a/H0>P36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/0100k>c/00<000000?ooo`3o
ool05P3oool00`000?l0o`000?l0000@0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000
003oool0oooo0080oooo0`3IfMT2000002X0k>c/00<000000?ooo`3oool0ZP3oool00`000000k>c/
0>c/k00E0>c/k0D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oooad0k>c/
00<000000?ooo`3oool0>@3oool00`3o00000?l0003o0003003o0940oooo00<000000>c/k03/k>`0
0P3/k>`50?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`000000fMWI
0=WIf@040=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02@3oool20?l000030000
o`00o`00o`000080o`004`3oool00`000000k>c/0>c/k00A0>c/k0030000003IfMT0fMWI0140fMWI
00<000000<K6aP36a/H0?@36a/H00`000000fMWI0=WIf@0A0=WIf@030000003/k>`0k>c/00h0k>c/
00<000000?ooo`3oool05@3oool20?l000030000o`3o0000o`000100oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`020?ooo`030<K6aP000000fMWI00D0fMWI00<000000>c/k03/k>`0
1`3/k>`00`000000oooo0?ooo`080?ooo`<0o`0000@0003o003o003o0000o`00503oool00`000000
k>c/0>c/k00A0>c/k0030000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H0?036a/H200000180
fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0E0?ooo`030?l000000?l0o`000080
o`003`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`80fMWI
00<000000>c/k03/k>`0:03/k>`200000:h0oooo0P00000E0>c/k0D0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`020?oooa/0k>c/0P00000l0?ooo`80o`000`00o`000`3o0000oooo
0?ooo`2@0?ooo`040000003/k>`0k>c/0>c/k0D0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`020?ooo`030000003IfMT0fMWI00@0fMWI00<000000>c/k03/k>`01`3/k>`00`000000
oooo0?ooo`0:0?ooo`030?l000000?l0o`000080o`00503oool00`000000k>c/0>c/k00@0>c/k003
0000003IfMT0fMWI0140fMWI00<000000<K6aP36a/H0?`36a/H00`000000fMWI0=WIf@0@0=WIf@03
0000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool04`3oool30?l00080003o0P3o000?0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`36a/H000000=WIf@050=WIf@03
0000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02@3oool20?l000030000o`3o0000o`0001D0
oooo00<000000>c/k03/k>`0403/k>`00`000000fMWI0=WIf@0@0=WIf@800000@@36a/H00`000000
fMWI0=WIf@0@0=WIf@030000003/k>`0k>c/00l0k>c/00<000000?ooo`3oool04`3oool20?l00003
003o00000?l0o`000080o`003P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo
0?ooo`020?ooo`80fMWI00<000000>c/k03/k>`09`3/k>`00`000000oooo0?ooo`2`0?ooo`800000
4`3/k>`50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3ooolJ0>c/k0030000
003oool0oooo03h0oooo0P3o000O0?ooo`80o`00M03oool00`000000k>c/0>c/k0050?ooo`030000
003oool0oooo01/0oooo100000060?ooo`8000001P3oool4000000H0oooo00<000000?ooo`3oool0
0P3oool00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0
2`3oool00`000?l0o`000?l0000D0?ooo`030000003/k>`0k>c/0140k>c/00<000000=WIf@3IfMT0
403IfMT00`000000a/K60<K6aP110<K6aP030000003IfMT0fMWI0100fMWI00<000000>c/k03/k>`0
3`3/k>`00`000000oooo0?ooo`0B0?ooo`80o`000`000?l00`00o`00o`000?ooo`0>0?ooo`030000
003oool0oooo01X0oooo100000060?ooo`8000001P3oool4000000H0oooo00<000000?ooo`3oool0
0P3oool00`36a/H000000=WIf@040=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0
2P3oool00`3o0000003o0?l0000E0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT0
403IfMT00`000000a/K60<K6aP110<K6aP030000003IfMT0fMWI0100fMWI00<000000>c/k03/k>`0
3`3/k>`00`000000oooo0?ooo`0C0?ooo`030?l00000o`00003o0080003o0P3o000>0?ooo`030000
003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo00<0fMWI0000003/k>`0:03/
k>`00`000000oooo0?ooo`2c0?ooo`030000003/k>`0k>c/0100k>c/1@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0080oooo6@3/k>`00`000000oooo0?ooo`1N0?ooo`H0o`00L`3o
ool00`000000k>c/0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000fMWI0=WIf@030=WIf@030000003/
k>`0k>c/00P0k>c/00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0E0?ooo`030000003/
k>`0k>c/0100k>c/00<000000=WIf@3IfMT0403IfMT00`000000a/K60<K6aP130<K6aP030000003I
fMT0fMWI00l0fMWI00<000000>c/k03/k>`03`3/k>`00`000000oooo0?ooo`0B0?ooo`80o`0000D0
0?l00000o`000?l00?l00?l0000?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000fMWI0=WIf@040=WIf@030000
003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0E0?ooo`030000
003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT0403IfMT00`000000a/K60<K6aP130<K6aP030000
003IfMT0fMWI0100fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0C0?ooo`050?l0
0000o`000?l00000o`00o`000P3o000>0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000
003oool0oooo0080oooo00<000000>c/k03/k>`09P3/k>`200000;L0oooo00<000000>c/k03/k>`0
3`3/k>`50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3ooolI0>c/k0030000
003oool0oooo05h0oooo0P3o0003003o00030?l0003oool0oooo0780oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000fMWI0=WIf@030=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0E0?ooo`030000003/k>`0k>c/0100k>c/00<000000=WIf@3IfMT0
3`3IfMT00`000000a/K60<K6aP0P0<K6aP@000008@36a/H00`000000fMWI0=WIf@0?0=WIf@030000
003/k>`0k>c/00h0k>c/00<000000?ooo`3oool04`3oool20?l000800?l000<0003o0?ooo`3oool0
3P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000fMWI0=WIf@040=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0E0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT0
403IfMT00`000000a/K60<K6aP0O0<K6aP@000008@36a/H00`000000fMWI0=WIf@0?0=WIf@800000
403/k>`00`000000oooo0?ooo`0C0?ooo`050?l00000o`000?l00000o`3o00003`3oool00`000000
oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooobP0k>c/00<000000?ooo`3oool0
^03oool00`000000k>c/0>c/k00>0>c/k0D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?oooaP0k>c/00<000000?ooo`3oool0GP3oool20?l000D00?l000<0o`000?ooo`3oool0
LP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo1P3IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00/0oooo
00<0003o0?ooo`3oool0503oool00`000000k>c/0>c/k00@0>c/k0030000003IfMT0fMWI00l0fMWI
00<000000<K6aP36a/H06P36a/H7000000@0/k>c1`00000K0<K6aP030000003IfMT0fMWI00h0fMWI
00<000000>c/k03/k>`03P3/k>`00`000000oooo0?ooo`0D0?ooo`<0o`0000<0003o0?ooo`3oool0
303oool3000001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool300000080oooo1P3IfMT00`000000k>c/
0>c/k0080>c/k0030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0503oool00`000000k>c/
0>c/k00?0>c/k0030000003IfMT0fMWI0100fMWI00<000000<K6aP36a/H06P36a/H6000000@0/k>c
1`00000K0<K6aP800000403IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo01@0oooo
0P3o00000`000?l0oooo0?ooo`0=0?ooo`800000803oool003D0oooo00<000000?ooo`3oool00P3o
oolV0>c/k0800000_03oool2000000h0k>c/1@3oool00`000000oooo0?ooo`0^0?ooo`8000000`3o
oolF0>c/k0800000H@3oool20?l000D00?l000<0o`000?ooo`3oool0MP3oool2000001`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001P3oool00`000000oooo0?oo
o`020?ooo`H0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo01D0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@0?0=WIf@0300000036
a/H0a/K601P0a/K60`00000B0;>c/`8000006P36a/H00`000000fMWI0=WIf@0>0=WIf@030000003/
k>`0k>c/00h0k>c/00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0>0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001P3o
ool00`000000oooo0?ooo`020?ooo`H0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo01D0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WI
f@0?0=WIf@0300000036a/H0a/K601P0a/K60`00000A0;>c/`<000006P36a/H00`000000fMWI0=WI
f@0>0=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0>0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo9@3/k>`0
0`000000oooo0?ooo`2n0?ooo`030000003/k>`0k>c/00/0k>c/1@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0080oooo5@3/k>`00`000000oooo0?ooo`1R0?ooo`030?l00000o`00
0?l000<00?l0NP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool50=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0D0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT03`3IfMT0
0`000000a/K60<K6aP0G0<K6aP8000005`2c/k<3000001P0a/K600<000000=WIf@3IfMT03@3IfMT0
0`000000k>c/0>c/k00?0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool6
0=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0D
0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT03P3IfMT2000001P0a/K60`00000G
0;>c/`8000006036a/H00`000000fMWI0=WIf@0>0=WIf@030000003/k>`0k>c/00l0k>c/00<00000
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo01h0oooo000e0?oo
o`030000003oool0oooo0080oooo9@3/k>`00`000000oooo0?ooo`2o0?ooo`030000003/k>`0k>c/
00X0k>c/1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo503/k>`00`00
0000oooo0?ooo`1S0?ooo`80o`000`00o`000`3o0000oooo0?ooo`1h0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`D0fMWI00<000000>c/
k03/k>`01`3/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01@0oooo00<000000>c/
k03/k>`03`3/k>`00`000000fMWI0=WIf@0>0=WIf@0300000036a/H0a/K601D0a/K60`00000L0;>c
/`<000005P36a/H00`000000fMWI0=WIf@0=0=WIf@800000403/k>`00`000000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo1P3IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo
00/0oooo00<0003o0?ooo`3oool04`3oool200000100k>c/00<000000=WIf@3IfMT03P3IfMT00`00
0000a/K60<K6aP0E0<K6aP<00000702c/k<3000001H0a/K60P00000?0=WIf@030000003/k>`0k>c/
00h0k>c/00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo
01h0oooo000e0?ooo`030000003oool0oooo0080oooo8`3/k>`200000<<0oooo00<000000>c/k03/
k>`02@3/k>`50?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3ooolC0>c/k003
0000003oool0oooo06H0oooo0P3o001l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`D0fMWI00<000000>c/k03/k>`01`3/k>`00`000000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo01D0oooo00<000000>c/k03/k>`03P3/k>`00`000000
fMWI0=WIf@0>0=WIf@0300000036a/H0a/K601@0a/K60P00000R0;>c/`8000005@36a/H00`000000
fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`H0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo01@0oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@0>0=WIf@03
00000036a/H0a/K601D0a/K600<000000;>c/`2c/k<0802c/k<2000001H0a/K600<000000=WIf@3I
fMT03@3IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3o
ool03@3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool2000000<0oooo8P3/k>`00`000000oooo
0?ooo`340?ooo`8000002@3/k>`40?ooo`800000<03oool00`000000oooo0?ooo`020?oooa<0k>c/
00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0K0?ooo`@000003P3oool4000000H0oooo
00<000000?ooo`3oool00P3oool40=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT0
3@3IfMT00`000000a/K60<K6aP0C0<K6aP8000009P2c/k<2000001@0a/K600<000000=WIf@3IfMT0
3@3IfMT00`000000k>c/0>c/k00>0>c/k0030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0
3@3oool00`000000oooo0?ooo`0J0?ooo`@000003P3oool4000000H0oooo00<000000?ooo`3oool0
0P3oool50=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0C0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT03P3IfMT00`000000a/K6
0<K6aP0C0<K6aP8000009@2c/k<2000001D0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/
0>c/k00>0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0303oool00`000000oooo
0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`020?ooob00k>c/0P0000390?ooo`030000003/
k>`0k>c/00H0k>c/1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo4P3/
k>`00`000000oooo0?ooo`1d0?ooo`<00?oo5@3oool20?l005L0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`020?ooo`@0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo01@0oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WI
f@0>0=WIf@0300000036a/H0a/K60180a/K600<000000;>c/`2c/k<09`2c/k<00`000000a/K60<K6
aP0B0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/k03/k>`03P3/k>`00`000000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`020?ooo`D0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo01<0oooo00<000000>c/k03/k>`03`3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036
a/H0a/K601<0a/K600<000000;>c/`2c/k<09`2c/k<00`000000a/K60<K6aP0B0<K6aP030000003I
fMT0fMWI00d0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo00`0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3ooolP
0>c/k0030000003oool0oooo0<T0oooo00<000000>c/k03/k>`01@3/k>`50?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool00P3oool@0>c/k0800000G@3oool3003oo`T0oooo0`00ool9
0?ooo`L00?oo4@3oool20?l000<00?l000<0o`000?ooo`3oool0D`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0080oooo103IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0
oooo00/0oooo00<0003o0?ooo`3oool04`3oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0
fMWI00h0fMWI00<000000<K6aP36a/H04P36a/H00`000000/k>c0;>c/`0Y0;>c/`8000004`36a/H0
0`000000fMWI0=WIf@0=0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool4
0=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0B
0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0B
0<K6aP800000:`2c/k<2000001<0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00>
0>c/k0030000003oool0oooo01D0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0N
0?ooo`00=@3oool00`000000oooo0?ooo`020?oooah0k>c/0P00003=0?ooo`030000003/k>`0k>c/
00@0k>c/1@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo3`3/k>`00`00
0000oooo0?ooo`1K0?ooo`<00?oo0P3o0002003oo`D0oooo1`00ool60?ooo`@00?oo0P3o0003003o
o`d0oooo0`00ool00`3o00000?l0003o0003003o05D0oooo00<000000?ooo`3oool0=`3oool20000
00<0oooo103IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00X0oooo00<0003o0?oo
o`3oool0503oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00d0fMWI00<000000<K6
aP36a/H04036a/H3000002h0/k>c0P00000B0<K6aP030000003IfMT0fMWI00d0fMWI00<000000>c/
k03/k>`03@3/k>`00`000000oooo0?ooo`0D0?ooo`030000o`3o0000o`0000/0oooo0P00000h0?oo
o`8000000`3oool40=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0C0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT03@3IfMT00`00
0000a/K60<K6aP0@0<K6aP800000;`2c/k<00`000000a/K60<K6aP0A0<K6aP030000003IfMT0fMWI
00`0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0E0?ooo`030000o`3o0000o`00
00X0oooo0P00000P0?ooo`00=@3oool00`000000oooo0?ooo`020?oooad0k>c/00<000000?ooo`3o
ool0cP3oool00`000000k>c/0>c/k0030>c/k0D0oooo00<000000?ooo`3oool0903oool4000000H0
oooo00<000000?ooo`3oool00P3oool>0>c/k0030000003oool0oooo05/0oooo0P00ool20?l000<0
0?l000<0o`00003oo`3oool00P3oool4003oo`80o`000`00ool50?ooo`800?oo00@0o`00003o0000
o`000?l00P3o00000`00ool0oooo0?ooo`090?ooo`@00?oo0P3o0005003o00030?l0003oool0oooo
0580oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`<0fMWI00<000000>c/
k03/k>`01`3/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01<0oooo00<000000>c/
k03/k>`03P3/k>`00`000000fMWI0=WIf@0=0=WIf@0300000036a/H0a/K60100a/K600<000000;>c
/`2c/k<0<02c/k<200000180a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00=0>c/
k0030000003oool0oooo01<0oooo0P3o00000`000?l00?l00?l0000;0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool40=WIf@030000003/k>`0k>c/00L0k>c/00<000000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0B0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WI
f@3IfMT03@3IfMT00`000000a/K60<K6aP0?0<K6aP800000<P2c/k<00`000000a/K60<K6aP0A0<K6
aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0C0?oo
o`030?l000000?l00?l00080o`002P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000
oooo0?ooo`020?oooa`0k>c/00<000000?ooo`3oool0d03oool00`000000k>c/0>c/k0020>c/k0D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool>0>c/k0030000003oool0oooo05/0oooo0P00ool00`3o0000
0?l0003o0003003o0004003oo`3oool0oooo0?ooo`800?oo00@0o`00003o0000o`000?l00P3o0000
0`00ool0oooo0?ooo`020?ooo`<00?oo0P00o`0010000?l00?l0003o003o0002003oo`T0oooo1000
ool30?l000D00?l000<0o`000?ooo`3oool0DP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0080oooo0`3IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00/0oooo00<0
003o0?ooo`3oool04P3oool00`000000k>c/0>c/k00?0>c/k0030000003IfMT0fMWI00`0fMWI00<0
00000<K6aP36a/H03`36a/H2000003D0/k>c0P00000A0<K6aP030000003IfMT0fMWI00`0fMWI00<0
00000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0A0?ooo`80o`0000D00?l00000o`00o`000?l0
0?l0000:0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool40=WIf@030000
003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0B0?ooo`030000
003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0?0<K6aP030000
002c/k<0/k>c03<0/k>c0P00000B0<K6aP030000003IfMT0fMWI00`0fMWI00<000000>c/k03/k>`0
3@3/k>`00`000000oooo0?ooo`0A0?ooo`050?l00000o`000?l00000o`00o`000P3o00090?ooo`03
0000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080oooo6P3/k>`200000=@0oooo
0P0000020>c/k0D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool=0>c/k0030000003oool0oooo05/0oooo
0P00ool20?l00003003o00000?l0003o00D0003o0`00ool2003o00040000o`00o`000?l00?l00080
0?oo0P3oool;0000o`03003oo`3oool0oooo00L0oooo0P00ool20?l000<00?l000D0o`00003o0000
o`000?l00?l0001E0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool30=WI
f@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0C0?oo
o`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT03@3IfMT00`000000a/K60<K6aP0>0<K6
aP030000002c/k<0/k>c03L0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0<0=WI
f@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04@3oool20?l00005003o00000?l00?l0
003o003o00000`3oool30?l000@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`02
0?ooo`@0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo01<0oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0
a/K600l0a/K600<000000;>c/`2c/k<0=P2c/k<200000100a/K600<000000=WIf@3IfMT0303IfMT0
0`000000k>c/0>c/k00=0>c/k0030000003oool0oooo0140oooo00D0o`00003o0000o`00003o003o
00020?l000<0oooo0`3o00030?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0
oooo0080oooo6@3/k>`00`000000oooo0?ooo`3F0?ooo`030000003/k>`0oooo00@0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`000002
0?ooo`/0k>c/0P00001N0?ooo`800?oo1@000?l2003o00030?l00000ool0oooo00d0003o00@0oooo
003oo`00ool0o`000P00o`000`000?l00?l0003o00020?l000X0003o0P00ool00`3o00000?l00000
o`03003o00@0o`00103oool3003ood`0oooo0`00000i0?ooo`030000003oool0oooo0080oooo0P3I
fMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00T0oooo0P3o00000`000?l0oooo0?oo
o`0B0?ooo`030000003/k>`0k>c/00l0k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6
aP0>0<K6aP030000002c/k<0/k>c03T0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WI
f@0;0=WIf@030000003/k>`0k>c/00h0k>c/00<000000?ooo`3oool0403oool30?l000040000o`00
o`00o`000?l00080oooo0P3o0002003o00050?l0003oool0oooo0?ooo`000000>03oool00`000000
oooo0?ooo`020?ooo`<0fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`090?ooo`80
o`0000<0003o0?ooo`3oool04P3oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00`0
fMWI00<000000<K6aP36a/H03`36a/H00`000000/k>c0;>c/`0i0;>c/`0300000036a/H0a/K600d0
a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00=0>c/k0030000003oool0oooo0140
oooo0P3o00000`00o`00003o0?l000020?l00080oooo0P3o0002003o00040?l0003oool0oooo0000
0200oooo000e0?ooo`030000003oool0oooo0080oooo603/k>`00`000000oooo0?ooo`3H0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool:0>c/k0030000003oool0oooo05d0
oooo0`000?l01000ool0o`000?l000000?l2003o00040?l00000ool00?oo0?ooo`800?oo00@0o`00
003o0000o`00003o0P00o`020?l00003003oo`3oool0oooo0080oooo0P00ool0103o00000?l0003o
0000o`020?l00003003oo`3oool0oooo00L0oooo00<00?oo0000o`000?l01@000?l00`00o`00o`00
0?l000040?ooo`L00?ooC03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo
0P3IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00P0oooo00D0o`00003o0000o`00
003o0?l0000C0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT0303IfMT00`000000
a/K60<K6aP0?0<K6aP030000002c/k<0/k>c03X0/k>c00<000000<K6aP36a/H03P36a/H00`000000
fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04@3oool30?l00003
0000o`00o`00o`0000<0o`001000o`00103o0000oooo0?ooo`00000h0?ooo`030000003oool0oooo
0080oooo0`3IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00P0oooo00D0o`00003o
0000o`00003o0?l0000C0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT0303IfMT0
0`000000a/K60<K6aP0>0<K6aP030000002c/k<0/k>c03X0/k>c00<000000<K6aP36a/H03P36a/H0
0`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3oool04@3oool2
0?l00003003o00000?l0o`0000@0o`001000o`000`3o0000oooo0000000P0?ooo`00=@3oool00`00
0000oooo0?ooo`020?oooaL0k>c/00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo2P3/k>`00`000000oooo0?ooo`1J0?ooo`<0003o0P3oool2003o
o`H0o`0000@00?oo0?ooo`3oool0oooo0P00ool0103o00000?l0003o0000o`020?l00003003oo`3o
ool0oooo00<0oooo0P00ool60?l00003003oo`3oool0oooo00L0oooo0P00ool20?l00004003o0000
0?l00?l0003o00<0003o0`3oool4003oo`80o`000`00oom;0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool00P3oool20=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0
1`3oool01@3o00000?l0003o00000?l00?l00080o`004@3oool00`000000k>c/0>c/k00>0>c/k003
0000003IfMT0fMWI00`0fMWI00<000000<K6aP36a/H03P36a/H2000003h0/k>c00<000000<K6aP36
a/H03@36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?ooo`3o
ool04@3oool20?l000<0003o00@00?l00?l0003o0000o`001000o`00103o0000oooo0?ooo`00000h
0?ooo`030000003oool0oooo0080oooo0`3IfMT00`000000k>c/0>c/k0060>c/k0030000003oool0
oooo00P0oooo00D0o`00003o0000o`00003o003o00020?l00140oooo00<000000>c/k03/k>`03P3/
k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600h0a/K600<000000;>c/`2c/k<0?02c
/k<2000000l0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00=0>c/k0030000003o
ool0oooo0140oooo00<0o`00003o00000?l00P000?l40?l000@00?l000<0o`000?ooo`000000803o
ool003D0oooo0P0000030?oooaH0k>c/00<000000?ooo`3oool0g`3oool2000002D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo2@3/k>`0
0`000000oooo0?ooo`1:0?ooo`<00?oo303oool20000o`D0oooo1000ool20?l000<00?oo0`3oool2
003oo`H0o`0000<00?oo0?ooo`3oool0103oool3003oo`80o`000P00ool;0?ooo`800?oo0P3o0003
003o00030?l00000ool0oooo00<0003o0P00ool0103o00000?l0003o0000o`020?l00003003oo`3o
ool0oooo04T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`80fMWI00<0
00000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`070?ooo`030?l00000o`00003o0080003o0P3o
000A0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT0303IfMT00`000000a/K60<K6
aP0=0<K6aP030000002c/k<0/k>c03l0/k>c00<000000<K6aP36a/H03@36a/H00`000000fMWI0=WI
f@0;0=WIf@8000003P3/k>`00`000000oooo0?ooo`0@0?ooo`80o`0000@00?l00000o`00o`000?l0
103o0002003o0080o`000P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo
0P3IfMT00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00P0oooo00<0o`00003o00000?l0
0P000?l20?l00140oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@0;0=WIf@030000
0036a/H0a/K600h0a/K600<000000;>c/`2c/k<0?`2c/k<00`000000a/K60<K6aP0=0<K6aP030000
003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`03@3/k>`00`000000oooo0?ooo`0@0?ooo`050?l0
0000o`000?l00000o`00o`001@3o0002003o0080o`0000<0oooo0000003oool07`3oool003D0oooo
00<000000?ooo`3oool00P3ooolE0>c/k0030000003oool0oooo0>40oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool80>c/k0030000003oool0oooo04T0oooo1`00ool70?ooo`<0003o203oool7003oo`D0oooo
0`00ool20?l000800?oo2@3oool3003oo`d0oooo0P00ool60?l00005003oo`3oool0oooo0?ooo`00
ool00`000?l4003o00030?l00000ool00?oo04X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`020?ooo`80fMWI00<000000>c/k03/k>`01P3/k>`00`000000oooo0?ooo`080?ooo`80
o`0000<00?l00000o`3o00000P3o000A0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3I
fMT02`3IfMT00`000000a/K60<K6aP0=0<K6aP030000002c/k<0/k>c01/0/k>c2@00000M0;>c/`03
00000036a/H0a/K600d0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00<0>c/k003
0000003oool0oooo0140oooo0P3o00000`00o`00003o0?l000020?ooo`D0o`000`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0P3IfMT00`000000k>c/0>c/k0070>c/k003
0000003oool0oooo00P0oooo0P3o00000`00o`00003o0?l000020?l00140oooo00<000000>c/k03/
k>`03@3/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036a/H0a/K600d0a/K600<000000;>c/`2c
/k<06`2c/k<9000001`0/k>c00<000000<K6aP36a/H03P36a/H00`000000fMWI0=WIf@0;0=WIf@03
0000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool04@3oool01@3o00000?l0003o00000?l0o`00
0080oooo1@3o00020?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0080
oooo503/k>`00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo02@0oooo100000060?ooo`03
0000003oool0oooo0080oooo1`3/k>`00`000000oooo0?ooo`190?ooo`@00?oo0P3o0003003oo`<0
oooo0`000?l=0?ooo`<00?oo2@3oool3003ooa`0oooo0`00ool20?l000800?oo103oool2003oo`03
0?l00000o`00003o0080003o00@00?l00?l0003o00000?ooBP3oool00`000000oooo0?ooo`0g0?oo
o`8000000`3oool00`3IfMT000000>c/k0080>c/k0030000003oool0oooo00T0oooo00<0o`000000
o`3o00000P3o000A0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT02`3IfMT20000
00l0a/K600<000000;>c/`2c/k<05`2c/k<4000000T0WinO1@00000I0;>c/`0300000036a/H0a/K6
00`0a/K600<000000=WIf@3IfMT0303IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo
0140oooo0P3o00000`000?l0o`000?l000020?ooo`<0o`000`3oool2000003P0oooo0P0000030?oo
o`80fMWI00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`090?ooo`030?l000000?l0o`00
0080o`004@3oool00`000000k>c/0>c/k00>0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6
aP36a/H03@36a/H00`000000/k>c0;>c/`0H0;>c/`@000002@2OWil4000001T0/k>c00<000000<K6
aP36a/H03@36a/H00`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/00d0k>c/00<000000?oo
o`3oool04@3oool20?l000030000o`3o0000oooo0080oooo0`3o00020?ooo`800000803oool003D0
oooo00<000000?ooo`3oool00P3ooolC0>c/k0030000003oool0oooo0><0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`020?ooo`H0k>c/00<000000?ooo`3oool0BP3oool2003oo`04
0?l00000o`000?l0003o0080o`0000@00?oo0000o`000?l0003o?@3oool3003oo`H0oooo0P00ool0
0`3o00000?l00000o`040000o`030?l00000ool0oooo04T0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`020?ooo`030=WIf@000000k>c/00P0k>c/00<000000?ooo`3oool02P3oool0
0`000?l0o`000?l0000B0?ooo`030000003/k>`0k>c/00h0k>c/00<000000=WIf@3IfMT02`3IfMT0
0`000000a/K60<K6aP0=0<K6aP030000002c/k<0/k>c01D0/k>c0`00000B09nOW`800000602c/k<0
0`000000a/K60<K6aP0<0<K6aP800000303IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0
oooo0180oooo00<0o`00003o00000?l00P3o00080?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool00P3oool20=WIf@030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02P3oool0
0`000?l0o`000?l0000B0?ooo`030000003/k>`0k>c/00d0k>c/00<000000=WIf@3IfMT0303IfMT0
0`000000a/K60<K6aP0<0<K6aP030000002c/k<0/k>c01H0/k>c0`00000A09nOW`<000005`2c/k<0
0`000000a/K60<K6aP0=0<K6aP030000003IfMT0fMWI00/0fMWI00<000000>c/k03/k>`0303/k>`0
0`000000oooo0?ooo`0A0?ooo`80o`0000<00?l00000o`3o0000203oool00`000000oooo0?ooo`0N
0?ooo`00=@3oool00`000000oooo0?ooo`020?oooa80k>c/00<000000?ooo`3oool0i03oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo1@3/k>`00`000000oooo0?ooo`1:0?oo
o`<00?oo0P00o`000`000?l00?l00000o`020000o`03003oo`3oool0oooo04L0oooo0P00ool0103o
00000?l00000o`00o`020?l000<0003oB@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0080oooo00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo0140oooo00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@0;0=WIf@0300000036a/H0
a/K600`0a/K60P00000F0;>c/`8000005`2OWil3000001H0/k>c00<000000<K6aP36a/H03036a/H0
0`000000fMWI0=WIf@0;0=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool04@3oool0
1@3o00000?l0003o00000?l00?l00080o`001`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0080oooo00<0fMWI0000003/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo0140oooo00<000000>c/k03/k>`03@3/k>`00`000000fMWI0=WIf@0<0=WIf@0300000036
a/H0a/K600`0a/K600<000000;>c/`2c/k<0502c/k<3000001L0WinO0P00000F0;>c/`8000003@36
a/H00`000000fMWI0=WIf@0<0=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool0403o
ool20?l00005003o00000?l0003o003o003o00001`3oool00`000000oooo0?ooo`0N0?ooo`00=@3o
ool00`000000oooo0?ooo`020?oooa40k>c/00<000000?ooo`3oool0i@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0080oooo1@3/k>`00`000000oooo0?ooo`1:0?ooo`800?oo00<0
o`00003o00000?l00P000?l01000o`00o`000?l00000oom90?ooo`800?oo1P3o00000`00ool0oooo
0?ooo`030000o`X0oooo0`00ooli0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
0P3oool00`000000k>c/0>c/k0070>c/k0030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0
4@3oool00`000000k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H0
3036a/H00`000000/k>c0;>c/`0C0;>c/`<00000702OWil2000001D0/k>c00<000000<K6aP36a/H0
3036a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool0
403oool00`3o00000?l00000o`020000o`80o`001`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0080oooo00<0fMWI0000003/k>`0203/k>`00`000000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo0140oooo00<000000>c/k03/k>`03@3/k>`00`000000fMWI0=WIf@0;0=WIf@030000
0036a/H0a/K600`0a/K600<000000;>c/`2c/k<04`2c/k<2000001`0WinO0`00000E0;>c/`030000
0036a/H0a/K600/0a/K600<000000=WIf@3IfMT02`3IfMT00`000000k>c/0>c/k00<0>c/k0030000
003oool0oooo00l0oooo0P3o00030000o`03003o003o0000oooo00H0oooo00<000000?ooo`3oool0
7P3oool003D0oooo00<000000?ooo`3oool00P3oool@0>c/k0030000003oool0oooo0>H0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`@0k>c/00<000000?ooo`3oool0B`3o
ool2003oo`040?l000000?l0003o0000o`800?l00P3o00000`00ool0oooo0?ooo`180?ooo`<00?oo
0P3o0002003oo`H0oooo0P000?l60?ooo`<00?oo0P3o0002003oocL0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`020?ooo`030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0A0?ooo`030000003/k>`0k>c/00d0k>c/00<000000=WIf@3IfMT0
303IfMT00`000000a/K60<K6aP0;0<K6aP030000002c/k<0/k>c0180/k>c0P00000Q09nOW`<00000
4`2c/k<00`000000a/K60<K6aP0;0<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`0
303/k>`00`000000oooo0?ooo`0@0?ooo`80o`0000<00?l00000o`000?l00P3o00070?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`000000k>c/0>c/k0070>c/k0030000
003oool0oooo00/0oooo00<0003o0?ooo`3oool04@3oool00`000000k>c/0>c/k00=0>c/k0030000
003IfMT0fMWI00/0fMWI00<000000<K6aP36a/H03036a/H00`000000/k>c0;>c/`0B0;>c/`800000
8@2OWil2000001<0/k>c00<000000<K6aP36a/H03036a/H00`000000fMWI0=WIf@0:0=WIf@030000
003/k>`0k>c/00`0k>c/00<000000?ooo`3oool03`3oool30?l000040000o`00o`00003o0?l000L0
oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool00P3oool>0>c/k0800000
j@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo0P3/k>`2000004l0oooo
0P000?l0103o00000?l0003o0000o`020?l00003003oo`3oool0oooo04/0oooo0`00ool:0?ooo`<0
003o0P3oool2003oo`H0o`0000<00?oo0?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0080oooo00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo0140oooo00<000000>c/k03/k>`03@3/k>`00`000000fMWI0=WIf@0;0=WIf@03
00000036a/H0a/K600/0a/K60P00000A0;>c/`<000009P2OWil200000180/k>c00<000000<K6aP36
a/H02`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3o
ool0403oool30?l000030000o`3o0000oooo00L0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`020?ooo`030000003/k>`0k>c/00L0k>c/00<000000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0A0?ooo`030000003/k>`0k>c/00d0k>c/00<000000=WIf@3IfMT02P3IfMT00`000000
a/K60<K6aP0<0<K6aP030000002c/k<0/k>c0100/k>c0`00000U09nOW`<000004@2c/k<2000000d0
a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo00l0
oooo103o00000`000?l0oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000
003oool0oooo0080oooo3@3/k>`00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo02h0oooo
0P0000030?ooo`030>c/k0000000oooo04@0oooo0`00ool70?ooo`80003o0P00ool60?l00003003o
o`3oool0oooo05/0oooo0`000?l00`00ool0o`00003o0002003o0080o`0000<00?oo0?ooo`3oool0
<`3oool2000003T0oooo00<000000?ooo`3oool00P3oool00`000000k>c/0>c/k0060>c/k0030000
003oool0oooo00/0oooo00<0003o0?ooo`3oool04@3oool00`000000k>c/0>c/k00=0>c/k0030000
003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H02`36a/H00`000000/k>c0;>c/`0@0;>c/`030000
002OWil0WinO02T0WinO00<000000;>c/`2c/k<0402c/k<00`000000a/K60<K6aP0;0<K6aP030000
003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0303/k>`00`000000oooo0?ooo`0A0?ooo`80o`00
00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo
00<000000>c/k03/k>`01`3/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0100oooo
00<000000>c/k03/k>`03P3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600/0a/K6
00<000000;>c/`2c/k<0402c/k<00`000000WinO09nOW`0Y09nOW`030000002c/k<0/k>c0100/k>c
00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/00`0k>c/
00<000000?ooo`3oool0403oool30?l000030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0
7P3oool003D0oooo00<000000?ooo`3oool00P3oool=0>c/k0030000003oool0oooo04d0oooo0P3o
o`0F0?ooo`80ool0PP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<0
k>c/0000003oool0@P3oool3003oo`80o`000P00ool30?ooo`80003o0`3oool3003oo`80o`000P00
oomO0?ooo`800?oo0P000?l01000o`00003o003o0000o`020?l00003003oo`3oool0oooo03<0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`T0k>c/00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0B0?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT0
2`3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c0140/k>c00<0000009nOW`2OWil0
:P2OWil00`000000/k>c0;>c/`0?0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT0
2P3IfMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo0180oooo00<0003o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo2P3/k>`00`000000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo0140oooo00<000000>c/k03/k>`03@3/k>`00`000000fMWI
0=WIf@0:0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c/k<0402c/k<00`000000WinO
09nOW`0[09nOW`030000002c/k<0/k>c00l0/k>c00<000000<K6aP36a/H02`36a/H00`000000fMWI
0=WIf@0:0=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`060?ooo`030000003oool0oooo01h0oooo000e0?ooo`8000000`3oool<0>c/k0030000003o
ool0oooo04d0oooo103oo`0D0?ooo`@0ool06`3oool20?oo06<0oooo0P00000`0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0@@3oool2003oo`H0o`0000<00?oo0000o`000?l01`3o
ool3003oof40oooo0P00ool00`3o00000?l00000o`020000o`03003o003o0000o`0000@00?oo<P3o
ool00`000000oooo0?ooo`0g0?ooo`8000000`3oool90>c/k0030000003oool0oooo00X0oooo00<0
003o0?ooo`3oool04@3oool00`000000k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00X0fMWI00<0
00000<K6aP36a/H02`36a/H00`000000/k>c0;>c/`0>0;>c/`<00000;P2OWil200000100/k>c00<0
00000<K6aP36a/H02`36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/00/0k>c/00<0
00000?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`800000>03oool2000000<0oooo2P3/
k>`00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0140oooo00<000000>c/k03/k>`03@3/
k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c/k<03P2c
/k<2000002l0WinO0P00000@0;>c/`0300000036a/H0a/K600X0a/K600<000000=WIf@3IfMT02P3I
fMT00`000000k>c/0>c/k00<0>c/k0030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0103o
ool200000200oooo000e0?ooo`030000003oool0oooo0080oooo2`3/k>`00`000000oooo0?ooo`1=
0?ooo`H0ool04P3oool60?oo01T0oooo103oo`1S0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0AP3oool2003oo`050?l00000o`000?l0003o003o00000P000?m]0?ooo`<00?oo0P00
o`030000o`030?l00000ool00?oo0080o`000`00ool`0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool00P3oool80>c/k0030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0403o
ool00`000000k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H02`36
a/H00`000000/k>c0;>c/`0>0;>c/`030000002OWil0WinO0340WinO0P00000?0;>c/`0300000036
a/H0a/K600X0a/K600<000000=WIf@3IfMT02P3IfMT00`000000k>c/0>c/k00;0>c/k0030000003o
ool0oooo01<0oooo00<0003o0?l0003o00001P3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0080oooo2@3/k>`00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0100oooo00<0
00000>c/k03/k>`03@3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600/0a/K600<0
00000;>c/`2c/k<03@2c/k<2000003<0WinO00<000000;>c/`2c/k<03P2c/k<00`000000a/K60<K6
aP0:0<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?oo
o`0B0?ooo`030?l000000?l0o`0000H0oooo00<000000?ooo`3oool07P3oool003D0oooo00<00000
0?ooo`3oool00P3oool90>c/k0800000D03oool60?oo0180oooo1P3oo`0H0?ooo`H0ool0HP3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo0`00ool50?ooo`800?oo00<0o`00
003o0000o`000`000?l20?l00003003oo`3oool0oooo06/0oooo0P00ool01P3o00000?l0003o0000
o`00o`000000o`H0o`000P00ool_0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
0P3oool80>c/k0030000003oool0oooo00X0oooo00<0003o0?ooo`3oool04@3oool00`000000k>c/
0>c/k00=0>c/k0030000003IfMT0fMWI00X0fMWI00<000000<K6aP36a/H02P36a/H00`000000/k>c
0;>c/`0>0;>c/`030000002OWil0WinO03@0WinO00<000000;>c/`2c/k<03@2c/k<00`000000a/K6
0<K6aP0:0<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo
0?ooo`0A0?ooo`030?l000000?l0o`000080o`001@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0080oooo2@3/k>`00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0140oooo
00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600/0a/K6
00<000000;>c/`2c/k<03@2c/k<00`000000WinO09nOW`0d09nOW`030000002c/k<0/k>c00h0/k>c
00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/00/0k>c/
00<000000?ooo`3oool0403oool20?l000030000o`3o0000o`0000D0oooo00<000000?ooo`3oool0
7P3oool003D0oooo00<000000?ooo`3oool00P3oool80>c/k0030000003oool0oooo0540oooo103o
o`0D0?ooo`@0ool06@3oool60?oo0680oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0k0?ooo`<00?oo0P3o0002003oo`<0oooo0P00ool00`3o00000?l00000o`020000o`04003o003o
0000o`00003oofd0oooo1000ool20?l000800?oo00<0003o0?l00000o`000P00o`000`3o00000?oo
003oo`0_0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool80>c/k0030000
003oool0oooo00X0oooo00<0003o0?ooo`3oool04@3oool00`000000k>c/0>c/k00=0>c/k0030000
003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H02P36a/H00`000000/k>c0;>c/`0=0;>c/`800000
>02OWil00`000000/k>c0;>c/`0<0;>c/`0300000036a/H0a/K600/0a/K600<000000=WIf@3IfMT0
2@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo0100oooo0P3o00000`00o`00003o
0?l000020?l000@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`T0k>c/
00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0A0?ooo`030000003/k>`0k>c/00`0k>c/
00<000000=WIf@3IfMT02@3IfMT00`000000a/K60<K6aP0;0<K6aP030000002c/k<0/k>c00d0/k>c
00<0000009nOW`2OWil0=P2OWil2000000h0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI
0=WIf@0:0=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool03`3oool30?l00005003o
00000?l0o`000?l0000000000`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo
0?ooo`020?ooo`P0k>c/00<000000?ooo`3oool0DP3oool20?oo01H0oooo0P3oo`0<0?ooo`80O`1o
3@3oool40?oo06<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0j0?ooo`800?oo
1P3o00001000ool0oooo0?ooo`00ool30000o`05003o00000?l00?l0003o003o00000P00oom^0?oo
o`H00?oo0P3o00020000o`<00?l000<0o`00003oo`00ool0;P3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0080oooo203/k>`00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
0100oooo00<000000>c/k03/k>`03@3/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K6
00X0a/K600<000000;>c/`2c/k<0302c/k<00`000000WinO09nOW`0i09nOW`030000002c/k<0/k>c
00`0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@0:0=WIf@030000003/k>`0k>c/
00/0k>c/00<000000?ooo`3oool03`3oool00`3o00000?l00000o`020000o`80o`0000D000000?oo
o`3oool0oooo0000000h0?ooo`030000003oool0oooo0080oooo203/k>`00`000000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo0100oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@0:
0=WIf@0300000036a/H0a/K600/0a/K600<000000;>c/`2c/k<0302c/k<00`000000WinO09nOW`0i
09nOW`030000002c/k<0/k>c00`0/k>c00<000000<K6aP36a/H02P36a/H00`000000fMWI0=WIf@09
0=WIf@030000003/k>`0k>c/00`0k>c/00<000000?ooo`3oool03P3oool20?l00005003o00000?l0
003o0000o`3o00000P0000020?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0
oooo0080oooo1`3/k>`00`000000oooo0?ooo`1g0?ooo`H0O`1o1P3oool207l0O`@0oooo0P3oo`1T
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0>P3oool2003oo`80o`000`00o`00
0`3o00000?oo0?ooo`020000o`800?oo00@0o`00003o0000o`000?l00P3o00000`00ool0oooo0?oo
o`1_0?ooo`@00?oo0P3o00030000o`800?l000<0o`00003oo`00ool00P3oool3003oobT0oooo00<0
00000?ooo`3oool0;03oool7000000@0oooo00<000000?ooo`3oool00P3oool80>c/k0030000003o
ool0oooo00P0oooo0P3o00000`000?l0oooo0?ooo`0@0?ooo`030000003/k>`0k>c/00d0k>c/00<0
00000=WIf@3IfMT02@3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00d0/k>c00<0
000009nOW`2OWil0>P2OWil00`000000/k>c0;>c/`0<0;>c/`0300000036a/H0a/K600X0a/K600<0
00000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo00l0oooo00<0
o`00003o0000o`000P000?l20?l0008000000P3oool00`000000oooo0?ooo`0[0?ooo`L00000103o
ool00`000000oooo0?ooo`020?ooo`P0k>c/00<000000?ooo`3oool02@3oool20?l000030000o`3o
ool0oooo0100oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036
a/H0a/K600T0a/K60P00000>0;>c/`030000002OWil0WinO03X0WinO00<000000;>c/`2c/k<03@2c
/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00X0fMWI00<000000>c/k03/k>`02`3/
k>`00`000000oooo0?ooo`0>0?ooo`80o`000P00o`0010000?l00?l00?l0003o0002000000030?oo
o`000000oooo01l0oooo000[0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`H0k>c/00<0
00000?ooo`3oool0M`3oool307l0O`80ool00`1o07l30?ooo`H0O`1oJ03oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo03T0oooo0P00ool20?l00004003o00000?l00?l0003o00<0003o
0P3oool4003oo`80o`000`00oomd0?ooo`800?oo00@0o`00003o00000?l00?l00P000?l:003oobL0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
o`001P3/k>`00`000000oooo0?ooo`080?ooo`030?l00000o`00003o0080o`00403oool00`000000
k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H02P36a/H00`000000
/k>c0;>c/`0<0;>c/`8000006P2OWil9000001/0WinO00<000000;>c/`2c/k<0302c/k<00`000000
a/K60<K6aP090<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`02`3/k>`00`000000
oooo0?ooo`0>0?ooo`040000003o0000o`00003o00<0003o00H0o`0000000000000000000?ooo`00
000`0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0`3o00060>c/k0030000
003oool0oooo00P0oooo00<0o`00003o00000?l00P3o000@0?ooo`030000003/k>`0k>c/00`0k>c/
00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00d0/k>c
00<0000009nOW`2OWil06@2OWil9000001X0WinO0P00000=0;>c/`0300000036a/H0a/K600X0a/K6
00<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo00h0oooo
00<000000?l0003o00000`000?l00`00o`00o`000000000300000200oooo000Z0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`D0k>c/00<0
00000?ooo`3oool0I`3oool207l0O`l0oooo0P1o07l40?oo0080O`1o0P3oool307l0O`80ool00`1o
07l>0?ooo`80O`1o2@3oool20?oo04`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0i0?ooo`800?oo0P3o00040000o`03003o003o00000?oo00<0oooo1`00oomf0?ooo`03003oo`3o
0000o`0000<00?l000<0o`000000o`000?l01000ool20?l000<00?oo9P3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o0000o`000P00o`000`3o0000k>c/
0>c/k0030>c/k0030000003oool0oooo00L0oooo00D0o`00003o0000o`00003o003o00020?l000l0
oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@0:0=WIf@0300000036a/H0a/K600X0
a/K600<000000;>c/`2c/k<02`2c/k<00`000000WinO09nOW`0E09nOW`D000002@2<S8`5000001L0
WinO00<000000;>c/`2c/k<0302c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00T0
fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0=0?ooo`030000003o0000o`000080
0?l000@0003o003o003o0000o`000P0000000`3oool000000?ooo`0_0?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool0o`000P00o`020?l000D0k>c/00<000000?ooo`3oool01`3oool0
1@3o00000?l0003o00000?l00?l00080o`003`3oool00`000000k>c/0>c/k00<0>c/k0030000003I
fMT0fMWI00X0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`0<0;>c/`030000002O
Wil0WinO01D0WinO1@00000908b<S0D000005`2OWil00`000000/k>c0;>c/`0;0;>c/`0300000036
a/H0a/K600X0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003o
ool0oooo00d0oooo00@000000?l0003o00000?l00P000?l00`00o`00o`000?l0000300000200oooo
000Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`@0k>c/00<000000?ooo`3oool0GP3oool207l0O`H0oooo1P1o07l<0?ooo`80O`1o1P00
0?l207l0O`030?ooo`1o07l0O`1o00@0ool00P1o07l<0?ooo`H0O`1o1P3oool40?oo04/0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0i0?ooo`<00?oo00<0o`00003o00000?l00`00
o`02003oo`D0oooo0`00oomh0?ooo`<00?oo0P3o0004003oo`80003o0P3o0003003o00030?l00000
ool0oooo02D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`050?ooo`040000003o
0000o`00003o0080003o00<00?l00?l0003/k>`00`3/k>`00`000000oooo0?ooo`070?ooo`030?l0
0000o`00003o0080003o0P3o000>0?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT0
2P3IfMT00`000000a/K60<K6aP0:0<K6aP030000002c/k<0/k>c00/0/k>c00<0000009nOW`2OWil0
502OWil2000001<0S8b<0P00000F09nOW`800000302c/k<00`000000a/K60<K6aP090<K6aP030000
003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0<0?ooo`<00000
0P3o00030000o`03003o003o0000000000<00000<03oool00`000000oooo0?ooo`050?ooo`800000
00D0o`00003o0000o`00003o003o00020?l000<0k>c/00<000000?ooo`3oool0203oool00`3o0000
0?l00000o`020000o`80o`003P3oool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00X0
fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`0;0;>c/`8000005P2OWil2000001<0
S8b<0P00000F09nOW`030000002c/k<0/k>c00/0/k>c00<000000<K6aP36a/H02@36a/H00`000000
fMWI0=WIf@090=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool0303oool300000003
0?l00000o`00003o0080003o0P3o000300000200oooo000Z0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<0k>c/00<000000?ooo`3oool0
G@3oool607l0O`<0oooo0`1o07l20?oo00<0O`1o1`3oool60000o`040?oo00000?l0003o0000o`80
ool01@000?l00`3oo`00003o0?oo00020?oo0080O`1o2P3oool307l0O`80ool00`1o07l40?ooo`H0
ool0BP3oool00`000000oooo0?ooo`0^0?ooo`800000>`3oool2003oo`030?l000000?l00?l00080
0?l000<0o`00003oo`3oool0P@3oool:003oo`80003o1000o`02003oob@0oooo0P00000a0?ooo`03
0000003oool0oooo00D0oooo00<000000?l0003o00001@000?l30>c/k0030000003oool0oooo00P0
oooo0P3o00020000o`<0o`003P3oool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00X0
fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO0180
WinO0`00000G08b<S0@00000502OWil00`000000/k>c0;>c/`0:0;>c/`0300000036a/H0a/K600T0
a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo00/0
oooo0`0000020?l000<0003o00<00?l00?l0000000000`00000`0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3o00000?l010000?l01@3o0000k>c/0>c/k03/k>`0000000X0oooo0P3o0002
0000o`<0o`003P3oool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00T0fMWI00<00000
0<K6aP36a/H02@36a/H2000000`0/k>c00<0000009nOW`2OWil04P2OWil4000001L0S8b<0`00000D
09nOW`030000002c/k<0/k>c00/0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WIf@09
0=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool02`3oool3000000030?l00000o`00
003o0080003o0P3o000300000200oooo000Z0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool2000000<0oooo0P3/k>`00`000000oooo0?ooo`1M0?ooo`<0O`1o0P3oo`0307l0
O`80oooo0P1o07l40?oo0080O`1o1`000?l50?ooo`80O`1o00@0ool00000o`3oo`00ool00P1o07l0
103oool0O`1o07l0O`3oo`0<0000o`D0oooo0P1o07l40?oo0080O`1o103oool60?oo04T0oooo0P00
000`0?ooo`030000003oool0oooo03X0oooo00@00?oo0000o`000?l00?oo0P3o0003003ooh@0oooo
0`00ool20?ooo`800?oo0P3o00000`00o`00003o0000o`02003o00030?l00000ool0oooo02@0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`050?ooo`060000003o0000o`000?l00000
0?l00?l00P3o000010000?l0k>c/0>c/k000000;0?ooo`030?l000000?l0o`000080o`003`3oool0
0`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H02@36a/H0
0`000000/k>c0;>c/`0;0;>c/`030000002OWil0WinO0140WinO0P00000N08b<S0030000002OWil0
WinO0140WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0
fMWI00P0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0;0?ooo`<000000`3o0000
10000?l00?l00?l0003o000400000300oooo00<000000?ooo`3oool01@3oool01P000000oooo0?l0
003o00000?l00000o`80o`0000D0003o0>c/k03/k>`0k>c/0000000;0?ooo`030?l000000?l0o`00
0080o`003P3oool00`000000k>c/0>c/k00=0>c/k0030000003IfMT0fMWI00T0fMWI00<000000<K6
aP36a/H02@36a/H00`000000/k>c0;>c/`0:0;>c/`030000002OWil0WinO0180WinO00<0000008b<
S02<S8`0702<S8`2000001<0WinO00<000000;>c/`2c/k<02`2c/k<00`000000a/K60<K6aP080<K6
aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0;0?oo
o`<000000P3o00000`00o`00003o0?l000020?l000<00000803oool002X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0k>c/0000003o
ool0G`3oool207l0O`80ool000H0003o0?oo001o07l0O`1o0?ooo`1o07l80000o`0307l0O`3oool0
oooo00T0oooo0`1o07l20?oo00<0O`1o0P3oool207l0O`040?oo00000?l0ool00?oo0080O`1o1P3o
ool;0000o`030?oo001o07l0O`1o00@0oooo103oo`1;0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0>P3oool00`000?l00?oo003oo`05003oohX0oooo0P00ool20?l000@0003o00<0
0?l00?l00000ool09@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3o0000103o00020>c/k080003o00<000000?ooo`3oool02P3oool00`000?l0o`000?l0
000@0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT02P3IfMT00`000000a/K60<K6
aP090<K6aP030000002c/k<0/k>c00X0/k>c00<0000009nOW`2OWil0402OWil200000240S8b<0P00
000B09nOW`030000002c/k<0/k>c00X0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WI
f@090=WIf@030000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool0303oool3000000D0o`000`00
00000`3oool000000?ooo`0_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
0000103/k>`0003o0000o`00000=0?ooo`030000o`3o0000o`0000l0oooo00<000000>c/k03/k>`0
303/k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<0
2`2c/k<00`000000WinO09nOW`0@09nOW`8000008@2<S8`200000180WinO00<000000;>c/`2c/k<0
2P2c/k<00`000000a/K60<K6aP090<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`0
2P3/k>`00`000000oooo0?ooo`0<0?ooo`<000001@3o000400000200oooo000Z0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo05h0oooo0P1o07l20?oo00L0003o00<0O`1o0?oo003oo`000`000?l00`3oo`00O`1o07l0
O`0<0?ooo`H0O`1o0`3oool307l0O`80ool00`1o07l:0?ooo`80O`1o0P3oo`060000o`D0oooo0P3o
o`1<0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0>@3oool010000?l0oooo0?oo
o`3oool3003oohd0oooo0P00ool20?l000030000o`00o`000?l00080003o9P3oool00`000000oooo
0?ooo`0]0?ooo`<000001`3oool00`000000oooo0?ooo`030?l000D0k>c/00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0?0?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT0
2@3IfMT00`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00X0/k>c00<0000009nOW`2OWil0
3`2OWil2000002D0S8b<0`00000@09nOW`030000002c/k<0/k>c00X0/k>c0P00000:0<K6aP030000
003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0;0?ooo`@00000
0`3o0004000000030?ooo`000000oooo02d0oooo0`0000070?ooo`040000003oool0oooo0?ooo`<0
o`00103/k>`20000o``0oooo00<0003o0?ooo`3oool03`3oool00`000000k>c/0>c/k00<0>c/k003
0000003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`0:0;>c/`03
0000002OWil0WinO00l0WinO0P00000U08b<S08000004@2OWil00`000000/k>c0;>c/`0:0;>c/`03
00000036a/H0a/K600P0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00;0>c/k003
0000003oool0oooo00/0oooo100000030?l000D00000803oool002X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
GP3oool207l0O`80003o00@0ool00000o`3oo`00ool00P1o07l00`3oool0O`1o07l0O`020?oo0004
0000o`3oo`00O`1o07l0O`l0oooo0P1o07l60?ooo`H0O`1o303oool207l0O`80ool000D0003o0?oo
001o07l0O`1o0?ooo`030000o`X0oooo0P1o07m40?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0>03oool00`000?l0oooo0?ooo`2B0?ooo`800?oo1P3o00000`00ool0003o0?ooo`0T
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`D0k>c/00@000000?ooo`000?l0003o203oool00`3o0000003o0?l0000@0?ooo`030000003/
k>`0k>c/00`0k>c/00<000000=WIf@3IfMT02@3IfMT00`000000a/K60<K6aP090<K6aP030000002c
/k<0/k>c00X0/k>c00<0000009nOW`2OWil03`2OWil00`000000S8b<08b<S00X08b<S0030000002O
Wil0WinO00h0WinO00<000000;>c/`2c/k<02P2c/k<00`000000a/K60<K6aP080<K6aP030000003I
fMT0fMWI00P0fMWI00<000000>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0<0?ooo`T000000P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool60>c/k0030000003oool0003o00T0oooo00<0o`000000o`3o0000403oool00`000000k>c/0>c/
k00<0>c/k0030000003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c
/`0:0;>c/`030000002OWil0WinO00h0WinO0P00000Y08b<S08000003`2OWil00`000000/k>c0;>c
/`0:0;>c/`0300000036a/H0a/K600T0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/
k00;0>c/k0030000003oool0oooo00`0oooo2@0000000`3oool000000?ooo`0O0?ooo`00:`3oool4
000000H0oooo00<000000?ooo`3oool0HP3oool30000o`0307l0O`3oo`00ool00080ool00P1o07l2
0?ooo`<0O`1o0P3oo`0307l0OaT0oooo0P1o07l>0?ooo`<0O`1o0P3oo`0307l0O`@0oooo10000?l4
0?ooo`H0O`1o@P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03L0oooo00<0003o
0?ooo`3oool0U03oool3003oo`80o`000P00ool20?ooo`030000o`3oool0oooo00<0oooo0`00oolL
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool50>c/k0050000003oool0
oooo0?ooo`000?l01P3oool20?l000030000o`00o`00o`0000l0oooo00<000000>c/k03/k>`0303/
k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0a/K600T0a/K600<000000;>c/`2c/k<02@2c
/k<00`000000WinO09nOW`0>09nOW`800000;02<S8`2000000l0WinO00<000000;>c/`2c/k<02P2c
/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00P0fMWI0P00000<0>c/k0030000003o
ool0oooo00`0oooo1`0000030?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3o
ool60>c/k0030000003oool0oooo0080003o1P3oool00`3o00000?l00000o`020?l000l0oooo00<0
00000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0a/K600P0a/K600<0
00000;>c/`2c/k<02P2c/k<00`000000WinO09nOW`0>09nOW`030000002<S8`0S8b<02/0S8b<00<0
000009nOW`2OWil03@2OWil2000000/0/k>c00<000000<K6aP36a/H02@36a/H00`000000fMWI0=WI
f@080=WIf@030000003/k>`0k>c/00/0k>c/00<000000?ooo`3oool0303oool700000080oooo00<0
00000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool0H03oool20000o`80oooo0`1o07l2
0?oo00<0O`1o0`3oool607l0Ob/0oooo1P1o07l90?ooo`<0003o0`1o07l20?oo00<0O`1o@@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03D0oooo0P000?nI0?ooo`<00?oo1@3oool2
0000o`030?ooo`00ool00?oo0080o`000`00oolJ0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool00P3oool40>c/k0030000003oool0oooo00<0oooo0P000?l30?ooo`80o`000`000?l0
0`00o`00o`000?ooo`0<0?ooo`030000003/k>`0k>c/00`0k>c/00<000000=WIf@3IfMT02@3IfMT0
0`000000a/K60<K6aP090<K6aP030000002c/k<0/k>c00T0/k>c00<0000009nOW`2OWil03@2OWil2
00000300S8b<00<0000009nOW`2OWil03@2OWil00`000000/k>c0;>c/`090;>c/`0300000036a/H0
a/K600P0a/K600<000000=WIf@3IfMT02@3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0
oooo00d0oooo1@0000040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool5
0>c/k0030000003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o00000?l00000o`02
0000o`80o`003@3oool00`000000k>c/0>c/k00<0>c/k0030000003IfMT0fMWI00T0fMWI00<00000
0<K6aP36a/H02036a/H00`000000/k>c0;>c/`0:0;>c/`030000002OWil0WinO00d0WinO0P00000_
08b<S08000003`2OWil00`000000/k>c0;>c/`090;>c/`0300000036a/H0a/K600P0a/K600<00000
0=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00;0>c/k0030000003oool0oooo00d0oooo1@000003
0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo0580oooo0P1o07l:0?oo
o`80003o1@3oool607l0O`H0oooo0P1o07l_0?ooo`80O`1o3P3oool30000o`<0ool00P1o07m10?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`2S0?oo
o`030000o`3o0000o`0000@0o`000P00oolI0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool00P3oool40>c/k0030000003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o00001@00
o`00003o003o0000o`00o`0000d0oooo00<000000>c/k03/k>`0303/k>`00`000000fMWI0=WIf@09
0=WIf@0300000036a/H0a/K600P0a/K60P00000:0;>c/`030000002OWil0WinO00d0WinO00<00000
08b<S02<S8`0<@2<S8`2000000h0WinO00<000000;>c/`2c/k<02@2c/k<00`000000a/K60<K6aP08
0<K6aP030000003IfMT0fMWI00T0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool50>c/k0030000003oool0
oooo00@0oooo0P000?l20?ooo`050?l00000o`000?l00000o`00o`000P3o000=0?ooo`030000003/
k>`0k>c/00`0k>c/00<000000=WIf@3IfMT0203IfMT00`000000a/K60<K6aP090<K6aP030000002c
/k<0/k>c00T0/k>c00<0000009nOW`2OWil0302OWil2000003<0S8b<00<0000009nOW`2OWil03@2O
Wil00`000000/k>c0;>c/`090;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT0203I
fMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo01D0oooo00<000000?ooo`3oool07P3o
ool003D0oooo00<000000?ooo`3oool0D03oool607l0O`D0oooo0`000?l90?ooo`80O`1oB03oool2
07l0O`80ool00P000?l20?oo0080O`1o@03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo02T0oooo0P3o00080?ooo`030000o`3oool0oooo0:@0oooo00<00?oo0000o`3o00000`00o`00
0`3o00000?oo003oo`020?l001L0oooo00<000000?ooo`3oool0=`3oool2000000<0oooo103/k>`0
0`000000oooo0?ooo`060?ooo`80003o0P3o00000`00o`00003o003o00020?l000d0oooo00<00000
0>c/k03/k>`0303/k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0a/K600P0a/K600<00000
0;>c/`2c/k<0202c/k<00`000000WinO09nOW`0=09nOW`030000002<S8`0S8b<03@0S8b<00<00000
09nOW`2OWil0302OWil00`000000/k>c0;>c/`090;>c/`0300000036a/H0a/K600P0a/K600<00000
0=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo01@0oooo0P00000h
0?ooo`8000000`3oool50>c/k0030000003oool0oooo00H0oooo0P000?l20?l00003003o00000?l0
o`000080o`003@3oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00T0fMWI00<00000
0<K6aP36a/H02036a/H00`000000/k>c0;>c/`090;>c/`030000002OWil0WinO00`0WinO00<00000
08b<S02<S8`0=02<S8`00`000000WinO09nOW`0=09nOW`030000002c/k<0/k>c00P0/k>c00<00000
0<K6aP36a/H02@36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00X0k>c/00<00000
0?ooo`3oool0503oool200000200oooo000e0?ooo`030000003oool0oooo04l0oooo201o07l20?oo
o`80003oEP3oool207l0O`80ool010000?l207l0Od00oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0W0?ooo`040?l00000o`000?l0003o0080o`001@3oool00`000?l0oooo0?ooo`2T
0?ooo`03003oo`3o0000o`0000<0003o0P00o`00103o00000?l0003o0000o`020?l001D0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`@0k>c/00<000000?ooo`3oool01`3o
ool01`3o0000003o003o0000o`00003o003o003o00003P3oool00`000000k>c/0>c/k00;0>c/k003
0000003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H02036a/H00`000000/k>c0;>c/`090;>c/`03
0000002OWil0WinO00`0WinO00<0000008b<S02<S8`0=P2<S8`00`000000WinO09nOW`0;09nOW`03
0000002c/k<0/k>c00T0/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@090=WIf@03
0000003/k>`0k>c/00X0k>c/00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0080oooo103/k>`00`000000oooo0?ooo`080?ooo`030?l000000?l00?l00080
003o00<00?l00?l0003oool0303oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00T0
fMWI00<000000<K6aP36a/H02@36a/H00`000000/k>c0;>c/`090;>c/`030000002OWil0WinO00/0
WinO00<0000008b<S02<S8`0=P2<S8`00`000000WinO09nOW`0<09nOW`030000002c/k<0/k>c00T0
/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00X0
k>c/00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo
0?ooo`1?0?ooo`<0O`1o0P3oo`0207l0O`<0003oF@3oool207l0O`80ool000<0003o0?oo001o07l0
0P000?m00?ooo`030000003oool0oooo02h0oooo0P00000X0?ooo`D00?l000<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`2U0?ooo`04003oo`3o0000o`00003o00<0003o1P00o`000`3o0000
oooo0?ooo`0B0?ooo`800000>@3oool00`000000oooo0?ooo`020?ooo`@0k>c/00<000000?ooo`3o
ool01`3oool20?l000@0003o00<0o`000?ooo`3oool0303oool00`000000k>c/0>c/k00;0>c/k003
0000003IfMT0fMWI00P0fMWI00<000000<K6aP36a/H02036a/H2000000X0/k>c00<0000009nOW`2O
Wil02`2OWil2000003X0S8b<00<0000009nOW`2OWil02`2OWil00`000000/k>c0;>c/`090;>c/`03
00000036a/H0a/K600P0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k00:0>c/k003
0000003oool0oooo01@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`@0
k>c/00<000000?ooo`3oool0203oool20?l000<0003o00<00?l00?l0003oool0303oool00`000000
k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H02036a/H00`000000
/k>c0;>c/`090;>c/`030000002OWil0WinO00/0WinO00<0000008b<S02<S8`0>02<S8`2000000d0
WinO00<000000;>c/`2c/k<0202c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00P0
fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01h0
oooo000e0?ooo`800000B03oool207l0O`D0oooo0`1o07l00`3oo`00003o0?oo00020000o`80O`1o
FP3oool307l0O`80ool00`1o07l00`3oool0003o0000o`0m0?ooo`800000<03oool00`000000oooo
0?ooo`0V0?ooo`030?l00000o`000?l000<00?l00P3o00000`3oool0003o0000o`2X0?ooo`800?oo
00<0o`00003o0000o`000P000?l6003o0080o`00503oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0080oooo0`3/k>`00`000000oooo0?ooo`080?ooo`80o`0000@00?l00000o`000?l0
003o0P3o000<0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT0203IfMT00`000000
a/K60<K6aP080<K6aP030000002c/k<0/k>c00T0/k>c00<0000009nOW`2OWil02`2OWil00`000000
S8b<08b<S00H08b<S0T000006P2<S8`00`000000WinO09nOW`0;09nOW`030000002c/k<0/k>c00P0
/k>c00<000000<K6aP36a/H02036a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00X0
k>c/00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080
oooo103/k>`00`000000oooo0?ooo`080?ooo`80o`0010000?l20?l000/0oooo00<000000>c/k03/
k>`02`3/k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c
/k<02@2c/k<00`000000WinO09nOW`0;09nOW`030000002<S8`0S8b<01P0S8b<2@00000J08b<S003
0000002OWil0WinO00/0WinO00<000000;>c/`2c/k<0202c/k<00`000000a/K60<K6aP070<K6aP03
0000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo04D0oooo1P1o07l30?ooo`80O`1o
00@0ool00000o`000?l0003o0P3oo`0207l0Oe/0oooo1P1o07l40?ooo`80003o203oool207l0Oc80
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0V0?ooo`030?l00000o`000?l000<0
0?l00P3o00000`000?l0oooo0?ooo`2Y0?ooo`03003oo`3o0000o`0000<00?l000<0003o003o0000
o`000`00o`020?l00003003oo`3oool0oooo0140oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`020?ooo`<0k>c/00<000000?ooo`3oool0203oool20?l000800?l000@0003o003o003o
0000o`00303oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00P0fMWI00<000000<K6
aP36a/H02036a/H00`000000/k>c0;>c/`090;>c/`030000002OWil0WinO00X0WinO00<0000008b<
S02<S8`0502<S8`5000000T0NGUi1@00000F08b<S0030000002OWil0WinO00/0WinO00<000000;>c
/`2c/k<0202c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/
k03/k>`02P3/k>`00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool00P3oool40>c/k0030000003oool0oooo00P0oooo0P3o00001000o`00003o0000o`00o`02
0?l000/0oooo00<000000>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@090=WIf@0300000036a/H0
a/K600P0a/K600<000000;>c/`2c/k<0202c/k<00`000000WinO09nOW`0;09nOW`030000002<S8`0
S8b<01@0S8b<1@00000907UiN@D000005P2<S8`00`000000WinO09nOW`0;09nOW`030000002c/k<0
/k>c00P0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0
k>c/00X0k>c/00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`00
0000oooo0?ooo`140?ooo`80O`1o0P3oo`0407l0O`80oooo0`000?l00`3oo`00003o0?oo00020?oo
000307l0O`3oool0oooo05`0oooo0P1o07l80?ooo`80003o103oool607l0Oc00oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0W0?ooo`040?l00000o`000?l0003o0080o`0000<0003o
0?ooo`3oool0ZP3oool3003oo`80o`000P00ool20000o`800?l0103o00000`00ool0oooo0?ooo`0@
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool30>c/k0030000003oool0
oooo00T0oooo0P3o0002003o00<0o`002`3oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0
fMWI00T0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`090;>c/`030000002OWil0
WinO00X0WinO00<0000008b<S02<S8`04`2<S8`2000001<0NGUi0P00000E08b<S0030000002OWil0
WinO00/0WinO00<000000;>c/`2c/k<0202c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0
fMWI00P0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool00P3oool40>c/k0030000003oool0oooo00T0oooo0P3o0002
003o00<0o`002`3oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00T0fMWI00<00000
0<K6aP36a/H01`36a/H00`000000/k>c0;>c/`080;>c/`030000002OWil0WinO00/0WinO00<00000
08b<S02<S8`04`2<S8`2000001<0NGUi0P00000E08b<S0030000002OWil0WinO00X0WinO00<00000
0;>c/`2c/k<0202c/k<00`000000a/K60<K6aP080<K6aP030000003IfMT0fMWI00L0fMWI00<00000
0>c/k03/k>`02`3/k>`00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01h0oooo000e0?oo
o`030000003oool0oooo04@0oooo00<0O`1o0?oo003oo`000P3oo`0307l0O`80003o00<0oooo07l0
O`1o07l0103oo`0207l0OfX0oooo0P000?l0103oool0O`1o07l0O`1o07l20?oo00<0O`1o;`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02L0oooo1@3o00000`000?l0oooo0?ooo`2/
0?ooo`H00?oo0P3o000010000?l00?l0003o0000o`020?l00003003oo`3oool0oooo0100oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`80k>c/00<000000?ooo`3oool02`3o
ool50?l000`0oooo00<000000>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@080=WIf@0300000036
a/H0a/K600P0a/K600<000000;>c/`2c/k<0202c/k<00`000000WinO09nOW`0;09nOW`030000002<
S8`0S8b<0140S8b<0P00000G07UiN@<000004`2<S8`00`000000WinO09nOW`0:09nOW`030000002c
/k<0/k>c00P0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@090=WIf@030000003/
k>`0k>c/00T0k>c/00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0080oooo0`3/k>`00`000000oooo0?ooo`0;0?ooo`D0o`00303oool00`000000k>c/0>c/
k00:0>c/k0030000003IfMT0fMWI00T0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c
/`080;>c/`030000002OWil0WinO00/0WinO00<0000008b<S02<S8`04@2<S8`3000001L0NGUi0P00
000C08b<S0030000002OWil0WinO00X0WinO00<000000;>c/`2c/k<02@2c/k<00`000000a/K60<K6
aP070<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`02P3/k>`00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo04<0oooo00H0O`1o
0?oo003oo`00ool00000o`3oo`030000o`0407l0O`3oool0oooo0?ooo`80O`1o0P3oo`0207l0Ofd0
oooo0P000?l00`1o07l0ool00?oo00020?oo0080O`1o;`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02T0oooo0P3o00000`000?l0oooo0?ooo`2_0?ooo`D00?oo00@0o`00003o0000
0?l0003o0P00o`020?l00003003oo`3oool0oooo00l0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`020?ooo`80k>c/00<000000?ooo`3oool0303oool30?l000d0oooo00<000000>c/
k03/k>`02`3/k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0a/K600P0a/K600<000000;>c
/`2c/k<0202c/k<00`000000WinO09nOW`0:09nOW`030000002<S8`0S8b<00l0S8b<0`00000L07Ui
N@8000004P2<S8`00`000000WinO09nOW`0:09nOW`030000002c/k<0/k>c00P0/k>c00<000000<K6
aP36a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00X0k>c/00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0`3/k>`00`00
0000oooo0?ooo`0<0?ooo`<0o`00303oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI
00T0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`080;>c/`030000002OWil0WinO
00X0WinO00<0000008b<S02<S8`0402<S8`2000001`0NGUi0`00000A08b<S08000002`2OWil00`00
0000/k>c0;>c/`080;>c/`0300000036a/H0a/K600P0a/K600<000000=WIf@3IfMT01`3IfMT20000
00/0k>c/00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000
oooo0?ooo`130?ooo`0307l0O`3oo`00ool000<0003o00@0ool007l0O`1o07l0O`1o1@3oool207l0
Ofl0oooo0P1o07l20000o`040?oo00000?l0ool00?oo0080O`1o;P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo02T0oooo0P000?ne0?ooo`800?oo00<0o`00003o00000?l00P000?l0
1000o`00o`000?l00000oolA0?ooo`030000003oool0oooo03L0oooo0P0000030?ooo`80k>c/00<0
00000?ooo`3oool06`3oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00P0fMWI00<0
00000<K6aP36a/H02036a/H00`000000/k>c0;>c/`080;>c/`030000002OWil0WinO00T0WinO0P00
000@08b<S08000008@1iNGT300000100S8b<00<0000009nOW`2OWil02@2OWil00`000000/k>c0;>c
/`080;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/
k00:0>c/k0030000003oool0oooo0140oooo0P00000h0?ooo`8000000`3oool30>c/k0030000003o
ool0oooo01X0oooo00<000000>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@090=WIf@0300000036
a/H0a/K600L0a/K600<000000;>c/`2c/k<0202c/k<00`000000WinO09nOW`0:09nOW`030000002<
S8`0S8b<00l0S8b<0P00000Q07UiN@8000004@2<S8`00`000000WinO09nOW`0909nOW`030000002c
/k<0/k>c00P0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000003/
k>`0k>c/00T0k>c/00<000000?ooo`3oool04@3oool200000200oooo000e0?ooo`030000003oool0
oooo04@0oooo00D0O`1o0000o`000?l0003o0?oo000307l0OgL0oooo0P1o07l20?oo00<0003o00<0
ool007l0O`1o07l0;P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02P0oooo00<0
003o0?ooo`3oool0]@3oool3003oo`800?l00P000?l01000o`00o`00003oo`00oolA0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool20>c/k0030000003oool0oooo01/0oooo
00<000000>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0a/K600L0a/K6
00<000000;>c/`2c/k<0202c/k<00`000000WinO09nOW`0909nOW`030000002<S8`0S8b<00h0S8b<
0P00000V07UiN@8000003`2<S8`00`000000WinO09nOW`0909nOW`030000002c/k<0/k>c00P0/k>c
00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00T0k>c/
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo
0P3/k>`2000001`0oooo00<000000>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@080=WIf@030000
0036a/H0a/K600P0a/K600<000000;>c/`2c/k<0202c/k<00`000000WinO09nOW`0909nOW`030000
002<S8`0S8b<00h0S8b<0P00000U07UiN@<000003`2<S8`00`000000WinO09nOW`0909nOW`030000
002c/k<0/k>c00P0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000
003/k>`0k>c/00T0k>c/00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0N0?ooo`00=@3o
ool00`000000oooo0?ooo`140?ooo`040000o`1o07l0ool00?oo00@0O`1oN03oool207l0O`80ool0
0`000?l00`1o07l0oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
7`3oool3003oo`D0oooo00<0003o0?ooo`3oool0]`3oool2003oo`040?l00000o`000?l0003o0080
003o00<00?oo0?ooo`3oool0403oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080
oooo00<0k>c/0000003oool0703oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00P0
fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`080;>c/`030000002OWil0WinO00T0
WinO00<0000008b<S02<S8`03P2<S8`00`000000NGUi07UiN@0X07UiN@8000003P2<S8`00`000000
WinO09nOW`0909nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H02036a/H00`000000
fMWI0=WIf@070=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo0P3/k>`00`000000oooo0?ooo`0K0?ooo`03
0000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP080<K6aP03
0000002c/k<0/k>c00P0/k>c00<0000009nOW`2OWil02@2OWil00`000000S8b<08b<S00=08b<S080
0000:P1iNGT2000000h0S8b<00<0000009nOW`2OWil02@2OWil00`000000/k>c0;>c/`070;>c/`03
00000036a/H0a/K600L0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k0090>c/k003
0000003oool0oooo0140oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool0
@P3oool20000o`030?ooo`1o07l0O`1o00@0O`1oN@3oool307l0O`80ool00P1o07l20000obh0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`<00?oo0P3o0002003oo`80oooo
00<0003o0?ooo`3oool0^03oool4003oo`80o`000P00ool00`000?l0oooo0?ooo`020?ooo`<00?oo
2`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo00<0k>c/0000003oool0
703oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00P0fMWI00<000000<K6aP36a/H0
1`36a/H00`000000/k>c0;>c/`070;>c/`030000002OWil0WinO00T0WinO00<0000008b<S02<S8`0
302<S8`3000002d0NGUi00<0000008b<S02<S8`0302<S8`00`000000WinO09nOW`0909nOW`030000
002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000
003/k>`0k>c/00T0k>c/00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0080oooo0P3/k>`00`000000oooo0?ooo`0K0?ooo`030000003/k>`0k>c/00X0k>c/
0P0000090=WIf@0300000036a/H0a/K600L0a/K60P0000090;>c/`030000002OWil0WinO00T0WinO
00<0000008b<S02<S8`0302<S8`2000002h0NGUi00<0000008b<S02<S8`0302<S8`00`000000WinO
09nOW`0909nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H01`36a/H00`000000fMWI
0=WIf@080=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo00<0oooo0P1o
07ml0?ooo`H0O`1o0P3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0703oool2003oo`H0o`0000<00?oo0000o`3oool0^`3oool7003oo`030?ooo`00
0?l0oooo00L00?oo2@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo00<0
k>c/0000003oool0703oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00L0fMWI00<0
00000<K6aP36a/H02036a/H00`000000/k>c0;>c/`070;>c/`030000002OWil0WinO00T0WinO00<0
000008b<S02<S8`02`2<S8`00`000000NGUi07UiN@0_07UiN@030000002<S8`0S8b<00`0S8b<00<0
000009nOW`2OWil02@2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600L0a/K600<0
00000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k00:0>c/k0030000003oool0oooo0100oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`80k>c/00<000000?ooo`3oool06P3o
ool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0fMWI00P0fMWI00<000000<K6aP36a/H01`36
a/H00`000000/k>c0;>c/`080;>c/`030000002OWil0WinO00P0WinO00<0000008b<S02<S8`0302<
S8`00`000000NGUi07UiN@0_07UiN@030000002<S8`0S8b<00/0S8b<00<0000009nOW`2OWil02@2O
Wil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT0203I
fMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo0100oooo00<000000?ooo`3oool07P3o
ool003D0oooo0P0000100?ooo`80003oQP3oool207l0O`D0oooo0P000?lZ0?ooo`800000<03oool2
000001d0oooo0P00ool20?l000<00?l00P000?no0?ooo`<00?oo103oool00`000?l00?oo003oo`02
0?l000@00?oo1`3oool2000003T0oooo00<000000?ooo`3oool00P3oool00`3/k>`000000?ooo`0K
0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT0203IfMT00`000000a/K60<K6aP07
0<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil02@2OWil00`000000S8b<08b<S00;
08b<S0030000001iNGT0NGUi0340NGUi0P00000=08b<S0030000002OWil0WinO00P0WinO00<00000
0;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00P0fMWI00<00000
0>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool00P3oool00`3/k>`000000?ooo`0L0?ooo`030000003/k>`0k>c/00X0k>c/00<00000
0=WIf@3IfMT0203IfMT00`000000a/K60<K6aP070<K6aP030000002c/k<0/k>c00P0/k>c00<00000
09nOW`2OWil0202OWil00`000000S8b<08b<S00<08b<S0030000001iNGT0NGUi0340NGUi00<00000
08b<S02<S8`02`2<S8`00`000000WinO09nOW`0809nOW`030000002c/k<0/k>c00P0/k>c00<00000
0<K6aP36a/H01`36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00T0k>c/00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`0n0?oo
o`030000o`3oool0oooo08l0oooo0P000?lY0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool06`3oool2003oo`80o`0000L00?l00000o`00o`00003o003o003o00000?oo0<D0oooo00<0
0?oo0000o`000?l00`00o`000`3o00000?oo003oo`080?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool00P3oool00`3/k>`000000?ooo`0K0?ooo`030000003/k>`0k>c/00/0k>c/00<0
00000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP080<K6aP030000002c/k<0/k>c00L0/k>c00<0
000009nOW`2OWil01`2OWil2000000d0S8b<00<0000007UiN@1iNGT0=01iNGT00`000000S8b<08b<
S00;08b<S0030000002OWil0WinO00P0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K60<K6
aP070<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`3/k>`000000?oo
o`0L0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT0203IfMT00`000000a/K60<K6
aP070<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil0202OWil2000000`0S8b<0P00
000e07UiN@030000002<S8`0S8b<00/0S8b<0P00000909nOW`030000002c/k<0/k>c00L0/k>c00<0
00000<K6aP36a/H01`36a/H00`000000fMWI0=WIf@080=WIf@030000003/k>`0k>c/00T0k>c/00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`0m
0?ooo`030000o`3oool0oooo0980oooo0P000?l50?ooo`80O`1o803oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01/0oooo0P00ool20?l000<0003o0P00o`000`3o00000?oo0?ooo`33
0?ooo`800?oo00@0o`00003o00000?l0003o0P00o`04003oo`H0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000>c/k03/k>`02`3/
k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600P0a/K600<000000;>c/`2c/k<01`2c
/k<00`000000WinO09nOW`0709nOW`030000002<S8`0S8b<00/0S8b<0P00000h07UiN@030000002<
S8`0S8b<00X0S8b<00<0000009nOW`2OWil0202OWil00`000000/k>c0;>c/`070;>c/`0300000036
a/H0a/K600L0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k0090>c/k0030000003o
ool0oooo0100oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030>c/k000
0000oooo01/0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@080=WIf@0300000036
a/H0a/K600P0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0809nOW`030000002<
S8`0S8b<00/0S8b<00<0000007UiN@1iNGT0=P1iNGT2000000`0S8b<00<0000009nOW`2OWil0202O
Wil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3IfMT01`3I
fMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00l0oooo00<000000?ooo`3oool07P3o
ool003D0oooo00<000000?ooo`3oool0>`3oool20000oiL0oooo00<0003o0?ooo`3oool01P1o07lN
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool06`3oool3003oo`030?l00000o`00
003o00<00?l00P00ooo40?ooo`04003oo`3o0000o`00003o00<0003o00<00?l00?l0003o00000`00
ool50?ooo`030000003oool0oooo03L0oooo0P0000030?ooo`030000003oool0oooo01X0oooo00<0
00000>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600L0a/K600<0
00000;>c/`2c/k<01`2c/k<2000000T0WinO00<0000008b<S02<S8`02P2<S8`00`000000NGUi07Ui
N@0E07UiN@h000005P1iNGT00`000000S8b<08b<S00:08b<S0030000002OWil0WinO00P0WinO00<0
00000;>c/`2c/k<01`2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00L0fMWI00<0
00000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0>0?ooo`800000>03oool2000000<0oooo00<0
k>c/0000003oool06`3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00P0fMWI00<0
00000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`070;>c/`030000002OWil0WinO00P0WinO00<0
000008b<S02<S8`02P2<S8`00`000000NGUi07UiN@0E07UiN@d000005`1iNGT00`000000S8b<08b<
S00:08b<S0030000002OWil0WinO00P0WinO00<000000;>c/`2c/k<01`2c/k<00`000000a/K60<K6
aP060<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?oo
o`0=0?ooo`800000803oool003D0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`2H
0?ooo`80003o00<0O`1o0?oo003oo`00101o07lM0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0703oool2003oo`030?l000000?l00?l000800?l000<0o`00003oo`3oool0a03oool0
0`00ool0o`000?l00002003o0080003o0`00o`020?l00003003oo`00000000000080000000<0oooo
0000003oool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<00000
0>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600L0a/K600<00000
0;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0709nOW`030000002<S8`0S8b<00X0S8b<00<00000
07UiN@1iNGT04`1iNGT3000000h0IVIV0P00000E07UiN@030000002<S8`0S8b<00X0S8b<00<00000
09nOW`2OWil0202OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<00000
0=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<00000
0>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0a/K600L0a/K600<00000
0;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0809nOW`030000002<S8`0S8b<00X0S8b<00<00000
07UiN@1iNGT04`1iNGT3000000d0IVIV0`00000E07UiN@030000002<S8`0S8b<00X0S8b<00<00000
09nOW`2OWil01`2OWil00`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600H0a/K600<00000
0=WIf@3IfMT0203IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00h0oooo00<00000
0?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool0<03oool207l0O`H0oooo0P000?nL0?oo
o`0507l0O`000?l0003o0000o`3oo`000`1o07lM0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0703oool2003oo`040000o`00ool0o`000?l000<00?ooaP3oool00`00ool0o`000?l0
0003003o00050000o`00o`000?l0003o003o00000P00ool5000003T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0I0?ooo`030000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT0
1`3IfMT00`000000a/K60<K6aP070<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil0
1`2OWil00`000000S8b<08b<S00:08b<S0030000001iNGT0NGUi0100NGUi1000000C06IVIP@00000
4P1iNGT00`000000S8b<08b<S00908b<S0030000002OWil0WinO00P0WinO00<000000;>c/`2c/k<0
1`2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`0
2@3/k>`00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0J0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT0
203IfMT00`000000a/K60<K6aP070<K6aP030000002c/k<0/k>c00L0/k>c00<0000009nOW`2OWil0
1`2OWil00`000000S8b<08b<S00:08b<S0030000001iNGT0NGUi0100NGUi1000000C06IVIP@00000
4P1iNGT00`000000S8b<08b<S00908b<S0030000002OWil0WinO00P0WinO00<000000;>c/`2c/k<0
1`2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00P0fMWI00<000000>c/k03/k>`0
2@3/k>`00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003o
ool0oooo02h0oooo1P1o07l30?ooo`030000o`3oool0oooo09/0oooo00<0O`1o0?oo003oo`000`00
0?l0103oo`00O`1o07l0O`1o07lL0?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool0
oooo0`00oolI0?ooo`030000o`00ool00?oo00@00?ooa`3oool00`00ool0o`000?l000020?l00080
0?l000<0003o003o0000o`000P3o0003003oo`<00000>@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003/k>`0k>c/00/0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP070<K6aP03
0000002c/k<0/k>c00H0/k>c0P00000909nOW`030000002<S8`0S8b<00X0S8b<00<0000007UiN@1i
NGT03P1iNGT3000001X0IVIV0`00000@07UiN@030000002<S8`0S8b<00T0S8b<00<0000009nOW`2O
Wil0202OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K600<000000=WIf@3I
fMT01`3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0O0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3I
fMT0203IfMT00`000000a/K60<K6aP060<K6aP800000202c/k<00`000000WinO09nOW`0809nOW`03
0000002<S8`0S8b<00T0S8b<00<0000007UiN@1iNGT03P1iNGT3000001/0IVIV0`00000@07UiN@03
0000002<S8`0S8b<00T0S8b<00<0000009nOW`2OWil01`2OWil00`000000/k>c0;>c/`070;>c/`03
00000036a/H0a/K600H0a/K600<000000=WIf@3IfMT0203IfMT00`000000k>c/0>c/k0090>c/k003
0000003oool0oooo00d0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool0
;@3oool307l0O`80ool00`1o07l20000oih0oooo00@0O`1o0?oo003oo`00ool00P000?l0103oo`00
O`1o07l0O`1o07lL0?ooo`030000003oool0oooo02<0oooo1`0000040?ooo`030000003oool00?oo
00H00?oo5P3oool00`000?l0oooo0?ooo`03003oolX0oooo0P00ool20?l00005003o00000?l0003o
0000o`00o`000`3o0003003oo`800000>@3oool00`000000oooo0?ooo`0M0?ooo`030000003/k>`0
k>c/00/0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP070<K6aP030000002c/k<0
/k>c00H0/k>c00<0000009nOW`2OWil0202OWil00`000000S8b<08b<S00908b<S08000003`1iNGT2
00000200IVIV0P00000?07UiN@8000002P2<S8`2000000P0WinO00<000000;>c/`2c/k<01`2c/k<0
0`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`02@3/k>`0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool07P3oool0
0`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00P0fMWI00<000000<K6aP36a/H01P36a/H0
0`000000/k>c0;>c/`070;>c/`030000002OWil0WinO00P0WinO00<0000008b<S02<S8`0202<S8`2
00000100NGUi00<0000006IVIP1VIVH07`1VIVH2000000l0NGUi00<0000008b<S02<S8`02@2<S8`0
0`000000WinO09nOW`0709nOW`030000002c/k<0/k>c00L0/k>c00<000000<K6aP36a/H01P36a/H0
0`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`0]0?ooo`80O`1o103oo`000`1o
07l0003o0?ooo`2P0?ooo`0307l0O`3oo`00ool00080ool00P000?l00`1o07l0oooo0?ooo`0K0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool00`0000000?oo003oo`02003o
o`80o`000`00oolD0?ooo`030000o`3oool0oooo0=00oooo0P00ool01@3o00000?l00000o`00o`00
003o00<00?l00P3o0002003oo`030000003oool0oooo01X0oooo1`0000040?ooo`8000001@3oool6
000000D0oooo00<000000?ooo`3oool07@3oool00`000000k>c/0>c/k00;0>c/k0030000003IfMT0
fMWI00L0fMWI00<000000<K6aP36a/H01`36a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0
WinO00L0WinO0P00000:08b<S0030000001iNGT0NGUi00h0NGUi00<0000006IVIP1VIVH08P1VIVH0
0`000000NGUi07UiN@0>07UiN@030000002<S8`0S8b<00P0S8b<00<0000009nOW`2OWil01`2OWil0
0`000000/k>c0;>c/`070;>c/`0300000036a/H0a/K600H0a/K600<000000=WIf@3IfMT01`3IfMT0
0`000000k>c/0>c/k0090>c/k0030000003oool0oooo00d0oooo00<000000?ooo`3oool06@3oool7
000000@0oooo0P0000050?ooo`H000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003/k>`0
k>c/00X0k>c/00<000000=WIf@3IfMT0203IfMT00`000000a/K60<K6aP060<K6aP030000002c/k<0
/k>c00L0/k>c00<0000009nOW`2OWil01`2OWil00`000000S8b<08b<S00908b<S0030000001iNGT0
NGUi00d0NGUi0P00000T06IVIP030000001iNGT0NGUi00d0NGUi00<0000008b<S02<S8`02@2<S8`0
0`000000WinO09nOW`0709nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H0
0`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`0/0?ooo`80O`1o0P3oo`001000
0?l0ool00000o`000?l207l0Oj00oooo0P1o07l20?oo00<0O`1o00<0003o0?ooo`3oool06`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00@00000003oo`00ool0o`000`00
o`020?l00003003oo`3oool0oooo0140oooo00<0003o0?ooo`3oool0d@3oool2003oo`@0o`0000<0
0?l00000o`00o`000P00o`00103o00000?oo003oo`00000O0?ooo`030000003oool0oooo00D0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0M0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K6
0<K6aP070<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01`2OWil00`000000S8b<
08b<S00908b<S0030000001iNGT0NGUi00d0NGUi0P00000V06IVIP8000003P1iNGT00`000000S8b<
08b<S00908b<S0030000002OWil0WinO00L0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K6
0<K6aP060<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool2000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo
00<000000>c/k03/k>`02`3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600H0a/K6
00<000000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0709nOW`030000002<S8`0S8b<00T0S8b<
00<0000007UiN@1iNGT0301iNGT2000002L0IVIV0P00000>07UiN@030000002<S8`0S8b<00T0S8b<
00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600L0a/K6
00<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00d0oooo
00<000000?ooo`3oool07P3oool003D0oooo0P00000]0?ooo`80O`1o00@0ool00000o`000?l0003o
0P3oo`0207l0Oj40oooo1P1o07l00`3oool0003o0?ooo`0J0?ooo`800000:03oool00`000000oooo
0?ooo`050?ooo`<00?oo0P00o`0010000?l00?l0003o003o0002003ooa40oooo00<0003o0?ooo`3o
ool0d`3oool3003oo`80o`000P00o`020000o`800?l000<0o`00003oo`00ool07`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000
k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01P36a/H00`000000
/k>c0;>c/`070;>c/`030000002OWil0WinO00L0WinO00<0000008b<S02<S8`0202<S8`00`000000
NGUi07UiN@0<07UiN@800000:P1VIVH2000000d0NGUi0P00000:08b<S0030000002OWil0WinO00L0
WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00L0
fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0
oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0a/K600H0
a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0709nOW`030000002<S8`0S8b<00P0
S8b<0P00000=07UiN@800000:`1VIVH2000000d0NGUi00<0000008b<S02<S8`02@2<S8`00`000000
WinO09nOW`0609nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01`36a/H00`000000
fMWI0=WIf@060=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`0]0?ooo`0407l0O`000?l0003o0000o`80
ool00P1o07nT0?ooo`80O`1o103oool20000oaX0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`050?ooo`800?oo00<0o`00003o00000?l00P000?l01000o`00o`000?l00000ool@0?oo
o`030000o`3oool0oooo0=H0oooo0P00ool00`3o00000?l00000o`030000o`04003o003o00000?oo
003ooal0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`8000007P3oool0
0`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01P36a/H0
0`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00L0WinO00<0000008b<S02<S8`0202<S8`0
0`000000NGUi07UiN@0;07UiN@800000;P1VIVH00`000000NGUi07UiN@0<07UiN@030000002<S8`0
S8b<00L0S8b<00<0000009nOW`2OWil01`2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0
a/K600H0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0
oooo00X0oooo0`00000N0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool3
000001d0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0
a/K600L0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nOW`0709nOW`030000002<S8`0
S8b<00L0S8b<00<0000007UiN@1iNGT0301iNGT00`000000IVIV06IVIP0]06IVIP030000001iNGT0
NGUi00/0NGUi00<0000008b<S02<S8`0202<S8`00`000000WinO09nOW`0709nOW`030000002c/k<0
/k>c00H0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0
k>c/00T0k>c/00<000000?ooo`3oool02`3oool200000200oooo000e0?ooo`030000003oool0oooo
02<0oooo0P1o07l70?ooo`80003o0P1o07l20?oo00<0O`1o[03oool00`000?l0oooo0?ooo`0G0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool2003oo`040?l00000o`000?l0
0000o`800?l00P3o00000`00ool0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0=L0oooo00D00000
003oo`3o0000o`00003o00020000o`800?l000<0o`00003oo`00ool07`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000k>c/0>c/
k00:0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01P36a/H00`000000/k>c0;>c
/`070;>c/`030000002OWil0WinO00H0WinO00<0000008b<S02<S8`0202<S8`00`000000NGUi07Ui
N@0;07UiN@030000001VIVH0IVIV02l0IVIV00<0000007UiN@1iNGT0301iNGT00`000000S8b<08b<
S00708b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6
aP070<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01`0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WI
f@080=WIf@0300000036a/H0a/K600H0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nO
W`0709nOW`030000002<S8`0S8b<00P0S8b<00<0000007UiN@1iNGT02`1iNGT00`000000IVIV06IV
IP0_06IVIP030000001iNGT0NGUi00/0NGUi00<0000008b<S02<S8`01`2<S8`00`000000WinO09nO
W`0709nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WI
f@070=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0N0?ooo`00=@3oool00`000000oooo0?ooo`0Q0?ooo`H0O`1o0P3oool30000o`80oooo1P1o07n^
0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`05
0?ooo`0700000000ool00?oo0?l00000o`00003o003o00020?l00003003oo`3oool0oooo00d0oooo
00<0003o0?ooo`3oool0f03oool00`0000000?oo003oo`020?l000<00?l000@0o`00003oo`00ool0
00007`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0703oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36
a/H01P36a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00L0WinO00<0000008b<S02<
S8`0202<S8`00`000000NGUi07UiN@0:07UiN@030000001VIVH0IVIV0340IVIV00<0000007UiN@1i
NGT02`1iNGT00`000000S8b<08b<S00808b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c
/k<01P2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/
k>`0203/k>`00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<000000>c/k03/
k>`02P3/k>`00`000000fMWI0=WIf@080=WIf@0300000036a/H0a/K600H0a/K600<000000;>c/`2c
/k<01P2c/k<00`000000WinO09nOW`0709nOW`030000002<S8`0S8b<00L0S8b<00<0000007UiN@1i
NGT02`1iNGT00`000000IVIV06IVIP0a06IVIP030000001iNGT0NGUi00/0NGUi00<0000008b<S02<
S8`01`2<S8`00`000000WinO09nOW`0709nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36
a/H01P36a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`0P0?ooo`<0O`1o
0P3oo`0207l0O`80003o1`3oool207l0Ok40oooo0P000?l40?ooo`80O`1o403oool00`000000oooo
0?ooo`0T0?ooo`<000001`3oool00`0000000?oo003oo`020?l000050000o`3o0000o`000?l00000
ool01`3oool3003oo`@0oooo00<0003o0?ooo`3oool0fP3oool00`0000000?oo0?l000050?l00080
0?oo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`030000003/k>`0k>c/00X0
k>c/00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP060<K6aP030000002c/k<0/k>c00H0
/k>c00<0000009nOW`2OWil01`2OWil00`000000S8b<08b<S00808b<S0030000001iNGT0NGUi00X0
NGUi00<0000006IVIP1VIVH0<`1VIVH2000000`0NGUi00<0000008b<S02<S8`0202<S8`00`000000
WinO09nOW`0509nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6aP36a/H01P36a/H00`000000
fMWI0=WIf@070=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000>c/k03/k>`02@3/k>`00`000000
fMWI0=WIf@080=WIf@0300000036a/H0a/K600H0a/K600<000000;>c/`2c/k<01P2c/k<00`000000
WinO09nOW`0709nOW`030000002<S8`0S8b<00L0S8b<00<0000007UiN@1iNGT02P1iNGT2000003D0
IVIV00<0000007UiN@1iNGT02`1iNGT00`000000S8b<08b<S00708b<S0030000002OWil0WinO00H0
WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00H0
fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0
oooo000e0?ooo`030000003oool0oooo0200oooo0P1o07l00`3oo`00003o0?oo00020000o`0307l0
O`3oool0oooo0;/0oooo00<0003o0?ooo`1o07l01@1o07l>0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo003oo`02003oo`040?l000000?l00?oo003oo`H0
oooo1`00ool00`3oool0003o0?ooo`3M0?ooo`0300000000ool00?oo0080o`000`00ool2000001d0
oooo0`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0K0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01`3IfMT00`000000
a/K60<K6aP060<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil00`000000
S8b<08b<S00708b<S08000002`1iNGT2000001D0IVIV3P00000E06IVIP030000001iNGT0NGUi00X0
NGUi00<0000008b<S02<S8`01`2<S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00H0
/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00P0
k>c/00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`<000003P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000
k>c/0>c/k0090>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01P36a/H2000000P0
/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00708b<S0030000001iNGT0NGUi00X0
NGUi00<0000006IVIP1VIVH0501VIVH=000001D0IVIV0P00000<07UiN@030000002<S8`0S8b<00L0
S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600H0
a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00X0
oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool07`3oool207l0O`040?oo
00000?l0003o0000o`80ool00P1o07nm0?ooo`030000o`1o07l0O`1o0080ool00`1o07l=0?ooo`03
0000003oool0oooo02h0oooo00@000000?ooo`3oool0oooo0P00ool00`000?l0oooo0?ooo`050?oo
o`@00?oo0P3o0002003oo`030000o`3oool0oooo0=h0oooo0P000003003oo`@000007`3oool00`00
0000oooo0?ooo`0=0?ooo`@000001P3oool00`000000oooo0?ooo`0K0?ooo`030000003/k>`0k>c/
00X0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP070<K6aP030000002c/k<0/k>c
00H0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00708b<S0030000001iNGT0NGUi
00T0NGUi00<0000006IVIP1VIVH04P1VIVH3000000h0De=C0P00000D06IVIP030000001iNGT0NGUi
00X0NGUi00<0000008b<S02<S8`01`2<S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c
00H0/k>c00<000000<K6aP36a/H01@36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/
00P0k>c/00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00d0oooo100000060?ooo`030000003oool0oooo01`0oooo00<000000>c/k03/k>`02@3/k>`00`00
0000fMWI0=WIf@070=WIf@0300000036a/H0a/K600H0a/K600<000000;>c/`2c/k<01P2c/k<00`00
0000WinO09nOW`0609nOW`030000002<S8`0S8b<00L0S8b<00<0000007UiN@1iNGT02P1iNGT00`00
0000IVIV06IVIP0B06IVIP<000003@1CDe<3000001@0IVIV00<0000007UiN@1iNGT02P1iNGT00`00
0000S8b<08b<S00608b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01P2c/k<00`00
0000a/K60<K6aP060<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02@3/k>`00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0oooo01l0
oooo00D0O`1o0000o`000?l0ool00000o`030?oo0080O`1o_@3oool00`1o07l0003o0000o`030?oo
0080O`1o3@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool2003oo`80o`000`00o`000`000?l00?oo0?ooo`3P0?ooo`H0000000<0oooo0000
003oool0>03oool00`000000oooo0?ooo`0J0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WI
f@3IfMT01`3IfMT00`000000a/K60<K6aP060<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nO
W`2OWil01P2OWil00`000000S8b<08b<S00708b<S0030000001iNGT0NGUi00T0NGUi00<0000006IV
IP1VIVH03`1VIVH4000001<0De=C1000000A06IVIP030000001iNGT0NGUi00T0NGUi00<0000008b<
S02<S8`01`2<S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00H0/k>c00<000000<K6
aP36a/H01P36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00P0k>c/00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01/0oooo00<000000>c/
k03/k>`02P3/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600H0a/K600<000000;>c
/`2c/k<01`2c/k<00`000000WinO09nOW`0609nOW`030000002<S8`0S8b<00L0S8b<00<0000007Ui
N@1iNGT02@1iNGT00`000000IVIV06IVIP0?06IVIP@000004`1CDe<400000140IVIV00<0000007Ui
N@1iNGT02@1iNGT00`000000S8b<08b<S00708b<S0030000002OWil0WinO00H0WinO00<000000;>c
/`2c/k<01@2c/k<00`000000a/K60<K6aP070<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/
k03/k>`02@3/k>`00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo000e0?ooo`03
0000003oool0oooo01h0oooo0P000?l207l0O`@0ool00P1o07nm0?ooo`80O`1o0P3oo`0010000?l0
ool00?oo003oo`0207l0O``0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo0`00ool01P3o00000?l0003o0000o`00003o003o00800?ooi`3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01X0oooo00<000000>c/k03/k>`02P3/
k>`00`000000fMWI0=WIf@070=WIf@0300000036a/H0a/K600H0a/K600<000000;>c/`2c/k<01P2c
/k<00`000000WinO09nOW`0609nOW`030000002<S8`0S8b<00H0S8b<0P00000:07UiN@030000001V
IVH0IVIV00h0IVIV0`00000J05=CD`<000003`1VIVH00`000000NGUi07UiN@0907UiN@030000002<
S8`0S8b<00L0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`050;>c/`0300000036
a/H0a/K600H0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/0>c/k0080>c/k0030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0K0?ooo`030000003/
k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01P3IfMT00`000000a/K60<K6aP060<K6aP030000002c
/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00708b<S0030000001i
NGT0NGUi00T0NGUi00<0000006IVIP1VIVH03@1VIVH4000001T0De=C1000000?06IVIP030000001i
NGT0NGUi00T0NGUi00<0000008b<S02<S8`01P2<S8`2000000L0WinO00<000000;>c/`2c/k<01P2c
/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02@3/
k>`00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo000e0?ooo`030000003oool0
oooo01/0oooo0`000?l20?ooo`<0O`1o0P3oo`0307l0Okd0oooo0P1o07l0103oo`00003o0000o`00
0?l20?oo0080O`1o303oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool2003oo`80o`0000<00?l00000o`000?l00P00o`000`3o00000?oo0?oo
o`3V0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06@3oool00`000000k>c/0>c/
k00:0>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01P36a/H00`000000/k>c0;>c
/`060;>c/`030000002OWil0WinO00H0WinO00<0000008b<S02<S8`01P2<S8`00`000000NGUi07Ui
N@0907UiN@030000001VIVH0IVIV00d0IVIV0P00000P05=CD`8000003P1VIVH2000000X0NGUi00<0
000008b<S02<S8`01P2<S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00H0/k>c00<0
00000<K6aP36a/H01@36a/H00`000000fMWI0=WIf@070=WIf@030000003/k>`0k>c/00T0k>c/00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01X0oooo00<0
00000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600H0a/K600<0
00000;>c/`2c/k<01`2c/k<00`000000WinO09nOW`0509nOW`030000002<S8`0S8b<00L0S8b<00<0
000007UiN@1iNGT02@1iNGT00`000000IVIV06IVIP0=06IVIP030000001CDe<0De=C01l0De=C0P00
000>06IVIP030000001iNGT0NGUi00P0NGUi00<0000008b<S02<S8`01`2<S8`00`000000WinO09nO
W`0609nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WI
f@060=WIf@030000003/k>`0k>c/00T0k>c/00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0N0?ooo`00=@3oool2000001X0oooo0P000?l60?ooo`H0O`1o_`3oool207l0O`040?oo00000?l0
ool00000o`80O`1o303oool200000300oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`800?oo0P3o00030000o`800?l000<0o`00003oo`3oool0iP3oool00`000000oooo0?oo
o`0g0?ooo`8000006P3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI00L0fMWI00<0
00000<K6aP36a/H01@36a/H2000000L0/k>c00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<
S00708b<S0030000001iNGT0NGUi00P0NGUi00<0000006IVIP1VIVH03@1VIVH00`000000De=C05=C
D`0R05=CD`030000001VIVH0IVIV00d0IVIV00<0000007UiN@1iNGT0201iNGT00`000000S8b<08b<
S00608b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6
aP050<K6aP030000003IfMT0fMWI00L0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?oo
o`080?ooo`800000>03oool2000001/0oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WI
f@060=WIf@0300000036a/H0a/K600H0a/K600<000000;>c/`2c/k<01P2c/k<00`000000WinO09nO
W`0609nOW`030000002<S8`0S8b<00H0S8b<00<0000007UiN@1iNGT0201iNGT2000000h0IVIV0P00
000T05=CD`030000001VIVH0IVIV00`0IVIV00<0000007UiN@1iNGT0201iNGT00`000000S8b<08b<
S00708b<S0030000002OWil0WinO00H0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6
aP060<K6aP030000003IfMT0fMWI00H0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?oo
o`070?ooo`800000803oool003D0oooo00<000000?ooo`3oool05`3oool20000o`X0oooo0P1o07o1
0?ooo`<0O`1o0P3oo`000`1o07l0003o07l0O`0=0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`800?oo00<0o`000000o`000?l00P00o`00
0`3o00000?oo0?ooo`3W0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06@3oool0
0`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01P36a/H0
0`000000/k>c0;>c/`050;>c/`030000002OWil0WinO00H0WinO00<0000008b<S02<S8`01`2<S8`0
0`000000NGUi07UiN@0807UiN@030000001VIVH0IVIV00`0IVIV0P00000V05=CD`8000003P1VIVH0
0`000000NGUi07UiN@0807UiN@030000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01P2OWil0
0`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT01`3IfMT0
0`000000k>c/0>c/k0080>c/k0030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01`3IfMT0
0`000000a/K60<K6aP050<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01P2OWil0
0`000000S8b<08b<S00608b<S0030000001iNGT0NGUi00P0NGUi00<0000006IVIP1VIVH0301VIVH2
000002L0De=C0P00000=06IVIP8000002@1iNGT00`000000S8b<08b<S00608b<S0030000002OWil0
WinO00H0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0
fMWI00H0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01h0oooo000e0?ooo`030000003oool0oooo01@0oooo0`000?o@0?ooo`H0O`1o00<0003o0?oo
o`3oool02`3oool00`000000oooo0?ooo`0^0?ooo`8000001@3oool00`000?l0oooo0?ooo`040?oo
o`800?oo00<0003o0?l0003o00000`3o00000`00ool0oooo0?ooo`3U0?ooo`800000>@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003/k>`0k>c/00T0k>c/00<000000=WIf@3IfMT01`3IfMT00`00
0000a/K60<K6aP060<K6aP030000002c/k<0/k>c00D0/k>c00<0000009nOW`2OWil01P2OWil00`00
0000S8b<08b<S00608b<S0030000001iNGT0NGUi00P0NGUi00<0000006IVIP1VIVH02`1VIVH20000
02X0De=C0P00000=06IVIP030000001iNGT0NGUi00P0NGUi00<0000008b<S02<S8`01@2<S8`20000
00L0WinO00<000000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI
00H0fMWI00<000000>c/k03/k>`02@3/k>`00`000000oooo0?ooo`080?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool06@3oool00`000000k>c/0>c/k00:0>c/k0030000003IfMT0fMWI
00H0fMWI0P0000070<K6aP030000002c/k<0/k>c00H0/k>c00<0000009nOW`2OWil01@2OWil20000
00P0S8b<00<0000007UiN@1iNGT01`1iNGT00`000000IVIV06IVIP0;06IVIP800000:`1CDe<20000
00d0IVIV00<0000007UiN@1iNGT01`1iNGT00`000000S8b<08b<S00608b<S0030000002OWil0WinO
00H0WinO00<000000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP060<K6aP030000003IfMT0fMWI
00H0fMWI00<000000>c/k03/k>`0203/k>`00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01h0oooo000e0?ooo`030000003oool0oooo0180oooo0P000?oE0?ooo`80O`1o0`3oool00`000?l0
oooo0?ooo`0:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030000o`00ool00?oo0080o`000P00oomX0?oooaP00000J@3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01T0oooo00<000000>c/k03/k>`02@3/k>`00`000000
fMWI0=WIf@070=WIf@0300000036a/H0a/K600D0a/K600<000000;>c/`2c/k<01P2c/k<00`000000
WinO09nOW`0509nOW`030000002<S8`0S8b<00H0S8b<00<0000007UiN@1iNGT0201iNGT00`000000
IVIV06IVIP0:06IVIP800000;P1CDe<00`000000IVIV06IVIP0:06IVIP030000001iNGT0NGUi00P0
NGUi00<0000008b<S02<S8`01P2<S8`00`000000WinO09nOW`0609nOW`030000002c/k<0/k>c00D0
/k>c00<000000<K6aP36a/H01P36a/H00`000000fMWI0=WIf@050=WIf@030000003/k>`0k>c/00T0
k>c/00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01T0
oooo00<000000>c/k03/k>`02P3/k>`00`000000fMWI0=WIf@060=WIf@0300000036a/H0a/K600H0
a/K600<000000;>c/`2c/k<01@2c/k<00`000000WinO09nOW`0609nOW`030000002<S8`0S8b<00H0
S8b<00<0000007UiN@1iNGT0201iNGT00`000000IVIV06IVIP0:06IVIP030000001CDe<0De=C02d0
De=C00<0000006IVIP1VIVH02P1VIVH00`000000NGUi07UiN@0807UiN@030000002<S8`0S8b<00H0
S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c0;>c/`040;>c/`0300000036a/H0a/K600H0
a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k0080>c/k0030000003oool0oooo00P0
oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool03`3oool30000omd0oooo
0P000?l30?ooo`H0000000<0oooo0000003oool0;`3oool00`000000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`00oomR0?ooo`P00000603/k>`800000640oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0H0?ooo`030000003/k>`0k>c/00T0k>c/
00<000000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP060<K6aP030000002c/k<0/k>c00D0/k>c
00<0000009nOW`2OWil01P2OWil00`000000S8b<08b<S00208b<S0<0o`0000<0S8b<0000001iNGT0
201iNGT00`000000IVIV06IVIP0:06IVIP030000001CDe<0De=C02l0De=C00<0000006IVIP1VIVH0
2P1VIVH00`000000NGUi07UiN@0807UiN@030000002<S8`0S8b<00H0S8b<00<0000009nOW`2OWil0
1@2OWil00`000000/k>c0;>c/`060;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT0
1P3IfMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00L0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0H0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT0
1P3IfMT00`000000a/K60<K6aP060<K6aP030000002c/k<0/k>c00D0/k>c00<0000009nOW`2OWil0
1P2OWil00`000000S8b<08b<S00308b<S0<0o`0000<0S8b<0000001iNGT0201iNGT00`000000IVIV
06IVIP0:06IVIP030000001CDe<0De=C02l0De=C00<0000006IVIP1VIVH02P1VIVH00`000000NGUi
07UiN@0807UiN@030000002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01P2OWil00`000000/k>c
0;>c/`050;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT01`3IfMT00`000000k>c/
0>c/k0080>c/k0030000003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool003D0oooo00<0
00000?ooo`3oool03@3oool20000on80oooo00<0003o0?ooo`0000000P00000207l0O`@00000<03o
ool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0HP3o
ool4000002P0k>c/1000001M0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0603o
ool00`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00L0fMWI00<000000<K6aP36a/H01@36
a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00D0WinO00<0000008b<S02<S8`00P2<
S8`50?l000T0NGUi00<0000006IVIP1VIVH02P1VIVH00`000000De=C05=CD`0a05=CD`030000001V
IVH0IVIV00X0IVIV0P00000807UiN@030000002<S8`0S8b<00H0S8b<00<0000009nOW`2OWil01P2O
Wil00`000000/k>c0;>c/`050;>c/`0300000036a/H0a/K600D0a/K600<000000=WIf@3IfMT01P3I
fMT00`000000k>c/0>c/k0090>c/k0030000003oool0oooo00L0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003/k>`0k>c/00X0k>c/00<000000=WIf@3IfMT01P3I
fMT00`000000a/K60<K6aP060<K6aP030000002c/k<0/k>c00D0/k>c00<0000009nOW`2OWil01P2O
Wil00`000000S8b<08b<S00208b<S0D0o`00201iNGT2000000`0IVIV00<0000005=CD`1CDe<0<@1C
De<00`000000IVIV06IVIP0:06IVIP030000001iNGT0NGUi00L0NGUi00<0000008b<S02<S8`01P2<
S8`00`000000WinO09nOW`0509nOW`030000002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01P36
a/H00`000000fMWI0=WIf@060=WIf@030000003/k>`0k>c/00P0k>c/00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0N0?ooo`00=@3oool010000000oooo0?ooo`3oool207l0O`P0oooo0P00
0?oU0?ooo`030000o`000000O`1o00D0O`1o0P00000`0?ooo`030000003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1N0?ooo`@00000<03/k>`6000005L0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0G0?ooo`030000003/k>`0k>c/00T0k>c/00<0
00000=WIf@3IfMT01`3IfMT00`000000a/K60<K6aP050<K6aP030000002c/k<0/k>c00H0/k>c00<0
000009nOW`2OWil01P2OWil010000000S8b<08b<S02<S8`30?l000800?l00P3o000707UiN@030000
001VIVH0IVIV00X0IVIV00<0000005=CD`1CDe<0501CDe<9000001H0De=C0P00000;06IVIP030000
001iNGT0NGUi00L0NGUi00<0000008b<S02<S8`01P2<S8`00`000000WinO09nOW`0509nOW`030000
002c/k<0/k>c00D0/k>c00<000000<K6aP36a/H01@36a/H00`000000fMWI0=WIf@060=WIf@030000
003/k>`0k>c/00T0k>c/00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo01P0oooo00<000000>c/k03/k>`02@3/k>`00`000000fMWI0=WIf@060=WIf@030000
0036a/H0a/K600H0a/K600<000000;>c/`2c/k<01@2c/k<00`000000WinO09nOW`0609nOW`030000
002<S8`0S8b<0080S8b<0`3o0002003o0080o`001P1iNGT00`000000IVIV06IVIP0:06IVIP800000
5P1CDe<9000001H0De=C00<0000006IVIP1VIVH02P1VIVH00`000000NGUi07UiN@0707UiN@030000
002<S8`0S8b<00D0S8b<00<0000009nOW`2OWil01@2OWil00`000000/k>c0;>c/`060;>c/`030000
0036a/H0a/K600D0a/K600<000000=WIf@3IfMT01P3IfMT00`000000k>c/0>c/k0090>c/k0030000
003oool0oooo00H0oooo00<000000?ooo`3oool07P3oool002X0oooo1`0000040?ooo`030000003o
ool0O`1o00D0O`1o0`3oool30000onH0oooo0P0000000`000?l0O`1o07l0O`020?oo00<0O`1o00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`030000o`00ool00?oo0080oooo00<0
003o0?ooo`3oool0F`3oool4000003X0k>c/1000001C0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool05`3oool00`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00L0fMWI00<0
00000<K6aP36a/H01@36a/H00`000000/k>c0;>c/`060;>c/`030000002OWil0WinO00D0WinO00<0
000008b<S02<S8`00P2<S8`20?l000@00?l000<0o`0007UiN@1iNGT0101iNGT00`000000IVIV06IV
IP0906IVIP800000501CDe<3000000T0?clo1000000D05=CD`030000001VIVH0IVIV00T0IVIV00<0
000007UiN@1iNGT01`1iNGT00`000000S8b<08b<S00608b<S0030000002OWil0WinO00D0WinO00<0
00000;>c/`2c/k<01@2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00H0fMWI00<0
00000>c/k03/k>`0203/k>`00`000000oooo0?ooo`070?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0603oool00`000000k>c/0>c/k0090>c/k0030000003IfMT0fMWI00H0fMWI00<0
00000<K6aP36a/H01P36a/H00`000000/k>c0;>c/`050;>c/`030000002OWil0WinO00H0WinO00<0
000008b<S02<S8`00P2<S8`20?l000@00?l000<0o`0007UiN@1iNGT0101iNGT00`000000IVIV06IV
IP0906IVIP030000001CDe<0De=C0180De=C1000000903lo?`@000004`1CDe<2000000/0IVIV00<0
000007UiN@1iNGT01`1iNGT00`000000S8b<08b<S00508b<S0030000002OWil0WinO00D0WinO00<0
00000;>c/`2c/k<01P2c/k<00`000000a/K60<K6aP050<K6aP030000003IfMT0fMWI00H0fMWI00<0
00000>c/k03/k>`0203/k>`00`000000oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo000]
0?ooo`030000003oool0oooo00D0oooo00@0000007l0O`1o07l0O`1o0P3oo`0307l0O`80003oj03o
ool30000000307l0O`000?l0ool000<0ool00P1o07l00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0080oooo0P00ool01@3o0000003o003oo`00ool0003o05`0oooo0P0000120>c/k0<00000
D03oool00`000000oooo0?ooo`0g0?ooo`800000C03oool20?l000@00?l000<0o`000?ooo`3oool0
WP3oool2000003P0oooo0P00001=0?ooo`80o`001000o`000`3o0000oooo0?ooo`2M0?ooo`800000
803oool002d0oooo00<000000?ooo`3oool01@3oool00`000000O`1o07l0O`040?oo0080003ojP3o
ool200000080O`1o00<0ool00000o`000?l00`3oo`0207l0Oc00oooo00D000000?ooo`3oool0oooo
003oo`020?l00004003o00000?l00?l00000o`800?ooEP3oool5000004L0k>c/0P00001>0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0C03oool20?l000800?l000<0o`000?ooo`3o
ool0X03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04d0oooo0P3o0002003o0003
0?l0003oool0oooo09l0oooo00<000000?ooo`3oool07P3oool002d0oooo00<000000?ooo`3oool0
1@3oool207l0O`80ool00`000?l00`3oo`00O`1o07l0O`3Y0?ooo`8000000P1o07l0103oo`00003o
0000o`000?l20?oo0080O`1o<03oool01P000000oooo0?ooo`3oool00?oo0?l000800?l00P000?l0
0`00o`000?oo003oo`1C0?ooo`<00000CP3/k>`3000004/0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0380oooo00@000000?l0003o0000o`00<P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<P3o
ool010000000o`000?l0003o000a0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo000]0?ooo`030000003o
ool0oooo00D0oooo0P1o07l0103oo`00003o0000o`000?l20?oo0080O`1oj@3oool200000080O`1o
00@0ool00000o`000?l0003o0P3oo`0207l0Oc00oooo00@000000?ooo`3oool00?oo0P3o0002003o
00040000o`00o`000?l00?l000800?ooD03oool2000005@0k>c/100000170?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`00;@3oool00`00
0000oooo0?ooo`050?ooo`050000001o07l0O`1o0?oo00000?l00P3oo`0207l0OnX0oooo0`000002
07l0O`040?oo00000?l0ool00?oo0080O`1o00<000000?ooo`3oool0;P3oool2000000050?ooo`00
ool0o`000?l00000o`000`000?l01000o`00o`00003oo`00ooo`0?ooo`800000>@3oooog000003P0
oooom`00000P0?ooo`00;@3oool00`000000oooo0?ooo`050?ooo`040000001o07l0O`1o07l0O`80
ool00`1o07oZ0?ooo`<000000`1o07l20?oo00<0O`1o00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`02003oo`80o`0000@00?l00000o`00o`00o`000`00oooa0?ooo`030000003oool0oooo
0?l0ooooo`3ooomo0?ooo`00:`3oool3000000L0oooo00<000000?ooo`1o07l01@1o07l80?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<0
00001P1o07l200000300oooo00D000000?ooo`3oool0oooo003oo`060?l000800?oolP3oool00`00
0000oooo0?ooo`3o0?ooool0ooooO`3oool002d0oooo00<000000?ooo`3oool01@3oool400000080
O`1ol`00000207l0O`@00000<03oool010000000oooo0?ooo`3oool3003oo`80o`001000ool30?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooooo0?ooogl0oooo003o0?ooofD0
oooo1@000007003ooo@00000o`3ooooo0?oooh40oooo003o0?ooool0ooooo`3ooooo0?ooonL0oooo
003o0?ooool0ooooo`3ooooo0?ooonL0oooo003o0?ooool0ooooo`3ooooo0?ooonL0oooo003o0?oo
ool0ooooo`3ooooo0?ooonL0oooo003o0?ooool0ooooo`3ooooo0?ooonL0oooo003o0?ooool0oooo
o`3ooooo0?ooonL0oooo003o0?ooool0ooooo`3ooooo0?ooonL0oooo003o0?ooool0ooooo`3ooooo
0?ooonL0oooo003o0?ooool0ooooo`3ooooo0?ooonL0oooo0000\
\>"],
  ImageRangeCache->{{{0, 1250.94}, {289.813, 0}} -> {-0.108032, -0.0232607, \
0.00505549, 0.00505549}, {{32, 308}, {282.875, 6.875}} -> {-1.7219, -4.43177, \
0.0134785, 0.0296528}, {{335.625, 611.625}, {282.875, 6.875}} -> {-4.45017, \
-3.7493, 0.0134785, 0.0279111}, {{639.25, 915.25}, {282.875, 6.875}} -> \
{-7.50706, -0.346081, 0.0140355, 0.00907201}, {{942.875, 1218.88}, {282.875, \
6.875}} -> {-10.3468, -0.346082, 0.0140334, 0.00907201}}],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {
              StyleBox["\[Null]",
                ShowStringCharacters->False], 
              TagBox["\<\"Default\"\>",
                HoldForm], 
              TagBox["\<\"Newton\"\>",
                HoldForm], 
              TagBox["\<\"QuasiNewton\"\>",
                HoldForm], 
              TagBox["\<\"FD\"\>",
                HoldForm]},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (StyleForm[ #, ShowStringCharacters -> False]&)], "0.`", 
              "4.9696177196758636`*^-18", "3.009122763698238`*^-21", 
              "2.002901521029204`*^-11"},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], \(X\_1 \[Rule] 1.`\), \(X\_1 \[Rule] 
                0.9999999977999193`\), \(X\_1 \[Rule] 
                1.0000000000278046`\), \(X\_1 \[Rule] 0.9999955249004842`\)},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], \(X\_2 \[Rule] 1.`\), \(X\_2 \[Rule] 
                0.9999999955638855`\), \(X\_2 \[Rule] 
                1.0000000000508806`\), \(X\_2 \[Rule] 0.9999910448214613`\)},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], \("Steps" \[Rule] 15\), \("Steps" \[Rule] 
                22\), \("Steps" \[Rule] 42\), \("Steps" \[Rule] 41\)},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], \("Residual" \[Rule] 21\), \("Function" \[Rule] 
                29\), \("Function" \[Rule] 51\), \("Function" \[Rule] 216\)},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], \("Jacobian" \[Rule] 16\), \("Gradient" \[Rule] 
                29\), \("Gradient" \[Rule] 51\), \("Gradient" \[Rule] 54\)},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], "\<\"\"\>", \("Hessian" \[Rule] 
                23\), "\<\"\"\>", "\<\"\"\>"},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {
              TagBox[
                StyleBox["\<\"\[Null]\"\>",
                  ShowStringCharacters->False],
                (
                StyleForm[ #, ShowStringCharacters -> 
                  False]&)], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left},
          RowLines->{True, False},
          ColumnLines->{True, False}],
        {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {{}, {"Default", "Newton", "QuasiNewton",
           "FD"}}]]]], "Output",
  CellLabel->"Out[43]//TableForm=",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Tsunami\ Modelling\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "As a demonstration for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s general capability for solving PDEs, I will solve a model for tsunami \
propagation.  "
}], "Text"],

Cell["\<\
The simplified model used above is based on the shallow water \
equations (SWE) and is really only appropriate for modelling the open ocean \
propagation of a tsunami.  The SWE model makes the following \
assumptions:\
\>", "Text"],

Cell["Hydrostatic pressure distribution", "BulletedList"],

Cell["Incompressible,homogeneous fluid", "BulletedList"],

Cell["Well-mixed-in-depth flows:uniform vertical mixing", "BulletedList"],

Cell["Small vertical scale relative to horizontal", "BulletedList"],

Cell["\<\
The last assumption is certainly violated when a tsunami nears \
land.\
\>", "Text"],

Cell["\<\
The US (National Oceanic and Atmospheric Administration) NOAA uses \
a model they refer to as MOST (Method of Splitting Tsunami) that uses \
different computations and models for three phases; generation, propagation, \
and inundation.  The propagation phase is computed by solving the SWE on the \
globe.\
\>", "Text"],

Cell["\<\
Here are the shallow water equations in spherical \
coordinates.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(swe = {\[PartialD]\_t h[\[Lambda], \ \[Phi], \ 
                  t] + \(\[PartialD]\_\[Lambda]\((u[\[Lambda], \ \[Phi], \ t]\
\ \ \((h[\[Lambda], \ \[Phi], \ t]\ \ \  - \ b[\[Lambda], \ \[Phi]]\ )\))\) + \
\[PartialD]\_\[Phi]\((v[\[Lambda], \ \[Phi], \ t]\ \ \((h[\[Lambda], \ \
\[Phi], \ t]\ \ \  - \ b[\[Lambda], \ \[Phi]]\ )\) Cos[\[Phi]])\)\)\/\(R\ \
Cos[\[Phi]]\) \[Equal] 
            0, \(\(\[PartialD]\_\[Phi] u[\[Lambda], \ \[Phi], \ \
t]\)\(\ \ \)\(v[\[Lambda], \ \[Phi], \ t]\)\(\ \)\)\/R + \(g\ \(\(\[PartialD]\
\_\[Lambda] h[\[Lambda], \ \[Phi], \ t]\)\(\ \)\)\)\/\(R\ Cos[\[Phi]]\) + \
\[PartialD]\_t u[\[Lambda], \ \[Phi], \ 
                  t] + \(u[\[Lambda], \ \[Phi], \ t]\ \ \(\(\[PartialD]\_\
\[Lambda] u[\[Lambda], \ \[Phi], \ t]\)\(\ \)\)\)\/\(R\ Cos[\[Phi]]\) \
\[Equal] f\ v[\[Lambda], \ \[Phi], \ 
                t]\ , \(\(\[PartialD]\_\[Phi] v[\[Lambda], \ \[Phi], \ t]\)\(\
\ \ \)\(v[\[Lambda], \ \[Phi], \ t]\)\(\ \)\)\/R + \(g\ \(\(\[PartialD]\_\
\[Phi] h[\[Lambda], \ \[Phi], \ t]\)\(\ \)\)\)\/R + \[PartialD]\_t 
                  v[\[Lambda], \ \[Phi], \ 
                  t]\  + \(u[\[Lambda], \ \[Phi], \ t]\ \ \(\(\[PartialD]\_\
\[Lambda] v[\[Lambda], \ \[Phi], \ t]\)\(\ \)\)\)\/\(R\ Cos[\[Phi]]\) \
\[Equal] \(-f\)\ u[\[Lambda], \ \[Phi], \ t]\ };\)\)], "Input",
  CellLabel->"In[21]:="],

Cell["\<\
\[Lambda] is longitude, \[Phi] is latitude, g is gravitational \
acceleration, f is the coriolis force (2 \[Omega] sin \[Phi]) , h is the \
amplitude above mean surface, b is the bottom level (measured from mean \
surface), and u and v are the depth averaged velocities in the \[Lambda] and \
\[Phi] directions.\
\>", "Text"],

Cell["Define some parameters for the simulation. (Units are MKS.)", \
"MathCaption"],

Cell[BoxData[{
    \(\[Lambda]\_min\  = \(-15\)\ \[Degree]\ ; \ \[Lambda]\_max = \ 
      15\ \[Degree]; \[Lambda]\_e\  = \ 0; \[Lambda]\_i = \ 
      2.5\ \[Degree];\), "\[IndentingNewLine]", 
    \(\[Phi]\_min = \ \(-35\)\ \[Degree]; \[Phi]\_max = \ 
      5\ \[Degree]; \[Phi]\_1 = \ \(-10\)\ \[Degree]; \[Phi]\_2 = \ \(-20\)\ \
\[Degree]; \ \[Phi]\_\(\(i\)\(\ \)\) = \ \(-25\)\ \[Degree];\), "\
\[IndentingNewLine]", 
    \(T\  = \ 2\ 3600; nxy\  = \ 50;\), "\[IndentingNewLine]", 
    \(\(b[lambda_, \ 
          phi_]\  := \ \(-4000\) \((1\  - \ 
              s\ Exp[\(-1000\)\ \((\((lambda - \[Lambda]\_i)\)^2\  + \ \((phi \
- \[Phi]\_i)\)^2)\)])\);\)\)}], "Input",
  CellLabel->"In[29]:="],

Cell["\<\
Solve the SWEs starting with an initial disturbance along a line of \
longitude.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Block[{R\  = \ 6378000, \ \[Omega]\  = \ 2\ \[Pi]/\((24\ 3600)\), \ 
          f = \ 2  \[Omega]\ Sin[\[Phi]], \ g\  = \ 9.8, \ 
          s\  = \  .95}, \[IndentingNewLine]sol\  = \ 
          First[h\  /. \ 
              NDSolve[{swe, \ 
                  h[\[Lambda], \ \[Phi], \ 0]\  \[Equal] \ 
                    Exp[\(-2000\)\ \(ldist[{\[Lambda]\_e, \ \[Phi]\_1}, \ {\
\[Lambda]\_e, \ \[Phi]\_2}]\)[{\[Lambda], \ \[Phi]}]^2], \ 
                  u[\[Lambda], \ \[Phi], \ 0]\  \[Equal] \ 0, \ 
                  v[\[Lambda], \ \[Phi], \ 0]\  \[Equal] \ 0, \ 
                  h[\[Lambda], \ \[Phi]\_min, \ 
                      t]\  \[Equal] \ \ h[\[Lambda], \ \[Phi]\_max, \ t], \ 
                  h[\[Lambda]\_min, \ \[Phi], \ 
                      t]\  \[Equal] \ \ h[\ \[Lambda]\_max, \ \[Phi], \ t]}, 
                h, \ {\[Lambda], \ \[Lambda]\_min, \ \ \[Lambda]\_max}, \ {\
\[Phi], \[Phi]\_min, \ \[Phi]\_max}, \ {t, 0, T}, \ 
                DependentVariables \[Rule] {h, u, v}, \ 
                Method \[Rule] {"\<MethodOfLines\>", "\<SpatialDiscretization\
\>" \[Rule] {"\<TensorProductGrid\>", \ "\<MinPoints\>" \[Rule] {nxy, 
                            nxy}, \ "\<MaxPoints\>" \[Rule] {nxy, 
                            nxy}, \ "\<DifferenceOrder\>" \[Rule] \
"\<Pseudospectral\>"}}]]]]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(8.451999999999998`\ Second\), ",", 
        TagBox[\(InterpolatingFunction[{{"...", \(-0.2617993877991494`\), 
                0.2617993877991494`, 
                "..."}, {"...", \(-0.6108652381980153`\), 
                0.08726646259971647`, "..."}, {0.`, 7200.`}}, "<>"]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["There are a few things worth noting about what I just did:", "Text"],

Cell["\<\
\[Bullet] The PDE was entered as an equation.  \
\>", "Text"],

Cell["\<\
\[Bullet] The solution was computed quickly.\
\>", "Text"],

Cell[TextData[{
  "\[Bullet] The solution is given as a piecewise interpolant that can be \
used in other ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands: "
}], "Text"],

Cell["Make a sequence of plots showing the wave height.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Plot3D[
        sol[\[Lambda], \ \[Phi], \ 
          t], \ {\[Lambda], \ \[Lambda]\_min, \ \[Lambda]\_max}, \ {\[Phi], \ \
\[Phi]\_min, \ \[Phi]\_max}, \ PlotRange \[Rule] {\(-1\), 1}, \ 
        PlotPoints \[Rule] nxy, \ Mesh \[Rule] False], {t, 0, T, \ 
        360}]\)], "Input",
  CellLabel->"In[34]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Mtetra
.59604 .63937 .60194 .6454 .6135 .64214 .60764 .63608 Mtetra
.60764 .63608 .6135 .64214 .62511 .63886 .61928 .63278 Mtetra
.61928 .63278 .62511 .63886 .63677 .63557 .63097 .62947 Mtetra
.63097 .62947 .63677 .63557 .64848 .63227 .64272 .62614 Mtetra
.64272 .62614 .64848 .63227 .66023 .62896 .65451 .6228 Mtetra
.65451 .6228 .66023 .62896 .67204 .62563 .66635 .61945 Mtetra
.66635 .61945 .67204 .62563 .6839 .62229 .67824 .61608 Mtetra
.67824 .61608 .6839 .62229 .6958 .61893 .69018 .6127 Mtetra
.69018 .6127 .6958 .61893 .70776 .61556 .70217 .6093 Mtetra
.70217 .6093 .70776 .61556 .71976 .61218 .71421 .60589 Mtetra
.71421 .60589 .71976 .61218 .73182 .60878 .7263 .60246 Mtetra
.7263 .60246 .73182 .60878 .74393 .60536 .73845 .59902 Mtetra
.73845 .59902 .74393 .60536 .75609 .60193 .75064 .59557 Mtetra
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62666 Mtetra
.61341 .62666 .61928 .63278 .63097 .62947 .62514 .62332 Mtetra
.62514 .62332 .63097 .62947 .64272 .62614 .63691 .61997 Mtetra
.63691 .61997 .64272 .62614 .65451 .6228 .64873 .6166 Mtetra
.64873 .6166 .65451 .6228 .66635 .61945 .66061 .61322 Mtetra
.66061 .61322 .66635 .61945 .67824 .61608 .67253 .60982 Mtetra
.67253 .60982 .67824 .61608 .69018 .6127 .68451 .60641 Mtetra
.68451 .60641 .69018 .6127 .70217 .6093 .69653 .60299 Mtetra
.69653 .60299 .70217 .6093 .71421 .60589 .70861 .59955 Mtetra
.70861 .59955 .71421 .60589 .7263 .60246 .72074 .5961 Mtetra
.72074 .5961 .7263 .60246 .73845 .59902 .73292 .59263 Mtetra
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Mtetra
.59578 .62383 .60173 .62998 .61341 .62666 .60749 .62048 Mtetra
.60749 .62048 .61341 .62666 .62514 .62332 .61925 .61712 Mtetra
.61925 .61712 .62514 .62332 .63691 .61997 .63106 .61374 Mtetra
.63106 .61374 .63691 .61997 .64873 .6166 .64292 .61035 Mtetra
.64292 .61035 .64873 .6166 .66061 .61322 .65482 .60694 Mtetra
.65482 .60694 .66061 .61322 .67253 .60982 .66678 .60352 Mtetra
.66678 .60352 .67253 .60982 .68451 .60641 .67879 .60008 Mtetra
.67879 .60008 .68451 .60641 .69653 .60299 .69085 .59663 Mtetra
.69085 .59663 .69653 .60299 .70861 .59955 .70297 .59317 Mtetra
.70297 .59317 .70861 .59955 .72074 .5961 .71513 .58968 Mtetra
.71513 .58968 .72074 .5961 .73292 .59263 .72735 .58619 Mtetra
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Mtetra
.60153 .61426 .60749 .62048 .61925 .61712 .61332 .61087 Mtetra
.61332 .61087 .61925 .61712 .63106 .61374 .62516 .60746 Mtetra
.62516 .60746 .63106 .61374 .64292 .61035 .63705 .60405 Mtetra
.63705 .60405 .64292 .61035 .65482 .60694 .649 .60061 Mtetra
.649 .60061 .65482 .60694 .66678 .60352 .66099 .59716 Mtetra
.66099 .59716 .66678 .60352 .67879 .60008 .67303 .5937 Mtetra
.67303 .5937 .67879 .60008 .69085 .59663 .68513 .59022 Mtetra
.68513 .59022 .69085 .59663 .70297 .59317 .69728 .58673 Mtetra
.69728 .58673 .70297 .59317 .71513 .58968 .70948 .58322 Mtetra
.70948 .58322 .71513 .58968 .72735 .58619 .72173 .5797 Mtetra
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Mtetra
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Mtetra
.59552 .60799 .60153 .61426 .61332 .61087 .60734 .60457 Mtetra
.60734 .60457 .61332 .61087 .62516 .60746 .61922 .60114 Mtetra
.61922 .60114 .62516 .60746 .63705 .60405 .63114 .59769 Mtetra
.63114 .59769 .63705 .60405 .649 .60061 .64312 .59423 Mtetra
.64312 .59423 .649 .60061 .66099 .59716 .65515 .59076 Mtetra
.65515 .59076 .66099 .59716 .67303 .5937 .66723 .58727 Mtetra
.66723 .58727 .67303 .5937 .68513 .59022 .67936 .58376 Mtetra
.67936 .58376 .68513 .59022 .69728 .58673 .69154 .58024 Mtetra
.69154 .58024 .69728 .58673 .70948 .58322 .70378 .5767 Mtetra
.70378 .5767 .70948 .58322 .72173 .5797 .71607 .57315 Mtetra
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56959 Mtetra
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Mtetra
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Mtetra
.58946 .60167 .59552 .60799 .60734 .60457 .60132 .59823 Mtetra
.60132 .59823 .60734 .60457 .61922 .60114 .61323 .59477 Mtetra
.61323 .59477 .61922 .60114 .63114 .59769 .62519 .59129 Mtetra
.62519 .59129 .63114 .59769 .64312 .59423 .6372 .5878 Mtetra
.6372 .5878 .64312 .59423 .65515 .59076 .64926 .5843 Mtetra
.64926 .5843 .65515 .59076 .66723 .58727 .66138 .58078 Mtetra
.66138 .58078 .66723 .58727 .67936 .58376 .67354 .57725 Mtetra
.67354 .57725 .67936 .58376 .69154 .58024 .68576 .5737 Mtetra
.68576 .5737 .69154 .58024 .70378 .5767 .69804 .57014 Mtetra
.69804 .57014 .70378 .5767 .71607 .57315 .71036 .56656 Mtetra
.71036 .56656 .71607 .57315 .72841 .56959 .72274 .56296 Mtetra
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59876 Mtetra
.57151 .59876 .57765 .6051 .58946 .60167 .58335 .5953 Mtetra
.58335 .5953 .58946 .60167 .60132 .59823 .59525 .59183 Mtetra
.59525 .59183 .60132 .59823 .61323 .59477 .60719 .58834 Mtetra
.60719 .58834 .61323 .59477 .62519 .59129 .61918 .58484 Mtetra
.61918 .58484 .62519 .59129 .6372 .5878 .63123 .58132 Mtetra
.63123 .58132 .6372 .5878 .64926 .5843 .64333 .57779 Mtetra
.64333 .57779 .64926 .5843 .66138 .58078 .65548 .57425 Mtetra
.65548 .57425 .66138 .58078 .67354 .57725 .66768 .57068 Mtetra
.66768 .57068 .67354 .57725 .68576 .5737 .67994 .56711 Mtetra
.67994 .56711 .68576 .5737 .69804 .57014 .69225 .56351 Mtetra
.69225 .56351 .69804 .57014 .71036 .56656 .70461 .55991 Mtetra
.70461 .55991 .71036 .56656 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Mtetra
.56532 .59236 .57151 .59876 .58335 .5953 .5772 .58888 Mtetra
.5772 .58888 .58335 .5953 .59525 .59183 .58913 .58538 Mtetra
.58913 .58538 .59525 .59183 .60719 .58834 .6011 .58187 Mtetra
.6011 .58187 .60719 .58834 .61918 .58484 .61313 .57834 Mtetra
.61313 .57834 .61918 .58484 .63123 .58132 .62521 .57479 Mtetra
.62521 .57479 .63123 .58132 .64333 .57779 .63735 .57123 Mtetra
.63735 .57123 .64333 .57779 .65548 .57425 .64953 .56766 Mtetra
.64953 .56766 .65548 .57425 .66768 .57068 .66177 .56407 Mtetra
.66177 .56407 .66768 .57068 .67994 .56711 .67407 .56046 Mtetra
.67407 .56046 .67994 .56711 .69225 .56351 .68641 .55684 Mtetra
.68641 .55684 .69225 .56351 .70461 .55991 .69881 .5532 Mtetra
.69881 .5532 .70461 .55991 .71703 .55628 .71127 .54955 Mtetra
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Mtetra
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58592 Mtetra
.55909 .58592 .56532 .59236 .5772 .58888 .571 .58241 Mtetra
.571 .58241 .5772 .58888 .58913 .58538 .58296 .57888 Mtetra
.58296 .57888 .58913 .58538 .6011 .58187 .59497 .57534 Mtetra
.59497 .57534 .6011 .58187 .61313 .57834 .60703 .57178 Mtetra
.60703 .57178 .61313 .57834 .62521 .57479 .61915 .56821 Mtetra
.61915 .56821 .62521 .57479 .63735 .57123 .63132 .56462 Mtetra
.63132 .56462 .63735 .57123 .64953 .56766 .64354 .56102 Mtetra
.64354 .56102 .64953 .56766 .66177 .56407 .65582 .5574 Mtetra
.65582 .5574 .66177 .56407 .67407 .56046 .66815 .55376 Mtetra
.66815 .55376 .67407 .56046 .68641 .55684 .68053 .55011 Mtetra
.68053 .55011 .68641 .55684 .69881 .5532 .69297 .54644 Mtetra
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Mtetra
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Mtetra
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Mtetra
.52907 .58646 .53542 .5929 .54723 .58942 .54091 .58295 Mtetra
.54091 .58295 .54723 .58942 .55909 .58592 .5528 .57943 Mtetra
.5528 .57943 .55909 .58592 .571 .58241 .56474 .57589 Mtetra
.56474 .57589 .571 .58241 .58296 .57888 .57674 .57233 Mtetra
.57674 .57233 .58296 .57888 .59497 .57534 .58878 .56876 Mtetra
.58878 .56876 .59497 .57534 .60703 .57178 .60088 .56517 Mtetra
.60088 .56517 .60703 .57178 .61915 .56821 .61304 .56157 Mtetra
.61304 .56157 .61915 .56821 .63132 .56462 .62524 .55796 Mtetra
.62524 .55796 .63132 .56462 .64354 .56102 .6375 .55432 Mtetra
.6375 .55432 .64354 .56102 .65582 .5574 .64981 .55067 Mtetra
.64981 .55067 .65582 .5574 .66815 .55376 .66218 .54701 Mtetra
.66218 .54701 .66815 .55376 .68053 .55011 .6746 .54333 Mtetra
.6746 .54333 .68053 .55011 .69297 .54644 .68707 .53963 Mtetra
.68707 .53963 .69297 .54644 .70546 .54276 .69961 .53592 Mtetra
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53219 Mtetra
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Mtetra
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57997 Mtetra
.52266 .57997 .52907 .58646 .54091 .58295 .53454 .57643 Mtetra
.53454 .57643 .54091 .58295 .5528 .57943 .54646 .57288 Mtetra
.54646 .57288 .5528 .57943 .56474 .57589 .55844 .56931 Mtetra
.55844 .56931 .56474 .57589 .57674 .57233 .57047 .56573 Mtetra
.57047 .56573 .57674 .57233 .58878 .56876 .58255 .56213 Mtetra
.58255 .56213 .58878 .56876 .60088 .56517 .59469 .55851 Mtetra
.59469 .55851 .60088 .56517 .61304 .56157 .60687 .55488 Mtetra
.60687 .55488 .61304 .56157 .62524 .55796 .61911 .55124 Mtetra
.61911 .55124 .62524 .55796 .6375 .55432 .63141 .54757 Mtetra
.63141 .54757 .6375 .55432 .64981 .55067 .64376 .54389 Mtetra
.64376 .54389 .64981 .55067 .66218 .54701 .65616 .5402 Mtetra
.65616 .5402 .66218 .54701 .6746 .54333 .66862 .53649 Mtetra
.66862 .53649 .6746 .54333 .68707 .53963 .68113 .53276 Mtetra
.68113 .53276 .68707 .53963 .69961 .53592 .6937 .52902 Mtetra
.6937 .52902 .69961 .53592 .71219 .53219 .70633 .52525 Mtetra
.70633 .52525 .71219 .53219 .72483 .52844 .71901 .52148 Mtetra
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Mtetra
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Mtetra
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Mtetra
.49255 .58051 .49907 .587 .51084 .58349 .50435 .57698 Mtetra
.50435 .57698 .51084 .58349 .52266 .57997 .51621 .57343 Mtetra
.51621 .57343 .52266 .57997 .53454 .57643 .52812 .56986 Mtetra
.52812 .56986 .53454 .57643 .54646 .57288 .54008 .56628 Mtetra
.54008 .56628 .54646 .57288 .55844 .56931 .55209 .56268 Mtetra
.55209 .56268 .55844 .56931 .57047 .56573 .56415 .55907 Mtetra
.56415 .55907 .57047 .56573 .58255 .56213 .57627 .55544 Mtetra
.57627 .55544 .58255 .56213 .59469 .55851 .58844 .5518 Mtetra
.58844 .5518 .59469 .55851 .60687 .55488 .60066 .54814 Mtetra
.60066 .54814 .60687 .55488 .61911 .55124 .61294 .54446 Mtetra
.61294 .54446 .61911 .55124 .63141 .54757 .62527 .54077 Mtetra
.62527 .54077 .63141 .54757 .64376 .54389 .63765 .53706 Mtetra
.63765 .53706 .64376 .54389 .65616 .5402 .65009 .53333 Mtetra
.65009 .53333 .65616 .5402 .66862 .53649 .66259 .52959 Mtetra
.66259 .52959 .66862 .53649 .68113 .53276 .67514 .52583 Mtetra
.67514 .52583 .68113 .53276 .6937 .52902 .68775 .52206 Mtetra
.68775 .52206 .6937 .52902 .70633 .52525 .70041 .51827 Mtetra
.70041 .51827 .70633 .52525 .71901 .52148 .71313 .51446 Mtetra
.71313 .51446 .71901 .52148 .73175 .51768 .72591 .51063 Mtetra
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Mtetra
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Mtetra
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Mtetra
.47419 .57752 .48079 .58403 .49255 .58051 .48598 .57397 Mtetra
.48598 .57397 .49255 .58051 .50435 .57698 .49781 .57041 Mtetra
.49781 .57041 .50435 .57698 .51621 .57343 .5097 .56683 Mtetra
.5097 .56683 .51621 .57343 .52812 .56986 .52164 .56324 Mtetra
.52164 .56324 .52812 .56986 .54008 .56628 .53364 .55963 Mtetra
.53364 .55963 .54008 .56628 .55209 .56268 .54568 .556 Mtetra
.54568 .556 .55209 .56268 .56415 .55907 .55778 .55236 Mtetra
.55778 .55236 .56415 .55907 .57627 .55544 .56993 .5487 Mtetra
.56993 .5487 .57627 .55544 .58844 .5518 .58214 .54503 Mtetra
.58214 .54503 .58844 .5518 .60066 .54814 .5944 .54134 Mtetra
.5944 .54134 .60066 .54814 .61294 .54446 .60671 .53763 Mtetra
.60671 .53763 .61294 .54446 .62527 .54077 .61908 .53391 Mtetra
.61908 .53391 .62527 .54077 .63765 .53706 .6315 .53017 Mtetra
.6315 .53017 .63765 .53706 .65009 .53333 .64398 .52641 Mtetra
.64398 .52641 .65009 .53333 .66259 .52959 .65651 .52264 Mtetra
.65651 .52264 .66259 .52959 .67514 .52583 .6691 .51885 Mtetra
.6691 .51885 .67514 .52583 .68775 .52206 .68175 .51504 Mtetra
.68175 .51504 .68775 .52206 .70041 .51827 .69445 .51122 Mtetra
.69445 .51122 .70041 .51827 .71313 .51446 .70721 .50738 Mtetra
.70721 .50738 .71313 .51446 .72591 .51063 .72003 .50352 Mtetra
.72003 .50352 .72591 .51063 .73875 .50679 .7329 .49965 Mtetra
.7329 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Mtetra
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Mtetra
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57096 Mtetra
.46753 .57096 .47419 .57752 .48598 .57397 .47935 .56738 Mtetra
.47935 .56738 .48598 .57397 .49781 .57041 .49122 .56379 Mtetra
.49122 .56379 .49781 .57041 .5097 .56683 .50314 .56018 Mtetra
.50314 .56018 .5097 .56683 .52164 .56324 .51512 .55656 Mtetra
.51512 .55656 .52164 .56324 .53364 .55963 .52715 .55292 Mtetra
.52715 .55292 .53364 .55963 .54568 .556 .53923 .54927 Mtetra
.53923 .54927 .54568 .556 .55778 .55236 .55136 .5456 Mtetra
.655 .751 .92 r
.55136 .5456 .55778 .55236 .56993 .5487 .56355 .54192 Mtetra
.655 .752 .921 r
.56355 .54192 .56993 .5487 .58214 .54503 .57579 .53823 Mtetra
.57579 .53823 .58214 .54503 .5944 .54134 .58808 .53453 Mtetra
.656 .753 .921 r
.58808 .53453 .5944 .54134 .60671 .53763 .60043 .53079 Mtetra
.60043 .53079 .60671 .53763 .61908 .53391 .61284 .52702 Mtetra
.656 .752 .921 r
.61284 .52702 .61908 .53391 .6315 .53017 .6253 .52323 Mtetra
.656 .752 .92 r
.6253 .52323 .6315 .53017 .64398 .52641 .63781 .51944 Mtetra
.63781 .51944 .64398 .52641 .65651 .52264 .65038 .51563 Mtetra
.656 .751 .92 r
.65038 .51563 .65651 .52264 .6691 .51885 .66301 .51181 Mtetra
.66301 .51181 .6691 .51885 .68175 .51504 .6757 .50797 Mtetra
.6757 .50797 .68175 .51504 .69445 .51122 .68844 .50412 Mtetra
.68844 .50412 .69445 .51122 .70721 .50738 .70124 .50024 Mtetra
.70124 .50024 .70721 .50738 .72003 .50352 .7141 .49635 Mtetra
.7141 .49635 .72003 .50352 .7329 .49965 .72701 .49245 Mtetra
.72701 .49245 .7329 .49965 .74584 .49575 .73999 .48852 Mtetra
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Mtetra
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Mtetra
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56793 Mtetra
.44902 .56793 .45576 .57452 .46753 .57096 .46082 .56434 Mtetra
.46082 .56434 .46753 .57096 .47935 .56738 .47267 .56074 Mtetra
.47267 .56074 .47935 .56738 .49122 .56379 .48457 .55712 Mtetra
.48457 .55712 .49122 .56379 .50314 .56018 .49653 .55348 Mtetra
.49653 .55348 .50314 .56018 .51512 .55656 .50854 .54983 Mtetra
.50854 .54983 .51512 .55656 .52715 .55292 .5206 .54616 Mtetra
.655 .751 .92 r
.5206 .54616 .52715 .55292 .53923 .54927 .53272 .54249 Mtetra
.654 .751 .921 r
.53272 .54249 .53923 .54927 .55136 .5456 .54489 .53884 Mtetra
.649 .751 .924 r
.54489 .53884 .55136 .5456 .56355 .54192 .55711 .53532 Mtetra
.641 .755 .931 r
.55711 .53532 .56355 .54192 .57579 .53823 .56939 .53198 Mtetra
.64 .766 .94 r
.56939 .53198 .57579 .53823 .58808 .53453 .58173 .52861 Mtetra
.652 .782 .943 r
.58173 .52861 .58808 .53453 .60043 .53079 .59412 .52485 Mtetra
.666 .787 .938 r
.59412 .52485 .60043 .53079 .61284 .52702 .60656 .52068 Mtetra
.668 .775 .93 r
.60656 .52068 .61284 .52702 .6253 .52323 .61905 .51648 Mtetra
.662 .761 .924 r
.61905 .51648 .6253 .52323 .63781 .51944 .6316 .51247 Mtetra
.658 .754 .921 r
.6316 .51247 .63781 .51944 .65038 .51563 .64421 .50857 Mtetra
.656 .752 .92 r
.64421 .50857 .65038 .51563 .66301 .51181 .65687 .50471 Mtetra
.656 .751 .92 r
.65687 .50471 .66301 .51181 .6757 .50797 .6696 .50084 Mtetra
.6696 .50084 .6757 .50797 .68844 .50412 .68238 .49695 Mtetra
.68238 .49695 .68844 .50412 .70124 .50024 .69522 .49305 Mtetra
.69522 .49305 .70124 .50024 .7141 .49635 .70812 .48912 Mtetra
.70812 .48912 .7141 .49635 .72701 .49245 .72107 .48518 Mtetra
.72107 .48518 .72701 .49245 .73999 .48852 .73409 .48122 Mtetra
.73409 .48122 .73999 .48852 .75302 .48458 .74716 .47725 Mtetra
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Mtetra
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Mtetra
.43044 .5649 .43727 .57151 .44902 .56793 .44222 .56129 Mtetra
.44222 .56129 .44902 .56793 .46082 .56434 .45405 .55768 Mtetra
.45405 .55768 .46082 .56434 .47267 .56074 .46594 .55404 Mtetra
.46594 .55404 .47267 .56074 .48457 .55712 .47788 .55039 Mtetra
.47788 .55039 .48457 .55712 .49653 .55348 .48987 .54673 Mtetra
.48987 .54673 .49653 .55348 .50854 .54983 .50191 .54304 Mtetra
.655 .751 .92 r
.50191 .54304 .50854 .54983 .5206 .54616 .51401 .53936 Mtetra
.652 .751 .922 r
.51401 .53936 .5206 .54616 .53272 .54249 .52616 .53574 Mtetra
.635 .748 .93 r
.52616 .53574 .53272 .54249 .54489 .53884 .53836 .53259 Mtetra
.569 .741 .958 r
.53836 .53259 .54489 .53884 .55711 .53532 .55064 .53088 Mtetra
.375 .721 .989 r
.55064 .53088 .55711 .53532 .56939 .53198 .56301 .53121 Mtetra
.062 .623 .79 r
.56301 .53121 .56939 .53198 .58173 .52861 .57546 .5314 Mtetra
0 0 0 r
.57546 .5314 .58173 .52861 .59412 .52485 .58792 .52762 Mtetra
.49 .885 .72 r
.58792 .52762 .59412 .52485 .60656 .52068 .60035 .51984 Mtetra
.74 .971 .93 r
.60035 .51984 .60656 .52068 .61905 .51648 .61281 .5119 Mtetra
.718 .851 .945 r
.61281 .5119 .61905 .51648 .6316 .51247 .62535 .506 Mtetra
.674 .777 .928 r
.62535 .506 .6316 .51247 .64421 .50857 .63798 .50155 Mtetra
.659 .756 .921 r
.63798 .50155 .64421 .50857 .65687 .50471 .65068 .49756 Mtetra
.656 .752 .92 r
.65068 .49756 .65687 .50471 .6696 .50084 .66344 .49365 Mtetra
.656 .751 .92 r
.66344 .49365 .6696 .50084 .68238 .49695 .67626 .48973 Mtetra
.67626 .48973 .68238 .49695 .69522 .49305 .68914 .48579 Mtetra
.68914 .48579 .69522 .49305 .70812 .48912 .70208 .48183 Mtetra
.70208 .48183 .70812 .48912 .72107 .48518 .71508 .47786 Mtetra
.71508 .47786 .72107 .48518 .73409 .48122 .72814 .47387 Mtetra
.72814 .47387 .73409 .48122 .74716 .47725 .74126 .46986 Mtetra
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Mtetra
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Mtetra
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55823 Mtetra
.42355 .55823 .43044 .5649 .44222 .56129 .43536 .5546 Mtetra
.43536 .5546 .44222 .56129 .45405 .55768 .44723 .55095 Mtetra
.44723 .55095 .45405 .55768 .46594 .55404 .45915 .54729 Mtetra
.45915 .54729 .46594 .55404 .47788 .55039 .47112 .54361 Mtetra
.47112 .54361 .47788 .55039 .48987 .54673 .48315 .53991 Mtetra
.48315 .53991 .48987 .54673 .50191 .54304 .49522 .53621 Mtetra
.654 .751 .921 r
.49522 .53621 .50191 .54304 .51401 .53936 .50735 .53252 Mtetra
.64 .748 .927 r
.50735 .53252 .51401 .53936 .52616 .53574 .51954 .52924 Mtetra
.541 .723 .958 r
.51954 .52924 .52616 .53574 .53836 .53259 .53178 .52815 Mtetra
0 .37 .776 r
.53178 .52815 .53836 .53259 .55064 .53088 .54414 .53377 Mtetra
.777 .318 .157 r
.54414 .53377 .55064 .53088 .56301 .53121 .55672 .54897 Mtetra
.694 .342 .376 r
.55672 .54897 .56301 .53121 .57546 .5314 .56949 .56377 Mtetra
.49 .198 .398 r
.56949 .56377 .57546 .5314 .58792 .52762 .58214 .56 Mtetra
.197 0 .302 r
.58214 .56 .58792 .52762 .60035 .51984 .59446 .53758 Mtetra
0 0 0 r
.59446 .53758 .60035 .51984 .61281 .5119 .60668 .51469 Mtetra
.796 .992 .754 r
.60668 .51469 .61281 .5119 .62535 .506 .6191 .50136 Mtetra
.737 .855 .935 r
.6191 .50136 .62535 .506 .63798 .50155 .63171 .49477 Mtetra
.67 .769 .924 r
.63171 .49477 .63798 .50155 .65068 .49756 .64444 .49039 Mtetra
.657 .753 .921 r
.64444 .49039 .65068 .49756 .66344 .49365 .65724 .4864 Mtetra
.656 .752 .92 r
.65724 .4864 .66344 .49365 .67626 .48973 .6701 .48244 Mtetra
.656 .751 .92 r
.6701 .48244 .67626 .48973 .68914 .48579 .68302 .47847 Mtetra
.68302 .47847 .68914 .48579 .70208 .48183 .696 .47448 Mtetra
.696 .47448 .70208 .48183 .71508 .47786 .70904 .47048 Mtetra
.70904 .47048 .71508 .47786 .72814 .47387 .72214 .46645 Mtetra
.72214 .46645 .72814 .47387 .74126 .46986 .7353 .4624 Mtetra
.7353 .4624 .74126 .46986 .75443 .46583 .74852 .45834 Mtetra
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Mtetra
.40481 .55516 .41179 .56185 .42355 .55823 .41661 .55152 Mtetra
.41661 .55152 .42355 .55823 .43536 .5546 .42845 .54786 Mtetra
.42845 .54786 .43536 .5546 .44723 .55095 .44035 .54418 Mtetra
.44035 .54418 .44723 .55095 .45915 .54729 .45231 .54048 Mtetra
.45231 .54048 .45915 .54729 .47112 .54361 .46431 .53677 Mtetra
.46431 .53677 .47112 .54361 .48315 .53991 .47637 .53305 Mtetra
.47637 .53305 .48315 .53991 .49522 .53621 .48848 .52931 Mtetra
.652 .75 .922 r
.48848 .52931 .49522 .53621 .50735 .53252 .50065 .52565 Mtetra
.622 .742 .933 r
.50065 .52565 .50735 .53252 .51954 .52924 .51286 .52281 Mtetra
.365 .644 .963 r
.51286 .52281 .51954 .52924 .53178 .52815 .52514 .52447 Mtetra
.753 .24 0 r
.52514 .52447 .53178 .52815 .54414 .53377 .53757 .53992 Mtetra
.867 .496 .342 r
.53757 .53992 .54414 .53377 .55672 .54897 .55035 .57537 Mtetra
.767 .445 .442 r
.55035 .57537 .55672 .54897 .56949 .56377 .56347 .61047 Mtetra
.509 .239 .44 r
.56347 .61047 .56949 .56377 .58214 .56 .57636 .60673 Mtetra
.034 0 .288 r
.57636 .60673 .58214 .56 .59446 .53758 .58858 .56401 Mtetra
0 0 0 r
.58858 .56401 .59446 .53758 .60668 .51469 .60055 .52075 Mtetra
.897 .948 .594 r
.60055 .52075 .60668 .51469 .6191 .50136 .6128 .49749 Mtetra
.81 .888 .901 r
.6128 .49749 .6191 .50136 .63171 .49477 .62539 .48806 Mtetra
.685 .777 .921 r
.62539 .48806 .63171 .49477 .64444 .49039 .63814 .48316 Mtetra
.659 .754 .92 r
.63814 .48316 .64444 .49039 .65724 .4864 .65098 .47909 Mtetra
.656 .752 .92 r
.65098 .47909 .65724 .4864 .6701 .48244 .66388 .4751 Mtetra
.656 .751 .92 r
.66388 .4751 .6701 .48244 .68302 .47847 .67684 .47109 Mtetra
.67684 .47109 .68302 .47847 .696 .47448 .68986 .46707 Mtetra
.68986 .46707 .696 .47448 .70904 .47048 .70294 .46303 Mtetra
.70294 .46303 .70904 .47048 .72214 .46645 .71609 .45897 Mtetra
.71609 .45897 .72214 .46645 .7353 .4624 .72929 .45489 Mtetra
.72929 .45489 .7353 .4624 .74852 .45834 .74255 .45079 Mtetra
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Mtetra
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43838 Mtetra
.78271 .43838 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Mtetra
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Mtetra
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54474 Mtetra
.40961 .54474 .41661 .55152 .42845 .54786 .42149 .54105 Mtetra
.42149 .54105 .42845 .54786 .44035 .54418 .43342 .53735 Mtetra
.43342 .53735 .44035 .54418 .45231 .54048 .44541 .53362 Mtetra
.44541 .53362 .45231 .54048 .46431 .53677 .45745 .52988 Mtetra
.45745 .52988 .46431 .53677 .47637 .53305 .46954 .52612 Mtetra
.46954 .52612 .47637 .53305 .48848 .52931 .48169 .52236 Mtetra
.652 .75 .922 r
.48169 .52236 .48848 .52931 .50065 .52565 .49389 .51867 Mtetra
.62 .74 .932 r
.49389 .51867 .50065 .52565 .51286 .52281 .50614 .51586 Mtetra
.362 .626 .954 r
.50614 .51586 .51286 .52281 .52514 .52447 .51844 .51782 Mtetra
.69 .197 0 r
.51844 .51782 .52514 .52447 .53757 .53992 .53087 .53442 Mtetra
.919 .523 .188 r
.53087 .53442 .53757 .53992 .55035 .57537 .54362 .57231 Mtetra
.913 .516 .221 r
.54362 .57231 .55035 .57537 .56347 .61047 .55675 .60988 Mtetra
.444 .872 .926 r
.55675 .60988 .56347 .61047 .57636 .60673 .5697 .60611 Mtetra
.979 .811 .604 r
.5697 .60611 .57636 .60673 .58858 .56401 .58202 .56086 Mtetra
.968 .789 .608 r
.58202 .56086 .58858 .56401 .60055 .52075 .59406 .5151 Mtetra
.922 .806 .714 r
.59406 .5151 .60055 .52075 .6128 .49749 .60637 .49061 Mtetra
.794 .797 .854 r
.60637 .49061 .6128 .49749 .62539 .48806 .619 .48081 Mtetra
.686 .763 .91 r
.619 .48081 .62539 .48806 .63814 .48316 .63179 .47583 Mtetra
.659 .753 .919 r
.63179 .47583 .63814 .48316 .65098 .47909 .64467 .47172 Mtetra
.656 .751 .92 r
.64467 .47172 .65098 .47909 .66388 .4751 .65761 .46769 Mtetra
.65761 .46769 .66388 .4751 .67684 .47109 .67061 .46365 Mtetra
.67061 .46365 .67684 .47109 .68986 .46707 .68368 .45959 Mtetra
.68368 .45959 .68986 .46707 .70294 .46303 .6968 .45551 Mtetra
.6968 .45551 .70294 .46303 .71609 .45897 .70998 .45142 Mtetra
.70998 .45142 .71609 .45897 .72929 .45489 .72323 .4473 Mtetra
.72323 .4473 .72929 .45489 .74255 .45079 .73653 .44317 Mtetra
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Mtetra
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43838 .77683 .43065 Mtetra
.77683 .43065 .78271 .43838 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Mtetra
.39069 .54162 .39778 .54842 .40961 .54474 .40255 .53792 Mtetra
.40255 .53792 .40961 .54474 .42149 .54105 .41447 .5342 Mtetra
.41447 .5342 .42149 .54105 .43342 .53735 .42643 .53046 Mtetra
.42643 .53046 .43342 .53735 .44541 .53362 .43845 .5267 Mtetra
.43845 .5267 .44541 .53362 .45745 .52988 .45052 .52293 Mtetra
.45052 .52293 .45745 .52988 .46954 .52612 .46265 .51914 Mtetra
.46265 .51914 .46954 .52612 .48169 .52236 .47483 .51535 Mtetra
.652 .75 .922 r
.47483 .51535 .48169 .52236 .49389 .51867 .48707 .51163 Mtetra
.62 .74 .932 r
.48707 .51163 .49389 .51867 .50614 .51586 .49935 .50879 Mtetra
.364 .625 .953 r
.49935 .50879 .50614 .51586 .51844 .51782 .51168 .51073 Mtetra
.673 .185 0 r
.51168 .51073 .51844 .51782 .53087 .53442 .5241 .52734 Mtetra
.917 .52 .155 r
.5241 .52734 .53087 .53442 .54362 .57231 .53681 .56528 Mtetra
.913 .512 .142 r
.53681 .56528 .54362 .57231 .55675 .60988 .54989 .60291 Mtetra
.646 .762 .934 r
.54989 .60291 .55675 .60988 .5697 .60611 .56289 .59911 Mtetra
.944 .758 .621 r
.56289 .59911 .5697 .60611 .58202 .56086 .57532 .55373 Mtetra
.945 .757 .617 r
.57532 .55373 .58202 .56086 .59406 .5151 .58749 .50786 Mtetra
.907 .781 .711 r
.58749 .50786 .59406 .5151 .60637 .49061 .59988 .48329 Mtetra
.79 .787 .849 r
.59988 .48329 .60637 .49061 .619 .48081 .61255 .47345 Mtetra
.686 .762 .909 r
.61255 .47345 .619 .48081 .63179 .47583 .62539 .46842 Mtetra
.659 .753 .919 r
.62539 .46842 .63179 .47583 .64467 .47172 .63831 .46428 Mtetra
.656 .751 .92 r
.63831 .46428 .64467 .47172 .65761 .46769 .65129 .46022 Mtetra
.65129 .46022 .65761 .46769 .67061 .46365 .66433 .45614 Mtetra
.66433 .45614 .67061 .46365 .68368 .45959 .67744 .45205 Mtetra
.67744 .45205 .68368 .45959 .6968 .45551 .6906 .44794 Mtetra
.6906 .44794 .6968 .45551 .70998 .45142 .70382 .44381 Mtetra
.70382 .44381 .70998 .45142 .72323 .4473 .71711 .43966 Mtetra
.71711 .43966 .72323 .4473 .73653 .44317 .73046 .43549 Mtetra
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Mtetra
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Mtetra
.38355 .53477 .39069 .54162 .40255 .53792 .39544 .53103 Mtetra
.39544 .53103 .40255 .53792 .41447 .5342 .40739 .52728 Mtetra
.40739 .52728 .41447 .5342 .42643 .53046 .41938 .52351 Mtetra
.41938 .52351 .42643 .53046 .43845 .5267 .43144 .51973 Mtetra
.43144 .51973 .43845 .5267 .45052 .52293 .44355 .51592 Mtetra
.44355 .51592 .45052 .52293 .46265 .51914 .45571 .51211 Mtetra
.45571 .51211 .46265 .51914 .47483 .51535 .46792 .50828 Mtetra
.652 .75 .922 r
.46792 .50828 .47483 .51535 .48707 .51163 .48019 .50453 Mtetra
.62 .74 .932 r
.48019 .50453 .48707 .51163 .49935 .50879 .49251 .50165 Mtetra
.364 .625 .953 r
.49251 .50165 .49935 .50879 .51168 .51073 .50486 .50358 Mtetra
.673 .185 0 r
.50486 .50358 .51168 .51073 .5241 .52734 .51728 .5202 Mtetra
.917 .52 .155 r
.51728 .5202 .5241 .52734 .53681 .56528 .52994 .55819 Mtetra
.913 .512 .142 r
.52994 .55819 .53681 .56528 .54989 .60291 .54298 .59588 Mtetra
.646 .762 .934 r
.54298 .59588 .54989 .60291 .56289 .59911 .55602 .59205 Mtetra
.944 .758 .621 r
.55602 .59205 .56289 .59911 .57532 .55373 .56857 .54655 Mtetra
.945 .757 .617 r
.56857 .54655 .57532 .55373 .58749 .50786 .58086 .50055 Mtetra
.907 .781 .711 r
.58086 .50055 .58749 .50786 .59988 .48329 .59333 .47591 Mtetra
.79 .787 .849 r
.59333 .47591 .59988 .48329 .61255 .47345 .60605 .46602 Mtetra
.686 .762 .909 r
.60605 .46602 .61255 .47345 .62539 .46842 .61893 .46096 Mtetra
.659 .753 .919 r
.61893 .46096 .62539 .46842 .63831 .46428 .63189 .45678 Mtetra
.656 .751 .92 r
.63189 .45678 .63831 .46428 .65129 .46022 .64491 .45268 Mtetra
.64491 .45268 .65129 .46022 .66433 .45614 .658 .44857 Mtetra
.658 .44857 .66433 .45614 .67744 .45205 .67114 .44444 Mtetra
.67114 .44444 .67744 .45205 .6906 .44794 .68435 .4403 Mtetra
.68435 .4403 .6906 .44794 .70382 .44381 .69761 .43613 Mtetra
.69761 .43613 .70382 .44381 .71711 .43966 .71095 .43194 Mtetra
.71095 .43194 .71711 .43966 .73046 .43549 .72434 .42774 Mtetra
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Mtetra
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40207 Mtetra
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Mtetra
.37634 .52786 .38355 .53477 .39544 .53103 .38827 .52409 Mtetra
.38827 .52409 .39544 .53103 .40739 .52728 .40025 .52031 Mtetra
.40025 .52031 .40739 .52728 .41938 .52351 .41228 .51651 Mtetra
.41228 .51651 .41938 .52351 .43144 .51973 .42437 .51269 Mtetra
.42437 .51269 .43144 .51973 .44355 .51592 .43651 .50886 Mtetra
.43651 .50886 .44355 .51592 .45571 .51211 .44871 .50501 Mtetra
.44871 .50501 .45571 .51211 .46792 .50828 .46096 .50115 Mtetra
.652 .75 .922 r
.46096 .50115 .46792 .50828 .48019 .50453 .47326 .49737 Mtetra
.62 .74 .932 r
.47326 .49737 .48019 .50453 .49251 .50165 .48561 .49446 Mtetra
.364 .625 .953 r
.48561 .49446 .49251 .50165 .50486 .50358 .49799 .49636 Mtetra
.673 .185 0 r
.49799 .49636 .50486 .50358 .51728 .5202 .5104 .513 Mtetra
.917 .52 .155 r
.5104 .513 .51728 .5202 .52994 .55819 .52302 .55105 Mtetra
.913 .512 .142 r
.52302 .55105 .52994 .55819 .54298 .59588 .53601 .5888 Mtetra
.646 .762 .934 r
.53601 .5888 .54298 .59588 .55602 .59205 .54908 .58493 Mtetra
.944 .758 .621 r
.54908 .58493 .55602 .59205 .56857 .54655 .56176 .5393 Mtetra
.945 .757 .617 r
.56176 .5393 .56857 .54655 .58086 .50055 .57417 .49318 Mtetra
.907 .781 .711 r
.57417 .49318 .58086 .50055 .59333 .47591 .58672 .46846 Mtetra
.79 .787 .849 r
.58672 .46846 .59333 .47591 .60605 .46602 .5995 .45852 Mtetra
.686 .762 .909 r
.5995 .45852 .60605 .46602 .61893 .46096 .61242 .45343 Mtetra
.659 .753 .919 r
.61242 .45343 .61893 .46096 .63189 .45678 .62542 .44921 Mtetra
.656 .751 .92 r
.62542 .44921 .63189 .45678 .64491 .45268 .63848 .44508 Mtetra
.63848 .44508 .64491 .45268 .658 .44857 .65161 .44094 Mtetra
.65161 .44094 .658 .44857 .67114 .44444 .66479 .43677 Mtetra
.66479 .43677 .67114 .44444 .68435 .4403 .67804 .43259 Mtetra
.67804 .43259 .68435 .4403 .69761 .43613 .69135 .42838 Mtetra
.69135 .42838 .69761 .43613 .71095 .43194 .70472 .42416 Mtetra
.70472 .42416 .71095 .43194 .72434 .42774 .71816 .41992 Mtetra
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Mtetra
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40207 .80014 .39403 Mtetra
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Mtetra
.33352 .53219 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Mtetra
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .52089 Mtetra
.36908 .52089 .37634 .52786 .38827 .52409 .38104 .5171 Mtetra
.38104 .5171 .38827 .52409 .40025 .52031 .39305 .51328 Mtetra
.39305 .51328 .40025 .52031 .41228 .51651 .40512 .50945 Mtetra
.40512 .50945 .41228 .51651 .42437 .51269 .41724 .5056 Mtetra
.41724 .5056 .42437 .51269 .43651 .50886 .42941 .50174 Mtetra
.42941 .50174 .43651 .50886 .44871 .50501 .44164 .49785 Mtetra
.44164 .49785 .44871 .50501 .46096 .50115 .45393 .49396 Mtetra
.652 .75 .922 r
.45393 .49396 .46096 .50115 .47326 .49737 .46627 .49015 Mtetra
.62 .74 .932 r
.46627 .49015 .47326 .49737 .48561 .49446 .47866 .48721 Mtetra
.364 .625 .953 r
.47866 .48721 .48561 .49446 .49799 .49636 .49106 .48909 Mtetra
.673 .185 0 r
.49106 .48909 .49799 .49636 .5104 .513 .50346 .50573 Mtetra
.917 .52 .155 r
.50346 .50573 .5104 .513 .52302 .55105 .51603 .54384 Mtetra
.913 .512 .142 r
.51603 .54384 .52302 .55105 .53601 .5888 .52897 .58165 Mtetra
.646 .762 .934 r
.52897 .58165 .53601 .5888 .54908 .58493 .54209 .57775 Mtetra
.944 .758 .621 r
.54209 .57775 .54908 .58493 .56176 .5393 .5549 .53199 Mtetra
.945 .757 .617 r
.5549 .53199 .56176 .5393 .57417 .49318 .56743 .48574 Mtetra
.907 .781 .711 r
.56743 .48574 .57417 .49318 .58672 .46846 .58005 .46095 Mtetra
.79 .787 .849 r
.58005 .46095 .58672 .46846 .5995 .45852 .59288 .45096 Mtetra
.686 .762 .909 r
.59288 .45096 .5995 .45852 .61242 .45343 .60585 .44583 Mtetra
.659 .753 .919 r
.60585 .44583 .61242 .45343 .62542 .44921 .61889 .44158 Mtetra
.656 .751 .92 r
.61889 .44158 .62542 .44921 .63848 .44508 .63199 .43741 Mtetra
.63199 .43741 .63848 .44508 .65161 .44094 .64516 .43323 Mtetra
.64516 .43323 .65161 .44094 .66479 .43677 .65839 .42903 Mtetra
.65839 .42903 .66479 .43677 .67804 .43259 .67168 .42481 Mtetra
.67168 .42481 .67804 .43259 .69135 .42838 .68503 .42057 Mtetra
.68503 .42057 .69135 .42838 .70472 .42416 .69845 .41631 Mtetra
.69845 .41631 .70472 .42416 .71816 .41992 .71193 .41203 Mtetra
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Mtetra
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52525 Mtetra
.32609 .52525 .33352 .53219 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Mtetra
.34981 .51768 .35717 .52467 .36908 .52089 .36175 .51387 Mtetra
.36175 .51387 .36908 .52089 .38104 .5171 .37374 .51004 Mtetra
.37374 .51004 .38104 .5171 .39305 .51328 .38579 .5062 Mtetra
.38579 .5062 .39305 .51328 .40512 .50945 .39789 .50233 Mtetra
.39789 .50233 .40512 .50945 .41724 .5056 .41005 .49845 Mtetra
.41005 .49845 .41724 .5056 .42941 .50174 .42226 .49455 Mtetra
.42226 .49455 .42941 .50174 .44164 .49785 .43452 .49064 Mtetra
.43452 .49064 .44164 .49785 .45393 .49396 .44685 .48671 Mtetra
.652 .75 .922 r
.44685 .48671 .45393 .49396 .46627 .49015 .45922 .48286 Mtetra
.62 .74 .932 r
.45922 .48286 .46627 .49015 .47866 .48721 .47164 .4799 Mtetra
.364 .625 .953 r
.47164 .4799 .47866 .48721 .49106 .48909 .48407 .48176 Mtetra
.673 .185 0 r
.48407 .48176 .49106 .48909 .50346 .50573 .49647 .4984 Mtetra
.917 .52 .155 r
.49647 .4984 .50346 .50573 .51603 .54384 .50898 .53657 Mtetra
.913 .512 .142 r
.50898 .53657 .51603 .54384 .52897 .58165 .52188 .57443 Mtetra
.646 .762 .934 r
.52188 .57443 .52897 .58165 .54209 .57775 .53503 .5705 Mtetra
.944 .758 .621 r
.53503 .5705 .54209 .57775 .5549 .53199 .54797 .52461 Mtetra
.945 .757 .617 r
.54797 .52461 .5549 .53199 .56743 .48574 .56063 .47824 Mtetra
.907 .781 .711 r
.56063 .47824 .56743 .48574 .58005 .46095 .57333 .45337 Mtetra
.79 .787 .849 r
.57333 .45337 .58005 .46095 .59288 .45096 .58621 .44334 Mtetra
.686 .762 .909 r
.58621 .44334 .59288 .45096 .60585 .44583 .59922 .43817 Mtetra
.659 .753 .919 r
.59922 .43817 .60585 .44583 .61889 .44158 .6123 .43388 Mtetra
.656 .751 .92 r
.6123 .43388 .61889 .44158 .63199 .43741 .62545 .42968 Mtetra
.62545 .42968 .63199 .43741 .64516 .43323 .63866 .42546 Mtetra
.63866 .42546 .64516 .43323 .65839 .42903 .65193 .42123 Mtetra
.65193 .42123 .65839 .42903 .67168 .42481 .66526 .41697 Mtetra
.66526 .41697 .67168 .42481 .68503 .42057 .67866 .41269 Mtetra
.67866 .41269 .68503 .42057 .69845 .41631 .69212 .40839 Mtetra
.69212 .40839 .69845 .41631 .71193 .41203 .70564 .40407 Mtetra
.70564 .40407 .71193 .41203 .72548 .40773 .71923 .39974 Mtetra
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Mtetra
.35437 .50679 .36175 .51387 .37374 .51004 .36639 .50293 Mtetra
.36639 .50293 .37374 .51004 .38579 .5062 .37847 .49905 Mtetra
.37847 .49905 .38579 .5062 .39789 .50233 .39061 .49515 Mtetra
.39061 .49515 .39789 .50233 .41005 .49845 .4028 .49124 Mtetra
.4028 .49124 .41005 .49845 .42226 .49455 .41504 .48731 Mtetra
.41504 .48731 .42226 .49455 .43452 .49064 .42734 .48336 Mtetra
.42734 .48336 .43452 .49064 .44685 .48671 .4397 .4794 Mtetra
.652 .75 .922 r
.4397 .4794 .44685 .48671 .45922 .48286 .45211 .47552 Mtetra
.62 .74 .932 r
.45211 .47552 .45922 .48286 .47164 .4799 .46457 .47252 Mtetra
.364 .625 .953 r
.46457 .47252 .47164 .4799 .48407 .48176 .47702 .47436 Mtetra
.673 .185 0 r
.47702 .47436 .48407 .48176 .49647 .4984 .48941 .49101 Mtetra
.917 .52 .155 r
.48941 .49101 .49647 .4984 .50898 .53657 .50187 .52923 Mtetra
.913 .512 .142 r
.50187 .52923 .50898 .53657 .52188 .57443 .51472 .56716 Mtetra
.646 .762 .934 r
.51472 .56716 .52188 .57443 .53503 .5705 .52792 .56319 Mtetra
.944 .758 .621 r
.52792 .56319 .53503 .5705 .54797 .52461 .54098 .51717 Mtetra
.945 .757 .617 r
.54098 .51717 .54797 .52461 .56063 .47824 .55377 .47068 Mtetra
.907 .781 .711 r
.55377 .47068 .56063 .47824 .57333 .45337 .56655 .44573 Mtetra
.79 .787 .849 r
.56655 .44573 .57333 .45337 .58621 .44334 .57949 .43565 Mtetra
.686 .762 .909 r
.57949 .43565 .58621 .44334 .59922 .43817 .59253 .43044 Mtetra
.659 .753 .919 r
.59253 .43044 .59922 .43817 .6123 .43388 .60566 .42612 Mtetra
.656 .751 .92 r
.60566 .42612 .6123 .43388 .62545 .42968 .61885 .42188 Mtetra
.61885 .42188 .62545 .42968 .63866 .42546 .6321 .41762 Mtetra
.6321 .41762 .63866 .42546 .65193 .42123 .64541 .41335 Mtetra
.64541 .41335 .65193 .42123 .66526 .41697 .65879 .40906 Mtetra
.65879 .40906 .66526 .41697 .67866 .41269 .67223 .40474 Mtetra
.67223 .40474 .67866 .41269 .69212 .40839 .68573 .4004 Mtetra
.68573 .4004 .69212 .40839 .70564 .40407 .6993 .39605 Mtetra
.6993 .39605 .70564 .40407 .71923 .39974 .71294 .39167 Mtetra
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Mtetra
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Mtetra
.34692 .49965 .35437 .50679 .36639 .50293 .35898 .49575 Mtetra
.35898 .49575 .36639 .50293 .37847 .49905 .37109 .49184 Mtetra
.37109 .49184 .37847 .49905 .39061 .49515 .38326 .48791 Mtetra
.38326 .48791 .39061 .49515 .4028 .49124 .39549 .48397 Mtetra
.39549 .48397 .4028 .49124 .41504 .48731 .40777 .48 Mtetra
.40777 .48 .41504 .48731 .42734 .48336 .4201 .47602 Mtetra
.4201 .47602 .42734 .48336 .4397 .4794 .4325 .47203 Mtetra
.652 .75 .922 r
.4325 .47203 .4397 .4794 .45211 .47552 .44495 .46811 Mtetra
.62 .74 .932 r
.44495 .46811 .45211 .47552 .46457 .47252 .45743 .46508 Mtetra
.364 .625 .953 r
.45743 .46508 .46457 .47252 .47702 .47436 .46991 .4669 Mtetra
.673 .185 0 r
.46991 .4669 .47702 .47436 .48941 .49101 .48229 .48356 Mtetra
.917 .52 .155 r
.48229 .48356 .48941 .49101 .50187 .52923 .4947 .52183 Mtetra
.913 .512 .142 r
.4947 .52183 .50187 .52923 .51472 .56716 .5075 .55982 Mtetra
.646 .762 .934 r
.5075 .55982 .51472 .56716 .52792 .56319 .52074 .55581 Mtetra
.944 .758 .621 r
.52074 .55581 .52792 .56319 .54098 .51717 .53393 .50967 Mtetra
.945 .757 .617 r
.53393 .50967 .54098 .51717 .55377 .47068 .54684 .46305 Mtetra
.907 .781 .711 r
.54684 .46305 .55377 .47068 .56655 .44573 .55972 .43802 Mtetra
.79 .787 .849 r
.55972 .43802 .56655 .44573 .57949 .43565 .5727 .4279 Mtetra
.686 .762 .909 r
.5727 .4279 .57949 .43565 .59253 .43044 .58579 .42265 Mtetra
.659 .753 .919 r
.58579 .42265 .59253 .43044 .60566 .42612 .59896 .41829 Mtetra
.656 .751 .92 r
.59896 .41829 .60566 .42612 .61885 .42188 .61219 .41401 Mtetra
.61219 .41401 .61885 .42188 .6321 .41762 .62548 .40972 Mtetra
.62548 .40972 .6321 .41762 .64541 .41335 .63884 .40541 Mtetra
.63884 .40541 .64541 .41335 .65879 .40906 .65226 .40107 Mtetra
.65226 .40107 .65879 .40906 .67223 .40474 .66574 .39672 Mtetra
.66574 .39672 .67223 .40474 .68573 .4004 .67929 .39235 Mtetra
.67929 .39235 .68573 .4004 .6993 .39605 .69291 .38795 Mtetra
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Mtetra
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Mtetra
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Mtetra
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Mtetra
.33941 .49245 .34692 .49965 .35898 .49575 .3515 .48852 Mtetra
.3515 .48852 .35898 .49575 .37109 .49184 .36365 .48458 Mtetra
.36365 .48458 .37109 .49184 .38326 .48791 .37585 .48061 Mtetra
.37585 .48061 .38326 .48791 .39549 .48397 .38811 .47663 Mtetra
.38811 .47663 .39549 .48397 .40777 .48 .40043 .47264 Mtetra
.40043 .47264 .40777 .48 .4201 .47602 .4128 .46862 Mtetra
.4128 .46862 .4201 .47602 .4325 .47203 .42523 .46459 Mtetra
.652 .75 .922 r
.42523 .46459 .4325 .47203 .44495 .46811 .43772 .46064 Mtetra
.62 .74 .932 r
.43772 .46064 .44495 .46811 .45743 .46508 .45024 .45758 Mtetra
.364 .625 .953 r
.45024 .45758 .45743 .46508 .46991 .4669 .46273 .45937 Mtetra
.673 .185 0 r
.46273 .45937 .46991 .4669 .48229 .48356 .47511 .47604 Mtetra
.917 .52 .155 r
.47511 .47604 .48229 .48356 .4947 .52183 .48746 .51437 Mtetra
.913 .512 .142 r
.48746 .51437 .4947 .52183 .5075 .55982 .50021 .55241 Mtetra
.646 .762 .934 r
.50021 .55241 .5075 .55982 .52074 .55581 .51349 .54837 Mtetra
.944 .758 .621 r
.51349 .54837 .52074 .55581 .53393 .50967 .52681 .5021 Mtetra
.945 .757 .617 r
.52681 .5021 .53393 .50967 .54684 .46305 .53986 .45535 Mtetra
.907 .781 .711 r
.53986 .45535 .54684 .46305 .55972 .43802 .55282 .43024 Mtetra
.79 .787 .849 r
.55282 .43024 .55972 .43802 .5727 .4279 .56586 .42007 Mtetra
.686 .762 .909 r
.56586 .42007 .5727 .4279 .58579 .42265 .57899 .41478 Mtetra
.659 .753 .919 r
.57899 .41478 .58579 .42265 .59896 .41829 .5922 .41039 Mtetra
.656 .751 .92 r
.5922 .41039 .59896 .41829 .61219 .41401 .60547 .40607 Mtetra
.60547 .40607 .61219 .41401 .62548 .40972 .6188 .40174 Mtetra
.6188 .40174 .62548 .40972 .63884 .40541 .6322 .39739 Mtetra
.6322 .39739 .63884 .40541 .65226 .40107 .64567 .39302 Mtetra
.64567 .39302 .65226 .40107 .66574 .39672 .6592 .38863 Mtetra
.6592 .38863 .66574 .39672 .67929 .39235 .67279 .38421 Mtetra
.67279 .38421 .67929 .39235 .69291 .38795 .68645 .37978 Mtetra
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Mtetra
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Mtetra
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48518 Mtetra
.33184 .48518 .33941 .49245 .3515 .48852 .34396 .48122 Mtetra
.34396 .48122 .3515 .48852 .36365 .48458 .35615 .47725 Mtetra
.35615 .47725 .36365 .48458 .37585 .48061 .36838 .47325 Mtetra
.36838 .47325 .37585 .48061 .38811 .47663 .38068 .46924 Mtetra
.38068 .46924 .38811 .47663 .40043 .47264 .39303 .46521 Mtetra
.39303 .46521 .40043 .47264 .4128 .46862 .40544 .46116 Mtetra
.40544 .46116 .4128 .46862 .42523 .46459 .4179 .45709 Mtetra
.652 .75 .922 r
.4179 .45709 .42523 .46459 .43772 .46064 .43042 .45311 Mtetra
.62 .74 .932 r
.43042 .45311 .43772 .46064 .45024 .45758 .44298 .45002 Mtetra
.364 .625 .953 r
.44298 .45002 .45024 .45758 .46273 .45937 .4555 .45178 Mtetra
.673 .185 0 r
.4555 .45178 .46273 .45937 .47511 .47604 .46787 .46846 Mtetra
.917 .52 .155 r
.46787 .46846 .47511 .47604 .48746 .51437 .48016 .50684 Mtetra
.913 .512 .142 r
.48016 .50684 .48746 .51437 .50021 .55241 .49286 .54493 Mtetra
.646 .762 .934 r
.49286 .54493 .50021 .55241 .51349 .54837 .50618 .54086 Mtetra
.944 .758 .621 r
.50618 .54086 .51349 .54837 .52681 .5021 .51964 .49446 Mtetra
.945 .757 .617 r
.51964 .49446 .52681 .5021 .53986 .45535 .53282 .44758 Mtetra
.907 .781 .711 r
.53282 .44758 .53986 .45535 .55282 .43024 .54586 .4224 Mtetra
.79 .787 .849 r
.54586 .4224 .55282 .43024 .56586 .42007 .55895 .41218 Mtetra
.686 .762 .909 r
.55895 .41218 .56586 .42007 .57899 .41478 .57213 .40685 Mtetra
.659 .753 .919 r
.57213 .40685 .57899 .41478 .5922 .41039 .58538 .40242 Mtetra
.656 .751 .92 r
.58538 .40242 .5922 .41039 .60547 .40607 .59869 .39806 Mtetra
.59869 .39806 .60547 .40607 .6188 .40174 .61207 .39369 Mtetra
.61207 .39369 .6188 .40174 .6322 .39739 .62551 .38931 Mtetra
.62551 .38931 .6322 .39739 .64567 .39302 .63902 .3849 Mtetra
.63902 .3849 .64567 .39302 .6592 .38863 .65259 .38046 Mtetra
.65259 .38046 .6592 .38863 .67279 .38421 .66623 .37601 Mtetra
.66623 .37601 .67279 .38421 .68645 .37978 .67994 .37154 Mtetra
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Mtetra
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34884 Mtetra
.74947 .34884 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48183 Mtetra
.31209 .48183 .31977 .48912 .33184 .48518 .3242 .47786 Mtetra
.3242 .47786 .33184 .48518 .34396 .48122 .33636 .47387 Mtetra
.33636 .47387 .34396 .48122 .35615 .47725 .34858 .46986 Mtetra
.34858 .46986 .35615 .47725 .36838 .47325 .36085 .46583 Mtetra
.36085 .46583 .36838 .47325 .38068 .46924 .37318 .46178 Mtetra
.37318 .46178 .38068 .46924 .39303 .46521 .38557 .45771 Mtetra
.38557 .45771 .39303 .46521 .40544 .46116 .39801 .45363 Mtetra
.39801 .45363 .40544 .46116 .4179 .45709 .41051 .44953 Mtetra
.652 .75 .922 r
.41051 .44953 .4179 .45709 .43042 .45311 .42307 .44551 Mtetra
.62 .74 .932 r
.42307 .44551 .43042 .45311 .44298 .45002 .43566 .44238 Mtetra
.364 .625 .953 r
.43566 .44238 .44298 .45002 .4555 .45178 .4482 .44413 Mtetra
.673 .185 0 r
.4482 .44413 .4555 .45178 .46787 .46846 .46056 .46081 Mtetra
.917 .52 .155 r
.46056 .46081 .46787 .46846 .48016 .50684 .4728 .49924 Mtetra
.913 .512 .142 r
.4728 .49924 .48016 .50684 .49286 .54493 .48544 .53739 Mtetra
.646 .762 .934 r
.48544 .53739 .49286 .54493 .50618 .54086 .4988 .53328 Mtetra
.944 .758 .621 r
.4988 .53328 .50618 .54086 .51964 .49446 .51239 .48675 Mtetra
.945 .757 .617 r
.51239 .48675 .51964 .49446 .53282 .44758 .52571 .43975 Mtetra
.907 .781 .711 r
.52571 .43975 .53282 .44758 .54586 .4224 .53884 .41449 Mtetra
.79 .787 .849 r
.53884 .41449 .54586 .4224 .55895 .41218 .55198 .40422 Mtetra
.686 .762 .909 r
.55198 .40422 .55895 .41218 .57213 .40685 .56521 .39885 Mtetra
.659 .753 .919 r
.56521 .39885 .57213 .40685 .58538 .40242 .5785 .39437 Mtetra
.656 .751 .92 r
.5785 .39437 .58538 .40242 .59869 .39806 .59185 .38998 Mtetra
.59185 .38998 .59869 .39806 .61207 .39369 .60528 .38558 Mtetra
.60528 .38558 .61207 .39369 .62551 .38931 .61876 .38115 Mtetra
.61876 .38115 .62551 .38931 .63902 .3849 .63231 .3767 Mtetra
.63231 .3767 .63902 .3849 .65259 .38046 .64593 .37223 Mtetra
.64593 .37223 .65259 .38046 .66623 .37601 .65962 .36773 Mtetra
.65962 .36773 .66623 .37601 .67994 .37154 .67337 .36322 Mtetra
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Mtetra
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34884 .74314 .34031 Mtetra
.74314 .34031 .74947 .34884 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48183 .30436 .47448 Mtetra
.30436 .47448 .31209 .48183 .3242 .47786 .3165 .47048 Mtetra
.3165 .47048 .3242 .47786 .33636 .47387 .32869 .46645 Mtetra
.32869 .46645 .33636 .47387 .34858 .46986 .34094 .4624 Mtetra
.34094 .4624 .34858 .46986 .36085 .46583 .35325 .45834 Mtetra
.35325 .45834 .36085 .46583 .37318 .46178 .36562 .45426 Mtetra
.36562 .45426 .37318 .46178 .38557 .45771 .37804 .45015 Mtetra
.37804 .45015 .38557 .45771 .39801 .45363 .39052 .44603 Mtetra
.39052 .44603 .39801 .45363 .41051 .44953 .40306 .4419 Mtetra
.652 .75 .922 r
.40306 .4419 .41051 .44953 .42307 .44551 .41565 .43785 Mtetra
.62 .74 .932 r
.41565 .43785 .42307 .44551 .43566 .44238 .42828 .43469 Mtetra
.364 .625 .953 r
.42828 .43469 .43566 .44238 .4482 .44413 .44084 .43641 Mtetra
.673 .185 0 r
.44084 .43641 .4482 .44413 .46056 .46081 .45319 .45309 Mtetra
.917 .52 .155 r
.45319 .45309 .46056 .46081 .4728 .49924 .46537 .49157 Mtetra
.913 .512 .142 r
.46537 .49157 .4728 .49924 .48544 .53739 .47795 .52978 Mtetra
.646 .762 .934 r
.47795 .52978 .48544 .53739 .4988 .53328 .49136 .52563 Mtetra
.944 .758 .621 r
.49136 .52563 .4988 .53328 .51239 .48675 .50509 .47897 Mtetra
.945 .757 .617 r
.50509 .47897 .51239 .48675 .52571 .43975 .51854 .43185 Mtetra
.907 .781 .711 r
.51854 .43185 .52571 .43975 .53884 .41449 .53176 .4065 Mtetra
.79 .787 .849 r
.53176 .4065 .53884 .41449 .55198 .40422 .54496 .39618 Mtetra
.686 .762 .909 r
.54496 .39618 .55198 .40422 .56521 .39885 .55822 .39077 Mtetra
.659 .753 .919 r
.55822 .39077 .56521 .39885 .5785 .39437 .57156 .38626 Mtetra
.656 .751 .92 r
.57156 .38626 .5785 .39437 .59185 .38998 .58496 .38183 Mtetra
.58496 .38183 .59185 .38998 .60528 .38558 .59842 .37738 Mtetra
.59842 .37738 .60528 .38558 .61876 .38115 .61195 .37292 Mtetra
.61195 .37292 .61876 .38115 .63231 .3767 .62555 .36843 Mtetra
.62555 .36843 .63231 .3767 .64593 .37223 .63921 .36392 Mtetra
.63921 .36392 .64593 .37223 .65962 .36773 .65294 .35938 Mtetra
.65294 .35938 .65962 .36773 .67337 .36322 .66673 .35483 Mtetra
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Mtetra
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Mtetra
.29656 .46707 .30436 .47448 .3165 .47048 .30873 .46303 Mtetra
.30873 .46303 .3165 .47048 .32869 .46645 .32096 .45897 Mtetra
.32096 .45897 .32869 .46645 .34094 .4624 .33324 .45489 Mtetra
.33324 .45489 .34094 .4624 .35325 .45834 .34559 .45079 Mtetra
.34559 .45079 .35325 .45834 .36562 .45426 .35799 .44667 Mtetra
.35799 .44667 .36562 .45426 .37804 .45015 .37045 .44253 Mtetra
.37045 .44253 .37804 .45015 .39052 .44603 .38296 .43838 Mtetra
.38296 .43838 .39052 .44603 .40306 .4419 .39554 .43421 Mtetra
.652 .75 .922 r
.39554 .43421 .40306 .4419 .41565 .43785 .40817 .43011 Mtetra
.622 .74 .931 r
.40817 .43011 .41565 .43785 .42828 .43469 .42083 .42686 Mtetra
.389 .636 .954 r
.42083 .42686 .42828 .43469 .44084 .43641 .43343 .42822 Mtetra
.611 .126 0 r
.43343 .42822 .44084 .43641 .45319 .45309 .44579 .44374 Mtetra
.903 .5 .097 r
.44579 .44374 .45319 .45309 .46537 .49157 .45795 .47983 Mtetra
.875 .476 .019 r
.45795 .47983 .46537 .49157 .47795 .52978 .4705 .51561 Mtetra
.637 .622 .819 r
.4705 .51561 .47795 .52978 .49136 .52563 .48393 .51141 Mtetra
.904 .711 .63 r
.48393 .51141 .49136 .52563 .50509 .47897 .49775 .4671 Mtetra
.92 .728 .627 r
.49775 .4671 .50509 .47897 .51854 .43185 .51131 .4223 Mtetra
.889 .76 .714 r
.51131 .4223 .51854 .43185 .53176 .4065 .52461 .39805 Mtetra
.782 .776 .847 r
.52461 .39805 .53176 .4065 .54496 .39618 .53787 .38801 Mtetra
.685 .759 .908 r
.53787 .38801 .54496 .39618 .55822 .39077 .55118 .38262 Mtetra
.659 .752 .919 r
.55118 .38262 .55822 .39077 .57156 .38626 .56455 .37808 Mtetra
.656 .751 .92 r
.56455 .37808 .57156 .38626 .58496 .38183 .578 .37361 Mtetra
.578 .37361 .58496 .38183 .59842 .37738 .5915 .36912 Mtetra
.5915 .36912 .59842 .37738 .61195 .37292 .60508 .36461 Mtetra
.60508 .36461 .61195 .37292 .62555 .36843 .61872 .36008 Mtetra
.61872 .36008 .62555 .36843 .63921 .36392 .63243 .35553 Mtetra
.63243 .35553 .63921 .36392 .65294 .35938 .6462 .35095 Mtetra
.6462 .35095 .65294 .35938 .66673 .35483 .66004 .34636 Mtetra
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Mtetra
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45551 Mtetra
.3009 .45551 .30873 .46303 .32096 .45897 .31316 .45142 Mtetra
.31316 .45142 .32096 .45897 .33324 .45489 .32548 .4473 Mtetra
.32548 .4473 .33324 .45489 .34559 .45079 .33786 .44317 Mtetra
.33786 .44317 .34559 .45079 .35799 .44667 .35029 .43902 Mtetra
.35029 .43902 .35799 .44667 .37045 .44253 .36279 .43484 Mtetra
.36279 .43484 .37045 .44253 .38296 .43838 .37534 .43065 Mtetra
.37534 .43065 .38296 .43838 .39554 .43421 .38795 .42644 Mtetra
.654 .751 .921 r
.38795 .42644 .39554 .43421 .40817 .43011 .40062 .42226 Mtetra
.64 .745 .925 r
.40062 .42226 .40817 .43011 .42083 .42686 .41334 .41848 Mtetra
.553 .699 .936 r
.41334 .41848 .42083 .42686 .43343 .42822 .42605 .41696 Mtetra
.242 .459 .87 r
.42605 .41696 .43343 .42822 .44579 .44374 .43865 .42235 Mtetra
.078 .189 .679 r
.43865 .42235 .44579 .44374 .45795 .47983 .45118 .43763 Mtetra
.361 .277 .624 r
.45118 .43763 .45795 .47983 .4705 .51561 .46393 .4525 Mtetra
.568 .392 .604 r
.46393 .4525 .4705 .51561 .48393 .51141 .47717 .4482 Mtetra
.663 .461 .602 r
.47717 .4482 .48393 .51141 .49775 .4671 .49068 .42467 Mtetra
.709 .517 .627 r
.49068 .42467 .49775 .4671 .51131 .4223 .50411 .40065 Mtetra
.729 .595 .706 r
.50411 .40065 .51131 .4223 .52461 .39805 .51741 .3865 Mtetra
.709 .693 .833 r
.51741 .3865 .52461 .39805 .53787 .38801 .53071 .37929 Mtetra
.67 .742 .904 r
.53071 .37929 .53787 .38801 .55118 .38262 .54407 .37435 Mtetra
.657 .75 .919 r
.54407 .37435 .55118 .38262 .56455 .37808 .55749 .36981 Mtetra
.656 .751 .92 r
.55749 .36981 .56455 .37808 .578 .37361 .57097 .36531 Mtetra
.57097 .36531 .578 .37361 .5915 .36912 .58452 .36078 Mtetra
.58452 .36078 .5915 .36912 .60508 .36461 .59814 .35623 Mtetra
.59814 .35623 .60508 .36461 .61872 .36008 .61183 .35166 Mtetra
.61183 .35166 .61872 .36008 .63243 .35553 .62558 .34707 Mtetra
.62558 .34707 .63243 .35553 .6462 .35095 .6394 .34245 Mtetra
.6394 .34245 .6462 .35095 .66004 .34636 .65329 .33781 Mtetra
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.28076 .45205 .28869 .45959 .3009 .45551 .293 .44794 Mtetra
.293 .44794 .3009 .45551 .31316 .45142 .30529 .44381 Mtetra
.30529 .44381 .31316 .45142 .32548 .4473 .31765 .43966 Mtetra
.31765 .43966 .32548 .4473 .33786 .44317 .33006 .43549 Mtetra
.33006 .43549 .33786 .44317 .35029 .43902 .34253 .4313 Mtetra
.34253 .4313 .35029 .43902 .36279 .43484 .35506 .42709 Mtetra
.35506 .42709 .36279 .43484 .37534 .43065 .36765 .42286 Mtetra
.36765 .42286 .37534 .43065 .38795 .42644 .3803 .41861 Mtetra
.655 .751 .92 r
.3803 .41861 .38795 .42644 .40062 .42226 .39301 .41435 Mtetra
.652 .749 .921 r
.39301 .41435 .40062 .42226 .41334 .41848 .40577 .41016 Mtetra
.636 .734 .919 r
.40577 .41016 .41334 .41848 .42605 .41696 .41858 .40645 Mtetra
.59 .662 .889 r
.41858 .40645 .42605 .41696 .43865 .42235 .43142 .40423 Mtetra
.541 .518 .779 r
.43142 .40423 .43865 .42235 .45118 .43763 .44428 .40412 Mtetra
.547 .428 .669 r
.44428 .40412 .45118 .43763 .46393 .4525 .45723 .40386 Mtetra
.577 .415 .625 r
.45723 .40386 .46393 .4525 .47717 .4482 .47036 .39947 Mtetra
.606 .435 .624 r
.47036 .39947 .47717 .4482 .49068 .42467 .4836 .39096 Mtetra
.634 .486 .664 r
.4836 .39096 .49068 .42467 .50411 .40065 .49687 .38228 Mtetra
.661 .583 .757 r
.49687 .38228 .50411 .40065 .51741 .3865 .51016 .3757 Mtetra
.667 .694 .865 r
.51016 .3757 .51741 .3865 .53071 .37929 .52349 .37062 Mtetra
.659 .741 .911 r
.52349 .37062 .53071 .37929 .54407 .37435 .53689 .36601 Mtetra
.656 .75 .919 r
.53689 .36601 .54407 .37435 .55749 .36981 .55036 .36148 Mtetra
.656 .751 .92 r
.55036 .36148 .55749 .36981 .57097 .36531 .56389 .35693 Mtetra
.56389 .35693 .57097 .36531 .58452 .36078 .57748 .35236 Mtetra
.57748 .35236 .58452 .36078 .59814 .35623 .59115 .34777 Mtetra
.59115 .34777 .59814 .35623 .61183 .35166 .60488 .34316 Mtetra
.60488 .34316 .61183 .35166 .62558 .34707 .61867 .33853 Mtetra
.61867 .33853 .62558 .34707 .6394 .34245 .63254 .33387 Mtetra
.63254 .33387 .6394 .34245 .65329 .33781 .64648 .32918 Mtetra
.64648 .32918 .65329 .33781 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Mtetra
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Mtetra
.29736 .43613 .30529 .44381 .31765 .43966 .30975 .43194 Mtetra
.30975 .43194 .31765 .43966 .33006 .43549 .3222 .42774 Mtetra
.3222 .42774 .33006 .43549 .34253 .4313 .3347 .42351 Mtetra
.3347 .42351 .34253 .4313 .35506 .42709 .34727 .41926 Mtetra
.34727 .41926 .35506 .42709 .36765 .42286 .3599 .415 Mtetra
.3599 .415 .36765 .42286 .3803 .41861 .37258 .41071 Mtetra
.37258 .41071 .3803 .41861 .39301 .41435 .38533 .4064 Mtetra
.655 .751 .92 r
.38533 .4064 .39301 .41435 .40577 .41016 .39813 .40209 Mtetra
.654 .748 .919 r
.39813 .40209 .40577 .41016 .41858 .40645 .411 .3978 Mtetra
.649 .732 .91 r
.411 .3978 .41858 .40645 .43142 .40423 .42392 .39363 Mtetra
.641 .684 .875 r
.42392 .39363 .43142 .40423 .44428 .40412 .43691 .38965 Mtetra
.631 .612 .813 r
.43691 .38965 .44428 .40412 .45723 .40386 .44996 .38564 Mtetra
.627 .566 .767 r
.44996 .38564 .45723 .40386 .47036 .39947 .46308 .3812 Mtetra
.634 .57 .765 r
.46308 .3812 .47036 .39947 .4836 .39096 .47627 .37635 Mtetra
.648 .62 .808 r
.47627 .37635 .4836 .39096 .49687 .38228 .48952 .37147 Mtetra
.657 .69 .869 r
.48952 .37147 .49687 .38228 .51016 .3757 .50284 .36676 Mtetra
.657 .735 .907 r
.50284 .36676 .51016 .3757 .52349 .37062 .51621 .36219 Mtetra
.656 .749 .918 r
.51621 .36219 .52349 .37062 .53689 .36601 .52965 .35763 Mtetra
.656 .751 .92 r
.52965 .35763 .53689 .36601 .55036 .36148 .54316 .35307 Mtetra
.54316 .35307 .55036 .36148 .56389 .35693 .55674 .34848 Mtetra
.55674 .34848 .56389 .35693 .57748 .35236 .57038 .34387 Mtetra
.57038 .34387 .57748 .35236 .59115 .34777 .58408 .33924 Mtetra
.58408 .33924 .59115 .34777 .60488 .34316 .59786 .33458 Mtetra
.59786 .33458 .60488 .34316 .61867 .33853 .6117 .32991 Mtetra
.6117 .32991 .61867 .33853 .63254 .33387 .62562 .32521 Mtetra
.62562 .32521 .63254 .33387 .64648 .32918 .6396 .32048 Mtetra
.6396 .32048 .64648 .32918 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Mtetra
.28935 .42838 .29736 .43613 .30975 .43194 .30178 .42416 Mtetra
.30178 .42416 .30975 .43194 .3222 .42774 .31426 .41992 Mtetra
.31426 .41992 .3222 .42774 .3347 .42351 .32681 .41565 Mtetra
.32681 .41565 .3347 .42351 .34727 .41926 .33941 .41137 Mtetra
.33941 .41137 .34727 .41926 .3599 .415 .35207 .40707 Mtetra
.35207 .40707 .3599 .415 .37258 .41071 .36479 .40274 Mtetra
.36479 .40274 .37258 .41071 .38533 .4064 .37758 .3984 Mtetra
.37758 .3984 .38533 .4064 .39813 .40209 .39042 .39403 Mtetra
.39042 .39403 .39813 .40209 .411 .3978 .40333 .38965 Mtetra
.656 .75 .919 r
.40333 .38965 .411 .3978 .42392 .39363 .4163 .38525 Mtetra
.655 .744 .915 r
.4163 .38525 .42392 .39363 .43691 .38965 .42933 .38084 Mtetra
.655 .734 .908 r
.42933 .38084 .43691 .38965 .44996 .38564 .44243 .3764 Mtetra
.655 .725 .9 r
.44243 .3764 .44996 .38564 .46308 .3812 .45559 .37193 Mtetra
.656 .725 .9 r
.45559 .37193 .46308 .3812 .47627 .37635 .46881 .36742 Mtetra
.656 .734 .907 r
.46881 .36742 .47627 .37635 .48952 .37147 .4821 .36288 Mtetra
.656 .744 .915 r
.4821 .36288 .48952 .37147 .50284 .36676 .49545 .35834 Mtetra
.656 .75 .919 r
.49545 .35834 .50284 .36676 .51621 .36219 .50887 .35377 Mtetra
.656 .751 .92 r
.50887 .35377 .51621 .36219 .52965 .35763 .52235 .34919 Mtetra
.52235 .34919 .52965 .35763 .54316 .35307 .5359 .34458 Mtetra
.5359 .34458 .54316 .35307 .55674 .34848 .54952 .33995 Mtetra
.54952 .33995 .55674 .34848 .57038 .34387 .5632 .3353 Mtetra
.5632 .3353 .57038 .34387 .58408 .33924 .57696 .33063 Mtetra
.57696 .33063 .58408 .33924 .59786 .33458 .59078 .32593 Mtetra
.59078 .32593 .59786 .33458 .6117 .32991 .60467 .32121 Mtetra
.60467 .32121 .6117 .32991 .62562 .32521 .61863 .31646 Mtetra
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Mtetra
.28128 .42057 .28935 .42838 .30178 .42416 .29374 .41631 Mtetra
.29374 .41631 .30178 .42416 .31426 .41992 .30626 .41203 Mtetra
.30626 .41203 .31426 .41992 .32681 .41565 .31884 .40773 Mtetra
.31884 .40773 .32681 .41565 .33941 .41137 .33148 .40341 Mtetra
.33148 .40341 .33941 .41137 .35207 .40707 .34418 .39907 Mtetra
.34418 .39907 .35207 .40707 .36479 .40274 .35694 .3947 Mtetra
.35694 .3947 .36479 .40274 .37758 .3984 .36976 .39032 Mtetra
.36976 .39032 .37758 .3984 .39042 .39403 .38264 .38591 Mtetra
.38264 .38591 .39042 .39403 .40333 .38965 .39559 .38149 Mtetra
.39559 .38149 .40333 .38965 .4163 .38525 .4086 .37704 Mtetra
.4086 .37704 .4163 .38525 .42933 .38084 .42167 .37257 Mtetra
.42167 .37257 .42933 .38084 .44243 .3764 .43481 .36808 Mtetra
.656 .75 .919 r
.43481 .36808 .44243 .3764 .45559 .37193 .44801 .36357 Mtetra
.44801 .36357 .45559 .37193 .46881 .36742 .46127 .35903 Mtetra
.656 .751 .92 r
.46127 .35903 .46881 .36742 .4821 .36288 .4746 .35448 Mtetra
.4746 .35448 .4821 .36288 .49545 .35834 .48799 .3499 Mtetra
.48799 .3499 .49545 .35834 .50887 .35377 .50145 .34529 Mtetra
.50145 .34529 .50887 .35377 .52235 .34919 .51498 .34067 Mtetra
.51498 .34067 .52235 .34919 .5359 .34458 .52858 .33602 Mtetra
.52858 .33602 .5359 .34458 .54952 .33995 .54224 .33135 Mtetra
.54224 .33135 .54952 .33995 .5632 .3353 .55597 .32665 Mtetra
.55597 .32665 .5632 .3353 .57696 .33063 .56976 .32194 Mtetra
.56976 .32194 .57696 .33063 .59078 .32593 .58363 .3172 Mtetra
.58363 .3172 .59078 .32593 .60467 .32121 .59757 .31243 Mtetra
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Mtetra
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Mtetra
.28563 .40839 .29374 .41631 .30626 .41203 .29819 .40407 Mtetra
.29819 .40407 .30626 .41203 .31884 .40773 .3108 .39974 Mtetra
.3108 .39974 .31884 .40773 .33148 .40341 .32348 .39538 Mtetra
.32348 .39538 .33148 .40341 .34418 .39907 .33621 .391 Mtetra
.33621 .391 .34418 .39907 .35694 .3947 .34901 .38659 Mtetra
.34901 .38659 .35694 .3947 .36976 .39032 .36187 .38217 Mtetra
.36187 .38217 .36976 .39032 .38264 .38591 .3748 .37773 Mtetra
.3748 .37773 .38264 .38591 .39559 .38149 .38778 .37326 Mtetra
.38778 .37326 .39559 .38149 .4086 .37704 .40083 .36877 Mtetra
.40083 .36877 .4086 .37704 .42167 .37257 .41394 .36426 Mtetra
.41394 .36426 .42167 .37257 .43481 .36808 .42712 .35973 Mtetra
.42712 .35973 .43481 .36808 .44801 .36357 .44036 .35518 Mtetra
.44036 .35518 .44801 .36357 .46127 .35903 .45366 .3506 Mtetra
.45366 .3506 .46127 .35903 .4746 .35448 .46703 .346 Mtetra
.46703 .346 .4746 .35448 .48799 .3499 .48047 .34138 Mtetra
.48047 .34138 .48799 .3499 .50145 .34529 .49397 .33674 Mtetra
.49397 .33674 .50145 .34529 .51498 .34067 .50754 .33207 Mtetra
.50754 .33207 .51498 .34067 .52858 .33602 .52118 .32738 Mtetra
.52118 .32738 .52858 .33602 .54224 .33135 .53489 .32266 Mtetra
.53489 .32266 .54224 .33135 .55597 .32665 .54866 .31793 Mtetra
.54866 .31793 .55597 .32665 .56976 .32194 .56251 .31316 Mtetra
.56251 .31316 .56976 .32194 .58363 .3172 .57642 .30838 Mtetra
.57642 .30838 .58363 .3172 .59757 .31243 .5904 .30357 Mtetra
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Mtetra
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Mtetra
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .4004 Mtetra
.27745 .4004 .28563 .40839 .29819 .40407 .29004 .39605 Mtetra
.29004 .39605 .29819 .40407 .3108 .39974 .30269 .39167 Mtetra
.30269 .39167 .3108 .39974 .32348 .39538 .31541 .38727 Mtetra
.31541 .38727 .32348 .39538 .33621 .391 .32818 .38285 Mtetra
.32818 .38285 .33621 .391 .34901 .38659 .34102 .37841 Mtetra
.34102 .37841 .34901 .38659 .36187 .38217 .35391 .37395 Mtetra
.35391 .37395 .36187 .38217 .3748 .37773 .36688 .36946 Mtetra
.36688 .36946 .3748 .37773 .38778 .37326 .3799 .36496 Mtetra
.3799 .36496 .38778 .37326 .40083 .36877 .39299 .36043 Mtetra
.39299 .36043 .40083 .36877 .41394 .36426 .40614 .35588 Mtetra
.40614 .35588 .41394 .36426 .42712 .35973 .41936 .35131 Mtetra
.41936 .35131 .42712 .35973 .44036 .35518 .43264 .34671 Mtetra
.43264 .34671 .44036 .35518 .45366 .3506 .44598 .34209 Mtetra
.44598 .34209 .45366 .3506 .46703 .346 .4594 .33745 Mtetra
.4594 .33745 .46703 .346 .48047 .34138 .47288 .33279 Mtetra
.47288 .33279 .48047 .34138 .49397 .33674 .48642 .3281 Mtetra
.48642 .3281 .49397 .33674 .50754 .33207 .50004 .32339 Mtetra
.50004 .32339 .50754 .33207 .52118 .32738 .51372 .31866 Mtetra
.51372 .31866 .52118 .32738 .53489 .32266 .52747 .3139 Mtetra
.52747 .3139 .53489 .32266 .54866 .31793 .54129 .30912 Mtetra
.54129 .30912 .54866 .31793 .56251 .31316 .55518 .30431 Mtetra
.55518 .30431 .56251 .31316 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Mtetra
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Mtetra
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .4004 .2692 .39235 Mtetra
.2692 .39235 .27745 .4004 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Mtetra
.29451 .38353 .30269 .39167 .31541 .38727 .30726 .3791 Mtetra
.30726 .3791 .31541 .38727 .32818 .38285 .32007 .37464 Mtetra
.32007 .37464 .32818 .38285 .34102 .37841 .33295 .37016 Mtetra
.33295 .37016 .34102 .37841 .35391 .37395 .34588 .36565 Mtetra
.34588 .36565 .35391 .37395 .36688 .36946 .35888 .36113 Mtetra
.35888 .36113 .36688 .36946 .3799 .36496 .37195 .35658 Mtetra
.37195 .35658 .3799 .36496 .39299 .36043 .38508 .35201 Mtetra
.38508 .35201 .39299 .36043 .40614 .35588 .39827 .34742 Mtetra
.39827 .34742 .40614 .35588 .41936 .35131 .41152 .34281 Mtetra
.41152 .34281 .41936 .35131 .43264 .34671 .42485 .33817 Mtetra
.42485 .33817 .43264 .34671 .44598 .34209 .43824 .33351 Mtetra
.43824 .33351 .44598 .34209 .4594 .33745 .45169 .32882 Mtetra
.45169 .32882 .4594 .33745 .47288 .33279 .46521 .32412 Mtetra
.46521 .32412 .47288 .33279 .48642 .3281 .4788 .31939 Mtetra
.4788 .31939 .48642 .3281 .50004 .32339 .49246 .31463 Mtetra
.49246 .31463 .50004 .32339 .51372 .31866 .50619 .30985 Mtetra
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Mtetra
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Mtetra
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36183 Mtetra
.32481 .36183 .33295 .37016 .34588 .36565 .33778 .35728 Mtetra
.33778 .35728 .34588 .36565 .35888 .36113 .35082 .35272 Mtetra
.35082 .35272 .35888 .36113 .37195 .35658 .36392 .34813 Mtetra
.36392 .34813 .37195 .35658 .38508 .35201 .37709 .34352 Mtetra
.37709 .34352 .38508 .35201 .39827 .34742 .39032 .33888 Mtetra
.39032 .33888 .39827 .34742 .41152 .34281 .40362 .33423 Mtetra
.40362 .33423 .41152 .34281 .42485 .33817 .41699 .32955 Mtetra
.41699 .32955 .42485 .33817 .43824 .33351 .43042 .32484 Mtetra
.43042 .32484 .43824 .33351 .45169 .32882 .44391 .32012 Mtetra
.44391 .32012 .45169 .32882 .46521 .32412 .45748 .31537 Mtetra
.45748 .31537 .46521 .32412 .4788 .31939 .47111 .31059 Mtetra
.47111 .31059 .4788 .31939 .49246 .31463 .48482 .30579 Mtetra
.48482 .30579 .49246 .31463 .50619 .30985 .49859 .30097 Mtetra
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Mtetra
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Mtetra
.31659 .35342 .32481 .36183 .33778 .35728 .32961 .34884 Mtetra
.32961 .34884 .33778 .35728 .35082 .35272 .34268 .34423 Mtetra
.34268 .34423 .35082 .35272 .36392 .34813 .35583 .3396 Mtetra
.35583 .3396 .36392 .34813 .37709 .34352 .36903 .33494 Mtetra
.36903 .33494 .37709 .34352 .39032 .33888 .38231 .33027 Mtetra
.38231 .33027 .39032 .33888 .40362 .33423 .39565 .32557 Mtetra
.39565 .32557 .40362 .33423 .41699 .32955 .40905 .32084 Mtetra
.40905 .32084 .41699 .32955 .43042 .32484 .42253 .3161 Mtetra
.42253 .3161 .43042 .32484 .44391 .32012 .43607 .31133 Mtetra
.43607 .31133 .44391 .32012 .45748 .31537 .44967 .30653 Mtetra
.44967 .30653 .45748 .31537 .47111 .31059 .46335 .30171 Mtetra
.46335 .30171 .47111 .31059 .48482 .30579 .4771 .29687 Mtetra
.4771 .29687 .48482 .30579 .49859 .30097 .49091 .292 Mtetra
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Mtetra
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.3083 .34494 .31659 .35342 .32961 .34884 .32136 .34031 Mtetra
.32136 .34031 .32961 .34884 .34268 .34423 .33447 .33566 Mtetra
.33447 .33566 .34268 .34423 .35583 .3396 .34766 .33099 Mtetra
.34766 .33099 .35583 .3396 .36903 .33494 .3609 .32629 Mtetra
.3609 .32629 .36903 .33494 .38231 .33027 .37422 .32157 Mtetra
.37422 .32157 .38231 .33027 .39565 .32557 .3876 .31683 Mtetra
.3876 .31683 .39565 .32557 .40905 .32084 .40105 .31206 Mtetra
.40105 .31206 .40905 .32084 .42253 .3161 .41456 .30727 Mtetra
.41456 .30727 .42253 .3161 .43607 .31133 .42814 .30246 Mtetra
.42814 .30246 .43607 .31133 .44967 .30653 .4418 .29762 Mtetra
.4418 .29762 .44967 .30653 .46335 .30171 .45552 .29275 Mtetra
.45552 .29275 .46335 .30171 .4771 .29687 .46931 .28786 Mtetra
.46931 .28786 .4771 .29687 .49091 .292 .48317 .28295 Mtetra
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Mtetra
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Mtetra
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Mtetra
.31303 .33171 .32136 .34031 .33447 .33566 .32619 .32702 Mtetra
.32619 .32702 .33447 .33566 .34766 .33099 .33941 .3223 Mtetra
.33941 .3223 .34766 .33099 .3609 .32629 .3527 .31756 Mtetra
.3527 .31756 .3609 .32629 .37422 .32157 .36605 .3128 Mtetra
.36605 .3128 .37422 .32157 .3876 .31683 .37947 .30801 Mtetra
.37947 .30801 .3876 .31683 .40105 .31206 .39296 .3032 Mtetra
.39296 .3032 .40105 .31206 .41456 .30727 .40652 .29836 Mtetra
.40652 .29836 .41456 .30727 .42814 .30246 .42015 .2935 Mtetra
.42015 .2935 .42814 .30246 .4418 .29762 .43384 .28862 Mtetra
.43384 .28862 .4418 .29762 .45552 .29275 .44761 .28371 Mtetra
.44761 .28371 .45552 .29275 .46931 .28786 .46145 .27877 Mtetra
.46145 .27877 .46931 .28786 .48317 .28295 .47535 .27381 Mtetra
.47535 .27381 .48317 .28295 .4971 .27801 .48933 .26883 Mtetra
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Mtetra
.30463 .32303 .31303 .33171 .32619 .32702 .31782 .31829 Mtetra
.31782 .31829 .32619 .32702 .33941 .3223 .33109 .31353 Mtetra
.33109 .31353 .33941 .3223 .3527 .31756 .34441 .30875 Mtetra
.34441 .30875 .3527 .31756 .36605 .3128 .35781 .30394 Mtetra
.35781 .30394 .36605 .3128 .37947 .30801 .37127 .29911 Mtetra
.37127 .29911 .37947 .30801 .39296 .3032 .38481 .29425 Mtetra
.38481 .29425 .39296 .3032 .40652 .29836 .39841 .28937 Mtetra
.39841 .28937 .40652 .29836 .42015 .2935 .41208 .28447 Mtetra
.41208 .28447 .42015 .2935 .43384 .28862 .42582 .27954 Mtetra
.42582 .27954 .43384 .28862 .44761 .28371 .43963 .27458 Mtetra
.43963 .27458 .44761 .28371 .46145 .27877 .45351 .2696 Mtetra
.45351 .2696 .46145 .27877 .47535 .27381 .46746 .26459 Mtetra
.46746 .26459 .47535 .27381 .48933 .26883 .48148 .25956 Mtetra
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Mtetra
.29615 .31427 .30463 .32303 .31782 .31829 .30938 .30949 Mtetra
.30938 .30949 .31782 .31829 .33109 .31353 .32269 .30468 Mtetra
.32269 .30468 .33109 .31353 .34441 .30875 .33606 .29985 Mtetra
.33606 .29985 .34441 .30875 .35781 .30394 .34949 .295 Mtetra
.34949 .295 .35781 .30394 .37127 .29911 .363 .29012 Mtetra
.363 .29012 .37127 .29911 .38481 .29425 .37657 .28522 Mtetra
.37657 .28522 .38481 .29425 .39841 .28937 .39022 .2803 Mtetra
.39022 .2803 .39841 .28937 .41208 .28447 .40393 .27534 Mtetra
.40393 .27534 .41208 .28447 .42582 .27954 .41771 .27037 Mtetra
.41771 .27037 .42582 .27954 .43963 .27458 .43157 .26536 Mtetra
.43157 .26536 .43963 .27458 .45351 .2696 .4455 .26033 Mtetra
.4455 .26033 .45351 .2696 .46746 .26459 .45949 .25528 Mtetra
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Mtetra
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Mtetra
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Mtetra
.28759 .30542 .29615 .31427 .30938 .30949 .30086 .3006 Mtetra
.30086 .3006 .30938 .30949 .32269 .30468 .31421 .29575 Mtetra
.31421 .29575 .32269 .30468 .33606 .29985 .32762 .29088 Mtetra
.32762 .29088 .33606 .29985 .34949 .295 .3411 .28598 Mtetra
.3411 .28598 .34949 .295 .363 .29012 .35464 .28106 Mtetra
.35464 .28106 .363 .29012 .37657 .28522 .36826 .27611 Mtetra
.36826 .27611 .37657 .28522 .39022 .2803 .38195 .27113 Mtetra
.38195 .27113 .39022 .2803 .40393 .27534 .39571 .26613 Mtetra
.39571 .26613 .40393 .27534 .41771 .27037 .40953 .26111 Mtetra
.40953 .26111 .41771 .27037 .43157 .26536 .42343 .25606 Mtetra
.42343 .25606 .43157 .26536 .4455 .26033 .43741 .25098 Mtetra
.43741 .25098 .4455 .26033 .45949 .25528 .45145 .24588 Mtetra
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Mtetra
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Mtetra
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Mtetra
.27895 .2965 .28759 .30542 .30086 .3006 .29226 .29163 Mtetra
.29226 .29163 .30086 .3006 .31421 .29575 .30565 .28673 Mtetra
.30565 .28673 .31421 .29575 .32762 .29088 .3191 .28181 Mtetra
.3191 .28181 .32762 .29088 .3411 .28598 .33262 .27687 Mtetra
.33262 .27687 .3411 .28598 .35464 .28106 .34621 .2719 Mtetra
.34621 .2719 .35464 .28106 .36826 .27611 .35987 .2669 Mtetra
.35987 .2669 .36826 .27611 .38195 .27113 .3736 .26188 Mtetra
.3736 .26188 .38195 .27113 .39571 .26613 .3874 .25684 Mtetra
.3874 .25684 .39571 .26613 .40953 .26111 .40128 .25176 Mtetra
.40128 .25176 .40953 .26111 .42343 .25606 .41522 .24666 Mtetra
.41522 .24666 .42343 .25606 .43741 .25098 .42924 .24154 Mtetra
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Mtetra
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Mtetra
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Mtetra
.27023 .28749 .27895 .2965 .29226 .29163 .28358 .28257 Mtetra
.28358 .28257 .29226 .29163 .30565 .28673 .29701 .27763 Mtetra
.29701 .27763 .30565 .28673 .3191 .28181 .3105 .27267 Mtetra
.3105 .27267 .3191 .28181 .33262 .27687 .32407 .26767 Mtetra
.32407 .26767 .33262 .27687 .34621 .2719 .3377 .26266 Mtetra
.3377 .26266 .34621 .2719 .35987 .2669 .3514 .25762 Mtetra
.3514 .25762 .35987 .2669 .3736 .26188 .36518 .25255 Mtetra
.36518 .25255 .3736 .26188 .3874 .25684 .37902 .24745 Mtetra
.37902 .24745 .3874 .25684 .40128 .25176 .39294 .24233 Mtetra
.39294 .24233 .40128 .25176 .41522 .24666 .40693 .23718 Mtetra
.40693 .23718 .41522 .24666 .42924 .24154 .42099 .23201 Mtetra
.42099 .23201 .42924 .24154 .44333 .23639 .43513 .2268 Mtetra
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Mtetra
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Mtetra
.26142 .27839 .27023 .28749 .28358 .28257 .27482 .27343 Mtetra
.27482 .27343 .28358 .28257 .29701 .27763 .28829 .26844 Mtetra
.28829 .26844 .29701 .27763 .3105 .27267 .30182 .26343 Mtetra
.30182 .26343 .3105 .27267 .32407 .26767 .31543 .25839 Mtetra
.31543 .25839 .32407 .26767 .3377 .26266 .3291 .25333 Mtetra
.3291 .25333 .3377 .26266 .3514 .25762 .34285 .24824 Mtetra
.34285 .24824 .3514 .25762 .36518 .25255 .35667 .24312 Mtetra
.35667 .24312 .36518 .25255 .37902 .24745 .37056 .23797 Mtetra
.37056 .23797 .37902 .24745 .39294 .24233 .38452 .2328 Mtetra
.38452 .2328 .39294 .24233 .40693 .23718 .39856 .22761 Mtetra
.39856 .22761 .40693 .23718 .42099 .23201 .41267 .22238 Mtetra
.41267 .22238 .42099 .23201 .43513 .2268 .42685 .21713 Mtetra
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3ooomC0:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0oooo00<000000?ooo`3oool0AP3ooomE0:O0j`03
0000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo
F@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?oooe`0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo02P0oooo000T
0?ooo`800000B`3ooomM0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?oo
oe`0Yl3[0`0000020:O0j`030000002W`>/0Yl3[0180Yl3[4P3oool00`000000oooo0?ooo`0V0?oo
o`007`3oool3000004T0ooooG@2W`>/3000000D0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`03
0000003oool0oooo02H0oooo000M0?ooo`800000B`3ooomK0:O0j`<000002@2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0303oool2000000@0oooo0P0000030?ooo`@00000
2P3oool001D0oooo1@0000030?ooo`800000B@3ooomJ0:O0j`<000003@2W`>/00`000000Yl3[0:O0
j`0C0:O0ja40oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`0000140?oooe`0Yl3[0P00
000A0:O0j`030000002W`>/0Yl3[01<0Yl3[403oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000o0?oooed0Yl3[0`00000C0:O0j`030000002W`>/0Yl3[01<0Yl3[
4@3oool00`000000oooo0?ooo`030?ooo`@000000P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00T0oooo000?0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>`3ooomK0:O0j`<000005`2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo03P0ooooFP2W`>/3000001/0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`80
00002`3oool2000000X0oooo0P00000;0?ooo`005P3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0c0?oooe/0Yl3[0`00000O0:O0j`030000002W`>/0Yl3[0180Yl3[
4@3oool00`000000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03o
oomK0:O0j`<000008P2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0803o
ool001`0oooo0P0000080?ooo`030000003oool0oooo02/0ooooFP2W`>/3000002H0Yl3[00<00000
0:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0:03ooomI0:O0j`<00000:P2W`>/00`000000Yl3[0:O0j`0B0:O0
ja40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0S0?oooeX0Yl3[0`00000^0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000
oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<000000?ooo`3oool07`3ooomK0:O0j`800000
<@2W`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo00<000000?ooo`3oool07P3oool001/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?oooe`0Yl3[0`00000d0:O0j`030000002W
`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01P0ooooFP2W`>/3000003P0Yl3[00<000000:O0j`2W`>/04@2W`>/@
0?ooo`8000007`3oool001/0oooo0P00000?0?ooo`030000003oool0oooo01D0ooooF@2W`>/30000
03/0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01`0oooo000K0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04@3ooomI0:O0j`<00000?`2W`>/00`000000
Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P0000040?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?oooeX0Yl3[
0`0000130:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0K0?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00000C0?ooo`03
0000003oool0oooo00X0ooooF02W`>/3000004L0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`03
0000003oool0oooo01X0oooo00070?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3o
ool0oooo0000000E0?ooo`030000003oool0oooo00L0ooooE`2W`>/3000004X0Yl3[00<000000:O0
j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01T0oooo00000`3oool000000000000200000080
oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`020?oooeP0Yl3[0`00001>0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`00
0000oooo0?ooo`0I0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00<0oooo0P00000F0?ooo`030000002W`>/0Yl3[05L0Yl3[0P00001B0:O0j`030000002W`>/0Yl3[
0140Yl3[403oool2000001X0oooo00080?ooo`8000002P3oool3000000<0oooo00<000000?ooo`3o
ool04P3ooomJ0:O0j`<00000E@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3o
ool05`3oool001T0oooo00<000000?ooo`3oool04P3ooomH0:O0j`<00000F02W`>/00`000000Yl3[
0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool05`3oool001T0oooo0P00000A0?oooeL0Yl3[0`00
001L0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0F0?ooo`006@3oool0
0`000000oooo0?ooo`0=0?oooeL0Yl3[0`00001P0:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool0
0`000000oooo0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`090?oooeP0Yl3[0`00001T0:O0
j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0E0?ooo`006@3oool2000000L0
ooooF02W`>/3000006L0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01@0
oooo000I0?ooo`030000003oool0oooo00<0ooooF02W`>/3000001h0Yl3[102W_n]90:O0j`030000
002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?oo
o`030?oooeH0Yl3[0`00000F0:O0j`80Yko[1@2W`>/50:NnjPT0Yko[A02W`>/00`000000Yl3[0:O0
j`0A0:O0j`l0oooo0P00000E0?ooo`00603oool010000000oooo0000003ooomF0:O0j`8000005`2W
`>/50:Noj`<0Yl3[0P2W^nP50:NnjP80Yko[0P2X_>P90:Nojcl0Yl3[00<000000:O0j`2W`>/04@2W
`>/A0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`00603oool00`000000Yl3[0:O0j`1D
0:O0j`<000005@2W`>/:0:Noj`D0Yk_X102W_^X50:Rlj080Yko[0`2X_NT40:Nojcl0Yl3[00<00000
0:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000002@3o
ool00140oooo0P0000050?ooo`030000003oool0Yl3[0540Yl3[0`00000I0:O0j`D0Yko[1@2W^NH4
0:Nkj0D0Z;3N102X_>P60:Rmj@80Yko[0P2X_n/o0:O0j`030000002W`>/0Yl3[0140Yl3[403oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0CP2W`>/3000001d0Yl3[2P2W^NH40:FNcPD0Z;3N102Z
/Md50:Rmj@D0Z;o[?`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`800000
0P3ooom:0:O0j`<000007@2W`>/40:Nkj0D0YkWV1@2RTL<40:FNcP80Z;3N0`2YUL440:Zag@D0ZkgW
102X_n/o0:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3ooom60:O0j`<00000702W`>/50:NnjP@0Yk_X0P2W^NH30:2@a0@0XY73102UW/h60:VE`@80
Z[7M0P2e/MD50:^mi`@0Z<3[?`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P0000040?ooo`80
00002P3oool00100oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?oood40
Yl3[0`00000N0:O0j`80Yko[1@2W_^X30:Nkj0D0X934102RTL<20:FNcP<0XWbY1@2YUL450;Fae@D0
[l;X102X`>/o0:O0j`030000002W`>/0Yl3[0140Yl3[3P3oool300000100oooo000A0?ooo`800000
103oool2000000L0oooo?@2W`>/3000001l0Yl3[1@2W_n/40:NnjP@0XIc@1@2PT<@30::A``D0XWbY
102YUL420;ZH]0<0]K7E0P38a]P40:o2j0D0Z<3[?`2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo
00<000000?ooo`3oool03P3oool001L0oooo00<000000?ooo`3oool01`3oooli0:O0j`<000008`2W
`>/50:Noj`@0Y:oO0`2QW=050:2@a080XY730P2KKil50:9lZ@80ZIG10`2jV;@20;Fae@@0b<KH102_
`nP50:S0jch0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00d0oooo000G
0?ooo`030000003oool0oooo00P0oooo=@2W`>/3000002L0Yl3[1@2V^nP40:B_g`<0XIc@102PT<@4
09]_W`D0XWbY00<0ZIG10;ZH]02jV;@00P2jV;@50<S6f080b/WI102_`nP50:S0jch0Yl3[00<00000
0:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00`0oooo000G0?ooo`8000002@3ooolc0:O0
j`8000009`2W`>/40:Noj`D0Y[_X0`2T[ml30:6Ld0D0TfZO0`2KKil50:9lZ@D0^YRd00@0hl:f0<S6
f038a]P0b<KH103:bMT40:o3j0D0Z<3[?P2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo00<00000
0?ooo`3oool0303oool001L0oooo00<000000?ooo`3oool02P3oool^0:O0j`<00000:P2W`>/40:No
j`@0Y[_X102:Q<L308a]Z`@0TfZO0`2KKil50:9lZ@040;F4X02jV;@0^YRd0;ZH]0<0hl:f1P3:bMT5
0:o3j0D0Z<3[?P2W`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo00<000000?ooo`3oool02`3oool0
01H0oooo00<000000?ooo`3oool0303ooolZ0:O0j`<00000;P2W`>/40::kj`@0UjWS0`2:Q<L308a]
Z`@0TfZO102KKil30:9lZ@80]HBP0`2jV;@30>?2]P030>S7]P3:bMT0b/WI00@0b/WI1@2_`nP40:S0
jch0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00X0oooo000F0?ooo`80
00003P3ooolV0:O0j`<00000;@2W`>/50:Joj`@0X[_[0`2GZN<308Z4a`<0S6f[102CJYl409]_W`80
XWbY102eQ:000`2jV;@0hl:f0>?2]P020>?2]P80j<Nf1P3:bMT50:o3j0@0Z<3[?P2W`>/00`000000
Yl3[0:O0j`0@0:O0j`l0oooo0P00000<0?ooo`005P3oool00`000000oooo0?ooo`0>0?ooob80Yl3[
0`00000a0:O0j`D0Y[o[0`2R^n/309NYh`<0RXC70`2<KJ/409=ZW`@0VfnO0P2RO:T40;F4X0040;ZH
]03S`[H0hl:f0>?2]P@0j<Nf1P3:bMT50:o3j0@0Z<3[?P2W`>/00`000000Yl3[0:O0j`0@0:O0ja00
oooo00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0403ooolM0:O0j`<00000
=@2W`>/50:>nk0<0SK;_0P0mMMh408Z4a`80S6f[102CJYl409]_W`030:9lZ@2eQ:00]HBP00<0]HBP
103S`[H50>S7]PD0b/WI1P2_`nP40:S0jcd0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000
003oool0oooo00P0oooo000F0?ooo`8000004P3ooolI0:O0j`<00000>@2W`>/50:>nk0<0SK;_0P0m
MMh308Z4a`80S6f[1@2CJYl309]_W`H0]HBP00<0jkZP0>?2]P3S`[H01`3XakH50<[9f@H0[l?X102X
`>/m0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`080?ooo`005P3oool0
0`000000oooo0?ooo`0B0?oooaD0Yl3[0`00000m0:O0j`@0Xkk/0`2=/^l203eegP0301<`[@2:Q<L0
RXC700<0S6f[102CJYl309]_W`030:UfVP2eQ:00]HBP00<0]HBP0P3[^Z000`3S`[H0j<Nf0>S7]P06
0>S7]PD0b/WI1P2_`nP40:S0jcd0Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`8000002@3oool0
00<0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0503ooolA0:O0
j`<00000?`2W`>/20:Jok0@0Wkg^0`1SX_@0100mMMh04c2]01<`[@2:Q<L308a]Z`@0TfZO0P2KKil2
0:UfVP@0]HBP0`3[^Z0:0>S7]PD0b/WI1@2_`nP50:S0jcd0Yl3[00<000000:O0j`2W`>/0402W`>/;
0?ooo`<0000000<0oooo0000003oool0203oool00080oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo3P2W`>/200000400Yl3[1@2V
_n`409nmkP<0Hj;d00<0?GGN01<`[@0C<:d00`2<KJ/409=ZW`80VfnO0P2YMYX40;F4X0<0jkZP00<0
lL6M0>S7]P3XakH0203XakH50<[9f@D0[l?X1@2X`>/l0:O0j`030000002W`>/0Yl3[0140Yl3[1P3o
ool4000000@0oooo00<000000?ooo`3oool01`3oool00080oooo00@000000?ooo`3oool000002`3o
ool010000000oooo0?ooo`3oool2000001L0oooo2P2W`>/3000004<0Yl3[102V_n`509jmkP<0GIoc
0`0C<:d208a]Z`@0TfZO00@0VfnO0:UfVP2YMYX0ZGJJ102eQ:030>^jX080lL6M2@3XakH60<[9f@@0
[l?X1P2X`>/l0:O0j`030000002W`>/0Yl3[0140Yl3[0P3oool3000000P0oooo00<000000?ooo`3o
ool01`3oool00080oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3o
ool0603oool50:O0j`<00000A`2W`>/40:Jok0D0W[g^0P1MWo<301<`[@0305a6W`2<KJ/0TfZO00<0
TfZO00@0VfnO0:UfVP2YMYX0ZGJJ0`2eQ:030>^jX0@0lL6M2@3XakH60<[9f@@0[l?X1@2X`>/m0:O0
j`030000002W`>/0Yl3[0100Yl3[0P00000<0?ooo`030000003oool0oooo00H0oooo00020?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?oo
o`040:O0j`0000000000000004/0Yl3[102V_n`509jmkP80GIoc0P0C<:d205a6W`@0TfZO1@2YMYX2
0;F4X0<0jkZP1@3a`Id90>S7]PH0b/WI102_`nP50:S0jcd0Yl3[00<000000:O0j`2W`>/0402W`>/=
0?ooo`030000003oool0oooo00H0oooo00030?ooo`8000002P3oool3000000<0oooo0P00000H0?oo
o`<00000C`2W`>/40:Jok0D0W[g^00<0GIoc01<`[@0C<:d00P1LAYl5095TVP@0ZGJJ0P2eQ:030>^j
X0H0lL6M2@3XakH60<[9f@@0[l?X102X`>/m0:O0j`030000002W`>/0Yl3[0100Yl3[3@3oool00`00
0000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`<00000103ooom?0:O0j`@0
Y[o/1@2N_Nh00`1MWo<04c2]05a6W`0205a6W`@0TFBJ102YMYX0102eQ:00jkZP0>^jX03[^Z080?71
W@P0j<Nf1`3:bMT40:o3j0@0Z<3[?@2W`>/00`000000Yl3[0:O0j`0@0:O0j``0oooo00<000000?oo
o`3oool01P3oool001@0oooo00<000000?ooo`3oool04P3oool3000000P0ooooC`2W`>/40:Jok0D0
W[g^00@04c2]05a6W`1LAYl0G4JO102AI9X40:UfVP040;F4X03[^Z00jkZP0>^jX0T0lL6M203XakH6
0<[9f@D0[l?X102X`>/m0:O0j`030000002W`>/0Yl3[0100Yl3[2`3oool00`000000oooo0?ooo`06
0?ooo`00503oool200000100oooo0`00000<0?ooodl0Yl3[102V_n`409jmkP804c2]0P1LAYl4095T
VP@0ZGJJ00@0]HBP0>^jX03[^Z00jkZP2@3a`Id90>S7]PH0b/WI1@2_`nP40:S0jcd0Yl3[00<00000
0:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo
00`0oooo0`00000A0?ooodh0Yl3[102V_n`409jmkP0301<`[@1LAYl0G4JO00@0TFBJ102YMYX30>^j
X0/0lL6M2@3XakH60<[9f@D0[l?X102X`>/l0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool00`00
0000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`8000005@3ooom>0:O0j`@0
Y[o/0`2N_Nh00`0C<:d0G4JO05a6W`04095TVP@0ZGJJ00<0ikJQ0>^jX03[^Z00303a`Id90>S7]PH0
b/WI102_`nP50:S0jc`0Yl3[00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00D0
oooo000D0?ooo`030000003oool0oooo00L0oooo0`00000H0?ooodh0Yl3[102V_n`309jmkP80G4JO
102AI9X40:UfVP80ikJQ00<0jkZP0?71W@3a`Id02`3a`Id90>S7]PH0b/WI102_`nP50:S0jc`0Yl3[
00<000000:O0j`2W`>/03`2W`>/:0?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000001@3o
ool3000001`0ooooCP2W`>/40:Jok080W[g^0P1LAYl4095TVP@0ZGJJ0P3W]Z4?0?71W@T0j<Nf1P3:
bMT40:o3j0D0Z<3[?02W`>/00`000000Yl3[0:O0j`0?0:O0j`T0oooo00<000000?ooo`3oool01@3o
ool001<0oooo00<000000?ooo`3oool00P3oool300000200ooooCP2W`>/40:Jok00309jmkP1LAYl0
G4JO00D0TFBJ0P2YMYX30>NfX@030?72WP3a`Id0lL6M00d0lL6M2@3XakH60<[9f@@0[l?X102X`>/l
0:O0j`030000002W`>/0Yl3[0100Yl3[203oool00`000000oooo0?ooo`050?ooo`004`3oool00`00
0000oooo00000002000002@0ooooCP2W`>/40:Jok00309jmkP1LAYl0G4JO00@0TFBJ0P2YMYX30>Nf
X@80lL:N3`3a`Id90>S7]P@0b/WI0P3;c=X40:o3j0D0Z<7[>`2W`>/00`000000Yl3[0:O0j`0@0:O0
j`L0oooo00<000000?ooo`3oool01@3oool001<0oooo0`00000W0?ooodh0Yl3[102V_n`205a6W`@0
TFBJ0P2YMYX30>NfX@80lL:N403a`Id90>S7]P80b/WI0`3;c=X50:o6j`80Z<7[0`2X`>/k0:O0j`03
0000002W`>/0Yl3[00l0Yl3[1`3oool00`000000oooo0?ooo`050?ooo`00503oool00`000000oooo
0?ooo`0W0?ooodh0Yl3[0`2V_n`205a6W`@0TFBJ0P2YMYX30>NfX@<0lL:N403a`Id80>S7]P@0blcJ
0P3?hnH40:o6j`H0Z<3[>P2W`>/00`000000Yl3[0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool0
103oool000/0oooo1@0000050?ooo`800000:@3ooom=0:O0j`<0Y[o/00<0G4JO095TVP2AI9X00P2A
I9X0102YMYX0ikJQ0>NfX@3W]Z450?72WQ00lL6M1`3XakH20>c>]PD0cn?V1@2[a>`o0:O0j`030000
002W`>/0Yl3[0100Yl3[1P3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02L0ooooC@2W`>/20:Jok00305a6W`2AI9X0TFBJ0080TFBJ00@0
ZGJJ0>NfX@3W]Z40ikJQ1P3a`Yh?0?71W@H0j<Nf0`3/c[H20>GbV0@0_=[_0`2[a>`20:S1jcl0Yl3[
00<000000:O0j`2W`>/0402W`>/50?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool09`3ooom=0:O0j`030:Jok01LAYl0TFBJ00<0TFBJ00@0
ZGJJ0>NfX@3W]Z40ikJQ1`3a`Yh?0?71W@D0j<Nf0`3/c[H00`3UlYP0bog10<_m`@040;cJk`D0Z<7[
?`2W`>/00`000000Yl3[0:O0j`0?0:O0j`D0oooo00<000000?ooo`3oool0103oool000d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooodd0Yl3[00<0Y[o/095TVP2AI9X00P2A
I9X0102YMYX0ikJQ0>NfX@3W]Z480?72WPl0lL6M0`3XakH30>c>]P040>GbV03;oL40bog10<_m`@D0
[<K]@`2W`>/00`000000Yl3[0:O0j`0@0:O0j`@0oooo00<000000?ooo`3oool0103oool000d0oooo
00<000000?ooo`3oool02P3oool2000002P0ooooC@2W`>/4095TVP<0ikJQ2P3a`Yh?0?71W@80j<Nf
0`3/c[H00`3;oL40]mWa0;OIl@030;OIl@@0Z<7[@`2W`>/00`000000Yl3[0:O0j`0?0:O0j`@0oooo
00<000000?ooo`3oool0103oool000`0oooo0P00000>0?ooo`030000003oool0oooo02H0ooooC02W
`>/50:>Od@80ikJQ2`3a`Yh?0?71W@<0k<jf00<000000;ghkP2mn>h00`2gfO420:W2k0@0Z<7[@`2W
`>/00`000000Yl3[0:O0j`0?0:O0j`<0oooo00<000000?ooo`3oool0103oool001d0oooo00<00000
0?ooo`3oool09P3ooom<0:O0j`@0XioA0P3W]Z4<0?72WPh0lL6M00<0mlVK0>c>]P3/c[H0102mn>h5
0:W2k4L0Yl3[00<000000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo00<0oooo000N0?oo
o`030000003oool0oooo02H0ooooB`2W`>/50:>Od@030>NfX@3a`Yh0lL:N00/0lL:N3@3a`Id20?O9
V`0307gR^02[a^h0ZlK^00<0ZlK^B`2W`>/00`000000Yl3[0:O0j`0@0:O0j`80oooo00<000000?oo
o`3oool00`3oool001l0oooo0P00000X0?ooodX0Yl3[102SWm4?0?72WP`0lL6M0P3gbI/30:[9l4l0
Yl3[00<000000:O0j`2W`>/0402W`>/00`3oool000000?ooo`040?ooo`008@3oool00`000000oooo
0?ooo`0V0?ooodT0Yl3[1@2U`nl?0?72WPX0lL6M0`3gbI]C0:O0j`030000002W`>/0Yl3[00l0Yl3[
00<0oooo0000003oool0103oool00280oooo00<000000?ooo`3oool09P3ooom90:O0j`D0YL?_3`3a
`Yh90?71W@<0mlVKE02W`>/00`000000Yl3[0:O0j`0?0:O0j`030000003oool0oooo00<0oooo000S
0?ooo`030000003oool0oooo02H0ooooB@2W`>/50:G3k`l0lL:N203a`Id20?O9VeD0Yl3[00<00000
0:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2000002L0ooooB@2W`>/50:G3
k`h0lL:N203a`Id20?O9VeH0Yl3[00<000000:O0j`2W`>/02`2W`>/30?ooo`030000003oool0oooo
00<0oooo000V0?ooo`030000003oool0oooo02D0ooooB@2W`>/50:G3k`h0lL:N1P3a`Id30?O9VeL0
Yl3[00<000000:O0j`2W`>/01P2W`>/80?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo02D0ooooB@2W`>/40:G3k`l0lL:N1@3a`Id30?O9VeL0Yl3[00<000000:O0j`2W`>/0
0`2W`>/;0?ooo`030000003oool0oooo0080oooo000X0?ooo`030000003oool0oooo02H0ooooB02W
`>/40:G3ka00lL:N0`3a`Id20?O9VeT0Yl3[00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`020?ooo`00:@3oool2000002L0ooooB02W`>/40:G3ka00lL:N0P3a`Id20?O9VeL0Yl3[0`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo
02D0ooooB02W`>/40:G3ka00lL:N0`3gbI]C0:O0j`P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?ooodP0Yl3[102U`nl?0?72WP80
n/nJD@2W`>/;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002d0oooo
00<000000?ooo`3oool09P3ooom70:O0j`@0YL?_3P3a`Yh20?[?VTh0Yl3[3`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0040oooo000^0?ooo`030000003oool0oooo02H0ooooA`2W
`>/40:G3k``0lL:N0`3jciY:0:O0ja@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`010?ooo`00;`3oool2000002L0ooooA`2W`>/40:G3k`/0lL:N0P3jciY80:O0jaP0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0U0?oo
odL0Yl3[102U`nl:0?72WP80n/nJA02W`>/L0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00@3oool00380oooo00<000000?ooo`3oool09@3ooom70:O0j`@0YL?_203a`Yh30?[?VT40
Yl3[803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000c0?ooo`030000
003oool0oooo02D0ooooA`2W`>/40:G3k`L0lL:N0P3jciXo0:O0jb@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`010?ooo`00=03oool2000002H0ooooAP2W`>/50:G3k`H0lL:N0P3j
ciXk0:O0jbT0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`010?ooo`00=P3oool0
0`000000oooo0?ooo`0U0?ooodD0Yl3[1@2U`nl40?72WP<0n/nJ>02W`>//0?ooo`030000003oool0
oooo00L0oooo0@0000010?ooo`40oooo000g0?ooo`030000003oool0oooo02D0ooooA@2W`>/50:G3
k`<0lL:N0P3jciXf0:O0jc00oooo00<000000?ooo`3oool01P3oool100000040oooo0@3oool003P0
oooo00<000000?ooo`3oool09@3ooom50:O0j`D0YL?_0P3a`Yh20?[?VRl0Yl3[>03oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>@3oool2000002H0ooooA@2W`>/50:G3k`<0n/nJ
;02W`>/k0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo000k0?ooo`030000003o
ool0oooo02@0ooooAP2W`>/5077OkBX0Yl3[?`3oool00`000000oooo0?ooo`040?ooo`4000000@3o
ool10?ooo`00?03oool00`000000oooo0?ooo`0T0?ooog40Yl3[@`3oool00`000000oooo0?ooo`03
0?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?ooo`0T0?ooof`0Yl3[B03oool00`00
0000oooo0?ooo`020?ooo`4000000@3oool10?ooo`00?P3oool2000002D0ooooJ02W`>];0?ooo`03
0000003oool0oooo00<0oooo0@0000010?ooo`00@03oool00`000000oooo0?ooo`0S0?ooof@0Yl3[
C`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3o
oomP0:O0je<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3oool00`000000oooo0?oo
o`0T0?oooe/0Yl3[E`3oool010000000oooo0?ooo`0000010?ooo`00@`3oool2000002D0ooooD`2W
`>]N0?ooo`040000003oool0oooo00000040oooo00150?ooo`030000003oool0oooo02<0ooooC`2W
`>]R0?ooo`030000003oool000000040oooo00160?ooo`030000003oool0oooo02<0ooooB`2W`>]V
0?ooo`4000000@3oool100000000A`3oool00`000000oooo0?ooo`0S0?ooodL0Yl3[JP3oool20000
0000B03oool2000002D0oooo@P2W`>]]0?ooo`800000001:0?ooo`030000003oool0oooo02<0oooo
?P2W`>]`0?ooo`800000001;0?ooo`030000003oool0oooo0280oooo>`2W`>]_0?ooo`@000000P3o
ool004`0oooo00<000000?ooo`3oool08`3ooolc0:O0jg40oooo100000060?ooo`00C@3oool20000
02@0oooo;`2W`>]`0?ooo`@000002P3oool004l0oooo00<000000?ooo`3oool08P3oool[0:O0jfl0
oooo1000000>0?ooo`00D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo
001A0?ooo`030000003oool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580oooo0P00000T
0?oooah0Yl3[K@3oool4000001T0oooo001D0?ooo`030000003oool0oooo0280oooo5`2W`>]_0?oo
o`@000007@3oool005D0oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00
EP3oool00`000000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?ooo`8000008`3o
ool;0:O0jf`0oooo1000000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool3
000002d0oooo001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool40000
0300oooo001K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0
oooo001L0?ooo`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool005h0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00000L0?ooo`03
0000003oool0oooo05<0oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo04/0oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo04L0oooo1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04<0oooo1000001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03oool3000005/0
oooo001Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4000005h0oooo
001Z0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?oo
o`800000403oool00`000000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`030000003oool0
oooo0280oooo1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01h0oooo1000001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0
oooo100000210?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo
100000250?ooo`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003o
ool0103oool4000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3o
ool200000:00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Mtetra
.59604 .63937 .60194 .6454 .6135 .64214 .60764 .63608 Mtetra
.60764 .63608 .6135 .64214 .62511 .63886 .61928 .63278 Mtetra
.61928 .63278 .62511 .63886 .63677 .63557 .63097 .62947 Mtetra
.63097 .62947 .63677 .63557 .64848 .63227 .64272 .62614 Mtetra
.64272 .62614 .64848 .63227 .66023 .62896 .65451 .62281 Mtetra
.656 .752 .92 r
.65451 .62281 .66023 .62896 .67204 .62563 .66635 .61945 Mtetra
.66635 .61945 .67204 .62563 .6839 .62228 .67824 .61608 Mtetra
.67824 .61608 .6839 .62228 .6958 .61893 .69018 .6127 Mtetra
.69018 .6127 .6958 .61893 .70776 .61556 .70217 .6093 Mtetra
.656 .751 .92 r
.70217 .6093 .70776 .61556 .71976 .61217 .71421 .60589 Mtetra
.71421 .60589 .71976 .61217 .73182 .60878 .7263 .60246 Mtetra
.7263 .60246 .73182 .60878 .74393 .60536 .73845 .59902 Mtetra
.73845 .59902 .74393 .60536 .75609 .60193 .75064 .59557 Mtetra
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62666 Mtetra
.61341 .62666 .61928 .63278 .63097 .62947 .62514 .62332 Mtetra
.62514 .62332 .63097 .62947 .64272 .62614 .63691 .61996 Mtetra
.63691 .61996 .64272 .62614 .65451 .62281 .64873 .6166 Mtetra
.64873 .6166 .65451 .62281 .66635 .61945 .66061 .61321 Mtetra
.66061 .61321 .66635 .61945 .67824 .61608 .67253 .60982 Mtetra
.67253 .60982 .67824 .61608 .69018 .6127 .68451 .60641 Mtetra
.68451 .60641 .69018 .6127 .70217 .6093 .69653 .60299 Mtetra
.69653 .60299 .70217 .6093 .71421 .60589 .70861 .59955 Mtetra
.70861 .59955 .71421 .60589 .7263 .60246 .72074 .5961 Mtetra
.72074 .5961 .7263 .60246 .73845 .59902 .73292 .59263 Mtetra
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Mtetra
.59578 .62383 .60173 .62998 .61341 .62666 .60749 .62048 Mtetra
.60749 .62048 .61341 .62666 .62514 .62332 .61925 .61712 Mtetra
.61925 .61712 .62514 .62332 .63691 .61996 .63106 .61374 Mtetra
.63106 .61374 .63691 .61996 .64873 .6166 .64292 .61035 Mtetra
.656 .752 .92 r
.64292 .61035 .64873 .6166 .66061 .61321 .65482 .60694 Mtetra
.65482 .60694 .66061 .61321 .67253 .60982 .66678 .60352 Mtetra
.66678 .60352 .67253 .60982 .68451 .60641 .67879 .60008 Mtetra
.67879 .60008 .68451 .60641 .69653 .60299 .69085 .59663 Mtetra
.656 .751 .92 r
.69085 .59663 .69653 .60299 .70861 .59955 .70297 .59317 Mtetra
.70297 .59317 .70861 .59955 .72074 .5961 .71513 .58968 Mtetra
.71513 .58968 .72074 .5961 .73292 .59263 .72735 .58619 Mtetra
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Mtetra
.60153 .61426 .60749 .62048 .61925 .61712 .61332 .61087 Mtetra
.61332 .61087 .61925 .61712 .63106 .61374 .62516 .60746 Mtetra
.62516 .60746 .63106 .61374 .64292 .61035 .63705 .60404 Mtetra
.63705 .60404 .64292 .61035 .65482 .60694 .649 .60061 Mtetra
.649 .60061 .65482 .60694 .66678 .60352 .66099 .59716 Mtetra
.66099 .59716 .66678 .60352 .67879 .60008 .67303 .5937 Mtetra
.67303 .5937 .67879 .60008 .69085 .59663 .68513 .59022 Mtetra
.68513 .59022 .69085 .59663 .70297 .59317 .69728 .58673 Mtetra
.69728 .58673 .70297 .59317 .71513 .58968 .70948 .58322 Mtetra
.70948 .58322 .71513 .58968 .72735 .58619 .72173 .5797 Mtetra
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Mtetra
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Mtetra
.59552 .60799 .60153 .61426 .61332 .61087 .60734 .60457 Mtetra
.60734 .60457 .61332 .61087 .62516 .60746 .61922 .60114 Mtetra
.61922 .60114 .62516 .60746 .63705 .60404 .63114 .5977 Mtetra
.656 .752 .92 r
.63114 .5977 .63705 .60404 .649 .60061 .64312 .59424 Mtetra
.64312 .59424 .649 .60061 .66099 .59716 .65515 .59076 Mtetra
.65515 .59076 .66099 .59716 .67303 .5937 .66723 .58727 Mtetra
.66723 .58727 .67303 .5937 .68513 .59022 .67936 .58376 Mtetra
.67936 .58376 .68513 .59022 .69728 .58673 .69154 .58024 Mtetra
.656 .751 .92 r
.69154 .58024 .69728 .58673 .70948 .58322 .70378 .5767 Mtetra
.70378 .5767 .70948 .58322 .72173 .5797 .71607 .57315 Mtetra
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56959 Mtetra
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Mtetra
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Mtetra
.58946 .60167 .59552 .60799 .60734 .60457 .60132 .59822 Mtetra
.60132 .59822 .60734 .60457 .61922 .60114 .61323 .59476 Mtetra
.61323 .59476 .61922 .60114 .63114 .5977 .62519 .59129 Mtetra
.62519 .59129 .63114 .5977 .64312 .59424 .6372 .5878 Mtetra
.6372 .5878 .64312 .59424 .65515 .59076 .64926 .5843 Mtetra
.64926 .5843 .65515 .59076 .66723 .58727 .66138 .58078 Mtetra
.66138 .58078 .66723 .58727 .67936 .58376 .67354 .57725 Mtetra
.67354 .57725 .67936 .58376 .69154 .58024 .68576 .5737 Mtetra
.68576 .5737 .69154 .58024 .70378 .5767 .69804 .57013 Mtetra
.69804 .57013 .70378 .5767 .71607 .57315 .71036 .56656 Mtetra
.71036 .56656 .71607 .57315 .72841 .56959 .72274 .56296 Mtetra
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59876 Mtetra
.57151 .59876 .57765 .6051 .58946 .60167 .58335 .5953 Mtetra
.58335 .5953 .58946 .60167 .60132 .59822 .59525 .59183 Mtetra
.59525 .59183 .60132 .59822 .61323 .59476 .60719 .58834 Mtetra
.656 .752 .92 r
.60719 .58834 .61323 .59476 .62519 .59129 .61918 .58485 Mtetra
.61918 .58485 .62519 .59129 .6372 .5878 .63123 .58133 Mtetra
.656 .752 .921 r
.63123 .58133 .6372 .5878 .64926 .5843 .64333 .5778 Mtetra
.64333 .5778 .64926 .5843 .66138 .58078 .65548 .57425 Mtetra
.656 .752 .92 r
.65548 .57425 .66138 .58078 .67354 .57725 .66768 .57069 Mtetra
.66768 .57069 .67354 .57725 .68576 .5737 .67994 .56711 Mtetra
.656 .751 .92 r
.67994 .56711 .68576 .5737 .69804 .57013 .69225 .56351 Mtetra
.69225 .56351 .69804 .57013 .71036 .56656 .70461 .55991 Mtetra
.70461 .55991 .71036 .56656 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Mtetra
.56532 .59236 .57151 .59876 .58335 .5953 .5772 .58888 Mtetra
.5772 .58888 .58335 .5953 .59525 .59183 .58913 .58538 Mtetra
.58913 .58538 .59525 .59183 .60719 .58834 .6011 .58186 Mtetra
.6011 .58186 .60719 .58834 .61918 .58485 .61313 .57833 Mtetra
.61313 .57833 .61918 .58485 .63123 .58133 .62521 .57479 Mtetra
.62521 .57479 .63123 .58133 .64333 .5778 .63735 .57123 Mtetra
.63735 .57123 .64333 .5778 .65548 .57425 .64953 .56765 Mtetra
.64953 .56765 .65548 .57425 .66768 .57069 .66177 .56406 Mtetra
.66177 .56406 .66768 .57069 .67994 .56711 .67407 .56046 Mtetra
.67407 .56046 .67994 .56711 .69225 .56351 .68641 .55684 Mtetra
.68641 .55684 .69225 .56351 .70461 .55991 .69881 .5532 Mtetra
.69881 .5532 .70461 .55991 .71703 .55628 .71127 .54955 Mtetra
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Mtetra
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58592 Mtetra
.55909 .58592 .56532 .59236 .5772 .58888 .571 .58241 Mtetra
.571 .58241 .5772 .58888 .58913 .58538 .58296 .57888 Mtetra
.58296 .57888 .58913 .58538 .6011 .58186 .59497 .57534 Mtetra
.656 .752 .92 r
.59497 .57534 .6011 .58186 .61313 .57833 .60703 .57179 Mtetra
.656 .752 .921 r
.60703 .57179 .61313 .57833 .62521 .57479 .61915 .56822 Mtetra
.61915 .56822 .62521 .57479 .63735 .57123 .63132 .56463 Mtetra
.63132 .56463 .63735 .57123 .64953 .56765 .64354 .56102 Mtetra
.64354 .56102 .64953 .56765 .66177 .56406 .65582 .5574 Mtetra
.656 .752 .92 r
.65582 .5574 .66177 .56406 .67407 .56046 .66815 .55376 Mtetra
.656 .751 .92 r
.66815 .55376 .67407 .56046 .68641 .55684 .68053 .55011 Mtetra
.68053 .55011 .68641 .55684 .69881 .5532 .69297 .54644 Mtetra
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Mtetra
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Mtetra
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Mtetra
.52907 .58646 .53542 .5929 .54723 .58942 .54091 .58295 Mtetra
.54091 .58295 .54723 .58942 .55909 .58592 .5528 .57943 Mtetra
.5528 .57943 .55909 .58592 .571 .58241 .56474 .57589 Mtetra
.56474 .57589 .571 .58241 .58296 .57888 .57674 .57233 Mtetra
.57674 .57233 .58296 .57888 .59497 .57534 .58878 .56876 Mtetra
.58878 .56876 .59497 .57534 .60703 .57179 .60088 .56517 Mtetra
.60088 .56517 .60703 .57179 .61915 .56822 .61304 .56156 Mtetra
.61304 .56156 .61915 .56822 .63132 .56463 .62524 .55794 Mtetra
.62524 .55794 .63132 .56463 .64354 .56102 .6375 .55431 Mtetra
.6375 .55431 .64354 .56102 .65582 .5574 .64981 .55067 Mtetra
.64981 .55067 .65582 .5574 .66815 .55376 .66218 .54701 Mtetra
.66218 .54701 .66815 .55376 .68053 .55011 .6746 .54333 Mtetra
.6746 .54333 .68053 .55011 .69297 .54644 .68707 .53963 Mtetra
.68707 .53963 .69297 .54644 .70546 .54276 .69961 .53592 Mtetra
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53219 Mtetra
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Mtetra
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57997 Mtetra
.52266 .57997 .52907 .58646 .54091 .58295 .53454 .57643 Mtetra
.53454 .57643 .54091 .58295 .5528 .57943 .54646 .57288 Mtetra
.54646 .57288 .5528 .57943 .56474 .57589 .55844 .56931 Mtetra
.55844 .56931 .56474 .57589 .57674 .57233 .57047 .56573 Mtetra
.57047 .56573 .57674 .57233 .58878 .56876 .58255 .56213 Mtetra
.656 .752 .921 r
.58255 .56213 .58878 .56876 .60088 .56517 .59469 .55852 Mtetra
.59469 .55852 .60088 .56517 .61304 .56156 .60687 .5549 Mtetra
.60687 .5549 .61304 .56156 .62524 .55794 .61911 .55125 Mtetra
.61911 .55125 .62524 .55794 .6375 .55431 .63141 .54758 Mtetra
.63141 .54758 .6375 .55431 .64981 .55067 .64376 .5439 Mtetra
.656 .752 .92 r
.64376 .5439 .64981 .55067 .66218 .54701 .65616 .5402 Mtetra
.65616 .5402 .66218 .54701 .6746 .54333 .66862 .53649 Mtetra
.656 .751 .92 r
.66862 .53649 .6746 .54333 .68707 .53963 .68113 .53276 Mtetra
.68113 .53276 .68707 .53963 .69961 .53592 .6937 .52902 Mtetra
.6937 .52902 .69961 .53592 .71219 .53219 .70633 .52525 Mtetra
.70633 .52525 .71219 .53219 .72483 .52844 .71901 .52148 Mtetra
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Mtetra
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Mtetra
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Mtetra
.49255 .58051 .49907 .587 .51084 .58349 .50435 .57698 Mtetra
.50435 .57698 .51084 .58349 .52266 .57997 .51621 .57343 Mtetra
.51621 .57343 .52266 .57997 .53454 .57643 .52812 .56986 Mtetra
.52812 .56986 .53454 .57643 .54646 .57288 .54008 .56628 Mtetra
.54008 .56628 .54646 .57288 .55844 .56931 .55209 .56268 Mtetra
.55209 .56268 .55844 .56931 .57047 .56573 .56415 .55907 Mtetra
.56415 .55907 .57047 .56573 .58255 .56213 .57627 .55544 Mtetra
.57627 .55544 .58255 .56213 .59469 .55852 .58844 .55179 Mtetra
.58844 .55179 .59469 .55852 .60687 .5549 .60066 .54812 Mtetra
.656 .75 .92 r
.60066 .54812 .60687 .5549 .61911 .55125 .61294 .54444 Mtetra
.61294 .54444 .61911 .55125 .63141 .54758 .62527 .54076 Mtetra
.656 .751 .92 r
.62527 .54076 .63141 .54758 .64376 .5439 .63765 .53705 Mtetra
.63765 .53705 .64376 .5439 .65616 .5402 .65009 .53333 Mtetra
.65009 .53333 .65616 .5402 .66862 .53649 .66259 .52959 Mtetra
.66259 .52959 .66862 .53649 .68113 .53276 .67514 .52583 Mtetra
.67514 .52583 .68113 .53276 .6937 .52902 .68775 .52206 Mtetra
.68775 .52206 .6937 .52902 .70633 .52525 .70041 .51827 Mtetra
.70041 .51827 .70633 .52525 .71901 .52148 .71313 .51446 Mtetra
.71313 .51446 .71901 .52148 .73175 .51768 .72591 .51063 Mtetra
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Mtetra
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Mtetra
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Mtetra
.47419 .57752 .48079 .58403 .49255 .58051 .48598 .57397 Mtetra
.48598 .57397 .49255 .58051 .50435 .57698 .49781 .57041 Mtetra
.49781 .57041 .50435 .57698 .51621 .57343 .5097 .56683 Mtetra
.5097 .56683 .51621 .57343 .52812 .56986 .52164 .56324 Mtetra
.52164 .56324 .52812 .56986 .54008 .56628 .53364 .55963 Mtetra
.53364 .55963 .54008 .56628 .55209 .56268 .54568 .556 Mtetra
.54568 .556 .55209 .56268 .56415 .55907 .55778 .55236 Mtetra
.656 .752 .921 r
.55778 .55236 .56415 .55907 .57627 .55544 .56993 .54871 Mtetra
.655 .752 .921 r
.56993 .54871 .57627 .55544 .58844 .55179 .58214 .54505 Mtetra
.58214 .54505 .58844 .55179 .60066 .54812 .5944 .54137 Mtetra
.656 .753 .921 r
.5944 .54137 .60066 .54812 .61294 .54444 .60671 .53766 Mtetra
.60671 .53766 .61294 .54444 .62527 .54076 .61908 .53393 Mtetra
.61908 .53393 .62527 .54076 .63765 .53705 .6315 .53018 Mtetra
.656 .752 .921 r
.6315 .53018 .63765 .53705 .65009 .53333 .64398 .52642 Mtetra
.656 .752 .92 r
.64398 .52642 .65009 .53333 .66259 .52959 .65651 .52264 Mtetra
.656 .751 .92 r
.65651 .52264 .66259 .52959 .67514 .52583 .6691 .51885 Mtetra
.6691 .51885 .67514 .52583 .68775 .52206 .68175 .51504 Mtetra
.68175 .51504 .68775 .52206 .70041 .51827 .69445 .51122 Mtetra
.69445 .51122 .70041 .51827 .71313 .51446 .70721 .50738 Mtetra
.70721 .50738 .71313 .51446 .72591 .51063 .72003 .50352 Mtetra
.72003 .50352 .72591 .51063 .73875 .50679 .7329 .49965 Mtetra
.7329 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Mtetra
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Mtetra
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57096 Mtetra
.46753 .57096 .47419 .57752 .48598 .57397 .47935 .56738 Mtetra
.47935 .56738 .48598 .57397 .49781 .57041 .49122 .56379 Mtetra
.49122 .56379 .49781 .57041 .5097 .56683 .50314 .56018 Mtetra
.50314 .56018 .5097 .56683 .52164 .56324 .51512 .55656 Mtetra
.51512 .55656 .52164 .56324 .53364 .55963 .52715 .55292 Mtetra
.52715 .55292 .53364 .55963 .54568 .556 .53923 .54927 Mtetra
.655 .751 .921 r
.53923 .54927 .54568 .556 .55778 .55236 .55136 .54562 Mtetra
.654 .751 .921 r
.55136 .54562 .55778 .55236 .56993 .54871 .56355 .54198 Mtetra
.653 .752 .923 r
.56355 .54198 .56993 .54871 .58214 .54505 .57579 .53836 Mtetra
.653 .755 .924 r
.57579 .53836 .58214 .54505 .5944 .54137 .58809 .53471 Mtetra
.655 .757 .925 r
.58809 .53471 .5944 .54137 .60671 .53766 .60044 .53098 Mtetra
.658 .758 .924 r
.60044 .53098 .60671 .53766 .61908 .53393 .61284 .52715 Mtetra
.658 .756 .922 r
.61284 .52715 .61908 .53393 .6315 .53018 .6253 .5233 Mtetra
.657 .754 .921 r
.6253 .5233 .6315 .53018 .64398 .52642 .63781 .51946 Mtetra
.656 .752 .921 r
.63781 .51946 .64398 .52642 .65651 .52264 .65038 .51564 Mtetra
.656 .752 .92 r
.65038 .51564 .65651 .52264 .6691 .51885 .66301 .51181 Mtetra
.656 .751 .92 r
.66301 .51181 .6691 .51885 .68175 .51504 .6757 .50797 Mtetra
.6757 .50797 .68175 .51504 .69445 .51122 .68844 .50412 Mtetra
.68844 .50412 .69445 .51122 .70721 .50738 .70124 .50024 Mtetra
.70124 .50024 .70721 .50738 .72003 .50352 .7141 .49635 Mtetra
.7141 .49635 .72003 .50352 .7329 .49965 .72701 .49245 Mtetra
.72701 .49245 .7329 .49965 .74584 .49575 .73999 .48852 Mtetra
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Mtetra
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Mtetra
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56793 Mtetra
.44902 .56793 .45576 .57452 .46753 .57096 .46082 .56434 Mtetra
.46082 .56434 .46753 .57096 .47935 .56738 .47267 .56074 Mtetra
.47267 .56074 .47935 .56738 .49122 .56379 .48457 .55712 Mtetra
.48457 .55712 .49122 .56379 .50314 .56018 .49653 .55348 Mtetra
.49653 .55348 .50314 .56018 .51512 .55656 .50854 .54983 Mtetra
.655 .751 .92 r
.50854 .54983 .51512 .55656 .52715 .55292 .5206 .54617 Mtetra
.653 .751 .921 r
.5206 .54617 .52715 .55292 .53923 .54927 .53272 .54256 Mtetra
.646 .751 .926 r
.53272 .54256 .53923 .54927 .55136 .54562 .54489 .53914 Mtetra
.628 .753 .937 r
.54489 .53914 .55136 .54562 .56355 .54198 .55712 .53616 Mtetra
.605 .768 .958 r
.55712 .53616 .56355 .54198 .57579 .53836 .56941 .53357 Mtetra
.598 .804 .979 r
.56941 .53357 .57579 .53836 .58809 .53471 .58177 .53076 Mtetra
.628 .846 .983 r
.58177 .53076 .58809 .53471 .60044 .53098 .59417 .527 Mtetra
.672 .858 .971 r
.59417 .527 .60044 .53098 .61284 .52715 .6066 .52227 Mtetra
.688 .831 .952 r
.6066 .52227 .61284 .52715 .6253 .5233 .61907 .51733 Mtetra
.678 .791 .935 r
.61907 .51733 .6253 .5233 .63781 .51946 .63161 .51277 Mtetra
.665 .765 .925 r
.63161 .51277 .63781 .51946 .65038 .51564 .64421 .50865 Mtetra
.658 .755 .921 r
.64421 .50865 .65038 .51564 .66301 .51181 .65687 .50472 Mtetra
.656 .752 .92 r
.65687 .50472 .66301 .51181 .6757 .50797 .6696 .50084 Mtetra
.656 .751 .92 r
.6696 .50084 .6757 .50797 .68844 .50412 .68238 .49695 Mtetra
.68238 .49695 .68844 .50412 .70124 .50024 .69522 .49305 Mtetra
.69522 .49305 .70124 .50024 .7141 .49635 .70812 .48912 Mtetra
.70812 .48912 .7141 .49635 .72701 .49245 .72107 .48518 Mtetra
.72107 .48518 .72701 .49245 .73999 .48852 .73409 .48122 Mtetra
.73409 .48122 .73999 .48852 .75302 .48458 .74716 .47725 Mtetra
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Mtetra
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Mtetra
.43044 .5649 .43727 .57151 .44902 .56793 .44222 .56129 Mtetra
.44222 .56129 .44902 .56793 .46082 .56434 .45405 .55768 Mtetra
.45405 .55768 .46082 .56434 .47267 .56074 .46594 .55404 Mtetra
.46594 .55404 .47267 .56074 .48457 .55712 .47788 .55039 Mtetra
.47788 .55039 .48457 .55712 .49653 .55348 .48987 .54673 Mtetra
.48987 .54673 .49653 .55348 .50854 .54983 .50191 .54305 Mtetra
.653 .751 .921 r
.50191 .54305 .50854 .54983 .5206 .54617 .514 .53943 Mtetra
.639 .748 .928 r
.514 .53943 .5206 .54617 .53272 .54256 .52616 .53618 Mtetra
.583 .742 .952 r
.52616 .53618 .53272 .54256 .54489 .53914 .53837 .53422 Mtetra
.393 .712 .986 r
.53837 .53422 .54489 .53914 .55712 .53616 .55067 .53466 Mtetra
0 .49 .735 r
.55067 .53466 .55712 .53616 .56941 .53357 .56307 .53691 Mtetra
.336 0 0 r
.56307 .53691 .56941 .53357 .58177 .53076 .57556 .53775 Mtetra
.207 0 0 r
.57556 .53775 .58177 .53076 .59417 .527 .58804 .53397 Mtetra
0 0 0 r
.58804 .53397 .59417 .527 .6066 .52227 .60048 .52556 Mtetra
.59 .923 .706 r
.60048 .52556 .6066 .52227 .61907 .51733 .61291 .51571 Mtetra
.762 .955 .936 r
.61291 .51571 .61907 .51733 .63161 .51277 .6254 .50765 Mtetra
.71 .831 .94 r
.6254 .50765 .63161 .51277 .64421 .50865 .63799 .502 Mtetra
.67 .771 .926 r
.63799 .502 .64421 .50865 .65687 .50472 .65068 .49764 Mtetra
.658 .754 .921 r
.65068 .49764 .65687 .50472 .6696 .50084 .66344 .49366 Mtetra
.656 .752 .92 r
.66344 .49366 .6696 .50084 .68238 .49695 .67626 .48973 Mtetra
.656 .751 .92 r
.67626 .48973 .68238 .49695 .69522 .49305 .68914 .48579 Mtetra
.68914 .48579 .69522 .49305 .70812 .48912 .70208 .48183 Mtetra
.70208 .48183 .70812 .48912 .72107 .48518 .71508 .47786 Mtetra
.71508 .47786 .72107 .48518 .73409 .48122 .72814 .47387 Mtetra
.72814 .47387 .73409 .48122 .74716 .47725 .74126 .46986 Mtetra
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Mtetra
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Mtetra
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55823 Mtetra
.42355 .55823 .43044 .5649 .44222 .56129 .43536 .5546 Mtetra
.43536 .5546 .44222 .56129 .45405 .55768 .44723 .55095 Mtetra
.44723 .55095 .45405 .55768 .46594 .55404 .45915 .54729 Mtetra
.45915 .54729 .46594 .55404 .47788 .55039 .47112 .54361 Mtetra
.47112 .54361 .47788 .55039 .48987 .54673 .48315 .53992 Mtetra
.655 .751 .921 r
.48315 .53992 .48987 .54673 .50191 .54305 .49522 .53623 Mtetra
.646 .749 .924 r
.49522 .53623 .50191 .54305 .514 .53943 .50735 .53278 Mtetra
.595 .738 .944 r
.50735 .53278 .514 .53943 .52616 .53618 .51954 .53059 Mtetra
.319 .649 .969 r
.51954 .53059 .52616 .53618 .53837 .53422 .53179 .53234 Mtetra
.546 0 0 r
.53179 .53234 .53837 .53422 .55067 .53466 .54418 .5404 Mtetra
.71 .262 .185 r
.54418 .5404 .55067 .53466 .56307 .53691 .55674 .5516 Mtetra
.609 .234 .308 r
.55674 .5516 .56307 .53691 .57556 .53775 .56941 .55792 Mtetra
.444 .11 .304 r
.56941 .55792 .57556 .53775 .58804 .53397 .58204 .55415 Mtetra
.189 0 .205 r
.58204 .55415 .58804 .53397 .60048 .52556 .59451 .54023 Mtetra
0 0 0 r
.59451 .54023 .60048 .52556 .61291 .51571 .60685 .52136 Mtetra
.715 .925 .588 r
.60685 .52136 .61291 .51571 .6254 .50765 .61921 .50558 Mtetra
.809 .945 .913 r
.61921 .50558 .6254 .50765 .63799 .502 .63175 .49613 Mtetra
.704 .808 .929 r
.63175 .49613 .63799 .502 .65068 .49764 .64445 .49064 Mtetra
.664 .761 .922 r
.64445 .49064 .65068 .49764 .66344 .49366 .65724 .48643 Mtetra
.657 .752 .92 r
.65724 .48643 .66344 .49366 .67626 .48973 .6701 .48245 Mtetra
.656 .751 .92 r
.6701 .48245 .67626 .48973 .68914 .48579 .68302 .47847 Mtetra
.68302 .47847 .68914 .48579 .70208 .48183 .696 .47448 Mtetra
.696 .47448 .70208 .48183 .71508 .47786 .70904 .47048 Mtetra
.70904 .47048 .71508 .47786 .72814 .47387 .72214 .46645 Mtetra
.72214 .46645 .72814 .47387 .74126 .46986 .7353 .4624 Mtetra
.7353 .4624 .74126 .46986 .75443 .46583 .74852 .45834 Mtetra
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Mtetra
.40481 .55516 .41179 .56185 .42355 .55823 .41661 .55152 Mtetra
.41661 .55152 .42355 .55823 .43536 .5546 .42845 .54786 Mtetra
.42845 .54786 .43536 .5546 .44723 .55095 .44035 .54418 Mtetra
.44035 .54418 .44723 .55095 .45915 .54729 .45231 .54048 Mtetra
.45231 .54048 .45915 .54729 .47112 .54361 .46431 .53677 Mtetra
.46431 .53677 .47112 .54361 .48315 .53992 .47637 .53305 Mtetra
.654 .751 .921 r
.47637 .53305 .48315 .53992 .49522 .53623 .48848 .52936 Mtetra
.638 .747 .927 r
.48848 .52936 .49522 .53623 .50735 .53278 .50064 .5261 Mtetra
.538 .717 .955 r
.50064 .5261 .50735 .53278 .51954 .53059 .51286 .52509 Mtetra
0 .408 .834 r
.51286 .52509 .51954 .53059 .53179 .53234 .52514 .53071 Mtetra
.778 .274 0 r
.52514 .53071 .53179 .53234 .54418 .5404 .53759 .54598 Mtetra
.789 .369 .251 r
.53759 .54598 .54418 .5404 .55674 .5516 .55026 .56421 Mtetra
.655 .266 .296 r
.55026 .56421 .55674 .5516 .56941 .55792 .56305 .57357 Mtetra
.403 .037 .226 r
.56305 .57357 .56941 .55792 .58204 .55415 .5758 .56979 Mtetra
0 0 .006 r
.5758 .56979 .58204 .55415 .59451 .54023 .58837 .55281 Mtetra
.659 .784 .321 r
.58837 .55281 .59451 .54023 .60685 .52136 .60069 .52685 Mtetra
.911 .954 .615 r
.60069 .52685 .60685 .52136 .61921 .50558 .61297 .50378 Mtetra
.885 .937 .846 r
.61297 .50378 .61921 .50558 .63175 .49613 .62546 .49036 Mtetra
.739 .82 .915 r
.62546 .49036 .63175 .49613 .64445 .49064 .63816 .48361 Mtetra
.671 .764 .92 r
.63816 .48361 .64445 .49064 .65724 .48643 .65098 .47914 Mtetra
.658 .753 .92 r
.65098 .47914 .65724 .48643 .6701 .48245 .66388 .4751 Mtetra
.656 .751 .92 r
.66388 .4751 .6701 .48245 .68302 .47847 .67684 .47109 Mtetra
.67684 .47109 .68302 .47847 .696 .47448 .68986 .46707 Mtetra
.68986 .46707 .696 .47448 .70904 .47048 .70294 .46303 Mtetra
.70294 .46303 .70904 .47048 .72214 .46645 .71609 .45897 Mtetra
.71609 .45897 .72214 .46645 .7353 .4624 .72929 .45489 Mtetra
.72929 .45489 .7353 .4624 .74852 .45834 .74255 .45079 Mtetra
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Mtetra
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43838 Mtetra
.78271 .43838 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Mtetra
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Mtetra
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54474 Mtetra
.40961 .54474 .41661 .55152 .42845 .54786 .42149 .54105 Mtetra
.42149 .54105 .42845 .54786 .44035 .54418 .43342 .53735 Mtetra
.43342 .53735 .44035 .54418 .45231 .54048 .44541 .53362 Mtetra
.44541 .53362 .45231 .54048 .46431 .53677 .45745 .52988 Mtetra
.45745 .52988 .46431 .53677 .47637 .53305 .46954 .52613 Mtetra
.654 .751 .921 r
.46954 .52613 .47637 .53305 .48848 .52936 .48168 .52242 Mtetra
.636 .745 .927 r
.48168 .52242 .48848 .52936 .50064 .5261 .49388 .51919 Mtetra
.519 .703 .954 r
.49388 .51919 .50064 .5261 .51286 .52509 .50612 .5186 Mtetra
0 .316 .783 r
.50612 .5186 .51286 .52509 .52514 .53071 .51842 .52597 Mtetra
.811 .331 0 r
.51842 .52597 .52514 .53071 .53759 .54598 .53089 .54567 Mtetra
.865 .435 .185 r
.53089 .54567 .53759 .54598 .55026 .56421 .54361 .57076 Mtetra
.749 .321 .232 r
.54361 .57076 .55026 .56421 .56305 .57357 .55652 .58571 Mtetra
.349 0 .126 r
.55652 .58571 .56305 .57357 .5758 .56979 .56938 .58192 Mtetra
0 0 0 r
.56938 .58192 .5758 .56979 .58837 .55281 .58199 .55932 Mtetra
.972 .912 .574 r
.58199 .55932 .58837 .55281 .60069 .52685 .5943 .52642 Mtetra
.971 .877 .683 r
.5943 .52642 .60069 .52685 .61297 .50378 .60657 .49882 Mtetra
.88 .845 .806 r
.60657 .49882 .61297 .50378 .62546 .49036 .61908 .48358 Mtetra
.745 .793 .891 r
.61908 .48358 .62546 .49036 .63816 .48361 .63181 .47635 Mtetra
.674 .76 .916 r
.63181 .47635 .63816 .48361 .65098 .47914 .64467 .47178 Mtetra
.658 .752 .92 r
.64467 .47178 .65098 .47914 .66388 .4751 .65761 .46769 Mtetra
.656 .751 .92 r
.65761 .46769 .66388 .4751 .67684 .47109 .67061 .46365 Mtetra
.67061 .46365 .67684 .47109 .68986 .46707 .68368 .45959 Mtetra
.68368 .45959 .68986 .46707 .70294 .46303 .6968 .45551 Mtetra
.6968 .45551 .70294 .46303 .71609 .45897 .70998 .45142 Mtetra
.70998 .45142 .71609 .45897 .72929 .45489 .72323 .4473 Mtetra
.72323 .4473 .72929 .45489 .74255 .45079 .73653 .44317 Mtetra
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Mtetra
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43838 .77683 .43065 Mtetra
.77683 .43065 .78271 .43838 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Mtetra
.39069 .54162 .39778 .54842 .40961 .54474 .40255 .53792 Mtetra
.40255 .53792 .40961 .54474 .42149 .54105 .41447 .5342 Mtetra
.41447 .5342 .42149 .54105 .43342 .53735 .42643 .53046 Mtetra
.42643 .53046 .43342 .53735 .44541 .53362 .43845 .5267 Mtetra
.43845 .5267 .44541 .53362 .45745 .52988 .45052 .52293 Mtetra
.45052 .52293 .45745 .52988 .46954 .52613 .46265 .51915 Mtetra
.654 .751 .921 r
.46265 .51915 .46954 .52613 .48168 .52242 .47483 .51541 Mtetra
.636 .745 .927 r
.47483 .51541 .48168 .52242 .49388 .51919 .48706 .51215 Mtetra
.519 .701 .952 r
.48706 .51215 .49388 .51919 .50612 .5186 .49933 .51155 Mtetra
0 .329 .8 r
.49933 .51155 .50612 .5186 .51842 .52597 .51165 .51897 Mtetra
.766 .292 0 r
.51165 .51897 .51842 .52597 .53089 .54567 .5241 .53883 Mtetra
.845 .398 0 r
.5241 .53883 .53089 .54567 .54361 .57076 .53681 .56418 Mtetra
.62 .118 0 r
.53681 .56418 .54361 .57076 .55652 .58571 .54972 .57932 Mtetra
.645 .778 .944 r
.54972 .57932 .55652 .58571 .56938 .58192 .56263 .57549 Mtetra
.906 .796 .728 r
.56263 .57549 .56938 .58192 .58199 .55932 .57531 .55263 Mtetra
.933 .776 .665 r
.57531 .55263 .58199 .55932 .5943 .52642 .58771 .51942 Mtetra
.92 .781 .691 r
.58771 .51942 .5943 .52642 .60657 .49882 .60006 .4916 Mtetra
.857 .793 .788 r
.60006 .4916 .60657 .49882 .61908 .48358 .61263 .47624 Mtetra
.743 .778 .882 r
.61263 .47624 .61908 .48358 .63181 .47635 .62541 .46895 Mtetra
.674 .758 .914 r
.62541 .46895 .63181 .47635 .64467 .47178 .63831 .46434 Mtetra
.658 .752 .92 r
.63831 .46434 .64467 .47178 .65761 .46769 .65129 .46022 Mtetra
.656 .751 .92 r
.65129 .46022 .65761 .46769 .67061 .46365 .66433 .45614 Mtetra
.66433 .45614 .67061 .46365 .68368 .45959 .67744 .45205 Mtetra
.67744 .45205 .68368 .45959 .6968 .45551 .6906 .44794 Mtetra
.6906 .44794 .6968 .45551 .70998 .45142 .70382 .44381 Mtetra
.70382 .44381 .70998 .45142 .72323 .4473 .71711 .43966 Mtetra
.71711 .43966 .72323 .4473 .73653 .44317 .73046 .43549 Mtetra
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Mtetra
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Mtetra
.38355 .53477 .39069 .54162 .40255 .53792 .39544 .53103 Mtetra
.39544 .53103 .40255 .53792 .41447 .5342 .40739 .52728 Mtetra
.40739 .52728 .41447 .5342 .42643 .53046 .41938 .52351 Mtetra
.41938 .52351 .42643 .53046 .43845 .5267 .43144 .51973 Mtetra
.43144 .51973 .43845 .5267 .45052 .52293 .44355 .51593 Mtetra
.44355 .51593 .45052 .52293 .46265 .51915 .45571 .51211 Mtetra
.654 .751 .921 r
.45571 .51211 .46265 .51915 .47483 .51541 .46792 .50834 Mtetra
.636 .745 .927 r
.46792 .50834 .47483 .51541 .48706 .51215 .48019 .50506 Mtetra
.518 .7 .953 r
.48019 .50506 .48706 .51215 .49933 .51155 .49248 .50445 Mtetra
0 .325 .797 r
.49248 .50445 .49933 .51155 .51165 .51897 .50481 .51192 Mtetra
.768 .294 0 r
.50481 .51192 .51165 .51897 .5241 .53883 .51726 .53188 Mtetra
.845 .398 0 r
.51726 .53188 .5241 .53883 .53681 .56418 .52994 .55729 Mtetra
.606 .108 0 r
.52994 .55729 .53681 .56418 .54972 .57932 .54286 .57242 Mtetra
.647 .765 .935 r
.54286 .57242 .54972 .57932 .56263 .57549 .5558 .56856 Mtetra
.901 .789 .727 r
.5558 .56856 .56263 .57549 .57531 .55263 .56856 .54565 Mtetra
.931 .773 .664 r
.56856 .54565 .57531 .55263 .58771 .51942 .58106 .51231 Mtetra
.919 .78 .691 r
.58106 .51231 .58771 .51942 .60006 .4916 .5935 .48432 Mtetra
.857 .793 .787 r
.5935 .48432 .60006 .4916 .61263 .47624 .60612 .46884 Mtetra
.743 .778 .881 r
.60612 .46884 .61263 .47624 .62541 .46895 .61895 .46149 Mtetra
.674 .758 .914 r
.61895 .46149 .62541 .46895 .63831 .46434 .63189 .45684 Mtetra
.658 .752 .92 r
.63189 .45684 .63831 .46434 .65129 .46022 .64491 .45269 Mtetra
.656 .751 .92 r
.64491 .45269 .65129 .46022 .66433 .45614 .658 .44857 Mtetra
.658 .44857 .66433 .45614 .67744 .45205 .67114 .44444 Mtetra
.67114 .44444 .67744 .45205 .6906 .44794 .68435 .4403 Mtetra
.68435 .4403 .6906 .44794 .70382 .44381 .69761 .43613 Mtetra
.69761 .43613 .70382 .44381 .71711 .43966 .71095 .43194 Mtetra
.71095 .43194 .71711 .43966 .73046 .43549 .72434 .42774 Mtetra
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Mtetra
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40207 Mtetra
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Mtetra
.37634 .52786 .38355 .53477 .39544 .53103 .38827 .52409 Mtetra
.38827 .52409 .39544 .53103 .40739 .52728 .40025 .52031 Mtetra
.40025 .52031 .40739 .52728 .41938 .52351 .41228 .51651 Mtetra
.41228 .51651 .41938 .52351 .43144 .51973 .42437 .51269 Mtetra
.42437 .51269 .43144 .51973 .44355 .51593 .43651 .50886 Mtetra
.43651 .50886 .44355 .51593 .45571 .51211 .44871 .50501 Mtetra
.654 .751 .921 r
.44871 .50501 .45571 .51211 .46792 .50834 .46096 .50121 Mtetra
.636 .745 .927 r
.46096 .50121 .46792 .50834 .48019 .50506 .47325 .4979 Mtetra
.517 .7 .953 r
.47325 .4979 .48019 .50506 .49248 .50445 .48558 .49728 Mtetra
0 .324 .797 r
.48558 .49728 .49248 .50445 .50481 .51192 .49792 .50476 Mtetra
.765 .292 0 r
.49792 .50476 .50481 .51192 .51726 .53188 .51035 .52471 Mtetra
.841 .394 0 r
.51035 .52471 .51726 .53188 .52994 .55729 .52302 .55001 Mtetra
.581 .088 0 r
.52302 .55001 .52994 .55729 .54286 .57242 .53593 .56498 Mtetra
.649 .752 .924 r
.53593 .56498 .54286 .57242 .5558 .56856 .54891 .56109 Mtetra
.896 .781 .727 r
.54891 .56109 .5558 .56856 .56856 .54565 .56175 .53827 Mtetra
.928 .77 .665 r
.56175 .53827 .56856 .54565 .58106 .51231 .57435 .50496 Mtetra
.918 .778 .691 r
.57435 .50496 .58106 .51231 .5935 .48432 .58688 .47692 Mtetra
.857 .792 .787 r
.58688 .47692 .5935 .48432 .60612 .46884 .59956 .46137 Mtetra
.743 .778 .881 r
.59956 .46137 .60612 .46884 .61895 .46149 .61243 .45397 Mtetra
.674 .758 .914 r
.61243 .45397 .61895 .46149 .63189 .45684 .62542 .44927 Mtetra
.658 .752 .92 r
.62542 .44927 .63189 .45684 .64491 .45269 .63848 .44508 Mtetra
.656 .751 .92 r
.63848 .44508 .64491 .45269 .658 .44857 .65161 .44094 Mtetra
.65161 .44094 .658 .44857 .67114 .44444 .66479 .43677 Mtetra
.66479 .43677 .67114 .44444 .68435 .4403 .67804 .43259 Mtetra
.67804 .43259 .68435 .4403 .69761 .43613 .69135 .42838 Mtetra
.69135 .42838 .69761 .43613 .71095 .43194 .70472 .42416 Mtetra
.70472 .42416 .71095 .43194 .72434 .42774 .71816 .41992 Mtetra
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Mtetra
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40207 .80014 .39403 Mtetra
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Mtetra
.33352 .53219 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Mtetra
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .52089 Mtetra
.36908 .52089 .37634 .52786 .38827 .52409 .38104 .5171 Mtetra
.38104 .5171 .38827 .52409 .40025 .52031 .39305 .51328 Mtetra
.39305 .51328 .40025 .52031 .41228 .51651 .40512 .50945 Mtetra
.40512 .50945 .41228 .51651 .42437 .51269 .41724 .5056 Mtetra
.41724 .5056 .42437 .51269 .43651 .50886 .42941 .50174 Mtetra
.42941 .50174 .43651 .50886 .44871 .50501 .44164 .49786 Mtetra
.654 .751 .921 r
.44164 .49786 .44871 .50501 .46096 .50121 .45393 .49402 Mtetra
.635 .745 .927 r
.45393 .49402 .46096 .50121 .47325 .4979 .46626 .49069 Mtetra
.516 .699 .953 r
.46626 .49069 .47325 .4979 .48558 .49728 .47862 .49006 Mtetra
0 .321 .795 r
.47862 .49006 .48558 .49728 .49792 .50476 .49097 .49757 Mtetra
.767 .294 0 r
.49097 .49757 .49792 .50476 .51035 .52471 .50339 .51757 Mtetra
.842 .394 0 r
.50339 .51757 .51035 .52471 .52302 .55001 .51603 .54285 Mtetra
.586 .09 0 r
.51603 .54285 .52302 .55001 .53593 .56498 .52894 .55772 Mtetra
.648 .758 .93 r
.52894 .55772 .53593 .56498 .54891 .56109 .54197 .5538 Mtetra
.898 .785 .728 r
.54197 .5538 .54891 .56109 .56175 .53827 .55489 .531 Mtetra
.929 .772 .665 r
.55489 .531 .56175 .53827 .57435 .50496 .56758 .49765 Mtetra
.919 .779 .691 r
.56758 .49765 .57435 .50496 .58688 .47692 .5802 .4695 Mtetra
.857 .793 .787 r
.5802 .4695 .58688 .47692 .59956 .46137 .59294 .45384 Mtetra
.744 .778 .881 r
.59294 .45384 .59956 .46137 .61243 .45397 .60586 .44638 Mtetra
.674 .758 .914 r
.60586 .44638 .61243 .45397 .62542 .44927 .61889 .44164 Mtetra
.658 .752 .92 r
.61889 .44164 .62542 .44927 .63848 .44508 .63199 .43742 Mtetra
.656 .751 .92 r
.63199 .43742 .63848 .44508 .65161 .44094 .64516 .43323 Mtetra
.64516 .43323 .65161 .44094 .66479 .43677 .65839 .42903 Mtetra
.65839 .42903 .66479 .43677 .67804 .43259 .67168 .42481 Mtetra
.67168 .42481 .67804 .43259 .69135 .42838 .68503 .42057 Mtetra
.68503 .42057 .69135 .42838 .70472 .42416 .69845 .41631 Mtetra
.69845 .41631 .70472 .42416 .71816 .41992 .71193 .41203 Mtetra
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Mtetra
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52525 Mtetra
.32609 .52525 .33352 .53219 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Mtetra
.34981 .51768 .35717 .52467 .36908 .52089 .36175 .51387 Mtetra
.36175 .51387 .36908 .52089 .38104 .5171 .37374 .51004 Mtetra
.37374 .51004 .38104 .5171 .39305 .51328 .38579 .5062 Mtetra
.38579 .5062 .39305 .51328 .40512 .50945 .39789 .50233 Mtetra
.39789 .50233 .40512 .50945 .41724 .5056 .41005 .49845 Mtetra
.41005 .49845 .41724 .5056 .42941 .50174 .42226 .49455 Mtetra
.42226 .49455 .42941 .50174 .44164 .49786 .43452 .49064 Mtetra
.654 .751 .921 r
.43452 .49064 .44164 .49786 .45393 .49402 .44685 .48677 Mtetra
.635 .745 .927 r
.44685 .48677 .45393 .49402 .46626 .49069 .45921 .48341 Mtetra
.515 .699 .953 r
.45921 .48341 .46626 .49069 .47862 .49006 .4716 .48277 Mtetra
0 .319 .793 r
.4716 .48277 .47862 .49006 .49097 .49757 .48396 .49031 Mtetra
.767 .294 0 r
.48396 .49031 .49097 .49757 .50339 .51757 .49636 .51033 Mtetra
.84 .392 0 r
.49636 .51033 .50339 .51757 .51603 .54285 .50898 .53553 Mtetra
.575 .08 0 r
.50898 .53553 .51603 .54285 .52894 .55772 .5219 .55026 Mtetra
.649 .754 .927 r
.5219 .55026 .52894 .55772 .54197 .5538 .53496 .5463 Mtetra
.896 .783 .729 r
.53496 .5463 .54197 .5538 .55489 .531 .54796 .52358 Mtetra
.928 .771 .666 r
.54796 .52358 .55489 .531 .56758 .49765 .56076 .49024 Mtetra
.918 .778 .691 r
.56076 .49024 .56758 .49765 .5802 .4695 .57346 .46199 Mtetra
.858 .792 .786 r
.57346 .46199 .5802 .4695 .59294 .45384 .58627 .44625 Mtetra
.744 .778 .881 r
.58627 .44625 .59294 .45384 .60586 .44638 .59923 .43872 Mtetra
.674 .758 .914 r
.59923 .43872 .60586 .44638 .61889 .44164 .6123 .43395 Mtetra
.658 .752 .92 r
.6123 .43395 .61889 .44164 .63199 .43742 .62545 .42968 Mtetra
.656 .751 .92 r
.62545 .42968 .63199 .43742 .64516 .43323 .63866 .42546 Mtetra
.63866 .42546 .64516 .43323 .65839 .42903 .65193 .42123 Mtetra
.65193 .42123 .65839 .42903 .67168 .42481 .66526 .41697 Mtetra
.66526 .41697 .67168 .42481 .68503 .42057 .67866 .41269 Mtetra
.67866 .41269 .68503 .42057 .69845 .41631 .69212 .40839 Mtetra
.69212 .40839 .69845 .41631 .71193 .41203 .70564 .40407 Mtetra
.70564 .40407 .71193 .41203 .72548 .40773 .71923 .39974 Mtetra
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Mtetra
.35437 .50679 .36175 .51387 .37374 .51004 .36639 .50293 Mtetra
.36639 .50293 .37374 .51004 .38579 .5062 .37847 .49905 Mtetra
.37847 .49905 .38579 .5062 .39789 .50233 .39061 .49515 Mtetra
.39061 .49515 .39789 .50233 .41005 .49845 .4028 .49124 Mtetra
.4028 .49124 .41005 .49845 .42226 .49455 .41504 .48731 Mtetra
.41504 .48731 .42226 .49455 .43452 .49064 .42734 .48336 Mtetra
.654 .751 .921 r
.42734 .48336 .43452 .49064 .44685 .48677 .4397 .47946 Mtetra
.635 .745 .928 r
.4397 .47946 .44685 .48677 .45921 .48341 .4521 .47607 Mtetra
.514 .699 .953 r
.4521 .47607 .45921 .48341 .4716 .48277 .46452 .47543 Mtetra
0 .316 .791 r
.46452 .47543 .4716 .48277 .48396 .49031 .47689 .483 Mtetra
.767 .294 0 r
.47689 .483 .48396 .49031 .49636 .51033 .48928 .50304 Mtetra
.839 .391 0 r
.48928 .50304 .49636 .51033 .50898 .53553 .50188 .52817 Mtetra
.57 .074 0 r
.50188 .52817 .50898 .53553 .5219 .55026 .51479 .54277 Mtetra
.648 .755 .927 r
.51479 .54277 .5219 .55026 .53496 .5463 .5279 .53878 Mtetra
.896 .784 .73 r
.5279 .53878 .53496 .5463 .54796 .52358 .54097 .51612 Mtetra
.928 .771 .666 r
.54097 .51612 .54796 .52358 .56076 .49024 .55387 .48278 Mtetra
.919 .779 .691 r
.55387 .48278 .56076 .49024 .57346 .46199 .56666 .45443 Mtetra
.858 .793 .786 r
.56666 .45443 .57346 .46199 .58627 .44625 .57954 .43859 Mtetra
.745 .779 .88 r
.57954 .43859 .58627 .44625 .59923 .43872 .59255 .431 Mtetra
.674 .758 .914 r
.59255 .431 .59923 .43872 .6123 .43395 .60566 .42618 Mtetra
.658 .752 .92 r
.60566 .42618 .6123 .43395 .62545 .42968 .61885 .42188 Mtetra
.656 .751 .92 r
.61885 .42188 .62545 .42968 .63866 .42546 .6321 .41762 Mtetra
.6321 .41762 .63866 .42546 .65193 .42123 .64541 .41335 Mtetra
.64541 .41335 .65193 .42123 .66526 .41697 .65879 .40906 Mtetra
.65879 .40906 .66526 .41697 .67866 .41269 .67223 .40474 Mtetra
.67223 .40474 .67866 .41269 .69212 .40839 .68573 .4004 Mtetra
.68573 .4004 .69212 .40839 .70564 .40407 .6993 .39605 Mtetra
.6993 .39605 .70564 .40407 .71923 .39974 .71294 .39167 Mtetra
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Mtetra
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Mtetra
.34692 .49965 .35437 .50679 .36639 .50293 .35898 .49575 Mtetra
.35898 .49575 .36639 .50293 .37847 .49905 .37109 .49184 Mtetra
.37109 .49184 .37847 .49905 .39061 .49515 .38326 .48791 Mtetra
.38326 .48791 .39061 .49515 .4028 .49124 .39549 .48397 Mtetra
.39549 .48397 .4028 .49124 .41504 .48731 .40777 .48 Mtetra
.40777 .48 .41504 .48731 .42734 .48336 .4201 .47602 Mtetra
.654 .751 .921 r
.4201 .47602 .42734 .48336 .4397 .47946 .4325 .47209 Mtetra
.635 .745 .928 r
.4325 .47209 .4397 .47946 .4521 .47607 .44493 .46867 Mtetra
.513 .698 .953 r
.44493 .46867 .4521 .47607 .46452 .47543 .45737 .46803 Mtetra
0 .313 .788 r
.45737 .46803 .46452 .47543 .47689 .483 .46976 .47563 Mtetra
.768 .295 0 r
.46976 .47563 .47689 .483 .48928 .50304 .48213 .49571 Mtetra
.839 .389 0 r
.48213 .49571 .48928 .50304 .50188 .52817 .49471 .52078 Mtetra
.564 .068 0 r
.49471 .52078 .50188 .52817 .51479 .54277 .50762 .53523 Mtetra
.648 .756 .928 r
.50762 .53523 .51479 .54277 .5279 .53878 .52077 .5312 Mtetra
.895 .785 .731 r
.52077 .5312 .5279 .53878 .54097 .51612 .53392 .50862 Mtetra
.928 .772 .667 r
.53392 .50862 .54097 .51612 .55387 .48278 .54693 .47527 Mtetra
.919 .779 .69 r
.54693 .47527 .55387 .48278 .56666 .45443 .55981 .44682 Mtetra
.858 .793 .785 r
.55981 .44682 .56666 .45443 .57954 .43859 .57274 .43087 Mtetra
.745 .779 .88 r
.57274 .43087 .57954 .43859 .59255 .431 .5858 .42321 Mtetra
.674 .758 .914 r
.5858 .42321 .59255 .431 .60566 .42618 .59896 .41835 Mtetra
.658 .752 .92 r
.59896 .41835 .60566 .42618 .61885 .42188 .61219 .41401 Mtetra
.656 .751 .92 r
.61219 .41401 .61885 .42188 .6321 .41762 .62548 .40972 Mtetra
.62548 .40972 .6321 .41762 .64541 .41335 .63884 .40541 Mtetra
.63884 .40541 .64541 .41335 .65879 .40906 .65226 .40107 Mtetra
.65226 .40107 .65879 .40906 .67223 .40474 .66574 .39672 Mtetra
.66574 .39672 .67223 .40474 .68573 .4004 .67929 .39235 Mtetra
.67929 .39235 .68573 .4004 .6993 .39605 .69291 .38795 Mtetra
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Mtetra
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Mtetra
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Mtetra
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Mtetra
.33941 .49245 .34692 .49965 .35898 .49575 .3515 .48852 Mtetra
.3515 .48852 .35898 .49575 .37109 .49184 .36365 .48458 Mtetra
.36365 .48458 .37109 .49184 .38326 .48791 .37585 .48061 Mtetra
.37585 .48061 .38326 .48791 .39549 .48397 .38811 .47663 Mtetra
.38811 .47663 .39549 .48397 .40777 .48 .40043 .47264 Mtetra
.40043 .47264 .40777 .48 .4201 .47602 .4128 .46862 Mtetra
.654 .751 .921 r
.4128 .46862 .4201 .47602 .4325 .47209 .42523 .46466 Mtetra
.635 .745 .928 r
.42523 .46466 .4325 .47209 .44493 .46867 .4377 .46121 Mtetra
.512 .698 .953 r
.4377 .46121 .44493 .46867 .45737 .46803 .45017 .46056 Mtetra
0 .31 .787 r
.45017 .46056 .45737 .46803 .46976 .47563 .46257 .46818 Mtetra
.768 .294 0 r
.46257 .46818 .46976 .47563 .48213 .49571 .47493 .48827 Mtetra
.836 .387 0 r
.47493 .48827 .48213 .49571 .49471 .52078 .48747 .51323 Mtetra
.55 .056 0 r
.48747 .51323 .49471 .52078 .50762 .53523 .50039 .5275 Mtetra
.649 .752 .925 r
.50039 .5275 .50762 .53523 .52077 .5312 .51357 .52344 Mtetra
.893 .783 .732 r
.51357 .52344 .52077 .5312 .53392 .50862 .52681 .50096 Mtetra
.927 .771 .667 r
.52681 .50096 .53392 .50862 .54693 .47527 .53992 .46765 Mtetra
.918 .778 .69 r
.53992 .46765 .54693 .47527 .55981 .44682 .55289 .43912 Mtetra
.859 .792 .785 r
.55289 .43912 .55981 .44682 .57274 .43087 .56589 .42307 Mtetra
.746 .779 .88 r
.56589 .42307 .57274 .43087 .5858 .42321 .579 .41536 Mtetra
.675 .758 .914 r
.579 .41536 .5858 .42321 .59896 .41835 .5922 .41045 Mtetra
.658 .752 .92 r
.5922 .41045 .59896 .41835 .61219 .41401 .60547 .40608 Mtetra
.656 .751 .92 r
.60547 .40608 .61219 .41401 .62548 .40972 .6188 .40174 Mtetra
.6188 .40174 .62548 .40972 .63884 .40541 .6322 .39739 Mtetra
.6322 .39739 .63884 .40541 .65226 .40107 .64567 .39302 Mtetra
.64567 .39302 .65226 .40107 .66574 .39672 .6592 .38863 Mtetra
.6592 .38863 .66574 .39672 .67929 .39235 .67279 .38422 Mtetra
.67279 .38422 .67929 .39235 .69291 .38795 .68645 .37978 Mtetra
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Mtetra
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Mtetra
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48518 Mtetra
.33184 .48518 .33941 .49245 .3515 .48852 .34396 .48122 Mtetra
.34396 .48122 .3515 .48852 .36365 .48458 .35615 .47725 Mtetra
.35615 .47725 .36365 .48458 .37585 .48061 .36838 .47325 Mtetra
.36838 .47325 .37585 .48061 .38811 .47663 .38068 .46924 Mtetra
.38068 .46924 .38811 .47663 .40043 .47264 .39303 .46521 Mtetra
.39303 .46521 .40043 .47264 .4128 .46862 .40544 .46116 Mtetra
.653 .751 .921 r
.40544 .46116 .4128 .46862 .42523 .46466 .4179 .45716 Mtetra
.634 .745 .928 r
.4179 .45716 .42523 .46466 .4377 .46121 .43041 .45369 Mtetra
.511 .697 .953 r
.43041 .45369 .4377 .46121 .45017 .46056 .4429 .45303 Mtetra
0 .306 .783 r
.4429 .45303 .45017 .46056 .46257 .46818 .45531 .46071 Mtetra
.77 .297 0 r
.45531 .46071 .46257 .46818 .47493 .48827 .46765 .48087 Mtetra
.837 .387 0 r
.46765 .48087 .47493 .48827 .48747 .51323 .48018 .50579 Mtetra
.554 .056 0 r
.48018 .50579 .48747 .51323 .50039 .5275 .49309 .51994 Mtetra
.648 .759 .93 r
.49309 .51994 .50039 .5275 .51357 .52344 .50632 .51584 Mtetra
.895 .787 .734 r
.50632 .51584 .51357 .52344 .52681 .50096 .51964 .49341 Mtetra
.929 .773 .668 r
.51964 .49341 .52681 .50096 .53992 .46765 .53285 .46007 Mtetra
.919 .78 .69 r
.53285 .46007 .53992 .46765 .55289 .43912 .54592 .4314 Mtetra
.86 .793 .785 r
.54592 .4314 .55289 .43912 .56589 .42307 .55898 .41522 Mtetra
.746 .779 .88 r
.55898 .41522 .56589 .42307 .579 .41536 .57214 .40743 Mtetra
.675 .758 .914 r
.57214 .40743 .579 .41536 .5922 .41045 .58538 .40248 Mtetra
.658 .752 .92 r
.58538 .40248 .5922 .41045 .60547 .40608 .59869 .39807 Mtetra
.656 .751 .92 r
.59869 .39807 .60547 .40608 .6188 .40174 .61207 .39369 Mtetra
.61207 .39369 .6188 .40174 .6322 .39739 .62551 .38931 Mtetra
.62551 .38931 .6322 .39739 .64567 .39302 .63902 .3849 Mtetra
.63902 .3849 .64567 .39302 .6592 .38863 .65259 .38046 Mtetra
.65259 .38046 .6592 .38863 .67279 .38422 .66623 .37601 Mtetra
.66623 .37601 .67279 .38422 .68645 .37978 .67994 .37154 Mtetra
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Mtetra
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34884 Mtetra
.74947 .34884 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48183 Mtetra
.31209 .48183 .31977 .48912 .33184 .48518 .3242 .47786 Mtetra
.3242 .47786 .33184 .48518 .34396 .48122 .33636 .47387 Mtetra
.33636 .47387 .34396 .48122 .35615 .47725 .34858 .46986 Mtetra
.34858 .46986 .35615 .47725 .36838 .47325 .36085 .46583 Mtetra
.36085 .46583 .36838 .47325 .38068 .46924 .37318 .46178 Mtetra
.37318 .46178 .38068 .46924 .39303 .46521 .38557 .45771 Mtetra
.38557 .45771 .39303 .46521 .40544 .46116 .39801 .45363 Mtetra
.653 .751 .921 r
.39801 .45363 .40544 .46116 .4179 .45716 .41051 .4496 Mtetra
.634 .745 .928 r
.41051 .4496 .4179 .45716 .43041 .45369 .42305 .4461 Mtetra
.51 .697 .953 r
.42305 .4461 .43041 .45369 .4429 .45303 .43558 .44543 Mtetra
0 .305 .782 r
.43558 .44543 .4429 .45303 .45531 .46071 .44799 .45312 Mtetra
.767 .294 0 r
.44799 .45312 .45531 .46071 .46765 .48087 .46032 .47323 Mtetra
.832 .381 0 r
.46032 .47323 .46765 .48087 .48018 .50579 .47282 .49795 Mtetra
.522 .032 0 r
.47282 .49795 .48018 .50579 .49309 .51994 .48574 .51184 Mtetra
.649 .746 .92 r
.48574 .51184 .49309 .51994 .50632 .51584 .499 .5077 Mtetra
.889 .78 .734 r
.499 .5077 .50632 .51584 .51964 .49341 .5124 .48546 Mtetra
.926 .77 .669 r
.5124 .48546 .51964 .49341 .53285 .46007 .52571 .45225 Mtetra
.918 .778 .69 r
.52571 .45225 .53285 .46007 .54592 .4314 .53888 .42355 Mtetra
.859 .792 .784 r
.53888 .42355 .54592 .4314 .55898 .41522 .55201 .40729 Mtetra
.747 .779 .879 r
.55201 .40729 .55898 .41522 .57214 .40743 .56521 .39944 Mtetra
.675 .758 .913 r
.56521 .39944 .57214 .40743 .58538 .40248 .5785 .39444 Mtetra
.658 .752 .92 r
.5785 .39444 .58538 .40248 .59869 .39807 .59185 .38999 Mtetra
.656 .751 .92 r
.59185 .38999 .59869 .39807 .61207 .39369 .60528 .38558 Mtetra
.60528 .38558 .61207 .39369 .62551 .38931 .61876 .38115 Mtetra
.61876 .38115 .62551 .38931 .63902 .3849 .63231 .3767 Mtetra
.63231 .3767 .63902 .3849 .65259 .38046 .64593 .37223 Mtetra
.64593 .37223 .65259 .38046 .66623 .37601 .65962 .36773 Mtetra
.65962 .36773 .66623 .37601 .67994 .37154 .67337 .36322 Mtetra
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Mtetra
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34884 .74314 .34031 Mtetra
.74314 .34031 .74947 .34884 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48183 .30436 .47448 Mtetra
.30436 .47448 .31209 .48183 .3242 .47786 .3165 .47048 Mtetra
.3165 .47048 .3242 .47786 .33636 .47387 .32869 .46645 Mtetra
.32869 .46645 .33636 .47387 .34858 .46986 .34094 .4624 Mtetra
.34094 .4624 .34858 .46986 .36085 .46583 .35325 .45834 Mtetra
.35325 .45834 .36085 .46583 .37318 .46178 .36562 .45426 Mtetra
.36562 .45426 .37318 .46178 .38557 .45771 .37804 .45015 Mtetra
.37804 .45015 .38557 .45771 .39801 .45363 .39052 .44604 Mtetra
.653 .751 .921 r
.39052 .44604 .39801 .45363 .41051 .4496 .40305 .44197 Mtetra
.634 .745 .928 r
.40305 .44197 .41051 .4496 .42305 .4461 .41563 .43844 Mtetra
.508 .696 .954 r
.41563 .43844 .42305 .4461 .43558 .44543 .42819 .43777 Mtetra
0 .303 .781 r
.42819 .43777 .43558 .44543 .44799 .45312 .44061 .44546 Mtetra
.764 .291 0 r
.44061 .44546 .44799 .45312 .46032 .47323 .45292 .46547 Mtetra
.826 .373 0 r
.45292 .46547 .46032 .47323 .47282 .49795 .4654 .48979 Mtetra
0 .001 .517 r
.4654 .48979 .47282 .49795 .48574 .51184 .47832 .50319 Mtetra
.649 .734 .911 r
.47832 .50319 .48574 .51184 .499 .5077 .49163 .49901 Mtetra
.883 .773 .736 r
.49163 .49901 .499 .5077 .5124 .48546 .5051 .47719 Mtetra
.923 .767 .67 r
.5051 .47719 .5124 .48546 .52571 .45225 .51852 .4443 Mtetra
.917 .777 .691 r
.51852 .4443 .52571 .45225 .53888 .42355 .53178 .41563 Mtetra
.859 .792 .784 r
.53178 .41563 .53888 .42355 .55201 .40729 .54498 .39929 Mtetra
.747 .779 .879 r
.54498 .39929 .55201 .40729 .56521 .39944 .55823 .39137 Mtetra
.675 .758 .913 r
.55823 .39137 .56521 .39944 .5785 .39444 .57156 .38633 Mtetra
.658 .752 .92 r
.57156 .38633 .5785 .39444 .59185 .38999 .58496 .38184 Mtetra
.656 .751 .92 r
.58496 .38184 .59185 .38999 .60528 .38558 .59842 .37738 Mtetra
.59842 .37738 .60528 .38558 .61876 .38115 .61195 .37292 Mtetra
.61195 .37292 .61876 .38115 .63231 .3767 .62555 .36843 Mtetra
.62555 .36843 .63231 .3767 .64593 .37223 .63921 .36392 Mtetra
.63921 .36392 .64593 .37223 .65962 .36773 .65294 .35938 Mtetra
.65294 .35938 .65962 .36773 .67337 .36322 .66673 .35483 Mtetra
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Mtetra
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Mtetra
.29656 .46707 .30436 .47448 .3165 .47048 .30873 .46303 Mtetra
.30873 .46303 .3165 .47048 .32869 .46645 .32096 .45897 Mtetra
.32096 .45897 .32869 .46645 .34094 .4624 .33324 .45489 Mtetra
.33324 .45489 .34094 .4624 .35325 .45834 .34559 .45079 Mtetra
.34559 .45079 .35325 .45834 .36562 .45426 .35799 .44667 Mtetra
.35799 .44667 .36562 .45426 .37804 .45015 .37045 .44253 Mtetra
.37045 .44253 .37804 .45015 .39052 .44604 .38296 .43838 Mtetra
.654 .751 .921 r
.38296 .43838 .39052 .44604 .40305 .44197 .39553 .43427 Mtetra
.637 .745 .927 r
.39553 .43427 .40305 .44197 .41563 .43844 .40815 .43064 Mtetra
.532 .704 .949 r
.40815 .43064 .41563 .43844 .42819 .43777 .42075 .42949 Mtetra
.059 .425 .869 r
.42075 .42949 .42819 .43777 .44061 .44546 .43323 .4354 Mtetra
0 0 .483 r
.43323 .4354 .44061 .44546 .45292 .46547 .44562 .45089 Mtetra
0 .003 .579 r
.44562 .45089 .45292 .46547 .4654 .48979 .45819 .46818 Mtetra
.362 .376 .741 r
.45819 .46818 .4654 .48979 .47832 .50319 .47115 .47581 Mtetra
.604 .491 .698 r
.47115 .47581 .47832 .50319 .49163 .49901 .48442 .47159 Mtetra
.716 .56 .676 r
.48442 .47159 .49163 .49901 .5051 .47719 .49785 .45544 Mtetra
.805 .633 .669 r
.49785 .45544 .5051 .47719 .51852 .4443 .51128 .4295 Mtetra
.844 .695 .697 r
.51128 .4295 .51852 .4443 .53178 .41563 .52461 .40529 Mtetra
.82 .745 .781 r
.52461 .40529 .53178 .41563 .54498 .39929 .53788 .39067 Mtetra
.734 .762 .875 r
.53788 .39067 .54498 .39929 .55823 .39137 .55118 .38315 Mtetra
.673 .755 .913 r
.55118 .38315 .55823 .39137 .57156 .38633 .56455 .37814 Mtetra
.658 .752 .919 r
.56455 .37814 .57156 .38633 .58496 .38184 .578 .37361 Mtetra
.656 .751 .92 r
.578 .37361 .58496 .38184 .59842 .37738 .5915 .36912 Mtetra
.5915 .36912 .59842 .37738 .61195 .37292 .60508 .36461 Mtetra
.60508 .36461 .61195 .37292 .62555 .36843 .61872 .36008 Mtetra
.61872 .36008 .62555 .36843 .63921 .36392 .63243 .35553 Mtetra
.63243 .35553 .63921 .36392 .65294 .35938 .6462 .35095 Mtetra
.6462 .35095 .65294 .35938 .66673 .35483 .66004 .34636 Mtetra
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Mtetra
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45551 Mtetra
.3009 .45551 .30873 .46303 .32096 .45897 .31316 .45142 Mtetra
.31316 .45142 .32096 .45897 .33324 .45489 .32548 .4473 Mtetra
.32548 .4473 .33324 .45489 .34559 .45079 .33786 .44317 Mtetra
.33786 .44317 .34559 .45079 .35799 .44667 .35029 .43902 Mtetra
.35029 .43902 .35799 .44667 .37045 .44253 .36279 .43484 Mtetra
.36279 .43484 .37045 .44253 .38296 .43838 .37534 .43065 Mtetra
.655 .751 .921 r
.37534 .43065 .38296 .43838 .39553 .43427 .38795 .42648 Mtetra
.645 .747 .923 r
.38795 .42648 .39553 .43427 .40815 .43064 .40061 .42256 Mtetra
.593 .722 .934 r
.40061 .42256 .40815 .43064 .42075 .42949 .41328 .42006 Mtetra
.408 .6 .925 r
.41328 .42006 .42075 .42949 .43323 .4354 .4259 .42177 Mtetra
.171 .362 .811 r
.4259 .42177 .43323 .4354 .44562 .45089 .43846 .42979 Mtetra
.255 .311 .728 r
.43846 .42979 .44562 .45089 .45819 .46818 .45112 .44029 Mtetra
.459 .395 .698 r
.45112 .44029 .45819 .46818 .47115 .47581 .46406 .44544 Mtetra
.598 .474 .683 r
.46406 .44544 .47115 .47581 .48442 .47159 .47727 .44119 Mtetra
.687 .531 .669 r
.47727 .44119 .48442 .47159 .49785 .45544 .49065 .42744 Mtetra
.735 .569 .667 r
.49065 .42744 .49785 .45544 .51128 .4295 .50406 .40816 Mtetra
.753 .609 .699 r
.50406 .40816 .51128 .4295 .52461 .40529 .5174 .39133 Mtetra
.742 .669 .78 r
.5174 .39133 .52461 .40529 .53788 .39067 .53071 .38087 Mtetra
.698 .726 .871 r
.53071 .38087 .53788 .39067 .55118 .38315 .54407 .37465 Mtetra
.665 .747 .911 r
.54407 .37465 .55118 .38315 .56455 .37814 .55749 .36985 Mtetra
.657 .751 .919 r
.55749 .36985 .56455 .37814 .578 .37361 .57097 .36531 Mtetra
.656 .751 .92 r
.57097 .36531 .578 .37361 .5915 .36912 .58452 .36078 Mtetra
.58452 .36078 .5915 .36912 .60508 .36461 .59814 .35623 Mtetra
.59814 .35623 .60508 .36461 .61872 .36008 .61183 .35166 Mtetra
.61183 .35166 .61872 .36008 .63243 .35553 .62558 .34707 Mtetra
.62558 .34707 .63243 .35553 .6462 .35095 .6394 .34245 Mtetra
.6394 .34245 .6462 .35095 .66004 .34636 .65329 .33781 Mtetra
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.28076 .45205 .28869 .45959 .3009 .45551 .293 .44794 Mtetra
.293 .44794 .3009 .45551 .31316 .45142 .30529 .44381 Mtetra
.30529 .44381 .31316 .45142 .32548 .4473 .31765 .43966 Mtetra
.31765 .43966 .32548 .4473 .33786 .44317 .33006 .43549 Mtetra
.33006 .43549 .33786 .44317 .35029 .43902 .34253 .4313 Mtetra
.34253 .4313 .35029 .43902 .36279 .43484 .35506 .42709 Mtetra
.35506 .42709 .36279 .43484 .37534 .43065 .36765 .42286 Mtetra
.655 .751 .92 r
.36765 .42286 .37534 .43065 .38795 .42648 .3803 .41862 Mtetra
.653 .75 .921 r
.3803 .41862 .38795 .42648 .40061 .42256 .393 .41444 Mtetra
.638 .739 .921 r
.393 .41444 .40061 .42256 .41328 .42006 .40575 .41068 Mtetra
.592 .69 .91 r
.40575 .41068 .41328 .42006 .4259 .42177 .41852 .40829 Mtetra
.525 .573 .846 r
.41852 .40829 .4259 .42177 .43846 .42979 .4313 .40834 Mtetra
.507 .467 .747 r
.4313 .40834 .43846 .42979 .45112 .44029 .44413 .41001 Mtetra
.542 .437 .685 r
.44413 .41001 .45112 .44029 .46406 .44544 .4571 .41013 Mtetra
.59 .452 .661 r
.4571 .41013 .46406 .44544 .47727 .44119 .47025 .4058 Mtetra
.632 .48 .658 r
.47025 .4058 .47727 .44119 .49065 .42744 .48352 .39693 Mtetra
.659 .513 .673 r
.48352 .39693 .49065 .42744 .50406 .40816 .49683 .3864 Mtetra
.676 .565 .722 r
.49683 .3864 .50406 .40816 .5174 .39133 .51015 .37751 Mtetra
.68 .647 .81 r
.51015 .37751 .5174 .39133 .53071 .38087 .52349 .37111 Mtetra
.668 .718 .886 r
.52349 .37111 .53071 .38087 .54407 .37465 .53689 .3661 Mtetra
.658 .745 .914 r
.53689 .3661 .54407 .37465 .55749 .36985 .55036 .36149 Mtetra
.656 .751 .92 r
.55036 .36149 .55749 .36985 .57097 .36531 .56389 .35693 Mtetra
.56389 .35693 .57097 .36531 .58452 .36078 .57748 .35236 Mtetra
.57748 .35236 .58452 .36078 .59814 .35623 .59115 .34777 Mtetra
.59115 .34777 .59814 .35623 .61183 .35166 .60488 .34316 Mtetra
.60488 .34316 .61183 .35166 .62558 .34707 .61867 .33853 Mtetra
.61867 .33853 .62558 .34707 .6394 .34245 .63254 .33387 Mtetra
.63254 .33387 .6394 .34245 .65329 .33781 .64648 .32918 Mtetra
.64648 .32918 .65329 .33781 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Mtetra
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Mtetra
.29736 .43613 .30529 .44381 .31765 .43966 .30975 .43194 Mtetra
.30975 .43194 .31765 .43966 .33006 .43549 .3222 .42774 Mtetra
.3222 .42774 .33006 .43549 .34253 .4313 .3347 .42351 Mtetra
.3347 .42351 .34253 .4313 .35506 .42709 .34727 .41926 Mtetra
.34727 .41926 .35506 .42709 .36765 .42286 .3599 .415 Mtetra
.3599 .415 .36765 .42286 .3803 .41862 .37258 .41071 Mtetra
.655 .751 .92 r
.37258 .41071 .3803 .41862 .393 .41444 .38533 .40642 Mtetra
.653 .748 .919 r
.38533 .40642 .393 .41444 .40575 .41068 .39813 .40217 Mtetra
.646 .734 .913 r
.39813 .40217 .40575 .41068 .41852 .40829 .41099 .39813 Mtetra
.631 .689 .886 r
.41099 .39813 .41852 .40829 .4313 .40834 .4239 .39453 Mtetra
.616 .614 .827 r
.4239 .39453 .4313 .40834 .44413 .41001 .43686 .3913 Mtetra
.609 .551 .764 r
.43686 .3913 .44413 .41001 .4571 .41013 .44991 .38781 Mtetra
.615 .526 .73 r
.44991 .38781 .4571 .41013 .47025 .4058 .46304 .38337 Mtetra
.629 .533 .727 r
.46304 .38337 .47025 .4058 .48352 .39693 .47625 .37797 Mtetra
.644 .57 .756 r
.47625 .37797 .48352 .39693 .49683 .3864 .48952 .37232 Mtetra
.657 .633 .814 r
.48952 .37232 .49683 .3864 .51015 .37751 .50284 .36706 Mtetra
.661 .7 .876 r
.50284 .36706 .51015 .37751 .52349 .37111 .51621 .36225 Mtetra
.658 .738 .909 r
.51621 .36225 .52349 .37111 .53689 .3661 .52965 .35764 Mtetra
.656 .749 .918 r
.52965 .35764 .53689 .3661 .55036 .36149 .54316 .35307 Mtetra
.656 .751 .92 r
.54316 .35307 .55036 .36149 .56389 .35693 .55674 .34848 Mtetra
.55674 .34848 .56389 .35693 .57748 .35236 .57038 .34387 Mtetra
.57038 .34387 .57748 .35236 .59115 .34777 .58408 .33924 Mtetra
.58408 .33924 .59115 .34777 .60488 .34316 .59786 .33458 Mtetra
.59786 .33458 .60488 .34316 .61867 .33853 .6117 .32991 Mtetra
.6117 .32991 .61867 .33853 .63254 .33387 .62562 .32521 Mtetra
.62562 .32521 .63254 .33387 .64648 .32918 .6396 .32048 Mtetra
.6396 .32048 .64648 .32918 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Mtetra
.28935 .42838 .29736 .43613 .30975 .43194 .30178 .42416 Mtetra
.30178 .42416 .30975 .43194 .3222 .42774 .31426 .41992 Mtetra
.31426 .41992 .3222 .42774 .3347 .42351 .32681 .41565 Mtetra
.32681 .41565 .3347 .42351 .34727 .41926 .33941 .41137 Mtetra
.33941 .41137 .34727 .41926 .3599 .415 .35207 .40707 Mtetra
.35207 .40707 .3599 .415 .37258 .41071 .36479 .40274 Mtetra
.36479 .40274 .37258 .41071 .38533 .40642 .37758 .3984 Mtetra
.37758 .3984 .38533 .40642 .39813 .40217 .39042 .39404 Mtetra
.655 .749 .919 r
.39042 .39404 .39813 .40217 .41099 .39813 .40333 .38967 Mtetra
.654 .741 .913 r
.40333 .38967 .41099 .39813 .4239 .39453 .4163 .38531 Mtetra
.653 .722 .9 r
.4163 .38531 .4239 .39453 .43686 .3913 .42933 .38097 Mtetra
.651 .697 .879 r
.42933 .38097 .43686 .3913 .44991 .38781 .44242 .37658 Mtetra
.651 .679 .863 r
.44242 .37658 .44991 .38781 .46304 .38337 .45558 .37209 Mtetra
.653 .679 .862 r
.45558 .37209 .46304 .38337 .47625 .37797 .46881 .36751 Mtetra
.655 .698 .878 r
.46881 .36751 .47625 .37797 .48952 .37232 .4821 .36292 Mtetra
.656 .724 .899 r
.4821 .36292 .48952 .37232 .50284 .36706 .49545 .35834 Mtetra
.656 .742 .913 r
.49545 .35834 .50284 .36706 .51621 .36225 .50887 .35377 Mtetra
.656 .749 .919 r
.50887 .35377 .51621 .36225 .52965 .35764 .52235 .34919 Mtetra
.656 .751 .92 r
.52235 .34919 .52965 .35764 .54316 .35307 .5359 .34458 Mtetra
.5359 .34458 .54316 .35307 .55674 .34848 .54952 .33995 Mtetra
.54952 .33995 .55674 .34848 .57038 .34387 .5632 .3353 Mtetra
.5632 .3353 .57038 .34387 .58408 .33924 .57696 .33063 Mtetra
.57696 .33063 .58408 .33924 .59786 .33458 .59078 .32593 Mtetra
.59078 .32593 .59786 .33458 .6117 .32991 .60467 .32121 Mtetra
.60467 .32121 .6117 .32991 .62562 .32521 .61863 .31646 Mtetra
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Mtetra
.28128 .42057 .28935 .42838 .30178 .42416 .29374 .41631 Mtetra
.29374 .41631 .30178 .42416 .31426 .41992 .30626 .41203 Mtetra
.30626 .41203 .31426 .41992 .32681 .41565 .31884 .40773 Mtetra
.31884 .40773 .32681 .41565 .33941 .41137 .33148 .40341 Mtetra
.33148 .40341 .33941 .41137 .35207 .40707 .34418 .39907 Mtetra
.34418 .39907 .35207 .40707 .36479 .40274 .35694 .3947 Mtetra
.35694 .3947 .36479 .40274 .37758 .3984 .36976 .39032 Mtetra
.36976 .39032 .37758 .3984 .39042 .39404 .38264 .38592 Mtetra
.38264 .38592 .39042 .39404 .40333 .38967 .39559 .38149 Mtetra
.39559 .38149 .40333 .38967 .4163 .38531 .4086 .37705 Mtetra
.655 .75 .919 r
.4086 .37705 .4163 .38531 .42933 .38097 .42167 .3726 Mtetra
.655 .748 .918 r
.42167 .3726 .42933 .38097 .44242 .37658 .4348 .36811 Mtetra
.656 .746 .917 r
.4348 .36811 .44242 .37658 .45558 .37209 .448 .3636 Mtetra
.656 .747 .917 r
.448 .3636 .45558 .37209 .46881 .36751 .46127 .35906 Mtetra
.656 .749 .918 r
.46127 .35906 .46881 .36751 .4821 .36292 .4746 .35449 Mtetra
.656 .751 .92 r
.4746 .35449 .4821 .36292 .49545 .35834 .48799 .3499 Mtetra
.48799 .3499 .49545 .35834 .50887 .35377 .50145 .34529 Mtetra
.50145 .34529 .50887 .35377 .52235 .34919 .51498 .34067 Mtetra
.51498 .34067 .52235 .34919 .5359 .34458 .52858 .33602 Mtetra
.52858 .33602 .5359 .34458 .54952 .33995 .54224 .33135 Mtetra
.54224 .33135 .54952 .33995 .5632 .3353 .55597 .32665 Mtetra
.55597 .32665 .5632 .3353 .57696 .33063 .56976 .32194 Mtetra
.56976 .32194 .57696 .33063 .59078 .32593 .58363 .3172 Mtetra
.58363 .3172 .59078 .32593 .60467 .32121 .59757 .31243 Mtetra
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Mtetra
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Mtetra
.28563 .40839 .29374 .41631 .30626 .41203 .29819 .40407 Mtetra
.29819 .40407 .30626 .41203 .31884 .40773 .3108 .39974 Mtetra
.3108 .39974 .31884 .40773 .33148 .40341 .32348 .39538 Mtetra
.32348 .39538 .33148 .40341 .34418 .39907 .33621 .391 Mtetra
.33621 .391 .34418 .39907 .35694 .3947 .34901 .38659 Mtetra
.34901 .38659 .35694 .3947 .36976 .39032 .36187 .38217 Mtetra
.36187 .38217 .36976 .39032 .38264 .38592 .3748 .37773 Mtetra
.3748 .37773 .38264 .38592 .39559 .38149 .38778 .37326 Mtetra
.38778 .37326 .39559 .38149 .4086 .37705 .40083 .36877 Mtetra
.40083 .36877 .4086 .37705 .42167 .3726 .41394 .36425 Mtetra
.656 .75 .919 r
.41394 .36425 .42167 .3726 .4348 .36811 .42712 .35971 Mtetra
.42712 .35971 .4348 .36811 .448 .3636 .44036 .35516 Mtetra
.44036 .35516 .448 .3636 .46127 .35906 .45366 .35059 Mtetra
.656 .75 .92 r
.45366 .35059 .46127 .35906 .4746 .35449 .46703 .346 Mtetra
.656 .751 .92 r
.46703 .346 .4746 .35449 .48799 .3499 .48047 .34138 Mtetra
.48047 .34138 .48799 .3499 .50145 .34529 .49397 .33674 Mtetra
.49397 .33674 .50145 .34529 .51498 .34067 .50754 .33207 Mtetra
.50754 .33207 .51498 .34067 .52858 .33602 .52118 .32738 Mtetra
.52118 .32738 .52858 .33602 .54224 .33135 .53489 .32266 Mtetra
.53489 .32266 .54224 .33135 .55597 .32665 .54866 .31793 Mtetra
.54866 .31793 .55597 .32665 .56976 .32194 .56251 .31316 Mtetra
.56251 .31316 .56976 .32194 .58363 .3172 .57642 .30838 Mtetra
.57642 .30838 .58363 .3172 .59757 .31243 .5904 .30357 Mtetra
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Mtetra
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Mtetra
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .4004 Mtetra
.27745 .4004 .28563 .40839 .29819 .40407 .29004 .39605 Mtetra
.29004 .39605 .29819 .40407 .3108 .39974 .30269 .39167 Mtetra
.30269 .39167 .3108 .39974 .32348 .39538 .31541 .38727 Mtetra
.31541 .38727 .32348 .39538 .33621 .391 .32818 .38285 Mtetra
.32818 .38285 .33621 .391 .34901 .38659 .34102 .37841 Mtetra
.34102 .37841 .34901 .38659 .36187 .38217 .35391 .37395 Mtetra
.35391 .37395 .36187 .38217 .3748 .37773 .36688 .36947 Mtetra
.36688 .36947 .3748 .37773 .38778 .37326 .3799 .36496 Mtetra
.3799 .36496 .38778 .37326 .40083 .36877 .39299 .36044 Mtetra
.656 .752 .921 r
.39299 .36044 .40083 .36877 .41394 .36425 .40614 .35589 Mtetra
.40614 .35589 .41394 .36425 .42712 .35971 .41935 .35132 Mtetra
.41935 .35132 .42712 .35971 .44036 .35516 .43264 .34672 Mtetra
.43264 .34672 .44036 .35516 .45366 .35059 .44598 .3421 Mtetra
.656 .752 .92 r
.44598 .3421 .45366 .35059 .46703 .346 .4594 .33745 Mtetra
.656 .751 .92 r
.4594 .33745 .46703 .346 .48047 .34138 .47288 .33279 Mtetra
.47288 .33279 .48047 .34138 .49397 .33674 .48642 .3281 Mtetra
.48642 .3281 .49397 .33674 .50754 .33207 .50004 .32339 Mtetra
.50004 .32339 .50754 .33207 .52118 .32738 .51372 .31866 Mtetra
.51372 .31866 .52118 .32738 .53489 .32266 .52747 .3139 Mtetra
.52747 .3139 .53489 .32266 .54866 .31793 .54129 .30912 Mtetra
.54129 .30912 .54866 .31793 .56251 .31316 .55518 .30431 Mtetra
.55518 .30431 .56251 .31316 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Mtetra
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Mtetra
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .4004 .2692 .39235 Mtetra
.2692 .39235 .27745 .4004 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Mtetra
.29451 .38353 .30269 .39167 .31541 .38727 .30726 .3791 Mtetra
.30726 .3791 .31541 .38727 .32818 .38285 .32007 .37464 Mtetra
.32007 .37464 .32818 .38285 .34102 .37841 .33295 .37016 Mtetra
.33295 .37016 .34102 .37841 .35391 .37395 .34588 .36565 Mtetra
.34588 .36565 .35391 .37395 .36688 .36947 .35888 .36113 Mtetra
.35888 .36113 .36688 .36947 .3799 .36496 .37195 .35658 Mtetra
.37195 .35658 .3799 .36496 .39299 .36044 .38508 .35201 Mtetra
.38508 .35201 .39299 .36044 .40614 .35589 .39827 .34741 Mtetra
.39827 .34741 .40614 .35589 .41935 .35132 .41152 .3428 Mtetra
.41152 .3428 .41935 .35132 .43264 .34672 .42485 .33816 Mtetra
.42485 .33816 .43264 .34672 .44598 .3421 .43824 .3335 Mtetra
.43824 .3335 .44598 .3421 .4594 .33745 .45169 .32882 Mtetra
.45169 .32882 .4594 .33745 .47288 .33279 .46521 .32412 Mtetra
.46521 .32412 .47288 .33279 .48642 .3281 .4788 .31939 Mtetra
.4788 .31939 .48642 .3281 .50004 .32339 .49246 .31463 Mtetra
.49246 .31463 .50004 .32339 .51372 .31866 .50619 .30985 Mtetra
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Mtetra
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Mtetra
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36183 Mtetra
.32481 .36183 .33295 .37016 .34588 .36565 .33778 .35728 Mtetra
.33778 .35728 .34588 .36565 .35888 .36113 .35082 .35272 Mtetra
.35082 .35272 .35888 .36113 .37195 .35658 .36392 .34813 Mtetra
.36392 .34813 .37195 .35658 .38508 .35201 .37709 .34352 Mtetra
.656 .752 .92 r
.37709 .34352 .38508 .35201 .39827 .34741 .39032 .33889 Mtetra
.656 .752 .921 r
.39032 .33889 .39827 .34741 .41152 .3428 .40362 .33423 Mtetra
.40362 .33423 .41152 .3428 .42485 .33816 .41699 .32955 Mtetra
.41699 .32955 .42485 .33816 .43824 .3335 .43042 .32485 Mtetra
.656 .752 .92 r
.43042 .32485 .43824 .3335 .45169 .32882 .44391 .32012 Mtetra
.44391 .32012 .45169 .32882 .46521 .32412 .45748 .31537 Mtetra
.656 .751 .92 r
.45748 .31537 .46521 .32412 .4788 .31939 .47111 .31059 Mtetra
.47111 .31059 .4788 .31939 .49246 .31463 .48482 .30579 Mtetra
.48482 .30579 .49246 .31463 .50619 .30985 .49859 .30097 Mtetra
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Mtetra
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Mtetra
.31659 .35342 .32481 .36183 .33778 .35728 .32961 .34883 Mtetra
.32961 .34883 .33778 .35728 .35082 .35272 .34268 .34423 Mtetra
.34268 .34423 .35082 .35272 .36392 .34813 .35583 .3396 Mtetra
.35583 .3396 .36392 .34813 .37709 .34352 .36903 .33494 Mtetra
.36903 .33494 .37709 .34352 .39032 .33889 .38231 .33026 Mtetra
.38231 .33026 .39032 .33889 .40362 .33423 .39565 .32556 Mtetra
.39565 .32556 .40362 .33423 .41699 .32955 .40905 .32084 Mtetra
.40905 .32084 .41699 .32955 .43042 .32485 .42253 .31609 Mtetra
.42253 .31609 .43042 .32485 .44391 .32012 .43607 .31132 Mtetra
.43607 .31132 .44391 .32012 .45748 .31537 .44967 .30653 Mtetra
.44967 .30653 .45748 .31537 .47111 .31059 .46335 .30171 Mtetra
.46335 .30171 .47111 .31059 .48482 .30579 .4771 .29687 Mtetra
.4771 .29687 .48482 .30579 .49859 .30097 .49091 .292 Mtetra
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Mtetra
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.3083 .34494 .31659 .35342 .32961 .34883 .32136 .34031 Mtetra
.32136 .34031 .32961 .34883 .34268 .34423 .33447 .33566 Mtetra
.33447 .33566 .34268 .34423 .35583 .3396 .34766 .33099 Mtetra
.34766 .33099 .35583 .3396 .36903 .33494 .3609 .3263 Mtetra
.656 .752 .92 r
.3609 .3263 .36903 .33494 .38231 .33026 .37422 .32158 Mtetra
.37422 .32158 .38231 .33026 .39565 .32556 .3876 .31684 Mtetra
.656 .752 .921 r
.3876 .31684 .39565 .32556 .40905 .32084 .40105 .31207 Mtetra
.40105 .31207 .40905 .32084 .42253 .31609 .41456 .30728 Mtetra
.656 .752 .92 r
.41456 .30728 .42253 .31609 .43607 .31132 .42814 .30246 Mtetra
.42814 .30246 .43607 .31132 .44967 .30653 .4418 .29762 Mtetra
.656 .751 .92 r
.4418 .29762 .44967 .30653 .46335 .30171 .45552 .29275 Mtetra
.45552 .29275 .46335 .30171 .4771 .29687 .46931 .28787 Mtetra
.46931 .28787 .4771 .29687 .49091 .292 .48317 .28295 Mtetra
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Mtetra
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Mtetra
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Mtetra
.31303 .33171 .32136 .34031 .33447 .33566 .32619 .32702 Mtetra
.32619 .32702 .33447 .33566 .34766 .33099 .33941 .3223 Mtetra
.33941 .3223 .34766 .33099 .3609 .3263 .3527 .31756 Mtetra
.3527 .31756 .3609 .3263 .37422 .32158 .36605 .31279 Mtetra
.36605 .31279 .37422 .32158 .3876 .31684 .37947 .308 Mtetra
.37947 .308 .3876 .31684 .40105 .31207 .39296 .30319 Mtetra
.39296 .30319 .40105 .31207 .41456 .30728 .40652 .29836 Mtetra
.40652 .29836 .41456 .30728 .42814 .30246 .42015 .2935 Mtetra
.42015 .2935 .42814 .30246 .4418 .29762 .43384 .28862 Mtetra
.43384 .28862 .4418 .29762 .45552 .29275 .44761 .28371 Mtetra
.44761 .28371 .45552 .29275 .46931 .28787 .46145 .27877 Mtetra
.46145 .27877 .46931 .28787 .48317 .28295 .47535 .27381 Mtetra
.47535 .27381 .48317 .28295 .4971 .27801 .48933 .26883 Mtetra
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Mtetra
.30463 .32303 .31303 .33171 .32619 .32702 .31782 .31829 Mtetra
.31782 .31829 .32619 .32702 .33941 .3223 .33109 .31353 Mtetra
.33109 .31353 .33941 .3223 .3527 .31756 .34441 .30875 Mtetra
.34441 .30875 .3527 .31756 .36605 .31279 .35781 .30394 Mtetra
.656 .752 .92 r
.35781 .30394 .36605 .31279 .37947 .308 .37127 .29911 Mtetra
.37127 .29911 .37947 .308 .39296 .30319 .38481 .29426 Mtetra
.38481 .29426 .39296 .30319 .40652 .29836 .39841 .28938 Mtetra
.39841 .28938 .40652 .29836 .42015 .2935 .41208 .28447 Mtetra
.41208 .28447 .42015 .2935 .43384 .28862 .42582 .27954 Mtetra
.656 .751 .92 r
.42582 .27954 .43384 .28862 .44761 .28371 .43963 .27458 Mtetra
.43963 .27458 .44761 .28371 .46145 .27877 .45351 .2696 Mtetra
.45351 .2696 .46145 .27877 .47535 .27381 .46746 .26459 Mtetra
.46746 .26459 .47535 .27381 .48933 .26883 .48148 .25956 Mtetra
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Mtetra
.29615 .31427 .30463 .32303 .31782 .31829 .30938 .30949 Mtetra
.30938 .30949 .31782 .31829 .33109 .31353 .32269 .30468 Mtetra
.32269 .30468 .33109 .31353 .34441 .30875 .33606 .29985 Mtetra
.33606 .29985 .34441 .30875 .35781 .30394 .34949 .295 Mtetra
.34949 .295 .35781 .30394 .37127 .29911 .363 .29012 Mtetra
.363 .29012 .37127 .29911 .38481 .29426 .37657 .28522 Mtetra
.37657 .28522 .38481 .29426 .39841 .28938 .39022 .28029 Mtetra
.39022 .28029 .39841 .28938 .41208 .28447 .40393 .27534 Mtetra
.40393 .27534 .41208 .28447 .42582 .27954 .41771 .27037 Mtetra
.41771 .27037 .42582 .27954 .43963 .27458 .43157 .26536 Mtetra
.43157 .26536 .43963 .27458 .45351 .2696 .4455 .26033 Mtetra
.4455 .26033 .45351 .2696 .46746 .26459 .45949 .25528 Mtetra
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Mtetra
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Mtetra
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Mtetra
.28759 .30542 .29615 .31427 .30938 .30949 .30086 .3006 Mtetra
.30086 .3006 .30938 .30949 .32269 .30468 .31421 .29575 Mtetra
.31421 .29575 .32269 .30468 .33606 .29985 .32762 .29088 Mtetra
.32762 .29088 .33606 .29985 .34949 .295 .3411 .28598 Mtetra
.656 .752 .92 r
.3411 .28598 .34949 .295 .363 .29012 .35464 .28106 Mtetra
.35464 .28106 .363 .29012 .37657 .28522 .36826 .27611 Mtetra
.36826 .27611 .37657 .28522 .39022 .28029 .38195 .27114 Mtetra
.38195 .27114 .39022 .28029 .40393 .27534 .39571 .26614 Mtetra
.656 .751 .92 r
.39571 .26614 .40393 .27534 .41771 .27037 .40953 .26111 Mtetra
.40953 .26111 .41771 .27037 .43157 .26536 .42343 .25606 Mtetra
.42343 .25606 .43157 .26536 .4455 .26033 .43741 .25098 Mtetra
.43741 .25098 .4455 .26033 .45949 .25528 .45145 .24588 Mtetra
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Mtetra
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Mtetra
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Mtetra
.27895 .2965 .28759 .30542 .30086 .3006 .29226 .29163 Mtetra
.29226 .29163 .30086 .3006 .31421 .29575 .30565 .28673 Mtetra
.30565 .28673 .31421 .29575 .32762 .29088 .3191 .28181 Mtetra
.3191 .28181 .32762 .29088 .3411 .28598 .33262 .27687 Mtetra
.33262 .27687 .3411 .28598 .35464 .28106 .34621 .2719 Mtetra
.34621 .2719 .35464 .28106 .36826 .27611 .35987 .2669 Mtetra
.35987 .2669 .36826 .27611 .38195 .27114 .3736 .26188 Mtetra
.3736 .26188 .38195 .27114 .39571 .26614 .3874 .25684 Mtetra
.3874 .25684 .39571 .26614 .40953 .26111 .40128 .25176 Mtetra
.40128 .25176 .40953 .26111 .42343 .25606 .41522 .24666 Mtetra
.41522 .24666 .42343 .25606 .43741 .25098 .42924 .24154 Mtetra
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Mtetra
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Mtetra
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Mtetra
.27023 .28749 .27895 .2965 .29226 .29163 .28358 .28257 Mtetra
.28358 .28257 .29226 .29163 .30565 .28673 .29701 .27763 Mtetra
.29701 .27763 .30565 .28673 .3191 .28181 .3105 .27267 Mtetra
.3105 .27267 .3191 .28181 .33262 .27687 .32407 .26768 Mtetra
.656 .752 .92 r
.32407 .26768 .33262 .27687 .34621 .2719 .3377 .26266 Mtetra
.3377 .26266 .34621 .2719 .35987 .2669 .3514 .25762 Mtetra
.3514 .25762 .35987 .2669 .3736 .26188 .36518 .25255 Mtetra
.36518 .25255 .3736 .26188 .3874 .25684 .37902 .24745 Mtetra
.656 .751 .92 r
.37902 .24745 .3874 .25684 .40128 .25176 .39294 .24233 Mtetra
.39294 .24233 .40128 .25176 .41522 .24666 .40693 .23718 Mtetra
.40693 .23718 .41522 .24666 .42924 .24154 .42099 .23201 Mtetra
.42099 .23201 .42924 .24154 .44333 .23639 .43513 .2268 Mtetra
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Mtetra
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Mtetra
.26142 .27839 .27023 .28749 .28358 .28257 .27482 .27343 Mtetra
.27482 .27343 .28358 .28257 .29701 .27763 .28829 .26844 Mtetra
.28829 .26844 .29701 .27763 .3105 .27267 .30182 .26343 Mtetra
.30182 .26343 .3105 .27267 .32407 .26768 .31543 .25839 Mtetra
.31543 .25839 .32407 .26768 .3377 .26266 .3291 .25332 Mtetra
.3291 .25332 .3377 .26266 .3514 .25762 .34285 .24823 Mtetra
.34285 .24823 .3514 .25762 .36518 .25255 .35667 .24312 Mtetra
.35667 .24312 .36518 .25255 .37902 .24745 .37056 .23797 Mtetra
.37056 .23797 .37902 .24745 .39294 .24233 .38452 .2328 Mtetra
.38452 .2328 .39294 .24233 .40693 .23718 .39856 .22761 Mtetra
.39856 .22761 .40693 .23718 .42099 .23201 .41267 .22238 Mtetra
.41267 .22238 .42099 .23201 .43513 .2268 .42685 .21713 Mtetra
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3ooomC0:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0oooo00<000000?ooo`3oool0AP3ooomE0:O0j`03
0000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo
F@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?oooe`0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo02P0oooo000T
0?ooo`800000B`3ooomM0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?oo
oe`0Yl3[0`0000020:O0j`030000002W`>/0Yl3[0180Yl3[4P3oool00`000000oooo0?ooo`0V0?oo
o`007`3oool3000004T0ooooG@2W`>/3000000D0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`03
0000003oool0oooo02H0oooo000M0?ooo`800000B`3ooomK0:O0j`<000002@2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0303oool2000000@0oooo0P0000030?ooo`@00000
2P3oool001D0oooo1@0000030?ooo`800000B@3ooomJ0:O0j`<000003@2W`>/00`000000Yl3[0:O0
j`0C0:O0ja40oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`0000140?oooe`0Yl3[0P00
000A0:O0j`030000002W`>/0Yl3[01<0Yl3[403oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000o0?oooed0Yl3[0`00000C0:O0j`030000002W`>/0Yl3[01<0Yl3[
4@3oool00`000000oooo0?ooo`030?ooo`@000000P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00T0oooo000?0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>`3ooomK0:O0j`<000005`2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo03P0ooooFP2W`>/3000001/0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`80
00002`3oool2000000X0oooo0P00000;0?ooo`005P3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0c0?oooe/0Yl3[0`00000O0:O0j`030000002W`>/0Yl3[0180Yl3[
4@3oool00`000000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03o
oomK0:O0j`<000008P2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0803o
ool001`0oooo0P0000080?ooo`030000003oool0oooo02/0ooooFP2W`>/3000002H0Yl3[00<00000
0:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0:03ooomI0:O0j`<00000:P2W`>/00`000000Yl3[0:O0j`0B0:O0
ja40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0S0?oooeX0Yl3[0`00000^0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000
oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<000000?ooo`3oool07`3ooomK0:O0j`800000
<@2W`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo00<000000?ooo`3oool07P3oool001/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?oooe`0Yl3[0`00000d0:O0j`030000002W
`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01P0ooooFP2W`>/3000003P0Yl3[00<000000:O0j`2W`>/04@2W`>/@
0?ooo`8000007`3oool001/0oooo0P00000?0?ooo`030000003oool0oooo01D0ooooF@2W`>/30000
03/0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01`0oooo000K0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04@3ooomI0:O0j`<00000?`2W`>/00`000000
Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P0000040?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?oooeX0Yl3[
0`0000130:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0K0?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00000C0?ooo`03
0000003oool0oooo00X0ooooF02W`>/3000004L0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`03
0000003oool0oooo01X0oooo00070?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3o
ool0oooo0000000E0?ooo`030000003oool0oooo00L0ooooE`2W`>/3000004X0Yl3[00<000000:O0
j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01T0oooo00000`3oool000000000000200000080
oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`020?oooeP0Yl3[0`00001>0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`00
0000oooo0?ooo`0I0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00<0oooo0P00000F0?ooo`030000002W`>/0Yl3[05L0Yl3[0P00001B0:O0j`030000002W`>/0Yl3[
0140Yl3[403oool2000001X0oooo00080?ooo`8000002P3oool3000000<0oooo00<000000?ooo`3o
ool04P3ooomJ0:O0j`<00000E@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3o
ool05`3oool001T0oooo00<000000?ooo`3oool04P3ooomH0:O0j`<00000F02W`>/00`000000Yl3[
0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool05`3oool001T0oooo0P00000A0?oooeL0Yl3[0`00
001L0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0F0?ooo`006@3oool0
0`000000oooo0?ooo`0=0?oooeL0Yl3[0`00001P0:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool0
0`000000oooo0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`090?oooeP0Yl3[0`00000<0:O0
j`D0Yko[D`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool05@3oool001T0
oooo0P0000070?oooeP0Yl3[0`00000<0:O0j`T0Yko[2@2W`>/50:Nojd@0Yl3[00<000000:O0j`2W
`>/04P2W`>/@0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo00<0oooo
F02W`>/3000000d0Yl3[302W_n/50:O0j`@0YkgY2@2W_n]00:O0j`030000002W`>/0Yl3[0180Yl3[
403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`030?oooeH0Yl3[0`00
000>0:O0j`P0Yko[0P2W_nX50:Noj`D0YkWV102W_NT50:Rlj0@0Yko[@02W`>/00`000000Yl3[0:O0
j`0A0:O0j`l0oooo0P00000E0?ooo`00603oool010000000oooo0000003ooomF0:O0j`8000003P2W
`>/90:Noj`D0YkoZ0`2W_n/20:Nbh0D0YkWV0P2W_NT20:Vch0D0Z;cX102X_^To0:O0j`030000002W
`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`060?ooo`8000002P3oool001P0oooo00<00000
0:O0j`2W`>/0E02W`>/300000140Yl3[102W_n/50:NnjPD0YkoZ1@2W/^040:NiiPD0ZK?P0P2X_>P3
0:^ghP@0Z;kY1@2X`>/j0:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000T0oooo000A0?ooo`8000001@3oool00`000000oooo0:O0j`1A
0:O0j`<000005@2W`>/40:Noj`D0YkkZ1@2W[M`40:Nbh0D0Z:;@102Y/n060:^ghP80Z;kY0P2Z_nT5
0:S0jcX0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1>0:O0j`<00000502W`>/90:Noj`D0YZgL1@2W[M`40:BA`@D0Z:;@102^YLl50:^ghPD0Z[oY1@2X
`>/j0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo0P0000020?ooodX0Yl3[
0`00000H0:O0j`D0Yko[102V/^450:J]g080YjgL0`2QR;X30:BA`@@0Z:;@0P2]T;P40:jUc`D0/[WN
102Z_nT60:S0jcT0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooodH0Yl3[0`00000L0:O0j`D0YkSV102V/^440:J]g0D0XHRj102TTL420:RRd0<0
[I2h0`2^YLl20;f[a`D0/[WN102/`NT50:S0jcX0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`80
0000103oool2000000X0oooo000@0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool01@3ooom10:O0j`<000007P2W`>/20:Nmj@D0YkSV0`2V/^4509f6^P@0XHRj102TTL450:f@^080
[ZG?102mZlL20;:igP<0^l?O102/`NT50:S0jcX0Yl3[00<000000:O0j`2W`>/04@2W`>/>0?ooo`<0
0000403oool00140oooo0P0000040?ooo`8000001`3ooolm0:O0j`<000007`2W`>/50:Nmj@@0YkSV
102KSL<409f6^P@0XHRj0`2TTL420:R3[0@0[I2h1P2mZlL50;_3g`D0[<;Y102X`>/k0:O0j`030000
002W`>/0Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`0>0?ooo`005`3oool00`000000oooo0?oo
o`070?ooocT0Yl3[0`00000O0:O0j`@0Yko[1@2W_NT409fMd`<0Vhg3102MQ[X40:68^P80Y9710`2X
Pj`40:f@^0030<2K/P2mZlL0_J_70080_J_70P3A_/L30;_3g`80_lOQ1@2/`^T40:S0jcX0Yl3[00<0
00000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00d0oooo000G0?ooo`030000003oool0
oooo00P0oooo=@2W`>/3000002<0Yl3[102W_n/50:6`hP<0WIgC0`2KSL<509f6^P<0XHRj1@2XPj`3
0:f@^080`9^b0`2mZlL40=6na`D0_lOQ1@2/`^T40:S0jcX0Yl3[00<000000:O0j`2W`>/04@2W`>/@
0?ooo`030000003oool0oooo00`0oooo000G0?ooo`8000002@3ooolc0:O0j`8000009`2W`>/40:Fk
j@@0XK3R102MWM<309^=``@0WHJj0P2QR;X20:5jZ0D0Z8>/0P2]T;P30<2K/P030;f[a`3A_/L0dKk7
00<0dKk700<0fl[80;o7h@2oan400`2oan450:c2j@@0Z<3[>P2W`>/00`000000Yl3[0:O0j`0A0:O0
j`l0oooo00<000000?ooo`3oool0303oool001L0oooo00<000000?ooo`3oool02P3oool^0:O0j`<0
00009@2W`>/50:Noj`@0YK_Y0`2Q/>8409fMd`<0Vhg3102MQ[X40:5jZ0D0Z8>/00<0[I2h0<2K/P30
Vk800P30Vk850=6na`<0fl[81@2oan450:c2j@@0Z<3[>P2W`>/00`000000Yl3[0:O0j`0@0:O0ja00
oooo00<000000?ooo`3oool02`3oool001H0oooo00<000000?ooo`3oool0303ooolZ0:O0j`<00000
:@2W`>/50:Noj`<0YK_Y0`2Q/>8409fMd`<0Vhg31@2GLjT30:5jZ0D0Z8>/1@30Vk80103H/K80dKk7
0=6na`3A_/L50=_:b0<0_lOQ0P2nan440:c2j@D0Z<3[>@2W`>/00`000000Yl3[0:O0j`0A0:O0ja00
oooo00<000000?ooo`3oool02P3oool001H0oooo0P00000>0?ooobH0Yl3[0`00000]0:O0j`D0Xkg[
0`2G/>P308JBf0@0PGNo0`2:Kjl409McZ@<0XGZX1@2XPj`0102lTJX0`9^b0<2K/P30Vk830=Ra/P03
0=6na`3Kb/P0fl[800D0fl[81@2nan440:c2j@D0Z<3[>@2W`>/00`000000Yl3[0:O0j`0@0:O0j`l0
oooo0P00000<0?ooo`005P3oool00`000000oooo0?ooo`0>0?ooob80Yl3[0`00000]0:O0j`@0Yko[
1@2S_N/309N`j080QY;H1021Mkl308Y_[`@0Ug>Y102QNZP30:R3[080_96Z0`30Vk830=Ra/PP0fl[8
00<0g<_80;k7h@2nan400`2nan440:c2j@D0Z<3[>@2W`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo
00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0403ooolM0:O0j`<00000<@2W
`>/40:Noj`@0Xkg[0`2G/>P308JBf0<0PGNo0`2:Kjl409McZ@@0XGZX0P2XPj`40;bAZP030<2K/P3H
/K80f;6b0080f;6b00<0j/J`0=_:b03Kb/P0103Kb/P20=c;b0H0_/OQ102/`^T50:S0jcP0Yl3[00<0
00000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00P0oooo000F0?ooo`8000004P3ooolI
0:O0j`<00000=@2W`>/40:Fok0@0UkS_0`1XVN`00`0[G<l0QY;H085g_`02085g_`<0RVn_1@2GLjT3
0:5jZ0030:R3[02lTJX0_96Z00<0_96Z00<0`9^b0=Ra/P3H/K800P3H/K820>[6/0@0fl[80`3LblP6
0;k7h@D0[<;Y1@2X`>/h0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`08
0?ooo`005P3oool00`000000oooo0?ooo`0B0?oooaD0Yl3[0`00000i0:O0j`@0YKo/102G^>l206RI
k080:ec?1021Mkl208Y_[`D0Ug>Y0`2QNZP60;bAZP@0f;6b0`3Za[000`3[ak00fl[80=_:b0040=c;
b0030=_:b02nan40_/OQ00@0_/OQ1@2/`^T40:S0jcT0Yl3[00<000000:O0j`2W`>/0402W`>/?0?oo
o`8000002@3oool000<0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool0503ooolA0:O0j`<00000?@2W`>/30:Fok0D0R;Cb00D03fcN06RIk00[G<l0:ec?045?^P02085g
_`<0RVn_102GLjT20:5jZ080[hN[1@2lTJX0103>XZ/0f;6b0=Ra/P3H/K830>[6/080jlN`103LblP3
0=_:b0H0_/OQ1@2/`^T40:S0jcT0Yl3[00<000000:O0j`2W`>/0402W`>/;0?ooo`<0000000<0oooo
0000003oool0203oool00080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo01D0oooo3P2W`>/200000400Yl3[102S_^d508RdlP0300m/gP0[
G<l0:ec?0080@Dnj00@0PGNo08Y_[`2:Kjl0RVn_102GLjT0102QNZP0[hN[0:n7Z`2_Qj/40;bAZP80
cZ:[0P3H/K830>[6/0@0jlN`0P3LblP40=_:b0030=_;b02nan40_/OQ00@0_/OQ1@2/`^T40:S0jcP0
Yl3[00<000000:O0j`2W`>/04@2W`>/60?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`00
0P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`8000005`3oool:0:O0
j`<00000@`2W`>/40:>nk@D0P[;d00<03fcN02]Lc`11CkX00P11CkX308Y_[`@0Ug>Y102_Qj/40;bA
ZP<0cZ:[00@0f;6b0>[6/03Za[00j/J`1@3[ak040=_:b0<0fl_81@2nan460:c2j@@0Z<3[>02W`>/0
0`000000Yl3[0:O0j`0A0:O0j`80oooo0`0000080?ooo`030000003oool0oooo00L0oooo00020?oo
o`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01P0oooo1@2W`>/3
000004L0Yl3[102R_^d508:bm00300m/gP0[G<l0@Dnj0080@Dnj00@0MFFb08Y_[`2GLjT0Ug>Y0`2I
NJh40:n7Z`80_96Z103>XZ/30>[6/0L0jlN`0P3Kb/P40=_;b0030=_;b@2nan40_/OQ00<0_/OQ1@2/
`^T50:S0jcP0Yl3[00<000000:O0j`2W`>/0402W`>/2000000`0oooo00<000000?ooo`3oool01P3o
ool00080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01T0oooo00@0Yl3[0000000000000000B`2W`>/40::nk@@0P[;d00<004g70000N`11CkX0
0P11CkX207EU/PD0VGV^102_Qj/20;bAZP@0cZ:[00<0k<B[0>[6/03Za[00203[ak040=_;b0<0fl_9
1@2nan450:c2j@D0Z<3[>02W`>/00`000000Yl3[0:O0j`0@0:O0j`d0oooo00<000000?ooo`3oool0
1P3oool000<0oooo0P00000:0?ooo`<000000`3oool2000001P0oooo0`00001?0:O0j`@0X[k]1022
/_<01000C/P0@Dnj045?^P11CkX307EU/P@0VGV^102_Qj/00`2lTJX0cZ:[0<jRZ`030<jRZ`80k<B[
2P3[ak020=_;b0<0fl_90P3Kb/T50;k7h@@0[<;Y1P2X`>/g0:O0j`030000002W`>/0Yl3[0100Yl3[
3@3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`<00000103o
oom?0:O0j`@0X[k]1022/_<00`00C/P0@Dnj045?^P0307EU/P@0VGV^102_Qj/50<jRZ`<0k<B[00<0
kLF[0>_7/03[ak00203[ak030=_;b@@0fl[91@2nan440:c2j@H0Z<3[=`2W`>/00`000000Yl3[0:O0
j`0@0:O0j``0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool04P3oool3
000000P0ooooC`2W`>/40::nk@@0P[;c00<0002D045?^P11CkX00P1eIK8509Ui[P<0[hN[00<0]hn]
0<jRZ`3>XZ/00P3>XZ/30>c4Z`80kLF[2P3[ak000`3KblT0fl[90=_:b@020=_:b@80fl_91@2nan44
0:c2j@D0Z<3[>02W`>/00`000000Yl3[0:O0j`0@0:O0j`/0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P00000@0?ooo`<00000303ooom?0:O0j`@0X[k]1022/_<0100009@0@Dnj07EU/P1eIK85
09Ui[P80[hN[0P2gSjd30<jRZ`<0k<B[103]aJ/90>_7/0@0fl[90`3KblT60;k7h@@0[<;Y1@2X`>/h
0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`00
0000oooo0?ooo`0<0?ooo`<000004@3ooom>0:O0j`@0X[k]0`23/_<20000U0<0MFFb102INJh20:n7
Z`80]hn]0`3>XZ/30>c4Z`D0kLF[2@3[ak020=_:b@@0fl_900<0fl[90;k7h@2nan40102nan440:c2
j@D0Z<3[=`2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0
oooo00<000000?ooo`3oool02P3oool2000001D0ooooCP2W`>/40::nk@<0Pk;c00@0002D07EU/P1e
IK80MFFb102INJh00`2_Qj/0]hn]0;N?[@020;N?[@040<jRZ`3/a:/0k<B[0>c4Z`H0kLF[00<0kLFZ
0>_7/03[ak001`3[ak040=_;b@<0fl[91@2nan450:c2j@D0Z<3[=`2W`>/00`000000Yl3[0:O0j`0@
0:O0j`X0oooo00<000000?ooo`3oool01@3oool001@0oooo00<000000?ooo`3oool01`3oool30000
01P0ooooCP2W`>/40::nk@<0Pk;c00<0002D05aP_@1eIK80102INJh50;N?[@040<jRZ`3/a:/0k<B[
0>c4Z`H0kLF[00<0kLFZ0>_7/03[ak00203[ak020=_;b@@0fl[900<0fl_90;k7h@2nan400`2nan45
0:c2j@D0Z<3[=`2W`>/00`000000Yl3[0:O0j`0?0:O0j`X0oooo00<000000?ooo`3oool01@3oool0
01<0oooo0`0000050?ooo`<00000703ooom>0:O0j`@0X[k]0P23/_<00`0009@0G62m05aP_@0509Ym
/P@0]hn]0`3/a:/60>g5Z`80kLFZ2`3[ak040=_:b@<0fl_91@2nan450:c2jPD0Z<3[=`2W`>/00`00
0000Yl3[0:O0j`0?0:O0j`T0oooo00<000000?ooo`3oool01@3oool001<0oooo00<000000?ooo`3o
ool00P3oool300000200ooooCP2W`>/40::nk@80Pk;c00<0002D05aP_@1LH;d0102JOK840;N?[@03
0>;5_03/a:/0k<B[00H0kLF[0`3]aJX;0>_7/080fl[91@3KblT30;k7h@80_/_T102/`^X50:S0jcL0
Yl3[00<000000:O0j`2W`>/0402W`>/80?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000
003oool0000000800000903ooom>0:O0j`@0X[k]0P23/_<205aP_@@0VWfb0`2gSjd30>;5_0H0kLF[
1@3]aJX;0>_7/0L0fl_91@2nbn@50:_3j`@0Z<3[=`2W`>/00`000000Yl3[0:O0j`0@0:O0j`L0oooo
00<000000?ooo`3oool01@3oool001<0oooo0`00000W0?ooodh0Yl3[102R_^d00`23/_<0G62m05aP
_@0509Ym/P80]hn]0`3RaK`00`3Sak/0kLF[0>g5Z`030>g5Z`H0kLFZ2`3[ak050=_;b@80hMS>0P2n
bn@30;gAjP80Zl?[0`2Y`^`40:S0jcL0Yl3[00<000000:O0j`2W`>/03`2W`>/70?ooo`030000003o
ool0oooo00D0oooo000D0?ooo`030000003oool0oooo02L0ooooCP2W`>/40::nk@0308Bbl`1LH;d0
G62m00@0VWfb00@0]hn]0>;5_03RaK`0h/Fl0`3Sak/30>g5Z`P0kLFZ2`3[ak030=_;b@<0hMS>1@2m
dNX60:W2k3X0Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00@0oooo000;
0?ooo`D000001@3oool2000002T0ooooC@2W`>/40::nk@0308Bbl`1LH;d0VWfb00<0VWfb00@0]hn]
0>;5_03RaK`0h/Fl0`3Sak/00`3UbK/0kLF[0>g5Z`0:0>g5ZPX0jlN`00@0fl_90>7HcP3Qf<h0hMS>
0`3RkmP50;C>k@D0Z<7[>P2W`>/00`000000Yl3[0:O0j`0@0:O0j`H0oooo00<000000?ooo`3oool0
103oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooodd0Yl3[102R
_^d00`0008@0VWfb09Ym/P0209Ym/P<0h/Fl0`3Sak/30>G9^``0kLFZ2@3[ak030>7HcP<0h^oH0P3?
lNT30;C>k@80ZlG]102X`N/k0:O0j`030000002W`>/0Yl3[0100Yl3[1@3oool00`000000oooo0?oo
o`040?ooo`003@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02L0ooooC@2W`>/4
0::nk@D0Y[_Y0P3RaK`30>?7^`<0iLVk00<0i<Rk0>g5ZP3]aJX02P3]aJX80>_7/080n>2^0`3RkmP4
0<oaj@D0ZlG]?`2W`>/00`000000Yl3[0:O0j`0?0:O0j`D0oooo00<000000?ooo`3oool0103oool0
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooodd0Yl3[102R_^d50:Jk
j@<0hlNk0`3UbK/30>C8^``0kLFZ1`3[ak020?SP[P80jOBM00<0co7Y0;GDl02ee?000`2ee?050:S1
jch0Yl3[00<000000:O0j`2W`>/0402W`>/40?ooo`030000003oool0oooo00@0oooo000=0?ooo`03
0000003oool0oooo00X0oooo0P00000X0?ooodd0Yl3[102R_^d50:Jnj`80hlNk0P3UbK/40>C8^`03
0>G8^`3]aJX0kLFZ00X0kLFZ1@3[ak020?SP[P80jOBM00<0]nbF0<?dk`33m>l00`2ee?020:[3k0@0
Z<7[?`2W`>/00`000000Yl3[0:O0j`0?0:O0j`@0oooo00<000000?ooo`3oool0103oool000`0oooo
0P00000>0?ooo`030000003oool0oooo02H0ooooC@2W`>/30::nk@0308d>002V_^/0Y[k[00<0Y[k[
0`3UbK/30>C8^`<0iLRk2`3]aJX00`3^aJT0jlN`0>_7/0020>_7/080n>2^00<0jOBM0<?dk`33m>l0
0`33m>l50:[3k4<0Yl3[00<000000:O0j`2W`>/03`2W`>/30?ooo`030000003oool0oooo00@0oooo
000M0?ooo`030000003oool0oooo02H0ooooC@2W`>/30::nk@0308`>002U`^h0YL;^00<0YL;^00@0
iLVk0>C8^`3Tb;/0i<Rk103Ub;/00`3Ub;X0kLFZ0>g5ZP080>g5ZP040>k5Z@3[ak00jlN`0>_7/080
n>2^00@0jOBM09O/]02Gk;@0Unbd1@2]b^m70:O0j`030000002W`>/0Yl3[00h0Yl3[103oool00`00
0000oooo0?ooo`030?ooo`007P3oool00`000000oooo0?ooo`0V0?ooodd0Yl3[0`2R_^d00`2<3P00
YL;^0:G2kP020:G2kP@0i<Rk0`3Ub;/30>G8^PP0kLFZ0P3^aJT00`3^aZX0jlN`0>_7/0020?SP[PD0
/=Cc1@2X`N]60:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?ooo`00
7`3oool2000002P0ooooC02W`>/30::nk@0308`>002V`>`0Y/3/0080Y/3/0P3Tb;/30>G8^`D0iLRj
1`3]aJX20>k5Z@80k/JZ0P3hh:h00`2Xb580[=_h0:cKn0040:S1k0@0Z<7[A`2W`>/00`000000Yl3[
0:O0j`0@0:O0j`030?ooo`000000oooo00@0oooo000Q0?ooo`030000003oool0oooo02H0ooooC02W
`>/30:>ok@0308`>002V`>`0Y/3/0080Y/3/103Ub;/60>G8^PD0kLFZ0P3^aJT30>k6ZP80n>VB102X
`^`40:S1k4/0Yl3[00<000000:O0j`2W`>/03`2W`>/00`3oool000000?ooo`040?ooo`008P3oool0
0`000000oooo0?ooo`0V0?oood`0Yl3[0`2S_nd00`2<3P00Y/3/0:K0k0020:G1k@80iLRk203Ub;X4
0>g5ZP80k/FY0`3^aZX00`3hjI80Z<QB0:O1k0040:S2k4l0Yl3[00<000000:O0j`2W`>/03`2W`>/0
0`000000oooo0?ooo`030?ooo`008`3oool00`000000oooo0?ooo`0V0?oood`0Yl3[0`2U_n`50:G1
k@T0iLRj0`3]aJX30>k5Z@80k/JZ0P3hjI820:O1k5<0Yl3[00<000000:O0j`2W`>/03`2W`>/00`00
0000oooo0?ooo`030?ooo`00903oool2000002L0ooooC02W`>/30:Fok0D0YL7]203Ub;X00`3UakX0
kLFZ0>g5ZP020>k5Z@<0k/JZ00<0n>VB0:O0j`2W`>/0E@2W`>/00`000000Yl3[0:O0j`0;0:O0j`<0
oooo00<000000?ooo`3oool00`3oool002H0oooo00<000000?ooo`3oool09@3ooom?0:O0j`D0YL7]
1P3Ub;X30>G7^P<0k/FY0`3^aZX00`3hjI80Yl3[0:O0j`030:O0j`@0Yko[C`2W`>/00`000000Yl3[
0:O0j`060:O0j`P0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool09@3o
oom?0:O0j`<0YL7]0P2V`Nd50>G8^P<0iLNj00<0i/Vj0>k5Z@3^aJT00P3^aZX0103hjI80Yl3[0:O0
j`2W`>/80:Nojdh0Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`030000003oool0oooo0080oooo
000X0?ooo`030000003oool0oooo02H0ooooCP2W`>/50:K1k@<0iLRj0`3UakX30>K9^P<0k/JZ1@2W
`>/40:Noje80Yl3[00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00:@3oool2
000002L0ooooCP2W`>/30:K1k@80YL;^0P3Ub;X30>G7^P<0i/Vj00<0il^j0>k6ZP3^aZX0F@2W`>/3
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?oo
o`3oool09@3ooom>0:O0j`D0YL;^0`3UakX30>K9^P<0il^jEP2W`>/80?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool09@3ooom>0:O0j`D0
Y/3/0P3UakX30>K9^P<0il^jD`2W`>/;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool002d0oooo00<000000?ooo`3oool09P3ooom=0:O0j`D0Y/3/0`3VbKX30>O;^U40Yl3[
3`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000^0?ooo`030000003o
ool0oooo02H0ooooC@2W`>/50:G3k`80i/Vj0P3WbkY>0:O0ja@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`010?ooo`00;`3oool2000002L0ooooC@2W`>/50:G3k`<0il^jB`2W`>/H
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool09@3ooom=0:O0j`D0YLOa00<0il^j0:O0j`2W`>/0AP2W`>/L0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3oool09@3ooom=0:O0j`@0
YLOaAP2W`>/P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool003<0oooo
00<000000?ooo`3oool09@3ooonC0:O0jb@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`010?ooo`00=03oool2000002H0ooooSP2W`>/Y0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00@3oool003H0oooo00<000000?ooo`3oool09@3ooon90:O0jb`0oooo00<00000
0?ooo`3oool01`3oool100000040oooo0@3oool003L0oooo00<000000?ooo`3oool09@3ooon50:O0
jc00oooo00<000000?ooo`3oool01P3oool100000040oooo0@3oool003P0oooo00<000000?ooo`3o
ool09@3ooomm0:O0jcP0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool003T0oooo
0P00000V0?ooogT0Yl3[>`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>`3o
ool00`000000oooo0?ooo`0T0?ooogD0Yl3[?`3oool00`000000oooo0?ooo`040?ooo`4000000@3o
ool10?ooo`00?03oool00`000000oooo0?ooo`0T0?ooog40Yl3[@`3oool00`000000oooo0?ooo`03
0?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?ooo`0T0?ooof`0Yl3[B03oool00`00
0000oooo0?ooo`020?ooo`4000000@3oool10?ooo`00?P3oool2000002D0ooooJ02W`>];0?ooo`03
0000003oool0oooo00<0oooo0@0000010?ooo`00@03oool00`000000oooo0?ooo`0S0?ooof@0Yl3[
C`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3o
oomP0:O0je<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3oool00`000000oooo0?oo
o`0T0?oooe/0Yl3[E`3oool010000000oooo0?ooo`0000010?ooo`00@`3oool2000002D0ooooD`2W
`>]N0?ooo`040000003oool0oooo00000040oooo00150?ooo`030000003oool0oooo02<0ooooC`2W
`>]R0?ooo`030000003oool000000040oooo00160?ooo`030000003oool0oooo02<0ooooB`2W`>]V
0?ooo`4000000@3oool100000000A`3oool00`000000oooo0?ooo`0S0?ooodL0Yl3[JP3oool20000
0000B03oool2000002D0oooo@P2W`>]]0?ooo`800000001:0?ooo`030000003oool0oooo02<0oooo
?P2W`>]`0?ooo`800000001;0?ooo`030000003oool0oooo0280oooo>`2W`>]_0?ooo`@000000P3o
ool004`0oooo00<000000?ooo`3oool08`3ooolc0:O0jg40oooo100000060?ooo`00C@3oool20000
02@0oooo;`2W`>]`0?ooo`@000002P3oool004l0oooo00<000000?ooo`3oool08P3oool[0:O0jfl0
oooo1000000>0?ooo`00D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo
001A0?ooo`030000003oool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580oooo0P00000T
0?oooah0Yl3[K@3oool4000001T0oooo001D0?ooo`030000003oool0oooo0280oooo5`2W`>]_0?oo
o`@000007@3oool005D0oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00
EP3oool00`000000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?ooo`8000008`3o
ool;0:O0jf`0oooo1000000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool3
000002d0oooo001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool40000
0300oooo001K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0
oooo001L0?ooo`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool005h0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00000L0?ooo`03
0000003oool0oooo05<0oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo04/0oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo04L0oooo1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04<0oooo1000001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03oool3000005/0
oooo001Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4000005h0oooo
001Z0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?oo
o`800000403oool00`000000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`030000003oool0
oooo0280oooo1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01h0oooo1000001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0
oooo100000210?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo
100000250?ooo`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003o
ool0103oool4000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3o
ool200000:00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Mtetra
.59604 .63937 .60194 .6454 .6135 .64214 .60764 .63608 Mtetra
.60764 .63608 .6135 .64214 .62511 .63886 .61928 .63278 Mtetra
.61928 .63278 .62511 .63886 .63677 .63558 .63097 .62947 Mtetra
.63097 .62947 .63677 .63558 .64848 .63228 .64272 .62614 Mtetra
.64272 .62614 .64848 .63228 .66023 .62897 .65451 .62279 Mtetra
.65451 .62279 .66023 .62897 .67204 .62564 .66635 .61944 Mtetra
.66635 .61944 .67204 .62564 .6839 .6223 .67824 .61607 Mtetra
.67824 .61607 .6839 .6223 .6958 .61894 .69018 .61269 Mtetra
.69018 .61269 .6958 .61894 .70776 .61556 .70217 .6093 Mtetra
.70217 .6093 .70776 .61556 .71976 .61218 .71421 .60589 Mtetra
.71421 .60589 .71976 .61218 .73182 .60878 .7263 .60246 Mtetra
.7263 .60246 .73182 .60878 .74393 .60536 .73845 .59902 Mtetra
.73845 .59902 .74393 .60536 .75609 .60193 .75064 .59557 Mtetra
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62666 Mtetra
.61341 .62666 .61928 .63278 .63097 .62947 .62514 .62332 Mtetra
.62514 .62332 .63097 .62947 .64272 .62614 .63691 .61997 Mtetra
.656 .752 .921 r
.63691 .61997 .64272 .62614 .65451 .62279 .64873 .61661 Mtetra
.64873 .61661 .65451 .62279 .66635 .61944 .66061 .61323 Mtetra
.66061 .61323 .66635 .61944 .67824 .61607 .67253 .60984 Mtetra
.67253 .60984 .67824 .61607 .69018 .61269 .68451 .60642 Mtetra
.68451 .60642 .69018 .61269 .70217 .6093 .69653 .60299 Mtetra
.656 .752 .92 r
.69653 .60299 .70217 .6093 .71421 .60589 .70861 .59955 Mtetra
.656 .751 .92 r
.70861 .59955 .71421 .60589 .7263 .60246 .72074 .5961 Mtetra
.72074 .5961 .7263 .60246 .73845 .59902 .73292 .59263 Mtetra
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Mtetra
.59578 .62383 .60173 .62998 .61341 .62666 .60749 .62048 Mtetra
.60749 .62048 .61341 .62666 .62514 .62332 .61925 .61712 Mtetra
.61925 .61712 .62514 .62332 .63691 .61997 .63106 .61373 Mtetra
.63106 .61373 .63691 .61997 .64873 .61661 .64292 .61034 Mtetra
.64292 .61034 .64873 .61661 .66061 .61323 .65482 .60693 Mtetra
.65482 .60693 .66061 .61323 .67253 .60984 .66678 .6035 Mtetra
.66678 .6035 .67253 .60984 .68451 .60642 .67879 .60007 Mtetra
.67879 .60007 .68451 .60642 .69653 .60299 .69085 .59663 Mtetra
.69085 .59663 .69653 .60299 .70861 .59955 .70297 .59316 Mtetra
.70297 .59316 .70861 .59955 .72074 .5961 .71513 .58968 Mtetra
.71513 .58968 .72074 .5961 .73292 .59263 .72735 .58619 Mtetra
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Mtetra
.60153 .61426 .60749 .62048 .61925 .61712 .61332 .61087 Mtetra
.61332 .61087 .61925 .61712 .63106 .61373 .62516 .60747 Mtetra
.656 .752 .921 r
.62516 .60747 .63106 .61373 .64292 .61034 .63705 .60406 Mtetra
.63705 .60406 .64292 .61034 .65482 .60693 .649 .60063 Mtetra
.649 .60063 .65482 .60693 .66678 .6035 .66099 .59718 Mtetra
.66099 .59718 .66678 .6035 .67879 .60007 .67303 .59371 Mtetra
.67303 .59371 .67879 .60007 .69085 .59663 .68513 .59023 Mtetra
.656 .752 .92 r
.68513 .59023 .69085 .59663 .70297 .59316 .69728 .58673 Mtetra
.656 .751 .92 r
.69728 .58673 .70297 .59316 .71513 .58968 .70948 .58322 Mtetra
.70948 .58322 .71513 .58968 .72735 .58619 .72173 .5797 Mtetra
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Mtetra
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Mtetra
.59552 .60799 .60153 .61426 .61332 .61087 .60734 .60457 Mtetra
.60734 .60457 .61332 .61087 .62516 .60747 .61922 .60114 Mtetra
.61922 .60114 .62516 .60747 .63705 .60406 .63114 .59768 Mtetra
.63114 .59768 .63705 .60406 .649 .60063 .64312 .59422 Mtetra
.656 .75 .92 r
.64312 .59422 .649 .60063 .66099 .59718 .65515 .59074 Mtetra
.65515 .59074 .66099 .59718 .67303 .59371 .66723 .58726 Mtetra
.656 .751 .92 r
.66723 .58726 .67303 .59371 .68513 .59023 .67936 .58376 Mtetra
.67936 .58376 .68513 .59023 .69728 .58673 .69154 .58024 Mtetra
.69154 .58024 .69728 .58673 .70948 .58322 .70378 .5767 Mtetra
.70378 .5767 .70948 .58322 .72173 .5797 .71607 .57315 Mtetra
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56959 Mtetra
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Mtetra
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Mtetra
.58946 .60167 .59552 .60799 .60734 .60457 .60132 .59823 Mtetra
.60132 .59823 .60734 .60457 .61922 .60114 .61323 .59477 Mtetra
.656 .752 .921 r
.61323 .59477 .61922 .60114 .63114 .59768 .62519 .59131 Mtetra
.62519 .59131 .63114 .59768 .64312 .59422 .6372 .58782 Mtetra
.6372 .58782 .64312 .59422 .65515 .59074 .64926 .58432 Mtetra
.64926 .58432 .65515 .59074 .66723 .58726 .66138 .58079 Mtetra
.66138 .58079 .66723 .58726 .67936 .58376 .67354 .57725 Mtetra
.656 .752 .92 r
.67354 .57725 .67936 .58376 .69154 .58024 .68576 .5737 Mtetra
.68576 .5737 .69154 .58024 .70378 .5767 .69804 .57014 Mtetra
.656 .751 .92 r
.69804 .57014 .70378 .5767 .71607 .57315 .71036 .56656 Mtetra
.71036 .56656 .71607 .57315 .72841 .56959 .72274 .56296 Mtetra
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59876 Mtetra
.57151 .59876 .57765 .6051 .58946 .60167 .58335 .5953 Mtetra
.58335 .5953 .58946 .60167 .60132 .59823 .59525 .59183 Mtetra
.59525 .59183 .60132 .59823 .61323 .59477 .60719 .58834 Mtetra
.60719 .58834 .61323 .59477 .62519 .59131 .61918 .58483 Mtetra
.61918 .58483 .62519 .59131 .6372 .58782 .63123 .5813 Mtetra
.656 .75 .919 r
.63123 .5813 .6372 .58782 .64926 .58432 .64333 .57777 Mtetra
.64333 .57777 .64926 .58432 .66138 .58079 .65548 .57423 Mtetra
.656 .75 .92 r
.65548 .57423 .66138 .58079 .67354 .57725 .66768 .57068 Mtetra
.656 .751 .92 r
.66768 .57068 .67354 .57725 .68576 .5737 .67994 .5671 Mtetra
.67994 .5671 .68576 .5737 .69804 .57014 .69225 .56351 Mtetra
.69225 .56351 .69804 .57014 .71036 .56656 .70461 .55991 Mtetra
.70461 .55991 .71036 .56656 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Mtetra
.56532 .59236 .57151 .59876 .58335 .5953 .5772 .58888 Mtetra
.5772 .58888 .58335 .5953 .59525 .59183 .58913 .58538 Mtetra
.58913 .58538 .59525 .59183 .60719 .58834 .6011 .58187 Mtetra
.655 .752 .921 r
.6011 .58187 .60719 .58834 .61918 .58483 .61313 .57835 Mtetra
.61313 .57835 .61918 .58483 .63123 .5813 .62521 .57482 Mtetra
.656 .753 .921 r
.62521 .57482 .63123 .5813 .64333 .57777 .63735 .57126 Mtetra
.63735 .57126 .64333 .57777 .65548 .57423 .64953 .56768 Mtetra
.656 .752 .921 r
.64953 .56768 .65548 .57423 .66768 .57068 .66177 .56408 Mtetra
.66177 .56408 .66768 .57068 .67994 .5671 .67407 .56046 Mtetra
.656 .752 .92 r
.67407 .56046 .67994 .5671 .69225 .56351 .68641 .55684 Mtetra
.656 .751 .92 r
.68641 .55684 .69225 .56351 .70461 .55991 .69881 .5532 Mtetra
.69881 .5532 .70461 .55991 .71703 .55628 .71127 .54955 Mtetra
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Mtetra
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58592 Mtetra
.55909 .58592 .56532 .59236 .5772 .58888 .571 .58241 Mtetra
.571 .58241 .5772 .58888 .58913 .58538 .58296 .57888 Mtetra
.58296 .57888 .58913 .58538 .6011 .58187 .59497 .57533 Mtetra
.59497 .57533 .6011 .58187 .61313 .57835 .60703 .57176 Mtetra
.656 .75 .919 r
.60703 .57176 .61313 .57835 .62521 .57482 .61915 .56818 Mtetra
.61915 .56818 .62521 .57482 .63735 .57126 .63132 .56459 Mtetra
.63132 .56459 .63735 .57126 .64953 .56768 .64354 .561 Mtetra
.64354 .561 .64953 .56768 .66177 .56408 .65582 .55739 Mtetra
.656 .751 .92 r
.65582 .55739 .66177 .56408 .67407 .56046 .66815 .55376 Mtetra
.66815 .55376 .67407 .56046 .68641 .55684 .68053 .55011 Mtetra
.68053 .55011 .68641 .55684 .69881 .5532 .69297 .54644 Mtetra
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Mtetra
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Mtetra
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Mtetra
.52907 .58646 .53542 .5929 .54723 .58942 .54091 .58295 Mtetra
.54091 .58295 .54723 .58942 .55909 .58592 .5528 .57943 Mtetra
.5528 .57943 .55909 .58592 .571 .58241 .56474 .57589 Mtetra
.56474 .57589 .571 .58241 .58296 .57888 .57674 .57233 Mtetra
.655 .752 .921 r
.57674 .57233 .58296 .57888 .59497 .57533 .58879 .56877 Mtetra
.58879 .56877 .59497 .57533 .60703 .57176 .60088 .5652 Mtetra
.655 .753 .921 r
.60088 .5652 .60703 .57176 .61915 .56818 .61304 .56161 Mtetra
.656 .753 .922 r
.61304 .56161 .61915 .56818 .63132 .56459 .62524 .55799 Mtetra
.656 .754 .922 r
.62524 .55799 .63132 .56459 .64354 .561 .6375 .55435 Mtetra
.656 .753 .921 r
.6375 .55435 .64354 .561 .65582 .55739 .64981 .55069 Mtetra
.656 .752 .921 r
.64981 .55069 .65582 .55739 .66815 .55376 .66218 .54701 Mtetra
.656 .752 .92 r
.66218 .54701 .66815 .55376 .68053 .55011 .6746 .54333 Mtetra
.656 .751 .92 r
.6746 .54333 .68053 .55011 .69297 .54644 .68707 .53963 Mtetra
.68707 .53963 .69297 .54644 .70546 .54276 .69961 .53592 Mtetra
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53219 Mtetra
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Mtetra
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57997 Mtetra
.52266 .57997 .52907 .58646 .54091 .58295 .53454 .57643 Mtetra
.53454 .57643 .54091 .58295 .5528 .57943 .54646 .57288 Mtetra
.54646 .57288 .5528 .57943 .56474 .57589 .55844 .56931 Mtetra
.55844 .56931 .56474 .57589 .57674 .57233 .57047 .56572 Mtetra
.57047 .56572 .57674 .57233 .58879 .56877 .58255 .56211 Mtetra
.656 .751 .919 r
.58255 .56211 .58879 .56877 .60088 .5652 .59469 .55848 Mtetra
.656 .75 .919 r
.59469 .55848 .60088 .5652 .61304 .56161 .60687 .55484 Mtetra
.656 .749 .918 r
.60687 .55484 .61304 .56161 .62524 .55799 .61911 .55119 Mtetra
.656 .749 .919 r
.61911 .55119 .62524 .55799 .6375 .55435 .63141 .54754 Mtetra
.655 .749 .919 r
.63141 .54754 .6375 .55435 .64981 .55069 .64376 .54388 Mtetra
.655 .75 .92 r
.64376 .54388 .64981 .55069 .66218 .54701 .65616 .54019 Mtetra
.656 .751 .92 r
.65616 .54019 .66218 .54701 .6746 .54333 .66862 .53649 Mtetra
.66862 .53649 .6746 .54333 .68707 .53963 .68113 .53276 Mtetra
.68113 .53276 .68707 .53963 .69961 .53592 .6937 .52902 Mtetra
.6937 .52902 .69961 .53592 .71219 .53219 .70633 .52525 Mtetra
.70633 .52525 .71219 .53219 .72483 .52844 .71901 .52148 Mtetra
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Mtetra
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Mtetra
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Mtetra
.49255 .58051 .49907 .587 .51084 .58349 .50435 .57698 Mtetra
.50435 .57698 .51084 .58349 .52266 .57997 .51621 .57343 Mtetra
.51621 .57343 .52266 .57997 .53454 .57643 .52812 .56986 Mtetra
.52812 .56986 .53454 .57643 .54646 .57288 .54008 .56628 Mtetra
.54008 .56628 .54646 .57288 .55844 .56931 .55209 .56268 Mtetra
.55209 .56268 .55844 .56931 .57047 .56572 .56415 .55908 Mtetra
.655 .752 .921 r
.56415 .55908 .57047 .56572 .58255 .56211 .57627 .55546 Mtetra
.57627 .55546 .58255 .56211 .59469 .55848 .58844 .55184 Mtetra
.655 .754 .922 r
.58844 .55184 .59469 .55848 .60687 .55484 .60066 .5482 Mtetra
.656 .755 .923 r
.60066 .5482 .60687 .55484 .61911 .55119 .61294 .54452 Mtetra
.61294 .54452 .61911 .55119 .63141 .54754 .62527 .54081 Mtetra
.656 .754 .922 r
.62527 .54081 .63141 .54754 .64376 .54388 .63766 .53708 Mtetra
.656 .753 .921 r
.63766 .53708 .64376 .54388 .65616 .54019 .6501 .53334 Mtetra
.656 .752 .92 r
.6501 .53334 .65616 .54019 .66862 .53649 .66259 .52959 Mtetra
.656 .751 .92 r
.66259 .52959 .66862 .53649 .68113 .53276 .67514 .52583 Mtetra
.67514 .52583 .68113 .53276 .6937 .52902 .68775 .52206 Mtetra
.68775 .52206 .6937 .52902 .70633 .52525 .70041 .51827 Mtetra
.70041 .51827 .70633 .52525 .71901 .52148 .71313 .51446 Mtetra
.71313 .51446 .71901 .52148 .73175 .51768 .72591 .51063 Mtetra
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Mtetra
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Mtetra
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Mtetra
.47419 .57752 .48079 .58403 .49255 .58051 .48598 .57397 Mtetra
.48598 .57397 .49255 .58051 .50435 .57698 .49781 .57041 Mtetra
.49781 .57041 .50435 .57698 .51621 .57343 .5097 .56683 Mtetra
.5097 .56683 .51621 .57343 .52812 .56986 .52164 .56324 Mtetra
.52164 .56324 .52812 .56986 .54008 .56628 .53364 .55963 Mtetra
.53364 .55963 .54008 .56628 .55209 .56268 .54568 .556 Mtetra
.54568 .556 .55209 .56268 .56415 .55908 .55778 .55237 Mtetra
.655 .751 .921 r
.55778 .55237 .56415 .55908 .57627 .55546 .56993 .54872 Mtetra
.655 .751 .92 r
.56993 .54872 .57627 .55546 .58844 .55184 .58214 .54507 Mtetra
.58214 .54507 .58844 .55184 .60066 .5482 .5944 .54139 Mtetra
.656 .751 .92 r
.5944 .54139 .60066 .5482 .61294 .54452 .60671 .53768 Mtetra
.60671 .53768 .61294 .54452 .62527 .54081 .61908 .53395 Mtetra
.61908 .53395 .62527 .54081 .63766 .53708 .6315 .53019 Mtetra
.656 .752 .92 r
.6315 .53019 .63766 .53708 .6501 .53334 .64398 .52642 Mtetra
.64398 .52642 .6501 .53334 .66259 .52959 .65651 .52264 Mtetra
.656 .751 .92 r
.65651 .52264 .66259 .52959 .67514 .52583 .6691 .51885 Mtetra
.6691 .51885 .67514 .52583 .68775 .52206 .68175 .51505 Mtetra
.68175 .51505 .68775 .52206 .70041 .51827 .69445 .51122 Mtetra
.69445 .51122 .70041 .51827 .71313 .51446 .70721 .50738 Mtetra
.70721 .50738 .71313 .51446 .72591 .51063 .72003 .50352 Mtetra
.72003 .50352 .72591 .51063 .73875 .50679 .7329 .49965 Mtetra
.7329 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Mtetra
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Mtetra
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57096 Mtetra
.46753 .57096 .47419 .57752 .48598 .57397 .47935 .56738 Mtetra
.47935 .56738 .48598 .57397 .49781 .57041 .49122 .56379 Mtetra
.49122 .56379 .49781 .57041 .5097 .56683 .50314 .56018 Mtetra
.50314 .56018 .5097 .56683 .52164 .56324 .51512 .55656 Mtetra
.655 .751 .92 r
.51512 .55656 .52164 .56324 .53364 .55963 .52715 .55294 Mtetra
.653 .751 .921 r
.52715 .55294 .53364 .55963 .54568 .556 .53923 .54935 Mtetra
.648 .751 .925 r
.53923 .54935 .54568 .556 .55778 .55237 .55136 .5459 Mtetra
.638 .755 .933 r
.55136 .5459 .55778 .55237 .56993 .54872 .56356 .54268 Mtetra
.629 .767 .946 r
.56356 .54268 .56993 .54872 .58214 .54507 .57581 .5396 Mtetra
.63 .789 .958 r
.57581 .5396 .58214 .54507 .5944 .54139 .58812 .53636 Mtetra
.645 .81 .962 r
.58812 .53636 .5944 .54139 .60671 .53768 .60047 .53262 Mtetra
.664 .815 .956 r
.60047 .53262 .60671 .53768 .61908 .53395 .61287 .5284 Mtetra
.673 .802 .944 r
.61287 .5284 .61908 .53395 .6315 .53019 .62532 .524 Mtetra
.67 .78 .932 r
.62532 .524 .6315 .53019 .64398 .52642 .63782 .51974 Mtetra
.662 .763 .925 r
.63782 .51974 .64398 .52642 .65651 .52264 .65039 .51572 Mtetra
.658 .755 .921 r
.65039 .51572 .65651 .52264 .6691 .51885 .66301 .51183 Mtetra
.656 .752 .92 r
.66301 .51183 .6691 .51885 .68175 .51505 .6757 .50797 Mtetra
.656 .751 .92 r
.6757 .50797 .68175 .51505 .69445 .51122 .68844 .50412 Mtetra
.68844 .50412 .69445 .51122 .70721 .50738 .70124 .50024 Mtetra
.70124 .50024 .70721 .50738 .72003 .50352 .7141 .49635 Mtetra
.7141 .49635 .72003 .50352 .7329 .49965 .72701 .49245 Mtetra
.72701 .49245 .7329 .49965 .74584 .49575 .73999 .48852 Mtetra
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Mtetra
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Mtetra
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56793 Mtetra
.44902 .56793 .45576 .57452 .46753 .57096 .46082 .56434 Mtetra
.46082 .56434 .46753 .57096 .47935 .56738 .47267 .56074 Mtetra
.47267 .56074 .47935 .56738 .49122 .56379 .48457 .55712 Mtetra
.48457 .55712 .49122 .56379 .50314 .56018 .49653 .55348 Mtetra
.655 .751 .921 r
.49653 .55348 .50314 .56018 .51512 .55656 .50854 .54985 Mtetra
.651 .751 .922 r
.50854 .54985 .51512 .55656 .52715 .55294 .5206 .54632 Mtetra
.635 .749 .931 r
.5206 .54632 .52715 .55294 .53923 .54935 .53272 .5432 Mtetra
.589 .75 .954 r
.53272 .5432 .53923 .54935 .55136 .5459 .5449 .54107 Mtetra
.488 .758 .99 r
.5449 .54107 .55136 .5459 .56356 .54268 .55716 .5402 Mtetra
.309 .753 .962 r
.55716 .5402 .56356 .54268 .57581 .5396 .5695 .53976 Mtetra
.159 .7 .783 r
.5695 .53976 .57581 .5396 .58812 .53636 .5819 .53821 Mtetra
.208 .722 .681 r
.5819 .53821 .58812 .53636 .60047 .53262 .59432 .53445 Mtetra
.428 .864 .768 r
.59432 .53445 .60047 .53262 .61287 .5284 .60675 .52848 Mtetra
.658 .967 .91 r
.60675 .52848 .61287 .5284 .62532 .524 .61919 .52139 Mtetra
.729 .921 .957 r
.61919 .52139 .62532 .524 .63782 .51974 .63167 .51472 Mtetra
.704 .832 .944 r
.63167 .51472 .63782 .51974 .65039 .51572 .64423 .50929 Mtetra
.673 .777 .928 r
.64423 .50929 .65039 .51572 .66301 .51183 .65688 .50487 Mtetra
.66 .757 .922 r
.65688 .50487 .66301 .51183 .6757 .50797 .6696 .50086 Mtetra
.656 .752 .921 r
.6696 .50086 .6757 .50797 .68844 .50412 .68238 .49696 Mtetra
.656 .751 .92 r
.68238 .49696 .68844 .50412 .70124 .50024 .69522 .49305 Mtetra
.69522 .49305 .70124 .50024 .7141 .49635 .70812 .48912 Mtetra
.70812 .48912 .7141 .49635 .72701 .49245 .72107 .48518 Mtetra
.72107 .48518 .72701 .49245 .73999 .48852 .73409 .48122 Mtetra
.73409 .48122 .73999 .48852 .75302 .48458 .74716 .47725 Mtetra
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Mtetra
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Mtetra
.43044 .5649 .43727 .57151 .44902 .56793 .44222 .56129 Mtetra
.44222 .56129 .44902 .56793 .46082 .56434 .45405 .55768 Mtetra
.45405 .55768 .46082 .56434 .47267 .56074 .46594 .55404 Mtetra
.46594 .55404 .47267 .56074 .48457 .55712 .47788 .55039 Mtetra
.655 .751 .92 r
.47788 .55039 .48457 .55712 .49653 .55348 .48987 .54674 Mtetra
.652 .751 .922 r
.48987 .54674 .49653 .55348 .50854 .54985 .50191 .54316 Mtetra
.633 .747 .93 r
.50191 .54316 .50854 .54985 .5206 .54632 .514 .54011 Mtetra
.548 .733 .961 r
.514 .54011 .5206 .54632 .53272 .5432 .52616 .53882 Mtetra
.219 .636 .955 r
.52616 .53882 .53272 .5432 .5449 .54107 .53839 .54079 Mtetra
.4 0 0 r
.53839 .54079 .5449 .54107 .55716 .5402 .55075 .5452 Mtetra
.502 0 0 r
.55075 .5452 .55716 .5402 .5695 .53976 .5632 .54824 Mtetra
.408 0 .069 r
.5632 .54824 .5695 .53976 .5819 .53821 .5757 .5475 Mtetra
.295 0 .034 r
.5757 .5475 .5819 .53821 .59432 .53445 .58823 .54374 Mtetra
.137 0 0 r
.58823 .54374 .59432 .53445 .60675 .52848 .60074 .53693 Mtetra
0 0 0 r
.60074 .53693 .60675 .52848 .61919 .52139 .61319 .52631 Mtetra
.575 .881 .589 r
.61319 .52631 .61919 .52139 .63167 .51472 .6256 .51427 Mtetra
.789 .984 .899 r
.6256 .51427 .63167 .51472 .64423 .50929 .63808 .50466 Mtetra
.73 .854 .939 r
.63808 .50466 .64423 .50929 .65688 .50487 .65071 .49832 Mtetra
.676 .777 .927 r
.65071 .49832 .65688 .50487 .6696 .50086 .66345 .49377 Mtetra
.659 .756 .921 r
.66345 .49377 .6696 .50086 .68238 .49696 .67626 .48974 Mtetra
.656 .752 .92 r
.67626 .48974 .68238 .49696 .69522 .49305 .68914 .48579 Mtetra
.656 .751 .92 r
.68914 .48579 .69522 .49305 .70812 .48912 .70208 .48183 Mtetra
.70208 .48183 .70812 .48912 .72107 .48518 .71508 .47786 Mtetra
.71508 .47786 .72107 .48518 .73409 .48122 .72814 .47387 Mtetra
.72814 .47387 .73409 .48122 .74716 .47725 .74126 .46986 Mtetra
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Mtetra
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Mtetra
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55823 Mtetra
.42355 .55823 .43044 .5649 .44222 .56129 .43536 .5546 Mtetra
.43536 .5546 .44222 .56129 .45405 .55768 .44723 .55095 Mtetra
.44723 .55095 .45405 .55768 .46594 .55404 .45915 .54729 Mtetra
.45915 .54729 .46594 .55404 .47788 .55039 .47112 .54361 Mtetra
.655 .751 .921 r
.47112 .54361 .47788 .55039 .48987 .54674 .48314 .53995 Mtetra
.645 .749 .925 r
.48314 .53995 .48987 .54674 .50191 .54316 .49522 .53655 Mtetra
.588 .736 .945 r
.49522 .53655 .50191 .54316 .514 .54011 .50734 .53452 Mtetra
.302 .64 .966 r
.50734 .53452 .514 .54011 .52616 .53882 .51953 .53646 Mtetra
.466 0 0 r
.51953 .53646 .52616 .53882 .53839 .54079 .53182 .54356 Mtetra
.592 .063 0 r
.53182 .54356 .53839 .54079 .55075 .5452 .54424 .54982 Mtetra
.099 0 0 r
.54424 .54982 .55075 .5452 .5632 .54824 .5567 .5466 Mtetra
.805 .95 .915 r
.5567 .5466 .5632 .54824 .5757 .5475 .56914 .53731 Mtetra
.651 .671 .856 r
.56914 .53731 .5757 .5475 .58823 .54374 .58169 .53352 Mtetra
.469 .586 .888 r
.58169 .53352 .58823 .54374 .60074 .53693 .59441 .53524 Mtetra
.575 .908 .977 r
.59441 .53524 .60074 .53693 .61319 .52631 .60708 .53085 Mtetra
.711 .946 .649 r
.60708 .53085 .61319 .52631 .6256 .51427 .61954 .5169 Mtetra
.844 .994 .749 r
.61954 .5169 .6256 .51427 .63808 .50466 .63194 .50206 Mtetra
.816 .93 .908 r
.63194 .50206 .63808 .50466 .65071 .49832 .64451 .49241 Mtetra
.709 .809 .927 r
.64451 .49241 .65071 .49832 .66345 .49377 .65725 .48675 Mtetra
.665 .762 .922 r
.65725 .48675 .66345 .49377 .67626 .48974 .6701 .48248 Mtetra
.657 .753 .92 r
.6701 .48248 .67626 .48974 .68914 .48579 .68302 .47848 Mtetra
.656 .751 .92 r
.68302 .47848 .68914 .48579 .70208 .48183 .696 .47448 Mtetra
.696 .47448 .70208 .48183 .71508 .47786 .70904 .47048 Mtetra
.70904 .47048 .71508 .47786 .72814 .47387 .72214 .46645 Mtetra
.72214 .46645 .72814 .47387 .74126 .46986 .7353 .4624 Mtetra
.7353 .4624 .74126 .46986 .75443 .46583 .74852 .45834 Mtetra
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Mtetra
.40481 .55516 .41179 .56185 .42355 .55823 .41661 .55152 Mtetra
.41661 .55152 .42355 .55823 .43536 .5546 .42845 .54786 Mtetra
.42845 .54786 .43536 .5546 .44723 .55095 .44035 .54418 Mtetra
.44035 .54418 .44723 .55095 .45915 .54729 .45231 .54048 Mtetra
.45231 .54048 .45915 .54729 .47112 .54361 .46431 .53678 Mtetra
.654 .751 .921 r
.46431 .53678 .47112 .54361 .48314 .53995 .47637 .53311 Mtetra
.637 .746 .927 r
.47637 .53311 .48314 .53995 .49522 .53655 .48848 .5299 Mtetra
.536 .716 .956 r
.48848 .5299 .49522 .53655 .50734 .53452 .50062 .52894 Mtetra
0 .447 .863 r
.50062 .52894 .50734 .53452 .51953 .53646 .51282 .53402 Mtetra
.679 .131 0 r
.51282 .53402 .51953 .53646 .53182 .54356 .52515 .54552 Mtetra
.576 .029 0 r
.52515 .54552 .53182 .54356 .54424 .54982 .53761 .55174 Mtetra
.795 .999 .821 r
.53761 .55174 .54424 .54982 .5567 .5466 .55008 .54007 Mtetra
.884 .792 .754 r
.55008 .54007 .5567 .5466 .56914 .53731 .56246 .52117 Mtetra
.634 .576 .772 r
.56246 .52117 .56914 .53731 .58169 .53352 .57502 .51734 Mtetra
.192 .313 .759 r
.57502 .51734 .58169 .53352 .59441 .53524 .58791 .52862 Mtetra
.196 .543 .928 r
.58791 .52862 .59441 .53524 .60708 .53085 .60082 .53267 Mtetra
.85 .998 .791 r
.60082 .53267 .60708 .53085 .61954 .5169 .61337 .51872 Mtetra
.936 .967 .732 r
.61337 .51872 .61954 .5169 .63194 .50206 .62573 .49939 Mtetra
.875 .918 .853 r
.62573 .49939 .63194 .50206 .64451 .49241 .63826 .48649 Mtetra
.74 .817 .912 r
.63826 .48649 .64451 .49241 .65725 .48675 .651 .47968 Mtetra
.672 .765 .92 r
.651 .47968 .65725 .48675 .6701 .48248 .66389 .47516 Mtetra
.658 .753 .92 r
.66389 .47516 .6701 .48248 .68302 .47848 .67684 .4711 Mtetra
.656 .752 .92 r
.67684 .4711 .68302 .47848 .696 .47448 .68986 .46707 Mtetra
.656 .751 .92 r
.68986 .46707 .696 .47448 .70904 .47048 .70294 .46303 Mtetra
.70294 .46303 .70904 .47048 .72214 .46645 .71609 .45897 Mtetra
.71609 .45897 .72214 .46645 .7353 .4624 .72929 .45489 Mtetra
.72929 .45489 .7353 .4624 .74852 .45834 .74255 .45079 Mtetra
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Mtetra
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43837 Mtetra
.78271 .43837 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Mtetra
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Mtetra
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54474 Mtetra
.40961 .54474 .41661 .55152 .42845 .54786 .42149 .54105 Mtetra
.42149 .54105 .42845 .54786 .44035 .54418 .43342 .53735 Mtetra
.43342 .53735 .44035 .54418 .45231 .54048 .44541 .53362 Mtetra
.44541 .53362 .45231 .54048 .46431 .53678 .45745 .52989 Mtetra
.653 .751 .921 r
.45745 .52989 .46431 .53678 .47637 .53311 .46954 .5262 Mtetra
.634 .745 .928 r
.46954 .5262 .47637 .53311 .48848 .5299 .48168 .52305 Mtetra
.507 .699 .956 r
.48168 .52305 .48848 .5299 .50062 .52894 .49385 .52266 Mtetra
0 .315 .777 r
.49385 .52266 .50062 .52894 .51282 .53402 .50606 .52987 Mtetra
.764 .257 0 r
.50606 .52987 .51282 .53402 .52515 .54552 .51839 .54604 Mtetra
.724 .208 0 r
.51839 .54604 .52515 .54552 .53761 .55174 .53091 .55784 Mtetra
0 0 0 r
.53091 .55784 .53761 .55174 .55008 .54007 .54349 .54879 Mtetra
.697 .873 .478 r
.54349 .54879 .55008 .54007 .56246 .52117 .556 .52937 Mtetra
.243 0 0 r
.556 .52937 .56246 .52117 .57502 .51734 .56865 .52553 Mtetra
.702 .276 .232 r
.56865 .52553 .57502 .51734 .58791 .52862 .58162 .53731 Mtetra
.478 .027 .102 r
.58162 .53731 .58791 .52862 .60082 .53267 .59455 .5387 Mtetra
.824 .949 .598 r
.59455 .5387 .60082 .53267 .61337 .51872 .60707 .51908 Mtetra
.967 .912 .704 r
.60707 .51908 .61337 .51872 .62573 .49939 .6194 .49498 Mtetra
.885 .862 .812 r
.6194 .49498 .62573 .49939 .63826 .48649 .63192 .47987 Mtetra
.751 .8 .892 r
.63192 .47987 .63826 .48649 .651 .47968 .6447 .47243 Mtetra
.675 .762 .916 r
.6447 .47243 .651 .47968 .66389 .47516 .65762 .46777 Mtetra
.658 .753 .92 r
.65762 .46777 .66389 .47516 .67684 .4711 .67061 .46366 Mtetra
.656 .751 .92 r
.67061 .46366 .67684 .4711 .68986 .46707 .68368 .45959 Mtetra
.68368 .45959 .68986 .46707 .70294 .46303 .6968 .45551 Mtetra
.6968 .45551 .70294 .46303 .71609 .45897 .70998 .45142 Mtetra
.70998 .45142 .71609 .45897 .72929 .45489 .72323 .4473 Mtetra
.72323 .4473 .72929 .45489 .74255 .45079 .73653 .44317 Mtetra
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Mtetra
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43837 .77683 .43065 Mtetra
.77683 .43065 .78271 .43837 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Mtetra
.39069 .54162 .39778 .54842 .40961 .54474 .40255 .53792 Mtetra
.40255 .53792 .40961 .54474 .42149 .54105 .41447 .5342 Mtetra
.41447 .5342 .42149 .54105 .43342 .53735 .42643 .53046 Mtetra
.42643 .53046 .43342 .53735 .44541 .53362 .43845 .5267 Mtetra
.43845 .5267 .44541 .53362 .45745 .52989 .45052 .52294 Mtetra
.653 .751 .921 r
.45052 .52294 .45745 .52989 .46954 .5262 .46265 .51922 Mtetra
.633 .744 .928 r
.46265 .51922 .46954 .5262 .48168 .52305 .47482 .51606 Mtetra
.503 .694 .955 r
.47482 .51606 .48168 .52305 .49385 .52266 .48702 .51576 Mtetra
0 .3 .776 r
.48702 .51576 .49385 .52266 .50606 .52987 .49924 .52347 Mtetra
.741 .252 0 r
.49924 .52347 .50606 .52987 .51839 .54604 .51156 .5412 Mtetra
.711 .193 0 r
.51156 .5412 .51839 .54604 .53091 .55784 .5241 .55629 Mtetra
.587 .914 .974 r
.5241 .55629 .53091 .55784 .54349 .54879 .53676 .55163 Mtetra
.882 .991 .756 r
.53676 .55163 .54349 .54879 .556 .52937 .5494 .53542 Mtetra
.134 0 0 r
.5494 .53542 .556 .52937 .56865 .52553 .56214 .53156 Mtetra
.653 .186 .13 r
.56214 .53156 .56865 .52553 .58162 .53731 .57512 .54009 Mtetra
0 0 0 r
.57512 .54009 .58162 .53731 .59455 .5387 .58804 .53702 Mtetra
.952 .883 .729 r
.58804 .53702 .59455 .5387 .60707 .51908 .60057 .51403 Mtetra
.933 .816 .706 r
.60057 .51403 .60707 .51908 .6194 .49498 .61295 .48828 Mtetra
.866 .806 .79 r
.61295 .48828 .6194 .49498 .63192 .47987 .62552 .47261 Mtetra
.75 .783 .88 r
.62552 .47261 .63192 .47987 .6447 .47243 .63833 .46501 Mtetra
.676 .759 .913 r
.63833 .46501 .6447 .47243 .65762 .46777 .65129 .4603 Mtetra
.658 .752 .92 r
.65129 .4603 .65762 .46777 .67061 .46366 .66433 .45615 Mtetra
.656 .751 .92 r
.66433 .45615 .67061 .46366 .68368 .45959 .67744 .45205 Mtetra
.67744 .45205 .68368 .45959 .6968 .45551 .6906 .44794 Mtetra
.6906 .44794 .6968 .45551 .70998 .45142 .70382 .44381 Mtetra
.70382 .44381 .70998 .45142 .72323 .4473 .71711 .43966 Mtetra
.71711 .43966 .72323 .4473 .73653 .44317 .73046 .43549 Mtetra
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Mtetra
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Mtetra
.38355 .53477 .39069 .54162 .40255 .53792 .39544 .53103 Mtetra
.39544 .53103 .40255 .53792 .41447 .5342 .40739 .52728 Mtetra
.40739 .52728 .41447 .5342 .42643 .53046 .41938 .52351 Mtetra
.41938 .52351 .42643 .53046 .43845 .5267 .43144 .51973 Mtetra
.43144 .51973 .43845 .5267 .45052 .52294 .44355 .51593 Mtetra
.653 .751 .921 r
.44355 .51593 .45052 .52294 .46265 .51922 .45571 .51219 Mtetra
.633 .744 .928 r
.45571 .51219 .46265 .51922 .47482 .51606 .46791 .509 Mtetra
.501 .693 .955 r
.46791 .509 .47482 .51606 .48702 .51576 .48014 .50871 Mtetra
0 .299 .777 r
.48014 .50871 .48702 .51576 .49924 .52347 .49237 .51646 Mtetra
.721 .237 0 r
.49237 .51646 .49924 .52347 .51156 .5412 .50468 .5342 Mtetra
.608 .112 0 r
.50468 .5342 .51156 .5412 .5241 .55629 .51722 .54904 Mtetra
.69 .763 .908 r
.51722 .54904 .5241 .55629 .53676 .55163 .52992 .54393 Mtetra
.857 .777 .772 r
.52992 .54393 .53676 .55163 .5494 .53542 .54262 .52738 Mtetra
.653 .731 .907 r
.54262 .52738 .5494 .53542 .56214 .53156 .55539 .52349 Mtetra
0 .297 .787 r
.55539 .52349 .56214 .53156 .57512 .54009 .56839 .53229 Mtetra
.61 .725 .927 r
.56839 .53229 .57512 .54009 .58804 .53702 .58135 .5296 Mtetra
.899 .783 .725 r
.58135 .5296 .58804 .53702 .60057 .51403 .59397 .50679 Mtetra
.913 .783 .704 r
.59397 .50679 .60057 .51403 .61295 .48828 .60642 .48098 Mtetra
.86 .794 .785 r
.60642 .48098 .61295 .48828 .62552 .47261 .61905 .46519 Mtetra
.75 .781 .878 r
.61905 .46519 .62552 .47261 .63833 .46501 .63191 .45752 Mtetra
.676 .759 .913 r
.63191 .45752 .63833 .46501 .65129 .4603 .64492 .45276 Mtetra
.658 .752 .919 r
.64492 .45276 .65129 .4603 .66433 .45615 .658 .44858 Mtetra
.656 .751 .92 r
.658 .44858 .66433 .45615 .67744 .45205 .67114 .44444 Mtetra
.67114 .44444 .67744 .45205 .6906 .44794 .68435 .4403 Mtetra
.68435 .4403 .6906 .44794 .70382 .44381 .69761 .43613 Mtetra
.69761 .43613 .70382 .44381 .71711 .43966 .71095 .43194 Mtetra
.71095 .43194 .71711 .43966 .73046 .43549 .72434 .42774 Mtetra
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Mtetra
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40208 Mtetra
.80604 .40208 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Mtetra
.37634 .52786 .38355 .53477 .39544 .53103 .38827 .52409 Mtetra
.38827 .52409 .39544 .53103 .40739 .52728 .40025 .52031 Mtetra
.40025 .52031 .40739 .52728 .41938 .52351 .41228 .51651 Mtetra
.41228 .51651 .41938 .52351 .43144 .51973 .42437 .51269 Mtetra
.42437 .51269 .43144 .51973 .44355 .51593 .43651 .50887 Mtetra
.653 .751 .921 r
.43651 .50887 .44355 .51593 .45571 .51219 .4487 .50509 Mtetra
.632 .744 .929 r
.4487 .50509 .45571 .51219 .46791 .509 .46094 .50189 Mtetra
.499 .693 .955 r
.46094 .50189 .46791 .509 .48014 .50871 .4732 .5016 Mtetra
0 .294 .773 r
.4732 .5016 .48014 .50871 .49237 .51646 .48544 .50943 Mtetra
.725 .24 0 r
.48544 .50943 .49237 .51646 .50468 .5342 .49774 .52727 Mtetra
.617 .118 0 r
.49774 .52727 .50468 .5342 .51722 .54904 .51028 .54215 Mtetra
.69 .776 .917 r
.51028 .54215 .51722 .54904 .52992 .54393 .52302 .53703 Mtetra
.865 .794 .779 r
.52302 .53703 .52992 .54393 .54262 .52738 .53578 .52046 Mtetra
.651 .765 .933 r
.53578 .52046 .54262 .52738 .55539 .52349 .5486 .51653 Mtetra
0 .262 .746 r
.5486 .51653 .55539 .52349 .56839 .53229 .56161 .52528 Mtetra
.604 .749 .946 r
.56161 .52528 .56839 .53229 .58135 .5296 .57461 .52255 Mtetra
.903 .79 .726 r
.57461 .52255 .58135 .5296 .59397 .50679 .5873 .49963 Mtetra
.915 .785 .704 r
.5873 .49963 .59397 .50679 .60642 .48098 .59984 .47365 Mtetra
.861 .795 .784 r
.59984 .47365 .60642 .48098 .61905 .46519 .61253 .45772 Mtetra
.751 .781 .878 r
.61253 .45772 .61905 .46519 .63191 .45752 .62544 .44996 Mtetra
.676 .759 .913 r
.62544 .44996 .63191 .45752 .64492 .45276 .63848 .44516 Mtetra
.658 .752 .919 r
.63848 .44516 .64492 .45276 .658 .44858 .65161 .44094 Mtetra
.656 .751 .92 r
.65161 .44094 .658 .44858 .67114 .44444 .66479 .43677 Mtetra
.66479 .43677 .67114 .44444 .68435 .4403 .67804 .43259 Mtetra
.67804 .43259 .68435 .4403 .69761 .43613 .69135 .42838 Mtetra
.69135 .42838 .69761 .43613 .71095 .43194 .70472 .42416 Mtetra
.70472 .42416 .71095 .43194 .72434 .42774 .71816 .41992 Mtetra
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Mtetra
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40208 .80014 .39403 Mtetra
.80014 .39403 .80604 .40208 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Mtetra
.33352 .53219 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Mtetra
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .52089 Mtetra
.36908 .52089 .37634 .52786 .38827 .52409 .38104 .5171 Mtetra
.38104 .5171 .38827 .52409 .40025 .52031 .39305 .51328 Mtetra
.39305 .51328 .40025 .52031 .41228 .51651 .40512 .50945 Mtetra
.40512 .50945 .41228 .51651 .42437 .51269 .41724 .5056 Mtetra
.41724 .5056 .42437 .51269 .43651 .50887 .42941 .50174 Mtetra
.653 .751 .921 r
.42941 .50174 .43651 .50887 .4487 .50509 .44164 .49794 Mtetra
.632 .744 .929 r
.44164 .49794 .4487 .50509 .46094 .50189 .45392 .49471 Mtetra
.497 .692 .955 r
.45392 .49471 .46094 .50189 .4732 .5016 .4662 .49444 Mtetra
0 .289 .769 r
.4662 .49444 .4732 .5016 .48544 .50943 .47845 .50233 Mtetra
.725 .241 0 r
.47845 .50233 .48544 .50943 .49774 .52727 .49074 .5202 Mtetra
.605 .107 0 r
.49074 .5202 .49774 .52727 .51028 .54215 .50328 .53491 Mtetra
.698 .769 .907 r
.50328 .53491 .51028 .54215 .52302 .53703 .51607 .52942 Mtetra
.86 .781 .773 r
.51607 .52942 .52302 .53703 .53578 .52046 .52889 .51258 Mtetra
.652 .739 .913 r
.52889 .51258 .53578 .52046 .5486 .51653 .54174 .50862 Mtetra
0 .278 .771 r
.54174 .50862 .5486 .51653 .56161 .52528 .55477 .51758 Mtetra
.597 .726 .935 r
.55477 .51758 .56161 .52528 .57461 .52255 .56781 .51513 Mtetra
.899 .786 .727 r
.56781 .51513 .57461 .52255 .5873 .49963 .58058 .49232 Mtetra
.914 .784 .703 r
.58058 .49232 .5873 .49963 .59984 .47365 .5932 .46624 Mtetra
.862 .795 .784 r
.5932 .46624 .59984 .47365 .61253 .45772 .60595 .45018 Mtetra
.751 .781 .877 r
.60595 .45018 .61253 .45772 .62544 .44996 .61891 .44235 Mtetra
.677 .759 .913 r
.61891 .44235 .62544 .44996 .63848 .44516 .632 .4375 Mtetra
.658 .752 .919 r
.632 .4375 .63848 .44516 .65161 .44094 .64516 .43324 Mtetra
.656 .751 .92 r
.64516 .43324 .65161 .44094 .66479 .43677 .65839 .42903 Mtetra
.65839 .42903 .66479 .43677 .67804 .43259 .67168 .42481 Mtetra
.67168 .42481 .67804 .43259 .69135 .42838 .68503 .42057 Mtetra
.68503 .42057 .69135 .42838 .70472 .42416 .69845 .41631 Mtetra
.69845 .41631 .70472 .42416 .71816 .41992 .71193 .41203 Mtetra
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Mtetra
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52525 Mtetra
.32609 .52525 .33352 .53219 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Mtetra
.34981 .51768 .35717 .52467 .36908 .52089 .36175 .51387 Mtetra
.36175 .51387 .36908 .52089 .38104 .5171 .37374 .51004 Mtetra
.37374 .51004 .38104 .5171 .39305 .51328 .38579 .5062 Mtetra
.38579 .5062 .39305 .51328 .40512 .50945 .39789 .50233 Mtetra
.39789 .50233 .40512 .50945 .41724 .5056 .41005 .49845 Mtetra
.41005 .49845 .41724 .5056 .42941 .50174 .42226 .49456 Mtetra
.653 .751 .921 r
.42226 .49456 .42941 .50174 .44164 .49794 .43452 .49072 Mtetra
.632 .744 .929 r
.43452 .49072 .44164 .49794 .45392 .49471 .44683 .48748 Mtetra
.495 .691 .955 r
.44683 .48748 .45392 .49471 .4662 .49444 .45914 .48722 Mtetra
0 .283 .764 r
.45914 .48722 .4662 .49444 .47845 .50233 .4714 .49519 Mtetra
.727 .243 0 r
.4714 .49519 .47845 .50233 .49074 .5202 .48368 .51312 Mtetra
.604 .105 0 r
.48368 .51312 .49074 .5202 .50328 .53491 .49622 .52775 Mtetra
.703 .775 .908 r
.49622 .52775 .50328 .53491 .51607 .52942 .50905 .52205 Mtetra
.864 .787 .774 r
.50905 .52205 .51607 .52942 .52889 .51258 .52194 .50506 Mtetra
.652 .751 .922 r
.52194 .50506 .52889 .51258 .54174 .50862 .53483 .50106 Mtetra
0 .259 .751 r
.53483 .50106 .54174 .50862 .55477 .51758 .54787 .5101 Mtetra
.587 .732 .943 r
.54787 .5101 .55477 .51758 .56781 .51513 .56095 .5078 Mtetra
.9 .788 .728 r
.56095 .5078 .56781 .51513 .58058 .49232 .5738 .48501 Mtetra
.915 .785 .703 r
.5738 .48501 .58058 .49232 .5932 .46624 .5865 .45879 Mtetra
.863 .795 .783 r
.5865 .45879 .5932 .46624 .60595 .45018 .59932 .44258 Mtetra
.752 .782 .877 r
.59932 .44258 .60595 .45018 .61891 .44235 .61232 .43466 Mtetra
.677 .759 .913 r
.61232 .43466 .61891 .44235 .632 .4375 .62545 .42977 Mtetra
.658 .752 .919 r
.62545 .42977 .632 .4375 .64516 .43324 .63866 .42547 Mtetra
.656 .751 .92 r
.63866 .42547 .64516 .43324 .65839 .42903 .65193 .42123 Mtetra
.65193 .42123 .65839 .42903 .67168 .42481 .66526 .41697 Mtetra
.66526 .41697 .67168 .42481 .68503 .42057 .67866 .41269 Mtetra
.67866 .41269 .68503 .42057 .69845 .41631 .69212 .40839 Mtetra
.69212 .40839 .69845 .41631 .71193 .41203 .70564 .40408 Mtetra
.70564 .40408 .71193 .41203 .72548 .40773 .71923 .39974 Mtetra
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Mtetra
.35437 .50679 .36175 .51387 .37374 .51004 .36639 .50293 Mtetra
.36639 .50293 .37374 .51004 .38579 .5062 .37847 .49905 Mtetra
.37847 .49905 .38579 .5062 .39789 .50233 .39061 .49515 Mtetra
.39061 .49515 .39789 .50233 .41005 .49845 .4028 .49124 Mtetra
.4028 .49124 .41005 .49845 .42226 .49456 .41504 .48731 Mtetra
.653 .751 .921 r
.41504 .48731 .42226 .49456 .43452 .49072 .42734 .48345 Mtetra
.631 .744 .929 r
.42734 .48345 .43452 .49072 .44683 .48748 .43968 .48018 Mtetra
.492 .69 .955 r
.43968 .48018 .44683 .48748 .45914 .48722 .45202 .47994 Mtetra
0 .276 .759 r
.45202 .47994 .45914 .48722 .4714 .49519 .46429 .48799 Mtetra
.729 .245 0 r
.46429 .48799 .4714 .49519 .48368 .51312 .47656 .50598 Mtetra
.598 .099 0 r
.47656 .50598 .48368 .51312 .49622 .52775 .48909 .52049 Mtetra
.71 .775 .904 r
.48909 .52049 .49622 .52775 .50905 .52205 .50197 .51451 Mtetra
.864 .785 .772 r
.50197 .51451 .50905 .52205 .52194 .50506 .51493 .49731 Mtetra
.652 .746 .919 r
.51493 .49731 .52194 .50506 .53483 .50106 .52785 .49328 Mtetra
0 .256 .75 r
.52785 .49328 .53483 .50106 .54787 .5101 .54091 .50246 Mtetra
.579 .725 .943 r
.54091 .50246 .54787 .5101 .56095 .5078 .55403 .50037 Mtetra
.899 .788 .729 r
.55403 .50037 .56095 .5078 .5738 .48501 .56696 .47763 Mtetra
.915 .784 .703 r
.56696 .47763 .5738 .48501 .5865 .45879 .57975 .45128 Mtetra
.864 .795 .782 r
.57975 .45128 .5865 .45879 .59932 .44258 .59263 .43492 Mtetra
.753 .782 .876 r
.59263 .43492 .59932 .44258 .61232 .43466 .60568 .42691 Mtetra
.677 .759 .913 r
.60568 .42691 .61232 .43466 .62545 .42977 .61885 .42197 Mtetra
.658 .752 .919 r
.61885 .42197 .62545 .42977 .63866 .42547 .6321 .41763 Mtetra
.656 .751 .92 r
.6321 .41763 .63866 .42547 .65193 .42123 .64541 .41335 Mtetra
.64541 .41335 .65193 .42123 .66526 .41697 .65879 .40906 Mtetra
.65879 .40906 .66526 .41697 .67866 .41269 .67223 .40474 Mtetra
.67223 .40474 .67866 .41269 .69212 .40839 .68573 .4004 Mtetra
.68573 .4004 .69212 .40839 .70564 .40408 .6993 .39605 Mtetra
.6993 .39605 .70564 .40408 .71923 .39974 .71294 .39167 Mtetra
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Mtetra
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Mtetra
.34692 .49965 .35437 .50679 .36639 .50293 .35898 .49575 Mtetra
.35898 .49575 .36639 .50293 .37847 .49905 .37109 .49184 Mtetra
.37109 .49184 .37847 .49905 .39061 .49515 .38326 .48791 Mtetra
.38326 .48791 .39061 .49515 .4028 .49124 .39549 .48397 Mtetra
.39549 .48397 .4028 .49124 .41504 .48731 .40777 .48001 Mtetra
.653 .751 .921 r
.40777 .48001 .41504 .48731 .42734 .48345 .4201 .47611 Mtetra
.631 .744 .929 r
.4201 .47611 .42734 .48345 .43968 .48018 .43248 .47282 Mtetra
.489 .688 .956 r
.43248 .47282 .43968 .48018 .45202 .47994 .44484 .4726 Mtetra
0 .27 .754 r
.44484 .4726 .45202 .47994 .46429 .48799 .45711 .48074 Mtetra
.73 .246 0 r
.45711 .48074 .46429 .48799 .47656 .50598 .46937 .49878 Mtetra
.59 .09 0 r
.46937 .49878 .47656 .50598 .48909 .52049 .48191 .51312 Mtetra
.717 .776 .899 r
.48191 .51312 .48909 .52049 .50197 .51451 .49483 .50681 Mtetra
.864 .783 .769 r
.49483 .50681 .50197 .51451 .51493 .49731 .50786 .48936 Mtetra
.652 .743 .916 r
.50786 .48936 .51493 .49731 .52785 .49328 .52082 .4853 Mtetra
0 .249 .746 r
.52082 .4853 .52785 .49328 .54091 .50246 .53389 .49465 Mtetra
.567 .717 .943 r
.53389 .49465 .54091 .50246 .55403 .50037 .54704 .49282 Mtetra
.898 .787 .73 r
.54704 .49282 .55403 .50037 .56696 .47763 .56006 .47018 Mtetra
.915 .784 .702 r
.56006 .47018 .56696 .47763 .57975 .45128 .57293 .44371 Mtetra
.864 .795 .781 r
.57293 .44371 .57975 .45128 .59263 .43492 .58588 .42719 Mtetra
.754 .782 .876 r
.58588 .42719 .59263 .43492 .60568 .42691 .59898 .4191 Mtetra
.678 .759 .913 r
.59898 .4191 .60568 .42691 .61885 .42197 .61219 .4141 Mtetra
.658 .752 .919 r
.61219 .4141 .61885 .42197 .6321 .41763 .62548 .40972 Mtetra
.656 .751 .92 r
.62548 .40972 .6321 .41763 .64541 .41335 .63884 .40541 Mtetra
.63884 .40541 .64541 .41335 .65879 .40906 .65226 .40107 Mtetra
.65226 .40107 .65879 .40906 .67223 .40474 .66574 .39672 Mtetra
.66574 .39672 .67223 .40474 .68573 .4004 .67929 .39235 Mtetra
.67929 .39235 .68573 .4004 .6993 .39605 .69291 .38795 Mtetra
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Mtetra
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Mtetra
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Mtetra
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Mtetra
.33941 .49245 .34692 .49965 .35898 .49575 .3515 .48852 Mtetra
.3515 .48852 .35898 .49575 .37109 .49184 .36365 .48458 Mtetra
.36365 .48458 .37109 .49184 .38326 .48791 .37585 .48061 Mtetra
.37585 .48061 .38326 .48791 .39549 .48397 .38811 .47663 Mtetra
.38811 .47663 .39549 .48397 .40777 .48001 .40043 .47264 Mtetra
.653 .751 .921 r
.40043 .47264 .40777 .48001 .4201 .47611 .4128 .46871 Mtetra
.63 .743 .929 r
.4128 .46871 .4201 .47611 .43248 .47282 .42521 .4654 Mtetra
.487 .687 .956 r
.42521 .4654 .43248 .47282 .44484 .4726 .43759 .46521 Mtetra
0 .262 .748 r
.43759 .46521 .44484 .4726 .45711 .48074 .44988 .47344 Mtetra
.733 .249 0 r
.44988 .47344 .45711 .48074 .46937 .49878 .46212 .49157 Mtetra
.59 .089 0 r
.46212 .49157 .46937 .49878 .48191 .51312 .47466 .50584 Mtetra
.722 .781 .9 r
.47466 .50584 .48191 .51312 .49483 .50681 .48763 .49933 Mtetra
.868 .788 .77 r
.48763 .49933 .49483 .50681 .50786 .48936 .50073 .48174 Mtetra
.652 .753 .924 r
.50073 .48174 .50786 .48936 .52082 .4853 .51373 .47764 Mtetra
0 .232 .727 r
.51373 .47764 .52082 .4853 .53389 .49465 .5268 .48705 Mtetra
.557 .721 .95 r
.5268 .48705 .53389 .49465 .54704 .49282 .54 .48536 Mtetra
.899 .79 .731 r
.54 .48536 .54704 .49282 .56006 .47018 .5531 .46272 Mtetra
.916 .785 .702 r
.5531 .46272 .56006 .47018 .57293 .44371 .56606 .43609 Mtetra
.865 .796 .78 r
.56606 .43609 .57293 .44371 .58588 .42719 .57907 .4194 Mtetra
.755 .783 .875 r
.57907 .4194 .58588 .42719 .59898 .4191 .59221 .41121 Mtetra
.678 .76 .913 r
.59221 .41121 .59898 .4191 .61219 .4141 .60547 .40616 Mtetra
.658 .752 .919 r
.60547 .40616 .61219 .4141 .62548 .40972 .6188 .40175 Mtetra
.656 .751 .92 r
.6188 .40175 .62548 .40972 .63884 .40541 .6322 .39739 Mtetra
.6322 .39739 .63884 .40541 .65226 .40107 .64567 .39302 Mtetra
.64567 .39302 .65226 .40107 .66574 .39672 .6592 .38863 Mtetra
.6592 .38863 .66574 .39672 .67929 .39235 .67279 .38421 Mtetra
.67279 .38421 .67929 .39235 .69291 .38795 .68645 .37978 Mtetra
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Mtetra
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Mtetra
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48518 Mtetra
.33184 .48518 .33941 .49245 .3515 .48852 .34396 .48122 Mtetra
.34396 .48122 .3515 .48852 .36365 .48458 .35615 .47725 Mtetra
.35615 .47725 .36365 .48458 .37585 .48061 .36838 .47325 Mtetra
.36838 .47325 .37585 .48061 .38811 .47663 .38068 .46924 Mtetra
.38068 .46924 .38811 .47663 .40043 .47264 .39303 .46521 Mtetra
.653 .751 .921 r
.39303 .46521 .40043 .47264 .4128 .46871 .40543 .46125 Mtetra
.63 .743 .929 r
.40543 .46125 .4128 .46871 .42521 .4654 .41788 .45792 Mtetra
.484 .686 .956 r
.41788 .45792 .42521 .4654 .43759 .46521 .43029 .45775 Mtetra
0 .256 .742 r
.43029 .45775 .43759 .46521 .44988 .47344 .44258 .46607 Mtetra
.733 .249 0 r
.44258 .46607 .44988 .47344 .46212 .49157 .45481 .48422 Mtetra
.571 .071 0 r
.45481 .48422 .46212 .49157 .47466 .50584 .46735 .49819 Mtetra
.732 .775 .888 r
.46735 .49819 .47466 .50584 .48763 .49933 .48037 .49115 Mtetra
.863 .776 .764 r
.48037 .49115 .48763 .49933 .50073 .48174 .49354 .47318 Mtetra
.652 .73 .906 r
.49354 .47318 .50073 .48174 .51373 .47764 .50658 .46904 Mtetra
0 .239 .744 r
.50658 .46904 .51373 .47764 .5268 .48705 .51966 .47876 Mtetra
.543 .697 .94 r
.51966 .47876 .5268 .48705 .54 .48536 .53289 .47753 Mtetra
.895 .785 .732 r
.53289 .47753 .54 .48536 .5531 .46272 .54607 .45511 Mtetra
.915 .784 .702 r
.54607 .45511 .5531 .46272 .56606 .43609 .55912 .4284 Mtetra
.866 .795 .779 r
.55912 .4284 .56606 .43609 .57907 .4194 .5722 .41155 Mtetra
.756 .783 .875 r
.5722 .41155 .57907 .4194 .59221 .41121 .58539 .40326 Mtetra
.679 .76 .912 r
.58539 .40326 .59221 .41121 .60547 .40616 .59869 .39816 Mtetra
.659 .752 .919 r
.59869 .39816 .60547 .40616 .6188 .40175 .61207 .3937 Mtetra
.656 .751 .92 r
.61207 .3937 .6188 .40175 .6322 .39739 .62551 .38931 Mtetra
.62551 .38931 .6322 .39739 .64567 .39302 .63902 .3849 Mtetra
.63902 .3849 .64567 .39302 .6592 .38863 .65259 .38046 Mtetra
.65259 .38046 .6592 .38863 .67279 .38421 .66623 .37601 Mtetra
.66623 .37601 .67279 .38421 .68645 .37978 .67994 .37154 Mtetra
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Mtetra
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34883 Mtetra
.74947 .34883 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48183 Mtetra
.31209 .48183 .31977 .48912 .33184 .48518 .3242 .47786 Mtetra
.3242 .47786 .33184 .48518 .34396 .48122 .33636 .47387 Mtetra
.33636 .47387 .34396 .48122 .35615 .47725 .34858 .46986 Mtetra
.34858 .46986 .35615 .47725 .36838 .47325 .36085 .46583 Mtetra
.36085 .46583 .36838 .47325 .38068 .46924 .37318 .46178 Mtetra
.37318 .46178 .38068 .46924 .39303 .46521 .38557 .45772 Mtetra
.653 .751 .921 r
.38557 .45772 .39303 .46521 .40543 .46125 .39801 .45372 Mtetra
.629 .743 .93 r
.39801 .45372 .40543 .46125 .41788 .45792 .41048 .45038 Mtetra
.48 .684 .956 r
.41048 .45038 .41788 .45792 .43029 .45775 .42292 .45024 Mtetra
0 .247 .735 r
.42292 .45024 .43029 .45775 .44258 .46607 .43522 .45867 Mtetra
.737 .253 0 r
.43522 .45867 .44258 .46607 .45481 .48422 .44743 .47695 Mtetra
.578 .076 0 r
.44743 .47695 .45481 .48422 .46735 .49819 .45997 .49091 Mtetra
.735 .788 .894 r
.45997 .49091 .46735 .49819 .48037 .49115 .47304 .48375 Mtetra
.872 .792 .769 r
.47304 .48375 .48037 .49115 .49354 .47318 .48628 .46571 Mtetra
.651 .761 .93 r
.48628 .46571 .49354 .47318 .50658 .46904 .49936 .46153 Mtetra
0 .202 .698 r
.49936 .46153 .50658 .46904 .51966 .47876 .51245 .47126 Mtetra
.527 .716 .958 r
.51245 .47126 .51966 .47876 .53289 .47753 .52572 .47006 Mtetra
.899 .792 .734 r
.52572 .47006 .53289 .47753 .54607 .45511 .53898 .44758 Mtetra
.917 .786 .701 r
.53898 .44758 .54607 .45511 .55912 .4284 .55212 .42067 Mtetra
.867 .796 .778 r
.55212 .42067 .55912 .4284 .5722 .41155 .56527 .40363 Mtetra
.757 .783 .874 r
.56527 .40363 .5722 .41155 .58539 .40326 .57851 .39524 Mtetra
.679 .76 .912 r
.57851 .39524 .58539 .40326 .59869 .39816 .59186 .39008 Mtetra
.659 .752 .919 r
.59186 .39008 .59869 .39816 .61207 .3937 .60528 .38558 Mtetra
.656 .751 .92 r
.60528 .38558 .61207 .3937 .62551 .38931 .61876 .38115 Mtetra
.61876 .38115 .62551 .38931 .63902 .3849 .63231 .3767 Mtetra
.63231 .3767 .63902 .3849 .65259 .38046 .64593 .37223 Mtetra
.64593 .37223 .65259 .38046 .66623 .37601 .65962 .36773 Mtetra
.65962 .36773 .66623 .37601 .67994 .37154 .67337 .36322 Mtetra
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Mtetra
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34883 .74314 .34031 Mtetra
.74314 .34031 .74947 .34883 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48183 .30436 .47448 Mtetra
.30436 .47448 .31209 .48183 .3242 .47786 .3165 .47048 Mtetra
.3165 .47048 .3242 .47786 .33636 .47387 .32869 .46645 Mtetra
.32869 .46645 .33636 .47387 .34858 .46986 .34094 .4624 Mtetra
.34094 .4624 .34858 .46986 .36085 .46583 .35325 .45834 Mtetra
.35325 .45834 .36085 .46583 .37318 .46178 .36562 .45426 Mtetra
.36562 .45426 .37318 .46178 .38557 .45772 .37804 .45016 Mtetra
.653 .75 .921 r
.37804 .45016 .38557 .45772 .39801 .45372 .39051 .44613 Mtetra
.629 .743 .93 r
.39051 .44613 .39801 .45372 .41048 .45038 .40302 .44276 Mtetra
.482 .685 .956 r
.40302 .44276 .41048 .45038 .42292 .45024 .41549 .44256 Mtetra
0 .275 .759 r
.41549 .44256 .42292 .45024 .43522 .45867 .4278 .45061 Mtetra
.669 .185 0 r
.4278 .45061 .43522 .45867 .44743 .47695 .44005 .46736 Mtetra
0 .202 .722 r
.44005 .46736 .44743 .47695 .45997 .49091 .45265 .4777 Mtetra
.765 .683 .772 r
.45265 .4777 .45997 .49091 .47304 .48375 .46583 .46568 Mtetra
.803 .652 .695 r
.46583 .46568 .47304 .48375 .48628 .46571 .47915 .44419 Mtetra
.617 .531 .734 r
.47915 .44419 .48628 .46571 .49936 .46153 .49222 .43997 Mtetra
.193 .266 .71 r
.49222 .43997 .49936 .46153 .51245 .47126 .50524 .45306 Mtetra
.453 .467 .783 r
.50524 .45306 .51245 .47126 .52572 .47006 .51849 .45665 Mtetra
.825 .703 .73 r
.51849 .45665 .52572 .47006 .53898 .44758 .53182 .43771 Mtetra
.891 .756 .706 r
.53182 .43771 .53898 .44758 .55212 .42067 .54506 .41227 Mtetra
.858 .784 .778 r
.54506 .41227 .55212 .42067 .56527 .40363 .55827 .39554 Mtetra
.756 .78 .873 r
.55827 .39554 .56527 .40363 .57851 .39524 .57157 .38713 Mtetra
.679 .76 .912 r
.57157 .38713 .57851 .39524 .59186 .39008 .58496 .38193 Mtetra
.659 .752 .919 r
.58496 .38193 .59186 .39008 .60528 .38558 .59842 .37739 Mtetra
.656 .751 .92 r
.59842 .37739 .60528 .38558 .61876 .38115 .61195 .37292 Mtetra
.61195 .37292 .61876 .38115 .63231 .3767 .62555 .36843 Mtetra
.62555 .36843 .63231 .3767 .64593 .37223 .63921 .36392 Mtetra
.63921 .36392 .64593 .37223 .65962 .36773 .65294 .35938 Mtetra
.65294 .35938 .65962 .36773 .67337 .36322 .66673 .35483 Mtetra
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Mtetra
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Mtetra
.29656 .46707 .30436 .47448 .3165 .47048 .30873 .46303 Mtetra
.30873 .46303 .3165 .47048 .32869 .46645 .32096 .45897 Mtetra
.32096 .45897 .32869 .46645 .34094 .4624 .33324 .45489 Mtetra
.33324 .45489 .34094 .4624 .35325 .45834 .34559 .45079 Mtetra
.34559 .45079 .35325 .45834 .36562 .45426 .35799 .44667 Mtetra
.35799 .44667 .36562 .45426 .37804 .45016 .37045 .44254 Mtetra
.653 .751 .921 r
.37045 .44254 .37804 .45016 .39051 .44613 .38296 .43846 Mtetra
.633 .744 .928 r
.38296 .43846 .39051 .44613 .40302 .44276 .39551 .43495 Mtetra
.517 .697 .951 r
.39551 .43495 .40302 .44276 .41549 .44256 .40802 .43411 Mtetra
.074 .43 .872 r
.40802 .43411 .41549 .44256 .4278 .45061 .42041 .43992 Mtetra
0 .135 .676 r
.42041 .43992 .4278 .45061 .44005 .46736 .43277 .45178 Mtetra
.386 .46 .814 r
.43277 .45178 .44005 .46736 .45265 .4777 .44549 .4564 Mtetra
.734 .598 .705 r
.44549 .4564 .45265 .4777 .46583 .46568 .45872 .4419 Mtetra
.764 .601 .676 r
.45872 .4419 .46583 .46568 .47915 .44419 .47204 .42117 Mtetra
.613 .519 .723 r
.47204 .42117 .47915 .44419 .49222 .43997 .48509 .41692 Mtetra
.246 .287 .707 r
.48509 .41692 .49222 .43997 .50524 .45306 .49806 .42916 Mtetra
.427 .4 .726 r
.49806 .42916 .50524 .45306 .51849 .45665 .51126 .43513 Mtetra
.723 .592 .71 r
.51126 .43513 .51849 .45665 .53182 .43771 .52461 .42183 Mtetra
.817 .677 .709 r
.52461 .42183 .53182 .43771 .54506 .41227 .53792 .4012 Mtetra
.813 .733 .777 r
.53792 .4012 .54506 .41227 .55827 .39554 .55121 .38666 Mtetra
.739 .759 .869 r
.55121 .38666 .55827 .39554 .57157 .38713 .56456 .37883 Mtetra
.676 .755 .911 r
.56456 .37883 .57157 .38713 .58496 .38193 .578 .37369 Mtetra
.658 .752 .919 r
.578 .37369 .58496 .38193 .59842 .37739 .5915 .36913 Mtetra
.656 .751 .92 r
.5915 .36913 .59842 .37739 .61195 .37292 .60508 .36461 Mtetra
.60508 .36461 .61195 .37292 .62555 .36843 .61872 .36008 Mtetra
.61872 .36008 .62555 .36843 .63921 .36392 .63243 .35553 Mtetra
.63243 .35553 .63921 .36392 .65294 .35938 .6462 .35095 Mtetra
.6462 .35095 .65294 .35938 .66673 .35483 .66004 .34636 Mtetra
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Mtetra
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45551 Mtetra
.3009 .45551 .30873 .46303 .32096 .45897 .31316 .45142 Mtetra
.31316 .45142 .32096 .45897 .33324 .45489 .32548 .4473 Mtetra
.32548 .4473 .33324 .45489 .34559 .45079 .33786 .44317 Mtetra
.33786 .44317 .34559 .45079 .35799 .44667 .35029 .43902 Mtetra
.35029 .43902 .35799 .44667 .37045 .44254 .36279 .43485 Mtetra
.654 .751 .921 r
.36279 .43485 .37045 .44254 .38296 .43846 .37534 .4307 Mtetra
.642 .746 .924 r
.37534 .4307 .38296 .43846 .39551 .43495 .38793 .42689 Mtetra
.579 .716 .937 r
.38793 .42689 .39551 .43495 .40802 .43411 .40053 .42475 Mtetra
.372 .583 .924 r
.40053 .42475 .40802 .43411 .42041 .43992 .41304 .42702 Mtetra
.181 .384 .827 r
.41304 .42702 .42041 .43992 .43277 .45178 .42552 .43434 Mtetra
.386 .435 .789 r
.42552 .43434 .43277 .45178 .44549 .4564 .4382 .43951 Mtetra
.649 .59 .775 r
.4382 .43951 .44549 .4564 .45872 .4419 .45126 .43415 Mtetra
.8 .79 .843 r
.45126 .43415 .45872 .4419 .47204 .42117 .46447 .42325 Mtetra
.251 .754 .711 r
.46447 .42325 .47204 .42117 .48509 .41692 .4776 .41901 Mtetra
.338 0 0 r
.4776 .41901 .48509 .41692 .49806 .42916 .49072 .4214 Mtetra
.616 .748 .94 r
.49072 .4214 .49806 .42916 .51126 .43513 .50399 .41809 Mtetra
.758 .643 .735 r
.50399 .41809 .51126 .43513 .52461 .42183 .51737 .40405 Mtetra
.771 .643 .72 r
.51737 .40405 .52461 .42183 .53792 .4012 .53073 .38787 Mtetra
.754 .683 .783 r
.53073 .38787 .53792 .4012 .55121 .38666 .54408 .37683 Mtetra
.706 .729 .868 r
.54408 .37683 .55121 .38666 .56456 .37883 .55749 .37026 Mtetra
.668 .747 .91 r
.55749 .37026 .56456 .37883 .578 .37369 .57097 .36536 Mtetra
.657 .751 .919 r
.57097 .36536 .578 .37369 .5915 .36913 .58452 .36078 Mtetra
.656 .751 .92 r
.58452 .36078 .5915 .36913 .60508 .36461 .59814 .35623 Mtetra
.59814 .35623 .60508 .36461 .61872 .36008 .61183 .35166 Mtetra
.61183 .35166 .61872 .36008 .63243 .35553 .62558 .34707 Mtetra
.62558 .34707 .63243 .35553 .6462 .35095 .6394 .34245 Mtetra
.6394 .34245 .6462 .35095 .66004 .34636 .65329 .33781 Mtetra
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.28076 .45205 .28869 .45959 .3009 .45551 .293 .44794 Mtetra
.293 .44794 .3009 .45551 .31316 .45142 .30529 .44381 Mtetra
.30529 .44381 .31316 .45142 .32548 .4473 .31765 .43966 Mtetra
.31765 .43966 .32548 .4473 .33786 .44317 .33006 .43549 Mtetra
.33006 .43549 .33786 .44317 .35029 .43902 .34253 .4313 Mtetra
.34253 .4313 .35029 .43902 .36279 .43485 .35506 .42709 Mtetra
.655 .751 .92 r
.35506 .42709 .36279 .43485 .37534 .4307 .36765 .42287 Mtetra
.651 .749 .921 r
.36765 .42287 .37534 .4307 .38793 .42689 .38029 .41877 Mtetra
.629 .735 .924 r
.38029 .41877 .38793 .42689 .40053 .42475 .39297 .4153 Mtetra
.558 .673 .915 r
.39297 .4153 .40053 .42475 .41304 .42702 .40564 .41383 Mtetra
.457 .542 .855 r
.40564 .41383 .41304 .42702 .42552 .43434 .41828 .4157 Mtetra
.438 .452 .776 r
.41828 .4157 .42552 .43434 .4382 .43951 .43097 .41953 Mtetra
.498 .475 .762 r
.43097 .41953 .4382 .43951 .45126 .43415 .44384 .4214 Mtetra
.58 .616 .852 r
.44384 .4214 .45126 .43415 .46447 .42325 .4569 .41955 Mtetra
.604 .871 .992 r
.4569 .41955 .46447 .42325 .4776 .41901 .47009 .41533 Mtetra
.715 .9 .962 r
.47009 .41533 .4776 .41901 .49072 .4214 .48337 .40861 Mtetra
.754 .69 .79 r
.48337 .40861 .49072 .4214 .50399 .41809 .49673 .39787 Mtetra
.726 .603 .719 r
.49673 .39787 .50399 .41809 .51737 .40405 .51011 .38498 Mtetra
.711 .604 .735 r
.51011 .38498 .51737 .40405 .53073 .38787 .52349 .37421 Mtetra
.697 .657 .806 r
.52349 .37421 .53073 .38787 .54408 .37683 .5369 .36692 Mtetra
.675 .718 .881 r
.5369 .36692 .54408 .37683 .55749 .37026 .55036 .36163 Mtetra
.66 .745 .913 r
.55036 .36163 .55749 .37026 .57097 .36536 .56389 .35695 Mtetra
.656 .751 .919 r
.56389 .35695 .57097 .36536 .58452 .36078 .57748 .35237 Mtetra
.656 .751 .92 r
.57748 .35237 .58452 .36078 .59814 .35623 .59115 .34777 Mtetra
.59115 .34777 .59814 .35623 .61183 .35166 .60488 .34316 Mtetra
.60488 .34316 .61183 .35166 .62558 .34707 .61867 .33853 Mtetra
.61867 .33853 .62558 .34707 .6394 .34245 .63254 .33387 Mtetra
.63254 .33387 .6394 .34245 .65329 .33781 .64648 .32919 Mtetra
.64648 .32919 .65329 .33781 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Mtetra
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Mtetra
.29736 .43613 .30529 .44381 .31765 .43966 .30975 .43194 Mtetra
.30975 .43194 .31765 .43966 .33006 .43549 .3222 .42774 Mtetra
.3222 .42774 .33006 .43549 .34253 .4313 .3347 .42351 Mtetra
.3347 .42351 .34253 .4313 .35506 .42709 .34727 .41926 Mtetra
.34727 .41926 .35506 .42709 .36765 .42287 .3599 .415 Mtetra
.655 .751 .92 r
.3599 .415 .36765 .42287 .38029 .41877 .37258 .41074 Mtetra
.65 .746 .92 r
.37258 .41074 .38029 .41877 .39297 .4153 .38532 .4066 Mtetra
.634 .724 .912 r
.38532 .4066 .39297 .4153 .40564 .41383 .3981 .40294 Mtetra
.602 .66 .879 r
.3981 .40294 .40564 .41383 .41828 .4157 .41091 .40031 Mtetra
.571 .568 .811 r
.41091 .40031 .41828 .4157 .43097 .41953 .42376 .39885 Mtetra
.564 .508 .751 r
.42376 .39885 .43097 .41953 .44384 .4214 .43669 .39764 Mtetra
.581 .496 .723 r
.43669 .39764 .44384 .4214 .4569 .41955 .44973 .39528 Mtetra
.61 .511 .716 r
.44973 .39528 .4569 .41955 .47009 .41533 .46289 .39088 Mtetra
.637 .526 .711 r
.46289 .39088 .47009 .41533 .48337 .40861 .47615 .38436 Mtetra
.653 .537 .71 r
.47615 .38436 .48337 .40861 .49673 .39787 .48947 .37657 Mtetra
.661 .56 .731 r
.48947 .37657 .49673 .39787 .51011 .38498 .50282 .36908 Mtetra
.665 .613 .787 r
.50282 .36908 .51011 .38498 .52349 .37421 .51621 .3629 Mtetra
.665 .685 .859 r
.51621 .3629 .52349 .37421 .5369 .36692 .52965 .35779 Mtetra
.659 .733 .904 r
.52965 .35779 .5369 .36692 .55036 .36163 .54316 .35309 Mtetra
.656 .748 .918 r
.54316 .35309 .55036 .36163 .56389 .35695 .55674 .34848 Mtetra
.656 .751 .92 r
.55674 .34848 .56389 .35695 .57748 .35237 .57038 .34387 Mtetra
.57038 .34387 .57748 .35237 .59115 .34777 .58408 .33924 Mtetra
.58408 .33924 .59115 .34777 .60488 .34316 .59786 .33458 Mtetra
.59786 .33458 .60488 .34316 .61867 .33853 .6117 .32991 Mtetra
.6117 .32991 .61867 .33853 .63254 .33387 .62562 .32521 Mtetra
.62562 .32521 .63254 .33387 .64648 .32919 .6396 .32048 Mtetra
.6396 .32048 .64648 .32919 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Mtetra
.28935 .42838 .29736 .43613 .30975 .43194 .30178 .42416 Mtetra
.30178 .42416 .30975 .43194 .3222 .42774 .31426 .41992 Mtetra
.31426 .41992 .3222 .42774 .3347 .42351 .32681 .41565 Mtetra
.32681 .41565 .3347 .42351 .34727 .41926 .33941 .41137 Mtetra
.33941 .41137 .34727 .41926 .3599 .415 .35207 .40707 Mtetra
.35207 .40707 .3599 .415 .37258 .41074 .36479 .40275 Mtetra
.655 .75 .92 r
.36479 .40275 .37258 .41074 .38532 .4066 .37758 .39842 Mtetra
.653 .746 .918 r
.37758 .39842 .38532 .4066 .3981 .40294 .39042 .39413 Mtetra
.648 .729 .908 r
.39042 .39413 .3981 .40294 .41091 .40031 .40332 .38999 Mtetra
.639 .691 .882 r
.40332 .38999 .41091 .40031 .42376 .39885 .41627 .38606 Mtetra
.631 .64 .84 r
.41627 .38606 .42376 .39885 .43669 .39764 .42929 .38224 Mtetra
.628 .599 .802 r
.42929 .38224 .43669 .39764 .44973 .39528 .44238 .3782 Mtetra
.632 .582 .78 r
.44238 .3782 .44973 .39528 .46289 .39088 .45555 .37368 Mtetra
.64 .585 .777 r
.45555 .37368 .46289 .39088 .47615 .38436 .46879 .36867 Mtetra
.648 .608 .795 r
.46879 .36867 .47615 .38436 .48947 .37657 .48209 .3635 Mtetra
.655 .649 .832 r
.48209 .3635 .48947 .37657 .50282 .36908 .49545 .35853 Mtetra
.657 .699 .877 r
.49545 .35853 .50282 .36908 .51621 .3629 .50887 .35381 Mtetra
.657 .734 .906 r
.50887 .35381 .51621 .3629 .52965 .35779 .52235 .3492 Mtetra
.656 .748 .917 r
.52235 .3492 .52965 .35779 .54316 .35309 .5359 .34458 Mtetra
.656 .751 .92 r
.5359 .34458 .54316 .35309 .55674 .34848 .54952 .33995 Mtetra
.54952 .33995 .55674 .34848 .57038 .34387 .5632 .3353 Mtetra
.5632 .3353 .57038 .34387 .58408 .33924 .57696 .33063 Mtetra
.57696 .33063 .58408 .33924 .59786 .33458 .59078 .32593 Mtetra
.59078 .32593 .59786 .33458 .6117 .32991 .60467 .32121 Mtetra
.60467 .32121 .6117 .32991 .62562 .32521 .61863 .31646 Mtetra
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Mtetra
.28128 .42057 .28935 .42838 .30178 .42416 .29374 .41631 Mtetra
.29374 .41631 .30178 .42416 .31426 .41992 .30626 .41203 Mtetra
.30626 .41203 .31426 .41992 .32681 .41565 .31884 .40773 Mtetra
.31884 .40773 .32681 .41565 .33941 .41137 .33148 .40341 Mtetra
.33148 .40341 .33941 .41137 .35207 .40707 .34418 .39907 Mtetra
.34418 .39907 .35207 .40707 .36479 .40275 .35694 .3947 Mtetra
.35694 .3947 .36479 .40275 .37758 .39842 .36976 .39032 Mtetra
.36976 .39032 .37758 .39842 .39042 .39413 .38264 .38592 Mtetra
.656 .749 .918 r
.38264 .38592 .39042 .39413 .40332 .38999 .39559 .3815 Mtetra
.655 .742 .914 r
.39559 .3815 .40332 .38999 .41627 .38606 .4086 .37706 Mtetra
.655 .73 .905 r
.4086 .37706 .41627 .38606 .42929 .38224 .42167 .37261 Mtetra
.654 .716 .893 r
.42167 .37261 .42929 .38224 .44238 .3782 .4348 .36812 Mtetra
.654 .706 .885 r
.4348 .36812 .44238 .3782 .45555 .37368 .448 .36359 Mtetra
.654 .707 .886 r
.448 .36359 .45555 .37368 .46879 .36867 .46127 .35904 Mtetra
.655 .719 .895 r
.46127 .35904 .46879 .36867 .48209 .3635 .4746 .35448 Mtetra
.656 .735 .908 r
.4746 .35448 .48209 .3635 .49545 .35853 .48799 .3499 Mtetra
.656 .746 .916 r
.48799 .3499 .49545 .35853 .50887 .35381 .50145 .34529 Mtetra
.656 .75 .919 r
.50145 .34529 .50887 .35381 .52235 .3492 .51498 .34067 Mtetra
.656 .751 .92 r
.51498 .34067 .52235 .3492 .5359 .34458 .52858 .33602 Mtetra
.52858 .33602 .5359 .34458 .54952 .33995 .54224 .33135 Mtetra
.54224 .33135 .54952 .33995 .5632 .3353 .55597 .32665 Mtetra
.55597 .32665 .5632 .3353 .57696 .33063 .56976 .32194 Mtetra
.56976 .32194 .57696 .33063 .59078 .32593 .58363 .3172 Mtetra
.58363 .3172 .59078 .32593 .60467 .32121 .59757 .31243 Mtetra
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Mtetra
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Mtetra
.28563 .40839 .29374 .41631 .30626 .41203 .29819 .40407 Mtetra
.29819 .40407 .30626 .41203 .31884 .40773 .3108 .39974 Mtetra
.3108 .39974 .31884 .40773 .33148 .40341 .32348 .39538 Mtetra
.32348 .39538 .33148 .40341 .34418 .39907 .33621 .391 Mtetra
.33621 .391 .34418 .39907 .35694 .3947 .34901 .38659 Mtetra
.34901 .38659 .35694 .3947 .36976 .39032 .36187 .38217 Mtetra
.36187 .38217 .36976 .39032 .38264 .38592 .37479 .37773 Mtetra
.37479 .37773 .38264 .38592 .39559 .3815 .38778 .37327 Mtetra
.655 .751 .92 r
.38778 .37327 .39559 .3815 .4086 .37706 .40083 .3688 Mtetra
.655 .751 .921 r
.40083 .3688 .4086 .37706 .42167 .37261 .41394 .36431 Mtetra
.655 .752 .921 r
.41394 .36431 .42167 .37261 .4348 .36812 .42711 .35979 Mtetra
.656 .752 .921 r
.42711 .35979 .4348 .36812 .448 .36359 .44035 .35523 Mtetra
.657 .753 .921 r
.44035 .35523 .448 .36359 .46127 .35904 .45366 .35063 Mtetra
.656 .752 .92 r
.45366 .35063 .46127 .35904 .4746 .35448 .46703 .346 Mtetra
.656 .751 .92 r
.46703 .346 .4746 .35448 .48799 .3499 .48047 .34138 Mtetra
.48047 .34138 .48799 .3499 .50145 .34529 .49397 .33674 Mtetra
.49397 .33674 .50145 .34529 .51498 .34067 .50754 .33207 Mtetra
.50754 .33207 .51498 .34067 .52858 .33602 .52118 .32738 Mtetra
.52118 .32738 .52858 .33602 .54224 .33135 .53489 .32266 Mtetra
.53489 .32266 .54224 .33135 .55597 .32665 .54866 .31793 Mtetra
.54866 .31793 .55597 .32665 .56976 .32194 .56251 .31316 Mtetra
.56251 .31316 .56976 .32194 .58363 .3172 .57642 .30838 Mtetra
.57642 .30838 .58363 .3172 .59757 .31243 .5904 .30357 Mtetra
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Mtetra
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Mtetra
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .4004 Mtetra
.27745 .4004 .28563 .40839 .29819 .40407 .29004 .39605 Mtetra
.29004 .39605 .29819 .40407 .3108 .39974 .30269 .39167 Mtetra
.30269 .39167 .3108 .39974 .32348 .39538 .31541 .38727 Mtetra
.31541 .38727 .32348 .39538 .33621 .391 .32818 .38285 Mtetra
.32818 .38285 .33621 .391 .34901 .38659 .34102 .37841 Mtetra
.34102 .37841 .34901 .38659 .36187 .38217 .35391 .37395 Mtetra
.35391 .37395 .36187 .38217 .37479 .37773 .36688 .36946 Mtetra
.36688 .36946 .37479 .37773 .38778 .37327 .3799 .36495 Mtetra
.3799 .36495 .38778 .37327 .40083 .3688 .39299 .36041 Mtetra
.656 .75 .919 r
.39299 .36041 .40083 .3688 .41394 .36431 .40614 .35585 Mtetra
.656 .749 .919 r
.40614 .35585 .41394 .36431 .42711 .35979 .41936 .35127 Mtetra
.656 .749 .918 r
.41936 .35127 .42711 .35979 .44035 .35523 .43264 .34668 Mtetra
.655 .749 .919 r
.43264 .34668 .44035 .35523 .45366 .35063 .44598 .34208 Mtetra
.655 .75 .92 r
.44598 .34208 .45366 .35063 .46703 .346 .4594 .33745 Mtetra
.656 .751 .92 r
.4594 .33745 .46703 .346 .48047 .34138 .47288 .33279 Mtetra
.47288 .33279 .48047 .34138 .49397 .33674 .48642 .3281 Mtetra
.48642 .3281 .49397 .33674 .50754 .33207 .50004 .32339 Mtetra
.50004 .32339 .50754 .33207 .52118 .32738 .51372 .31866 Mtetra
.51372 .31866 .52118 .32738 .53489 .32266 .52747 .3139 Mtetra
.52747 .3139 .53489 .32266 .54866 .31793 .54129 .30912 Mtetra
.54129 .30912 .54866 .31793 .56251 .31316 .55518 .30431 Mtetra
.55518 .30431 .56251 .31316 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Mtetra
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Mtetra
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .4004 .2692 .39235 Mtetra
.2692 .39235 .27745 .4004 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Mtetra
.29451 .38353 .30269 .39167 .31541 .38727 .30726 .3791 Mtetra
.30726 .3791 .31541 .38727 .32818 .38285 .32007 .37464 Mtetra
.32007 .37464 .32818 .38285 .34102 .37841 .33295 .37016 Mtetra
.33295 .37016 .34102 .37841 .35391 .37395 .34588 .36565 Mtetra
.34588 .36565 .35391 .37395 .36688 .36946 .35888 .36113 Mtetra
.35888 .36113 .36688 .36946 .3799 .36495 .37195 .35659 Mtetra
.655 .752 .921 r
.37195 .35659 .3799 .36495 .39299 .36041 .38507 .35203 Mtetra
.38507 .35203 .39299 .36041 .40614 .35585 .39827 .34745 Mtetra
.656 .753 .921 r
.39827 .34745 .40614 .35585 .41936 .35127 .41152 .34284 Mtetra
.656 .753 .922 r
.41152 .34284 .41936 .35127 .43264 .34668 .42485 .3382 Mtetra
.656 .753 .921 r
.42485 .3382 .43264 .34668 .44598 .34208 .43824 .33352 Mtetra
.656 .752 .921 r
.43824 .33352 .44598 .34208 .4594 .33745 .45169 .32883 Mtetra
.656 .752 .92 r
.45169 .32883 .4594 .33745 .47288 .33279 .46521 .32412 Mtetra
.656 .751 .92 r
.46521 .32412 .47288 .33279 .48642 .3281 .4788 .31939 Mtetra
.4788 .31939 .48642 .3281 .50004 .32339 .49246 .31463 Mtetra
.49246 .31463 .50004 .32339 .51372 .31866 .50619 .30985 Mtetra
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Mtetra
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Mtetra
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36183 Mtetra
.32481 .36183 .33295 .37016 .34588 .36565 .33778 .35728 Mtetra
.33778 .35728 .34588 .36565 .35888 .36113 .35082 .35272 Mtetra
.35082 .35272 .35888 .36113 .37195 .35659 .36392 .34812 Mtetra
.36392 .34812 .37195 .35659 .38507 .35203 .37709 .34351 Mtetra
.37709 .34351 .38507 .35203 .39827 .34745 .39032 .33886 Mtetra
.656 .75 .919 r
.39032 .33886 .39827 .34745 .41152 .34284 .40362 .3342 Mtetra
.40362 .3342 .41152 .34284 .42485 .3382 .41699 .32952 Mtetra
.655 .75 .919 r
.41699 .32952 .42485 .3382 .43824 .33352 .43042 .32482 Mtetra
.655 .75 .92 r
.43042 .32482 .43824 .33352 .45169 .32883 .44391 .32011 Mtetra
.656 .751 .92 r
.44391 .32011 .45169 .32883 .46521 .32412 .45748 .31536 Mtetra
.45748 .31536 .46521 .32412 .4788 .31939 .47111 .31059 Mtetra
.47111 .31059 .4788 .31939 .49246 .31463 .48482 .30579 Mtetra
.48482 .30579 .49246 .31463 .50619 .30985 .49859 .30097 Mtetra
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Mtetra
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Mtetra
.31659 .35342 .32481 .36183 .33778 .35728 .32961 .34883 Mtetra
.32961 .34883 .33778 .35728 .35082 .35272 .34268 .34423 Mtetra
.34268 .34423 .35082 .35272 .36392 .34812 .35583 .3396 Mtetra
.35583 .3396 .36392 .34812 .37709 .34351 .36903 .33495 Mtetra
.655 .752 .921 r
.36903 .33495 .37709 .34351 .39032 .33886 .38231 .33029 Mtetra
.656 .752 .921 r
.38231 .33029 .39032 .33886 .40362 .3342 .39565 .32559 Mtetra
.656 .753 .921 r
.39565 .32559 .40362 .3342 .41699 .32952 .40905 .32087 Mtetra
.40905 .32087 .41699 .32952 .43042 .32482 .42252 .31612 Mtetra
.656 .752 .921 r
.42252 .31612 .43042 .32482 .44391 .32011 .43607 .31134 Mtetra
.656 .752 .92 r
.43607 .31134 .44391 .32011 .45748 .31536 .44967 .30653 Mtetra
.656 .751 .92 r
.44967 .30653 .45748 .31536 .47111 .31059 .46335 .30171 Mtetra
.46335 .30171 .47111 .31059 .48482 .30579 .4771 .29687 Mtetra
.4771 .29687 .48482 .30579 .49859 .30097 .49091 .292 Mtetra
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Mtetra
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.3083 .34494 .31659 .35342 .32961 .34883 .32136 .34031 Mtetra
.32136 .34031 .32961 .34883 .34268 .34423 .33447 .33566 Mtetra
.33447 .33566 .34268 .34423 .35583 .3396 .34766 .33099 Mtetra
.34766 .33099 .35583 .3396 .36903 .33495 .3609 .32628 Mtetra
.3609 .32628 .36903 .33495 .38231 .33029 .37422 .32156 Mtetra
.37422 .32156 .38231 .33029 .39565 .32559 .3876 .31681 Mtetra
.656 .75 .919 r
.3876 .31681 .39565 .32559 .40905 .32087 .40105 .31204 Mtetra
.40105 .31204 .40905 .32087 .42252 .31612 .41456 .30726 Mtetra
.656 .75 .92 r
.41456 .30726 .42252 .31612 .43607 .31134 .42814 .30245 Mtetra
.656 .751 .92 r
.42814 .30245 .43607 .31134 .44967 .30653 .4418 .29762 Mtetra
.4418 .29762 .44967 .30653 .46335 .30171 .45552 .29275 Mtetra
.45552 .29275 .46335 .30171 .4771 .29687 .46931 .28787 Mtetra
.46931 .28787 .4771 .29687 .49091 .292 .48317 .28295 Mtetra
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Mtetra
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Mtetra
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Mtetra
.31303 .33171 .32136 .34031 .33447 .33566 .32619 .32702 Mtetra
.32619 .32702 .33447 .33566 .34766 .33099 .33941 .3223 Mtetra
.33941 .3223 .34766 .33099 .3609 .32628 .3527 .31757 Mtetra
.656 .752 .921 r
.3527 .31757 .3609 .32628 .37422 .32156 .36605 .31281 Mtetra
.36605 .31281 .37422 .32156 .3876 .31681 .37947 .30803 Mtetra
.37947 .30803 .3876 .31681 .40105 .31204 .39296 .30322 Mtetra
.656 .753 .921 r
.39296 .30322 .40105 .31204 .41456 .30726 .40652 .29838 Mtetra
.656 .752 .921 r
.40652 .29838 .41456 .30726 .42814 .30245 .42015 .29351 Mtetra
.656 .752 .92 r
.42015 .29351 .42814 .30245 .4418 .29762 .43384 .28862 Mtetra
.43384 .28862 .4418 .29762 .45552 .29275 .44761 .28371 Mtetra
.656 .751 .92 r
.44761 .28371 .45552 .29275 .46931 .28787 .46145 .27877 Mtetra
.46145 .27877 .46931 .28787 .48317 .28295 .47535 .27381 Mtetra
.47535 .27381 .48317 .28295 .4971 .27801 .48933 .26883 Mtetra
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Mtetra
.30463 .32303 .31303 .33171 .32619 .32702 .31782 .31829 Mtetra
.31782 .31829 .32619 .32702 .33941 .3223 .33109 .31353 Mtetra
.33109 .31353 .33941 .3223 .3527 .31757 .34441 .30874 Mtetra
.34441 .30874 .3527 .31757 .36605 .31281 .35781 .30393 Mtetra
.35781 .30393 .36605 .31281 .37947 .30803 .37128 .29909 Mtetra
.656 .75 .92 r
.37128 .29909 .37947 .30803 .39296 .30322 .38481 .29424 Mtetra
.38481 .29424 .39296 .30322 .40652 .29838 .39841 .28936 Mtetra
.656 .751 .92 r
.39841 .28936 .40652 .29838 .42015 .29351 .41208 .28446 Mtetra
.41208 .28446 .42015 .29351 .43384 .28862 .42582 .27953 Mtetra
.42582 .27953 .43384 .28862 .44761 .28371 .43963 .27458 Mtetra
.43963 .27458 .44761 .28371 .46145 .27877 .45351 .2696 Mtetra
.45351 .2696 .46145 .27877 .47535 .27381 .46746 .26459 Mtetra
.46746 .26459 .47535 .27381 .48933 .26883 .48148 .25956 Mtetra
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Mtetra
.29615 .31427 .30463 .32303 .31782 .31829 .30938 .30949 Mtetra
.30938 .30949 .31782 .31829 .33109 .31353 .32268 .30468 Mtetra
.32268 .30468 .33109 .31353 .34441 .30874 .33605 .29986 Mtetra
.656 .752 .921 r
.33605 .29986 .34441 .30874 .35781 .30393 .34949 .29501 Mtetra
.34949 .29501 .35781 .30393 .37128 .29909 .363 .29014 Mtetra
.363 .29014 .37128 .29909 .38481 .29424 .37657 .28524 Mtetra
.37657 .28524 .38481 .29424 .39841 .28936 .39022 .28031 Mtetra
.39022 .28031 .39841 .28936 .41208 .28446 .40393 .27535 Mtetra
.656 .752 .92 r
.40393 .27535 .41208 .28446 .42582 .27953 .41771 .27037 Mtetra
.41771 .27037 .42582 .27953 .43963 .27458 .43157 .26536 Mtetra
.656 .751 .92 r
.43157 .26536 .43963 .27458 .45351 .2696 .4455 .26033 Mtetra
.4455 .26033 .45351 .2696 .46746 .26459 .45949 .25528 Mtetra
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Mtetra
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Mtetra
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Mtetra
.28759 .30542 .29615 .31427 .30938 .30949 .30086 .3006 Mtetra
.30086 .3006 .30938 .30949 .32268 .30468 .31421 .29575 Mtetra
.31421 .29575 .32268 .30468 .33605 .29986 .32762 .29087 Mtetra
.32762 .29087 .33605 .29986 .34949 .29501 .3411 .28597 Mtetra
.3411 .28597 .34949 .29501 .363 .29014 .35465 .28104 Mtetra
.35465 .28104 .363 .29014 .37657 .28524 .36826 .27609 Mtetra
.36826 .27609 .37657 .28524 .39022 .28031 .38195 .27112 Mtetra
.38195 .27112 .39022 .28031 .40393 .27535 .39571 .26613 Mtetra
.39571 .26613 .40393 .27535 .41771 .27037 .40954 .26111 Mtetra
.40954 .26111 .41771 .27037 .43157 .26536 .42343 .25606 Mtetra
.42343 .25606 .43157 .26536 .4455 .26033 .43741 .25098 Mtetra
.43741 .25098 .4455 .26033 .45949 .25528 .45145 .24588 Mtetra
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Mtetra
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Mtetra
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Mtetra
.27895 .2965 .28759 .30542 .30086 .3006 .29226 .29163 Mtetra
.29226 .29163 .30086 .3006 .31421 .29575 .30565 .28673 Mtetra
.30565 .28673 .31421 .29575 .32762 .29087 .3191 .28182 Mtetra
.656 .752 .921 r
.3191 .28182 .32762 .29087 .3411 .28597 .33262 .27688 Mtetra
.33262 .27688 .3411 .28597 .35465 .28104 .34621 .27191 Mtetra
.34621 .27191 .35465 .28104 .36826 .27609 .35987 .26692 Mtetra
.35987 .26692 .36826 .27609 .38195 .27112 .3736 .26189 Mtetra
.3736 .26189 .38195 .27112 .39571 .26613 .3874 .25684 Mtetra
.656 .752 .92 r
.3874 .25684 .39571 .26613 .40954 .26111 .40128 .25177 Mtetra
.656 .751 .92 r
.40128 .25177 .40954 .26111 .42343 .25606 .41522 .24666 Mtetra
.41522 .24666 .42343 .25606 .43741 .25098 .42924 .24154 Mtetra
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Mtetra
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Mtetra
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Mtetra
.27023 .28749 .27895 .2965 .29226 .29163 .28358 .28257 Mtetra
.28358 .28257 .29226 .29163 .30565 .28673 .29701 .27763 Mtetra
.29701 .27763 .30565 .28673 .3191 .28182 .3105 .27266 Mtetra
.3105 .27266 .3191 .28182 .33262 .27688 .32407 .26767 Mtetra
.32407 .26767 .33262 .27688 .34621 .27191 .3377 .26265 Mtetra
.3377 .26265 .34621 .27191 .35987 .26692 .3514 .2576 Mtetra
.3514 .2576 .35987 .26692 .3736 .26189 .36518 .25254 Mtetra
.36518 .25254 .3736 .26189 .3874 .25684 .37902 .24745 Mtetra
.37902 .24745 .3874 .25684 .40128 .25177 .39294 .24233 Mtetra
.39294 .24233 .40128 .25177 .41522 .24666 .40693 .23718 Mtetra
.40693 .23718 .41522 .24666 .42924 .24154 .42099 .23201 Mtetra
.42099 .23201 .42924 .24154 .44333 .23639 .43513 .2268 Mtetra
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Mtetra
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Mtetra
.26142 .27839 .27023 .28749 .28358 .28257 .27482 .27343 Mtetra
.27482 .27343 .28358 .28257 .29701 .27763 .28829 .26845 Mtetra
.28829 .26845 .29701 .27763 .3105 .27266 .30182 .26344 Mtetra
.656 .752 .92 r
.30182 .26344 .3105 .27266 .32407 .26767 .31543 .2584 Mtetra
.656 .752 .921 r
.31543 .2584 .32407 .26767 .3377 .26265 .3291 .25334 Mtetra
.3291 .25334 .3377 .26265 .3514 .2576 .34285 .24825 Mtetra
.34285 .24825 .3514 .2576 .36518 .25254 .35667 .24313 Mtetra
.35667 .24313 .36518 .25254 .37902 .24745 .37056 .23798 Mtetra
.656 .752 .92 r
.37056 .23798 .37902 .24745 .39294 .24233 .38452 .2328 Mtetra
.656 .751 .92 r
.38452 .2328 .39294 .24233 .40693 .23718 .39856 .22761 Mtetra
.39856 .22761 .40693 .23718 .42099 .23201 .41267 .22238 Mtetra
.41267 .22238 .42099 .23201 .43513 .2268 .42685 .21713 Mtetra
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3ooomC0:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0oooo00<000000?ooo`3oool0AP3ooomE0:O0j`03
0000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo
F@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?oooe`0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo02P0oooo000T
0?ooo`800000B`3ooomM0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?oo
oe`0Yl3[0`0000020:O0j`030000002W`>/0Yl3[0180Yl3[4P3oool00`000000oooo0?ooo`0V0?oo
o`007`3oool3000004T0ooooG@2W`>/3000000D0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`03
0000003oool0oooo02H0oooo000M0?ooo`800000B`3ooomK0:O0j`<000002@2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0303oool2000000@0oooo0P0000030?ooo`@00000
2P3oool001D0oooo1@0000030?ooo`800000B@3ooomJ0:O0j`<000003@2W`>/00`000000Yl3[0:O0
j`0C0:O0ja40oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`0000140?oooe`0Yl3[0P00
000A0:O0j`030000002W`>/0Yl3[01<0Yl3[403oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000o0?oooed0Yl3[0`00000C0:O0j`030000002W`>/0Yl3[01<0Yl3[
4@3oool00`000000oooo0?ooo`030?ooo`@000000P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00T0oooo000?0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>`3ooomK0:O0j`<000005`2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo03P0ooooFP2W`>/3000001/0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`80
00002`3oool2000000X0oooo0P00000;0?ooo`005P3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0c0?oooe/0Yl3[0`00000O0:O0j`030000002W`>/0Yl3[0180Yl3[
4@3oool00`000000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03o
oomK0:O0j`<000008P2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0803o
ool001`0oooo0P0000080?ooo`030000003oool0oooo02/0ooooFP2W`>/3000002H0Yl3[00<00000
0:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0:03ooomI0:O0j`<00000:P2W`>/00`000000Yl3[0:O0j`0B0:O0
ja40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0S0?ooob`0Yl3[1@2W_n/Y0:O0j`<00000;P2W`>/00`000000Yl3[0:O0j`0B0:O0ja40
oooo00<000000?ooo`3oool07P3oool001/0oooo0P00000<0?ooo`030000003oool0oooo01l0oooo
:`2W`>/:0:NojbH0Yl3[0P00000a0:O0j`030000002W`>/0Yl3[01<0Yl3[403oool00`000000oooo
0?ooo`0N0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo<02W
`>/70:NojbD0Yl3[0`00000d0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?oo
o`0M0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo<P2W`>/4
0:Noj`P0Yl3[0`2W_n/I0:O0j`<00000>02W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000O
0?ooo`006`3oool2000000l0oooo00<000000?ooo`3oool05@3oooln0:O0j`H0Yko[5@2W`>/30000
03/0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01`0oooo000K0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04@3ooolm0:O0j`X0Yko[4P2W`>/3000003l0
Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01/0oooo00080?ooo`800000
103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
303oooln0:O0j`T0Yko[4`2W`>/3000004<0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000
003oool0oooo01/0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool2000001<0oooo00<000000?ooo`3oool02P3ooom00:O0j`D0Yko[4`2W`>/3000004L0
Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01X0oooo00070?ooo`040000
003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo
00L0ooooC02W`>/50:Noj`H0Yl3[0`00001:0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`00
0000oooo0?ooo`0I0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo0000
00T0oooo0P0000040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3ooom?0:O0
j`L0Yko[0P2W`>/3000004h0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo
01T0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool20000
01H0oooo00<000000:O0j`2W`>/0CP2W`>/70:Noj`80Yl3[0P00001B0:O0j`030000002W`>/0Yl3[
0140Yl3[403oool2000001X0oooo00080?ooo`8000002P3oool3000000<0oooo00<000000?ooo`3o
ool04P3ooom@0:O0j`T0Yko[00@0Yl3[0000000000000000E@2W`>/00`000000Yl3[0:O0j`0A0:O0
ja40oooo00<000000?ooo`3oool05`3oool001T0oooo00<000000?ooo`3oool04P3ooom>0:O0j`T0
Yko[00@0Yl3[0000000000000000F02W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?oo
o`3oool05`3oool001T0oooo0P00000A0?oooe40Yl3[102W_n/20:O0k0<00000102W`>/50:Noje<0
Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01H0oooo000I0?ooo`030000
003oool0oooo00d0ooooE`2W`>/3000000@0Yl3/2@2W_n/90:O0j`D0Yko[A@2W`>/00`000000Yl3[
0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool05@3oool001T0oooo00<000000?ooo`3oool02@3o
oomH0:O0j`<000000`2W`>/90:Noj`X0Yl3[102W_^X50:Noj`@0YkoZ@@2W`>/00`000000Yl3[0:O0
j`0A0:O0ja00oooo00<000000?ooo`3oool05@3oool001T0oooo0P0000070?oooeP0Yl3[0`000005
0:O0j`L0Yko[102X`>/50:O0j`D0YkcX102W_^X50:Rki`@0YkoZ1@2W_n/k0:O0j`030000002W`>/0
Yl3[0180Yl3[403oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`030?oo
oeP0Yl3[0`0000060:O0j`L0Yko[0`2W`>/40:S0j`D0YkSU1@2W_>P40:Rbh0T0Z;_W1@2W_n/k0:O0
j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000
oooo0?ooo`030?oooeH0Yl3[0`0000050:O0j`T0Yko[1P2W`>/20:S0j`80YkCR1@2W^>D20:Nlj0<0
YjKD102X/^050:Z_f`@0Z;_W1@2X_^Tk0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool2000001D0
oooo000H0?ooo`040000003oool000000?oooeH0Yl3[0P0000090:O0j`D0Yko[2@2W`>/50:NdhP@0
YkSU1P2WY]@20:Rbh080ZYc91@2Z[m/20:Rki`80[;OQ1@2X_^T40:S0jcH0Yl3[00<000000:O0j`2W
`>/04@2W`>/A0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`00603oool00`000000Yl3[
0:O0j`1D0:O0j`<000005@2W`>/:0:NdhP@0YI_;1@2WY]@50:ZLb@@0ZZoK1@2/]n450:^oj0@0Z<3[
=P2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000090?ooo`004@3oool2000000D0oooo00<000000?ooo`2W`>/0D@2W`>/3000001D0Yl3[
102W]n@50:NdhPD0XiG6102UVl/20:NVe0<0ZHnk102ZW<T50;:XcP<0[;OQ0P2d^]h50:^oj0@0Z<3[
=P2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04h0
Yl3[0`00000D0:O0j`D0Yk[W102W]n@20:NdhP<0XIC7102SULH40:FKb`D0ZHnk0`2ZW<T20;JJ_0D0
/ZS>1@2d^]h20:^oj0<0[L7Y102X`>/f0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo0000
00@0oooo0P0000020?ooodX0Yl3[0`00000D0:O0j`@0YkgY1@2W^^L30:Ngi0D0XIC7102SULH20:FK
b`<0YhVe1@2YSk/0102ZW<T0]YZl0;JJ_02fV[`40;:XcP80`Jk8102d^]h60:g1j@@0Z<3[=@2W`>/0
0`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080ooooAP2W
`>/3000001D0Yl3[0`2W_n/40:Nmj@@0Yk[W102PVLd50:6Da`<0XiG61@2WRKD50:V?^`D0]YZl0P2b
Z<h40<6^b080];[N0P2m`]h50:g1j@D0Z<3[=@2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00
00040?ooo`8000002P3oool00100oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`050?oood40Yl3[0`00000F0:O0j`H0Yko[0`2W_NT50:6Se`<0X9W=1@2QU<L20:>EaP80XhJf102W
RKD40:V?^`80^IZh102fV[`60<6^b0D0_L;N1@2]`^T40:S0jcH0Yl3[00<000000:O0j`2W`>/04@2W
`>/>0?ooo`<00000403oool00140oooo0P0000040?ooo`8000001`3ooolm0:O0j`<000006`2W`>/4
0:Noj`@0Xk3Q102QXmL40:2Ic@@0XIC7102SQ[H50:N9]@80ZHnk0`2iV[P30;JJ_080aJBh1031[/P2
0=2kaP80_L;N0`31aml40:g2j@D0Z<3[=P2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo00<00000
0?ooo`3oool03P3oool001L0oooo00<000000?ooo`3oool01`3oooli0:O0j`<000007`2W`>/40:Fj
j0@0Xk3Q102QXmL30:2Ic@D0W8:g0`2SQ[H50:N9]@030:V?^`2iV[P0^IZh0080^IZh0P2fV[`30<FT
^0<0`Jk80`3@^lH60<77g`@0[L;Y1@2X`>/e0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`00
0000oooo0?ooo`0=0?ooo`005`3oool00`000000oooo0?ooo`080?ooocD0Yl3[0`00000N0:O0j`D0
Ykk[102U^^P30:>`h@@0XJ?G102DO[T409b2]`@0XhJf102WRKD50;VJ^0030;JJ_035Y;P0aJBh00<0
aJBh00<0`Jk80=2kaP3@^lH00P3@^lH0103Kb<L0`LOO0<77g`31aml30<78g`@0[L;Y1@2X`>/e0:O0
j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0<0?ooo`005`3oool2000000T0
oooo<`2W`>/2000001h0Yl3[102W_n/50:Nnj`@0VZSQ0`2BTLl40922`0<0U7ji102LP[L40:>6]P<0
YhVe0P31/<X40;VJ^0H0aJBh103@^lH30=_8a`H0`LSO102]`^T50:S0jcD0Yl3[00<000000:O0j`2W
`>/04@2W`>/?0?ooo`030000003oool0oooo00`0oooo000G0?ooo`030000003oool0oooo00X0oooo
;P2W`>/300000240Yl3[102W_n/50::ij@<0VZSQ0`2BTLl40922`0<0U7ji1@2LP[L30:>6]P80YhVe
0`31/<X40;VJ^0030<:T_035Y;P0aJBh00<0aJBh00@0dJfe0=2kaP3@^lH0d;_60`3Kb<L00`3MblL0
`LSO0<78g`040<78g`@0[L;Y1@2X`>/e0:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`000000
oooo0?ooo`0;0?ooo`005P3oool00`000000oooo0?ooo`0<0?ooobX0Yl3[0`00000U0:O0j`@0Y[k[
1@2R^NT309ZXh@80TY7?102@P/0409An^@@0W8:g0`2SQ[H60<6`bP80^IZh0P32Y;`40<FT^0<0dJfe
00@0d;_60=_8a`3Kb<L0flS70`3MblL50<78g`D0[L;Y102X`>/e0:O0j`030000002W`>/0Yl3[0140
Yl3[403oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000h0oooo9P2W`>/3000002T0Yl3[
102V_^/40::ij@<0VZSQ0`2BTLl40922`0<0U7ji102LP[L40;OVmPD0`K3:00<0^IZh0<:T_032Y;`0
0P32Y;`20<FT^0@0dJfe103Kb<L40=g;a`D0`LSO1@2]`^T40:S0jcD0Yl3[00<000000:O0j`2W`>/0
402W`>/?0?ooo`800000303oool001H0oooo00<000000?ooo`3oool03P3ooolR0:O0j`<00000;@2W
`>/40:6lk0@0SZcZ0P1dR]X309:Ac`@0T8;00`2DO[T209b2]`@0V]km0`2gi_H40<6`bPD0`ZBl00<0
aJBh0=6]]@3A[KD00`3A[KD00`3T`K@0flS70=_8a`060=g;a`D0`LSO1@2]`^T40:S0jcD0Yl3[00<0
00000:O0j`2W`>/0402W`>/@0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000003oool0
oooo0100oooo7@2W`>/3000002h0Yl3[0`2V_n/40:6lk0<0SZcZ0`1dR]X2071caP@0T8;00`2DO[T4
09[No@D0W8Bi1@2M_o040<:T_0D0dJfe0`3T`K@70=g;a`@0`LSO0P31b>050:g2j@@0Z<3[=02W`>/0
0`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0203oool001H0oooo0P00000B0?oo
oaT0Yl3[0`00000_0:O0j`H0Y[o[0`2Q_>`408j/jP80M8[J0`1`LlH407mi``@0U9gJ0P3<b]L00`33
VJd0W8Bi09b4^@0209b4^@0303i9]02M_o00WKo`0080WKo`1032Y;`0102iUkD0dJfe0=6]]@3A[KD4
0>C1]0030>[9/`3MblL0gL_700D0gL_70P31b=l40<78h0D0[L;Y102X`>/d0:O0j`030000002W`>/0
Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`080?ooo`005P3oool00`000000oooo0?ooo`0B0?oo
oaD0Yl3[0`00000d0:O0j`@0Y[o[102D]nl305nEk0<0M8[J0P1`LlH407mi``<0U9gJ0P3<b]L20<>I
[@@0W8Bi0P0nBK@409fol080`ZBl0P2iUkD30=6]]@<0i<6d0`3ZbK<70=g;a`D0`LSP1@2]`^T50:S0
jc@0Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`8000002@3oool000<0oooo0P0000040?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool0503ooolA0:O0j`<00000>02W`>/40:Bnk0@0
U;O_0`1OUN`00`0^H]<0M8[J071caP02071caP@0OgW300@0U9gJ0<c:e`3<b]L0c<[G0P33VJd509b4
^@80?TVd00@0KFJi09fol02M_o00`ZBl102iUkD00`3A[KD0i<6d0>C1]0020>C1]0<0j/Vc00<0j/Rc
0=g;a`3MblL01@3MblL30<78h080`<SP1@2]`^T50:S0jc@0Yl3[00<000000:O0j`2W`>/0402W`>/;
0?ooo`<0000000<0oooo0000003oool0203oool00080oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo3P2W`>/2000003`0Yl3[102T
_^`309Bgk`@0GiG/00@0;V;C071caP1`LlH0L7?6101oNL<30<c:e`@0`iV]102LQ;T203i9]0<0KFJi
1@2iUkD40>C1]0<0j/Vc0`3Zb;<70=g;a`D0`<SP1@2]`^T50:S0jc<0Yl3[00<000000:O0j`2W`>/0
4@2W`>/60?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`000P3oool010000000oooo0?oo
o`00000;0?ooo`040000003oool0oooo0?ooo`8000005`3oool:0:O0j`<00000?`2W`>/40::nk@<0
Q;;c0`0BK]l202iRd`80HVo91@2VUlH20<c:e`@0`iV]102LQ;T203i9]0@0KFJi102iUkD0103C/kX0
i<6d0>C1]03T`K@30>[9/`@0j/Rc1@3MblL20=g;b0D0`<SP1@2]`^T40:S0jc@0Yl3[00<000000:O0
j`2W`>/04@2W`>/20?ooo`<00000203oool00`000000oooo0?ooo`070?ooo`000P3oool010000000
oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0H0?ooo`D0Yl3[0`0000130:O0
j`@0X[k]0`24/_<3019^g`0402iRd`1RKlT0HVo9069_b@D0YYO61@33VJd509f7^`80?TVd0`1]I[T3
0;VG]@<0dk>j00@0i<6d0>[9/`3ZbK<0j/Vc1@3Zb;<40=g;a`<0gL_81P30b>050:g2j@@0Z<3[=02W
`>/00`000000Yl3[0:O0j`0@0:O0j`800000303oool00`000000oooo0?ooo`060?ooo`000P3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3o
ool0102W`>/000000000000000170:O0j`@0XKk^0`1k[o@01000A/804VkO019^g`0^H]<2069_b@@0
YYO60P2kVK@40<>I[@030<fV/@2MQk/0WHNk0080WHNk00<0<DBe03i9]01]I[T00P1]I[T30;VG]@<0
dk>j103ZbK<60>[8/`80gL_7103MblP0103LblP0`<SP0<38h030b>030<37h0D0[L;Y102X`>/d0:O0
j`030000002W`>/0Yl3[0100Yl3[3@3oool00`000000oooo0?ooo`060?ooo`000`3oool2000000X0
oooo0`0000030?ooo`800000603oool3000004H0Yl3[1@2W_n/40:6nkP<0Njod0P00A/8010008Zd0
HVo9069_b@1RKlT20:JGaP<0^iVd0`33VJd20<fV/@@0WHNk0P0aA;D406eV^@030;VG]@3C/kX0dk>j
0080dk>j00<0i/Zk0>[9/`3ZbK<0203Zb;<40=g;b0<0g<_81@30an060:g2j@@0Z<3[<`2W`>/00`00
0000Yl3[0:O0j`0@0:O0j`d0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3o
ool05@3oool3000000@0ooooAP2W`>/50:Noj`@0XKk^0`1j[o@00`00?k`004K2000R[@02069ed0D0
^iVd0`33VJd20<fV/@D0WHNk00<0<DBe06eV^@1]I[T00P1]I[T0102iUkD0dk>j0=>c^P3C/kX30>K:
^`X0j/Rc0P3MblP50=c;b0D0`<OP1P2]`^T40:S0jc<0Yl3[00<000000:O0j`2W`>/0402W`>/<0?oo
o`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo0180oooo0`0000080?oood/0
Yl3[102Q_^h307Z_m08003nl0`1RMM050;^I]0030<>I[@3=Y[40cJJa0080cJJa102MQk/20354]@<0
LgO8103C/kX30>K:^`030>G8^`3Zb;<0j/Rc00P0j/Rc1`3LblP50<37h0D0[L;Y1@2X`>/c0:O0j`03
0000002W`>/0Yl3[0100Yl3[2`3oool00`000000oooo0?ooo`060?ooo`00503oool200000100oooo
0`00000<0?oood/0Yl3[102Q_^d307^_m0040011_@00?k`0HWG@069ed0D0^iVd00<0`iV]0<fV/@3=
Y[400P3=Y[4409f7^`80<DBe101cMlP20=>c^P<0i/Zk0`3Ub;/:0>[8/`L0g<_80`30an020;o7h0@0
[L;Y1@2X`>/d0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00
503oool00`000000oooo0?ooo`0<0?ooo`<000004@3ooom:0:O0j`@0XKk]0`1k[o@00`00@Kd0HWG@
069ed0050;^I]0D0cJJa1@2V`^h00`00<k80<DBe07=gb00307=gb0040=>c^P3Vb[/0i/Zk0>K:^`<0
iLRk00<0i/Zk0>[8/`3Zb;<0203Zb;<70=c;b0D0_lOP102]`^T50:S0jc<0Yl3[00<000000:O0j`2W
`>/0402W`>/:0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo00X0oooo
0P00000E0?ooodX0Yl3[102Q_^d307b_m0030013_`1RMM00HWG@00<0^iVd0P33[/D40<fV/@030=o:
a02V`^h0Y/;^00<0Y/;^00<003>b07=gb01cMlP00P1cMlP30>K:^`<0iLRk0`3Vb[/90>[8/`030>W8
/`3LblP0g<_800D0g<_80P2oan030;o8h@@0[L;Y1@2X`>/c0:O0j`030000002W`>/0Yl3[0100Yl3[
2P3oool00`000000oooo0?ooo`050?ooo`00503oool00`000000oooo0?ooo`070?ooo`<00000603o
oom:0:O0j`@0XKk]0`1l[o@01000@kl0HWG@0;^I]02kVK@30<>^a@<0cJJa0`3Ob/@50:Jji`03000m
_P26]oD0Q[Oe0080Q[Oe0P3Vb[/30>G8^`<0i/Zk00<0iLVj0>[8/`3Zb;<01@3Zb;<30>W8/`H0g<_8
1P2ob>450:c3jP@0Z<3[<`2W`>/00`000000Yl3[0:O0j`0?0:O0j`X0oooo00<000000?ooo`3oool0
1@3oool001<0oooo0`0000050?ooo`<00000703ooom90:O0j`D0XKk]0`1m/?@00`00<kP0`jk50<>^
a@040<>^a@80cJJa0`3Ob/@00`3La/<0Y[[W0:Jji`030:Jji`03000m_P26]oD0Q[Oe0080Q[Oe0`3U
b;/30>K:^`<0iLVj1P3Zb;<30>W8/`030>[8]03LblP0g<_800<0g<_800@0gLk:0;o8h@2ob>40_lSQ
0`30c>@20:c3jP<0[<?[102X`>/c0:O0j`030000002W`>/0Yl3[00l0Yl3[2@3oool00`000000oooo
0?ooo`050?ooo`004`3oool00`000000oooo0?ooo`020?ooo`<00000803ooom90:O0j`D0XKk]0`1m
/?@00`00<kP0`jk50<>^a@030<>^a@040<fV/@3Ob/@0gl[40=o:a0<0g<K31@2V`>`00`00?Kh0Rk;`
08^bl00208^bl080iLRk0P3Vb[/40>G9^P030>K9^P3Zb;<0j/Rc0080j/Rc0`3Yb;<20>[8]0@0g<_8
0`3Mc/X50<3<i0D0[<?[1@2X`>/b0:O0j`030000002W`>/0Yl3[0100Yl3[203oool00`000000oooo
0?ooo`050?ooo`004`3oool00`000000oooo00000002000002@0ooooB@2W`>/50:6nk@<0OK3d1@33
[/D40=o:a0<0g<K300<0g/W50:K0k02V`>`00P2V`>`00`00>kX003fn08^bl00308^bl0<0i/Zk0`3U
bKX30>K9^P<0j/Rc0`3Yb;<20>[8]0030>W8]03LblP0g<_800@0gLk:00@0h]c?0<3<i030c>@0`<cT
0P2mdNT30:c3j`80Z/?/102X`>/c0:O0j`030000002W`>/0Yl3[0100Yl3[1`3oool00`000000oooo
0?ooo`050?ooo`004`3oool3000002L0ooooB@2W`>/50:6nk@<0OK3d0P33[/D30;c9i080gl[40`3L
a/<30=k9a@@0Y[kZ00<003nn08jhl`2>^?<00`2>^?<0103Vb[/0iLVj0>G9^P3UbKX50>K9^P040>[8
/`3Yb;<0jLRc0>W8/`<0j/Rd0P3Yb;@40=g>bP<0h]c?1@2mdNT50:[3k3L0Yl3[00<000000:O0j`2W
`>/03`2W`>/70?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003oool0oooo02L0oooo
B@2W`>/50:6nk@80O[3d1P2lbN@40=c6``<0g/W500<0gLS40:JnjP2V_^X00P2V_^X00`00?kh0S[Sc
08jhl`0208jhl`@0iLVj1@3VbKX40>W8/`80j/Rd0`3Yb;@00`3^d;@0gLk:0=g>bP030>;Lc`80gn_J
1P2ecnd40:S1jcH0Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00@0oooo
000;0?ooo`D000001@3oool2000002T0ooooB02W`>/50:6nk@80O[3d0`2lbN@30;_6h`80g<K30`3N
bLD30=g8a0@0Y[k[00<0046o096gl@2A]o400P2A]o420>G9^PL0i/Vj0P3Yb;<30>[8]0<0jLRd0P3^
d;@30>;Lc`80gn_J0P3@k^P30;G?k@<0[LK]102X`N/f0:O0j`030000002W`>/0Yl3[0100Yl3[1P3o
ool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02L0ooooB02W`>/50:6nk@80Ok7d1P2ka^<30=k9a@@0gLS400<0gLS50:Jnj`2V_^/00P2V_^/0
0`00@Kl0TKOa096gl@02096gl@T0i/Vj0`3Zb;@30>W8]0<0k]2d00@0mnVd0=o[fP3OjmX0gn_J103@
k^P50:g6kC/0Yl3[00<000000:O0j`2W`>/0402W`>/50?ooo`030000003oool0oooo00@0oooo000=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3ooom90:O0j`<0XKk]0`1o/O@3
0;_6h`<0^<OV00<0g/W50=g8a03Mb<@00P3Mb<@30=g8a@@0Y/3/00<004;009Bil@2D^O400P2D^O48
0>K9^P030>O:^@3Zb;@0j/Rd00<0jLRd0P3^d;@20?OY]080koNk0P3@k^P50;[Jl0@0Z<7/>`2W`>/0
0`000000Yl3[0:O0j`0?0:O0j`D0oooo00<000000?ooo`3oool0103oool000d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0W0?ooodT0Yl3[0`2Q_^d307nam0D0^<OV103Mb<@40=g8
a@030=g9aP2V`>`0Y/3/0080Y/3/00<004;009Bil@2D^O400P2D^O460>K9^P<0ilZi0`3Yb;@20>k@
]080mnVd0`3_mk/00`3Ho[l0bO_V0<WkiP020;[Jl0<0[<K]102X`N`j0:O0j`030000002W`>/0Yl3[
0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0:0?ooo`80
0000:03ooom90:O0j`<0XKk]0`20/O@30;S7iP80]lKV0P3Mb<@40=g8a@<0gLW6102V_NT00`00@/00
U[_a09Jkl@0209Jkl@D0i/Vj0`3Wb[T00`3Vb;T0jLRd0>W8]0020>k@]080mnVd0P3_mk/0103Ho[l0
bO_V0<WkiP39nnH50:c6kCl0Yl3[00<000000:O0j`2W`>/03`2W`>/40?ooo`030000003oool0oooo
00@0oooo000<0?ooo`8000003P3oool00`000000oooo0?ooo`0V0?ooodT0Yl3[102R_^d2082am0D0
]lKV103Mb<D40=g9aP030=c7a@2V_NT0Y[gY0080Y[gY00<004;009Jkl@2F^o400P2F^o430>K9^P<0
ilZi0`3Vb;T20>k@]080mnVd0P3_mk/20<WkiPD0]=Ca102X`N/o0:O0j`030000002W`>/0Yl3[00l0
Yl3[0`3oool00`000000oooo0?ooo`040?ooo`007@3oool00`000000oooo0?ooo`0V0?ooodT0Yl3[
102R_^d2082am0<0]lKV0P2ea^L20=g8a@@0gLW60P3LalD40:Jmj@030017a@2H^Nl0V;W_00<0V;W_
0P3VbKX30>O:^@<0i/Ri00<0ln:j0?OY]03gjK@00P3_mk/209?QUP<0^^_d102Y`n`40:S1jcl0Yl3[
00<000000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo00<0oooo000N0?ooo`030000003o
ool0oooo02H0ooooB@2W`>/40::nk@80P;7d1@2ea^L40=g9aP<0g<O51P2V`nh509Rik`<0ilZi0`3V
b;T20??R^P80d_:I00<0fOo:09?QUP2jjo@00P2jjo@30:_7kP@0ZL?/@P2W`>/00`000000Yl3[0:O0
j`0@0:O0j`80oooo00<000000?ooo`3oool00`3oool001l0oooo0P00000X0?ooodP0Yl3[102R_^d2
086bm0<0]LKW0P2ca^P20=g9aP@0g<O50P3MblL50:Nkj0D0V[ob0P3Wb[T20>K8^@80ln:j0P3BlYT0
103IolX0Z?OX0:Sgj02XmnP50:_7kTL0Yl3[00<000000:O0j`2W`>/0402W`>/00`3oool000000?oo
o`040?ooo`008@3oool00`000000oooo0?ooo`0V0?ooodP0Yl3[102R_^d2086bm0D0/lKX103LalD3
0=g;a`030=_6a@2W^nP0Yk_X0080Yk_X00<004c909ZolP2J_o800`2J_o830>K8^@80ln:j00<0d_:I
09?XnP2XmnP01@2/cO5;0:O0j`030000002W`>/0Yl3[00l0Yl3[00<0oooo0000003oool0103oool0
0280oooo00<000000?ooo`3oool09P3ooom80:O0j`@0Xkk]0`29]o@40;;4j080g<O50`3MblL30=_6
a@<0Yk_X0P00C<T509bik@050>K8^@3ch[X0ln:j0=;bV@2Cj?X0102Yd?A?0:O0j`030000002W`>/0
Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002<0oooo00<000000?ooo`3oool09P3ooom80:O0
j`@0Xkk]0`2F_?440;;4j0@0gL_70`3Ka/D00`3QoL40h/[10>;:`@020>;:`@03001<b@2L^Nd0W;W]
0080W;W]0P3ch[X209?XnP030:G?mP2W`>/0Yl3[0540Yl3[00<000000:O0j`2W`>/03`2W`>/00`00
0000oooo0?ooo`030?ooo`00903oool2000002L0ooooA`2W`>/50:Fok0<0U[ca102`a^X20=g;a`@0
flK5103Rb/420<kcjP@0YZ_K0P1hU^<80:O0j`D0Yl7/BP2W`>/00`000000Yl3[0:O0j`0;0:O0j`<0
oooo00<000000?ooo`3oool00`3oool002H0oooo00<000000?ooo`3oool09@3ooom70:O0j`@0YKo/
102R_nh40;36jP@0flK50P3;om820>;:`@@0c_?Z0`2VZm/70:O0j`P0Yl7/1@2W_n]60:O0j`030000
002W`>/0Yl3[00H0Yl3[203oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`0U0?ooodL0Yl3[1@2V`>`20::okPD0/<?X0P3Ka/D40<_odPD0c_?Z1`2W`>/80:O1k0P0Yko[AP2W
`>/00`000000Yl3[0:O0j`030:O0j`/0oooo00<000000?ooo`3oool00P3oool002P0oooo00<00000
0?ooo`3oool09P3ooom;0:O0j`80Y/3/1@2``nP00`2W`>/0YL3/0:G0k0020:G0k0P0Yl3[2@2W`N`8
0:NojdX0Yl3[00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00:@3oool20000
02L0ooooC@2W`>/309KYn@l0Yl3[102W`N`90:Nojd/0Yl3[0`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo02D0ooooG`2W`>/80:Noj`D0
Yl7/1@2W_n]10:O0j`P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00
;03oool00`000000oooo0?ooo`0U0?oooel0Yl3[102W_n/50:O0k0P0Yko[?P2W`>/;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002d0oooo00<000000?ooo`3oool09P3o
oomS0:O0j`P0Yko[?P2W`>/?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3o
ool002h0oooo00<000000?ooo`3oool09P3ooomN0:O0j`T0Yko[?@2W`>/D0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00@3oool002l0oooo0P00000W0?oooeh0Yl3[102W_n/80:O0
j`D0Yko[<@2W`>/H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool09@3ooomV0:O0j`P0Yko[;@2W`>/L0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3oool09@3ooomR0:O0j`P0Yko[
;@2W`>/P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool003<0oooo00<0
00000?ooo`3oool09@3ooomR0:O0j`@0Yko[;@2W`>/T0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00@3oool003@0oooo0P00000V0?ooofH0Yl3[1@2W_n/S0:O0jbT0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`010?ooo`00=P3oool00`000000oooo0?ooo`0U0?oo
of40Yl3[202W_n/P0:O0jb`0oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool003L0
oooo00<000000?ooo`3oool09@3ooomQ0:O0j`@0Yko[802W`>/`0?ooo`030000003oool0oooo00H0
oooo0@0000010?ooo`40oooo000h0?ooo`030000003oool0oooo02D0ooooO@2W`>/h0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`40oooo000i0?ooo`8000009P3ooomi0:O0jc/0oooo00<0
00000?ooo`3oool01@3oool100000040oooo0@3oool003/0oooo00<000000?ooo`3oool0903ooome
0:O0jcl0oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool003`0oooo00<000000?oo
o`3oool0903oooma0:O0jd<0oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool003d0
oooo00<000000?ooo`3oool0903ooom/0:O0jdP0oooo00<000000?ooo`3oool00P3oool100000040
oooo0@3oool003h0oooo0P00000U0?ooofP0Yl3[B`3oool00`000000oooo0?ooo`030?ooo`400000
0@3oool00400oooo00<000000?ooo`3oool08`3ooomT0:O0jdl0oooo00<000000?ooo`3oool00P3o
ool100000040oooo00110?ooo`030000003oool0oooo02<0ooooH02W`>]C0?ooo`050000003oool0
oooo0?ooo`0000000@3oool00480oooo00<000000?ooo`3oool0903ooomK0:O0jeL0oooo00@00000
0?ooo`3oool000000@3oool004<0oooo0P00000U0?oooe<0Yl3[GP3oool010000000oooo0?ooo`00
00010?ooo`00A@3oool00`000000oooo0?ooo`0S0?ooodl0Yl3[HP3oool00`000000oooo00000001
0?ooo`00AP3oool00`000000oooo0?ooo`0S0?oood/0Yl3[IP3oool100000040oooo0@00000004L0
oooo00<000000?ooo`3oool08`3ooom70:O0jfX0oooo0P00000004P0oooo0P00000U0?oood80Yl3[
K@3oool200000000BP3oool00`000000oooo0?ooo`0S0?oooch0Yl3[L03oool200000000B`3oool0
0`000000oooo0?ooo`0R0?oooc/0Yl3[K`3oool400000080oooo001<0?ooo`030000003oool0oooo
02<0oooo<`2W`>]a0?ooo`@000001P3oool004d0oooo0P00000T0?ooobl0Yl3[L03oool4000000X0
oooo001?0?ooo`030000003oool0oooo0280oooo:`2W`>]_0?ooo`@000003P3oool00500oooo00<0
00000?ooo`3oool08`3ooolV0:O0jfh0oooo1000000B0?ooo`00D@3oool00`000000oooo0?ooo`0S
0?ooob80Yl3[KP3oool3000001H0oooo001B0?ooo`800000903ooolN0:O0jfd0oooo1000000I0?oo
o`00E03oool00`000000oooo0?ooo`0R0?oooaL0Yl3[K`3oool4000001d0oooo001E0?ooo`030000
003oool0oooo0240oooo502W`>]^0?ooo`@000008@3oool005H0oooo00<000000?ooo`3oool08P3o
ool?0:O0jfd0oooo1000000U0?ooo`00E`3oool2000002<0oooo2`2W`>]/0?ooo`@00000:@3oool0
05T0oooo00<000000?ooo`3oool08@3oool40:O0jfl0oooo0`00000]0?ooo`00FP3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo06X0oooo1000000`0?ooo`00F`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo06H0oooo1000000d0?ooo`00G03oool200000240oooo00<0
00000?ooo`3oool0HP3oool4000003P0oooo001N0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0GP3oool4000003`0oooo001O0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0FP3oool400000400oooo001P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E`3oool3000004@0oooo001Q0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`@00000
A`3oool006<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000B`3o
ool006@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`@00000C`3oool0
06D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`170?ooo`@00000D`3oool006H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`130?ooo`@00000E`3oool006L0oooo
0P00000F0?ooo`030000003oool0oooo0400oooo0`00001K0?ooo`00J@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03`0oooo1000001N0?ooo`00JP3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03P0oooo1000001R0?ooo`00J`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo03@0oooo1000001V0?ooo`00K03oool200000100oooo00<000000?ooo`3o
ool0<@3oool4000006X0oooo001^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
;@3oool4000006h0oooo001_0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3o
ool300000780oooo001`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool4
000007D0oooo001a0?ooo`8000002`3oool00`000000oooo0?ooo`0R0?ooo`@00000N@3oool007<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000O@3oool007@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000P@3oool007D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`@00000Q@3oool007H0oooo0P000006
0?ooo`030000003oool0oooo01<0oooo0`0000290?ooo`00N03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00l0oooo1000002<0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo1000002@0?ooo`00NP3oool01@000000oooo0?ooo`3oool0000000T0
oooo1000002D0?ooo`00N`3oool2000000030?ooo`000000oooo00@0oooo1000002H0?ooo`00O@3o
ool2000000030?ooo`000000000000800000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Mtetra
.59604 .63937 .60194 .6454 .6135 .64214 .60764 .63608 Mtetra
.60764 .63608 .6135 .64214 .62511 .63886 .61928 .63278 Mtetra
.61928 .63278 .62511 .63886 .63677 .63557 .63097 .62947 Mtetra
.63097 .62947 .63677 .63557 .64848 .63227 .64272 .62615 Mtetra
.656 .752 .921 r
.64272 .62615 .64848 .63227 .66023 .62895 .65451 .62281 Mtetra
.65451 .62281 .66023 .62895 .67204 .62561 .66635 .61947 Mtetra
.656 .753 .921 r
.66635 .61947 .67204 .62561 .6839 .62227 .67824 .6161 Mtetra
.67824 .6161 .6839 .62227 .6958 .61892 .69018 .61271 Mtetra
.656 .752 .921 r
.69018 .61271 .6958 .61892 .70776 .61556 .70217 .6093 Mtetra
.656 .752 .92 r
.70217 .6093 .70776 .61556 .71976 .61217 .71421 .60589 Mtetra
.656 .751 .92 r
.71421 .60589 .71976 .61217 .73182 .60878 .7263 .60246 Mtetra
.7263 .60246 .73182 .60878 .74393 .60536 .73845 .59902 Mtetra
.73845 .59902 .74393 .60536 .75609 .60193 .75064 .59557 Mtetra
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62666 Mtetra
.61341 .62666 .61928 .63278 .63097 .62947 .62514 .62332 Mtetra
.62514 .62332 .63097 .62947 .64272 .62615 .63691 .61996 Mtetra
.63691 .61996 .64272 .62615 .65451 .62281 .64873 .61659 Mtetra
.64873 .61659 .65451 .62281 .66635 .61947 .66061 .6132 Mtetra
.656 .75 .919 r
.66061 .6132 .66635 .61947 .67824 .6161 .67253 .6098 Mtetra
.67253 .6098 .67824 .6161 .69018 .61271 .68451 .6064 Mtetra
.656 .751 .92 r
.68451 .6064 .69018 .61271 .70217 .6093 .69653 .60298 Mtetra
.69653 .60298 .70217 .6093 .71421 .60589 .70861 .59955 Mtetra
.70861 .59955 .71421 .60589 .7263 .60246 .72074 .5961 Mtetra
.72074 .5961 .7263 .60246 .73845 .59902 .73292 .59263 Mtetra
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Mtetra
.59578 .62383 .60173 .62998 .61341 .62666 .60749 .62048 Mtetra
.60749 .62048 .61341 .62666 .62514 .62332 .61925 .61712 Mtetra
.61925 .61712 .62514 .62332 .63691 .61996 .63106 .61374 Mtetra
.655 .752 .921 r
.63106 .61374 .63691 .61996 .64873 .61659 .64292 .61036 Mtetra
.64292 .61036 .64873 .61659 .66061 .6132 .65483 .60696 Mtetra
.656 .753 .921 r
.65483 .60696 .66061 .6132 .67253 .6098 .66678 .60354 Mtetra
.66678 .60354 .67253 .6098 .68451 .6064 .67879 .60009 Mtetra
.656 .752 .921 r
.67879 .60009 .68451 .6064 .69653 .60298 .69085 .59664 Mtetra
.656 .752 .92 r
.69085 .59664 .69653 .60298 .70861 .59955 .70297 .59317 Mtetra
.656 .751 .92 r
.70297 .59317 .70861 .59955 .72074 .5961 .71513 .58968 Mtetra
.71513 .58968 .72074 .5961 .73292 .59263 .72735 .58619 Mtetra
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Mtetra
.60153 .61426 .60749 .62048 .61925 .61712 .61332 .61087 Mtetra
.61332 .61087 .61925 .61712 .63106 .61374 .62516 .60746 Mtetra
.62516 .60746 .63106 .61374 .64292 .61036 .63705 .60403 Mtetra
.656 .751 .919 r
.63705 .60403 .64292 .61036 .65483 .60696 .64899 .60059 Mtetra
.656 .75 .919 r
.64899 .60059 .65483 .60696 .66678 .60354 .66099 .59714 Mtetra
.66099 .59714 .66678 .60354 .67879 .60009 .67303 .59368 Mtetra
.656 .75 .92 r
.67303 .59368 .67879 .60009 .69085 .59664 .68513 .59022 Mtetra
.656 .751 .92 r
.68513 .59022 .69085 .59664 .70297 .59317 .69728 .58673 Mtetra
.69728 .58673 .70297 .59317 .71513 .58968 .70948 .58322 Mtetra
.70948 .58322 .71513 .58968 .72735 .58619 .72173 .5797 Mtetra
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Mtetra
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Mtetra
.59552 .60799 .60153 .61426 .61332 .61087 .60734 .60457 Mtetra
.60734 .60457 .61332 .61087 .62516 .60746 .61922 .60115 Mtetra
.655 .752 .921 r
.61922 .60115 .62516 .60746 .63705 .60403 .63114 .59771 Mtetra
.63114 .59771 .63705 .60403 .64899 .60059 .64312 .59426 Mtetra
.656 .753 .921 r
.64312 .59426 .64899 .60059 .66099 .59714 .65515 .59078 Mtetra
.65515 .59078 .66099 .59714 .67303 .59368 .66723 .58728 Mtetra
.656 .752 .921 r
.66723 .58728 .67303 .59368 .68513 .59022 .67936 .58377 Mtetra
.67936 .58377 .68513 .59022 .69728 .58673 .69154 .58024 Mtetra
.656 .751 .92 r
.69154 .58024 .69728 .58673 .70948 .58322 .70378 .5767 Mtetra
.70378 .5767 .70948 .58322 .72173 .5797 .71607 .57315 Mtetra
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56959 Mtetra
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Mtetra
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Mtetra
.58946 .60167 .59552 .60799 .60734 .60457 .60132 .59822 Mtetra
.60132 .59822 .60734 .60457 .61922 .60115 .61323 .59476 Mtetra
.61323 .59476 .61922 .60115 .63114 .59771 .62519 .59127 Mtetra
.656 .75 .919 r
.62519 .59127 .63114 .59771 .64312 .59426 .6372 .58778 Mtetra
.6372 .58778 .64312 .59426 .65515 .59078 .64926 .58427 Mtetra
.64926 .58427 .65515 .59078 .66723 .58728 .66138 .58076 Mtetra
.656 .75 .92 r
.66138 .58076 .66723 .58728 .67936 .58377 .67354 .57724 Mtetra
.656 .751 .92 r
.67354 .57724 .67936 .58377 .69154 .58024 .68576 .5737 Mtetra
.68576 .5737 .69154 .58024 .70378 .5767 .69804 .57014 Mtetra
.69804 .57014 .70378 .5767 .71607 .57315 .71036 .56656 Mtetra
.71036 .56656 .71607 .57315 .72841 .56959 .72274 .56296 Mtetra
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59876 Mtetra
.57151 .59876 .57765 .6051 .58946 .60167 .58335 .5953 Mtetra
.58335 .5953 .58946 .60167 .60132 .59822 .59525 .59183 Mtetra
.59525 .59183 .60132 .59822 .61323 .59476 .60719 .58835 Mtetra
.655 .752 .921 r
.60719 .58835 .61323 .59476 .62519 .59127 .61918 .58486 Mtetra
.655 .753 .921 r
.61918 .58486 .62519 .59127 .6372 .58778 .63123 .58136 Mtetra
.656 .753 .922 r
.63123 .58136 .6372 .58778 .64926 .58427 .64333 .57782 Mtetra
.64333 .57782 .64926 .58427 .66138 .58076 .65548 .57427 Mtetra
.656 .753 .921 r
.65548 .57427 .66138 .58076 .67354 .57724 .66768 .57069 Mtetra
.656 .752 .921 r
.66768 .57069 .67354 .57724 .68576 .5737 .67994 .56711 Mtetra
.656 .751 .92 r
.67994 .56711 .68576 .5737 .69804 .57014 .69225 .56351 Mtetra
.69225 .56351 .69804 .57014 .71036 .56656 .70461 .5599 Mtetra
.70461 .5599 .71036 .56656 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Mtetra
.56532 .59236 .57151 .59876 .58335 .5953 .5772 .58888 Mtetra
.5772 .58888 .58335 .5953 .59525 .59183 .58913 .58538 Mtetra
.58913 .58538 .59525 .59183 .60719 .58835 .6011 .58186 Mtetra
.6011 .58186 .60719 .58835 .61918 .58486 .61313 .57831 Mtetra
.656 .75 .919 r
.61313 .57831 .61918 .58486 .63123 .58136 .62521 .57476 Mtetra
.656 .749 .919 r
.62521 .57476 .63123 .58136 .64333 .57782 .63735 .5712 Mtetra
.63735 .5712 .64333 .57782 .65548 .57427 .64953 .56763 Mtetra
.655 .75 .919 r
.64953 .56763 .65548 .57427 .66768 .57069 .66177 .56406 Mtetra
.656 .751 .92 r
.66177 .56406 .66768 .57069 .67994 .56711 .67407 .56046 Mtetra
.67407 .56046 .67994 .56711 .69225 .56351 .68641 .55684 Mtetra
.68641 .55684 .69225 .56351 .70461 .5599 .69881 .5532 Mtetra
.69881 .5532 .70461 .5599 .71703 .55628 .71127 .54955 Mtetra
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Mtetra
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58592 Mtetra
.55909 .58592 .56532 .59236 .5772 .58888 .571 .58241 Mtetra
.571 .58241 .5772 .58888 .58913 .58538 .58296 .57888 Mtetra
.655 .751 .92 r
.58296 .57888 .58913 .58538 .6011 .58186 .59497 .57535 Mtetra
.655 .752 .921 r
.59497 .57535 .6011 .58186 .61313 .57831 .60703 .57181 Mtetra
.655 .753 .922 r
.60703 .57181 .61313 .57831 .62521 .57476 .61915 .56825 Mtetra
.656 .754 .922 r
.61915 .56825 .62521 .57476 .63735 .5712 .63132 .56467 Mtetra
.63132 .56467 .63735 .5712 .64953 .56763 .64354 .56105 Mtetra
.656 .753 .921 r
.64354 .56105 .64953 .56763 .66177 .56406 .65582 .55741 Mtetra
.656 .752 .921 r
.65582 .55741 .66177 .56406 .67407 .56046 .66815 .55376 Mtetra
.656 .752 .92 r
.66815 .55376 .67407 .56046 .68641 .55684 .68053 .55011 Mtetra
.656 .751 .92 r
.68053 .55011 .68641 .55684 .69881 .5532 .69297 .54644 Mtetra
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Mtetra
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Mtetra
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Mtetra
.52907 .58646 .53542 .5929 .54723 .58942 .54091 .58295 Mtetra
.54091 .58295 .54723 .58942 .55909 .58592 .5528 .57943 Mtetra
.5528 .57943 .55909 .58592 .571 .58241 .56474 .57589 Mtetra
.56474 .57589 .571 .58241 .58296 .57888 .57674 .57233 Mtetra
.57674 .57233 .58296 .57888 .59497 .57535 .58878 .56875 Mtetra
.657 .751 .919 r
.58878 .56875 .59497 .57535 .60703 .57181 .60088 .56514 Mtetra
.657 .75 .918 r
.60088 .56514 .60703 .57181 .61915 .56825 .61303 .56152 Mtetra
.656 .748 .918 r
.61303 .56152 .61915 .56825 .63132 .56467 .62524 .5579 Mtetra
.655 .748 .918 r
.62524 .5579 .63132 .56467 .64354 .56105 .6375 .55428 Mtetra
.655 .749 .919 r
.6375 .55428 .64354 .56105 .65582 .55741 .64981 .55066 Mtetra
.655 .75 .92 r
.64981 .55066 .65582 .55741 .66815 .55376 .66218 .54701 Mtetra
.656 .751 .92 r
.66218 .54701 .66815 .55376 .68053 .55011 .6746 .54333 Mtetra
.6746 .54333 .68053 .55011 .69297 .54644 .68707 .53963 Mtetra
.68707 .53963 .69297 .54644 .70546 .54276 .69961 .53592 Mtetra
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53219 Mtetra
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Mtetra
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57997 Mtetra
.52266 .57997 .52907 .58646 .54091 .58295 .53454 .57643 Mtetra
.53454 .57643 .54091 .58295 .5528 .57943 .54646 .57288 Mtetra
.54646 .57288 .5528 .57943 .56474 .57589 .55844 .56931 Mtetra
.55844 .56931 .56474 .57589 .57674 .57233 .57047 .56573 Mtetra
.655 .751 .921 r
.57047 .56573 .57674 .57233 .58878 .56875 .58255 .56215 Mtetra
.655 .752 .921 r
.58255 .56215 .58878 .56875 .60088 .56514 .59469 .55856 Mtetra
.655 .754 .923 r
.59469 .55856 .60088 .56514 .61303 .56152 .60687 .55495 Mtetra
.655 .755 .923 r
.60687 .55495 .61303 .56152 .62524 .5579 .61912 .55131 Mtetra
.656 .756 .923 r
.61912 .55131 .62524 .5579 .6375 .55428 .63141 .54762 Mtetra
.657 .754 .922 r
.63141 .54762 .6375 .55428 .64981 .55066 .64376 .54391 Mtetra
.656 .753 .921 r
.64376 .54391 .64981 .55066 .66218 .54701 .65616 .5402 Mtetra
.656 .752 .92 r
.65616 .5402 .66218 .54701 .6746 .54333 .66862 .53649 Mtetra
.656 .751 .92 r
.66862 .53649 .6746 .54333 .68707 .53963 .68113 .53276 Mtetra
.68113 .53276 .68707 .53963 .69961 .53592 .6937 .52902 Mtetra
.6937 .52902 .69961 .53592 .71219 .53219 .70633 .52525 Mtetra
.70633 .52525 .71219 .53219 .72483 .52844 .71901 .52148 Mtetra
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Mtetra
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Mtetra
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Mtetra
.49255 .58051 .49907 .587 .51084 .58349 .50435 .57698 Mtetra
.50435 .57698 .51084 .58349 .52266 .57997 .51621 .57343 Mtetra
.51621 .57343 .52266 .57997 .53454 .57643 .52812 .56986 Mtetra
.52812 .56986 .53454 .57643 .54646 .57288 .54008 .56628 Mtetra
.54008 .56628 .54646 .57288 .55844 .56931 .55209 .56269 Mtetra
.656 .752 .92 r
.55209 .56269 .55844 .56931 .57047 .56573 .56415 .55908 Mtetra
.56415 .55908 .57047 .56573 .58255 .56215 .57627 .55544 Mtetra
.656 .751 .92 r
.57627 .55544 .58255 .56215 .59469 .55856 .58844 .55178 Mtetra
.656 .75 .919 r
.58844 .55178 .59469 .55856 .60687 .55495 .60066 .54811 Mtetra
.656 .748 .918 r
.60066 .54811 .60687 .55495 .61912 .55131 .61294 .54443 Mtetra
.655 .748 .918 r
.61294 .54443 .61912 .55131 .63141 .54762 .62527 .54075 Mtetra
.655 .749 .919 r
.62527 .54075 .63141 .54762 .64376 .54391 .63765 .53706 Mtetra
.656 .751 .92 r
.63765 .53706 .64376 .54391 .65616 .5402 .6501 .53334 Mtetra
.656 .752 .92 r
.6501 .53334 .65616 .5402 .66862 .53649 .66259 .5296 Mtetra
.66259 .5296 .66862 .53649 .68113 .53276 .67514 .52584 Mtetra
.656 .751 .92 r
.67514 .52584 .68113 .53276 .6937 .52902 .68775 .52206 Mtetra
.68775 .52206 .6937 .52902 .70633 .52525 .70041 .51827 Mtetra
.70041 .51827 .70633 .52525 .71901 .52148 .71313 .51446 Mtetra
.71313 .51446 .71901 .52148 .73175 .51768 .72591 .51063 Mtetra
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Mtetra
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Mtetra
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Mtetra
.47419 .57752 .48079 .58403 .49255 .58051 .48598 .57397 Mtetra
.48598 .57397 .49255 .58051 .50435 .57698 .49781 .57041 Mtetra
.49781 .57041 .50435 .57698 .51621 .57343 .5097 .56683 Mtetra
.5097 .56683 .51621 .57343 .52812 .56986 .52164 .56324 Mtetra
.655 .751 .92 r
.52164 .56324 .52812 .56986 .54008 .56628 .53364 .55964 Mtetra
.654 .751 .921 r
.53364 .55964 .54008 .56628 .55209 .56269 .54568 .55607 Mtetra
.651 .752 .924 r
.54568 .55607 .55209 .56269 .56415 .55908 .55778 .55257 Mtetra
.645 .755 .929 r
.55778 .55257 .56415 .55908 .57627 .55544 .56994 .5492 Mtetra
.641 .763 .936 r
.56994 .5492 .57627 .55544 .58844 .55178 .58215 .54589 Mtetra
.643 .776 .944 r
.58215 .54589 .58844 .55178 .60066 .54811 .59442 .54246 Mtetra
.651 .788 .947 r
.59442 .54246 .60066 .54811 .61294 .54443 .60674 .53875 Mtetra
.661 .791 .944 r
.60674 .53875 .61294 .54443 .62527 .54075 .6191 .53477 Mtetra
.666 .783 .936 r
.6191 .53477 .62527 .54075 .63765 .53706 .63152 .53067 Mtetra
.664 .77 .929 r
.63152 .53067 .63765 .53706 .6501 .53334 .64399 .52663 Mtetra
.66 .759 .923 r
.64399 .52663 .6501 .53334 .66259 .5296 .65652 .52271 Mtetra
.657 .754 .921 r
.65652 .52271 .66259 .5296 .67514 .52584 .6691 .51887 Mtetra
.656 .752 .92 r
.6691 .51887 .67514 .52584 .68775 .52206 .68175 .51505 Mtetra
.656 .751 .92 r
.68175 .51505 .68775 .52206 .70041 .51827 .69445 .51122 Mtetra
.69445 .51122 .70041 .51827 .71313 .51446 .70721 .50738 Mtetra
.70721 .50738 .71313 .51446 .72591 .51063 .72003 .50352 Mtetra
.72003 .50352 .72591 .51063 .73875 .50679 .7329 .49965 Mtetra
.7329 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Mtetra
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Mtetra
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57096 Mtetra
.46753 .57096 .47419 .57752 .48598 .57397 .47935 .56738 Mtetra
.47935 .56738 .48598 .57397 .49781 .57041 .49122 .56379 Mtetra
.49122 .56379 .49781 .57041 .5097 .56683 .50314 .56019 Mtetra
.655 .751 .921 r
.50314 .56019 .5097 .56683 .52164 .56324 .51512 .5566 Mtetra
.65 .751 .923 r
.51512 .5566 .52164 .56324 .53364 .55964 .52715 .55312 Mtetra
.636 .751 .931 r
.52715 .55312 .53364 .55964 .54568 .55607 .53923 .54999 Mtetra
.606 .756 .951 r
.53923 .54999 .54568 .55607 .55778 .55257 .55137 .54753 Mtetra
.556 .776 .981 r
.55137 .54753 .55778 .55257 .56994 .5492 .56359 .5457 Mtetra
.495 .811 1 r
.56359 .5457 .56994 .5492 .58215 .54589 .57587 .54395 Mtetra
.459 .849 .98 r
.57587 .54395 .58215 .54589 .59442 .54246 .58821 .54147 Mtetra
.494 .888 .953 r
.58821 .54147 .59442 .54246 .60674 .53875 .60059 .53775 Mtetra
.59 .928 .959 r
.60059 .53775 .60674 .53875 .6191 .53477 .61299 .53276 Mtetra
.677 .928 .971 r
.61299 .53276 .6191 .53477 .63152 .53067 .62541 .52703 Mtetra
.705 .879 .962 r
.62541 .52703 .63152 .53067 .64399 .52663 .63788 .52138 Mtetra
.692 .819 .944 r
.63788 .52138 .64399 .52663 .65652 .52271 .65041 .51637 Mtetra
.672 .778 .929 r
.65041 .51637 .65652 .52271 .6691 .51887 .66302 .51201 Mtetra
.661 .759 .923 r
.66302 .51201 .6691 .51887 .68175 .51505 .6757 .50801 Mtetra
.657 .753 .921 r
.6757 .50801 .68175 .51505 .69445 .51122 .68844 .50412 Mtetra
.656 .752 .92 r
.68844 .50412 .69445 .51122 .70721 .50738 .70124 .50024 Mtetra
.656 .751 .92 r
.70124 .50024 .70721 .50738 .72003 .50352 .7141 .49635 Mtetra
.7141 .49635 .72003 .50352 .7329 .49965 .72701 .49245 Mtetra
.72701 .49245 .7329 .49965 .74584 .49575 .73999 .48852 Mtetra
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Mtetra
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Mtetra
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56793 Mtetra
.44902 .56793 .45576 .57452 .46753 .57096 .46082 .56434 Mtetra
.46082 .56434 .46753 .57096 .47935 .56738 .47267 .56074 Mtetra
.47267 .56074 .47935 .56738 .49122 .56379 .48457 .55712 Mtetra
.655 .751 .921 r
.48457 .55712 .49122 .56379 .50314 .56019 .49653 .55352 Mtetra
.648 .75 .924 r
.49653 .55352 .50314 .56019 .51512 .5566 .50854 .55008 Mtetra
.621 .747 .937 r
.50854 .55008 .51512 .5566 .52715 .55312 .5206 .54735 Mtetra
.53 .739 .971 r
.5206 .54735 .52715 .55312 .53923 .54999 .53273 .54628 Mtetra
.257 .681 .964 r
.53273 .54628 .53923 .54999 .55137 .54753 .54494 .54738 Mtetra
.209 0 0 r
.54494 .54738 .55137 .54753 .56359 .5457 .55725 .54946 Mtetra
.359 0 0 r
.55725 .54946 .56359 .5457 .57587 .54395 .56964 .55031 Mtetra
.319 0 0 r
.56964 .55031 .57587 .54395 .58821 .54147 .58208 .5488 Mtetra
.229 0 0 r
.58208 .5488 .58821 .54147 .60059 .53775 .59454 .54506 Mtetra
.087 0 0 r
.59454 .54506 .60059 .53775 .61299 .53276 .60701 .53908 Mtetra
0 0 0 r
.60701 .53908 .61299 .53276 .62541 .52703 .61945 .53071 Mtetra
.528 .884 .656 r
.61945 .53071 .62541 .52703 .63788 .52138 .63187 .52108 Mtetra
.75 .983 .908 r
.63187 .52108 .63788 .52138 .65041 .51637 .64434 .51241 Mtetra
.734 .877 .947 r
.64434 .51241 .65041 .51637 .66302 .51201 .65692 .50591 Mtetra
.685 .792 .932 r
.65692 .50591 .66302 .51201 .6757 .50801 .66961 .5011 Mtetra
.662 .76 .923 r
.66961 .5011 .6757 .50801 .68844 .50412 .68238 .49699 Mtetra
.657 .753 .921 r
.68238 .49699 .68844 .50412 .70124 .50024 .69522 .49305 Mtetra
.656 .752 .92 r
.69522 .49305 .70124 .50024 .7141 .49635 .70812 .48912 Mtetra
.656 .751 .92 r
.70812 .48912 .7141 .49635 .72701 .49245 .72107 .48518 Mtetra
.72107 .48518 .72701 .49245 .73999 .48852 .73409 .48122 Mtetra
.73409 .48122 .73999 .48852 .75302 .48458 .74716 .47725 Mtetra
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Mtetra
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Mtetra
.43044 .5649 .43727 .57151 .44902 .56793 .44222 .56129 Mtetra
.44222 .56129 .44902 .56793 .46082 .56434 .45405 .55768 Mtetra
.45405 .55768 .46082 .56434 .47267 .56074 .46594 .55404 Mtetra
.655 .751 .92 r
.46594 .55404 .47267 .56074 .48457 .55712 .47787 .55041 Mtetra
.651 .75 .922 r
.47787 .55041 .48457 .55712 .49653 .55352 .48986 .54688 Mtetra
.626 .746 .933 r
.48986 .54688 .49653 .55352 .50854 .55008 .5019 .54402 Mtetra
.514 .723 .968 r
.5019 .54402 .50854 .55008 .5206 .54735 .51399 .54332 Mtetra
.074 .554 .899 r
.51399 .54332 .5206 .54735 .53273 .54628 .52616 .54636 Mtetra
.467 0 0 r
.52616 .54636 .53273 .54628 .54494 .54738 .53844 .5514 Mtetra
.41 0 0 r
.53844 .5514 .54494 .54738 .55725 .54946 .55081 .55298 Mtetra
0 0 0 r
.55081 .55298 .55725 .54946 .56964 .55031 .5632 .54853 Mtetra
.71 .94 .96 r
.5632 .54853 .56964 .55031 .58208 .5488 .57562 .54199 Mtetra
.653 .757 .926 r
.57562 .54199 .58208 .5488 .59454 .54506 .58812 .53823 Mtetra
.539 .714 .953 r
.58812 .53823 .59454 .54506 .60701 .53908 .60075 .53725 Mtetra
.489 .868 .978 r
.60075 .53725 .60701 .53908 .61945 .53071 .61339 .53416 Mtetra
.517 .884 .672 r
.61339 .53416 .61945 .53071 .63187 .52108 .62592 .52498 Mtetra
.69 .949 .676 r
.62592 .52498 .63187 .52108 .64434 .51241 .63834 .51228 Mtetra
.813 .99 .876 r
.63834 .51228 .64434 .51241 .65692 .50591 .65083 .50158 Mtetra
.747 .869 .936 r
.65083 .50158 .65692 .50591 .66961 .5011 .66348 .49464 Mtetra
.681 .783 .927 r
.66348 .49464 .66961 .5011 .68238 .49699 .67627 .48989 Mtetra
.66 .757 .921 r
.67627 .48989 .68238 .49699 .69522 .49305 .68914 .48581 Mtetra
.656 .752 .92 r
.68914 .48581 .69522 .49305 .70812 .48912 .70208 .48184 Mtetra
.656 .751 .92 r
.70208 .48184 .70812 .48912 .72107 .48518 .71508 .47786 Mtetra
.71508 .47786 .72107 .48518 .73409 .48122 .72814 .47387 Mtetra
.72814 .47387 .73409 .48122 .74716 .47725 .74126 .46986 Mtetra
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Mtetra
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Mtetra
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55823 Mtetra
.42355 .55823 .43044 .5649 .44222 .56129 .43536 .5546 Mtetra
.43536 .5546 .44222 .56129 .45405 .55768 .44723 .55095 Mtetra
.44723 .55095 .45405 .55768 .46594 .55404 .45915 .54729 Mtetra
.654 .751 .921 r
.45915 .54729 .46594 .55404 .47787 .55041 .47112 .54365 Mtetra
.644 .749 .925 r
.47112 .54365 .47787 .55041 .48986 .54688 .48314 .54031 Mtetra
.581 .734 .948 r
.48314 .54031 .48986 .54688 .5019 .54402 .4952 .53846 Mtetra
.272 .623 .96 r
.4952 .53846 .5019 .54402 .51399 .54332 .50731 .54071 Mtetra
.457 0 0 r
.50731 .54071 .51399 .54332 .52616 .54636 .51951 .54784 Mtetra
.52 0 0 r
.51951 .54784 .52616 .54636 .53844 .5514 .53184 .55292 Mtetra
.503 .908 .824 r
.53184 .55292 .53844 .5514 .55081 .55298 .54422 .54668 Mtetra
.859 .8 .791 r
.54422 .54668 .55081 .55298 .5632 .54853 .55656 .53161 Mtetra
.743 .622 .725 r
.55656 .53161 .5632 .54853 .57562 .54199 .5689 .51886 Mtetra
.618 .513 .713 r
.5689 .51886 .57562 .54199 .58812 .53823 .58138 .51506 Mtetra
.476 .426 .722 r
.58138 .51506 .58812 .53823 .60075 .53725 .5941 .52022 Mtetra
.362 .408 .775 r
.5941 .52022 .60075 .53725 .61339 .53416 .607 .52774 Mtetra
.547 .734 .962 r
.607 .52774 .61339 .53416 .62592 .52498 .6198 .52638 Mtetra
.831 1 .813 r
.6198 .52638 .62592 .52498 .63834 .51228 .63231 .51358 Mtetra
.881 .992 .789 r
.63231 .51358 .63834 .51228 .65083 .50158 .64474 .49868 Mtetra
.823 .922 .901 r
.64474 .49868 .65083 .50158 .66348 .49464 .65733 .48869 Mtetra
.713 .81 .925 r
.65733 .48869 .66348 .49464 .67627 .48989 .67012 .48284 Mtetra
.667 .763 .922 r
.67012 .48284 .67627 .48989 .68914 .48581 .68302 .47852 Mtetra
.657 .753 .92 r
.68302 .47852 .68914 .48581 .70208 .48184 .696 .47449 Mtetra
.656 .751 .92 r
.696 .47449 .70208 .48184 .71508 .47786 .70904 .47048 Mtetra
.70904 .47048 .71508 .47786 .72814 .47387 .72214 .46645 Mtetra
.72214 .46645 .72814 .47387 .74126 .46986 .7353 .4624 Mtetra
.7353 .4624 .74126 .46986 .75443 .46583 .74852 .45834 Mtetra
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Mtetra
.40481 .55516 .41179 .56185 .42355 .55823 .41661 .55152 Mtetra
.41661 .55152 .42355 .55823 .43536 .5546 .42845 .54786 Mtetra
.42845 .54786 .43536 .5546 .44723 .55095 .44035 .54418 Mtetra
.44035 .54418 .44723 .55095 .45915 .54729 .45231 .54049 Mtetra
.653 .751 .921 r
.45231 .54049 .45915 .54729 .47112 .54365 .46431 .53685 Mtetra
.636 .746 .928 r
.46431 .53685 .47112 .54365 .48314 .54031 .47636 .53369 Mtetra
.528 .713 .957 r
.47636 .53369 .48314 .54031 .4952 .53846 .48844 .53288 Mtetra
0 .436 .855 r
.48844 .53288 .4952 .53846 .50731 .54071 .50056 .53807 Mtetra
.662 .11 0 r
.50056 .53807 .50731 .54071 .51951 .54784 .51277 .54912 Mtetra
.517 0 0 r
.51277 .54912 .51951 .54784 .53184 .55292 .52515 .55431 Mtetra
.848 .996 .83 r
.52515 .55431 .53184 .55292 .54422 .54668 .53758 .5416 Mtetra
.916 .808 .726 r
.53758 .5416 .54422 .54668 .55656 .53161 .54992 .5186 Mtetra
.806 .685 .73 r
.54992 .5186 .55656 .53161 .5689 .51886 .56225 .5018 Mtetra
.632 .565 .761 r
.56225 .5018 .5689 .51886 .58138 .51506 .57473 .49797 Mtetra
.301 .369 .766 r
.57473 .49797 .58138 .51506 .5941 .52022 .58751 .50713 Mtetra
0 .125 .674 r
.58751 .50713 .5941 .52022 .607 .52774 .60059 .52254 Mtetra
0 .46 .865 r
.60059 .52254 .607 .52774 .6198 .52638 .6136 .52764 Mtetra
.838 .999 .817 r
.6136 .52764 .6198 .52638 .63231 .51358 .6262 .51467 Mtetra
.937 .962 .746 r
.6262 .51467 .63231 .51358 .64474 .49868 .63857 .49575 Mtetra
.875 .912 .851 r
.63857 .49575 .64474 .49868 .65733 .48869 .65112 .48272 Mtetra
.743 .818 .91 r
.65112 .48272 .65733 .48869 .67012 .48284 .66391 .47575 Mtetra
.674 .765 .919 r
.66391 .47575 .67012 .48284 .68302 .47852 .67685 .47117 Mtetra
.658 .753 .92 r
.67685 .47117 .68302 .47852 .696 .47449 .68986 .46707 Mtetra
.656 .752 .92 r
.68986 .46707 .696 .47449 .70904 .47048 .70294 .46303 Mtetra
.656 .751 .92 r
.70294 .46303 .70904 .47048 .72214 .46645 .71609 .45897 Mtetra
.71609 .45897 .72214 .46645 .7353 .4624 .72929 .45489 Mtetra
.72929 .45489 .7353 .4624 .74852 .45834 .74255 .45079 Mtetra
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Mtetra
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43838 Mtetra
.78271 .43838 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Mtetra
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Mtetra
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54474 Mtetra
.40961 .54474 .41661 .55152 .42845 .54786 .42149 .54105 Mtetra
.42149 .54105 .42845 .54786 .44035 .54418 .43342 .53735 Mtetra
.43342 .53735 .44035 .54418 .45231 .54049 .44541 .53363 Mtetra
.653 .751 .921 r
.44541 .53363 .45231 .54049 .46431 .53685 .45744 .52997 Mtetra
.631 .744 .929 r
.45744 .52997 .46431 .53685 .47636 .53369 .46953 .52691 Mtetra
.492 .694 .958 r
.46953 .52691 .47636 .53369 .48844 .53288 .48163 .52676 Mtetra
0 .288 .752 r
.48163 .52676 .48844 .53288 .50056 .53807 .49374 .53418 Mtetra
.752 .238 0 r
.49374 .53418 .50056 .53807 .51277 .54912 .50595 .54937 Mtetra
.62 .063 0 r
.50595 .54937 .51277 .54912 .52515 .55431 .51836 .55752 Mtetra
.863 .994 .754 r
.51836 .55752 .52515 .55431 .53758 .5416 .53088 .54207 Mtetra
.975 .865 .667 r
.53088 .54207 .53758 .5416 .54992 .5186 .54329 .51172 Mtetra
.898 .781 .723 r
.54329 .51172 .54992 .5186 .56225 .5018 .55562 .4891 Mtetra
.645 .624 .815 r
.55562 .4891 .56225 .5018 .57473 .49797 .56812 .48523 Mtetra
0 .123 .673 r
.56812 .48523 .57473 .49797 .58751 .50713 .58099 .50016 Mtetra
.786 .323 0 r
.58099 .50016 .58751 .50713 .60059 .52254 .59423 .52292 Mtetra
.583 .014 0 r
.59423 .52292 .60059 .52254 .6136 .52764 .60736 .53072 Mtetra
.853 .99 .729 r
.60736 .53072 .6136 .52764 .6262 .51467 .61996 .51471 Mtetra
.963 .915 .714 r
.61996 .51471 .6262 .51467 .63857 .49575 .6323 .49154 Mtetra
.89 .869 .811 r
.6323 .49154 .63857 .49575 .65112 .48272 .64483 .47619 Mtetra
.757 .805 .891 r
.64483 .47619 .65112 .48272 .66391 .47575 .65765 .46849 Mtetra
.678 .763 .916 r
.65765 .46849 .66391 .47575 .67685 .47117 .67062 .46374 Mtetra
.658 .753 .92 r
.67062 .46374 .67685 .47117 .68986 .46707 .68368 .4596 Mtetra
.656 .751 .92 r
.68368 .4596 .68986 .46707 .70294 .46303 .6968 .45552 Mtetra
.6968 .45552 .70294 .46303 .71609 .45897 .70998 .45142 Mtetra
.70998 .45142 .71609 .45897 .72929 .45489 .72323 .4473 Mtetra
.72323 .4473 .72929 .45489 .74255 .45079 .73653 .44317 Mtetra
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Mtetra
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43838 .77683 .43065 Mtetra
.77683 .43065 .78271 .43838 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Mtetra
.39069 .54162 .39778 .54842 .40961 .54474 .40255 .53792 Mtetra
.40255 .53792 .40961 .54474 .42149 .54105 .41447 .5342 Mtetra
.41447 .5342 .42149 .54105 .43342 .53735 .42643 .53046 Mtetra
.42643 .53046 .43342 .53735 .44541 .53363 .43845 .52671 Mtetra
.653 .751 .921 r
.43845 .52671 .44541 .53363 .45744 .52997 .45052 .52302 Mtetra
.63 .743 .93 r
.45052 .52302 .45744 .52997 .46953 .52691 .46264 .51997 Mtetra
.482 .686 .957 r
.46264 .51997 .46953 .52691 .48163 .52676 .47476 .52002 Mtetra
0 .243 .727 r
.47476 .52002 .48163 .52676 .49374 .53418 .48688 .52837 Mtetra
.765 .274 0 r
.48688 .52837 .49374 .53418 .50595 .54937 .49907 .54611 Mtetra
.691 .151 0 r
.49907 .54611 .50595 .54937 .51836 .55752 .51149 .55876 Mtetra
.791 .997 .856 r
.51149 .55876 .51836 .55752 .53088 .54207 .5241 .5479 Mtetra
.965 .933 .622 r
.5241 .5479 .53088 .54207 .54329 .51172 .53665 .51981 Mtetra
.832 .927 .544 r
.53665 .51981 .54329 .51172 .55562 .4891 .54912 .49736 Mtetra
.239 0 0 r
.54912 .49736 .55562 .4891 .56812 .48523 .56171 .49348 Mtetra
.737 .32 .257 r
.56171 .49348 .56812 .48523 .58099 .50016 .57464 .50821 Mtetra
.787 .382 .285 r
.57464 .50821 .58099 .50016 .59423 .52292 .58788 .52866 Mtetra
.499 0 0 r
.58788 .52866 .59423 .52292 .60736 .53072 .60098 .5318 Mtetra
.949 .949 .734 r
.60098 .5318 .60736 .53072 .61996 .51471 .61356 .5112 Mtetra
.948 .843 .705 r
.61356 .5112 .61996 .51471 .6323 .49154 .62591 .48538 Mtetra
.878 .82 .787 r
.62591 .48538 .6323 .49154 .64483 .47619 .63847 .46903 Mtetra
.758 .789 .879 r
.63847 .46903 .64483 .47619 .65765 .46849 .65132 .46106 Mtetra
.679 .761 .913 r
.65132 .46106 .65765 .46849 .67062 .46374 .66434 .45624 Mtetra
.659 .753 .919 r
.66434 .45624 .67062 .46374 .68368 .4596 .67744 .45206 Mtetra
.656 .751 .92 r
.67744 .45206 .68368 .4596 .6968 .45552 .6906 .44794 Mtetra
.6906 .44794 .6968 .45552 .70998 .45142 .70382 .44381 Mtetra
.70382 .44381 .70998 .45142 .72323 .4473 .71711 .43966 Mtetra
.71711 .43966 .72323 .4473 .73653 .44317 .73046 .43549 Mtetra
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Mtetra
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Mtetra
.38355 .53477 .39069 .54162 .40255 .53792 .39544 .53103 Mtetra
.39544 .53103 .40255 .53792 .41447 .5342 .40739 .52728 Mtetra
.40739 .52728 .41447 .5342 .42643 .53046 .41938 .52351 Mtetra
.41938 .52351 .42643 .53046 .43845 .52671 .43144 .51973 Mtetra
.653 .751 .921 r
.43144 .51973 .43845 .52671 .45052 .52302 .44354 .51602 Mtetra
.629 .743 .93 r
.44354 .51602 .45052 .52302 .46264 .51997 .45569 .51295 Mtetra
.479 .684 .957 r
.45569 .51295 .46264 .51997 .47476 .52002 .46784 .51304 Mtetra
0 .239 .727 r
.46784 .51304 .47476 .52002 .48688 .52837 .47997 .52154 Mtetra
.745 .262 0 r
.47997 .52154 .48688 .52837 .49907 .54611 .49214 .53966 Mtetra
.588 .078 0 r
.49214 .53966 .49907 .54611 .51149 .55876 .50456 .55319 Mtetra
.788 .828 .883 r
.50456 .55319 .51149 .55876 .5241 .5479 .51723 .54423 Mtetra
.936 .828 .713 r
.51723 .54423 .5241 .5479 .53665 .51981 .52988 .51887 Mtetra
.943 .903 .755 r
.52988 .51887 .53665 .51981 .54912 .49736 .54246 .49852 Mtetra
.3 .794 .779 r
.54246 .49852 .54912 .49736 .56171 .49348 .55513 .49462 Mtetra
.73 .222 .012 r
.55513 .49462 .56171 .49348 .57464 .50821 .56806 .5072 Mtetra
.797 .306 .019 r
.56806 .5072 .57464 .50821 .58788 .52866 .58127 .52484 Mtetra
.237 .676 .957 r
.58127 .52484 .58788 .52866 .60098 .5318 .59436 .52601 Mtetra
.911 .816 .74 r
.59436 .52601 .60098 .5318 .61356 .5112 .607 .50445 Mtetra
.92 .792 .702 r
.607 .50445 .61356 .5112 .62591 .48538 .61942 .47819 Mtetra
.869 .798 .779 r
.61942 .47819 .62591 .48538 .63847 .46903 .63205 .46161 Mtetra
.758 .784 .874 r
.63205 .46161 .63847 .46903 .65132 .46106 .64494 .45354 Mtetra
.679 .76 .912 r
.64494 .45354 .65132 .46106 .66434 .45624 .658 .44867 Mtetra
.659 .752 .919 r
.658 .44867 .66434 .45624 .67744 .45206 .67114 .44445 Mtetra
.656 .751 .92 r
.67114 .44445 .67744 .45206 .6906 .44794 .68435 .4403 Mtetra
.68435 .4403 .6906 .44794 .70382 .44381 .69761 .43613 Mtetra
.69761 .43613 .70382 .44381 .71711 .43966 .71095 .43194 Mtetra
.71095 .43194 .71711 .43966 .73046 .43549 .72434 .42774 Mtetra
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Mtetra
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40207 Mtetra
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Mtetra
.37634 .52786 .38355 .53477 .39544 .53103 .38827 .52409 Mtetra
.38827 .52409 .39544 .53103 .40739 .52728 .40025 .52031 Mtetra
.40025 .52031 .40739 .52728 .41938 .52351 .41228 .51651 Mtetra
.41228 .51651 .41938 .52351 .43144 .51973 .42437 .5127 Mtetra
.653 .75 .921 r
.42437 .5127 .43144 .51973 .44354 .51602 .43651 .50896 Mtetra
.629 .743 .93 r
.43651 .50896 .44354 .51602 .45569 .51295 .44869 .50587 Mtetra
.475 .683 .957 r
.44869 .50587 .45569 .51295 .46784 .51304 .46086 .50599 Mtetra
0 .231 .721 r
.46086 .50599 .46784 .51304 .47997 .52154 .47299 .51461 Mtetra
.745 .262 0 r
.47299 .51461 .47997 .52154 .49214 .53966 .48516 .5328 Mtetra
.557 .053 0 r
.48516 .5328 .49214 .53966 .50456 .55319 .49759 .54612 Mtetra
.785 .788 .855 r
.49759 .54612 .50456 .55319 .51723 .54423 .5103 .53666 Mtetra
.902 .769 .705 r
.5103 .53666 .51723 .54423 .52988 .51887 .52304 .5108 Mtetra
.878 .768 .737 r
.52304 .5108 .52988 .51887 .54246 .49852 .53569 .49017 Mtetra
.654 .723 .899 r
.53569 .49017 .54246 .49852 .55513 .49462 .54838 .48623 Mtetra
0 .075 .607 r
.54838 .48623 .55513 .49462 .56806 .5072 .56132 .49902 Mtetra
.629 .161 0 r
.56132 .49902 .56806 .5072 .58127 .52484 .57453 .5171 Mtetra
.403 .634 .948 r
.57453 .5171 .58127 .52484 .59436 .52601 .58766 .5187 Mtetra
.895 .79 .737 r
.58766 .5187 .59436 .52601 .607 .50445 .60038 .49729 Mtetra
.917 .786 .701 r
.60038 .49729 .607 .50445 .61942 .47819 .61288 .47089 Mtetra
.869 .797 .777 r
.61288 .47089 .61942 .47819 .63205 .46161 .62557 .45413 Mtetra
.759 .784 .874 r
.62557 .45413 .63205 .46161 .64494 .45354 .63851 .44596 Mtetra
.679 .76 .912 r
.63851 .44596 .64494 .45354 .658 .44867 .65161 .44104 Mtetra
.659 .753 .919 r
.65161 .44104 .658 .44867 .67114 .44445 .66479 .43678 Mtetra
.656 .751 .92 r
.66479 .43678 .67114 .44445 .68435 .4403 .67804 .43259 Mtetra
.67804 .43259 .68435 .4403 .69761 .43613 .69135 .42838 Mtetra
.69135 .42838 .69761 .43613 .71095 .43194 .70472 .42416 Mtetra
.70472 .42416 .71095 .43194 .72434 .42774 .71816 .41992 Mtetra
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Mtetra
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40207 .80014 .39403 Mtetra
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Mtetra
.33352 .53219 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Mtetra
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .52089 Mtetra
.36908 .52089 .37634 .52786 .38827 .52409 .38104 .5171 Mtetra
.38104 .5171 .38827 .52409 .40025 .52031 .39305 .51328 Mtetra
.39305 .51328 .40025 .52031 .41228 .51651 .40512 .50945 Mtetra
.40512 .50945 .41228 .51651 .42437 .5127 .41724 .50561 Mtetra
.653 .75 .921 r
.41724 .50561 .42437 .5127 .43651 .50896 .42941 .50184 Mtetra
.628 .743 .93 r
.42941 .50184 .43651 .50896 .44869 .50587 .44162 .49874 Mtetra
.472 .681 .957 r
.44162 .49874 .44869 .50587 .46086 .50599 .45383 .49889 Mtetra
0 .223 .714 r
.45383 .49889 .46086 .50599 .47299 .51461 .46596 .50762 Mtetra
.747 .264 0 r
.46596 .50762 .47299 .51461 .48516 .5328 .47812 .52587 Mtetra
.549 .045 0 r
.47812 .52587 .48516 .5328 .49759 .54612 .49055 .53905 Mtetra
.787 .79 .854 r
.49055 .53905 .49759 .54612 .5103 .53666 .50331 .5294 Mtetra
.905 .775 .706 r
.50331 .5294 .5103 .53666 .52304 .5108 .51613 .5036 Mtetra
.886 .784 .742 r
.51613 .5036 .52304 .5108 .53569 .49017 .52885 .48313 Mtetra
.653 .762 .93 r
.52885 .48313 .53569 .49017 .54838 .48623 .54159 .47916 Mtetra
0 .032 .539 r
.54159 .47916 .54838 .48623 .56132 .49902 .55454 .49172 Mtetra
.669 .186 0 r
.55454 .49172 .56132 .49902 .57453 .5171 .56774 .50967 Mtetra
.382 .635 .954 r
.56774 .50967 .57453 .5171 .58766 .5187 .5809 .5114 Mtetra
.895 .791 .739 r
.5809 .5114 .58766 .5187 .60038 .49729 .5937 .49007 Mtetra
.918 .786 .7 r
.5937 .49007 .60038 .49729 .61288 .47089 .60628 .46353 Mtetra
.87 .797 .776 r
.60628 .46353 .61288 .47089 .62557 .45413 .61903 .44659 Mtetra
.76 .785 .873 r
.61903 .44659 .62557 .45413 .63851 .44596 .63202 .43831 Mtetra
.68 .76 .912 r
.63202 .43831 .63851 .44596 .65161 .44104 .64516 .43334 Mtetra
.659 .753 .919 r
.64516 .43334 .65161 .44104 .66479 .43678 .65839 .42904 Mtetra
.656 .751 .92 r
.65839 .42904 .66479 .43678 .67804 .43259 .67168 .42481 Mtetra
.67168 .42481 .67804 .43259 .69135 .42838 .68503 .42057 Mtetra
.68503 .42057 .69135 .42838 .70472 .42416 .69845 .41631 Mtetra
.69845 .41631 .70472 .42416 .71816 .41992 .71193 .41203 Mtetra
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Mtetra
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52525 Mtetra
.32609 .52525 .33352 .53219 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Mtetra
.34981 .51768 .35717 .52467 .36908 .52089 .36175 .51387 Mtetra
.36175 .51387 .36908 .52089 .38104 .5171 .37374 .51004 Mtetra
.37374 .51004 .38104 .5171 .39305 .51328 .38579 .5062 Mtetra
.38579 .5062 .39305 .51328 .40512 .50945 .39789 .50233 Mtetra
.39789 .50233 .40512 .50945 .41724 .50561 .41005 .49846 Mtetra
.653 .75 .922 r
.41005 .49846 .41724 .50561 .42941 .50184 .42226 .49466 Mtetra
.627 .743 .93 r
.42226 .49466 .42941 .50184 .44162 .49874 .4345 .49154 Mtetra
.468 .679 .957 r
.4345 .49154 .44162 .49874 .45383 .49889 .44673 .49174 Mtetra
0 .214 .705 r
.44673 .49174 .45383 .49889 .46596 .50762 .45887 .50059 Mtetra
.749 .266 0 r
.45887 .50059 .46596 .50762 .47812 .52587 .47101 .51891 Mtetra
.539 .035 0 r
.47101 .51891 .47812 .52587 .49055 .53905 .48345 .53189 Mtetra
.792 .789 .85 r
.48345 .53189 .49055 .53905 .50331 .5294 .49627 .52185 Mtetra
.904 .771 .705 r
.49627 .52185 .50331 .5294 .51613 .5036 .50917 .49581 Mtetra
.881 .775 .74 r
.50917 .49581 .51613 .5036 .52885 .48313 .52196 .47529 Mtetra
.654 .74 .913 r
.52196 .47529 .52885 .48313 .54159 .47916 .53474 .47128 Mtetra
0 .063 .585 r
.53474 .47128 .54159 .47916 .55454 .49172 .54769 .48383 Mtetra
.651 .176 0 r
.54769 .48383 .55454 .49172 .56774 .50967 .56088 .50196 Mtetra
.368 .62 .949 r
.56088 .50196 .56774 .50967 .5809 .5114 .57408 .504 Mtetra
.894 .791 .74 r
.57408 .504 .5809 .5114 .5937 .49007 .58695 .4828 Mtetra
.918 .786 .7 r
.58695 .4828 .5937 .49007 .60628 .46353 .59963 .45612 Mtetra
.871 .797 .775 r
.59963 .45612 .60628 .46353 .61903 .44659 .61244 .43899 Mtetra
.761 .785 .872 r
.61244 .43899 .61903 .44659 .63202 .43831 .62548 .4306 Mtetra
.68 .761 .912 r
.62548 .4306 .63202 .43831 .64516 .43334 .63866 .42557 Mtetra
.659 .753 .919 r
.63866 .42557 .64516 .43334 .65839 .42904 .65193 .42123 Mtetra
.656 .751 .92 r
.65193 .42123 .65839 .42904 .67168 .42481 .66526 .41697 Mtetra
.66526 .41697 .67168 .42481 .68503 .42057 .67866 .41269 Mtetra
.67866 .41269 .68503 .42057 .69845 .41631 .69212 .40839 Mtetra
.69212 .40839 .69845 .41631 .71193 .41203 .70564 .40407 Mtetra
.70564 .40407 .71193 .41203 .72548 .40773 .71923 .39974 Mtetra
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Mtetra
.35437 .50679 .36175 .51387 .37374 .51004 .36639 .50293 Mtetra
.36639 .50293 .37374 .51004 .38579 .5062 .37847 .49905 Mtetra
.37847 .49905 .38579 .5062 .39789 .50233 .39061 .49515 Mtetra
.39061 .49515 .39789 .50233 .41005 .49846 .4028 .49125 Mtetra
.652 .75 .922 r
.4028 .49125 .41005 .49846 .42226 .49466 .41504 .48742 Mtetra
.627 .742 .93 r
.41504 .48742 .42226 .49466 .4345 .49154 .42732 .48429 Mtetra
.463 .677 .957 r
.42732 .48429 .4345 .49154 .44673 .49174 .43957 .48454 Mtetra
0 .204 .697 r
.43957 .48454 .44673 .49174 .45887 .50059 .45172 .49351 Mtetra
.75 .268 0 r
.45172 .49351 .45887 .50059 .47101 .51891 .46385 .51191 Mtetra
.529 .025 0 r
.46385 .51191 .47101 .51891 .48345 .53189 .47629 .52468 Mtetra
.797 .79 .846 r
.47629 .52468 .48345 .53189 .49627 .52185 .48916 .51429 Mtetra
.905 .772 .704 r
.48916 .51429 .49627 .52185 .50917 .49581 .50215 .4881 Mtetra
.882 .777 .742 r
.50215 .4881 .50917 .49581 .52196 .47529 .51502 .4676 Mtetra
.654 .747 .918 r
.51502 .4676 .52196 .47529 .53474 .47128 .52783 .46356 Mtetra
0 .059 .577 r
.52783 .46356 .53474 .47128 .54769 .48383 .54078 .47601 Mtetra
.66 .182 0 r
.54078 .47601 .54769 .48383 .56088 .50196 .55397 .49422 Mtetra
.347 .61 .948 r
.55397 .49422 .56088 .50196 .57408 .504 .5672 .49655 Mtetra
.893 .792 .742 r
.5672 .49655 .57408 .504 .58695 .4828 .58015 .47548 Mtetra
.918 .787 .7 r
.58015 .47548 .58695 .4828 .59963 .45612 .59291 .44866 Mtetra
.872 .798 .774 r
.59291 .44866 .59963 .45612 .61244 .43899 .60579 .43133 Mtetra
.763 .785 .872 r
.60579 .43133 .61244 .43899 .62548 .4306 .61887 .42283 Mtetra
.681 .761 .912 r
.61887 .42283 .62548 .4306 .63866 .42557 .6321 .41773 Mtetra
.659 .753 .919 r
.6321 .41773 .63866 .42557 .65193 .42123 .64541 .41336 Mtetra
.656 .751 .92 r
.64541 .41336 .65193 .42123 .66526 .41697 .65879 .40906 Mtetra
.65879 .40906 .66526 .41697 .67866 .41269 .67223 .40474 Mtetra
.67223 .40474 .67866 .41269 .69212 .40839 .68573 .40041 Mtetra
.68573 .40041 .69212 .40839 .70564 .40407 .6993 .39605 Mtetra
.6993 .39605 .70564 .40407 .71923 .39974 .71294 .39167 Mtetra
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Mtetra
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Mtetra
.34692 .49965 .35437 .50679 .36639 .50293 .35898 .49575 Mtetra
.35898 .49575 .36639 .50293 .37847 .49905 .37109 .49184 Mtetra
.37109 .49184 .37847 .49905 .39061 .49515 .38326 .48791 Mtetra
.38326 .48791 .39061 .49515 .4028 .49125 .39549 .48398 Mtetra
.652 .75 .922 r
.39549 .48398 .4028 .49125 .41504 .48742 .40776 .48011 Mtetra
.626 .742 .931 r
.40776 .48011 .41504 .48742 .42732 .48429 .42007 .47698 Mtetra
.459 .675 .958 r
.42007 .47698 .42732 .48429 .43957 .48454 .43235 .47728 Mtetra
0 .194 .688 r
.43235 .47728 .43957 .48454 .45172 .49351 .4445 .48638 Mtetra
.752 .27 0 r
.4445 .48638 .45172 .49351 .46385 .51191 .45662 .50486 Mtetra
.518 .013 0 r
.45662 .50486 .46385 .51191 .47629 .52468 .46906 .51742 Mtetra
.801 .791 .843 r
.46906 .51742 .47629 .52468 .48916 .51429 .48199 .50671 Mtetra
.905 .773 .704 r
.48199 .50671 .48916 .51429 .50215 .4881 .49507 .48044 Mtetra
.882 .78 .743 r
.49507 .48044 .50215 .4881 .51502 .4676 .50801 .46003 Mtetra
.653 .752 .922 r
.50801 .46003 .51502 .4676 .52783 .46356 .52086 .45596 Mtetra
0 .06 .575 r
.52086 .45596 .52783 .46356 .54078 .47601 .53381 .46824 Mtetra
.665 .186 0 r
.53381 .46824 .54078 .47601 .55397 .49422 .547 .48646 Mtetra
.327 .6 .946 r
.547 .48646 .55397 .49422 .5672 .49655 .56026 .48904 Mtetra
.892 .792 .744 r
.56026 .48904 .5672 .49655 .58015 .47548 .57329 .46811 Mtetra
.919 .787 .699 r
.57329 .46811 .58015 .47548 .59291 .44866 .58614 .44115 Mtetra
.874 .798 .772 r
.58614 .44115 .59291 .44866 .60579 .43133 .59908 .42361 Mtetra
.765 .786 .871 r
.59908 .42361 .60579 .43133 .61887 .42283 .61221 .41498 Mtetra
.682 .761 .911 r
.61221 .41498 .61887 .42283 .6321 .41773 .62548 .40983 Mtetra
.659 .753 .919 r
.62548 .40983 .6321 .41773 .64541 .41336 .63884 .40541 Mtetra
.656 .751 .92 r
.63884 .40541 .64541 .41336 .65879 .40906 .65226 .40107 Mtetra
.65226 .40107 .65879 .40906 .67223 .40474 .66574 .39672 Mtetra
.66574 .39672 .67223 .40474 .68573 .40041 .67929 .39235 Mtetra
.67929 .39235 .68573 .40041 .6993 .39605 .69291 .38795 Mtetra
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Mtetra
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Mtetra
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Mtetra
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Mtetra
.33941 .49245 .34692 .49965 .35898 .49575 .3515 .48852 Mtetra
.3515 .48852 .35898 .49575 .37109 .49184 .36365 .48458 Mtetra
.36365 .48458 .37109 .49184 .38326 .48791 .37585 .48061 Mtetra
.37585 .48061 .38326 .48791 .39549 .48398 .38811 .47664 Mtetra
.652 .75 .922 r
.38811 .47664 .39549 .48398 .40776 .48011 .40042 .47275 Mtetra
.625 .742 .931 r
.40042 .47275 .40776 .48011 .42007 .47698 .41277 .4696 Mtetra
.454 .673 .958 r
.41277 .4696 .42007 .47698 .43235 .47728 .42507 .46996 Mtetra
0 .183 .678 r
.42507 .46996 .43235 .47728 .4445 .48638 .43722 .47922 Mtetra
.754 .272 0 r
.43722 .47922 .4445 .48638 .45662 .50486 .44932 .49777 Mtetra
.504 0 0 r
.44932 .49777 .45662 .50486 .46906 .51742 .46177 .51006 Mtetra
.807 .79 .837 r
.46177 .51006 .46906 .51742 .48199 .50671 .47477 .49884 Mtetra
.904 .769 .702 r
.47477 .49884 .48199 .50671 .49507 .48044 .48793 .47221 Mtetra
.878 .771 .741 r
.48793 .47221 .49507 .48044 .50801 .46003 .50094 .45168 Mtetra
.654 .732 .907 r
.50094 .45168 .50801 .46003 .52086 .45596 .51383 .44757 Mtetra
0 .084 .61 r
.51383 .44757 .52086 .45596 .53381 .46824 .52679 .4599 Mtetra
.651 .181 0 r
.52679 .4599 .53381 .46824 .547 .48646 .53997 .4784 Mtetra
.306 .581 .938 r
.53997 .4784 .547 .48646 .56026 .48904 .55326 .48142 Mtetra
.89 .792 .746 r
.55326 .48142 .56026 .48904 .57329 .46811 .56637 .46071 Mtetra
.919 .787 .699 r
.56637 .46071 .57329 .46811 .58614 .44115 .5793 .4336 Mtetra
.875 .798 .771 r
.5793 .4336 .58614 .44115 .59908 .42361 .59231 .41584 Mtetra
.766 .787 .87 r
.59231 .41584 .59908 .42361 .61221 .41498 .60549 .40707 Mtetra
.682 .761 .911 r
.60549 .40707 .61221 .41498 .62548 .40983 .61881 .40186 Mtetra
.659 .753 .919 r
.61881 .40186 .62548 .40983 .63884 .40541 .6322 .3974 Mtetra
.656 .751 .92 r
.6322 .3974 .63884 .40541 .65226 .40107 .64567 .39302 Mtetra
.64567 .39302 .65226 .40107 .66574 .39672 .6592 .38863 Mtetra
.6592 .38863 .66574 .39672 .67929 .39235 .67279 .38422 Mtetra
.67279 .38422 .67929 .39235 .69291 .38795 .68645 .37978 Mtetra
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Mtetra
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Mtetra
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48518 Mtetra
.33184 .48518 .33941 .49245 .3515 .48852 .34396 .48122 Mtetra
.34396 .48122 .3515 .48852 .36365 .48458 .35615 .47725 Mtetra
.35615 .47725 .36365 .48458 .37585 .48061 .36838 .47325 Mtetra
.36838 .47325 .37585 .48061 .38811 .47664 .38068 .46925 Mtetra
.652 .75 .922 r
.38068 .46925 .38811 .47664 .40042 .47275 .39302 .46533 Mtetra
.624 .742 .931 r
.39302 .46533 .40042 .47275 .41277 .4696 .4054 .46217 Mtetra
.448 .671 .958 r
.4054 .46217 .41277 .4696 .42507 .46996 .41772 .46259 Mtetra
0 .172 .668 r
.41772 .46259 .42507 .46996 .43722 .47922 .42988 .472 Mtetra
.755 .274 0 r
.42988 .472 .43722 .47922 .44932 .49777 .44196 .49061 Mtetra
0 .013 .509 r
.44196 .49061 .44932 .49777 .46177 .51006 .45442 .50269 Mtetra
.809 .792 .836 r
.45442 .50269 .46177 .51006 .47477 .49884 .46747 .49128 Mtetra
.906 .775 .705 r
.46747 .49128 .47477 .49884 .48793 .47221 .48073 .46484 Mtetra
.885 .787 .748 r
.48073 .46484 .48793 .47221 .50094 .45168 .49381 .44463 Mtetra
.652 .77 .935 r
.49381 .44463 .50094 .45168 .51383 .44757 .50674 .44048 Mtetra
0 .054 .555 r
.50674 .44048 .51383 .44757 .52679 .4599 .5197 .45243 Mtetra
.682 .197 0 r
.5197 .45243 .52679 .4599 .53997 .4784 .53287 .47066 Mtetra
.279 .578 .94 r
.53287 .47066 .53997 .4784 .55326 .48142 .54619 .4738 Mtetra
.889 .793 .748 r
.54619 .4738 .55326 .48142 .56637 .46071 .55938 .45322 Mtetra
.919 .787 .699 r
.55938 .45322 .56637 .46071 .5793 .4336 .57241 .42598 Mtetra
.876 .798 .77 r
.57241 .42598 .5793 .4336 .59231 .41584 .58548 .40799 Mtetra
.768 .787 .869 r
.58548 .40799 .59231 .41584 .60549 .40707 .59872 .39909 Mtetra
.683 .762 .911 r
.59872 .39909 .60549 .40707 .61881 .40186 .61207 .39382 Mtetra
.659 .753 .919 r
.61207 .39382 .61881 .40186 .6322 .3974 .62551 .38931 Mtetra
.656 .752 .92 r
.62551 .38931 .6322 .3974 .64567 .39302 .63902 .3849 Mtetra
.656 .751 .92 r
.63902 .3849 .64567 .39302 .6592 .38863 .65259 .38046 Mtetra
.65259 .38046 .6592 .38863 .67279 .38422 .66623 .37601 Mtetra
.66623 .37601 .67279 .38422 .68645 .37978 .67994 .37154 Mtetra
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Mtetra
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34884 Mtetra
.74947 .34884 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48184 Mtetra
.31209 .48184 .31977 .48912 .33184 .48518 .3242 .47786 Mtetra
.3242 .47786 .33184 .48518 .34396 .48122 .33636 .47387 Mtetra
.33636 .47387 .34396 .48122 .35615 .47725 .34858 .46986 Mtetra
.34858 .46986 .35615 .47725 .36838 .47325 .36085 .46583 Mtetra
.655 .751 .92 r
.36085 .46583 .36838 .47325 .38068 .46925 .37318 .46179 Mtetra
.652 .75 .922 r
.37318 .46179 .38068 .46925 .39302 .46533 .38556 .45784 Mtetra
.623 .741 .932 r
.38556 .45784 .39302 .46533 .4054 .46217 .39797 .45467 Mtetra
.443 .668 .958 r
.39797 .45467 .4054 .46217 .41772 .46259 .41031 .45515 Mtetra
0 .165 .661 r
.41031 .45515 .41772 .46259 .42988 .472 .42247 .46466 Mtetra
.747 .264 0 r
.42247 .46466 .42988 .472 .44196 .49061 .43455 .48301 Mtetra
0 .108 .612 r
.43455 .48301 .44196 .49061 .45442 .50269 .44704 .49375 Mtetra
.823 .76 .793 r
.44704 .49375 .45442 .50269 .46747 .49128 .46019 .47971 Mtetra
.883 .726 .682 r
.46019 .47971 .46747 .49128 .48073 .46484 .47357 .45031 Mtetra
.832 .688 .704 r
.47357 .45031 .48073 .46484 .49381 .44463 .48672 .42814 Mtetra
.632 .582 .78 r
.48672 .42814 .49381 .44463 .50674 .44048 .49965 .42394 Mtetra
.014 .203 .713 r
.49965 .42394 .50674 .44048 .5197 .45243 .51258 .43776 Mtetra
0 0 .492 r
.51258 .43776 .5197 .45243 .53287 .47066 .52572 .45888 Mtetra
.269 .462 .865 r
.52572 .45888 .53287 .47066 .54619 .4738 .53905 .46459 Mtetra
.866 .768 .751 r
.53905 .46459 .54619 .4738 .55938 .45322 .55233 .44529 Mtetra
.915 .782 .7 r
.55233 .44529 .55938 .45322 .57241 .42598 .56545 .41824 Mtetra
.876 .797 .768 r
.56545 .41824 .57241 .42598 .58548 .40799 .57859 .40008 Mtetra
.77 .787 .868 r
.57859 .40008 .58548 .40799 .59872 .39909 .59188 .39105 Mtetra
.684 .762 .911 r
.59188 .39105 .59872 .39909 .61207 .39382 .60528 .3857 Mtetra
.659 .753 .919 r
.60528 .3857 .61207 .39382 .62551 .38931 .61876 .38116 Mtetra
.656 .752 .92 r
.61876 .38116 .62551 .38931 .63902 .3849 .63231 .3767 Mtetra
.656 .751 .92 r
.63231 .3767 .63902 .3849 .65259 .38046 .64593 .37223 Mtetra
.64593 .37223 .65259 .38046 .66623 .37601 .65962 .36773 Mtetra
.65962 .36773 .66623 .37601 .67994 .37154 .67337 .36322 Mtetra
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Mtetra
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34884 .74314 .34031 Mtetra
.74314 .34031 .74947 .34884 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48184 .30436 .47448 Mtetra
.30436 .47448 .31209 .48184 .3242 .47786 .3165 .47048 Mtetra
.3165 .47048 .3242 .47786 .33636 .47387 .32869 .46645 Mtetra
.32869 .46645 .33636 .47387 .34858 .46986 .34094 .4624 Mtetra
.34094 .4624 .34858 .46986 .36085 .46583 .35325 .45834 Mtetra
.655 .751 .92 r
.35325 .45834 .36085 .46583 .37318 .46179 .36562 .45427 Mtetra
.652 .75 .922 r
.36562 .45427 .37318 .46179 .38556 .45784 .37803 .45028 Mtetra
.623 .741 .931 r
.37803 .45028 .38556 .45784 .39797 .45467 .39048 .44708 Mtetra
.451 .671 .957 r
.39048 .44708 .39797 .45467 .41031 .45515 .40285 .44741 Mtetra
0 .228 .721 r
.40285 .44741 .41031 .45515 .42247 .46466 .41504 .45611 Mtetra
.613 .134 0 r
.41504 .45611 .42247 .46466 .43455 .48301 .42718 .47176 Mtetra
.232 .452 .867 r
.42718 .47176 .43455 .48301 .44704 .49375 .43979 .47743 Mtetra
.799 .662 .712 r
.43979 .47743 .44704 .49375 .46019 .47971 .45307 .4584 Mtetra
.827 .644 .655 r
.45307 .4584 .46019 .47971 .47357 .45031 .46653 .42702 Mtetra
.773 .607 .673 r
.46653 .42702 .47357 .45031 .48672 .42814 .4797 .4051 Mtetra
.614 .517 .721 r
.4797 .4051 .48672 .42814 .49965 .42394 .49261 .40086 Mtetra
.212 .262 .697 r
.49261 .40086 .49965 .42394 .51258 .43776 .50548 .41433 Mtetra
0 .038 .586 r
.50548 .41433 .51258 .43776 .52572 .45888 .51853 .43735 Mtetra
.282 .325 .73 r
.51853 .43735 .52572 .45888 .53905 .46459 .53184 .44796 Mtetra
.763 .649 .736 r
.53184 .44796 .53905 .46459 .55233 .44529 .54519 .43367 Mtetra
.873 .735 .707 r
.54519 .43367 .55233 .44529 .56545 .41824 .55841 .40926 Mtetra
.858 .775 .768 r
.55841 .40926 .56545 .41824 .57859 .40008 .57164 .39185 Mtetra
.765 .78 .865 r
.57164 .39185 .57859 .40008 .59188 .39105 .58498 .38289 Mtetra
.683 .761 .91 r
.58498 .38289 .59188 .39105 .60528 .3857 .59842 .37751 Mtetra
.659 .753 .919 r
.59842 .37751 .60528 .3857 .61876 .38116 .61195 .37293 Mtetra
.656 .752 .92 r
.61195 .37293 .61876 .38116 .63231 .3767 .62555 .36843 Mtetra
.656 .751 .92 r
.62555 .36843 .63231 .3767 .64593 .37223 .63921 .36392 Mtetra
.63921 .36392 .64593 .37223 .65962 .36773 .65294 .35938 Mtetra
.65294 .35938 .65962 .36773 .67337 .36322 .66673 .35483 Mtetra
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Mtetra
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Mtetra
.29656 .46707 .30436 .47448 .3165 .47048 .30873 .46303 Mtetra
.30873 .46303 .3165 .47048 .32869 .46645 .32096 .45897 Mtetra
.32096 .45897 .32869 .46645 .34094 .4624 .33325 .45489 Mtetra
.33325 .45489 .34094 .4624 .35325 .45834 .34559 .45079 Mtetra
.34559 .45079 .35325 .45834 .36562 .45427 .35799 .44668 Mtetra
.652 .75 .922 r
.35799 .44668 .36562 .45427 .37803 .45028 .37044 .44264 Mtetra
.628 .742 .93 r
.37044 .44264 .37803 .45028 .39048 .44708 .38292 .43928 Mtetra
.496 .687 .952 r
.38292 .43928 .39048 .44708 .40285 .44741 .39535 .43885 Mtetra
.037 .402 .856 r
.39535 .43885 .40285 .44741 .41504 .45611 .40763 .44513 Mtetra
0 .169 .704 r
.40763 .44513 .41504 .45611 .42718 .47176 .41988 .45641 Mtetra
.453 .502 .819 r
.41988 .45641 .42718 .47176 .43979 .47743 .43256 .45911 Mtetra
.763 .632 .715 r
.43256 .45911 .43979 .47743 .45307 .4584 .44581 .44315 Mtetra
.835 .684 .695 r
.44581 .44315 .45307 .4584 .46653 .42702 .45918 .41935 Mtetra
.857 .789 .784 r
.45918 .41935 .46653 .42702 .4797 .4051 .47233 .40321 Mtetra
.552 .898 .977 r
.47233 .40321 .4797 .4051 .49261 .40086 .48531 .39893 Mtetra
.496 0 0 r
.48531 .39893 .49261 .40086 .50548 .41433 .49825 .40658 Mtetra
.578 .089 0 r
.49825 .40658 .50548 .41433 .51853 .43735 .51132 .42193 Mtetra
.276 .398 .806 r
.51132 .42193 .51853 .43735 .53184 .44796 .52461 .42934 Mtetra
.721 .612 .735 r
.52461 .42934 .53184 .44796 .54519 .43367 .53799 .4179 Mtetra
.815 .678 .712 r
.53799 .4179 .54519 .43367 .55841 .40926 .5513 .3978 Mtetra
.814 .729 .77 r
.5513 .3978 .55841 .40926 .57164 .39185 .56461 .38277 Mtetra
.745 .757 .862 r
.56461 .38277 .57164 .39185 .58498 .38289 .57801 .37452 Mtetra
.679 .756 .909 r
.57801 .37452 .58498 .38289 .59842 .37751 .59151 .36923 Mtetra
.659 .752 .919 r
.59151 .36923 .59842 .37751 .61195 .37293 .60508 .36462 Mtetra
.656 .751 .92 r
.60508 .36462 .61195 .37293 .62555 .36843 .61872 .36008 Mtetra
.61872 .36008 .62555 .36843 .63921 .36392 .63243 .35553 Mtetra
.63243 .35553 .63921 .36392 .65294 .35938 .6462 .35095 Mtetra
.6462 .35095 .65294 .35938 .66673 .35483 .66004 .34636 Mtetra
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Mtetra
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45551 Mtetra
.3009 .45551 .30873 .46303 .32096 .45897 .31316 .45142 Mtetra
.31316 .45142 .32096 .45897 .33325 .45489 .32548 .4473 Mtetra
.32548 .4473 .33325 .45489 .34559 .45079 .33786 .44317 Mtetra
.33786 .44317 .34559 .45079 .35799 .44668 .35029 .43902 Mtetra
.654 .751 .921 r
.35029 .43902 .35799 .44668 .37044 .44264 .36278 .43491 Mtetra
.639 .745 .926 r
.36278 .43491 .37044 .44264 .38292 .43928 .37531 .43122 Mtetra
.562 .709 .94 r
.37531 .43122 .38292 .43928 .39535 .43885 .38782 .42947 Mtetra
.329 .559 .92 r
.38782 .42947 .39535 .43885 .40763 .44513 .40023 .43242 Mtetra
.168 .38 .827 r
.40023 .43242 .40763 .44513 .41988 .45641 .4126 .43978 Mtetra
.439 .477 .801 r
.4126 .43978 .41988 .45641 .43256 .45911 .42525 .44313 Mtetra
.707 .627 .765 r
.42525 .44313 .43256 .45911 .44581 .44315 .43834 .43422 Mtetra
.844 .765 .775 r
.43834 .43422 .44581 .44315 .45918 .41935 .45162 .41797 Mtetra
.864 .951 .868 r
.45162 .41797 .45918 .41935 .47233 .40321 .4648 .40526 Mtetra
.257 .759 .715 r
.4648 .40526 .47233 .40321 .48531 .39893 .47786 .40098 Mtetra
.448 0 0 r
.47786 .40098 .48531 .39893 .49825 .40658 .49089 .4052 Mtetra
.517 0 0 r
.49089 .4052 .49825 .40658 .51132 .42193 .50403 .41298 Mtetra
.476 .654 .938 r
.50403 .41298 .51132 .42193 .52461 .42934 .51735 .41317 Mtetra
.747 .647 .75 r
.51735 .41317 .52461 .42934 .53799 .4179 .53075 .40084 Mtetra
.778 .653 .724 r
.53075 .40084 .53799 .4179 .5513 .3978 .54413 .38455 Mtetra
.763 .688 .78 r
.54413 .38455 .5513 .3978 .56461 .38277 .55752 .37284 Mtetra
.713 .73 .864 r
.55752 .37284 .56461 .38277 .57801 .37452 .57098 .36588 Mtetra
.671 .748 .908 r
.57098 .36588 .57801 .37452 .59151 .36923 .58453 .36085 Mtetra
.658 .751 .919 r
.58453 .36085 .59151 .36923 .60508 .36462 .59814 .35624 Mtetra
.656 .751 .92 r
.59814 .35624 .60508 .36462 .61872 .36008 .61183 .35166 Mtetra
.61183 .35166 .61872 .36008 .63243 .35553 .62558 .34707 Mtetra
.62558 .34707 .63243 .35553 .6462 .35095 .6394 .34245 Mtetra
.6394 .34245 .6462 .35095 .66004 .34636 .65329 .33781 Mtetra
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.28076 .45205 .28869 .45959 .3009 .45551 .293 .44794 Mtetra
.293 .44794 .3009 .45551 .31316 .45142 .30529 .44381 Mtetra
.30529 .44381 .31316 .45142 .32548 .4473 .31765 .43966 Mtetra
.31765 .43966 .32548 .4473 .33786 .44317 .33006 .43549 Mtetra
.33006 .43549 .33786 .44317 .35029 .43902 .34253 .4313 Mtetra
.655 .751 .921 r
.34253 .4313 .35029 .43902 .36278 .43491 .35506 .42711 Mtetra
.649 .748 .922 r
.35506 .42711 .36278 .43491 .37531 .43122 .36764 .42309 Mtetra
.618 .73 .926 r
.36764 .42309 .37531 .43122 .38782 .42947 .38024 .41996 Mtetra
.521 .654 .919 r
.38024 .41996 .38782 .42947 .40023 .43242 .3928 .4194 Mtetra
.396 .511 .857 r
.3928 .4194 .40023 .43242 .4126 .43978 .40531 .42262 Mtetra
.408 .452 .794 r
.40531 .42262 .4126 .43978 .42525 .44313 .41791 .42695 Mtetra
.538 .54 .805 r
.41791 .42695 .42525 .44313 .43834 .43422 .43076 .42686 Mtetra
.702 .783 .914 r
.43076 .42686 .43834 .43422 .45162 .41797 .44386 .42093 Mtetra
.455 .873 .741 r
.44386 .42093 .45162 .41797 .4648 .40526 .45703 .41365 Mtetra
.168 0 0 r
.45703 .41365 .4648 .40526 .47786 .40098 .47019 .40948 Mtetra
.336 0 0 r
.47019 .40948 .47786 .40098 .49089 .4052 .48337 .40839 Mtetra
0 0 0 r
.48337 .40839 .49089 .4052 .50403 .41298 .49666 .40575 Mtetra
.772 .808 .881 r
.49666 .40575 .50403 .41298 .51735 .41317 .51006 .39674 Mtetra
.759 .65 .742 r
.51006 .39674 .51735 .41317 .53075 .40084 .52349 .38309 Mtetra
.735 .628 .739 r
.52349 .38309 .53075 .40084 .54413 .38455 .53691 .37091 Mtetra
.711 .664 .802 r
.53691 .37091 .54413 .38455 .55752 .37284 .55037 .36276 Mtetra
.681 .717 .876 r
.55037 .36276 .55752 .37284 .57098 .36588 .56389 .35715 Mtetra
.662 .744 .911 r
.56389 .35715 .57098 .36588 .58453 .36085 .57748 .35239 Mtetra
.657 .75 .919 r
.57748 .35239 .58453 .36085 .59814 .35624 .59115 .34778 Mtetra
.656 .751 .92 r
.59115 .34778 .59814 .35624 .61183 .35166 .60488 .34316 Mtetra
.60488 .34316 .61183 .35166 .62558 .34707 .61867 .33853 Mtetra
.61867 .33853 .62558 .34707 .6394 .34245 .63254 .33387 Mtetra
.63254 .33387 .6394 .34245 .65329 .33781 .64648 .32918 Mtetra
.64648 .32918 .65329 .33781 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Mtetra
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Mtetra
.29736 .43613 .30529 .44381 .31765 .43966 .30975 .43194 Mtetra
.30975 .43194 .31765 .43966 .33006 .43549 .3222 .42774 Mtetra
.3222 .42774 .33006 .43549 .34253 .4313 .3347 .42351 Mtetra
.3347 .42351 .34253 .4313 .35506 .42711 .34727 .41927 Mtetra
.654 .75 .92 r
.34727 .41927 .35506 .42711 .36764 .42309 .35989 .41505 Mtetra
.646 .743 .92 r
.35989 .41505 .36764 .42309 .38024 .41996 .37256 .41107 Mtetra
.617 .712 .913 r
.37256 .41107 .38024 .41996 .3928 .4194 .38526 .40795 Mtetra
.561 .63 .877 r
.38526 .40795 .3928 .4194 .40531 .42262 .39796 .40662 Mtetra
.514 .529 .809 r
.39796 .40662 .40531 .42262 .41791 .42695 .41066 .40731 Mtetra
.511 .486 .765 r
.41066 .40731 .41791 .42695 .43076 .42686 .42346 .40852 Mtetra
.543 .518 .778 r
.42346 .40852 .43076 .42686 .44386 .42093 .4364 .40828 Mtetra
.594 .625 .853 r
.4364 .40828 .44386 .42093 .45703 .41365 .44948 .40592 Mtetra
.645 .76 .933 r
.44948 .40592 .45703 .41365 .47019 .40948 .46268 .40175 Mtetra
.705 .78 .91 r
.46268 .40175 .47019 .40948 .48337 .40839 .47598 .39559 Mtetra
.727 .682 .806 r
.47598 .39559 .48337 .40839 .49666 .40575 .48936 .38676 Mtetra
.711 .605 .737 r
.48936 .38676 .49666 .40575 .51006 .39674 .50277 .37609 Mtetra
.692 .583 .728 r
.50277 .37609 .51006 .39674 .52349 .38309 .5162 .36626 Mtetra
.68 .61 .771 r
.5162 .36626 .52349 .38309 .53691 .37091 .52966 .35889 Mtetra
.671 .675 .845 r
.52966 .35889 .53691 .37091 .55037 .36276 .54316 .35335 Mtetra
.662 .728 .898 r
.54316 .35335 .55037 .36276 .56389 .35715 .55674 .34853 Mtetra
.657 .747 .916 r
.55674 .34853 .56389 .35715 .57748 .35239 .57038 .34388 Mtetra
.656 .751 .92 r
.57038 .34388 .57748 .35239 .59115 .34778 .58408 .33924 Mtetra
.58408 .33924 .59115 .34778 .60488 .34316 .59786 .33458 Mtetra
.59786 .33458 .60488 .34316 .61867 .33853 .6117 .32991 Mtetra
.6117 .32991 .61867 .33853 .63254 .33387 .62562 .32521 Mtetra
.62562 .32521 .63254 .33387 .64648 .32918 .6396 .32048 Mtetra
.6396 .32048 .64648 .32918 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Mtetra
.28935 .42838 .29736 .43613 .30975 .43194 .30178 .42416 Mtetra
.30178 .42416 .30975 .43194 .3222 .42774 .31426 .41992 Mtetra
.31426 .41992 .3222 .42774 .3347 .42351 .32681 .41565 Mtetra
.32681 .41565 .3347 .42351 .34727 .41927 .33941 .41137 Mtetra
.33941 .41137 .34727 .41927 .35989 .41505 .35207 .40707 Mtetra
.654 .75 .92 r
.35207 .40707 .35989 .41505 .37256 .41107 .36479 .4028 Mtetra
.649 .741 .917 r
.36479 .4028 .37256 .41107 .38526 .40795 .37757 .39866 Mtetra
.636 .712 .902 r
.37757 .39866 .38526 .40795 .39796 .40662 .39039 .39492 Mtetra
.615 .651 .862 r
.39039 .39492 .39796 .40662 .41066 .40731 .40325 .39182 Mtetra
.596 .581 .807 r
.40325 .39182 .41066 .40731 .42346 .40852 .41616 .38925 Mtetra
.591 .537 .762 r
.41616 .38925 .42346 .40852 .4364 .40828 .42916 .38663 Mtetra
.6 .522 .739 r
.42916 .38663 .4364 .40828 .44948 .40592 .44225 .38326 Mtetra
.615 .524 .728 r
.44225 .38326 .44948 .40592 .46268 .40175 .45544 .37872 Mtetra
.632 .532 .723 r
.45544 .37872 .46268 .40175 .47598 .39559 .46871 .37293 Mtetra
.644 .542 .724 r
.46871 .37293 .47598 .39559 .48936 .38676 .48205 .3663 Mtetra
.65 .561 .742 r
.48205 .3663 .48936 .38676 .50277 .37609 .49544 .3598 Mtetra
.653 .604 .787 r
.49544 .3598 .50277 .37609 .5162 .36626 .50887 .35421 Mtetra
.657 .669 .85 r
.50887 .35421 .5162 .36626 .52966 .35889 .52235 .34929 Mtetra
.657 .723 .897 r
.52235 .34929 .52966 .35889 .54316 .35335 .5359 .3446 Mtetra
.656 .745 .915 r
.5359 .3446 .54316 .35335 .55674 .34853 .54952 .33996 Mtetra
.656 .75 .919 r
.54952 .33996 .55674 .34853 .57038 .34388 .5632 .3353 Mtetra
.656 .751 .92 r
.5632 .3353 .57038 .34388 .58408 .33924 .57696 .33063 Mtetra
.57696 .33063 .58408 .33924 .59786 .33458 .59078 .32593 Mtetra
.59078 .32593 .59786 .33458 .6117 .32991 .60467 .32121 Mtetra
.60467 .32121 .6117 .32991 .62562 .32521 .61863 .31646 Mtetra
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Mtetra
.28128 .42057 .28935 .42838 .30178 .42416 .29374 .41631 Mtetra
.29374 .41631 .30178 .42416 .31426 .41992 .30626 .41203 Mtetra
.30626 .41203 .31426 .41992 .32681 .41565 .31884 .40773 Mtetra
.31884 .40773 .32681 .41565 .33941 .41137 .33148 .40341 Mtetra
.33148 .40341 .33941 .41137 .35207 .40707 .34418 .39907 Mtetra
.34418 .39907 .35207 .40707 .36479 .4028 .35694 .39471 Mtetra
.655 .75 .919 r
.35694 .39471 .36479 .4028 .37757 .39866 .36976 .39034 Mtetra
.654 .744 .916 r
.36976 .39034 .37757 .39866 .39039 .39492 .38264 .386 Mtetra
.651 .729 .906 r
.38264 .386 .39039 .39492 .40325 .39182 .39558 .38173 Mtetra
.646 .7 .886 r
.39558 .38173 .40325 .39182 .41616 .38925 .40858 .37756 Mtetra
.641 .666 .858 r
.40858 .37756 .41616 .38925 .42916 .38663 .42164 .37341 Mtetra
.64 .639 .833 r
.42164 .37341 .42916 .38663 .44225 .38326 .43478 .36909 Mtetra
.643 .626 .818 r
.43478 .36909 .44225 .38326 .45544 .37872 .44798 .36445 Mtetra
.649 .628 .816 r
.44798 .36445 .45544 .37872 .46871 .37293 .46126 .35954 Mtetra
.652 .643 .829 r
.46126 .35954 .46871 .37293 .48205 .3663 .4746 .35462 Mtetra
.653 .675 .858 r
.4746 .35462 .48205 .3663 .49544 .3598 .48799 .34991 Mtetra
.655 .715 .892 r
.48799 .34991 .49544 .3598 .50887 .35421 .50145 .34529 Mtetra
.656 .74 .912 r
.50145 .34529 .50887 .35421 .52235 .34929 .51498 .34067 Mtetra
.656 .749 .918 r
.51498 .34067 .52235 .34929 .5359 .3446 .52858 .33602 Mtetra
.656 .751 .92 r
.52858 .33602 .5359 .3446 .54952 .33996 .54224 .33135 Mtetra
.54224 .33135 .54952 .33996 .5632 .3353 .55597 .32665 Mtetra
.55597 .32665 .5632 .3353 .57696 .33063 .56976 .32194 Mtetra
.56976 .32194 .57696 .33063 .59078 .32593 .58363 .3172 Mtetra
.58363 .3172 .59078 .32593 .60467 .32121 .59757 .31243 Mtetra
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Mtetra
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Mtetra
.28563 .40839 .29374 .41631 .30626 .41203 .29819 .40407 Mtetra
.29819 .40407 .30626 .41203 .31884 .40773 .3108 .39974 Mtetra
.3108 .39974 .31884 .40773 .33148 .40341 .32348 .39538 Mtetra
.32348 .39538 .33148 .40341 .34418 .39907 .33621 .391 Mtetra
.33621 .391 .34418 .39907 .35694 .39471 .34901 .38659 Mtetra
.34901 .38659 .35694 .39471 .36976 .39034 .36187 .38217 Mtetra
.36187 .38217 .36976 .39034 .38264 .386 .37479 .37773 Mtetra
.656 .749 .919 r
.37479 .37773 .38264 .386 .39558 .38173 .38778 .37327 Mtetra
.656 .745 .916 r
.38778 .37327 .39558 .38173 .40858 .37756 .40083 .36877 Mtetra
.656 .738 .91 r
.40083 .36877 .40858 .37756 .42164 .37341 .41394 .36424 Mtetra
.656 .729 .903 r
.41394 .36424 .42164 .37341 .43478 .36909 .42712 .35969 Mtetra
.655 .725 .9 r
.42712 .35969 .43478 .36909 .44798 .36445 .44036 .35514 Mtetra
.654 .727 .903 r
.44036 .35514 .44798 .36445 .46126 .35954 .45366 .3506 Mtetra
.655 .738 .91 r
.45366 .3506 .46126 .35954 .4746 .35462 .46703 .34601 Mtetra
.656 .748 .917 r
.46703 .34601 .4746 .35462 .48799 .34991 .48047 .34138 Mtetra
.656 .751 .92 r
.48047 .34138 .48799 .34991 .50145 .34529 .49397 .33674 Mtetra
.49397 .33674 .50145 .34529 .51498 .34067 .50754 .33207 Mtetra
.50754 .33207 .51498 .34067 .52858 .33602 .52118 .32738 Mtetra
.52118 .32738 .52858 .33602 .54224 .33135 .53489 .32266 Mtetra
.53489 .32266 .54224 .33135 .55597 .32665 .54866 .31793 Mtetra
.54866 .31793 .55597 .32665 .56976 .32194 .56251 .31316 Mtetra
.56251 .31316 .56976 .32194 .58363 .3172 .57642 .30838 Mtetra
.57642 .30838 .58363 .3172 .59757 .31243 .5904 .30357 Mtetra
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Mtetra
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Mtetra
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .4004 Mtetra
.27745 .4004 .28563 .40839 .29819 .40407 .29004 .39605 Mtetra
.29004 .39605 .29819 .40407 .3108 .39974 .30269 .39167 Mtetra
.30269 .39167 .3108 .39974 .32348 .39538 .31541 .38727 Mtetra
.31541 .38727 .32348 .39538 .33621 .391 .32818 .38285 Mtetra
.32818 .38285 .33621 .391 .34901 .38659 .34102 .37841 Mtetra
.34102 .37841 .34901 .38659 .36187 .38217 .35391 .37395 Mtetra
.35391 .37395 .36187 .38217 .37479 .37773 .36688 .36946 Mtetra
.36688 .36946 .37479 .37773 .38778 .37327 .3799 .36496 Mtetra
.655 .751 .92 r
.3799 .36496 .38778 .37327 .40083 .36877 .39299 .36045 Mtetra
.655 .752 .921 r
.39299 .36045 .40083 .36877 .41394 .36424 .40614 .35593 Mtetra
.655 .753 .922 r
.40614 .35593 .41394 .36424 .42712 .35969 .41935 .35137 Mtetra
.656 .754 .922 r
.41935 .35137 .42712 .35969 .44036 .35514 .43264 .34677 Mtetra
.657 .754 .922 r
.43264 .34677 .44036 .35514 .45366 .3506 .44598 .34211 Mtetra
.656 .752 .921 r
.44598 .34211 .45366 .3506 .46703 .34601 .4594 .33745 Mtetra
.656 .751 .92 r
.4594 .33745 .46703 .34601 .48047 .34138 .47288 .33279 Mtetra
.656 .752 .92 r
.47288 .33279 .48047 .34138 .49397 .33674 .48642 .3281 Mtetra
.656 .751 .92 r
.48642 .3281 .49397 .33674 .50754 .33207 .50004 .32339 Mtetra
.50004 .32339 .50754 .33207 .52118 .32738 .51372 .31866 Mtetra
.51372 .31866 .52118 .32738 .53489 .32266 .52747 .3139 Mtetra
.52747 .3139 .53489 .32266 .54866 .31793 .54129 .30912 Mtetra
.54129 .30912 .54866 .31793 .56251 .31316 .55518 .30431 Mtetra
.55518 .30431 .56251 .31316 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Mtetra
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Mtetra
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .4004 .2692 .39235 Mtetra
.2692 .39235 .27745 .4004 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Mtetra
.29451 .38353 .30269 .39167 .31541 .38727 .30726 .3791 Mtetra
.30726 .3791 .31541 .38727 .32818 .38285 .32007 .37464 Mtetra
.32007 .37464 .32818 .38285 .34102 .37841 .33295 .37016 Mtetra
.33295 .37016 .34102 .37841 .35391 .37395 .34588 .36565 Mtetra
.34588 .36565 .35391 .37395 .36688 .36946 .35888 .36113 Mtetra
.656 .752 .92 r
.35888 .36113 .36688 .36946 .3799 .36496 .37195 .35658 Mtetra
.656 .751 .92 r
.37195 .35658 .3799 .36496 .39299 .36045 .38508 .35199 Mtetra
.657 .751 .919 r
.38508 .35199 .39299 .36045 .40614 .35593 .39827 .34738 Mtetra
.656 .749 .918 r
.39827 .34738 .40614 .35593 .41935 .35137 .41153 .34275 Mtetra
.656 .748 .918 r
.41153 .34275 .41935 .35137 .43264 .34677 .42485 .33812 Mtetra
.655 .748 .919 r
.42485 .33812 .43264 .34677 .44598 .34211 .43824 .33348 Mtetra
.655 .75 .92 r
.43824 .33348 .44598 .34211 .4594 .33745 .45169 .32882 Mtetra
.656 .751 .92 r
.45169 .32882 .4594 .33745 .47288 .33279 .46521 .32412 Mtetra
.46521 .32412 .47288 .33279 .48642 .3281 .4788 .31939 Mtetra
.4788 .31939 .48642 .3281 .50004 .32339 .49246 .31463 Mtetra
.49246 .31463 .50004 .32339 .51372 .31866 .50619 .30985 Mtetra
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Mtetra
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Mtetra
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36183 Mtetra
.32481 .36183 .33295 .37016 .34588 .36565 .33778 .35728 Mtetra
.33778 .35728 .34588 .36565 .35888 .36113 .35082 .35271 Mtetra
.35082 .35271 .35888 .36113 .37195 .35658 .36392 .34813 Mtetra
.655 .751 .92 r
.36392 .34813 .37195 .35658 .38508 .35199 .37709 .34353 Mtetra
.655 .752 .921 r
.37709 .34353 .38508 .35199 .39827 .34738 .39032 .33892 Mtetra
.655 .753 .922 r
.39032 .33892 .39827 .34738 .41153 .34275 .40362 .33427 Mtetra
.656 .754 .922 r
.40362 .33427 .41153 .34275 .42485 .33812 .41698 .32959 Mtetra
.41698 .32959 .42485 .33812 .43824 .33348 .43042 .32487 Mtetra
.656 .753 .921 r
.43042 .32487 .43824 .33348 .45169 .32882 .44391 .32012 Mtetra
.656 .752 .92 r
.44391 .32012 .45169 .32882 .46521 .32412 .45748 .31536 Mtetra
.656 .751 .92 r
.45748 .31536 .46521 .32412 .4788 .31939 .47111 .31059 Mtetra
.47111 .31059 .4788 .31939 .49246 .31463 .48482 .30579 Mtetra
.48482 .30579 .49246 .31463 .50619 .30985 .49859 .30097 Mtetra
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Mtetra
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Mtetra
.31659 .35342 .32481 .36183 .33778 .35728 .32961 .34884 Mtetra
.32961 .34884 .33778 .35728 .35082 .35271 .34268 .34423 Mtetra
.34268 .34423 .35082 .35271 .36392 .34813 .35583 .3396 Mtetra
.35583 .3396 .36392 .34813 .37709 .34353 .36903 .33493 Mtetra
.36903 .33493 .37709 .34353 .39032 .33892 .38231 .33024 Mtetra
.656 .75 .919 r
.38231 .33024 .39032 .33892 .40362 .33427 .39565 .32553 Mtetra
.656 .749 .919 r
.39565 .32553 .40362 .33427 .41698 .32959 .40905 .32081 Mtetra
.655 .749 .919 r
.40905 .32081 .41698 .32959 .43042 .32487 .42253 .31607 Mtetra
.655 .75 .92 r
.42253 .31607 .43042 .32487 .44391 .32012 .43607 .31132 Mtetra
.655 .751 .92 r
.43607 .31132 .44391 .32012 .45748 .31536 .44967 .30653 Mtetra
.656 .752 .92 r
.44967 .30653 .45748 .31536 .47111 .31059 .46335 .30172 Mtetra
.656 .751 .92 r
.46335 .30172 .47111 .31059 .48482 .30579 .4771 .29687 Mtetra
.4771 .29687 .48482 .30579 .49859 .30097 .49091 .292 Mtetra
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Mtetra
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.3083 .34494 .31659 .35342 .32961 .34884 .32136 .34031 Mtetra
.32136 .34031 .32961 .34884 .34268 .34423 .33447 .33566 Mtetra
.33447 .33566 .34268 .34423 .35583 .3396 .34765 .33099 Mtetra
.34765 .33099 .35583 .3396 .36903 .33493 .3609 .3263 Mtetra
.655 .752 .921 r
.3609 .3263 .36903 .33493 .38231 .33024 .37422 .3216 Mtetra
.655 .753 .921 r
.37422 .3216 .38231 .33024 .39565 .32553 .3876 .31686 Mtetra
.656 .753 .922 r
.3876 .31686 .39565 .32553 .40905 .32081 .40104 .3121 Mtetra
.656 .753 .921 r
.40104 .3121 .40905 .32081 .42253 .31607 .41456 .3073 Mtetra
.41456 .3073 .42253 .31607 .43607 .31132 .42814 .30247 Mtetra
.656 .752 .92 r
.42814 .30247 .43607 .31132 .44967 .30653 .4418 .29762 Mtetra
.656 .751 .92 r
.4418 .29762 .44967 .30653 .46335 .30172 .45552 .29275 Mtetra
.45552 .29275 .46335 .30172 .4771 .29687 .46931 .28786 Mtetra
.46931 .28786 .4771 .29687 .49091 .292 .48317 .28295 Mtetra
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Mtetra
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Mtetra
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Mtetra
.31303 .33171 .32136 .34031 .33447 .33566 .32619 .32702 Mtetra
.32619 .32702 .33447 .33566 .34765 .33099 .33941 .3223 Mtetra
.33941 .3223 .34765 .33099 .3609 .3263 .3527 .31755 Mtetra
.3527 .31755 .3609 .3263 .37422 .3216 .36605 .31278 Mtetra
.656 .75 .919 r
.36605 .31278 .37422 .3216 .3876 .31686 .37948 .30798 Mtetra
.37948 .30798 .3876 .31686 .40104 .3121 .39297 .30317 Mtetra
.655 .75 .919 r
.39297 .30317 .40104 .3121 .41456 .3073 .40652 .29834 Mtetra
.655 .75 .92 r
.40652 .29834 .41456 .3073 .42814 .30247 .42015 .2935 Mtetra
.656 .751 .92 r
.42015 .2935 .42814 .30247 .4418 .29762 .43384 .28862 Mtetra
.43384 .28862 .4418 .29762 .45552 .29275 .44761 .28371 Mtetra
.44761 .28371 .45552 .29275 .46931 .28786 .46145 .27877 Mtetra
.46145 .27877 .46931 .28786 .48317 .28295 .47535 .27381 Mtetra
.47535 .27381 .48317 .28295 .4971 .27801 .48933 .26883 Mtetra
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Mtetra
.30463 .32303 .31303 .33171 .32619 .32702 .31782 .31829 Mtetra
.31782 .31829 .32619 .32702 .33941 .3223 .33109 .31353 Mtetra
.33109 .31353 .33941 .3223 .3527 .31755 .34441 .30876 Mtetra
.655 .752 .921 r
.34441 .30876 .3527 .31755 .36605 .31278 .35781 .30396 Mtetra
.656 .752 .921 r
.35781 .30396 .36605 .31278 .37948 .30798 .37127 .29914 Mtetra
.656 .753 .921 r
.37127 .29914 .37948 .30798 .39297 .30317 .38481 .29428 Mtetra
.38481 .29428 .39297 .30317 .40652 .29834 .39841 .28939 Mtetra
.39841 .28939 .40652 .29834 .42015 .2935 .41208 .28447 Mtetra
.656 .752 .92 r
.41208 .28447 .42015 .2935 .43384 .28862 .42582 .27954 Mtetra
.656 .751 .92 r
.42582 .27954 .43384 .28862 .44761 .28371 .43963 .27458 Mtetra
.43963 .27458 .44761 .28371 .46145 .27877 .45351 .2696 Mtetra
.45351 .2696 .46145 .27877 .47535 .27381 .46746 .26459 Mtetra
.46746 .26459 .47535 .27381 .48933 .26883 .48148 .25956 Mtetra
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Mtetra
.29615 .31427 .30463 .32303 .31782 .31829 .30938 .30949 Mtetra
.30938 .30949 .31782 .31829 .33109 .31353 .32269 .30468 Mtetra
.32269 .30468 .33109 .31353 .34441 .30876 .33606 .29985 Mtetra
.33606 .29985 .34441 .30876 .35781 .30396 .34949 .29499 Mtetra
.34949 .29499 .35781 .30396 .37127 .29914 .363 .2901 Mtetra
.656 .75 .919 r
.363 .2901 .37127 .29914 .38481 .29428 .37657 .2852 Mtetra
.37657 .2852 .38481 .29428 .39841 .28939 .39022 .28028 Mtetra
.655 .75 .92 r
.39022 .28028 .39841 .28939 .41208 .28447 .40393 .27534 Mtetra
.656 .751 .92 r
.40393 .27534 .41208 .28447 .42582 .27954 .41771 .27037 Mtetra
.41771 .27037 .42582 .27954 .43963 .27458 .43157 .26536 Mtetra
.43157 .26536 .43963 .27458 .45351 .2696 .4455 .26033 Mtetra
.4455 .26033 .45351 .2696 .46746 .26459 .45949 .25528 Mtetra
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Mtetra
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Mtetra
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Mtetra
.28759 .30542 .29615 .31427 .30938 .30949 .30086 .3006 Mtetra
.30086 .3006 .30938 .30949 .32269 .30468 .31421 .29575 Mtetra
.31421 .29575 .32269 .30468 .33606 .29985 .32762 .29088 Mtetra
.656 .752 .921 r
.32762 .29088 .33606 .29985 .34949 .29499 .3411 .28599 Mtetra
.3411 .28599 .34949 .29499 .363 .2901 .35464 .28108 Mtetra
.656 .753 .921 r
.35464 .28108 .363 .2901 .37657 .2852 .36826 .27613 Mtetra
.36826 .27613 .37657 .2852 .39022 .28028 .38195 .27115 Mtetra
.656 .752 .921 r
.38195 .27115 .39022 .28028 .40393 .27534 .39571 .26614 Mtetra
.656 .752 .92 r
.39571 .26614 .40393 .27534 .41771 .27037 .40953 .26111 Mtetra
.656 .751 .92 r
.40953 .26111 .41771 .27037 .43157 .26536 .42343 .25606 Mtetra
.42343 .25606 .43157 .26536 .4455 .26033 .43741 .25098 Mtetra
.43741 .25098 .4455 .26033 .45949 .25528 .45145 .24588 Mtetra
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Mtetra
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Mtetra
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Mtetra
.27895 .2965 .28759 .30542 .30086 .3006 .29226 .29163 Mtetra
.29226 .29163 .30086 .3006 .31421 .29575 .30565 .28673 Mtetra
.30565 .28673 .31421 .29575 .32762 .29088 .3191 .28181 Mtetra
.3191 .28181 .32762 .29088 .3411 .28599 .33262 .27686 Mtetra
.33262 .27686 .3411 .28599 .35464 .28108 .34621 .27188 Mtetra
.656 .75 .92 r
.34621 .27188 .35464 .28108 .36826 .27613 .35987 .26688 Mtetra
.35987 .26688 .36826 .27613 .38195 .27115 .3736 .26187 Mtetra
.656 .751 .92 r
.3736 .26187 .38195 .27115 .39571 .26614 .3874 .25683 Mtetra
.3874 .25683 .39571 .26614 .40953 .26111 .40128 .25176 Mtetra
.40128 .25176 .40953 .26111 .42343 .25606 .41522 .24667 Mtetra
.41522 .24667 .42343 .25606 .43741 .25098 .42924 .24154 Mtetra
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Mtetra
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Mtetra
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Mtetra
.27023 .28749 .27895 .2965 .29226 .29163 .28358 .28257 Mtetra
.28358 .28257 .29226 .29163 .30565 .28673 .29701 .27763 Mtetra
.29701 .27763 .30565 .28673 .3191 .28181 .3105 .27267 Mtetra
.656 .752 .921 r
.3105 .27267 .3191 .28181 .33262 .27686 .32407 .26769 Mtetra
.32407 .26769 .33262 .27686 .34621 .27188 .3377 .26268 Mtetra
.3377 .26268 .34621 .27188 .35987 .26688 .3514 .25763 Mtetra
.3514 .25763 .35987 .26688 .3736 .26187 .36518 .25256 Mtetra
.36518 .25256 .3736 .26187 .3874 .25683 .37902 .24746 Mtetra
.656 .752 .92 r
.37902 .24746 .3874 .25683 .40128 .25176 .39294 .24233 Mtetra
.656 .751 .92 r
.39294 .24233 .40128 .25176 .41522 .24667 .40693 .23718 Mtetra
.40693 .23718 .41522 .24667 .42924 .24154 .42099 .23201 Mtetra
.42099 .23201 .42924 .24154 .44333 .23639 .43513 .2268 Mtetra
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Mtetra
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Mtetra
.26142 .27839 .27023 .28749 .28358 .28257 .27482 .27343 Mtetra
.27482 .27343 .28358 .28257 .29701 .27763 .28829 .26844 Mtetra
.28829 .26844 .29701 .27763 .3105 .27267 .30182 .26343 Mtetra
.30182 .26343 .3105 .27267 .32407 .26769 .31543 .25838 Mtetra
.31543 .25838 .32407 .26769 .3377 .26268 .32911 .25331 Mtetra
.656 .75 .92 r
.32911 .25331 .3377 .26268 .3514 .25763 .34285 .24822 Mtetra
.34285 .24822 .3514 .25763 .36518 .25256 .35667 .24311 Mtetra
.656 .751 .92 r
.35667 .24311 .36518 .25256 .37902 .24746 .37056 .23797 Mtetra
.37056 .23797 .37902 .24746 .39294 .24233 .38452 .2328 Mtetra
.38452 .2328 .39294 .24233 .40693 .23718 .39856 .22761 Mtetra
.39856 .22761 .40693 .23718 .42099 .23201 .41267 .22238 Mtetra
.41267 .22238 .42099 .23201 .43513 .2268 .42685 .21713 Mtetra
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3ooomC0:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0oooo00<000000?ooo`3oool0AP3ooomE0:O0j`03
0000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo
F@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?oooe`0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo02P0oooo000T
0?ooo`800000B`3oool30:NojeX0Yl3[0P00000E0:O0ja00oooo0P00000Y0?ooo`008@3oool30000
04/0oooo1P2W_n]F0:O0j`<000000P2W`>/00`000000Yl3[0:O0j`0B0:O0ja80oooo00<000000?oo
o`3oool09P3oool001l0oooo0`0000190?ooo`X0Yko[D`2W`>/3000000D0Yl3[00<000000:O0j`2W
`>/04`2W`>/A0?ooo`030000003oool0oooo02H0oooo000M0?ooo`800000B`3oool20:O0j`D0Yko[
E02W`>/3000000T0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00`0oooo
0P0000040?ooo`8000000`3oool4000000X0oooo000E0?ooo`D000000`3oool2000004T0oooo1@2W
`>/20:Noje<0Yl3[0`00000=0:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool02`3oool001L0oooo00<0
00000?ooo`3oool00`3oool3000004@0oooo4@2W`>/30:NojdP0Yl3[0P00000A0:O0j`030000002W
`>/0Yl3[01<0Yl3[403oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`00000o0?oooa<0Yl3[1P2W_n]40:O0j`<000004`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo
00<000000?ooo`3oool00`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`090?ooo`003`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03/0oooo4@2W`>/90:Nojd40Yl3[0`00000G0:O0j`030000
002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000002P3oool001L0oooo00<000000?ooo`3oool00P3oool2000000@0
oooo00<000000?ooo`3oool0>03ooolD0:O0j`D0Yko[@@2W`>/3000001/0Yl3[00<000000:O0j`2W
`>/04P2W`>/@0?ooo`8000002`3oool2000000X0oooo0P00000;0?ooo`005P3oool2000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?oooaT0Yl3[0P2W_n/80:O0j`@0Yko[
=02W`>/3000001l0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0240oooo
000L0?ooo`030000003oool0oooo00D0oooo0P00000`0?ooob@0Yl3[1`2W_n/`0:O0j`<000008P2W
`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0803oool001`0oooo0P000008
0?ooo`030000003oool0oooo02/0oooo902W`>/90:Nojbd0Yl3[0`00000V0:O0j`030000002W`>/0
Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0P0?ooo`00703oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02P0oooo8P2W`>/:0:Nojbd0Yl3[0`00000Z0:O0j`030000002W`>/0Yl3[
0180Yl3[4@3oool00`000000oooo0?ooo`0O0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02<0oooo9`2W`>/50:Nojbh0Yl3[0`00000^0:O0j`030000002W`>/0Yl3[0180
Yl3[4@3oool00`000000oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<000000?ooo`3oool0
7`3ooole0:O0j`D0Yko[8@2W`>/200000340Yl3[00<000000:O0j`2W`>/04`2W`>/@0?ooo`030000
003oool0oooo01h0oooo000K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3o
oolg0:O0j`P0Yko[7@2W`>/3000003@0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003o
ool0oooo01d0oooo000K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0603ooolf
0:O0j`P0Yko[702W`>/3000003P0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`8000007`3oool0
01/0oooo0P00000?0?ooo`030000003oool0oooo01D0oooo=@2W`>/90:Noja/0Yl3[0`00000k0:O0
j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo=02W`>/90:Noja`0Yl3[0`00000o0:O0j`03
0000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0K0?ooo`00203oool2000000@0oooo
0P0000040?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo
>@2W`>/50:Noj`D0Yl3/102W`>/50:Noj`h0Yl3[0`0000130:O0j`030000002W`>/0Yl3[0180Yl3[
403oool00`000000oooo0?ooo`0K0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000<0oooo0P00000C0?ooo`030000003oool0oooo00X0oooo@02W`>/50:O0k0T0
Yko[2P2W`>/3000004L0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01X0
oooo00070?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000E0?oo
o`030000003oool0oooo00L0oooo@`2W`>/90:Noj`/0Yl3[0`00001:0:O0j`030000002W`>/0Yl3[
0180Yl3[4@3oool00`000000oooo0?ooo`0I0?ooo`0000<0oooo0000000000000P0000020?ooo`04
0000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00P3ooom50:O0j`X0Yko[0P2W`N`70:O0j`<00000CP2W`>/00`000000Yl3[0:O0j`0B0:O0
ja00oooo00<000000?ooo`3oool06@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`030?ooo`8000005P3oool00`000000Yl3[0:O0j`140:O0j`X0Yko[1@2W`N`20:O0
j`80Yko[0P00001B0:O0j`030000002W`>/0Yl3[0140Yl3[403oool2000001X0oooo00080?ooo`80
00002P3oool3000000<0oooo00<000000?ooo`3oool04P3ooom<0:O0j`@0Yko[2@2W`N`0102W_n/0
00000000000000020:Noje<0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo
01L0oooo000I0?ooo`030000003oool0oooo0180ooooCP2W`>/40:O0k0D0Yl7/00@0Yko[00000000
000000001@2W_n/A0:O0j`80Yko[1@2W`>/50:NojcH0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?oo
o`030000003oool0oooo01L0oooo000I0?ooo`8000004@3ooomA0:O0j`@0Yl3/0P2W_n/3000000@0
Yko[4`2W`>/50:Noj`80Yl3[0`2W_^X50:NojcH0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`03
0000003oool0oooo01H0oooo000I0?ooo`030000003oool0oooo00d0ooooE@2W`>/20:Noj`<00000
102W_n/40:S1k0D0Yl3[1@2W_nX40:O0j`D0YkgY102W_n/60:NnjP80Yko[0`2X_nXf0:O0j`030000
002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`000000oooo0?oo
o`090?oooeL0Yl3[00@0Z<3[00000000000000000`2W_n/50:O1k0@0Z<7/1@2W_>P50:NojP@0YkOT
1@2W_NT40:Rii@D0YkkZ1P2X_nX20:O0j`80Z;o[<P2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo
00<000000?ooo`3oool05@3oool001T0oooo0P0000070?oooeP0Yl3[0`0000030:S0j`80Yko[0P2W
`>`50:O1k0@0Yk[W1@2W_>P50:N/f`@0YkOT1@2XZmT40:Rii@D0ZK[U1@2X_nX50:Rojc40Yl3[00<0
00000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0
oooo00<0ooooF02W`>/3000000030:O0j`2X`>/0Z<3[00<0Z<3[1@2W`>`20:O1k0<0YkWV102W^^L2
0:Nlj0<0YZCD1@2W[=/20:Ngi080Yi[91@2XZmT40:^/f0D0ZK[U1@2Y_^T40:Rojc80Yl3[00<00000
0:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01<0oooo000H0?ooo`030000003oool0oooo
00<0ooooEP2W`>/3000000X0Yl3[102W`>`60:NiiP<0Yk[W1P2VY=@40:N/f`D0Yi[90P2XZmT30:jL
a@@0ZjcH1@2^]n040:Vnj@D0Z<3[<P2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo0P00000E0?oo
o`00603oool010000000oooo0000003ooomF0:O0j`8000003P2W`>/40:Nji`D0YkWV102VX=050:JT
e0D0YXnm102WV/T50:jLa@<0ZjcH0P2fZLd50:jgh0@0ZkoX1@2X`>/a0:O0j`030000002W`>/0Yl3[
0140Yl3[4@3oool00`000000oooo0?ooo`060?ooo`8000002P3oool001P0oooo00<000000:O0j`2W
`>/0E02W`>/3000000`0Yl3[1@2W_>P40:Nji`D0Y:3A102VX=020:JTe0<0Y8Zi102VSkd30:NJb@80
/IFj1@2^W<D00`2[[=P0]ZW=0;JYc@020;JYc@80[[OP0`2f^]d40:^oj0D0Z<3[<@2W`>/00`000000
Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?oo
o`004@3oool2000000D0oooo00<000000?ooo`2W`>/0D@2W`>/3000000`0Yl3[102W_^X50:Nlj0@0
Xj?E102TX=440:JPd0D0Y8Zi1@2VSkd0102WV/T0/IFj0;6E^P2aUKX50:jLa@D0]ZW=1P2f^]d20:^o
j080[L7X1@2X`>/a0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0CP2W`>/3000000/0Yl3[1@2W_n/40:NnjPD0Y:[K0`2SXmD50:BPd@80YZ3@0P2QR;T4
0:B:^@D0YXnm1@2aUKX30:jLa@80_:2m0`2fZLd20<>`a`D0][[M1@2]`NP50:S0jc40Yl3[00<00000
0:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002@3o
ool00100oooo00@000000?ooo`3oool00000103oool200000080ooooBP2W`>/3000000l0Yl3[1@2W
_n/20:NnjP80YK?R102TZ]/40:>Se@@0Y:3A102QR;T50:B:^@<0YXnm0P2fV[`40;6E^P80[Yc5102l
X;d00`2fZLd0`k370<>`a`020<>`a`80][[M0`2n`M`30:g1j080[/;X1@2X`>/`0:O0j`030000002W
`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0oooo
000@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooom60:O0j`<00000
4`2W`>/40:Noj`@0YK?R1@2TZ]/30:>Se@D0WHJj0`2QR;T50:B:^@80YXnm0`2fV[`40;6E^PH0_:2m
1@33/<L60;k1g0D0[/;X1@2X`>/`0:O0j`030000002W`>/0Yl3[0140Yl3[403oool2000000@0oooo
0P00000:0?ooo`00403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo
@@2W`>/3000001H0Yl3[1@2V^^L40:FchP@0Y:[K102IQKd409f6^P@0XHRi102TR[T50;JJ_0@0/IFj
00<0`ZJm0;bP_@2lX;d00`2lX;d00`37YkT0`k370<>`a`020<>`a`040=2ja@2n`M`0_/7L0;k1g0<0
`lOM102^`^P50:S0jc40Yl3[00<000000:O0j`2W`>/04@2W`>/>0?ooo`<00000403oool00140oooo
0P0000040?ooo`8000001`3ooolm0:O0j`<000005P2W`>/50:NnjP@0Y[[W0`2U/n8509N9``<0VHFm
102MQ[X40:68^@80Y8Zi0`2j[/h50;JJ_080/IFj0P32Y[d40;bP_@80ajNi0`33/<L30=2ja@D0`lOM
1@2_`nT40:S0jc80Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003oool0oooo00h0oooo
000G0?ooo`030000003oool0oooo00L0oooo>@2W`>/3000001H0Yl3[102W_n/50:NnjP@0WJKL0`2H
U<h409N9``<0VHFm1@2MQ[X30:68^@D0^Zk>1@2fV[`00`2aUKX0`ZJm0<:V_@020<:V_@80_:2m1037
YkT00`33/<L0d;[50=2ja@020=2ja@040=_6a033amd0`lOM0<?7g@80aLWN1@2_`nT40:S0jc40Yl3[
00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00d0oooo000G0?ooo`030000003o
ool0oooo00P0oooo=@2W`>/3000001X0Yl3[102W_n/50::fiP<0WJKL0`2HU<h409N9``@0VHFm102M
Q[X20:68^@80]<OX1@2j[/h40;JJ_0D0`ZJm00<0_:2m0<NW^@37YkT00`37YkT40=2ja@<0flK41@35
bMh50:k3j@@0Z<3[<@2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0303o
ool001L0oooo0P0000090?oooc<0Yl3[0P00000N0:O0j`@0Y[gZ1@2R]^H309fVg0<0V9C>102GRL<3
09V5_@@0WHJj102danP50;Z^cP80]YZl0`35c^440<:V_@H0ajNi00<0d:ff0=2ja@3@^/D0103Ka/@0
103Pc<@0aLWN0<G9gP35bMh20<C9gPD0[/?Y102X`>/a0:O0j`030000002W`>/0Yl3[0140Yl3[3`3o
ool00`000000oooo0?ooo`0<0?ooo`005`3oool00`000000oooo0?ooo`0:0?ooobh0Yl3[0`00000L
0:O0j`D0Yko[102V_NX40::fiP<0WJKL0`2HU<h409N9``<0VHFm1@2U`^h40;C7j0@0^Zk>1@35c^43
0<:V_@80_jFo1037YkT20=2]]P030=2ja@3Ka/@0flK40080flK40`3Pc<@00`35bMh0a<WN0<C9gP02
0<C9gPD0[/;Y102X`>/a0:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?ooo`0;
0?ooo`005P3oool00`000000oooo0?ooo`0<0?ooobX0Yl3[0`00000P0:O0j`D0Yko[0`2V_NX508nQ
h0<0PhO?0P22O<<409N9``@0V9oJ1@2U`^h30;C7j0@0WHBh00<000000<G>h@35c^400P35c^420<:V
_@<0_jFo0`37YkT30=2]]P@0flK4103Pc<@60<C9gP@0[/;Y1@2X`>/`0:O0j`030000002W`>/0Yl3[
0140Yl3[403oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000h0oooo9P2W`>/3000002@0
Yl3[1@2U_^/309ffj@@0Sj7P0`23Qll3089l``@0RhC7102HWmX30=gcgP80flW80P35Vj`409f4^080
=T>b0`35c^460;nU_`030<NW^@3@[KH0d:ff0080d:ff00<0gkbd0=_6a03Ka/@0103Pc<@20>3<a@H0
a<WN102^`^T50:S0jc00Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`800000303oool001H0oooo
00<000000?ooo`3oool03P3ooolR0:O0j`<000009P2W`>/20:Noj`D0YKk[0`2M]^T408nQh080PhO?
0`22O<<508^4a`80V9oJ0`3Mlmh30=_9b080aI^/1@2MQ;P203I3/P<0NJO`1@2oYKl40=2]]P<0gkbd
103Pc<@40>3<a@@0a<WN0P33bMh40:k2j@D0Z<3[<02W`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo
00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0403ooolM0:O0j`<000009`2W
`>/50:Noj`@0YKk[0`2M]^T408nQh0<0PhO?0`22O<<408^4a`80/lSY0P3H`lH30=_9b0@0aI^/102M
Q;P203I3/P030009UP1iYo00NJO`00@0_jFo0P2hW;`30=2]]P<0gkbd00<0j/Rc0>3<a03Pc<@0103P
c<D20=o<a@80a<WN1033bMh40:k2j@@0Z<3[<02W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<0
00000?ooo`3oool0203oool001H0oooo0P00000B0?oooaT0Yl3[0`00000[0:O0j`@0Yko[1@2N^^d3
08FWj`@0IH;K00<0J7?;08>7c`22O<<00P22O<<208^4a`<0/lSY0`3H`lH00`3E[k40flW80=_9b004
0<FK[0@0WHBh0P0f@k8010002IH0TaH004IUcP1iYo020;nU_`<0^9bl0P3@[KH40=nl]080j/Rc103P
c<D30=o<a@D0`lWN0P33b=l40:k2j@@0Z<3[<02W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo00<0
00000?ooo`3oool0203oool001H0oooo00<000000?ooo`3oool04P3ooolE0:O0j`<00000;`2W`>/5
0:Jok0@0W[[]0`25Yn/306F2f`80J7?;0`22O<<40;?8j@<0f<?60`3E[k450<FK[0D0XIC70P0f@k80
0`002IH0AVG>04IUcP060;RL_0040=2]]P3O_;@0gkbd0=nl]0<0j/Rc00<0jlVb0>3<a@3Pc<D01@3O
c<D30<?9gP<0`lSO1@2^`^T40:S0jc00Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`8000002@3o
ool000<0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0503ooolA
0:O0j`<00000<`2W`>/50:Jok0@0SkG`0P1DSn/306F2f`<0J7?;0`29R/h20;?8j@<0f<?6103E[k40
0`3CY:L0aI^/0<FK[0020<FK[0030=B`]02QU<L0XIC70080XIC700@00c>f03I3/P002IH000VF0P16
ILh50;RL_0@0gkbd0`3Zb;<20>_9/PL0glc51@33b=l60:k2j@@0Z<3[<02W`>/00`000000Yl3[0:O0
j`0@0:O0j`/0oooo0`0000000`3oool000000?ooo`080?ooo`000P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool>0:O0j`800000
=`2W`>/50:>nk@@0SkG`0P1DSn/00`0[HM<0IH;K06Qcb`0206Qcb`@0RH[>103H`lH30=F_/@80djBW
0`35Vj`20=B`]0D0XIC700<00c>f0009UP002IH00P16ILh40;RL_080`jJl0P3O_;@30>[8/`@0jlVb
1P3Oc<D0103Oc<H0`lSO0<?8g`33b=l20<;8g`H0[/;Y102X`>/_0:O0j`030000002W`>/0Yl3[0140
Yl3[1P3oool4000000@0oooo00<000000?ooo`3oool01`3oool00080oooo00@000000?ooo`3oool0
00002`3oool010000000oooo0?ooo`3oool2000001L0oooo2P2W`>/3000003X0Yl3[1@2S_^d308ne
l0<0E8o[00<0:f7C06Qcb`1XLl/00P1XLl/208V:cP80]:330P3H`lH40=F_/@80djBW0`35Vj`30=B`
]0@0XIC70P03<kH20009UP80AVG>0P2hW;`40<>V_0040=nl]03Zb;<0j/Rc0>[8/`D0jlVb103Oc<D3
0=o<aPD0`/SO1@2^`^T50:S0jbl0Yl3[00<000000:O0j`2W`>/04@2W`>/20?ooo`<00000203oool0
0`000000oooo0?ooo`070?ooo`000P3oool010000000oooo0?ooo`0000090?ooo`800000103oool0
0`000000oooo0?ooo`0H0?ooo`D0Yl3[0`00000n0:O0j`D0X;g^0`1n[o<200UVf`80:f7C0`1`N/d5
0;BP``@0eJna103CY:L00`35Vj`0e;2d0=B`]0020=B`]0D0Y/G_00H00c>f0000O@002IH0B5>j04IU
cP2hW;`50<>V_0@0j/Rc1P3[bK820=o<a@<0glc60P3Nc<H50<;8g`<0[/;Y0P2]`^T50:S0jbl0Yl3[
00<000000:O0j`2W`>/0402W`>/2000000`0oooo00<000000?ooo`3oool01P3oool00080oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo
00@0Yl3[0000000000000000?P2W`>/40:Jok0D0X;g^0`1n[o<200UVf`0302]Qd`1`N/d0L7[=0080
L7[=102dX<<01033XKL0eJna0=F_/@3E[k440=>TY`030<FK[03D/;@0e;2d0080e;2d00<0h/Vo0:K5
k`2VaNl00`2VaNl01003<kH000VF04QC^P18DkX60<>V_0030=g4`03Zb;<0j/Rc00P0jlVb0`3Oc<H4
0=k<aPD0`/SO1@2]`^T50:S0jbl0Yl3[00<000000:O0j`2W`>/0402W`>/=0?ooo`030000003oool0
oooo00H0oooo00030?ooo`8000002P3oool3000000<0oooo0P00000H0?ooo`<00000@P2W`>/40:Jo
k0D0Wkg^0`1cZo@00`00>[P02FKK02]Qd`03071jc@<0]:330P33XKL20=F_/@D0djBW103D/;@30>;9
_`D0Yk_X00@0001m0009UP18DkX0B5>j1033Y[`30=g4`0030>[8/`3[bK80jlVb00H0jlVb00<0jlVc
0=o<aP3Nc<H01@3Nc<H50<;8g`D0[L;Y102X`>/_0:O0j`030000002W`>/0Yl3[0100Yl3[3@3oool0
0`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`<00000103ooom20:O0
j`@0Y[o/1@2O_Nh307>[m003000j^000:k@0L7[=00<0L7[=00<0]:330<>Q]`33XKL00P33XKL00`3E
[k40djBW0=>TY`030=>TY`040>:i[P3D/;@0e;2d0=B`]0<0h/Vo00<0h<Fm0:Nkj02W^nP00P2W^nP0
10005I`0001m04QC^P18DkX30<>V_0@0gLC0203[bK820>_9/`L0g/c61P32b=l50:g2j@@0Z<3[;`2W
`>/00`000000Yl3[0:O0j`0@0:O0j``0oooo00<000000?ooo`3oool01P3oool001@0oooo00<00000
0?ooo`3oool04P3oool3000000P0oooo@P2W`>/40:Jok0D0Wkg^0`1aZoD00`00>[P002^d07>0d@02
07>0d@D0`j6g1@3CY:L20>:i[P80e;2d0`3RbKl30>35_@@0Yl3/00@001FL04QC^P18DkX0B5>j0P33
Y[`40=g4`0030>?;_`3[bK80jlVb00D0jlVb0`3[bK<70=k<aPH0`/SO1@2]`^T40:S0jbl0Yl3[00<0
00000:O0j`2W`>/0402W`>/;0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000403oool3
000000`0oooo@P2W`>/40:Jok0D0Wkg^0`1aZoD00`00>[P0Lh3A07>0d@0207>0d@@0`j6g00<0c:Vf
0=>TY`3CY:L00P3CY:L30>:i[P040=B`]03RbKl0h/Vo0>;9_`<0h<Fm00<0hLNn0:O0k02W`>`00P2W
`>`010005I`0A7KM04QC^P33Y[`40=g4`0<0hl^o1@3[bK850>_9/`L0g/c61@32b=l50:g2j@D0Z<3[
;`2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<0
00000?ooo`3oool0303oool300000140oooo@@2W`>/40:Jok0D0Wkg^0`1bZoD01000:k@0Lh3A07>0
d@1cP=430<>Q]`80c:Vf0`3CY:L40>:i[P<0h/Vo0`3PaKd30>77_P@0Yko[00<001FL04Afg@3Ma<00
0`3Ma<040>?;_`030>?:_P3[bK80jlVb0080jlVb1P3[bK<60=k<aP040=k<a`32b=l0`/SO0<;8g`80
`/WQ0`2]`^T20:g3jPD0Z<3[;P2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3o
ool01P3oool001@0oooo00<000000?ooo`3oool02P3oool2000001D0oooo@@2W`>/40:Jok0D0Wkg^
0`1bZoD407>0d@80`j6g0P3<ZKH30=>TY`@0h[V^00<0ilJd0>;9_`3RbKl00`3PaKd30>77_P030>76
_@2W_n/0Yko[0080Yko[0P14M]d20=g4`0@0hl^o0P3Sb[h30>_9/PP0jlVc103Nc<H30=k<a`D0`/WQ
1@2]`nX50:S0jbh0Yl3[00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00D0oooo
000D0?ooo`030000003oool0oooo00L0oooo0`00000H0?oood40Yl3[102V_n`509nmkP80M:ce101c
P=400`33XKL0c:Vf0<bY]P020<bY]P030=>TY`3R^Jh0h[V^0080h[V^0`3Wa[@30>35_@<0hLNn0`3Q
a[d20:Noj`80YkgY0P17To040>?;_`<0hlZn00<0i<Zn0>_9/P3[bK80203[bK<00`3ZbK<0g/c60=k<
aP040=k<a`040>3Ab@32bN40`/WQ0<;9h@80`LkT0`2]`nX20:c3j`@0Z<3[;`2W`>/00`000000Yl3[
0:O0j`0?0:O0j`X0oooo00<000000?ooo`3oool01@3oool001<0oooo0`0000050?ooo`<00000703o
oom10:O0j`@0Y[o/102O_Nh307B/m@<0>g?M1@3<ZKH00`3CY:L0h[V^0>:i[P020>:i[P<0ilJd00<0
ilBc0>35_@3PaKd00P3Qakh40>76_@D0YkgY0P17To020>?;_`<0hlZn0`3Tb[h90>_9/`80j/Vc103N
c<L30>3Ab@D0`LkT1@2/`n/40:S0jbl0Yl3[00<000000:O0j`2W`>/03`2W`>/90?ooo`030000003o
ool0oooo00D0oooo000C0?ooo`030000003oool0oooo0080oooo0`00000P0?oood40Yl3[102V_n`4
0:2mkP<0MJce0`0kLmd40<bY]P@0h[V^0`3Wa[@30>O4/`<0hLNn1@3Qa[d40:Nmj@03000@U@1>U?00
CYC`00@0hlZn0`3Tb[h00`3Tb[d0jlVc0>_9/`050>_9/`<0j/Vc00<0jlZc0=k<a`3Nc<L00`3PdLT2
0>?Nc`D0_]7X0P2/`n/30:[3k0@0Z<3[;P2W`>/00`000000Yl3[0:O0j`0@0:O0j`P0oooo00<00000
0?ooo`3oool01@3oool001<0oooo00<000000?ooo`0000000P00000T0?oood40Yl3[102V_n`40:2m
kP80MJce0`0kLmd30<bY]P80d/;;0`3R^Jh30>O6]0<0ilBc00<0ilFd0>77_P3Qa[d01P3Qa[d40:O3
kP<0CYC`0P3Sb[h30>C:_P<0i<Zm1P3[bK<20>[9/`<0jlZc0`3PdLT30>?Nc`030=oYf@2ndNP0_]7X
0080_]7X1@2Z`n`c0:O0j`030000002W`>/0Yl3[0100Yl3[1`3oool00`000000oooo0?ooo`050?oo
o`004`3oool3000002L0oooo@@2W`>/40:Jok0@0X;g^0P1f[O@010006i`0>g?M03]cg@3<ZKH40=;2
b`040>:i[P3Wa[@0ilJd0>O6]0<0ilBc0P3WaK@80>76_@030>;8_@2W^NH0YkWV0080YkWV0`1CVO84
0>C:_PD0i<Zm0`3[bK<30>[9/`<0jlZc00<0l]Nd0>3Ab@3Sg/l00P3Sg/l30=oYf@D0]/o/102X`N/c
0:O0j`030000002W`>/0Yl3[00l0Yl3[1`3oool00`000000oooo0?ooo`050?ooo`00503oool00`00
0000oooo0?ooo`0W0?oood40Yl3[102V_n`40:2mkP80MZgd0P006i`50=;2b`@0ilJd0`3Wa;<30>O5
]0H0hLJm0P3Rb;d00`3Pa;`0YkWV0:NiiP020:NiiP<0DiWb0P3Tb[h60>C:_@030>G:_@3[bK<0jlVc
0080j/Vc0`3[b[<20?;G]0<0hmk?0`3OjMT20=;/iP<0]/o/0P2^b>d40:S1jc80Yl3[00<000000:O0
j`2W`>/0402W`>/70?ooo`030000003oool0oooo00@0oooo000;0?ooo`D000001@3oool2000002T0
oooo@02W`>/40:Jok0@0X;k^0P1g[O@00`000h8001^L0=;2b`020=;2b`80cl[F0P3Wa[@30>O4/`D0
ilFd103Qa[d20>;8_@<0h<Bl0`2W^NH405>IlPH0i<Zm0`3Ub[d30>[9/`<0jlZc0P3bek@20?KZ]P<0
gnWI103Bk>H50:k8k@@0Z<3[<P2W`>/00`000000Yl3[0:O0j`0@0:O0j`H0oooo00<000000?ooo`3o
ool0103oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?oood00Yl3[
102W_n`40:2nkP80Mjgd00<000>2000KW03B`//0103?b]H40>O4/`H0ilFd0P3Qa[d30>;8_@<0h<Bl
0P3ail420>G7^@@0F9cb103Tb[d40>G:_@030>G:_03ZbK<0jlZc0080jlZc0P3bek@30?KZ]P80koJn
0`3Bk>H30;oNk`D0ZL;/102X`>/b0:O0j`030000002W`>/0Yl3[0100Yl3[1@3oool00`000000oooo
0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo@02W
`>/40:Nok0@0X;k^0`1h[_@40<o:eP80c/[F0P3Wa;<80>O5]0<0h/Rm103Pa;`00`3ail40e>f;0>G7
^@020>G7^@@0F9cb0`3Tb[d30>G:_@80iLZl103[b[<20?;G]080m^Zf0P3_m[h20>7mb@@0_mk_0P2_
b^h40:W2k3L0Yl3[00<000000:O0j`2W`>/03`2W`>/50?ooo`030000003oool0oooo00@0oooo000=
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3ooom00:O0j`@0Yko[102P_^h3
07R^m080cl[F103>b]H90>O5]0030>O6]03Rb;d0h/Rm00<0h<Bl0P3ail440>G7^@030<j_^P1NW_80
GYkb0080GYkb00@0i<Zm0>G:_@3Ub[d0iLZm0`3Ub[`00`3Yd;d0jlZc0>_:/`020?;G]0<0m^Zf00<0
koJn0>7mb@3QoLT00`3@oN050:o:kP@0Z<3[=P2W`>/00`000000Yl3[0:O0j`0@0:O0j`@0oooo00<0
00000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool02P3oool2000002P0oooo@02W`>/4
0:Noj`@0XKk^0`1i[_@40<k:eP80cL[G203WaK@20>O6]0@0h<Bl00<0lNO10>G7^@3UakT00P3UakT2
0<j_^P040:6@`P1NW_80GYkb05jNlP@0iLZm0P3Ub[`30>W@_@<0l]Nd0P3fj[H00`3_m[h0hOg90=3m
h0050;_PlPD0ZL;/102X`>/f0:O0j`030000002W`>/0Yl3[00l0Yl3[103oool00`000000oooo0?oo
o`040?ooo`00303oool2000000h0oooo00<000000?ooo`3oool09P3ooom00:O0j`D0Yko[0`2Q_^h3
07V^m080c/[F103=b]L60>O5]0<0ilJd00<0i/Bd0>34_03Pa;`00P3ail400`3igJX0iLNi0>G7^@04
0<j_^P040:6@`P1QX_@0HJ;d066Rm080iLZm0`3Ub[`30>W@_@80l_:k0P3fj[H00`3_m[h0e?o@0=Co
d0030;okj0@0[<O]102Y`^`k0:O0j`030000002W`>/0Yl3[00l0Yl3[0`3oool00`000000oooo0?oo
o`040?ooo`007@3oool00`000000oooo0?ooo`0V0?ooodD0Yl3[102Q_^h207Z_m0@0cL[G0P3<b]P5
0>O5]0<0ilJd0P3Va;@20?7W`@030?O^W`3igJX0nMfZ00D0cZnj0P2NPkH3066Rm0<0iLZl0`3Yd;d3
0?;b^`040=[m^P3Fom40e?o@0=Cod0<0_o_X0P2adO440:c7kCl0Yl3[00<000000:O0j`2W`>/03P2W
`>/40?ooo`030000003oool0oooo00<0oooo000N0?ooo`030000003oool0oooo02H0ooooA@2W`>/4
0:6nkP80Njod0P3=b]L40<c:f0<0ilFd0`3Wa[@30>K4]080km>f0`3igJX00`3Zc[T0cZnj0<j_^P02
0<j_^P030;jO^@2NPkH0WX>f00<0Ij;b0P3Ub[`30>W@_@80l_:k00@0f_fj0=Kod@3Dom00e?o@0P2o
nnP50;7Al@@0Z<7[?P2W`>/00`000000Yl3[0:O0j`0@0:O0j`80oooo00<000000?ooo`3oool00`3o
ool001l0oooo0P00000X0?oood@0Yl3[102Q_^h207^_m0@0c<[H0P3:bMT20>O5]0<0ilJd0P3Va;@2
0>oC]P030?O^W`3igJX0nMfZ0080j/ji0`3>[kX20;jO^@<0WX>f0`1WX_830>W@_@80l_:k00@0f_fj
0=Kod@3Dom00e?o@102dhOH50:S2k0@0Z<7[?P2W`>/00`000000Yl3[0:O0j`0@0:O0j`030?ooo`00
0000oooo00@0oooo000Q0?ooo`030000003oool0oooo02H0oooo@`2W`>/50:6nk@80OK7e0P3<b]P4
0<[9f@<0ilJd0`3Va;@20>oC]P030?O^W`3igJX0nMfZ00<0j/ji00@0cZnj0;jO^@2nWkT0_Yni102N
PkH303b]m080jM2m00@0l_:k0=[m^P2<^oH0S;_f0`2]kOP40:W5k@@0Z<;/@`2W`>/00`000000Yl3[
0:O0j`0?0:O0j`030?ooo`000000oooo00@0oooo000R0?ooo`030000003oool0oooo02H0oooo@`2W
`>/50:6nk@0307fam@3:bMT0b/WI00<0b/WI0P39b]X20>O6]080i/Bd0P3_dkH00`3gkYl0nMfZ0?WM
ZP040>[>^@D0_Yni0`2NPkH407U]^0<0G6S600<0OMkj0:g]n02Zb>l00`2Zb>l40:W5kDL0Yl3[00<0
00000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`008`3oool00`000000oooo0?ooo`0V
0?oood<0Yl3[1@2R_^d01027]_@0b/WI0<[9f@3:bMT40<W:fP<0i/Bd0P3_dkH00`3gkYl0nMfZ0?WM
ZP040>[>^@030=_<bP2nWkT0_Yni0080_Yni0`2NPkH407U]^0<0OMkj0`2Yb_440:[8kdX0Yl3[00<0
00000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2000002L0oooo@`2W`>/4
0::nk@80U;_b1039b]X30<S9fP040>K4]03_dkH0km>f0?O^W`80nMfZ103Zc[T20=_<bP@0_Yni102W
`Nd408Vfl`030:K9lP2Yb_40ZL[a0080ZL[a1@2W_n]:0:O0j`030000002W`>/0Yl3[00/0Yl3[0`3o
ool00`000000oooo0?ooo`030?ooo`009P3oool00`000000oooo0?ooo`0U0?oood<0Yl3[102T_n`3
09BklPD0b<WJ0`3_dkH0103:om/0g?k10=cn`@3Io]@20>[>^@@0flc:0P2nWkT20;G`m@@0Yl7]00<0
Y<Ka0:K9lP2VbO800P2VbO880:Nojd/0Yl3[00<000000:O0j`2W`>/01P2W`>/80?ooo`030000003o
ool0oooo0080oooo000W0?ooo`030000003oool0oooo02D0oooo@`2W`>/40:Bok0<0X;k^0`38bMX3
0<WChP030<[of`3Lo/40g?k100<0fOkD1@3Kc<X50;G`m@030:C3k`2Ta_40Y<Ka0080Y<Ka202W_n/4
0:S1k4X0Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`030000003oool0oooo0080oooo000X0?oo
o`030000003oool0oooo02H0oooo@P2W`>/50:Jok080X;k^1039dn800`3:om/0g?k10=cn`@05083X
dP80Vl7c1@2U`Nd30:C3k`T0Yko[102W`N`40:S1k0D0Yko[A@2W`>/00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0080oooo000Y0?ooo`8000009`3ooom70:O0j`80YKo/0P39dn80103:om/0
g?k10=cn`@2V`>`40:;0kP@0Y/3/102U`Nd40:O0j`@0Yko[2@2W`N`50:NojdH0Yl3[0`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo02D0
ooooB`2W`>/40:K0k0@0Yl3[102V`>`80:O0j`P0Yl7/1@2W_n]60:O0j`P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?oooel0Yl3[
102W`N`50:Noj`@0Yl7/@P2W`>/;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool002d0oooo00<000000?ooo`3oool09P3ooomN0:O0j`D0Z;o[202W`N`40:NojcX0Yl3[3`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000^0?ooo`030000003oool0
oooo02H0ooooF`2W`>/30:S0j`D0Yl3/102W`N`80:NojcD0Yl3[503oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0040oooo000_0?ooo`8000009`3ooomN0:O0j`@0Yl3/202W_n/f0:O0
jaP0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`0U0?oooeh0Yl3[202W_n/40:O0k340Yl3[703oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0040oooo000b0?ooo`030000003oool0oooo02D0ooooGP2W`>/40:Noj`P0Yl3/
102W_n/Y0:O0jb00oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`00<`3o
ool00`000000oooo0?ooo`0U0?ooof80Yl3[102W`>`80:NojbD0Yl3[903oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0040oooo000d0?ooo`8000009P3ooomR0:O0j`@0Yko[:02W`>/Y
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool003H0oooo00<000000?oo
o`3oool09@3ooomL0:O0j`D0Yko[202W`>/40:Noja`0Yl3[;03oool00`000000oooo0?ooo`070?oo
o`4000000@3oool10?ooo`00=`3oool00`000000oooo0?ooo`0U0?ooofD0Yl3[202W_n/H0:O0jc00
oooo00<000000?ooo`3oool01P3oool100000040oooo0@3oool003P0oooo00<000000?ooo`3oool0
9@3ooomQ0:O0j`P0Yko[502W`>/h0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
000i0?ooo`8000009P3ooomQ0:O0j`<0Yko[5@2W`>/k0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo000k0?ooo`030000003oool0oooo02@0ooooM@2W`>/o0?ooo`030000003oool0
oooo00@0oooo0@0000010?ooo`40oooo000l0?ooo`030000003oool0oooo02@0ooooH@2W`>/80:No
j`P0Yl3[@`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool10?ooo`00?@3oool00`000000
oooo0?ooo`0T0?ooof40Yl3[0`2W_n/80:O0jdP0oooo00<000000?ooo`3oool00P3oool100000040
oooo0@3oool003h0oooo0P00000U0?ooofP0Yl3[B`3oool00`000000oooo0?ooo`030?ooo`400000
0@3oool00400oooo00<000000?ooo`3oool08`3ooomT0:O0jdl0oooo00<000000?ooo`3oool00P3o
ool100000040oooo00110?ooo`030000003oool0oooo02<0ooooH02W`>]C0?ooo`050000003oool0
oooo0?ooo`0000000@3oool00480oooo00<000000?ooo`3oool0903ooomK0:O0jeL0oooo00@00000
0?ooo`3oool000000@3oool004<0oooo0P00000U0?oooe<0Yl3[GP3oool010000000oooo0?ooo`00
00010?ooo`00A@3oool00`000000oooo0?ooo`0S0?ooodl0Yl3[HP3oool00`000000oooo00000001
0?ooo`00AP3oool00`000000oooo0?ooo`0S0?oood/0Yl3[IP3oool100000040oooo0@00000004L0
oooo00<000000?ooo`3oool08`3ooom70:O0jfX0oooo0P00000004P0oooo0P00000U0?oood80Yl3[
K@3oool200000000BP3oool00`000000oooo0?ooo`0S0?oooch0Yl3[L03oool200000000B`3oool0
0`000000oooo0?ooo`0R0?oooc/0Yl3[K`3oool400000080oooo001<0?ooo`030000003oool0oooo
02<0oooo<`2W`>]a0?ooo`@000001P3oool004d0oooo0P00000T0?ooobl0Yl3[L03oool4000000X0
oooo001?0?ooo`030000003oool0oooo0280oooo:`2W`>]_0?ooo`@000003P3oool00500oooo00<0
00000?ooo`3oool08`3ooolV0:O0jfh0oooo1000000B0?ooo`00D@3oool00`000000oooo0?ooo`0S
0?ooob80Yl3[KP3oool3000001H0oooo001B0?ooo`800000903ooolN0:O0jfd0oooo1000000I0?oo
o`00E03oool00`000000oooo0?ooo`0R0?oooaL0Yl3[K`3oool4000001d0oooo001E0?ooo`030000
003oool0oooo0240oooo502W`>]^0?ooo`@000008@3oool005H0oooo00<000000?ooo`3oool08P3o
ool?0:O0jfd0oooo1000000U0?ooo`00E`3oool2000002<0oooo2`2W`>]/0?ooo`@00000:@3oool0
05T0oooo00<000000?ooo`3oool08@3oool40:O0jfl0oooo0`00000]0?ooo`00FP3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo06X0oooo1000000`0?ooo`00F`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo06H0oooo1000000d0?ooo`00G03oool200000240oooo00<0
00000?ooo`3oool0HP3oool4000003P0oooo001N0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0GP3oool4000003`0oooo001O0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0FP3oool400000400oooo001P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E`3oool3000004@0oooo001Q0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`@00000
A`3oool006<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000B`3o
ool006@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`@00000C`3oool0
06D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`170?ooo`@00000D`3oool006H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`130?ooo`@00000E`3oool006L0oooo
0P00000F0?ooo`030000003oool0oooo0400oooo0`00001K0?ooo`00J@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03`0oooo1000001N0?ooo`00JP3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03P0oooo1000001R0?ooo`00J`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo03@0oooo1000001V0?ooo`00K03oool200000100oooo00<000000?ooo`3o
ool0<@3oool4000006X0oooo001^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
;@3oool4000006h0oooo001_0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3o
ool300000780oooo001`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool4
000007D0oooo001a0?ooo`8000002`3oool00`000000oooo0?ooo`0R0?ooo`@00000N@3oool007<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000O@3oool007@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000P@3oool007D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`@00000Q@3oool007H0oooo0P000006
0?ooo`030000003oool0oooo01<0oooo0`0000290?ooo`00N03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00l0oooo1000002<0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo1000002@0?ooo`00NP3oool01@000000oooo0?ooo`3oool0000000T0
oooo1000002D0?ooo`00N`3oool2000000030?ooo`000000oooo00@0oooo1000002H0?ooo`00O@3o
ool2000000030?ooo`000000000000800000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Mtetra
.59604 .63937 .60194 .6454 .6135 .64213 .60764 .63608 Mtetra
.60764 .63608 .6135 .64213 .62511 .63886 .61928 .63278 Mtetra
.656 .752 .92 r
.61928 .63278 .62511 .63886 .63677 .63557 .63098 .62947 Mtetra
.63098 .62947 .63677 .63557 .64848 .63227 .64272 .62614 Mtetra
.656 .751 .92 r
.64272 .62614 .64848 .63227 .66023 .62897 .65451 .62279 Mtetra
.65451 .62279 .66023 .62897 .67204 .62565 .66635 .61943 Mtetra
.656 .75 .919 r
.66635 .61943 .67204 .62565 .6839 .6223 .67824 .61606 Mtetra
.656 .75 .92 r
.67824 .61606 .6839 .6223 .6958 .61894 .69018 .61269 Mtetra
.656 .751 .92 r
.69018 .61269 .6958 .61894 .70776 .61556 .70217 .6093 Mtetra
.70217 .6093 .70776 .61556 .71976 .61217 .71421 .60589 Mtetra
.656 .752 .92 r
.71421 .60589 .71976 .61217 .73182 .60877 .7263 .60246 Mtetra
.7263 .60246 .73182 .60877 .74393 .60536 .73845 .59902 Mtetra
.656 .751 .92 r
.73845 .59902 .74393 .60536 .75609 .60193 .75064 .59557 Mtetra
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62665 Mtetra
.61341 .62665 .61928 .63278 .63098 .62947 .62514 .62332 Mtetra
.62514 .62332 .63098 .62947 .64272 .62614 .63691 .61997 Mtetra
.63691 .61997 .64272 .62614 .65451 .62279 .64873 .61661 Mtetra
.655 .752 .921 r
.64873 .61661 .65451 .62279 .66635 .61943 .66061 .61323 Mtetra
.656 .752 .921 r
.66061 .61323 .66635 .61943 .67824 .61606 .67253 .60984 Mtetra
.656 .753 .921 r
.67253 .60984 .67824 .61606 .69018 .61269 .68451 .60642 Mtetra
.656 .752 .921 r
.68451 .60642 .69018 .61269 .70217 .6093 .69653 .60299 Mtetra
.656 .752 .92 r
.69653 .60299 .70217 .6093 .71421 .60589 .70861 .59955 Mtetra
.656 .751 .92 r
.70861 .59955 .71421 .60589 .7263 .60246 .72074 .5961 Mtetra
.72074 .5961 .7263 .60246 .73845 .59902 .73292 .59263 Mtetra
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Mtetra
.59578 .62383 .60173 .62998 .61341 .62665 .60749 .62048 Mtetra
.60749 .62048 .61341 .62665 .62514 .62332 .61925 .61712 Mtetra
.656 .752 .92 r
.61925 .61712 .62514 .62332 .63691 .61997 .63106 .61374 Mtetra
.656 .751 .92 r
.63106 .61374 .63691 .61997 .64873 .61661 .64292 .61034 Mtetra
.64292 .61034 .64873 .61661 .66061 .61323 .65482 .60692 Mtetra
.656 .75 .919 r
.65482 .60692 .66061 .61323 .67253 .60984 .66678 .6035 Mtetra
.656 .75 .92 r
.66678 .6035 .67253 .60984 .68451 .60642 .67879 .60007 Mtetra
.656 .751 .92 r
.67879 .60007 .68451 .60642 .69653 .60299 .69085 .59663 Mtetra
.69085 .59663 .69653 .60299 .70861 .59955 .70297 .59317 Mtetra
.656 .752 .92 r
.70297 .59317 .70861 .59955 .72074 .5961 .71513 .58969 Mtetra
.656 .751 .92 r
.71513 .58969 .72074 .5961 .73292 .59263 .72735 .58619 Mtetra
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Mtetra
.60153 .61426 .60749 .62048 .61925 .61712 .61332 .61087 Mtetra
.61332 .61087 .61925 .61712 .63106 .61374 .62516 .60747 Mtetra
.655 .751 .92 r
.62516 .60747 .63106 .61374 .64292 .61034 .63705 .60406 Mtetra
.655 .752 .921 r
.63705 .60406 .64292 .61034 .65482 .60692 .649 .60063 Mtetra
.656 .753 .921 r
.649 .60063 .65482 .60692 .66678 .6035 .66099 .59718 Mtetra
.66099 .59718 .66678 .6035 .67879 .60007 .67303 .59371 Mtetra
.656 .752 .921 r
.67303 .59371 .67879 .60007 .69085 .59663 .68513 .59022 Mtetra
.656 .752 .92 r
.68513 .59022 .69085 .59663 .70297 .59317 .69728 .58673 Mtetra
.656 .751 .92 r
.69728 .58673 .70297 .59317 .71513 .58969 .70948 .58322 Mtetra
.70948 .58322 .71513 .58969 .72735 .58619 .72173 .5797 Mtetra
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Mtetra
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Mtetra
.656 .752 .92 r
.59552 .60799 .60153 .61426 .61332 .61087 .60734 .60458 Mtetra
.60734 .60458 .61332 .61087 .62516 .60747 .61922 .60114 Mtetra
.656 .751 .92 r
.61922 .60114 .62516 .60747 .63705 .60406 .63114 .59768 Mtetra
.63114 .59768 .63705 .60406 .649 .60063 .64312 .59421 Mtetra
.656 .75 .919 r
.64312 .59421 .649 .60063 .66099 .59718 .65515 .59074 Mtetra
.65515 .59074 .66099 .59718 .67303 .59371 .66723 .58725 Mtetra
.655 .751 .92 r
.66723 .58725 .67303 .59371 .68513 .59022 .67936 .58376 Mtetra
.656 .751 .92 r
.67936 .58376 .68513 .59022 .69728 .58673 .69154 .58024 Mtetra
.656 .752 .92 r
.69154 .58024 .69728 .58673 .70948 .58322 .70378 .57671 Mtetra
.70378 .57671 .70948 .58322 .72173 .5797 .71607 .57315 Mtetra
.656 .751 .92 r
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56959 Mtetra
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Mtetra
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Mtetra
.58946 .60167 .59552 .60799 .60734 .60458 .60132 .59822 Mtetra
.60132 .59822 .60734 .60458 .61922 .60114 .61323 .59477 Mtetra
.655 .751 .92 r
.61323 .59477 .61922 .60114 .63114 .59768 .62519 .59131 Mtetra
.655 .752 .921 r
.62519 .59131 .63114 .59768 .64312 .59421 .6372 .58783 Mtetra
.656 .753 .921 r
.6372 .58783 .64312 .59421 .65515 .59074 .64926 .58432 Mtetra
.64926 .58432 .65515 .59074 .66723 .58725 .66138 .5808 Mtetra
.656 .752 .921 r
.66138 .5808 .66723 .58725 .67936 .58376 .67354 .57725 Mtetra
.656 .752 .92 r
.67354 .57725 .67936 .58376 .69154 .58024 .68576 .5737 Mtetra
.656 .751 .92 r
.68576 .5737 .69154 .58024 .70378 .57671 .69804 .57013 Mtetra
.69804 .57013 .70378 .57671 .71607 .57315 .71036 .56655 Mtetra
.71036 .56655 .71607 .57315 .72841 .56959 .72274 .56296 Mtetra
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59876 Mtetra
.57151 .59876 .57765 .6051 .58946 .60167 .58335 .5953 Mtetra
.656 .752 .92 r
.58335 .5953 .58946 .60167 .60132 .59822 .59525 .59183 Mtetra
.59525 .59183 .60132 .59822 .61323 .59477 .60719 .58834 Mtetra
.656 .751 .92 r
.60719 .58834 .61323 .59477 .62519 .59131 .61918 .58483 Mtetra
.656 .751 .919 r
.61918 .58483 .62519 .59131 .6372 .58783 .63123 .5813 Mtetra
.656 .75 .919 r
.63123 .5813 .6372 .58783 .64926 .58432 .64333 .57777 Mtetra
.655 .75 .919 r
.64333 .57777 .64926 .58432 .66138 .5808 .65548 .57423 Mtetra
.655 .75 .92 r
.65548 .57423 .66138 .5808 .67354 .57725 .66768 .57068 Mtetra
.656 .751 .92 r
.66768 .57068 .67354 .57725 .68576 .5737 .67994 .56711 Mtetra
.656 .752 .92 r
.67994 .56711 .68576 .5737 .69804 .57013 .69225 .56352 Mtetra
.69225 .56352 .69804 .57013 .71036 .56655 .70461 .55991 Mtetra
.656 .751 .92 r
.70461 .55991 .71036 .56655 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Mtetra
.56532 .59236 .57151 .59876 .58335 .5953 .5772 .58888 Mtetra
.5772 .58888 .58335 .5953 .59525 .59183 .58913 .58538 Mtetra
.58913 .58538 .59525 .59183 .60719 .58834 .6011 .58187 Mtetra
.655 .751 .921 r
.6011 .58187 .60719 .58834 .61918 .58483 .61313 .57836 Mtetra
.655 .752 .921 r
.61313 .57836 .61918 .58483 .63123 .5813 .62521 .57483 Mtetra
.656 .753 .922 r
.62521 .57483 .63123 .5813 .64333 .57777 .63735 .57127 Mtetra
.63735 .57127 .64333 .57777 .65548 .57423 .64953 .56768 Mtetra
.656 .753 .921 r
.64953 .56768 .65548 .57423 .66768 .57068 .66177 .56407 Mtetra
.656 .752 .92 r
.66177 .56407 .66768 .57068 .67994 .56711 .67407 .56046 Mtetra
.656 .751 .92 r
.67407 .56046 .67994 .56711 .69225 .56352 .68641 .55684 Mtetra
.68641 .55684 .69225 .56352 .70461 .55991 .69881 .5532 Mtetra
.69881 .5532 .70461 .55991 .71703 .55628 .71127 .54955 Mtetra
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Mtetra
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58592 Mtetra
.55909 .58592 .56532 .59236 .5772 .58888 .571 .58241 Mtetra
.656 .752 .92 r
.571 .58241 .5772 .58888 .58913 .58538 .58296 .57889 Mtetra
.58296 .57889 .58913 .58538 .6011 .58187 .59497 .57534 Mtetra
.59497 .57534 .6011 .58187 .61313 .57836 .60703 .57176 Mtetra
.656 .75 .919 r
.60703 .57176 .61313 .57836 .62521 .57483 .61915 .56817 Mtetra
.656 .749 .919 r
.61915 .56817 .62521 .57483 .63735 .57127 .63132 .56458 Mtetra
.655 .749 .919 r
.63132 .56458 .63735 .57127 .64953 .56768 .64354 .561 Mtetra
.655 .75 .92 r
.64354 .561 .64953 .56768 .66177 .56407 .65582 .5574 Mtetra
.656 .751 .92 r
.65582 .5574 .66177 .56407 .67407 .56046 .66815 .55377 Mtetra
.656 .752 .92 r
.66815 .55377 .67407 .56046 .68641 .55684 .68053 .55011 Mtetra
.68053 .55011 .68641 .55684 .69881 .5532 .69297 .54644 Mtetra
.656 .751 .92 r
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Mtetra
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Mtetra
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Mtetra
.52907 .58646 .53542 .5929 .54723 .58942 .54091 .58295 Mtetra
.54091 .58295 .54723 .58942 .55909 .58592 .5528 .57942 Mtetra
.5528 .57942 .55909 .58592 .571 .58241 .56474 .57588 Mtetra
.56474 .57588 .571 .58241 .58296 .57889 .57674 .57232 Mtetra
.655 .751 .92 r
.57674 .57232 .58296 .57889 .59497 .57534 .58878 .56876 Mtetra
.655 .751 .921 r
.58878 .56876 .59497 .57534 .60703 .57176 .60088 .5652 Mtetra
.655 .753 .922 r
.60088 .5652 .60703 .57176 .61915 .56817 .61304 .56162 Mtetra
.656 .754 .922 r
.61304 .56162 .61915 .56817 .63132 .56458 .62524 .55801 Mtetra
.62524 .55801 .63132 .56458 .64354 .561 .6375 .55435 Mtetra
.656 .753 .921 r
.6375 .55435 .64354 .561 .65582 .5574 .64981 .55068 Mtetra
.656 .752 .92 r
.64981 .55068 .65582 .5574 .66815 .55377 .66218 .547 Mtetra
.656 .751 .92 r
.66218 .547 .66815 .55377 .68053 .55011 .6746 .54332 Mtetra
.6746 .54332 .68053 .55011 .69297 .54644 .68707 .53963 Mtetra
.68707 .53963 .69297 .54644 .70546 .54276 .69961 .53592 Mtetra
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53219 Mtetra
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Mtetra
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57997 Mtetra
.52266 .57997 .52907 .58646 .54091 .58295 .53454 .57643 Mtetra
.53454 .57643 .54091 .58295 .5528 .57942 .54646 .57288 Mtetra
.54646 .57288 .5528 .57942 .56474 .57588 .55844 .56932 Mtetra
.656 .752 .921 r
.55844 .56932 .56474 .57588 .57674 .57232 .57047 .56574 Mtetra
.57047 .56574 .57674 .57232 .58878 .56876 .58255 .56214 Mtetra
.657 .752 .92 r
.58255 .56214 .58878 .56876 .60088 .5652 .59469 .5585 Mtetra
.657 .75 .919 r
.59469 .5585 .60088 .5652 .61304 .56162 .60687 .55485 Mtetra
.656 .749 .918 r
.60687 .55485 .61304 .56162 .62524 .55801 .61911 .5512 Mtetra
.655 .749 .919 r
.61911 .5512 .62524 .55801 .6375 .55435 .63141 .54756 Mtetra
.655 .75 .92 r
.63141 .54756 .6375 .55435 .64981 .55068 .64376 .5439 Mtetra
.656 .752 .92 r
.64376 .5439 .64981 .55068 .66218 .547 .65616 .54021 Mtetra
.656 .752 .921 r
.65616 .54021 .66218 .547 .6746 .54332 .66862 .5365 Mtetra
.656 .752 .92 r
.66862 .5365 .6746 .54332 .68707 .53963 .68113 .53276 Mtetra
.68113 .53276 .68707 .53963 .69961 .53592 .6937 .52902 Mtetra
.656 .751 .92 r
.6937 .52902 .69961 .53592 .71219 .53219 .70633 .52525 Mtetra
.70633 .52525 .71219 .53219 .72483 .52844 .71901 .52148 Mtetra
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Mtetra
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Mtetra
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Mtetra
.49255 .58051 .49907 .587 .51084 .58349 .50435 .57698 Mtetra
.50435 .57698 .51084 .58349 .52266 .57997 .51621 .57343 Mtetra
.51621 .57343 .52266 .57997 .53454 .57643 .52812 .56986 Mtetra
.655 .751 .92 r
.52812 .56986 .53454 .57643 .54646 .57288 .54008 .56629 Mtetra
.655 .751 .921 r
.54008 .56629 .54646 .57288 .55844 .56932 .55209 .56273 Mtetra
.653 .752 .922 r
.55209 .56273 .55844 .56932 .57047 .56574 .56415 .55919 Mtetra
.65 .753 .925 r
.56415 .55919 .57047 .56574 .58255 .56214 .57627 .55572 Mtetra
.648 .758 .929 r
.57627 .55572 .58255 .56214 .59469 .5585 .58845 .55228 Mtetra
.649 .765 .934 r
.58845 .55228 .59469 .5585 .60687 .55485 .60067 .54877 Mtetra
.654 .772 .936 r
.60067 .54877 .60687 .55485 .61911 .5512 .61295 .5451 Mtetra
.659 .774 .934 r
.61295 .5451 .61911 .5512 .63141 .54756 .62528 .54125 Mtetra
.661 .769 .93 r
.62528 .54125 .63141 .54756 .64376 .5439 .63766 .53734 Mtetra
.66 .762 .925 r
.63766 .53734 .64376 .5439 .65616 .54021 .6501 .53346 Mtetra
.658 .756 .922 r
.6501 .53346 .65616 .54021 .66862 .5365 .66259 .52964 Mtetra
.657 .753 .921 r
.66259 .52964 .66862 .5365 .68113 .53276 .67514 .52585 Mtetra
.656 .752 .92 r
.67514 .52585 .68113 .53276 .6937 .52902 .68775 .52206 Mtetra
.656 .751 .92 r
.68775 .52206 .6937 .52902 .70633 .52525 .70041 .51827 Mtetra
.70041 .51827 .70633 .52525 .71901 .52148 .71313 .51446 Mtetra
.71313 .51446 .71901 .52148 .73175 .51768 .72591 .51063 Mtetra
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Mtetra
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Mtetra
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Mtetra
.47419 .57752 .48079 .58403 .49255 .58051 .48598 .57397 Mtetra
.48598 .57397 .49255 .58051 .50435 .57698 .49781 .57041 Mtetra
.49781 .57041 .50435 .57698 .51621 .57343 .5097 .56684 Mtetra
.654 .751 .921 r
.5097 .56684 .51621 .57343 .52812 .56986 .52164 .56328 Mtetra
.65 .751 .923 r
.52164 .56328 .52812 .56986 .54008 .56629 .53364 .55982 Mtetra
.64 .752 .93 r
.53364 .55982 .54008 .56629 .55209 .56273 .54569 .55663 Mtetra
.621 .759 .945 r
.54569 .55663 .55209 .56273 .56415 .55919 .5578 .55384 Mtetra
.597 .778 .967 r
.5578 .55384 .56415 .55919 .57627 .55572 .56997 .55136 Mtetra
.578 .81 .987 r
.56997 .55136 .57627 .55572 .58845 .55228 .5822 .54886 Mtetra
.575 .845 .996 r
.5822 .54886 .58845 .55228 .60067 .54877 .59449 .54589 Mtetra
.599 .874 .993 r
.59449 .54589 .60067 .54877 .61295 .5451 .60682 .54219 Mtetra
.64 .887 .985 r
.60682 .54219 .61295 .5451 .62528 .54125 .61919 .53775 Mtetra
.675 .875 .974 r
.61919 .53775 .62528 .54125 .63766 .53734 .63159 .53285 Mtetra
.687 .843 .958 r
.63159 .53285 .63766 .53734 .6501 .53346 .64403 .5279 Mtetra
.681 .804 .941 r
.64403 .5279 .6501 .53346 .66259 .52964 .65654 .52328 Mtetra
.669 .774 .929 r
.65654 .52328 .66259 .52964 .67514 .52585 .66911 .51905 Mtetra
.66 .759 .923 r
.66911 .51905 .67514 .52585 .68775 .52206 .68175 .51509 Mtetra
.657 .753 .921 r
.68175 .51509 .68775 .52206 .70041 .51827 .69445 .51123 Mtetra
.656 .752 .92 r
.69445 .51123 .70041 .51827 .71313 .51446 .70721 .50738 Mtetra
.656 .751 .92 r
.70721 .50738 .71313 .51446 .72591 .51063 .72003 .50352 Mtetra
.72003 .50352 .72591 .51063 .73875 .50679 .7329 .49965 Mtetra
.7329 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Mtetra
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Mtetra
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57096 Mtetra
.46753 .57096 .47419 .57752 .48598 .57397 .47935 .56738 Mtetra
.655 .751 .92 r
.47935 .56738 .48598 .57397 .49781 .57041 .49122 .5638 Mtetra
.654 .751 .921 r
.49122 .5638 .49781 .57041 .5097 .56684 .50314 .56025 Mtetra
.645 .75 .926 r
.50314 .56025 .5097 .56684 .52164 .56328 .51512 .55693 Mtetra
.616 .749 .941 r
.51512 .55693 .52164 .56328 .53364 .55982 .52715 .55431 Mtetra
.541 .752 .974 r
.52715 .55431 .53364 .55982 .54569 .55663 .53924 .55297 Mtetra
.361 .74 .988 r
.53924 .55297 .54569 .55663 .5578 .55384 .55142 .55299 Mtetra
.043 .607 .785 r
.55142 .55299 .5578 .55384 .56997 .55136 .56368 .55344 Mtetra
.162 0 0 r
.56368 .55344 .56997 .55136 .5822 .54886 .57601 .55304 Mtetra
.182 0 0 r
.57601 .55304 .5822 .54886 .59449 .54589 .58839 .55106 Mtetra
.113 0 0 r
.58839 .55106 .59449 .54589 .60682 .54219 .60081 .54734 Mtetra
0 0 0 r
.60081 .54734 .60682 .54219 .61919 .53775 .61323 .54189 Mtetra
.61323 .54189 .61919 .53775 .63159 .53285 .62565 .53482 Mtetra
.566 .931 .785 r
.62565 .53482 .63159 .53285 .64403 .5279 .63806 .52689 Mtetra
.725 .966 .937 r
.63806 .52689 .64403 .5279 .65654 .52328 .65053 .51938 Mtetra
.723 .876 .952 r
.65053 .51938 .65654 .52328 .66911 .51905 .66307 .51322 Mtetra
.687 .8 .935 r
.66307 .51322 .66911 .51905 .68175 .51509 .67571 .50835 Mtetra
.665 .765 .924 r
.67571 .50835 .68175 .51509 .69445 .51123 .68844 .50419 Mtetra
.658 .754 .921 r
.68844 .50419 .69445 .51123 .70721 .50738 .70124 .50025 Mtetra
.656 .752 .92 r
.70124 .50025 .70721 .50738 .72003 .50352 .7141 .49635 Mtetra
.656 .751 .92 r
.7141 .49635 .72003 .50352 .7329 .49965 .72701 .49245 Mtetra
.72701 .49245 .7329 .49965 .74584 .49575 .73999 .48852 Mtetra
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Mtetra
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Mtetra
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56793 Mtetra
.44902 .56793 .45576 .57452 .46753 .57096 .46082 .56434 Mtetra
.46082 .56434 .46753 .57096 .47935 .56738 .47267 .56074 Mtetra
.654 .751 .921 r
.47267 .56074 .47935 .56738 .49122 .5638 .48457 .55717 Mtetra
.645 .749 .925 r
.48457 .55717 .49122 .5638 .50314 .56025 .49653 .55385 Mtetra
.603 .744 .944 r
.49653 .55385 .50314 .56025 .51512 .55693 .50853 .55153 Mtetra
.455 .721 .982 r
.50853 .55153 .51512 .55693 .52715 .55431 .5206 .55148 Mtetra
.01 .544 .847 r
.5206 .55148 .52715 .55431 .53924 .55297 .53274 .55403 Mtetra
.371 0 0 r
.53274 .55403 .53924 .55297 .55142 .55299 .54499 .55693 Mtetra
.309 0 0 r
.54499 .55693 .55142 .55299 .56368 .55344 .55732 .55689 Mtetra
0 0 0 r
.55732 .55689 .56368 .55344 .57601 .55304 .56968 .55333 Mtetra
.479 .897 .889 r
.56968 .55333 .57601 .55304 .58839 .55106 .58207 .54857 Mtetra
.58 .883 .992 r
.58207 .54857 .58839 .55106 .60081 .54734 .59454 .54483 Mtetra
.506 .854 .993 r
.59454 .54483 .60081 .54734 .61323 .54189 .60708 .54212 Mtetra
.392 .851 .866 r
.60708 .54212 .61323 .54189 .62565 .53482 .61966 .5382 Mtetra
.384 .809 .63 r
.61966 .5382 .62565 .53482 .63806 .52689 .63218 .53072 Mtetra
.564 .897 .65 r
.63218 .53072 .63806 .52689 .65053 .51938 .64462 .52025 Mtetra
.759 .995 .852 r
.64462 .52025 .65053 .51938 .66307 .51322 .65709 .5101 Mtetra
.761 .912 .941 r
.65709 .5101 .66307 .51322 .67571 .50835 .66967 .50257 Mtetra
.697 .808 .934 r
.66967 .50257 .67571 .50835 .68844 .50419 .6824 .49733 Mtetra
.666 .764 .924 r
.6824 .49733 .68844 .50419 .70124 .50025 .69522 .4931 Mtetra
.657 .753 .921 r
.69522 .4931 .70124 .50025 .7141 .49635 .70812 .48913 Mtetra
.656 .752 .92 r
.70812 .48913 .7141 .49635 .72701 .49245 .72107 .48518 Mtetra
.656 .751 .92 r
.72107 .48518 .72701 .49245 .73999 .48852 .73409 .48122 Mtetra
.73409 .48122 .73999 .48852 .75302 .48458 .74716 .47725 Mtetra
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Mtetra
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Mtetra
.43044 .5649 .43727 .57151 .44902 .56793 .44222 .56129 Mtetra
.44222 .56129 .44902 .56793 .46082 .56434 .45405 .55768 Mtetra
.655 .751 .921 r
.45405 .55768 .46082 .56434 .47267 .56074 .46594 .55406 Mtetra
.65 .75 .923 r
.46594 .55406 .47267 .56074 .48457 .55717 .47787 .55059 Mtetra
.619 .744 .936 r
.47787 .55059 .48457 .55717 .49653 .55385 .48985 .54791 Mtetra
.48 .713 .972 r
.48985 .54791 .49653 .55385 .50853 .55153 .50188 .54772 Mtetra
0 .488 .845 r
.50188 .54772 .50853 .55153 .5206 .55148 .51397 .55145 Mtetra
.457 0 0 r
.51397 .55145 .5206 .55148 .53274 .55403 .52616 .55637 Mtetra
.168 0 0 r
.52616 .55637 .53274 .55403 .54499 .55693 .53846 .55587 Mtetra
.765 .962 .931 r
.53846 .55587 .54499 .55693 .55732 .55689 .55077 .5477 Mtetra
.784 .731 .803 r
.55077 .5477 .55732 .55689 .56968 .55333 .56307 .53691 Mtetra
.696 .603 .748 r
.56307 .53691 .56968 .55333 .58207 .54857 .57542 .52879 Mtetra
.625 .538 .736 r
.57542 .52879 .58207 .54857 .59454 .54483 .58788 .52502 Mtetra
.555 .497 .745 r
.58788 .52502 .59454 .54483 .60708 .54212 .60048 .5256 Mtetra
.484 .487 .784 r
.60048 .5256 .60708 .54212 .61966 .5382 .61325 .52888 Mtetra
.504 .625 .904 r
.61325 .52888 .61966 .5382 .63218 .53072 .62606 .52953 Mtetra
.707 .96 .946 r
.62606 .52953 .63218 .53072 .64462 .52025 .63869 .52242 Mtetra
.79 .995 .778 r
.63869 .52242 .64462 .52025 .65709 .5101 .65114 .50982 Mtetra
.835 .987 .867 r
.65114 .50982 .65709 .5101 .66967 .50257 .66364 .4984 Mtetra
.761 .878 .931 r
.66364 .4984 .66967 .50257 .6824 .49733 .67632 .49093 Mtetra
.687 .787 .927 r
.67632 .49093 .6824 .49733 .69522 .4931 .68915 .48599 Mtetra
.661 .758 .922 r
.68915 .48599 .69522 .4931 .70812 .48913 .70208 .48186 Mtetra
.656 .752 .92 r
.70208 .48186 .70812 .48913 .72107 .48518 .71508 .47786 Mtetra
.656 .751 .92 r
.71508 .47786 .72107 .48518 .73409 .48122 .72814 .47387 Mtetra
.72814 .47387 .73409 .48122 .74716 .47725 .74126 .46986 Mtetra
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Mtetra
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Mtetra
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55823 Mtetra
.42355 .55823 .43044 .5649 .44222 .56129 .43536 .5546 Mtetra
.43536 .5546 .44222 .56129 .45405 .55768 .44723 .55096 Mtetra
.654 .751 .921 r
.44723 .55096 .45405 .55768 .46594 .55406 .45915 .54734 Mtetra
.642 .748 .926 r
.45915 .54734 .46594 .55406 .47787 .55059 .47111 .54405 Mtetra
.572 .731 .95 r
.47111 .54405 .47787 .55059 .48985 .54791 .48311 .54238 Mtetra
.239 .605 .953 r
.48311 .54238 .48985 .54791 .50188 .54772 .49515 .54496 Mtetra
.462 0 0 r
.49515 .54496 .50188 .54772 .51397 .55145 .50725 .55221 Mtetra
.469 0 0 r
.50725 .55221 .51397 .55145 .52616 .55637 .51949 .55678 Mtetra
.639 .962 .908 r
.51949 .55678 .52616 .55637 .53846 .55587 .53183 .54996 Mtetra
.861 .807 .796 r
.53183 .54996 .53846 .55587 .55077 .5477 .54415 .53514 Mtetra
.775 .678 .756 r
.54415 .53514 .55077 .5477 .56307 .53691 .55647 .52239 Mtetra
.697 .623 .77 r
.55647 .52239 .56307 .53691 .57542 .52879 .56884 .51505 Mtetra
.642 .606 .798 r
.56884 .51505 .57542 .52879 .58788 .52502 .58131 .51124 Mtetra
.562 .566 .815 r
.58131 .51124 .58788 .52502 .60048 .5256 .59391 .51099 Mtetra
.403 .465 .81 r
.59391 .51099 .60048 .5256 .61325 .52888 .60672 .51617 Mtetra
.277 .422 .828 r
.60672 .51617 .61325 .52888 .62606 .52953 .61972 .52345 Mtetra
.509 .73 .973 r
.61972 .52345 .62606 .52953 .63869 .52242 .63261 .52266 Mtetra
.846 .992 .847 r
.63261 .52266 .63869 .52242 .65114 .50982 .64516 .51035 Mtetra
.895 .983 .801 r
.64516 .51035 .65114 .50982 .66364 .4984 .65759 .4953 Mtetra
.83 .917 .895 r
.65759 .4953 .66364 .4984 .67632 .49093 .67021 .48496 Mtetra
.718 .812 .923 r
.67021 .48496 .67632 .49093 .68915 .48599 .68304 .47892 Mtetra
.668 .763 .922 r
.68304 .47892 .68915 .48599 .70208 .48186 .696 .47453 Mtetra
.657 .753 .92 r
.696 .47453 .70208 .48186 .71508 .47786 .70904 .47048 Mtetra
.656 .752 .92 r
.70904 .47048 .71508 .47786 .72814 .47387 .72214 .46645 Mtetra
.656 .751 .92 r
.72214 .46645 .72814 .47387 .74126 .46986 .7353 .4624 Mtetra
.7353 .4624 .74126 .46986 .75443 .46583 .74852 .45834 Mtetra
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Mtetra
.40481 .55516 .41179 .56185 .42355 .55823 .41661 .55152 Mtetra
.41661 .55152 .42355 .55823 .43536 .5546 .42845 .54786 Mtetra
.42845 .54786 .43536 .5546 .44723 .55096 .44035 .54418 Mtetra
.653 .751 .921 r
.44035 .54418 .44723 .55096 .45915 .54734 .4523 .54057 Mtetra
.633 .746 .929 r
.4523 .54057 .45915 .54734 .47111 .54405 .4643 .53748 Mtetra
.518 .71 .959 r
.4643 .53748 .47111 .54405 .48311 .54238 .47632 .53685 Mtetra
0 .418 .841 r
.47632 .53685 .48311 .54238 .49515 .54496 .48834 .54222 Mtetra
.653 .098 0 r
.48834 .54222 .49515 .54496 .50725 .55221 .50045 .55297 Mtetra
.451 0 0 r
.50045 .55297 .50725 .55221 .51949 .55678 .51274 .55729 Mtetra
.869 .981 .845 r
.51274 .55729 .51949 .55678 .53183 .54996 .52515 .54445 Mtetra
.905 .802 .735 r
.52515 .54445 .53183 .54996 .54415 .53514 .53751 .52279 Mtetra
.805 .691 .739 r
.53751 .52279 .54415 .53514 .55647 .52239 .54983 .50685 Mtetra
.698 .613 .758 r
.54983 .50685 .55647 .52239 .56884 .51505 .56222 .49901 Mtetra
.635 .576 .771 r
.56222 .49901 .56884 .51505 .58131 .51124 .57468 .49517 Mtetra
.555 .533 .786 r
.57468 .49517 .58131 .51124 .59391 .51099 .58729 .49535 Mtetra
.303 .39 .786 r
.58729 .49535 .59391 .51099 .60672 .51617 .60016 .50367 Mtetra
0 .17 .706 r
.60016 .50367 .60672 .51617 .61972 .52345 .61334 .51777 Mtetra
.033 .467 .879 r
.61334 .51777 .61972 .52345 .63261 .52266 .62645 .523 Mtetra
.837 .994 .849 r
.62645 .523 .63261 .52266 .64516 .51035 .63909 .51087 Mtetra
.938 .957 .756 r
.63909 .51087 .64516 .51035 .65759 .4953 .65148 .49221 Mtetra
.877 .909 .847 r
.65148 .49221 .65759 .4953 .67021 .48496 .66405 .47897 Mtetra
.747 .819 .909 r
.66405 .47897 .67021 .48496 .68304 .47892 .67688 .47181 Mtetra
.675 .766 .919 r
.67688 .47181 .68304 .47892 .696 .47453 .68987 .46715 Mtetra
.658 .753 .92 r
.68987 .46715 .696 .47453 .70904 .47048 .70294 .46303 Mtetra
.656 .752 .92 r
.70294 .46303 .70904 .47048 .72214 .46645 .71609 .45897 Mtetra
.656 .751 .92 r
.71609 .45897 .72214 .46645 .7353 .4624 .72929 .45489 Mtetra
.72929 .45489 .7353 .4624 .74852 .45834 .74255 .45079 Mtetra
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Mtetra
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43837 Mtetra
.78271 .43837 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Mtetra
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Mtetra
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54474 Mtetra
.40961 .54474 .41661 .55152 .42845 .54786 .42149 .54105 Mtetra
.42149 .54105 .42845 .54786 .44035 .54418 .43342 .53735 Mtetra
.653 .75 .922 r
.43342 .53735 .44035 .54418 .4523 .54057 .4454 .53372 Mtetra
.628 .743 .93 r
.4454 .53372 .4523 .54057 .4643 .53748 .45743 .53075 Mtetra
.476 .689 .96 r
.45743 .53075 .4643 .53748 .47632 .53685 .46946 .53085 Mtetra
0 .259 .725 r
.46946 .53085 .47632 .53685 .48834 .54222 .48148 .53851 Mtetra
.743 .224 0 r
.48148 .53851 .48834 .54222 .50045 .55297 .49357 .55297 Mtetra
.521 0 0 r
.49357 .55297 .50045 .55297 .51274 .55729 .50589 .55902 Mtetra
.916 .974 .78 r
.50589 .55902 .51274 .55729 .52515 .54445 .51839 .54235 Mtetra
.954 .836 .689 r
.51839 .54235 .52515 .54445 .53751 .52279 .53083 .51391 Mtetra
.867 .749 .73 r
.53083 .51391 .53751 .52279 .54983 .50685 .54319 .4934 Mtetra
.73 .651 .771 r
.54319 .4934 .54983 .50685 .56222 .49901 .55558 .48412 Mtetra
.638 .591 .785 r
.55558 .48412 .56222 .49901 .57468 .49517 .56806 .48025 Mtetra
.515 .526 .805 r
.56806 .48025 .57468 .49517 .58729 .49535 .58068 .4818 Mtetra
.006 .231 .74 r
.58068 .4818 .58729 .49535 .60016 .50367 .59364 .49465 Mtetra
.659 .214 0 r
.59364 .49465 .60016 .50367 .61334 .51777 .60698 .51552 Mtetra
.535 0 0 r
.60698 .51552 .61334 .51777 .62645 .523 .62024 .52455 Mtetra
.849 .998 .797 r
.62024 .52455 .62645 .523 .63909 .51087 .63292 .51062 Mtetra
.96 .917 .722 r
.63292 .51062 .63909 .51087 .65148 .49221 .64527 .48813 Mtetra
.895 .874 .808 r
.64527 .48813 .65148 .49221 .66405 .47897 .65781 .4725 Mtetra
.763 .81 .89 r
.65781 .4725 .66405 .47897 .67688 .47181 .67065 .46454 Mtetra
.68 .765 .915 r
.67065 .46454 .67688 .47181 .68987 .46715 .68368 .4597 Mtetra
.659 .753 .92 r
.68368 .4597 .68987 .46715 .70294 .46303 .6968 .45552 Mtetra
.656 .752 .92 r
.6968 .45552 .70294 .46303 .71609 .45897 .70998 .45142 Mtetra
.656 .751 .92 r
.70998 .45142 .71609 .45897 .72929 .45489 .72323 .4473 Mtetra
.72323 .4473 .72929 .45489 .74255 .45079 .73653 .44317 Mtetra
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Mtetra
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43837 .77683 .43065 Mtetra
.77683 .43065 .78271 .43837 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Mtetra
.39069 .54162 .39778 .54842 .40961 .54474 .40255 .53792 Mtetra
.40255 .53792 .40961 .54474 .42149 .54105 .41447 .5342 Mtetra
.41447 .5342 .42149 .54105 .43342 .53735 .42643 .53047 Mtetra
.652 .75 .922 r
.42643 .53047 .43342 .53735 .4454 .53372 .43845 .52681 Mtetra
.626 .742 .931 r
.43845 .52681 .4454 .53372 .45743 .53075 .4505 .52387 Mtetra
.459 .677 .959 r
.4505 .52387 .45743 .53075 .46946 .53085 .46256 .52428 Mtetra
0 .19 .677 r
.46256 .52428 .46946 .53085 .48148 .53851 .47457 .53318 Mtetra
.776 .282 0 r
.47457 .53318 .48148 .53851 .49357 .55297 .48663 .55061 Mtetra
.625 .061 0 r
.48663 .55061 .49357 .55297 .50589 .55902 .49896 .56057 Mtetra
.893 .984 .803 r
.49896 .56057 .50589 .55902 .51839 .54235 .51154 .5455 Mtetra
.984 .891 .646 r
.51154 .5455 .51839 .54235 .53083 .51391 .52411 .51408 Mtetra
.966 .884 .698 r
.52411 .51408 .53083 .51391 .54319 .4934 .53654 .48814 Mtetra
.854 .832 .825 r
.53654 .48814 .54319 .4934 .55558 .48412 .54896 .475 Mtetra
.655 .699 .879 r
.54896 .475 .55558 .48412 .56806 .48025 .56147 .4711 Mtetra
.229 .481 .89 r
.56147 .4711 .56806 .48025 .58068 .4818 .57417 .47647 Mtetra
.747 .25 0 r
.57417 .47647 .58068 .4818 .59364 .49465 .58724 .49472 Mtetra
.851 .404 .145 r
.58724 .49472 .59364 .49465 .60698 .51552 .60068 .51854 Mtetra
.608 .079 0 r
.60068 .51854 .60698 .51552 .62024 .52455 .61395 .52591 Mtetra
.922 .975 .757 r
.61395 .52591 .62024 .52455 .63292 .51062 .6266 .50796 Mtetra
.956 .86 .705 r
.6266 .50796 .63292 .51062 .64527 .48813 .63893 .4824 Mtetra
.888 .831 .784 r
.63893 .4824 .64527 .48813 .65781 .4725 .65149 .46545 Mtetra
.766 .795 .877 r
.65149 .46545 .65781 .4725 .67065 .46454 .66437 .4571 Mtetra
.681 .762 .912 r
.66437 .4571 .67065 .46454 .68368 .4597 .67744 .45216 Mtetra
.659 .753 .919 r
.67744 .45216 .68368 .4597 .6968 .45552 .6906 .44795 Mtetra
.656 .751 .92 r
.6906 .44795 .6968 .45552 .70998 .45142 .70382 .44381 Mtetra
.70382 .44381 .70998 .45142 .72323 .4473 .71711 .43966 Mtetra
.71711 .43966 .72323 .4473 .73653 .44317 .73046 .43549 Mtetra
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Mtetra
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Mtetra
.38355 .53477 .39069 .54162 .40255 .53792 .39544 .53103 Mtetra
.39544 .53103 .40255 .53792 .41447 .5342 .40739 .52728 Mtetra
.40739 .52728 .41447 .5342 .42643 .53047 .41938 .52352 Mtetra
.652 .75 .922 r
.41938 .52352 .42643 .53047 .43845 .52681 .43144 .51984 Mtetra
.625 .742 .931 r
.43144 .51984 .43845 .52681 .4505 .52387 .44352 .51689 Mtetra
.453 .673 .958 r
.44352 .51689 .4505 .52387 .46256 .52428 .4556 .51739 Mtetra
0 .176 .67 r
.4556 .51739 .46256 .52428 .47457 .53318 .46761 .52665 Mtetra
.768 .285 0 r
.46761 .52665 .47457 .53318 .48663 .55061 .47965 .54506 Mtetra
.584 .053 0 r
.47965 .54506 .48663 .55061 .49896 .56057 .49197 .55727 Mtetra
.844 .891 .873 r
.49197 .55727 .49896 .56057 .51154 .5455 .50461 .54596 Mtetra
.969 .88 .691 r
.50461 .54596 .51154 .5455 .52411 .51408 .51729 .51861 Mtetra
.948 .955 .669 r
.51729 .51861 .52411 .51408 .53654 .48814 .52985 .49531 Mtetra
0 0 0 r
.52985 .49531 .53654 .48814 .54896 .475 .54238 .48305 Mtetra
.225 0 0 r
.54238 .48305 .54896 .475 .56147 .4711 .55499 .47914 Mtetra
.562 .108 .131 r
.55499 .47914 .56147 .4711 .57417 .47647 .56776 .48359 Mtetra
.751 .324 .236 r
.56776 .48359 .57417 .47647 .58724 .49472 .58084 .49916 Mtetra
.802 .365 .209 r
.58084 .49916 .58724 .49472 .60068 .51854 .59422 .51883 Mtetra
.335 0 0 r
.59422 .51883 .60068 .51854 .61395 .52591 .60744 .52235 Mtetra
.928 .866 .758 r
.60744 .52235 .61395 .52591 .6266 .50796 .62011 .50207 Mtetra
.931 .806 .7 r
.62011 .50207 .6266 .50796 .63893 .4824 .6325 .47544 Mtetra
.878 .804 .773 r
.6325 .47544 .63893 .4824 .65149 .46545 .64511 .45806 Mtetra
.766 .788 .871 r
.64511 .45806 .65149 .46545 .66437 .4571 .65804 .44956 Mtetra
.682 .761 .911 r
.65804 .44956 .66437 .4571 .67744 .45216 .67115 .44456 Mtetra
.659 .753 .919 r
.67115 .44456 .67744 .45216 .6906 .44795 .68435 .4403 Mtetra
.656 .751 .92 r
.68435 .4403 .6906 .44795 .70382 .44381 .69761 .43613 Mtetra
.69761 .43613 .70382 .44381 .71711 .43966 .71095 .43194 Mtetra
.71095 .43194 .71711 .43966 .73046 .43549 .72434 .42774 Mtetra
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Mtetra
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40208 Mtetra
.80604 .40208 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Mtetra
.37634 .52786 .38355 .53477 .39544 .53103 .38827 .52409 Mtetra
.38827 .52409 .39544 .53103 .40739 .52728 .40025 .52031 Mtetra
.40025 .52031 .40739 .52728 .41938 .52352 .41228 .51652 Mtetra
.652 .75 .922 r
.41228 .51652 .41938 .52352 .43144 .51984 .42436 .51281 Mtetra
.624 .742 .931 r
.42436 .51281 .43144 .51984 .44352 .51689 .43648 .50986 Mtetra
.448 .671 .958 r
.43648 .50986 .44352 .51689 .4556 .51739 .44858 .51041 Mtetra
0 .167 .662 r
.44858 .51041 .4556 .51739 .46761 .52665 .4606 .51982 Mtetra
.763 .282 0 r
.4606 .51982 .46761 .52665 .47965 .54506 .47263 .53833 Mtetra
.506 0 0 r
.47263 .53833 .47965 .54506 .49197 .55727 .48495 .55043 Mtetra
.812 .794 .835 r
.48495 .55043 .49197 .55727 .50461 .54596 .49764 .53922 Mtetra
.91 .779 .703 r
.49764 .53922 .50461 .54596 .51729 .51861 .5104 .51287 Mtetra
.905 .804 .738 r
.5104 .51287 .51729 .51861 .52985 .49531 .52305 .49126 Mtetra
.835 .875 .873 r
.52305 .49126 .52985 .49531 .54238 .48305 .53565 .48031 Mtetra
.588 .883 .992 r
.53565 .48031 .54238 .48305 .55499 .47914 .54831 .47636 Mtetra
0 .498 .804 r
.54831 .47636 .55499 .47914 .56776 .48359 .56111 .47945 Mtetra
.665 .13 0 r
.56111 .47945 .56776 .48359 .58084 .49916 .57418 .49326 Mtetra
.73 .235 0 r
.57418 .49326 .58084 .49916 .59422 .51883 .58753 .51186 Mtetra
.256 .577 .942 r
.58753 .51186 .59422 .51883 .60744 .52235 .60078 .51521 Mtetra
.892 .797 .748 r
.60078 .51521 .60744 .52235 .62011 .50207 .61353 .49497 Mtetra
.921 .789 .698 r
.61353 .49497 .62011 .50207 .6325 .47544 .626 .46818 Mtetra
.877 .799 .77 r
.626 .46818 .6325 .47544 .64511 .45806 .63867 .45058 Mtetra
.768 .787 .869 r
.63867 .45058 .64511 .45806 .65804 .44956 .65164 .44195 Mtetra
.683 .762 .911 r
.65164 .44195 .65804 .44956 .67115 .44456 .6648 .43689 Mtetra
.659 .753 .919 r
.6648 .43689 .67115 .44456 .68435 .4403 .67804 .4326 Mtetra
.656 .751 .92 r
.67804 .4326 .68435 .4403 .69761 .43613 .69135 .42838 Mtetra
.69135 .42838 .69761 .43613 .71095 .43194 .70472 .42416 Mtetra
.70472 .42416 .71095 .43194 .72434 .42774 .71816 .41992 Mtetra
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Mtetra
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40208 .80014 .39403 Mtetra
.80014 .39403 .80604 .40208 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53218 Mtetra
.33352 .53218 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Mtetra
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .52089 Mtetra
.36908 .52089 .37634 .52786 .38827 .52409 .38104 .5171 Mtetra
.38104 .5171 .38827 .52409 .40025 .52031 .39305 .51328 Mtetra
.655 .751 .92 r
.39305 .51328 .40025 .52031 .41228 .51652 .40512 .50946 Mtetra
.652 .75 .922 r
.40512 .50946 .41228 .51652 .42436 .51281 .41723 .50572 Mtetra
.623 .741 .932 r
.41723 .50572 .42436 .51281 .43648 .50986 .42938 .50276 Mtetra
.442 .668 .958 r
.42938 .50276 .43648 .50986 .44858 .51041 .44151 .50338 Mtetra
0 .155 .651 r
.44151 .50338 .44858 .51041 .4606 .51982 .45353 .51295 Mtetra
.765 .284 0 r
.45353 .51295 .4606 .51982 .47263 .53833 .46554 .53154 Mtetra
.493 0 0 r
.46554 .53154 .47263 .53833 .48495 .55043 .47787 .54342 Mtetra
.815 .791 .83 r
.47787 .54342 .48495 .55043 .49764 .53922 .49062 .53184 Mtetra
.905 .77 .701 r
.49062 .53184 .49764 .53922 .5104 .51287 .50347 .50525 Mtetra
.887 .773 .73 r
.50347 .50525 .5104 .51287 .52305 .49126 .51619 .48347 Mtetra
.803 .774 .826 r
.51619 .48347 .52305 .49126 .53565 .48031 .52884 .47236 Mtetra
.654 .735 .909 r
.52884 .47236 .53565 .48031 .54831 .47636 .54154 .46839 Mtetra
.31 .573 .933 r
.54154 .46839 .54831 .47636 .56111 .47945 .55435 .47156 Mtetra
0 .003 .528 r
.55435 .47156 .56111 .47945 .57418 .49326 .56743 .48546 Mtetra
.664 .19 0 r
.56743 .48546 .57418 .49326 .58753 .51186 .58078 .50424 Mtetra
.263 .561 .933 r
.58078 .50424 .58753 .51186 .60078 .51521 .59407 .5079 Mtetra
.889 .795 .749 r
.59407 .5079 .60078 .51521 .61353 .49497 .60689 .48781 Mtetra
.921 .789 .698 r
.60689 .48781 .61353 .49497 .626 .46818 .61944 .46087 Mtetra
.878 .799 .769 r
.61944 .46087 .626 .46818 .63867 .45058 .63218 .44304 Mtetra
.769 .788 .868 r
.63218 .44304 .63867 .45058 .65164 .44195 .6452 .43428 Mtetra
.683 .762 .911 r
.6452 .43428 .65164 .44195 .6648 .43689 .65839 .42916 Mtetra
.659 .753 .919 r
.65839 .42916 .6648 .43689 .67804 .4326 .67168 .42482 Mtetra
.656 .752 .92 r
.67168 .42482 .67804 .4326 .69135 .42838 .68503 .42057 Mtetra
.656 .751 .92 r
.68503 .42057 .69135 .42838 .70472 .42416 .69845 .41631 Mtetra
.69845 .41631 .70472 .42416 .71816 .41992 .71193 .41203 Mtetra
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Mtetra
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53218 .32609 .52525 Mtetra
.32609 .52525 .33352 .53218 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Mtetra
.34981 .51768 .35717 .52467 .36908 .52089 .36175 .51387 Mtetra
.36175 .51387 .36908 .52089 .38104 .5171 .37374 .51004 Mtetra
.37374 .51004 .38104 .5171 .39305 .51328 .38579 .5062 Mtetra
.655 .751 .92 r
.38579 .5062 .39305 .51328 .40512 .50946 .39789 .50234 Mtetra
.652 .75 .922 r
.39789 .50234 .40512 .50946 .41723 .50572 .41004 .49858 Mtetra
.622 .741 .932 r
.41004 .49858 .41723 .50572 .42938 .50276 .42223 .49561 Mtetra
.436 .666 .958 r
.42223 .49561 .42938 .50276 .44151 .50338 .43437 .49631 Mtetra
0 .143 .64 r
.43437 .49631 .44151 .50338 .45353 .51295 .44639 .50603 Mtetra
.767 .286 0 r
.44639 .50603 .45353 .51295 .46554 .53154 .45839 .52469 Mtetra
0 .031 .525 r
.45839 .52469 .46554 .53154 .47787 .54342 .47073 .53628 Mtetra
.819 .79 .825 r
.47073 .53628 .47787 .54342 .49062 .53184 .48354 .52427 Mtetra
.904 .769 .701 r
.48354 .52427 .49062 .53184 .50347 .50525 .49647 .49758 Mtetra
.886 .774 .732 r
.49647 .49758 .50347 .50525 .51619 .48347 .50927 .47601 Mtetra
.804 .783 .834 r
.50927 .47601 .51619 .48347 .52884 .47236 .52197 .46508 Mtetra
.654 .756 .925 r
.52197 .46508 .52884 .47236 .54154 .46839 .53471 .46106 Mtetra
.293 .587 .944 r
.53471 .46106 .54154 .46839 .55435 .47156 .54755 .46399 Mtetra
0 .001 .519 r
.54755 .46399 .55435 .47156 .56743 .48546 .56062 .47762 Mtetra
.665 .191 0 r
.56062 .47762 .56743 .48546 .58078 .50424 .57397 .49643 Mtetra
.242 .544 .927 r
.57397 .49643 .58078 .50424 .59407 .5079 .58729 .50045 Mtetra
.887 .794 .752 r
.58729 .50045 .59407 .5079 .60689 .48781 .60019 .48059 Mtetra
.921 .788 .697 r
.60019 .48059 .60689 .48781 .61944 .46087 .61283 .45351 Mtetra
.879 .8 .767 r
.61283 .45351 .61944 .46087 .63218 .44304 .62563 .43545 Mtetra
.771 .789 .867 r
.62563 .43545 .63218 .44304 .6452 .43428 .63869 .42654 Mtetra
.684 .762 .911 r
.63869 .42654 .6452 .43428 .65839 .42916 .65193 .42135 Mtetra
.66 .753 .919 r
.65193 .42135 .65839 .42916 .67168 .42482 .66526 .41698 Mtetra
.656 .752 .92 r
.66526 .41698 .67168 .42482 .68503 .42057 .67866 .41269 Mtetra
.656 .751 .92 r
.67866 .41269 .68503 .42057 .69845 .41631 .69212 .40839 Mtetra
.69212 .40839 .69845 .41631 .71193 .41203 .70564 .40408 Mtetra
.70564 .40408 .71193 .41203 .72548 .40773 .71923 .39974 Mtetra
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Mtetra
.35437 .50679 .36175 .51387 .37374 .51004 .36639 .50293 Mtetra
.36639 .50293 .37374 .51004 .38579 .5062 .37847 .49905 Mtetra
.655 .751 .92 r
.37847 .49905 .38579 .5062 .39789 .50234 .39061 .49516 Mtetra
.652 .75 .922 r
.39061 .49516 .39789 .50234 .41004 .49858 .40279 .49137 Mtetra
.621 .741 .932 r
.40279 .49137 .41004 .49858 .42223 .49561 .41501 .4884 Mtetra
.429 .662 .959 r
.41501 .4884 .42223 .49561 .43437 .49631 .42717 .48918 Mtetra
0 .13 .627 r
.42717 .48918 .43437 .49631 .44639 .50603 .43919 .49908 Mtetra
.768 .288 0 r
.43919 .49908 .44639 .50603 .45839 .52469 .45118 .51781 Mtetra
0 .049 .542 r
.45118 .51781 .45839 .52469 .47073 .53628 .46353 .52909 Mtetra
.823 .79 .821 r
.46353 .52909 .47073 .53628 .48354 .52427 .4764 .51664 Mtetra
.905 .769 .701 r
.4764 .51664 .48354 .52427 .49647 .49758 .48942 .48981 Mtetra
.885 .774 .734 r
.48942 .48981 .49647 .49758 .50927 .47601 .50229 .46835 Mtetra
.801 .78 .834 r
.50229 .46835 .50927 .47601 .52197 .46508 .51505 .4575 Mtetra
.654 .749 .92 r
.51505 .4575 .52197 .46508 .53471 .46106 .52782 .45345 Mtetra
.312 .59 .943 r
.52782 .45345 .53471 .46106 .54755 .46399 .54068 .45623 Mtetra
0 .015 .536 r
.54068 .45623 .54755 .46399 .56062 .47762 .55376 .46968 Mtetra
.666 .193 0 r
.55376 .46968 .56062 .47762 .57397 .49643 .5671 .48855 Mtetra
.213 .527 .92 r
.5671 .48855 .57397 .49643 .58729 .50045 .58045 .49295 Mtetra
.885 .795 .754 r
.58045 .49295 .58729 .50045 .60019 .48059 .59343 .47333 Mtetra
.921 .789 .697 r
.59343 .47333 .60019 .48059 .61283 .45351 .60616 .44611 Mtetra
.881 .8 .765 r
.60616 .44611 .61283 .45351 .62563 .43545 .61902 .4278 Mtetra
.773 .789 .866 r
.61902 .4278 .62563 .43545 .63869 .42654 .63213 .41874 Mtetra
.685 .763 .91 r
.63213 .41874 .63869 .42654 .65193 .42135 .64542 .41348 Mtetra
.66 .753 .919 r
.64542 .41348 .65193 .42135 .66526 .41698 .65879 .40907 Mtetra
.656 .752 .92 r
.65879 .40907 .66526 .41698 .67866 .41269 .67223 .40474 Mtetra
.656 .751 .92 r
.67223 .40474 .67866 .41269 .69212 .40839 .68573 .4004 Mtetra
.68573 .4004 .69212 .40839 .70564 .40408 .6993 .39605 Mtetra
.6993 .39605 .70564 .40408 .71923 .39974 .71294 .39167 Mtetra
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51505 Mtetra
.29922 .51505 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Mtetra
.34692 .49965 .35437 .50679 .36639 .50293 .35898 .49575 Mtetra
.35898 .49575 .36639 .50293 .37847 .49905 .37109 .49184 Mtetra
.655 .751 .92 r
.37109 .49184 .37847 .49905 .39061 .49516 .38326 .48792 Mtetra
.651 .75 .922 r
.38326 .48792 .39061 .49516 .40279 .49137 .39548 .48411 Mtetra
.62 .74 .933 r
.39548 .48411 .40279 .49137 .41501 .4884 .40773 .48114 Mtetra
.422 .659 .958 r
.40773 .48114 .41501 .4884 .42717 .48918 .41991 .482 Mtetra
0 .116 .614 r
.41991 .482 .42717 .48918 .43919 .49908 .43193 .4921 Mtetra
.77 .29 0 r
.43193 .4921 .43919 .49908 .45118 .51781 .44391 .5109 Mtetra
0 .068 .56 r
.44391 .5109 .45118 .51781 .46353 .52909 .45627 .52187 Mtetra
.828 .79 .816 r
.45627 .52187 .46353 .52909 .4764 .51664 .4692 .50896 Mtetra
.905 .769 .7 r
.4692 .50896 .4764 .51664 .48942 .48981 .48231 .48195 Mtetra
.884 .773 .734 r
.48231 .48195 .48942 .48981 .50229 .46835 .49525 .46049 Mtetra
.799 .777 .833 r
.49525 .46049 .50229 .46835 .51505 .4575 .50806 .44964 Mtetra
.654 .743 .915 r
.50806 .44964 .51505 .4575 .52782 .45345 .52087 .44556 Mtetra
.325 .59 .941 r
.52087 .44556 .52782 .45345 .54068 .45623 .53376 .44826 Mtetra
0 .025 .548 r
.53376 .44826 .54068 .45623 .55376 .46968 .54683 .46162 Mtetra
.667 .195 0 r
.54683 .46162 .55376 .46968 .5671 .48855 .56017 .48061 Mtetra
.183 .508 .912 r
.56017 .48061 .5671 .48855 .58045 .49295 .57355 .4854 Mtetra
.884 .795 .757 r
.57355 .4854 .58045 .49295 .59343 .47333 .58661 .46603 Mtetra
.922 .789 .697 r
.58661 .46603 .59343 .47333 .60616 .44611 .59942 .43867 Mtetra
.882 .8 .764 r
.59942 .43867 .60616 .44611 .61902 .4278 .61235 .42009 Mtetra
.775 .79 .865 r
.61235 .42009 .61902 .4278 .63213 .41874 .62552 .41088 Mtetra
.686 .763 .91 r
.62552 .41088 .63213 .41874 .64542 .41348 .63884 .40555 Mtetra
.66 .753 .919 r
.63884 .40555 .64542 .41348 .65879 .40907 .65226 .40108 Mtetra
.656 .752 .92 r
.65226 .40108 .65879 .40907 .67223 .40474 .66574 .39672 Mtetra
.656 .751 .92 r
.66574 .39672 .67223 .40474 .68573 .4004 .67929 .39235 Mtetra
.67929 .39235 .68573 .4004 .6993 .39605 .69291 .38795 Mtetra
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Mtetra
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51505 .29158 .50797 Mtetra
.29158 .50797 .29922 .51505 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Mtetra
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Mtetra
.33941 .49245 .34692 .49965 .35898 .49575 .3515 .48852 Mtetra
.3515 .48852 .35898 .49575 .37109 .49184 .36365 .48458 Mtetra
.655 .751 .92 r
.36365 .48458 .37109 .49184 .38326 .48792 .37585 .48062 Mtetra
.651 .75 .922 r
.37585 .48062 .38326 .48792 .39548 .48411 .38811 .47678 Mtetra
.618 .74 .933 r
.38811 .47678 .39548 .48411 .40773 .48114 .40038 .47381 Mtetra
.414 .655 .958 r
.40038 .47381 .40773 .48114 .41991 .482 .41259 .47477 Mtetra
0 .102 .6 r
.41259 .47477 .41991 .482 .43193 .4921 .42461 .48507 Mtetra
.771 .291 0 r
.42461 .48507 .43193 .4921 .44391 .5109 .43657 .50392 Mtetra
0 .093 .585 r
.43657 .50392 .44391 .5109 .45627 .52187 .44894 .51449 Mtetra
.832 .788 .81 r
.44894 .51449 .45627 .52187 .4692 .50896 .46194 .50107 Mtetra
.904 .767 .7 r
.46194 .50107 .4692 .50896 .48231 .48195 .47514 .47404 Mtetra
.882 .774 .737 r
.47514 .47404 .48231 .48195 .49525 .46049 .48815 .45297 Mtetra
.798 .786 .842 r
.48815 .45297 .49525 .46049 .50806 .44964 .50101 .44243 Mtetra
.653 .763 .93 r
.50101 .44243 .50806 .44964 .52087 .44556 .51386 .43831 Mtetra
.32 .611 .953 r
.51386 .43831 .52087 .44556 .53376 .44826 .52678 .44063 Mtetra
0 .033 .548 r
.52678 .44063 .53376 .44826 .54683 .46162 .53985 .45354 Mtetra
.667 .194 0 r
.53985 .45354 .54683 .46162 .56017 .48061 .55318 .47248 Mtetra
.156 .487 .902 r
.55318 .47248 .56017 .48061 .57355 .4854 .56658 .47771 Mtetra
.88 .794 .76 r
.56658 .47771 .57355 .4854 .58661 .46603 .57972 .45867 Mtetra
.922 .789 .697 r
.57972 .45867 .58661 .46603 .59942 .43867 .59263 .43118 Mtetra
.884 .8 .762 r
.59263 .43118 .59942 .43867 .61235 .42009 .60563 .41233 Mtetra
.778 .791 .864 r
.60563 .41233 .61235 .42009 .62552 .41088 .61884 .40294 Mtetra
.687 .763 .91 r
.61884 .40294 .62552 .41088 .63884 .40555 .63221 .39754 Mtetra
.66 .753 .919 r
.63221 .39754 .63884 .40555 .65226 .40108 .64567 .39303 Mtetra
.656 .752 .92 r
.64567 .39303 .65226 .40108 .66574 .39672 .6592 .38863 Mtetra
.656 .751 .92 r
.6592 .38863 .66574 .39672 .67929 .39235 .67279 .38421 Mtetra
.67279 .38421 .67929 .39235 .69291 .38795 .68645 .37978 Mtetra
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Mtetra
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Mtetra
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48518 Mtetra
.33184 .48518 .33941 .49245 .3515 .48852 .34396 .48122 Mtetra
.34396 .48122 .3515 .48852 .36365 .48458 .35615 .47725 Mtetra
.655 .751 .92 r
.35615 .47725 .36365 .48458 .37585 .48062 .36838 .47326 Mtetra
.651 .75 .922 r
.36838 .47326 .37585 .48062 .38811 .47678 .38067 .46939 Mtetra
.617 .739 .934 r
.38067 .46939 .38811 .47678 .40038 .47381 .39298 .46643 Mtetra
.405 .651 .958 r
.39298 .46643 .40038 .47381 .41259 .47477 .40521 .46749 Mtetra
0 .087 .586 r
.40521 .46749 .41259 .47477 .42461 .48507 .41722 .478 Mtetra
.772 .292 0 r
.41722 .478 .42461 .48507 .43657 .50392 .42916 .49688 Mtetra
0 .126 .617 r
.42916 .49688 .43657 .50392 .44894 .51449 .44156 .50694 Mtetra
.84 .786 .799 r
.44156 .50694 .44894 .51449 .46194 .50107 .45464 .49251 Mtetra
.902 .758 .692 r
.45464 .49251 .46194 .50107 .47514 .47404 .46794 .46421 Mtetra
.872 .745 .72 r
.46794 .46421 .47514 .47404 .48815 .45297 .48104 .44171 Mtetra
.777 .71 .789 r
.48104 .44171 .48815 .45297 .50101 .44243 .49395 .43007 Mtetra
.646 .644 .834 r
.49395 .43007 .50101 .44243 .51386 .43831 .50682 .42591 Mtetra
.403 .52 .862 r
.50682 .42591 .51386 .43831 .52678 .44063 .51974 .42924 Mtetra
0 .088 .642 r
.51974 .42924 .52678 .44063 .53985 .45354 .53281 .44351 Mtetra
.621 .181 0 r
.53281 .44351 .53985 .45354 .55318 .47248 .54613 .46365 Mtetra
.121 .445 .88 r
.54613 .46365 .55318 .47248 .56658 .47771 .55956 .46982 Mtetra
.876 .792 .764 r
.55956 .46982 .56658 .47771 .57972 .45867 .57278 .45123 Mtetra
.922 .789 .697 r
.57278 .45123 .57972 .45867 .59263 .43118 .58578 .42365 Mtetra
.886 .8 .76 r
.58578 .42365 .59263 .43118 .60563 .41233 .59884 .40451 Mtetra
.78 .791 .862 r
.59884 .40451 .60563 .41233 .61884 .40294 .6121 .39494 Mtetra
.688 .764 .909 r
.6121 .39494 .61884 .40294 .63221 .39754 .62552 .38946 Mtetra
.66 .753 .919 r
.62552 .38946 .63221 .39754 .64567 .39303 .63902 .38491 Mtetra
.656 .752 .92 r
.63902 .38491 .64567 .39303 .6592 .38863 .65259 .38046 Mtetra
.656 .751 .92 r
.65259 .38046 .6592 .38863 .67279 .38421 .66623 .37601 Mtetra
.66623 .37601 .67279 .38421 .68645 .37978 .67994 .37154 Mtetra
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Mtetra
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34883 Mtetra
.74947 .34883 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48183 Mtetra
.31209 .48183 .31977 .48912 .33184 .48518 .3242 .47786 Mtetra
.3242 .47786 .33184 .48518 .34396 .48122 .33636 .47387 Mtetra
.33636 .47387 .34396 .48122 .35615 .47725 .34858 .46986 Mtetra
.655 .751 .92 r
.34858 .46986 .35615 .47725 .36838 .47326 .36085 .46584 Mtetra
.651 .75 .922 r
.36085 .46584 .36838 .47326 .38067 .46939 .37317 .46194 Mtetra
.616 .739 .934 r
.37317 .46194 .38067 .46939 .39298 .46643 .38551 .45898 Mtetra
.399 .648 .958 r
.38551 .45898 .39298 .46643 .40521 .46749 .39776 .46012 Mtetra
0 .092 .591 r
.39776 .46012 .40521 .46749 .41722 .478 .40978 .47057 Mtetra
.74 .255 0 r
.40978 .47057 .41722 .478 .42916 .49688 .42173 .48846 Mtetra
0 .368 .834 r
.42173 .48846 .42916 .49688 .44156 .50694 .43421 .49545 Mtetra
.837 .72 .735 r
.43421 .49545 .44156 .50694 .45464 .49251 .44745 .47636 Mtetra
.86 .683 .662 r
.44745 .47636 .45464 .49251 .46794 .46421 .46089 .44402 Mtetra
.804 .637 .675 r
.46089 .44402 .46794 .46421 .48104 .44171 .47405 .41952 Mtetra
.708 .576 .704 r
.47405 .41952 .48104 .44171 .49395 .43007 .48696 .40743 Mtetra
.615 .52 .723 r
.48696 .40743 .49395 .43007 .50682 .42591 .49981 .40322 Mtetra
.477 .435 .732 r
.49981 .40322 .50682 .42591 .51974 .42924 .5127 .40692 Mtetra
.112 .202 .678 r
.5127 .40692 .51974 .42924 .53281 .44351 .52571 .42309 Mtetra
0 0 .543 r
.52571 .42309 .53281 .44351 .54613 .46365 .53898 .44719 Mtetra
.17 .312 .767 r
.53898 .44719 .54613 .46365 .55956 .46982 .55244 .45796 Mtetra
.814 .721 .762 r
.55244 .45796 .55956 .46982 .57278 .45123 .56575 .44239 Mtetra
.907 .772 .701 r
.56575 .44239 .57278 .45123 .58578 .42365 .57885 .41574 Mtetra
.882 .795 .759 r
.57885 .41574 .58578 .42365 .59884 .40451 .59199 .39658 Mtetra
.781 .791 .86 r
.59199 .39658 .59884 .40451 .6121 .39494 .60531 .38687 Mtetra
.689 .764 .909 r
.60531 .38687 .6121 .39494 .62552 .38946 .61877 .38131 Mtetra
.66 .753 .919 r
.61877 .38131 .62552 .38946 .63902 .38491 .63231 .37671 Mtetra
.656 .752 .92 r
.63231 .37671 .63902 .38491 .65259 .38046 .64593 .37223 Mtetra
.656 .751 .92 r
.64593 .37223 .65259 .38046 .66623 .37601 .65962 .36773 Mtetra
.65962 .36773 .66623 .37601 .67994 .37154 .67337 .36322 Mtetra
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Mtetra
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34883 .74314 .34031 Mtetra
.74314 .34031 .74947 .34883 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48183 .30436 .47448 Mtetra
.30436 .47448 .31209 .48183 .3242 .47786 .3165 .47048 Mtetra
.3165 .47048 .3242 .47786 .33636 .47387 .32869 .46645 Mtetra
.32869 .46645 .33636 .47387 .34858 .46986 .34094 .4624 Mtetra
.655 .751 .92 r
.34094 .4624 .34858 .46986 .36085 .46584 .35325 .45835 Mtetra
.651 .75 .922 r
.35325 .45835 .36085 .46584 .37317 .46194 .36561 .45442 Mtetra
.616 .739 .934 r
.36561 .45442 .37317 .46194 .38551 .45898 .37798 .45141 Mtetra
.415 .654 .957 r
.37798 .45141 .38551 .45898 .39776 .46012 .39026 .45231 Mtetra
0 .184 .684 r
.39026 .45231 .39776 .46012 .40978 .47057 .40232 .46159 Mtetra
.549 .081 0 r
.40232 .46159 .40978 .47057 .42173 .48846 .41436 .47621 Mtetra
.431 .543 .869 r
.41436 .47621 .42173 .48846 .43421 .49545 .42697 .47861 Mtetra
.806 .66 .701 r
.42697 .47861 .43421 .49545 .44745 .47636 .44029 .45774 Mtetra
.832 .659 .667 r
.44029 .45774 .44745 .47636 .46089 .44402 .45372 .4289 Mtetra
.806 .674 .718 r
.45372 .4289 .46089 .44402 .47405 .41952 .46683 .41022 Mtetra
.745 .74 .847 r
.46683 .41022 .47405 .41952 .48696 .40743 .47974 .40198 Mtetra
.645 .821 .967 r
.47974 .40198 .48696 .40743 .49981 .40322 .49264 .39773 Mtetra
.42 .729 .99 r
.49264 .39773 .49981 .40322 .5127 .40692 .50558 .39749 Mtetra
0 .226 .741 r
.50558 .39749 .5127 .40692 .52571 .42309 .51859 .40775 Mtetra
0 0 .533 r
.51859 .40775 .52571 .42309 .53898 .44719 .5318 .42825 Mtetra
.165 .276 .733 r
.5318 .42825 .53898 .44719 .55244 .45796 .54523 .44071 Mtetra
.725 .626 .747 r
.54523 .44071 .55244 .45796 .56575 .44239 .55863 .42966 Mtetra
.86 .721 .708 r
.55863 .42966 .56575 .44239 .57885 .41574 .57185 .40624 Mtetra
.859 .767 .76 r
.57185 .40624 .57885 .41574 .59199 .39658 .58508 .3882 Mtetra
.774 .78 .858 r
.58508 .3882 .59199 .39658 .60531 .38687 .59845 .37867 Mtetra
.688 .762 .908 r
.59845 .37867 .60531 .38687 .61877 .38131 .61196 .37308 Mtetra
.66 .753 .919 r
.61196 .37308 .61877 .38131 .63231 .37671 .62555 .36844 Mtetra
.656 .752 .92 r
.62555 .36844 .63231 .37671 .64593 .37223 .63921 .36392 Mtetra
.656 .751 .92 r
.63921 .36392 .64593 .37223 .65962 .36773 .65294 .35938 Mtetra
.65294 .35938 .65962 .36773 .67337 .36322 .66673 .35483 Mtetra
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Mtetra
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Mtetra
.29656 .46707 .30436 .47448 .3165 .47048 .30873 .46303 Mtetra
.30873 .46303 .3165 .47048 .32869 .46645 .32096 .45897 Mtetra
.32096 .45897 .32869 .46645 .34094 .4624 .33324 .45489 Mtetra
.655 .751 .92 r
.33324 .45489 .34094 .4624 .35325 .45835 .34559 .4508 Mtetra
.651 .75 .922 r
.34559 .4508 .35325 .45835 .36561 .45442 .35798 .44681 Mtetra
.622 .74 .931 r
.35798 .44681 .36561 .45442 .37798 .45141 .37039 .44361 Mtetra
.471 .675 .954 r
.37039 .44361 .37798 .45141 .39026 .45231 .38273 .44365 Mtetra
0 .37 .836 r
.38273 .44365 .39026 .45231 .40232 .46159 .39489 .45043 Mtetra
0 .199 .727 r
.39489 .45043 .40232 .46159 .41436 .47621 .40705 .46115 Mtetra
.51 .537 .82 r
.40705 .46115 .41436 .47621 .42697 .47861 .4197 .46204 Mtetra
.78 .652 .721 r
.4197 .46204 .42697 .47861 .44029 .45774 .43295 .44545 Mtetra
.848 .715 .715 r
.43295 .44545 .44029 .45774 .45372 .4289 .44628 .42341 Mtetra
.864 .837 .818 r
.44628 .42341 .45372 .4289 .46683 .41022 .45939 .40889 Mtetra
.701 .955 .951 r
.45939 .40889 .46683 .41022 .47974 .40198 .47236 .40174 Mtetra
.45 .879 .909 r
.47236 .40174 .47974 .40198 .49264 .39773 .48533 .39748 Mtetra
.164 .702 .808 r
.48533 .39748 .49264 .39773 .50558 .39749 .49834 .39612 Mtetra
.42 0 0 r
.49834 .39612 .50558 .39749 .51859 .40775 .5114 .40216 Mtetra
.601 .072 0 r
.5114 .40216 .51859 .40775 .5318 .42825 .52461 .41575 Mtetra
.159 .379 .829 r
.52461 .41575 .5318 .42825 .54523 .44071 .53801 .42377 Mtetra
.711 .623 .757 r
.53801 .42377 .54523 .44071 .55863 .42966 .55143 .41408 Mtetra
.814 .68 .716 r
.55143 .41408 .55863 .42966 .57185 .40624 .56476 .3945 Mtetra
.817 .726 .765 r
.56476 .3945 .57185 .40624 .58508 .3882 .57808 .37894 Mtetra
.753 .756 .855 r
.57808 .37894 .58508 .3882 .59845 .37867 .59153 .37021 Mtetra
.683 .756 .906 r
.59153 .37021 .59845 .37867 .61196 .37308 .60508 .36475 Mtetra
.66 .752 .919 r
.60508 .36475 .61196 .37308 .62555 .36844 .61872 .36009 Mtetra
.656 .751 .92 r
.61872 .36009 .62555 .36844 .63921 .36392 .63243 .35553 Mtetra
.63243 .35553 .63921 .36392 .65294 .35938 .6462 .35095 Mtetra
.6462 .35095 .65294 .35938 .66673 .35483 .66004 .34636 Mtetra
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Mtetra
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45551 Mtetra
.3009 .45551 .30873 .46303 .32096 .45897 .31316 .45142 Mtetra
.31316 .45142 .32096 .45897 .33324 .45489 .32548 .4473 Mtetra
.32548 .4473 .33324 .45489 .34559 .4508 .33786 .44318 Mtetra
.653 .75 .921 r
.33786 .44318 .34559 .4508 .35798 .44681 .35029 .43911 Mtetra
.634 .743 .927 r
.35029 .43911 .35798 .44681 .37039 .44361 .36275 .43556 Mtetra
.544 .701 .943 r
.36275 .43556 .37039 .44361 .38273 .44365 .37517 .43423 Mtetra
.285 .533 .913 r
.37517 .43423 .38273 .44365 .39489 .45043 .38747 .43783 Mtetra
.159 .376 .826 r
.38747 .43783 .39489 .45043 .40705 .46115 .39974 .44521 Mtetra
.475 .506 .81 r
.39974 .44521 .40705 .46115 .4197 .46204 .41234 .4473 Mtetra
.73 .65 .77 r
.41234 .4473 .4197 .46204 .43295 .44545 .42543 .43727 Mtetra
.847 .778 .784 r
.42543 .43727 .43295 .44545 .44628 .42341 .43868 .4215 Mtetra
.854 .94 .878 r
.43868 .4215 .44628 .42341 .45939 .40889 .45181 .40945 Mtetra
.606 .952 .898 r
.45181 .40945 .45939 .40889 .47236 .40174 .46486 .40249 Mtetra
.37 .838 .837 r
.46486 .40249 .47236 .40174 .48533 .39748 .4779 .39823 Mtetra
.096 .652 .717 r
.4779 .39823 .48533 .39748 .49834 .39612 .49098 .39667 Mtetra
.348 0 0 r
.49098 .39667 .49834 .39612 .5114 .40216 .50411 .40026 Mtetra
.463 0 0 r
.50411 .40026 .5114 .40216 .52461 .41575 .51736 .40754 Mtetra
.404 .639 .952 r
.51736 .40754 .52461 .41575 .53801 .42377 .53076 .40878 Mtetra
.743 .659 .767 r
.53076 .40878 .53801 .42377 .55143 .41408 .54421 .39759 Mtetra
.783 .66 .728 r
.54421 .39759 .55143 .41408 .56476 .3945 .5576 .38124 Mtetra
.771 .692 .776 r
.5576 .38124 .56476 .3945 .57808 .37894 .57102 .36888 Mtetra
.721 .731 .859 r
.57102 .36888 .57808 .37894 .59153 .37021 .58454 .3615 Mtetra
.674 .748 .906 r
.58454 .3615 .59153 .37021 .60508 .36475 .59815 .35632 Mtetra
.658 .751 .918 r
.59815 .35632 .60508 .36475 .61872 .36009 .61183 .35167 Mtetra
.656 .751 .92 r
.61183 .35167 .61872 .36009 .63243 .35553 .62558 .34707 Mtetra
.62558 .34707 .63243 .35553 .6462 .35095 .6394 .34245 Mtetra
.6394 .34245 .6462 .35095 .66004 .34636 .65329 .33781 Mtetra
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.28076 .45205 .28869 .45959 .3009 .45551 .293 .44794 Mtetra
.293 .44794 .3009 .45551 .31316 .45142 .30529 .44381 Mtetra
.30529 .44381 .31316 .45142 .32548 .4473 .31765 .43966 Mtetra
.31765 .43966 .32548 .4473 .33786 .44318 .33006 .43549 Mtetra
.655 .751 .921 r
.33006 .43549 .33786 .44318 .35029 .43911 .34253 .43134 Mtetra
.646 .747 .923 r
.34253 .43134 .35029 .43911 .36275 .43556 .35504 .42742 Mtetra
.604 .724 .929 r
.35504 .42742 .36275 .43556 .37517 .43423 .36756 .42465 Mtetra
.482 .634 .921 r
.36756 .42465 .37517 .43423 .38747 .43783 .38002 .42494 Mtetra
.351 .488 .857 r
.38002 .42494 .38747 .43783 .39974 .44521 .39241 .42903 Mtetra
.416 .47 .808 r
.39241 .42903 .39974 .44521 .41234 .4473 .40494 .43281 Mtetra
.608 .599 .816 r
.40494 .43281 .41234 .4473 .42543 .43727 .41781 .42989 Mtetra
.787 .796 .86 r
.41781 .42989 .42543 .43727 .43868 .4215 .43096 .42001 Mtetra
.832 .955 .895 r
.43096 .42001 .43868 .4215 .45181 .40945 .44416 .40891 Mtetra
.714 .971 .93 r
.44416 .40891 .45181 .40945 .46486 .40249 .4573 .40084 Mtetra
.527 .894 .97 r
.4573 .40084 .46486 .40249 .4779 .39823 .4704 .39665 Mtetra
.162 .689 .868 r
.4704 .39665 .4779 .39823 .49098 .39667 .48353 .39638 Mtetra
.238 0 0 r
.48353 .39638 .49098 .39667 .50411 .40026 .49672 .39918 Mtetra
0 .546 .744 r
.49672 .39918 .50411 .40026 .51736 .40754 .51004 .40041 Mtetra
.714 .8 .918 r
.51004 .40041 .51736 .40754 .53076 .40878 .52348 .39394 Mtetra
.768 .672 .757 r
.52348 .39394 .53076 .40878 .54421 .39759 .53695 .38065 Mtetra
.75 .642 .742 r
.53695 .38065 .54421 .39759 .5576 .38124 .55041 .36759 Mtetra
.723 .67 .797 r
.55041 .36759 .5576 .38124 .57102 .36888 .56391 .35863 Mtetra
.688 .717 .871 r
.56391 .35863 .57102 .36888 .58454 .3615 .57749 .35268 Mtetra
.664 .744 .91 r
.57749 .35268 .58454 .3615 .59815 .35632 .59115 .34781 Mtetra
.657 .75 .919 r
.59115 .34781 .59815 .35632 .61183 .35167 .60488 .34316 Mtetra
.656 .751 .92 r
.60488 .34316 .61183 .35167 .62558 .34707 .61867 .33853 Mtetra
.61867 .33853 .62558 .34707 .6394 .34245 .63254 .33387 Mtetra
.63254 .33387 .6394 .34245 .65329 .33781 .64648 .32919 Mtetra
.64648 .32919 .65329 .33781 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Mtetra
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Mtetra
.29736 .43613 .30529 .44381 .31765 .43966 .30975 .43194 Mtetra
.30975 .43194 .31765 .43966 .33006 .43549 .3222 .42774 Mtetra
.655 .751 .92 r
.3222 .42774 .33006 .43549 .34253 .43134 .3347 .42352 Mtetra
.653 .75 .921 r
.3347 .42352 .34253 .43134 .35504 .42742 .34726 .41936 Mtetra
.639 .74 .921 r
.34726 .41936 .35504 .42742 .36756 .42465 .35987 .41559 Mtetra
.595 .698 .915 r
.35987 .41559 .36756 .42465 .38002 .42494 .37247 .41312 Mtetra
.514 .599 .876 r
.37247 .41312 .38002 .42494 .39241 .42903 .38504 .41314 Mtetra
.464 .502 .813 r
.38504 .41314 .39241 .42903 .40494 .43281 .39761 .4154 Mtetra
.489 .497 .792 r
.39761 .4154 .40494 .43281 .41781 .42989 .41032 .41714 Mtetra
.57 .611 .854 r
.41032 .41714 .41781 .42989 .43096 .42001 .42324 .41559 Mtetra
.64 .858 .982 r
.42324 .41559 .43096 .42001 .44416 .40891 .43632 .41099 Mtetra
.347 .818 .755 r
.43632 .41099 .44416 .40891 .4573 .40084 .44949 .40579 Mtetra
.007 0 0 r
.44949 .40579 .4573 .40084 .4704 .39665 .46268 .40192 Mtetra
.125 0 0 r
.46268 .40192 .4704 .39665 .48353 .39638 .47592 .39928 Mtetra
0 0 0 r
.47592 .39928 .48353 .39638 .49672 .39918 .48926 .39545 Mtetra
.759 .908 .941 r
.48926 .39545 .49672 .39918 .51004 .40041 .5027 .3873 Mtetra
.768 .694 .781 r
.5027 .3873 .51004 .40041 .52348 .39394 .51618 .37527 Mtetra
.723 .615 .736 r
.51618 .37527 .52348 .39394 .53695 .38065 .52966 .36362 Mtetra
.696 .617 .764 r
.52966 .36362 .53695 .38065 .55041 .36759 .54317 .35504 Mtetra
.68 .67 .834 r
.54317 .35504 .55041 .36759 .56391 .35863 .55674 .34895 Mtetra
.666 .724 .892 r
.55674 .34895 .56391 .35863 .57749 .35268 .57038 .34395 Mtetra
.658 .746 .915 r
.57038 .34395 .57749 .35268 .59115 .34781 .58408 .33925 Mtetra
.656 .751 .92 r
.58408 .33925 .59115 .34781 .60488 .34316 .59786 .33459 Mtetra
.59786 .33459 .60488 .34316 .61867 .33853 .6117 .32991 Mtetra
.6117 .32991 .61867 .33853 .63254 .33387 .62562 .32521 Mtetra
.62562 .32521 .63254 .33387 .64648 .32919 .6396 .32048 Mtetra
.6396 .32048 .64648 .32919 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Mtetra
.28935 .42838 .29736 .43613 .30975 .43194 .30178 .42416 Mtetra
.30178 .42416 .30975 .43194 .3222 .42774 .31426 .41992 Mtetra
.31426 .41992 .3222 .42774 .3347 .42352 .32681 .41566 Mtetra
.655 .751 .92 r
.32681 .41566 .3347 .42352 .34726 .41936 .33941 .41139 Mtetra
.653 .748 .92 r
.33941 .41139 .34726 .41936 .35987 .41559 .35207 .40718 Mtetra
.642 .734 .916 r
.35207 .40718 .35987 .41559 .37247 .41312 .36477 .40329 Mtetra
.615 .69 .897 r
.36477 .40329 .37247 .41312 .38504 .41314 .3775 .40022 Mtetra
.577 .61 .849 r
.3775 .40022 .38504 .41314 .39761 .4154 .39024 .39845 Mtetra
.55 .538 .794 r
.39024 .39845 .39761 .4154 .41032 .41714 .40302 .3978 Mtetra
.548 .512 .767 r
.40302 .3978 .41032 .41714 .42324 .41559 .41589 .39728 Mtetra
.569 .534 .777 r
.41589 .39728 .42324 .41559 .43632 .41099 .42888 .39581 Mtetra
.603 .591 .812 r
.42888 .39581 .43632 .41099 .44949 .40579 .442 .39296 Mtetra
.641 .646 .839 r
.442 .39296 .44949 .40579 .46268 .40192 .45522 .38866 Mtetra
.676 .655 .822 r
.45522 .38866 .46268 .40192 .47592 .39928 .46854 .38264 Mtetra
.692 .618 .77 r
.46854 .38264 .47592 .39928 .48926 .39545 .48194 .37452 Mtetra
.686 .578 .728 r
.48194 .37452 .48926 .39545 .5027 .3873 .49539 .36505 Mtetra
.668 .559 .722 r
.49539 .36505 .5027 .3873 .51618 .37527 .50885 .35656 Mtetra
.656 .581 .758 r
.50885 .35656 .51618 .37527 .52966 .36362 .52235 .3501 Mtetra
.658 .646 .826 r
.52235 .3501 .52966 .36362 .54317 .35504 .5359 .34483 Mtetra
.659 .71 .885 r
.5359 .34483 .54317 .35504 .55674 .34895 .54952 .34001 Mtetra
.657 .741 .912 r
.54952 .34001 .55674 .34895 .57038 .34395 .5632 .33531 Mtetra
.656 .75 .919 r
.5632 .33531 .57038 .34395 .58408 .33925 .57696 .33063 Mtetra
.656 .751 .92 r
.57696 .33063 .58408 .33925 .59786 .33459 .59078 .32593 Mtetra
.59078 .32593 .59786 .33459 .6117 .32991 .60467 .32121 Mtetra
.60467 .32121 .6117 .32991 .62562 .32521 .61863 .31646 Mtetra
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Mtetra
.28128 .42057 .28935 .42838 .30178 .42416 .29374 .41631 Mtetra
.29374 .41631 .30178 .42416 .31426 .41992 .30626 .41203 Mtetra
.30626 .41203 .31426 .41992 .32681 .41566 .31884 .40773 Mtetra
.31884 .40773 .32681 .41566 .33941 .41139 .33148 .40341 Mtetra
.655 .751 .92 r
.33148 .40341 .33941 .41139 .35207 .40718 .34418 .39908 Mtetra
.654 .748 .919 r
.34418 .39908 .35207 .40718 .36477 .40329 .35694 .39477 Mtetra
.649 .737 .913 r
.35694 .39477 .36477 .40329 .3775 .40022 .36975 .39059 Mtetra
.64 .707 .895 r
.36975 .39059 .3775 .40022 .39024 .39845 .38261 .38668 Mtetra
.626 .656 .86 r
.38261 .38668 .39024 .39845 .40302 .3978 .39552 .38314 Mtetra
.614 .603 .816 r
.39552 .38314 .40302 .3978 .41589 .39728 .4085 .3798 Mtetra
.611 .566 .78 r
.4085 .3798 .41589 .39728 .42888 .39581 .42155 .37632 Mtetra
.615 .549 .757 r
.42155 .37632 .42888 .39581 .442 .39296 .43469 .3723 Mtetra
.624 .545 .745 r
.43469 .3723 .442 .39296 .45522 .38866 .44791 .36751 Mtetra
.635 .547 .739 r
.44791 .36751 .45522 .38866 .46854 .38264 .46121 .3619 Mtetra
.643 .556 .741 r
.46121 .3619 .46854 .38264 .48194 .37452 .47458 .35579 Mtetra
.643 .574 .761 r
.47458 .35579 .48194 .37452 .49539 .36505 .48799 .35016 Mtetra
.644 .619 .81 r
.48799 .35016 .49539 .36505 .50885 .35656 .50145 .34533 Mtetra
.652 .685 .869 r
.50145 .34533 .50885 .35656 .52235 .3501 .51498 .34068 Mtetra
.656 .728 .903 r
.51498 .34068 .52235 .3501 .5359 .34483 .52858 .33603 Mtetra
.656 .745 .915 r
.52858 .33603 .5359 .34483 .54952 .34001 .54224 .33135 Mtetra
.656 .75 .919 r
.54224 .33135 .54952 .34001 .5632 .33531 .55597 .32665 Mtetra
.656 .751 .92 r
.55597 .32665 .5632 .33531 .57696 .33063 .56976 .32194 Mtetra
.56976 .32194 .57696 .33063 .59078 .32593 .58363 .3172 Mtetra
.58363 .3172 .59078 .32593 .60467 .32121 .59757 .31243 Mtetra
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Mtetra
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Mtetra
.28563 .40839 .29374 .41631 .30626 .41203 .29819 .40408 Mtetra
.29819 .40408 .30626 .41203 .31884 .40773 .3108 .39974 Mtetra
.3108 .39974 .31884 .40773 .33148 .40341 .32348 .39538 Mtetra
.32348 .39538 .33148 .40341 .34418 .39908 .33621 .391 Mtetra
.33621 .391 .34418 .39908 .35694 .39477 .34901 .3866 Mtetra
.655 .75 .919 r
.34901 .3866 .35694 .39477 .36975 .39059 .36187 .38219 Mtetra
.655 .744 .916 r
.36187 .38219 .36975 .39059 .38261 .38668 .37479 .37778 Mtetra
.653 .732 .907 r
.37479 .37778 .38261 .38668 .39552 .38314 .38777 .3734 Mtetra
.65 .712 .893 r
.38777 .3734 .39552 .38314 .4085 .3798 .40082 .36906 Mtetra
.648 .689 .875 r
.40082 .36906 .4085 .3798 .42155 .37632 .41392 .3647 Mtetra
.648 .673 .86 r
.41392 .3647 .42155 .37632 .43469 .3723 .4271 .36022 Mtetra
.651 .666 .851 r
.4271 .36022 .43469 .3723 .44791 .36751 .44035 .35553 Mtetra
.654 .67 .853 r
.44035 .35553 .44791 .36751 .46121 .3619 .45366 .35072 Mtetra
.654 .686 .868 r
.45366 .35072 .46121 .3619 .47458 .35579 .46703 .34601 Mtetra
.655 .718 .895 r
.46703 .34601 .47458 .35579 .48799 .35016 .48047 .34138 Mtetra
.656 .744 .915 r
.48047 .34138 .48799 .35016 .50145 .34533 .49397 .33674 Mtetra
.656 .75 .92 r
.49397 .33674 .50145 .34533 .51498 .34068 .50754 .33207 Mtetra
.656 .751 .92 r
.50754 .33207 .51498 .34068 .52858 .33603 .52118 .32738 Mtetra
.52118 .32738 .52858 .33603 .54224 .33135 .53489 .32266 Mtetra
.53489 .32266 .54224 .33135 .55597 .32665 .54866 .31793 Mtetra
.54866 .31793 .55597 .32665 .56976 .32194 .56251 .31317 Mtetra
.56251 .31317 .56976 .32194 .58363 .3172 .57642 .30838 Mtetra
.57642 .30838 .58363 .3172 .59757 .31243 .5904 .30357 Mtetra
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Mtetra
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Mtetra
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .4004 Mtetra
.27745 .4004 .28563 .40839 .29819 .40408 .29004 .39605 Mtetra
.29004 .39605 .29819 .40408 .3108 .39974 .30269 .39167 Mtetra
.30269 .39167 .3108 .39974 .32348 .39538 .31541 .38727 Mtetra
.31541 .38727 .32348 .39538 .33621 .391 .32818 .38285 Mtetra
.32818 .38285 .33621 .391 .34901 .3866 .34102 .37841 Mtetra
.34102 .37841 .34901 .3866 .36187 .38219 .35391 .37395 Mtetra
.35391 .37395 .36187 .38219 .37479 .37778 .36687 .36948 Mtetra
.656 .75 .92 r
.36687 .36948 .37479 .37778 .38777 .3734 .3799 .36498 Mtetra
.656 .748 .918 r
.3799 .36498 .38777 .3734 .40082 .36906 .39299 .36044 Mtetra
.657 .744 .915 r
.39299 .36044 .40082 .36906 .41392 .3647 .40614 .35586 Mtetra
.656 .74 .911 r
.40614 .35586 .41392 .3647 .4271 .36022 .41936 .35127 Mtetra
.655 .738 .91 r
.41936 .35127 .4271 .36022 .44035 .35553 .43264 .34668 Mtetra
.655 .741 .913 r
.43264 .34668 .44035 .35553 .45366 .35072 .44598 .3421 Mtetra
.656 .748 .918 r
.44598 .3421 .45366 .35072 .46703 .34601 .4594 .33746 Mtetra
.656 .751 .92 r
.4594 .33746 .46703 .34601 .48047 .34138 .47288 .33279 Mtetra
.47288 .33279 .48047 .34138 .49397 .33674 .48642 .3281 Mtetra
.656 .752 .92 r
.48642 .3281 .49397 .33674 .50754 .33207 .50004 .32339 Mtetra
.656 .751 .92 r
.50004 .32339 .50754 .33207 .52118 .32738 .51372 .31866 Mtetra
.51372 .31866 .52118 .32738 .53489 .32266 .52747 .3139 Mtetra
.52747 .3139 .53489 .32266 .54866 .31793 .54129 .30912 Mtetra
.54129 .30912 .54866 .31793 .56251 .31317 .55518 .30431 Mtetra
.55518 .30431 .56251 .31317 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Mtetra
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Mtetra
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .4004 .2692 .39235 Mtetra
.2692 .39235 .27745 .4004 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Mtetra
.29451 .38353 .30269 .39167 .31541 .38727 .30726 .3791 Mtetra
.30726 .3791 .31541 .38727 .32818 .38285 .32007 .37464 Mtetra
.32007 .37464 .32818 .38285 .34102 .37841 .33295 .37016 Mtetra
.33295 .37016 .34102 .37841 .35391 .37395 .34588 .36565 Mtetra
.34588 .36565 .35391 .37395 .36687 .36948 .35888 .36112 Mtetra
.35888 .36112 .36687 .36948 .3799 .36498 .37195 .35657 Mtetra
.655 .751 .92 r
.37195 .35657 .3799 .36498 .39299 .36044 .38507 .35202 Mtetra
.655 .751 .921 r
.38507 .35202 .39299 .36044 .40614 .35586 .39827 .34745 Mtetra
.655 .753 .921 r
.39827 .34745 .40614 .35586 .41936 .35127 .41152 .34286 Mtetra
.656 .754 .922 r
.41152 .34286 .41936 .35127 .43264 .34668 .42485 .33821 Mtetra
.657 .753 .921 r
.42485 .33821 .43264 .34668 .44598 .3421 .43824 .33352 Mtetra
.656 .752 .92 r
.43824 .33352 .44598 .3421 .4594 .33746 .45169 .32882 Mtetra
.656 .751 .92 r
.45169 .32882 .4594 .33746 .47288 .33279 .46521 .32412 Mtetra
.46521 .32412 .47288 .33279 .48642 .3281 .4788 .31939 Mtetra
.4788 .31939 .48642 .3281 .50004 .32339 .49246 .31463 Mtetra
.49246 .31463 .50004 .32339 .51372 .31866 .50619 .30985 Mtetra
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Mtetra
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Mtetra
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36183 Mtetra
.32481 .36183 .33295 .37016 .34588 .36565 .33778 .35728 Mtetra
.33778 .35728 .34588 .36565 .35888 .36112 .35082 .35272 Mtetra
.656 .752 .921 r
.35082 .35272 .35888 .36112 .37195 .35657 .36392 .34813 Mtetra
.656 .752 .92 r
.36392 .34813 .37195 .35657 .38507 .35202 .37709 .34351 Mtetra
.656 .751 .92 r
.37709 .34351 .38507 .35202 .39827 .34745 .39032 .33886 Mtetra
.656 .75 .919 r
.39032 .33886 .39827 .34745 .41152 .34286 .40362 .33418 Mtetra
.656 .749 .919 r
.40362 .33418 .41152 .34286 .42485 .33821 .41699 .32951 Mtetra
.655 .749 .919 r
.41699 .32951 .42485 .33821 .43824 .33352 .43042 .32483 Mtetra
.655 .751 .92 r
.43042 .32483 .43824 .33352 .45169 .32882 .44391 .32012 Mtetra
.656 .752 .921 r
.44391 .32012 .45169 .32882 .46521 .32412 .45748 .31537 Mtetra
.656 .752 .92 r
.45748 .31537 .46521 .32412 .4788 .31939 .47111 .31059 Mtetra
.656 .751 .92 r
.47111 .31059 .4788 .31939 .49246 .31463 .48482 .30579 Mtetra
.48482 .30579 .49246 .31463 .50619 .30985 .49859 .30097 Mtetra
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Mtetra
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Mtetra
.31659 .35342 .32481 .36183 .33778 .35728 .32961 .34883 Mtetra
.32961 .34883 .33778 .35728 .35082 .35272 .34268 .34422 Mtetra
.34268 .34422 .35082 .35272 .36392 .34813 .35583 .33959 Mtetra
.35583 .33959 .36392 .34813 .37709 .34351 .36903 .33495 Mtetra
.655 .751 .921 r
.36903 .33495 .37709 .34351 .39032 .33886 .38231 .33029 Mtetra
.655 .752 .921 r
.38231 .33029 .39032 .33886 .40362 .33418 .39565 .3256 Mtetra
.656 .753 .922 r
.39565 .3256 .40362 .33418 .41699 .32951 .40905 .32088 Mtetra
.656 .753 .921 r
.40905 .32088 .41699 .32951 .43042 .32483 .42253 .31611 Mtetra
.656 .752 .921 r
.42253 .31611 .43042 .32483 .44391 .32012 .43607 .31132 Mtetra
.656 .751 .92 r
.43607 .31132 .44391 .32012 .45748 .31537 .44968 .30652 Mtetra
.44968 .30652 .45748 .31537 .47111 .31059 .46335 .30171 Mtetra
.46335 .30171 .47111 .31059 .48482 .30579 .4771 .29687 Mtetra
.4771 .29687 .48482 .30579 .49859 .30097 .49091 .292 Mtetra
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Mtetra
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.3083 .34494 .31659 .35342 .32961 .34883 .32136 .34031 Mtetra
.32136 .34031 .32961 .34883 .34268 .34422 .33447 .33567 Mtetra
.656 .752 .92 r
.33447 .33567 .34268 .34422 .35583 .33959 .34765 .33099 Mtetra
.34765 .33099 .35583 .33959 .36903 .33495 .3609 .32629 Mtetra
.656 .751 .92 r
.3609 .32629 .36903 .33495 .38231 .33029 .37422 .32156 Mtetra
.656 .751 .919 r
.37422 .32156 .38231 .33029 .39565 .3256 .3876 .3168 Mtetra
.656 .75 .919 r
.3876 .3168 .39565 .3256 .40905 .32088 .40105 .31203 Mtetra
.655 .75 .919 r
.40105 .31203 .40905 .32088 .42253 .31611 .41456 .30726 Mtetra
.655 .75 .92 r
.41456 .30726 .42253 .31611 .43607 .31132 .42814 .30246 Mtetra
.656 .752 .92 r
.42814 .30246 .43607 .31132 .44968 .30652 .4418 .29763 Mtetra
.656 .752 .921 r
.4418 .29763 .44968 .30652 .46335 .30171 .45552 .29276 Mtetra
.656 .752 .92 r
.45552 .29276 .46335 .30171 .4771 .29687 .46931 .28787 Mtetra
.656 .751 .92 r
.46931 .28787 .4771 .29687 .49091 .292 .48317 .28295 Mtetra
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Mtetra
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Mtetra
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Mtetra
.31303 .33171 .32136 .34031 .33447 .33567 .32619 .32701 Mtetra
.32619 .32701 .33447 .33567 .34765 .33099 .33941 .3223 Mtetra
.33941 .3223 .34765 .33099 .3609 .32629 .3527 .31756 Mtetra
.655 .751 .92 r
.3527 .31756 .3609 .32629 .37422 .32156 .36605 .31281 Mtetra
.655 .752 .921 r
.36605 .31281 .37422 .32156 .3876 .3168 .37947 .30804 Mtetra
.656 .753 .921 r
.37947 .30804 .3876 .3168 .40105 .31203 .39296 .30323 Mtetra
.39296 .30323 .40105 .31203 .41456 .30726 .40652 .29838 Mtetra
.656 .752 .921 r
.40652 .29838 .41456 .30726 .42814 .30246 .42015 .2935 Mtetra
.656 .751 .92 r
.42015 .2935 .42814 .30246 .4418 .29763 .43384 .28861 Mtetra
.43384 .28861 .4418 .29763 .45552 .29276 .44761 .28371 Mtetra
.44761 .28371 .45552 .29276 .46931 .28787 .46145 .27877 Mtetra
.46145 .27877 .46931 .28787 .48317 .28295 .47535 .27381 Mtetra
.47535 .27381 .48317 .28295 .4971 .27801 .48933 .26883 Mtetra
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Mtetra
.30463 .32303 .31303 .33171 .32619 .32701 .31782 .31829 Mtetra
.656 .752 .92 r
.31782 .31829 .32619 .32701 .33941 .3223 .33109 .31354 Mtetra
.33109 .31354 .33941 .3223 .3527 .31756 .34441 .30875 Mtetra
.656 .751 .92 r
.34441 .30875 .3527 .31756 .36605 .31281 .35781 .30393 Mtetra
.35781 .30393 .36605 .31281 .37947 .30804 .37128 .29909 Mtetra
.656 .75 .919 r
.37128 .29909 .37947 .30804 .39296 .30323 .38481 .29423 Mtetra
.655 .75 .919 r
.38481 .29423 .39296 .30323 .40652 .29838 .39841 .28936 Mtetra
.655 .751 .92 r
.39841 .28936 .40652 .29838 .42015 .2935 .41208 .28446 Mtetra
.656 .751 .92 r
.41208 .28446 .42015 .2935 .43384 .28861 .42582 .27954 Mtetra
.656 .752 .92 r
.42582 .27954 .43384 .28861 .44761 .28371 .43963 .27458 Mtetra
.43963 .27458 .44761 .28371 .46145 .27877 .45351 .2696 Mtetra
.656 .751 .92 r
.45351 .2696 .46145 .27877 .47535 .27381 .46746 .26459 Mtetra
.46746 .26459 .47535 .27381 .48933 .26883 .48148 .25956 Mtetra
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Mtetra
.29615 .31427 .30463 .32303 .31782 .31829 .30938 .30948 Mtetra
.30938 .30948 .31782 .31829 .33109 .31354 .32269 .30468 Mtetra
.32269 .30468 .33109 .31354 .34441 .30875 .33606 .29986 Mtetra
.655 .751 .92 r
.33606 .29986 .34441 .30875 .35781 .30393 .34949 .29501 Mtetra
.655 .752 .921 r
.34949 .29501 .35781 .30393 .37128 .29909 .363 .29015 Mtetra
.656 .753 .921 r
.363 .29015 .37128 .29909 .38481 .29423 .37657 .28524 Mtetra
.37657 .28524 .38481 .29423 .39841 .28936 .39022 .28031 Mtetra
.656 .752 .921 r
.39022 .28031 .39841 .28936 .41208 .28446 .40393 .27534 Mtetra
.656 .752 .92 r
.40393 .27534 .41208 .28446 .42582 .27954 .41772 .27036 Mtetra
.656 .751 .92 r
.41772 .27036 .42582 .27954 .43963 .27458 .43157 .26536 Mtetra
.43157 .26536 .43963 .27458 .45351 .2696 .4455 .26033 Mtetra
.4455 .26033 .45351 .2696 .46746 .26459 .45949 .25528 Mtetra
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Mtetra
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Mtetra
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Mtetra
.28759 .30542 .29615 .31427 .30938 .30948 .30086 .3006 Mtetra
.656 .752 .92 r
.30086 .3006 .30938 .30948 .32269 .30468 .31421 .29575 Mtetra
.31421 .29575 .32269 .30468 .33606 .29986 .32762 .29088 Mtetra
.656 .751 .92 r
.32762 .29088 .33606 .29986 .34949 .29501 .3411 .28597 Mtetra
.3411 .28597 .34949 .29501 .363 .29015 .35465 .28104 Mtetra
.656 .75 .92 r
.35465 .28104 .363 .29015 .37657 .28524 .36826 .27609 Mtetra
.36826 .27609 .37657 .28524 .39022 .28031 .38195 .27112 Mtetra
.655 .751 .92 r
.38195 .27112 .39022 .28031 .40393 .27534 .39571 .26613 Mtetra
.656 .751 .92 r
.39571 .26613 .40393 .27534 .41772 .27036 .40953 .26111 Mtetra
.656 .752 .92 r
.40953 .26111 .41772 .27036 .43157 .26536 .42343 .25606 Mtetra
.42343 .25606 .43157 .26536 .4455 .26033 .43741 .25098 Mtetra
.656 .751 .92 r
.43741 .25098 .4455 .26033 .45949 .25528 .45145 .24588 Mtetra
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Mtetra
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Mtetra
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Mtetra
.27895 .2965 .28759 .30542 .30086 .3006 .29226 .29163 Mtetra
.29226 .29163 .30086 .3006 .31421 .29575 .30565 .28673 Mtetra
.30565 .28673 .31421 .29575 .32762 .29088 .3191 .28181 Mtetra
.655 .751 .92 r
.3191 .28181 .32762 .29088 .3411 .28597 .33262 .27688 Mtetra
.656 .752 .921 r
.33262 .27688 .3411 .28597 .35465 .28104 .34621 .27192 Mtetra
.34621 .27192 .35465 .28104 .36826 .27609 .35987 .26692 Mtetra
.35987 .26692 .36826 .27609 .38195 .27112 .3736 .2619 Mtetra
.3736 .2619 .38195 .27112 .39571 .26613 .3874 .25684 Mtetra
.656 .752 .92 r
.3874 .25684 .39571 .26613 .40953 .26111 .40128 .25176 Mtetra
.656 .751 .92 r
.40128 .25176 .40953 .26111 .42343 .25606 .41522 .24666 Mtetra
.41522 .24666 .42343 .25606 .43741 .25098 .42924 .24154 Mtetra
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Mtetra
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Mtetra
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Mtetra
.27023 .28749 .27895 .2965 .29226 .29163 .28358 .28258 Mtetra
.656 .752 .92 r
.28358 .28258 .29226 .29163 .30565 .28673 .29701 .27764 Mtetra
.29701 .27764 .30565 .28673 .3191 .28181 .3105 .27267 Mtetra
.656 .751 .92 r
.3105 .27267 .3191 .28181 .33262 .27688 .32407 .26766 Mtetra
.32407 .26766 .33262 .27688 .34621 .27192 .3377 .26264 Mtetra
.656 .75 .92 r
.3377 .26264 .34621 .27192 .35987 .26692 .3514 .2576 Mtetra
.3514 .2576 .35987 .26692 .3736 .2619 .36518 .25254 Mtetra
.655 .751 .92 r
.36518 .25254 .3736 .2619 .3874 .25684 .37902 .24745 Mtetra
.656 .751 .92 r
.37902 .24745 .3874 .25684 .40128 .25176 .39294 .24233 Mtetra
.656 .752 .92 r
.39294 .24233 .40128 .25176 .41522 .24666 .40693 .23718 Mtetra
.40693 .23718 .41522 .24666 .42924 .24154 .42099 .23201 Mtetra
.656 .751 .92 r
.42099 .23201 .42924 .24154 .44333 .23639 .43513 .2268 Mtetra
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Mtetra
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Mtetra
.26142 .27839 .27023 .28749 .28358 .28258 .27482 .27343 Mtetra
.27482 .27343 .28358 .28258 .29701 .27764 .28829 .26844 Mtetra
.28829 .26844 .29701 .27764 .3105 .27267 .30182 .26343 Mtetra
.655 .751 .92 r
.30182 .26343 .3105 .27267 .32407 .26766 .31543 .2584 Mtetra
.656 .752 .921 r
.31543 .2584 .32407 .26766 .3377 .26264 .3291 .25335 Mtetra
.3291 .25335 .3377 .26264 .3514 .2576 .34285 .24825 Mtetra
.34285 .24825 .3514 .2576 .36518 .25254 .35667 .24313 Mtetra
.35667 .24313 .36518 .25254 .37902 .24745 .37056 .23798 Mtetra
.656 .752 .92 r
.37056 .23798 .37902 .24745 .39294 .24233 .38452 .2328 Mtetra
.656 .751 .92 r
.38452 .2328 .39294 .24233 .40693 .23718 .39856 .2276 Mtetra
.39856 .2276 .40693 .23718 .42099 .23201 .41267 .22238 Mtetra
.41267 .22238 .42099 .23201 .43513 .2268 .42685 .21713 Mtetra
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3ooomC0:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0oooo00<000000?ooo`3oool0AP3ooomE0:O0j`03
0000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo
F@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?oooe`0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo02P0oooo000T
0?ooo`800000B`3ooomM0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?oo
oe`0Yl3[0`0000020:O0j`030000002W`>/0Yl3[0180Yl3[4P3oool00`000000oooo0?ooo`0V0?oo
o`007`3oool3000004T0ooooG@2W`>/3000000D0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`03
0000003oool0oooo02H0oooo000M0?ooo`800000B`3oool70:O0j`D0Yko[C`2W`>/3000000T0Yl3[
00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`800000
0`3oool4000000X0oooo000E0?ooo`D000000`3oool2000004T0oooo1`2W`>/80:Nojd/0Yl3[0`00
000=0:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool02`3oool001L0oooo00<000000?ooo`3oool00`3o
ool3000004@0oooo2@2W`>/80:Nojd/0Yl3[0P00000A0:O0j`030000002W`>/0Yl3[01<0Yl3[403o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
2P3oool001L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000o0?ooo`l0Yl3[
102W_n]:0:O0j`<000004`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0
0`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`090?ooo`00
3`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03/0ooooF`2W`>/3000001L0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000
003oool0oooo00P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000:0?oo
o`005`3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0h0?oooaT0
Yl3[1@2W_n/l0:O0j`<000006`2W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo0P00000;0?ooo`80
00002P3oool2000000/0oooo000F0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03<0oooo6`2W`>/80:NojcP0Yl3[0`00000O0:O0j`030000002W`>/0Yl3[0180Yl3[
4@3oool00`000000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03o
oolL0:O0j`P0Yko[=`2W`>/300000280Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003o
ool0oooo0200oooo000L0?ooo`800000203oool00`000000oooo0?ooo`0[0?oooal0Yl3[1@2W_n/f
0:O0j`<000009P2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool0803oool0
01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?oooeT0Yl3[0`00000Z0:O0
j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0O0?ooo`006`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo;02W`>/50:NojbT0Yl3[0`00000^0:O0j`03
0000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo
00<000000?ooo`3oool07`3oool[0:O0j`X0Yko[9P2W`>/200000340Yl3[00<000000:O0j`2W`>/0
4`2W`>/@0?ooo`030000003oool0oooo01h0oooo000K0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool06P3oool`0:O0j`L0Yko[9@2W`>/3000003@0Yl3[00<000000:O0j`2W`>/04P2W
`>/A0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0603ooolb0:O0j`@0Yko[202W`>/30:NojaT0Yl3[0`00000h0:O0j`030000002W`>/0
Yl3[0140Yl3[403oool2000001l0oooo000K0?ooo`8000003`3oool00`000000oooo0?ooo`0E0?oo
och0Yl3[1P2W_n/E0:O0j`<00000>`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?oo
o`3oool0703oool001/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooocd0
Yl3[2P2W_n/B0:O0j`<00000?`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3o
ool06`3oool000P0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0<0?oooch0Yl3[2@2W_n/C0:O0j`<00000@`2W`>/00`000000Yl3[
0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool06`3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`8000004`3oool00`000000oooo0?ooo`0:0?oood00
Yl3[1@2W_n/C0:O0j`<00000A`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3o
ool06P3oool000L0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool00000
01D0oooo00<000000?ooo`3oool01`3ooom30:O0j`80Yko[0`2W`>`?0:O0j`<00000BP2W`>/00`00
0000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06@3oool000030?ooo`00000000000080
00000P3oool010000000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0080ooooA`2W`>/60:O0k080Yl3[0P2W_n/70:O0j`<00000CP2W`>/00`00
0000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool06@3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`030?ooo`8000005P3oool00`000000Yl3[0:O0j`190:O0
j`D0Yl3/1@2W_n/40:O0j`8000005P2W`>/50:NojcL0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?oo
o`8000006P3oool000P0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0B0?oooe00
Yl3[2@2W_n/0102W`>/0000000000000000;0:O0j`D0Yko[102W`>/50:NnjPT0Yko[<`2W`>/00`00
0000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool05`3oool001T0oooo00<000000?ooo`3o
ool04P3ooom>0:O0j`T0Yko[00@0Z<3[00000000000000003@2W`>/20:NnjPD0Yko[0P2W`>/20:Nj
i`D0YkkZ1@2X_NT40:Nojc80Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo
01L0oooo000I0?ooo`8000004@3ooomA0:O0j`@0Yko[0P2W`N`3000000@0Z<3[1@2W_n/50:O0j`D0
YkkZ102W_n/50:Nji`80YkkZ0`2X]N850:Rmj@@0Z;kZ<P2W`>/00`000000Yl3[0:O0j`0B0:O0ja00
oooo00<000000?ooo`3oool05P3oool001T0oooo00<000000?ooo`3oool03@3ooomG0:O0j`<00000
102W`N`40:Nmj@D0Yko[1@2W]nD40:NnjPD0YZoN102W^^L60:RehP80Z;gY0`2Z^N@40:RnjPD0Z;o[
;@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool05@3oool001T0oooo00<0
00000?ooo`3oool02@3ooomH0:O0j`<000000`2W`>/50:Nlj0@0YkgY1@2W[mh50:Ngi@@0Y9k?1@2V
[mh40:RUd`D0Z;GR1P2Z^N@20:RnjP80ZKkX1@2X_n/]0:O0j`030000002W`>/0Yl3[0140Yl3[403o
ool00`000000oooo0?ooo`0E0?ooo`006@3oool2000000L0ooooF02W`>/3000000D0Yl3[0P2W_NT5
0:Nlj080YkgY0P2WZmX50:N_gP80YkOU0`2TT/840:BNc`80YZoN0`2WU<840:RUd`D0[Z_E1@2Z^N@5
0:Vnj080Z;o[0`2X`>//0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0D
0?ooo`006@3oool00`000000oooo0?ooo`030?oooeP0Yl3[0`0000060:O0j`D0YkgY102W_>P50:N[
fP@0YjoN1@2TT/840:BNc`D0YiC20`2XYM<20;:M``D0[Z_E1@2`]mh40:Vnj0H0Z<3[;02W`>/00`00
0000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool04`3oool001P0oooo00<000000?ooo`3o
ool00`3ooomF0:O0j`<000001@2W`>/50:RnjP@0YkgY1@2VZ]T40:N[fPD0Y8jm1@2TT/820:BNc`80
Zhnh1@2WU<80102XYM<0/Yg30;:M``2bWL<40:j[e@80^J_<102`]mh50:boi`D0Z<3[;@2W`>/00`00
0000Yl3[0:O0j`0A0:O0j`l0oooo0P00000E0?ooo`00603oool010000000oooo0000003ooomF0:O0
j`8000001@2W`>/40:Noj`D0Z;kZ102U[=`50:JZf@80Yj_J0P2RS;d40:B>_@D0Y9;2102[SkP50:ND
`PD0/Yg30P2^ZmD40;V[c080/;ON0P2h^m/50:boi`D0Z<3[;02W`>/00`000000Yl3[0:O0j`0A0:O0
ja40oooo00<000000?ooo`3oool01P3oool2000000X0oooo000H0?ooo`030000002W`>/0Yl3[05@0
Yl3[0`0000030:O0j`T0Yko[1@2U/=l40:F/g0@0YZ[I102RS;d50:B>_@<0Y9;20P2_TkX40:^?^0<0
YiC20P2iWK`40;:M``H0^J_<1@2h^m/50:k1i`@0Z<3[;@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`004@3oool2000000D0
oooo00<000000?ooo`2W`>/0D@2W`>/3000000L0Yl3[1@2W_n/40:Jfi0D0YK3O0`2U[=`509n;_P<0
XXbm1@2TS[d20:BB`P<0[i>j102[SkP20:ND`P<0^Ifl0`2bWL<20;nT_@@0^J_<0P35/LH30;Rkf`80
`<7J1@2^`NL40:S0jbd0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1>0:O0j`<000002`2W`>/50:Nkj0@0Y[KT102U/=l409f<`@@0Wh^n102RS;d40:B>
_@D0[i>j102[SkP60;VM_0030;:M``2oY;d0_jBm0080_jBm0P2iZl`40<FaaP030;Rkf`30`MX0`<7J
0080`<7J0P2^`NL30;33j0@0Z<3[;@2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`000004
0?ooo`8000000P3ooom:0:O0j`<000003@2W`>/20:NnjPD0Yk_X0`2V]^@509b@a`<0WHc11@2ORkh3
0::<_@80Y8jm0`2aW/D50:nC^P80Zhnh0P34/LL50;VM_0D0_jBm1P35/LH50<31fPH0/<?X102X`>//
0:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3o
oom60:O0j`<000003P2W`>/50:NnjP@0Yk_X102MV]0409b@a`<0WHc11@2ORkh30::<_@D0/Ik51@2_
TkX0102[SkP0a;770<Baa`34/LL40;VM_080a:c1102oY;d00`38Z;X0aK760<FaaP020<FaaP80dKW3
0`30`MX20<K7f`H0/<?X102X`>//0:O0j`030000002W`>/0Yl3[0140Yl3[403oool2000000@0oooo
0P00000:0?ooo`00403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo
@@2W`>/3000000d0Yl3[1@2W_n/40:NnjPD0X:OL0`2MV]0509b@a`<0WHc1102ORkh40:fWdPD0/Ik5
102_TkX50<Baa`80^Ifl0`34[<430;nT_@80b:Rj0`35/LH40=6i``D0a/OK1@2``nP50:S0jb`0Yl3[
00<000000:O0j`2W`>/04@2W`>/>0?ooo`<00000403oool00140oooo0P0000040?ooo`8000001`3o
oolm0:O0j`<000004P2W`>/40:Noj`@0XkCU102PYm`409fJd0@0W9370`2MS<4209n;_P<0Y:GF0`2]
Ym850;6Na@80[i>j0`32j?040<Baa`030;VM_034[<40a:c100<0a:c10P2oY;d30<RX^P030<FaaP3A
^L<0dKW300<0dKW300<0flC20<K7f`36am/00`37b]`40;33j0H0Z<3[;02W`>/00`000000Yl3[0:O0
j`0A0:O0j`l0oooo00<000000?ooo`3oool03P3oool001L0oooo00<000000?ooo`3oool01`3oooli
0:O0j`<000005P2W`>/40:Jlj@@0XkCU102PYm`309fJd0@0W9370`2MS<450:BUeP@0[JOB102aW/D6
0<;Xl0<0a;771P34[<400`2oY;d0b:Rj0<RX^P020<RX^PD0dKW30P3Ka<860<O:g0@0/<?X1@2X`>//
0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0=0?ooo`005`3oool00`00
0000oooo0?ooo`080?ooocD0Yl3[0`00000E0:O0j`D0Yko[102V_>T40:>di@<0X:OL0`2MV]050968
aP<0VYO?1@2TYMH30:fWdP0308KTn00HY[L06:Jg00<0:K?>1032j?040;K<j`D0a:c11@38Z;X0103@
[[L0dKW30=6i``3A^L<30=_4`P030>7;`P37b]`0al[L00@0al[L102``nP50:S0jb`0Yl3[00<00000
0:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00`0oooo000G0?ooo`8000002@3ooolc0:O0
j`8000006@2W`>/50:Noj`@0WK3U102CW=T308b9b`<0S8?4102AR<H409ZGc`@0Y:GF0P1Ne]H207?Q
j0H0YM;g0P1[^_d00`00>Kd008^n0;K<j`020;K<j`@0a:c10P2nZ<@30<RX^P<0d:jg00@0dKW30=_4
`P3Ka<80flC20`3Qbl860<O:g0@0[l?X1@2X`>//0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool0
0`000000oooo0?ooo`0<0?ooo`005`3oool00`000000oooo0?ooo`0:0?ooobh0Yl3[0`00000L0:O0
j`D0Y;_Z0`2M/>D409>Lf@<0S8W;0`2<Pl@50968aP<0VYO?00<0F=710;KhkP2fn>h00P2KlnD20;?d
l`<0_[gH1@2MQKT207Y_^`03000i_@2fc>/0]/c[0080]/c[0P34[<430;jXa0<0b:Rj0`3@[[L40=_4
`P<0hL_21@37b]`20<O:g@@0[l?X1@2X`>//0:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`00
0000oooo0?ooo`0;0?ooo`005P3oool00`000000oooo0?ooo`0<0?ooobX0Yl3[0`00000L0:O0j`@0
Yko[1@2T^nX309f`i@<0TicI102<RL/308b3a0@0THS60P1HdL420;KhkP80Vo?U0P2cm?<50;jmf003
0;FC]02MQKT0WHFi0080WHFi0`1jKk/01000>Kd0Ij?c06NSl`1WXo<60;jXa0030<RX^P3@[[L0d:jg
0080d:jg00<0g;Re0=_4`P3Ka<80103Qbl80103Rc<80al[L0<O:g037b]`30<O:g@D0[l?X102X`>//
0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0:0?ooo`005P3oool20000
00h0oooo9P2W`>/300000200Yl3[102W_n/40:BkjP<0WK3U0`2CW=T408b9b`<0S8?40P2AR<H30:?K
n`80e?CU0P3Jl>030=gFd@040<j/]`2n_MP0_[gH0;jmf080]I>d102MQKT307Y_^`0301`c[@00>Kd0
Ij?c0080Ij?c1@2nZ<@40=2^]`<0g;Re00@0flC20>7;`P3Qbl80hL_20`3Rc<840<O:g@80a/[M1@2_
`nP40:S0jb`0Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`800000303oool001H0oooo00<00000
0?ooo`3oool03P3ooolR0:O0j`<00000902W`>/30:Noj`D0V;;Z0`23VN0207J0d0@0S8W;0`2<Pl@4
0:?Kn`80e?CU0P3Jl>030=gFd@<0cZbg00@0_[gH0;FC]02eTk@0]I>d1@2MQKT207Y_^`8073>]0`1W
Xo<40;jXa080]Yo10`3@[[L30=bh]@@0hL_20`3Rc<800`3Rc<<0al[M0<O:g@040<K:g@D0[l?X102X
`>//0:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?ooo`090?ooo`005P3oool0
0`000000oooo0?ooo`0@0?oooad0Yl3[0`00000W0:O0j`@0Xkg[1@2H/^X208>Ih0<0MX3@101mOlX4
096LfP80e?CU0`3Jl>030=gFd@@0cZbg1@2eTk@409f5^@<0NVnk0P0L<jd00`0XHM@0Ij?c06NSl`02
0;jXa0<0]Yo10P3@[[L40=bh]@030>S5/`3Qbl80hL_200<0h/c20`3Rc<<40<K:g@80aLWM102_`nP5
0:S0jb/0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00P0oooo000F0?oo
o`8000004P3ooolI0:O0j`<000009`2W`>/40:Noj`@0Xkg[102H/^X308>Ih080MX3@1@1mOlX2096L
fP<0bL_L0P3HalP30=gFd@D0cZbg00<0cJ>/0;FC]02eTk@00P2eTk@409f5^@<0NVnk0P0L<jd00`00
08P0:67D02QQe0060;JO`@040=2^]`3L^;D0g;Re0=bh]@<0j<Fc103Rc<830>;<``030>7<``36b]d0
a/[M00@0aLWM102_`nT50:S0jb/0Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003oool0
oooo00P0oooo000F0?ooo`030000003oool0oooo0180oooo5@2W`>/3000002/0Yl3[102W_n/409Zi
k@@0Nj;[0P1IO=/307J0d0@0OGo:1039bm`30=S7b080fKNg1@3>[;L20<fS[0@0]I>d1@2UY=D206N5
g0<073>]0`0XHM@50;JO`@@0g;Re0`3XaK<00`3/bK80h/c20>;<`P030>;<``<0hLc31P35bMd40:o3
j@D0Z<3[:`2W`>/00`000000Yl3[0:O0j`0@0:O0j`l0oooo0P0000090?ooo`000`3oool2000000@0
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0D0?oooa40Yl3[0`00000_0:O0j`@0
YKo/102J^Nd307^Rj`<0FGcK0P1ZN<h509^Id080bL_L0`3HalP30=Vg]`040=BXZP3>[;L0cZbg0<j/
]`<0cJ>/102eTk@00`36]LT0YJCE0:FTe@020:FTe@<0IhGL0P0L<jd00`0008P0:TJk02QQe0040;JO
`@80^J2o0P3L^;D30>S5/`<0k<Vb0`3Rc<<50>7<``H0aLWM0P2_`nT20:k3j@@0Z<3[;02W`>/00`00
0000Yl3[0:O0j`0@0:O0j`/0oooo0`0000000`3oool000000?ooo`080?ooo`000P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool>
0:O0j`800000<`2W`>/40:Fok0<0V[W]101kX^/205Ulf`<0JWS>1@2KVM040=S7b0<0fKNg00@0e:RZ
0<j/]`3>[;L0cZbg103=Xj`20;FC]080a[G91@2UY=D306N5g08073>]0P0ZA[/00`0XHM@0]Yo10;JO
`@030;VP_`80g;Re0`3XaK<40>c9/P030>;<``3Qc<<0hLc300@0hLc31P35bMd50:k3j@@0Z<3[:`2W
`>/00`000000Yl3[0:O0j`0A0:O0j`H0oooo100000040?ooo`030000003oool0oooo00L0oooo0002
0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`X0Yl3[
0`00000f0:O0j`@0X[k]102;/o4204R8j@<0FGcK0P1ZN<h409^Id080^ZK50P3HalP30=Vg]`<0e:RZ
00<0cZbg0<fS[03=Xj`00`3=Xj`00`2eTk@0a[G90<Jeb@020<Jeb@@0YJCE0`1WQM`00`005Z@073>]
0000R00202Y6^`D0^J2o00@0g;Re0>S5/`3XaK<0j<Fc1@3/bK870>7<``040>7<a035bMd0aLWM0<G9
g@<0a<WN1@2^`nT40:S0jb/0Yl3[00<000000:O0j`2W`>/04@2W`>/20?ooo`<00000203oool00`00
0000oooo0?ooo`070?ooo`000P3oool010000000oooo0?ooo`0000090?ooo`800000103oool00`00
0000oooo0?ooo`0H0?ooo`D0Yl3[0`00000f0:O0j`@0Yko[102R_^d408^cl@80B8SY0P0XH=<306Yh
cP80ViW@102jY/D0103HalP0fKNg0=Vg]`3I]kL30=BXZPH0cJ>/1@36]LT50:O3kP<0DIcc00<001JT
0000R`0ZA[/00P0ZA[/40;VP_`@0j<Fc1P3/bK850>7<``<0hLc41@34bMh60:k3j@@0Z<3[:`2W`>/0
0`000000Yl3[0:O0j`0@0:O0j`800000303oool00`000000oooo0?ooo`060?ooo`000P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool0
102W`>/0000000000000000j0:O0j`@0Yko[102O_Nh407R/m004001NeP18R>T0:63C02QPd`80NH7?
1P2jY/D40=Vg]`<0e:RZ00<0g:jY0<fS[03=Xj`00`3=Xj`0103O_[P0a[G90<Jeb@36]LT20<c9e`@0
Yl?^101AW?<010005Z@0:TJk02Y6^`0ZA[/40;VP_`030=2h``3XaK<0j<Fc00P0k<Vb103Qc<<30>7<
a0030>3<a034bMh0a<WN00<0a<WN0`2^`nT30:k2j@@0Z<3[:`2W`>/00`000000Yl3[0:O0j`0@0:O0
j`d0oooo00<000000?ooo`3oool01P3oool000<0oooo0P00000:0?ooo`<000000`3oool2000001P0
oooo0`00000n0:O0j`@0Y[o/102O_Nh407R/m003001NeP0XH=<0:63C00<0NH7?102jY/D20<NV^080
fKNg103DZ:X00`3L[ZT0cJ>/0<fS[0020<fS[0<0gkjh00<0a[G90<c9e`3<bML00P3<bML40:NnjP@0
DiO`00@001JT02]?a00ZA[/0:TJk0P2iX;l30=2h``T0k<Vb00<0jlVb0>7<``3Qc<<00`3Qc<@30>3<
a0D0a<WN1@2^`^T50:S0jbX0Yl3[00<000000:O0j`2W`>/0402W`>/=0?ooo`030000003oool0oooo
00H0oooo000D0?ooo`030000003oool0oooo01D0oooo0`0000040?oooch0Yl3[102V_n`409fmk`@0
JZOd00<005kF02QPd`0XH=<00P1iPLl30;ZVa@@0ajJh00@0fKNg0=BXZP3DZ:X0e:RZ0P3L[ZT30<fS
[0@0gkjh103<bML20<c6e@@0YkkZ101CUo0202]?a00302Y6^`2iX;l0d;S300<0d;S300<0h<[30>c9
/P3/bK801P3/bK820>_9/P@0hLc40`3Pc<@00`3Pc<D0a<WN0<C9gP030<C9gP<0[/;Y0P2^`nT40:S0
jb/0Yl3[00<000000:O0j`2W`>/0402W`>/<0?ooo`030000003oool0oooo00H0oooo000D0?ooo`03
0000003oool0oooo0180oooo0`0000080?oooch0Yl3[102V_n`409fmk`@0JZOd00<005kF02QPd`1i
PLl00P1iPLl00`2jY/D0ajJh0<NV^0030<NV^0@0e:RZ0`3L[ZT20<fS[0@0gkjh00<0hLJl0<c9e`3<
bML0103<a]D40:Noj`@0CiOa0P0[Cl@40=2h``<0h<[31P3/bK840>_9/P80hLc40`3Pc<@30>3<a@D0
a<WN1@2^`nT40:S0jb/0Yl3[00<000000:O0j`2W`>/0402W`>/;0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`800000403oool3000000`0oooo?P2W`>/40:Jok0@0WKg_101VYOD01000<[X0NH7?
07V1c`1iPLl60<NV^0040<jX/`3DZ:X0e:RZ0=BXZP<0g:jY00<0cJ>/0=nn^03O_[P00P3O_[P30>76
_0@0c<KE0P3=amD40:Noj`<0CiOa0`0[Cl@30=2h``<0h<[300<0hL_20>c9/P3/bK800`3/bK850>_9
/P@0h<c40`3Pc<D00`3PcLD0a<WN0<C9gP030<C;h080[/?Y0`2^`nX40:S0jb/0Yl3[00<000000:O0
j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo00`0
oooo0`00000A0?ooocd0Yl3[102V_n`409fmk`@0IZGe00@003:j08:9d@22RM40PXWA1037Y[P20<jX
/`80e:RZ103L[ZT40=nn^0@0hLJl00<0h/Fk0<c6e@3<a]D0103=amD40:O1k0<0BiKa00@07W7Q02]?
a00[Cl@0d;S30`3Pb/<30>7;`P<0k<Vb1`3[bK820>3<a0<0h<c50P3PcLD50<C;h0H0[/?Z102X`>/Z
0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`00
0000oooo0?ooo`0:0?ooo`8000005@3ooolm0:O0j`@0Y[o/102M_Nl406NVm@<0PXWA0`37Y[P40<jX
/`030=BXZP3L[ZT0g:jY0080g:jY00<0i/:a0=nn^03O_[P0103Qa[`20>;5^`D0cLOE0P3=b=D40:O1
k0<0BiKa0P0NLN440>3:``<0hL_200<0h/_10>c9/P3/bK80203[bK830>3<a@<0h<g500@0hmC80<C;
h034bn00a<_P0P33cn<30:k3jP<0[<C[102X`>/Z0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool0
0`000000oooo0?ooo`050?ooo`00503oool00`000000oooo0?ooo`070?ooo`<00000603ooolm0:O0
j`@0Y[o/102M_Nl306NVm@05000FUP22RM40PXWA08:9d@37Y[P01@3>Z;<00`3DZ:X0g:jY0=b^Z@02
0=b^Z@80i/:a103Qa[`30>;5^`040>;6^`3=amD0cLOE0<g7e@@0cLSE102W_>P204nBkP<07W7Q0P3P
b/<30>7;`P<0h/_12P3[bK80103Pc<D0h<g50>3=a@3PcLD30>?Db0D0`loS1@2/a>/50:S0jbX0Yl3[
00<000000:O0j`2W`>/03`2W`>/:0?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000001@3o
ool3000001`0oooo?@2W`>/40:Jok0@0W[g^0`1YYoD308:9d@H0cZRc103L[ZT30>K2/@030>O4/`3Q
a[`0hLJl00<0h/Fk0`3Ra[/50<g8e@80cLKC102W_>P204nBkP<09gcV103Qbl840>;;`@T0jlVb0`3P
cLD40>?Db080iMo>1@2odNP40:_3k0@0Z<3[:`2W`>/00`000000Yl3[0:O0j`0?0:O0j`T0oooo00<0
00000?ooo`3oool01@3oool001<0oooo00<000000?ooo`3oool00P3oool300000200oooo?@2W`>/4
0:Jok0@0W[g^0`1YYoD306j;gPD0cZRc00@0e[Rl0=b^Z@3L[ZT0g:jY0`3V`[420>O4/`@0h/Fk103R
a[/30<g8e@<0cLKC1P2Fh_d01000Old09gcV02MliP0WO>H20>7;`PH0h/_1203[bK820>k>/`@0hmC8
0P3Uglh20>3Xf080_m7X0`2gcn`40:_3k2h0Yl3[00<000000:O0j`2W`>/0402W`>/80?ooo`030000
003oool0oooo00D0oooo000C0?ooo`030000003oool0000000800000903ooolm0:O0j`@0Y[o/102N
_Nh306bXm@80KX_N103>Z;<20=Jh_080g:jY0`3V`[440>O4/`80h/Fk1P3Ra[/40<g6d`<0eMoO103J
e=<20:>Gb0<0;X;Y1`3Rbl400`3Sbl00jlVb0>_9/P050>_9/P80k/jc00<0m=bd0>?Db03Se<P00P3U
glh30>3Xf0D0]lo/1@2Y`^`^0:O0j`030000002W`>/0Yl3[0100Yl3[1`3oool00`000000oooo0?oo
o`050?ooo`004`3oool3000002L0oooo?@2W`>/40:Jok0@0W[g^0P1/Z?D306j;gP80cZRc103F^;`0
103L[ZT0i/:a0>K2/@3V`[450>O4/`L0h/Jk00<0hlFj0<g6d`3=a]<00`3Egml30=[Dd`<0^ZK50P2S
UlP302j2j@D0h/_10P3Sbl060>_9/P<0k/jc0P3dg;@20>GOcP<0h>SH0P3Dj^D30;O?k080[lW]102Y
`^`_0:O0j`030000002W`>/0Yl3[00l0Yl3[1`3oool00`000000oooo0?ooo`050?ooo`00503oool0
0`000000oooo0?ooo`0W0?ooocd0Yl3[102V_n`409jmkP80KJWe00<005kE06j;gP3>Z;<01@3F^;`3
0>K2/@L0ilBc1@3Ra[/30>?5^P<0eMoO00<0l_B[0?OR/P2jY/D0102jY/D30:>Gb080=XK[103Rbl43
0>?;`0030>?;_`3[bK80jlVb00<0jlVb0P3^c[<30?CL]0040?GZ^03Pj=P0h>SH0>3Xf0@0e>[U1@2_
bNd40:S0jbh0Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00@0oooo000;
0?ooo`D000001@3oool2000002T0oooo?02W`>/40:Jok0@0W[g^0P1]ZOD00`00G]D0e[Rl0=Jh_003
0=Jh_080elW<0P3V`[480>O4/`@0h/Jk0`3SaKX20>O=_0040?;dZ`3gh[80mn:b0=fo^P@0^ZK5102S
UlP203J6j`80h/_10`3Sbl030>?;_`<0jlVb0`3^c[<20?CL]080mNZh0P3`m<440=CZi@<0`^3^102Z
`n`40:S0jbh0Yl3[00<000000:O0j`2W`>/0402W`>/60?ooo`030000003oool0oooo00@0oooo000=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09`3oooll0:O0j`@0Y[o/102O_Nh2
06nZm@04001Ne@3F^;`0e[Rl0=Jh_0@0elW<2P3Wa;<20>;6^`<0hlFj0`3WcK`0103bm:/0mn:b0=fo
^P3M_kX40;ZVa@D0XY?50P0mRnd40>?;`0<0hl^o00<0i<bo0>_9/P3[bK800P3^c[<20?CL]080mNZh
0`3`m<420>Gkc@<0`^3^0`2bc^l40:[3k380Yl3[00<000000:O0j`2W`>/0402W`>/50?ooo`030000
003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3o
ooll0:O0j`@0Y[o/102O_Nh206nZm@03001Ne@3F^;`0elW<00<0elW<0P3DbLl:0>O4/`040>;6^`3S
aKX0hlFj0>?5^P80ilfl00<0l_B[0?OR/P3gh[800`3M_kX20;ZVa@80/Yc2102RTlD303f;k@80hl_0
0`3Sbkl30>C<_`<0k/jc0P3dg;@20?GZ^080l?C10P3Unld20=Glg@D0//k_1@2X`N/b0:O0j`030000
002W`>/0Yl3[00l0Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02L0oooo?02W`>/40:Jok0@0Wkg^0P1aZoD40=O9c0@0e<W?2@3W
a;<30>?5^P80ilfl0P3bm:/00`3gh[80gKnj0=fo^P020=fo^P@0/Yc21@2RTlD304>?kP@0hl^o0`3T
c;l20>gM`P80m=bd0P3ej[P20?3d`@80iO_=0P3Eo=d30<;Yl0@0Z/?/102X`N/b0:O0j`030000002W
`>/0Yl3[0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0:
0?ooo`800000:03ooolk0:O0j`D0Y[o/102O_Nh2076[m@80elW<1@3DbLl90>O4/`030>O5/`3SaKX0
hlFj0080ilfl00<0l_B[0?OR/P3gh[80103M_kX00`3>/;d0/Yc20;:L`P020;:L`P@0XY?500@0SXS9
04>?kP13Snh0@ho^0P3Sbkl30>C<_`<0kMg200<0k?W10?GZ^03ej[P00P3`m<400`3Unld0eOcM0=Gl
g@030<;Yl0<0[lc_102Z`n`f0:O0j`030000002W`>/0Yl3[00l0Yl3[103oool00`000000oooo0?oo
o`040?ooo`00303oool2000000h0oooo00<000000?ooo`3oool09P3ooolk0:O0j`D0Y[o/102O_Nh2
07:[m@D0e<W?0P3Cb]070>O4/`<0ilFc0P3WcK`00`3bm:/0mn:b0?OR/P040=fo^P80c[2m102bW<85
0:BKc00408n@d011To40@I?a046Cl@@0i<bo0P3]gL820>ci`@040=Woc03Fo]T0e_kI0=Smf080b_k7
0P32o]X50:o<k`D0Z<3[=P2W`>/00`000000Yl3[0:O0j`0?0:O0j`<0oooo00<000000?ooo`3oool0
103oool001d0oooo00<000000?ooo`3oool09P3ooolk0:O0j`H0Y[o/0`2O_Nh207:[m@<0e<W?103C
b]060>O4/`<0ilFc00<0j<Nc0?SQ/03hhK000P3ki:D00`3de[00gKnj0=fo^P040<j`_@80/Yc20P2b
WlD40:BKc080Si3@0`11To420>C<_`80kMg20P3/nL40103Iol`0e_kI0=Knf@3HoMP20<[na`D0^N3c
102X`^`40:S0jcL0Yl3[00<000000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo00<0oooo
000N0?ooo`030000003oool0oooo02H0oooo?02W`>/50:Jok0@0Wkg^00<0Ljce0=?:d03Cb]000`3C
b]020=;:dP@0ilBc0`3WaK<20>S7/`80n>6`0P3ki:D20?CF/0D0c[2m102bWlD40:BKc0@0Si3@0P1W
Mll20>gM`P80k?W100@0fOo<0=Knf@3HoMP0f?gH0P3:o/L30;Wgk`@0ZlK]102X`^`j0:O0j`030000
002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?ooo`007`3oool2000002P0oooo>`2W
`>/40:Jok0D0X;g^00@0MJge0=?:d03Cb]00dl[@0`3Bb]840>O4/`<0ilFc0P3Xak<00`3hhK00nnBU
0?_TY@030?CF/0030>O=_03>/;d0c[2m0080c[2m00<0aZg10;:Oa@2bWlD00P2bWlD30:BKc0@0Si3@
0`1WMll20>ci`@0504I/d`22^_T0P[[i08:jn@2dmO800`2imnl30:k=l0@0ZlK]?P2W`>/00`000000
Yl3[0:O0j`0@0:O0j`030?ooo`000000oooo00@0oooo000Q0?ooo`030000003oool0oooo02H0oooo
>`2W`>/40:Jok0@0X;g^0P1e[OD40=;:dP80dL[C0P3Wa;<30>O5/`80j<Nc0P3hhK020?_TY@80m=J`
0P3WcK`30<j`_@80aZg1102bWlD409n9_0@0SWnn0P1kO<P404I/d`040;CelP2@k/P0T>k8093^b0D0
[/g`1@2X`>/n0:O0j`030000002W`>/0Yl3[00l0Yl3[00<0oooo0000003oool0103oool00280oooo
00<000000?ooo`3oool09P3ooolk0:O0j`@0Y[o/102P_^h207V`m@80d/[B103Ab]<40>O5/`80j<Nc
0P3hhK00103ki:D0m=J`0?CF/03de[030>O=_0030<j`_@36[L40aZg10080aZg10P2bWlD20;:J_`<0
WhVl102>Okh307]lb0<0PIoW00<0T>k80:oGm@2_eoD00`2_eoD40:S1k0@0Z<3[?`2W`>/00`000000
Yl3[0:O0j`0?0:O0j`030000003oool0oooo00<0oooo000S0?ooo`030000003oool0oooo02H0oooo
>`2W`>/40:Nok0@0X;k^0P1i/?D40=7:d`80d<[D0P3WaK<20>S7/`80n>6`0P3ki:D20?CF/0@0ilfl
1@36[L440;:J_`@0WhVl0`2>Okh407]lb0D0[=oi102X`n`40:S1k480Yl3[00<000000:O0j`2W`>/0
3`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2000002L0oooo>`2W`>/40:Nok0@0X[k]0P24
]OD20=7:d`@0d<[D0`3Xak<20?SQ/0040?_TY@3de[00m=J`0?CF/0<0ilfl0P3Lc//30<J]`@80b;_=
102bV[l309n9_0<0SWnn0P1TfMd30:?So0D0ZLC^102X`na60:O0j`030000002W`>/0Yl3[00/0Yl3[
0`3oool00`000000oooo0?ooo`030?ooo`009P3oool00`000000oooo0?ooo`0U0?ooocl0Yl3[102R
_^d209:kl`@0d<[D0`3?bmD20?SQ/080i?_=0P3ZnLL30>O=_0<0g<k;0P36[L430<Rkc@@0/YZo0`2O
RK`4087JoP0309WOoP2Xa^l0Z<K_0080Z<K_102Ya>i;0:O0j`030000002W`>/0Yl3[00H0Yl3[203o
ool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0U0?ooocl0Yl3[102T_nd2
09:kl`80d<[D0`3?bmD30=STg`030>Ckc@3ZnLL0j_W70080g__H1@3Lc//50<Rkc@@0/YZo1@2Dh_d4
0:O5k`@0Z<K_102W_n]:0:O0j`030000002W`>/0Yl3[00<0Yl3[2`3oool00`000000oooo0?ooo`02
0?ooo`00:03oool00`000000oooo0?ooo`0V0?oooch0Yl3[102T_nd209jnk`<0cl_E0`3Hi=l00`3T
nld0j_W70>[ia`020=kkf080XoKX0`3Lc//20<?fkP@0b;_=1@1jiN<50:K3k`@0YlG_202W_n]:0:O0
j`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00000W0?oooch0
Yl3[1@2V_n`209jnk`<0f>CO00@0i?_=0>[ia`3NnmP0g__H1@2Sm^P50<?fkPD0V<Og102U`^d40:K3
k`T0Yko[B`2W`>/30?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool002/0
oooo00<000000?ooo`3oool09@3ooom30:O0j`<0YKo/00<0i?_=0:Fok@2U_nd00P2U_nd409fol0@0
Xl3^102N`_440:K0k0@0YL;]102X_n/40:Noj`D0Yl7/1@2W_n]10:O0j`P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?ooodL0Yl3[
102U_nd40:K0k0@0Xl3^102W`>`40:K0k0@0Z<3[102X_n/50:O1k0P0Yko[?P2W`>/;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002d0oooo00<000000?ooo`3oool09P3o
oom:0:O0j`@0Y/3/102W`>/40:O0k0D0Yl3[0`2X`>/50:O0k0P0Yko[?P2W`>/?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00@3oool002h0oooo00<000000?ooo`3oool09P3ooomN
0:O0j`T0Yko[102W`>`i0:O0ja@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`01
0?ooo`00;`3oool2000002L0ooooGP2W`>/40:Noj`P0Yl3/1@2W_n/a0:O0jaP0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0U0?ooof80
Yl3[102W`>`80:Nojbd0Yl3[703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040
oooo000b0?ooo`030000003oool0oooo02D0ooooHP2W`>/80:Nojbd0Yl3[803oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0040oooo000c0?ooo`030000003oool0oooo02D0ooooHP2W
`>/40:Nojbd0Yl3[903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000d
0?ooo`8000009P3ooomV0:O0j`D0Yko[8`2W`>/Y0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00@3oool003H0oooo00<000000?ooo`3oool09@3ooomQ0:O0j`P0Yko[802W`>//0?oo
o`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo000g0?ooo`030000003oool0oooo02D0
ooooH@2W`>/40:Nojb00Yl3[<03oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00
>03oool00`000000oooo0?ooo`0U0?ooogd0Yl3[>03oool00`000000oooo0?ooo`050?ooo`400000
0@3oool10?ooo`00>@3oool2000002H0ooooI02W`>/50:Noja00Yl3[>`3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`00>`3oool00`000000oooo0?ooo`0T0?ooof00Yl3[202W_n/=
0:O0jcl0oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool003`0oooo00<000000?oo
o`3oool0903oooma0:O0jd<0oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool003d0
oooo00<000000?ooo`3oool0903ooomT0:O0j`D0Yko[0`2W`>]80?ooo`030000003oool0oooo0080
oooo0@0000010?ooo`40oooo000n0?ooo`8000009@3ooomP0:O0j`P0Yko[B`3oool00`000000oooo
0?ooo`030?ooo`4000000@3oool00400oooo00<000000?ooo`3oool08`3ooomP0:O0j`@0Yko[C`3o
ool00`000000oooo0?ooo`020?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3ooomP
0:O0je<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3oool00`000000oooo0?ooo`0T
0?oooe/0Yl3[E`3oool010000000oooo0?ooo`0000010?ooo`00@`3oool2000002D0ooooD`2W`>]N
0?ooo`040000003oool0oooo00000040oooo00150?ooo`030000003oool0oooo02<0ooooC`2W`>]R
0?ooo`030000003oool000000040oooo00160?ooo`030000003oool0oooo02<0ooooB`2W`>]V0?oo
o`4000000@3oool100000000A`3oool00`000000oooo0?ooo`0S0?ooodL0Yl3[JP3oool200000000
B03oool2000002D0oooo@P2W`>]]0?ooo`800000001:0?ooo`030000003oool0oooo02<0oooo?P2W
`>]`0?ooo`800000001;0?ooo`030000003oool0oooo0280oooo>`2W`>]_0?ooo`@000000P3oool0
04`0oooo00<000000?ooo`3oool08`3ooolc0:O0jg40oooo100000060?ooo`00C@3oool2000002@0
oooo;`2W`>]`0?ooo`@000002P3oool004l0oooo00<000000?ooo`3oool08P3oool[0:O0jfl0oooo
1000000>0?ooo`00D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo001A
0?ooo`030000003oool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580oooo0P00000T0?oo
oah0Yl3[K@3oool4000001T0oooo001D0?ooo`030000003oool0oooo0280oooo5`2W`>]_0?ooo`@0
00007@3oool005D0oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00EP3o
ool00`000000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?ooo`8000008`3oool;
0:O0jf`0oooo1000000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool30000
02d0oooo001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool400000300
oooo001K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0oooo
001L0?ooo`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool005h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00000L0?ooo`030000
003oool0oooo05<0oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo04/0oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
04L0oooo1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0
oooo1000001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03oool3000005/0oooo
001Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4000005h0oooo001Z
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?ooo`80
0000403oool00`000000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`030000003oool0oooo
0280oooo1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0
oooo1000001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
100000210?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo1000
00250?ooo`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`050000
003oool0oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003oool0
103oool4000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3oool2
00000:00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .64539 .59604 .63937 Mtetra
.59604 .63937 .60194 .64539 .6135 .64214 .60764 .63608 Mtetra
.60764 .63608 .6135 .64214 .62511 .63887 .61928 .63278 Mtetra
.61928 .63278 .62511 .63887 .63677 .63558 .63097 .62946 Mtetra
.63097 .62946 .63677 .63558 .64848 .63228 .64272 .62613 Mtetra
.64272 .62613 .64848 .63228 .66023 .62896 .65451 .6228 Mtetra
.65451 .6228 .66023 .62896 .67204 .62563 .66635 .61945 Mtetra
.656 .752 .92 r
.66635 .61945 .67204 .62563 .6839 .62228 .67824 .61608 Mtetra
.67824 .61608 .6839 .62228 .6958 .61893 .69018 .61269 Mtetra
.656 .751 .92 r
.69018 .61269 .6958 .61893 .70776 .61557 .70217 .60929 Mtetra
.70217 .60929 .70776 .61557 .71977 .61218 .71421 .60588 Mtetra
.71421 .60588 .71977 .61218 .73182 .60878 .7263 .60246 Mtetra
.7263 .60246 .73182 .60878 .74393 .60536 .73845 .59902 Mtetra
.73845 .59902 .74393 .60536 .75609 .60193 .75064 .59557 Mtetra
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62666 Mtetra
.656 .752 .92 r
.61341 .62666 .61928 .63278 .63097 .62946 .62514 .62333 Mtetra
.656 .752 .921 r
.62514 .62333 .63097 .62946 .64272 .62613 .63691 .61997 Mtetra
.63691 .61997 .64272 .62613 .65451 .6228 .64873 .6166 Mtetra
.656 .752 .92 r
.64873 .6166 .65451 .6228 .66635 .61945 .66061 .61322 Mtetra
.656 .751 .92 r
.66061 .61322 .66635 .61945 .67824 .61608 .67253 .60982 Mtetra
.67253 .60982 .67824 .61608 .69018 .61269 .68451 .60642 Mtetra
.656 .752 .92 r
.68451 .60642 .69018 .61269 .70217 .60929 .69653 .603 Mtetra
.656 .752 .921 r
.69653 .603 .70217 .60929 .71421 .60588 .70861 .59956 Mtetra
.70861 .59956 .71421 .60588 .7263 .60246 .72074 .5961 Mtetra
.656 .752 .92 r
.72074 .5961 .7263 .60246 .73845 .59902 .73292 .59263 Mtetra
.656 .751 .92 r
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Mtetra
.59578 .62383 .60173 .62998 .61341 .62666 .60749 .62048 Mtetra
.60749 .62048 .61341 .62666 .62514 .62333 .61925 .61711 Mtetra
.61925 .61711 .62514 .62333 .63691 .61997 .63106 .61373 Mtetra
.63106 .61373 .63691 .61997 .64873 .6166 .64292 .61034 Mtetra
.64292 .61034 .64873 .6166 .66061 .61322 .65482 .60694 Mtetra
.65482 .60694 .66061 .61322 .67253 .60982 .66678 .60352 Mtetra
.656 .752 .92 r
.66678 .60352 .67253 .60982 .68451 .60642 .67879 .60008 Mtetra
.656 .751 .92 r
.67879 .60008 .68451 .60642 .69653 .603 .69085 .59662 Mtetra
.69085 .59662 .69653 .603 .70861 .59956 .70297 .59316 Mtetra
.70297 .59316 .70861 .59956 .72074 .5961 .71513 .58968 Mtetra
.71513 .58968 .72074 .5961 .73292 .59263 .72735 .58619 Mtetra
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Mtetra
.656 .752 .92 r
.60153 .61426 .60749 .62048 .61925 .61711 .61332 .61088 Mtetra
.656 .752 .921 r
.61332 .61088 .61925 .61711 .63106 .61373 .62516 .60748 Mtetra
.62516 .60748 .63106 .61373 .64292 .61034 .63705 .60405 Mtetra
.656 .752 .92 r
.63705 .60405 .64292 .61034 .65482 .60694 .649 .60061 Mtetra
.656 .751 .92 r
.649 .60061 .65482 .60694 .66678 .60352 .66099 .59716 Mtetra
.66099 .59716 .66678 .60352 .67879 .60008 .67303 .5937 Mtetra
.656 .752 .921 r
.67303 .5937 .67879 .60008 .69085 .59662 .68513 .59023 Mtetra
.68513 .59023 .69085 .59662 .70297 .59316 .69728 .58674 Mtetra
.69728 .58674 .70297 .59316 .71513 .58968 .70948 .58322 Mtetra
.656 .752 .92 r
.70948 .58322 .71513 .58968 .72735 .58619 .72173 .5797 Mtetra
.656 .751 .92 r
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Mtetra
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Mtetra
.59552 .60799 .60153 .61426 .61332 .61088 .60734 .60456 Mtetra
.60734 .60456 .61332 .61088 .62516 .60748 .61922 .60113 Mtetra
.61922 .60113 .62516 .60748 .63705 .60405 .63114 .59769 Mtetra
.63114 .59769 .63705 .60405 .649 .60061 .64312 .59423 Mtetra
.64312 .59423 .649 .60061 .66099 .59716 .65515 .59076 Mtetra
.656 .752 .92 r
.65515 .59076 .66099 .59716 .67303 .5937 .66723 .58726 Mtetra
.656 .751 .92 r
.66723 .58726 .67303 .5937 .68513 .59023 .67936 .58375 Mtetra
.67936 .58375 .68513 .59023 .69728 .58674 .69154 .58023 Mtetra
.69154 .58023 .69728 .58674 .70948 .58322 .70378 .5767 Mtetra
.70378 .5767 .70948 .58322 .72173 .5797 .71607 .57315 Mtetra
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56959 Mtetra
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Mtetra
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Mtetra
.656 .752 .921 r
.58946 .60167 .59552 .60799 .60734 .60456 .60132 .59824 Mtetra
.60132 .59824 .60734 .60456 .61922 .60113 .61323 .59478 Mtetra
.61323 .59478 .61922 .60113 .63114 .59769 .62519 .5913 Mtetra
.656 .752 .92 r
.62519 .5913 .63114 .59769 .64312 .59423 .6372 .5878 Mtetra
.656 .751 .92 r
.6372 .5878 .64312 .59423 .65515 .59076 .64926 .5843 Mtetra
.64926 .5843 .65515 .59076 .66723 .58726 .66138 .58079 Mtetra
.656 .752 .921 r
.66138 .58079 .66723 .58726 .67936 .58375 .67354 .57726 Mtetra
.67354 .57726 .67936 .58375 .69154 .58023 .68577 .57371 Mtetra
.68577 .57371 .69154 .58023 .70378 .5767 .69804 .57014 Mtetra
.656 .752 .92 r
.69804 .57014 .70378 .5767 .71607 .57315 .71036 .56656 Mtetra
.656 .751 .92 r
.71036 .56656 .71607 .57315 .72841 .56959 .72274 .56296 Mtetra
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59876 Mtetra
.57151 .59876 .57765 .6051 .58946 .60167 .58335 .59529 Mtetra
.58335 .59529 .58946 .60167 .60132 .59824 .59525 .59182 Mtetra
.59525 .59182 .60132 .59824 .61323 .59478 .60719 .58833 Mtetra
.656 .75 .92 r
.60719 .58833 .61323 .59478 .62519 .5913 .61918 .58483 Mtetra
.655 .751 .92 r
.61918 .58483 .62519 .5913 .6372 .5878 .63123 .58133 Mtetra
.656 .752 .92 r
.63123 .58133 .6372 .5878 .64926 .5843 .64333 .5778 Mtetra
.64333 .5778 .64926 .5843 .66138 .58079 .65548 .57424 Mtetra
.656 .751 .92 r
.65548 .57424 .66138 .58079 .67354 .57726 .66768 .57067 Mtetra
.656 .75 .92 r
.66768 .57067 .67354 .57726 .68577 .57371 .67994 .56709 Mtetra
.656 .751 .92 r
.67994 .56709 .68577 .57371 .69804 .57014 .69225 .56351 Mtetra
.69225 .56351 .69804 .57014 .71036 .56656 .70461 .5599 Mtetra
.70461 .5599 .71036 .56656 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Mtetra
.56532 .59236 .57151 .59876 .58335 .59529 .5772 .58889 Mtetra
.655 .752 .921 r
.5772 .58889 .58335 .59529 .59525 .59182 .58913 .5854 Mtetra
.656 .752 .921 r
.58913 .5854 .59525 .59182 .60719 .58833 .6011 .58189 Mtetra
.656 .753 .921 r
.6011 .58189 .60719 .58833 .61918 .58483 .61313 .57835 Mtetra
.656 .752 .921 r
.61313 .57835 .61918 .58483 .63123 .58133 .62521 .57479 Mtetra
.656 .751 .92 r
.62521 .57479 .63123 .58133 .64333 .5778 .63735 .57123 Mtetra
.655 .751 .92 r
.63735 .57123 .64333 .5778 .65548 .57424 .64953 .56767 Mtetra
.655 .752 .921 r
.64953 .56767 .65548 .57424 .66768 .57067 .66177 .56409 Mtetra
.656 .752 .921 r
.66177 .56409 .66768 .57067 .67994 .56709 .67407 .56048 Mtetra
.67407 .56048 .67994 .56709 .69225 .56351 .68641 .55684 Mtetra
.656 .752 .92 r
.68641 .55684 .69225 .56351 .70461 .5599 .69881 .5532 Mtetra
.656 .751 .92 r
.69881 .5532 .70461 .5599 .71703 .55628 .71127 .54955 Mtetra
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Mtetra
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58592 Mtetra
.55909 .58592 .56532 .59236 .5772 .58889 .571 .5824 Mtetra
.571 .5824 .5772 .58889 .58913 .5854 .58296 .57886 Mtetra
.656 .75 .919 r
.58296 .57886 .58913 .5854 .6011 .58189 .59497 .57532 Mtetra
.655 .75 .919 r
.59497 .57532 .6011 .58189 .61313 .57835 .60703 .57177 Mtetra
.655 .751 .92 r
.60703 .57177 .61313 .57835 .62521 .57479 .61915 .56821 Mtetra
.656 .752 .92 r
.61915 .56821 .62521 .57479 .63735 .57123 .63132 .56462 Mtetra
.63132 .56462 .63735 .57123 .64953 .56767 .64354 .56101 Mtetra
.656 .751 .92 r
.64354 .56101 .64953 .56767 .66177 .56409 .65582 .55738 Mtetra
.656 .75 .919 r
.65582 .55738 .66177 .56409 .67407 .56048 .66815 .55374 Mtetra
.655 .75 .92 r
.66815 .55374 .67407 .56048 .68641 .55684 .68053 .5501 Mtetra
.656 .751 .92 r
.68053 .5501 .68641 .55684 .69881 .5532 .69297 .54644 Mtetra
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Mtetra
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Mtetra
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Mtetra
.52907 .58646 .53542 .5929 .54723 .58942 .54091 .58295 Mtetra
.54091 .58295 .54723 .58942 .55909 .58592 .5528 .57943 Mtetra
.655 .751 .92 r
.5528 .57943 .55909 .58592 .571 .5824 .56474 .5759 Mtetra
.655 .752 .921 r
.56474 .5759 .571 .5824 .58296 .57886 .57674 .57236 Mtetra
.655 .753 .921 r
.57674 .57236 .58296 .57886 .59497 .57532 .58879 .56879 Mtetra
.656 .753 .922 r
.58879 .56879 .59497 .57532 .60703 .57177 .60088 .5652 Mtetra
.656 .753 .921 r
.60088 .5652 .60703 .57177 .61915 .56821 .61304 .56158 Mtetra
.656 .752 .92 r
.61304 .56158 .61915 .56821 .63132 .56462 .62524 .55796 Mtetra
.655 .751 .921 r
.62524 .55796 .63132 .56462 .64354 .56101 .6375 .55435 Mtetra
.655 .752 .921 r
.6375 .55435 .64354 .56101 .65582 .55738 .64981 .55071 Mtetra
.656 .753 .922 r
.64981 .55071 .65582 .55738 .66815 .55374 .66218 .54703 Mtetra
.656 .753 .921 r
.66218 .54703 .66815 .55374 .68053 .5501 .6746 .54334 Mtetra
.656 .752 .921 r
.6746 .54334 .68053 .5501 .69297 .54644 .68707 .53963 Mtetra
.656 .751 .92 r
.68707 .53963 .69297 .54644 .70546 .54276 .69961 .53592 Mtetra
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53218 Mtetra
.71219 .53218 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Mtetra
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57997 Mtetra
.52266 .57997 .52907 .58646 .54091 .58295 .53454 .57643 Mtetra
.53454 .57643 .54091 .58295 .5528 .57943 .54646 .57289 Mtetra
.655 .752 .921 r
.54646 .57289 .5528 .57943 .56474 .5759 .55844 .56933 Mtetra
.655 .751 .921 r
.55844 .56933 .56474 .5759 .57674 .57236 .57047 .56578 Mtetra
.653 .751 .922 r
.57047 .56578 .57674 .57236 .58879 .56879 .58255 .56225 Mtetra
.652 .753 .924 r
.58255 .56225 .58879 .56879 .60088 .5652 .59469 .55873 Mtetra
.653 .757 .926 r
.59469 .55873 .60088 .5652 .61304 .56158 .60688 .55518 Mtetra
.655 .76 .927 r
.60688 .55518 .61304 .56158 .62524 .55796 .61912 .55154 Mtetra
.658 .761 .926 r
.61912 .55154 .62524 .55796 .6375 .55435 .63142 .5478 Mtetra
.659 .759 .924 r
.63142 .5478 .6375 .55435 .64981 .55071 .64376 .54402 Mtetra
.658 .755 .922 r
.64376 .54402 .64981 .55071 .66218 .54703 .65616 .54025 Mtetra
.657 .753 .921 r
.65616 .54025 .66218 .54703 .6746 .54334 .66862 .53651 Mtetra
.656 .752 .92 r
.66862 .53651 .6746 .54334 .68707 .53963 .68113 .53277 Mtetra
.68113 .53277 .68707 .53963 .69961 .53592 .6937 .52902 Mtetra
.6937 .52902 .69961 .53592 .71219 .53218 .70633 .52526 Mtetra
.656 .751 .92 r
.70633 .52526 .71219 .53218 .72483 .52844 .71901 .52148 Mtetra
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Mtetra
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Mtetra
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Mtetra
.49255 .58051 .49907 .587 .51084 .58349 .50435 .57698 Mtetra
.50435 .57698 .51084 .58349 .52266 .57997 .51621 .57343 Mtetra
.655 .751 .921 r
.51621 .57343 .52266 .57997 .53454 .57643 .52812 .5699 Mtetra
.651 .751 .923 r
.52812 .5699 .53454 .57643 .54646 .57289 .54008 .56645 Mtetra
.644 .753 .928 r
.54008 .56645 .54646 .57289 .55844 .56933 .55209 .56317 Mtetra
.633 .759 .939 r
.55209 .56317 .55844 .56933 .57047 .56578 .56416 .56013 Mtetra
.621 .774 .954 r
.56416 .56013 .57047 .56578 .58255 .56225 .5763 .55726 Mtetra
.614 .797 .969 r
.5763 .55726 .58255 .56225 .59469 .55873 .58849 .55433 Mtetra
.618 .821 .978 r
.58849 .55433 .59469 .55873 .60688 .55518 .60073 .5511 Mtetra
.632 .838 .979 r
.60073 .5511 .60688 .55518 .61912 .55154 .61301 .54742 Mtetra
.652 .844 .974 r
.61301 .54742 .61912 .55154 .63142 .5478 .62534 .54331 Mtetra
.669 .836 .963 r
.62534 .54331 .63142 .5478 .64376 .54402 .63772 .53889 Mtetra
.676 .815 .95 r
.63772 .53889 .64376 .54402 .65616 .54025 .65013 .53441 Mtetra
.672 .79 .937 r
.65013 .53441 .65616 .54025 .66862 .53651 .66261 .53008 Mtetra
.665 .769 .928 r
.66261 .53008 .66862 .53651 .68113 .53277 .67515 .52601 Mtetra
.66 .758 .923 r
.67515 .52601 .68113 .53277 .6937 .52902 .68775 .5221 Mtetra
.657 .753 .921 r
.68775 .5221 .6937 .52902 .70633 .52526 .70041 .51828 Mtetra
.656 .752 .92 r
.70041 .51828 .70633 .52526 .71901 .52148 .71313 .51446 Mtetra
.656 .751 .92 r
.71313 .51446 .71901 .52148 .73175 .51768 .72591 .51063 Mtetra
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Mtetra
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Mtetra
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Mtetra
.47419 .57752 .48079 .58403 .49255 .58051 .48598 .57397 Mtetra
.655 .751 .92 r
.48598 .57397 .49255 .58051 .50435 .57698 .49781 .57043 Mtetra
.653 .751 .922 r
.49781 .57043 .50435 .57698 .51621 .57343 .5097 .56693 Mtetra
.644 .751 .927 r
.5097 .56693 .51621 .57343 .52812 .5699 .52164 .56367 Mtetra
.619 .752 .941 r
.52164 .56367 .52812 .5699 .54008 .56645 .53364 .56099 Mtetra
.565 .761 .97 r
.53364 .56099 .54008 .56645 .55209 .56317 .5457 .55922 Mtetra
.462 .777 .998 r
.5457 .55922 .55209 .56317 .56416 .56013 .55784 .55828 Mtetra
.288 .757 .941 r
.55784 .55828 .56416 .56013 .5763 .55726 .57005 .55755 Mtetra
.115 .667 .752 r
.57005 .55755 .5763 .55726 .58849 .55433 .58233 .55627 Mtetra
0 0 0 r
.58233 .55627 .58849 .55433 .60073 .5511 .59466 .55389 Mtetra
.59466 .55389 .60073 .5511 .61301 .54742 .60702 .5502 Mtetra
.60702 .5502 .61301 .54742 .62534 .54331 .61939 .5452 Mtetra
.43 .863 .758 r
.61939 .5452 .62534 .54331 .63772 .53889 .63178 .53908 Mtetra
.625 .958 .904 r
.63178 .53908 .63772 .53889 .65013 .53441 .64419 .53238 Mtetra
.711 .936 .961 r
.64419 .53238 .65013 .53441 .66261 .53008 .65664 .52589 Mtetra
.709 .861 .954 r
.65664 .52589 .66261 .53008 .67515 .52601 .66916 .52023 Mtetra
.684 .8 .936 r
.66916 .52023 .67515 .52601 .68775 .5221 .68177 .51548 Mtetra
.666 .767 .926 r
.68177 .51548 .68775 .5221 .70041 .51828 .69446 .51132 Mtetra
.658 .755 .921 r
.69446 .51132 .70041 .51828 .71313 .51446 .70721 .5074 Mtetra
.656 .752 .92 r
.70721 .5074 .71313 .51446 .72591 .51063 .72003 .50352 Mtetra
.656 .751 .92 r
.72003 .50352 .72591 .51063 .73875 .50679 .7329 .49965 Mtetra
.7329 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Mtetra
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Mtetra
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57096 Mtetra
.655 .751 .92 r
.46753 .57096 .47419 .57752 .48598 .57397 .47935 .5674 Mtetra
.652 .751 .922 r
.47935 .5674 .48598 .57397 .49781 .57043 .49122 .56391 Mtetra
.638 .749 .929 r
.49122 .56391 .49781 .57043 .5097 .56693 .50314 .5608 Mtetra
.588 .746 .952 r
.50314 .5608 .5097 .56693 .52164 .56367 .51511 .55879 Mtetra
.438 .731 .989 r
.51511 .55879 .52164 .56367 .53364 .56099 .52715 .55871 Mtetra
.065 .598 .861 r
.52715 .55871 .53364 .56099 .5457 .55922 .53927 .56031 Mtetra
.257 0 0 r
.53927 .56031 .5457 .55922 .55784 .55828 .55149 .56177 Mtetra
.25 0 0 r
.55149 .56177 .55784 .55828 .57005 .55755 .56377 .56122 Mtetra
.071 0 0 r
.56377 .56122 .57005 .55755 .58233 .55627 .57609 .55842 Mtetra
0 0 0 r
.57609 .55842 .58233 .55627 .59466 .55389 .58846 .5546 Mtetra
.331 .815 .817 r
.58846 .5546 .59466 .55389 .60702 .5502 .60089 .55089 Mtetra
.317 .806 .812 r
.60089 .55089 .60702 .5502 .61939 .5452 .61337 .5473 Mtetra
.26 .754 .68 r
.61337 .5473 .61939 .5452 .63178 .53908 .62588 .54267 Mtetra
0 0 0 r
.62588 .54267 .63178 .53908 .64419 .53238 .63836 .53577 Mtetra
.498 .872 .661 r
.63836 .53577 .64419 .53238 .65664 .52589 .6508 .5268 Mtetra
.71 .986 .857 r
.6508 .5268 .65664 .52589 .66916 .52023 .66326 .51768 Mtetra
.753 .929 .946 r
.66326 .51768 .66916 .52023 .68177 .51548 .6758 .51024 Mtetra
.705 .827 .94 r
.6758 .51024 .68177 .51548 .69446 .51132 .68847 .50474 Mtetra
.671 .773 .927 r
.68847 .50474 .69446 .51132 .70721 .5074 .70125 .50036 Mtetra
.659 .756 .922 r
.70125 .50036 .70721 .5074 .72003 .50352 .7141 .49637 Mtetra
.656 .752 .92 r
.7141 .49637 .72003 .50352 .7329 .49965 .72701 .49245 Mtetra
.656 .751 .92 r
.72701 .49245 .7329 .49965 .74584 .49575 .73999 .48852 Mtetra
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Mtetra
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Mtetra
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56793 Mtetra
.44902 .56793 .45576 .57452 .46753 .57096 .46082 .56435 Mtetra
.653 .751 .921 r
.46082 .56435 .46753 .57096 .47935 .5674 .47267 .56081 Mtetra
.64 .749 .927 r
.47267 .56081 .47935 .5674 .49122 .56391 .48457 .55762 Mtetra
.583 .74 .951 r
.48457 .55762 .49122 .56391 .50314 .5608 .49651 .55573 Mtetra
.374 .694 .982 r
.49651 .55573 .50314 .5608 .51511 .55879 .50851 .55655 Mtetra
0 .43 .727 r
.50851 .55655 .51511 .55879 .52715 .55871 .52058 .55993 Mtetra
.341 0 0 r
.52058 .55993 .52715 .55871 .53927 .56031 .53276 .56228 Mtetra
0 0 0 r
.53276 .56228 .53927 .56031 .55149 .56177 .54501 .55963 Mtetra
.753 .93 .946 r
.54501 .55963 .55149 .56177 .56377 .56122 .55727 .55235 Mtetra
.751 .728 .831 r
.55727 .55235 .56377 .56122 .57609 .55842 .56955 .54411 Mtetra
.685 .618 .775 r
.56955 .54411 .57609 .55842 .58846 .5546 .58189 .5377 Mtetra
.633 .565 .76 r
.58189 .5377 .58846 .5546 .60089 .55089 .59431 .53396 Mtetra
.585 .539 .769 r
.59431 .53396 .60089 .55089 .61337 .5473 .60686 .53289 Mtetra
.54 .544 .807 r
.60686 .53289 .61337 .5473 .62588 .54267 .61953 .53367 Mtetra
.536 .646 .905 r
.61953 .53367 .62588 .54267 .63836 .53577 .63227 .53349 Mtetra
.631 .91 .982 r
.63227 .53349 .63836 .53577 .6508 .5268 .64492 .52862 Mtetra
.693 .978 .803 r
.64492 .52862 .6508 .5268 .66326 .51768 .65743 .51867 Mtetra
.783 .998 .837 r
.65743 .51867 .66326 .51768 .6758 .51024 .66989 .50767 Mtetra
.783 .933 .93 r
.66989 .50767 .6758 .51024 .68847 .50474 .68249 .49924 Mtetra
.71 .822 .935 r
.68249 .49924 .68847 .50474 .70125 .50036 .69524 .49356 Mtetra
.669 .768 .924 r
.69524 .49356 .70125 .50036 .7141 .49637 .70812 .4892 Mtetra
.658 .754 .921 r
.70812 .4892 .7141 .49637 .72701 .49245 .72107 .48519 Mtetra
.656 .752 .92 r
.72107 .48519 .72701 .49245 .73999 .48852 .73409 .48123 Mtetra
.656 .751 .92 r
.73409 .48123 .73999 .48852 .75302 .48458 .74716 .47725 Mtetra
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Mtetra
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Mtetra
.43044 .5649 .43727 .57151 .44902 .56793 .44222 .5613 Mtetra
.655 .751 .921 r
.44222 .5613 .44902 .56793 .46082 .56435 .45405 .5577 Mtetra
.648 .75 .923 r
.45405 .5577 .46082 .56435 .47267 .56081 .46593 .55428 Mtetra
.611 .742 .939 r
.46593 .55428 .47267 .56081 .48457 .55762 .47786 .55179 Mtetra
.447 .701 .975 r
.47786 .55179 .48457 .55762 .49651 .55573 .48981 .55205 Mtetra
0 .434 .798 r
.48981 .55205 .49651 .55573 .50851 .55655 .50182 .5563 Mtetra
.432 0 0 r
.50182 .5563 .50851 .55655 .52058 .55993 .51394 .56097 Mtetra
0 0 0 r
.51394 .56097 .52058 .55993 .53276 .56228 .52616 .55908 Mtetra
.819 .893 .896 r
.52616 .55908 .53276 .56228 .54501 .55963 .53843 .54949 Mtetra
.779 .712 .789 r
.53843 .54949 .54501 .55963 .55727 .55235 .5507 .53835 Mtetra
.711 .634 .769 r
.5507 .53835 .55727 .55235 .56955 .54411 .563 .53024 Mtetra
.668 .616 .787 r
.563 .53024 .56955 .54411 .58189 .5377 .57536 .52498 Mtetra
.645 .621 .812 r
.57536 .52498 .58189 .5377 .59431 .53396 .5878 .52121 Mtetra
.612 .606 .82 r
.5878 .52121 .59431 .53396 .60686 .53289 .60033 .51892 Mtetra
.542 .552 .814 r
.60033 .51892 .60686 .53289 .61953 .53367 .61301 .5195 Mtetra
.453 .5 .817 r
.61301 .5195 .61953 .53367 .63227 .53349 .62586 .52314 Mtetra
.46 .577 .885 r
.62586 .52314 .63227 .53349 .64492 .52862 .63878 .52521 Mtetra
.696 .892 .969 r
.63878 .52521 .64492 .52862 .65743 .51867 .65151 .5195 Mtetra
.832 .999 .829 r
.65151 .5195 .65743 .51867 .66989 .50767 .66401 .50713 Mtetra
.851 .982 .862 r
.66401 .50713 .66989 .50767 .68249 .49924 .67651 .49515 Mtetra
.773 .884 .925 r
.67651 .49515 .68249 .49924 .69524 .49356 .68921 .48721 Mtetra
.692 .792 .927 r
.68921 .48721 .69524 .49356 .70812 .4892 .7021 .48208 Mtetra
.662 .759 .922 r
.7021 .48208 .70812 .4892 .72107 .48519 .71508 .47789 Mtetra
.657 .752 .92 r
.71508 .47789 .72107 .48519 .73409 .48123 .72814 .47387 Mtetra
.656 .751 .92 r
.72814 .47387 .73409 .48123 .74716 .47725 .74126 .46986 Mtetra
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Mtetra
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Mtetra
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55823 Mtetra
.42355 .55823 .43044 .5649 .44222 .5613 .43536 .55461 Mtetra
.654 .751 .921 r
.43536 .55461 .44222 .5613 .45405 .5577 .44723 .55101 Mtetra
.64 .748 .927 r
.44723 .55101 .45405 .5577 .46593 .55428 .45914 .54779 Mtetra
.563 .729 .952 r
.45914 .54779 .46593 .55428 .47786 .55179 .47108 .54631 Mtetra
.202 .585 .943 r
.47108 .54631 .47786 .55179 .48981 .55205 .48303 .54922 Mtetra
.472 0 0 r
.48303 .54922 .48981 .55205 .50182 .5563 .49504 .5566 Mtetra
.419 0 0 r
.49504 .5566 .50182 .5563 .51394 .56097 .50721 .5607 Mtetra
.713 .971 .93 r
.50721 .5607 .51394 .56097 .52616 .55908 .5195 .55326 Mtetra
.862 .807 .795 r
.5195 .55326 .52616 .55908 .53843 .54949 .53181 .53835 Mtetra
.786 .699 .768 r
.53181 .53835 .53843 .54949 .5507 .53835 .5441 .52572 Mtetra
.712 .652 .789 r
.5441 .52572 .5507 .53835 .563 .53024 .55643 .51817 Mtetra
.667 .642 .815 r
.55643 .51817 .563 .53024 .57536 .52498 .56882 .51337 Mtetra
.648 .642 .83 r
.56882 .51337 .57536 .52498 .5878 .52121 .58128 .50957 Mtetra
.625 .631 .837 r
.58128 .50957 .5878 .52121 .60033 .51892 .59382 .50676 Mtetra
.55 .586 .843 r
.59382 .50676 .60033 .51892 .61301 .5195 .60649 .50672 Mtetra
.377 .48 .838 r
.60649 .50672 .61301 .5195 .62586 .52314 .61939 .51179 Mtetra
.226 .419 .843 r
.61939 .51179 .62586 .52314 .63878 .52521 .63249 .51918 Mtetra
.472 .715 .976 r
.63249 .51918 .63878 .52521 .65151 .5195 .64547 .51901 Mtetra
.847 .982 .865 r
.64547 .51901 .65151 .5195 .66401 .50713 .65807 .50714 Mtetra
.902 .975 .806 r
.65807 .50714 .66401 .50713 .67651 .49515 .67052 .49193 Mtetra
.836 .914 .888 r
.67052 .49193 .67651 .49515 .68921 .48721 .68315 .48123 Mtetra
.723 .814 .921 r
.68315 .48123 .68921 .48721 .7021 .48208 .69603 .47499 Mtetra
.67 .764 .921 r
.69603 .47499 .7021 .48208 .71508 .47789 .70904 .47054 Mtetra
.657 .753 .92 r
.70904 .47054 .71508 .47789 .72814 .47387 .72214 .46645 Mtetra
.656 .752 .92 r
.72214 .46645 .72814 .47387 .74126 .46986 .7353 .4624 Mtetra
.656 .751 .92 r
.7353 .4624 .74126 .46986 .75443 .46583 .74852 .45834 Mtetra
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Mtetra
.40481 .55516 .41179 .56185 .42355 .55823 .41661 .55152 Mtetra
.41661 .55152 .42355 .55823 .43536 .55461 .42845 .54786 Mtetra
.653 .751 .921 r
.42845 .54786 .43536 .55461 .44723 .55101 .44035 .54427 Mtetra
.631 .745 .93 r
.44035 .54427 .44723 .55101 .45914 .54779 .45229 .54126 Mtetra
.506 .706 .96 r
.45229 .54126 .45914 .54779 .47108 .54631 .46424 .54083 Mtetra
0 .395 .823 r
.46424 .54083 .47108 .54631 .48303 .54922 .47618 .54643 Mtetra
.646 .089 0 r
.47618 .54643 .48303 .54922 .49504 .5566 .48818 .55692 Mtetra
.369 0 0 r
.48818 .55692 .49504 .5566 .50721 .5607 .5004 .56036 Mtetra
.882 .958 .847 r
.5004 .56036 .50721 .5607 .5195 .55326 .51278 .54718 Mtetra
.894 .792 .741 r
.51278 .54718 .5195 .55326 .53181 .53835 .52514 .52659 Mtetra
.796 .695 .753 r
.52514 .52659 .53181 .53835 .5441 .52572 .53747 .5123 Mtetra
.691 .634 .787 r
.53747 .5123 .5441 .52572 .55643 .51817 .54982 .50574 Mtetra
.644 .627 .818 r
.54982 .50574 .55643 .51817 .56882 .51337 .56225 .50199 Mtetra
.649 .647 .835 r
.56225 .50199 .56882 .51337 .58128 .50957 .57473 .49816 Mtetra
.65 .648 .834 r
.57473 .49816 .58128 .50957 .59382 .50676 .58727 .49423 Mtetra
.58 .596 .833 r
.58727 .49423 .59382 .50676 .60649 .50672 .59992 .49314 Mtetra
.323 .435 .82 r
.59992 .49314 .60649 .50672 .61939 .51179 .61286 .49982 Mtetra
0 .207 .732 r
.61286 .49982 .61939 .51179 .63249 .51918 .62614 .51287 Mtetra
.058 .462 .884 r
.62614 .51287 .63249 .51918 .64547 .51901 .63935 .51844 Mtetra
.831 .983 .877 r
.63935 .51844 .64547 .51901 .65807 .50714 .65205 .50718 Mtetra
.937 .952 .763 r
.65205 .50718 .65807 .50714 .67052 .49193 .66446 .48873 Mtetra
.88 .907 .843 r
.66446 .48873 .67052 .49193 .68315 .48123 .67703 .47523 Mtetra
.752 .822 .907 r
.67703 .47523 .68315 .48123 .69603 .47499 .6899 .46786 Mtetra
.677 .767 .919 r
.6899 .46786 .69603 .47499 .70904 .47054 .70295 .46312 Mtetra
.659 .753 .92 r
.70295 .46312 .70904 .47054 .72214 .46645 .71609 .45897 Mtetra
.656 .752 .92 r
.71609 .45897 .72214 .46645 .7353 .4624 .72929 .45489 Mtetra
.656 .751 .92 r
.72929 .45489 .7353 .4624 .74852 .45834 .74255 .45079 Mtetra
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Mtetra
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43838 Mtetra
.78271 .43838 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Mtetra
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Mtetra
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54475 Mtetra
.655 .751 .92 r
.40961 .54475 .41661 .55152 .42845 .54786 .42149 .54106 Mtetra
.652 .75 .922 r
.42149 .54106 .42845 .54786 .44035 .54427 .43342 .53746 Mtetra
.625 .743 .932 r
.43342 .53746 .44035 .54427 .45229 .54126 .44538 .53459 Mtetra
.459 .682 .962 r
.44538 .53459 .45229 .54126 .46424 .54083 .45734 .53495 Mtetra
0 .228 .694 r
.45734 .53495 .46424 .54083 .47618 .54643 .46926 .54287 Mtetra
.736 .214 0 r
.46926 .54287 .47618 .54643 .48818 .55692 .48124 .55674 Mtetra
.409 0 0 r
.48124 .55674 .48818 .55692 .5004 .56036 .49349 .56111 Mtetra
.928 .949 .783 r
.49349 .56111 .5004 .56036 .51278 .54718 .50598 .54376 Mtetra
.938 .821 .703 r
.50598 .54376 .51278 .54718 .52514 .52659 .51844 .5172 Mtetra
.845 .739 .747 r
.51844 .5172 .52514 .52659 .53747 .5123 .53081 .49957 Mtetra
.706 .65 .792 r
.53081 .49957 .53747 .5123 .54982 .50574 .54318 .49235 Mtetra
.638 .61 .806 r
.54318 .49235 .54982 .50574 .56225 .50199 .55562 .48875 Mtetra
.643 .616 .807 r
.55562 .48875 .56225 .50199 .57473 .49816 .56812 .48488 Mtetra
.648 .618 .806 r
.56812 .48488 .57473 .49816 .58727 .49423 .58066 .48075 Mtetra
.565 .574 .821 r
.58066 .48075 .58727 .49423 .59992 .49314 .59334 .48025 Mtetra
.136 .331 .794 r
.59334 .48025 .59992 .49314 .61286 .49982 .60636 .49023 Mtetra
0 0 .43 r
.60636 .49023 .61286 .49982 .62614 .51287 .61981 .50925 Mtetra
.487 0 0 r
.61981 .50925 .62614 .51287 .63935 .51844 .63319 .51898 Mtetra
.832 .997 .842 r
.63319 .51898 .63935 .51844 .65205 .50718 .64594 .5067 Mtetra
.958 .919 .728 r
.64594 .5067 .65205 .50718 .66446 .48873 .6583 .48474 Mtetra
.899 .877 .806 r
.6583 .48474 .66446 .48873 .67703 .47523 .67084 .46883 Mtetra
.769 .814 .889 r
.67084 .46883 .67703 .47523 .6899 .46786 .68372 .46058 Mtetra
.682 .767 .915 r
.68372 .46058 .6899 .46786 .70295 .46312 .6968 .45563 Mtetra
.659 .753 .92 r
.6968 .45563 .70295 .46312 .71609 .45897 .70998 .45143 Mtetra
.656 .752 .92 r
.70998 .45143 .71609 .45897 .72929 .45489 .72323 .4473 Mtetra
.656 .751 .92 r
.72323 .4473 .72929 .45489 .74255 .45079 .73653 .44317 Mtetra
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Mtetra
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43838 .77683 .43065 Mtetra
.77683 .43065 .78271 .43838 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .42221 Mtetra
.80401 .42221 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Mtetra
.39069 .54162 .39778 .54842 .40961 .54475 .40255 .53792 Mtetra
.655 .751 .92 r
.40255 .53792 .40961 .54475 .42149 .54106 .41447 .53421 Mtetra
.652 .75 .922 r
.41447 .53421 .42149 .54106 .43342 .53746 .42643 .53059 Mtetra
.622 .741 .932 r
.42643 .53059 .43342 .53746 .44538 .53459 .43842 .52777 Mtetra
.434 .667 .96 r
.43842 .52777 .44538 .53459 .45734 .53495 .4504 .52854 Mtetra
0 .14 .626 r
.4504 .52854 .45734 .53495 .46926 .54287 .4623 .53794 Mtetra
.779 .283 0 r
.4623 .53794 .46926 .54287 .48124 .55674 .47424 .55487 Mtetra
.52 0 0 r
.47424 .55487 .48124 .55674 .49349 .56111 .48649 .56226 Mtetra
.932 .952 .775 r
.48649 .56226 .49349 .56111 .50598 .54376 .49908 .54433 Mtetra
.974 .858 .664 r
.49908 .54433 .50598 .54376 .51844 .5172 .51167 .51287 Mtetra
.923 .819 .726 r
.51167 .51287 .51844 .5172 .53081 .49957 .52411 .48967 Mtetra
.773 .719 .802 r
.52411 .48967 .53081 .49957 .54318 .49235 .53651 .47931 Mtetra
.657 .625 .806 r
.53651 .47931 .54318 .49235 .55562 .48875 .54896 .47477 Mtetra
.641 .605 .798 r
.54896 .47477 .55562 .48875 .56812 .48488 .56146 .47087 Mtetra
.628 .599 .801 r
.56146 .47087 .56812 .48488 .58066 .48075 .57404 .46761 Mtetra
.467 .528 .837 r
.57404 .46761 .58066 .48075 .59334 .48025 .58678 .4702 Mtetra
0 .022 .58 r
.58678 .4702 .59334 .48025 .60636 .49023 .59993 .48573 Mtetra
.834 .369 0 r
.59993 .48573 .60636 .49023 .61981 .50925 .61351 .50963 Mtetra
.657 .108 0 r
.61351 .50963 .61981 .50925 .63319 .51898 .62696 .51989 Mtetra
.89 .987 .794 r
.62696 .51989 .63319 .51898 .64594 .5067 .6397 .50448 Mtetra
.959 .872 .707 r
.6397 .50448 .64594 .5067 .6583 .48474 .65203 .47936 Mtetra
.897 .84 .781 r
.65203 .47936 .6583 .48474 .67084 .46883 .66458 .46187 Mtetra
.774 .801 .875 r
.66458 .46187 .67084 .46883 .68372 .46058 .67749 .45314 Mtetra
.685 .764 .912 r
.67749 .45314 .68372 .46058 .6968 .45563 .69061 .44807 Mtetra
.66 .753 .919 r
.69061 .44807 .6968 .45563 .70998 .45143 .70383 .44382 Mtetra
.656 .752 .92 r
.70383 .44382 .70998 .45143 .72323 .4473 .71711 .43966 Mtetra
.656 .751 .92 r
.71711 .43966 .72323 .4473 .73653 .44317 .73046 .43549 Mtetra
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Mtetra
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .42221 .79816 .41434 Mtetra
.79816 .41434 .80401 .42221 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Mtetra
.38355 .53477 .39069 .54162 .40255 .53792 .39544 .53103 Mtetra
.655 .751 .92 r
.39544 .53103 .40255 .53792 .41447 .53421 .40738 .52729 Mtetra
.652 .75 .922 r
.40738 .52729 .41447 .53421 .42643 .53059 .41938 .52365 Mtetra
.62 .741 .933 r
.41938 .52365 .42643 .53059 .43842 .52777 .43141 .52083 Mtetra
.424 .661 .959 r
.43141 .52083 .43842 .52777 .4504 .52854 .4434 .52177 Mtetra
0 .113 .608 r
.4434 .52177 .4504 .52854 .4623 .53794 .4553 .53175 Mtetra
.784 .301 0 r
.4553 .53175 .4623 .53794 .47424 .55487 .46721 .55023 Mtetra
.54 0 0 r
.46721 .55023 .47424 .55487 .48649 .56226 .47944 .56052 Mtetra
.894 .915 .83 r
.47944 .56052 .48649 .56226 .49908 .54433 .49208 .54596 Mtetra
.977 .879 .668 r
.49208 .54596 .49908 .54433 .51167 .51287 .50479 .5159 Mtetra
.97 .927 .684 r
.50479 .5159 .51167 .51287 .52411 .48967 .51735 .49068 Mtetra
.884 .984 .818 r
.51735 .49068 .52411 .48967 .53651 .47931 .52982 .47652 Mtetra
.751 .916 .947 r
.52982 .47652 .53651 .47931 .54896 .47477 .54231 .46924 Mtetra
.648 .804 .958 r
.54231 .46924 .54896 .47477 .56146 .47087 .55486 .46532 Mtetra
.474 .737 .985 r
.55486 .46532 .56146 .47087 .57404 .46761 .56751 .46475 Mtetra
.344 0 0 r
.56751 .46475 .57404 .46761 .58678 .4702 .58037 .47111 Mtetra
.798 .32 .087 r
.58037 .47111 .58678 .4702 .59993 .48573 .59359 .48862 Mtetra
.829 .391 .193 r
.59359 .48862 .59993 .48573 .61351 .50963 .60716 .51107 Mtetra
.558 0 0 r
.60716 .51107 .61351 .50963 .62696 .51989 .62056 .51786 Mtetra
.93 .911 .78 r
.62056 .51786 .62696 .51989 .6397 .50448 .63328 .49945 Mtetra
.94 .821 .699 r
.63328 .49945 .6397 .50448 .65203 .47936 .64565 .47269 Mtetra
.888 .812 .768 r
.64565 .47269 .65203 .47936 .66458 .46187 .65824 .45453 Mtetra
.775 .793 .867 r
.65824 .45453 .66458 .46187 .67749 .45314 .67119 .44558 Mtetra
.686 .763 .91 r
.67119 .44558 .67749 .45314 .69061 .44807 .68435 .44043 Mtetra
.66 .753 .919 r
.68435 .44043 .69061 .44807 .70383 .44382 .69762 .43614 Mtetra
.656 .752 .92 r
.69762 .43614 .70383 .44382 .71711 .43966 .71095 .43194 Mtetra
.656 .751 .92 r
.71095 .43194 .71711 .43966 .73046 .43549 .72434 .42774 Mtetra
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Mtetra
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40207 Mtetra
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Mtetra
.37634 .52786 .38355 .53477 .39544 .53103 .38827 .52409 Mtetra
.655 .751 .92 r
.38827 .52409 .39544 .53103 .40738 .52729 .40025 .52032 Mtetra
.651 .75 .922 r
.40025 .52032 .40738 .52729 .41938 .52365 .41228 .51665 Mtetra
.619 .74 .933 r
.41228 .51665 .41938 .52365 .43141 .52083 .42433 .51384 Mtetra
.416 .657 .959 r
.42433 .51384 .43141 .52083 .4434 .52177 .43635 .51486 Mtetra
0 .101 .598 r
.43635 .51486 .4434 .52177 .4553 .53175 .44825 .52507 Mtetra
.779 .299 0 r
.44825 .52507 .4553 .53175 .46721 .55023 .46014 .54382 Mtetra
0 .059 .543 r
.46014 .54382 .46721 .55023 .47944 .56052 .47237 .55461 Mtetra
.841 .814 .823 r
.47237 .55461 .47944 .56052 .49208 .54596 .48505 .54166 Mtetra
.931 .81 .704 r
.48505 .54166 .49208 .54596 .50479 .5159 .49784 .51486 Mtetra
.945 .89 .746 r
.49784 .51486 .50479 .5159 .51735 .49068 .51049 .49347 Mtetra
.741 .988 .786 r
.51049 .49347 .51735 .49068 .52982 .47652 .52305 .4821 Mtetra
0 0 0 r
.52305 .4821 .52982 .47652 .54231 .46924 .53564 .47606 Mtetra
.163 0 0 r
.53564 .47606 .54231 .46924 .55486 .46532 .54828 .47211 Mtetra
.292 0 0 r
.54828 .47211 .55486 .46532 .56751 .46475 .56101 .47027 Mtetra
.509 .006 0 r
.56101 .47027 .56751 .46475 .58037 .47111 .57389 .47379 Mtetra
.743 .257 .083 r
.57389 .47379 .58037 .47111 .59359 .48862 .58707 .4874 Mtetra
.807 .32 .021 r
.58707 .4874 .59359 .48862 .60716 .51107 .60059 .50649 Mtetra
0 .439 .829 r
.60059 .50649 .60716 .51107 .62056 .51786 .61397 .51159 Mtetra
.895 .818 .764 r
.61397 .51159 .62056 .51786 .63328 .49945 .62675 .49262 Mtetra
.925 .794 .696 r
.62675 .49262 .63328 .49945 .64565 .47269 .63919 .46551 Mtetra
.884 .802 .763 r
.63919 .46551 .64565 .47269 .65824 .45453 .65184 .44706 Mtetra
.777 .791 .865 r
.65184 .44706 .65824 .45453 .67119 .44558 .66484 .43794 Mtetra
.686 .763 .91 r
.66484 .43794 .67119 .44558 .68435 .44043 .67805 .43273 Mtetra
.66 .753 .919 r
.67805 .43273 .68435 .44043 .69762 .43614 .69135 .42839 Mtetra
.656 .752 .92 r
.69135 .42839 .69762 .43614 .71095 .43194 .70472 .42416 Mtetra
.656 .751 .92 r
.70472 .42416 .71095 .43194 .72434 .42774 .71816 .41992 Mtetra
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Mtetra
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40207 .80014 .39403 Mtetra
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Mtetra
.33352 .53219 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Mtetra
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .52089 Mtetra
.36908 .52089 .37634 .52786 .38827 .52409 .38104 .5171 Mtetra
.655 .751 .92 r
.38104 .5171 .38827 .52409 .40025 .52032 .39305 .51329 Mtetra
.651 .75 .922 r
.39305 .51329 .40025 .52032 .41228 .51665 .40511 .5096 Mtetra
.618 .74 .933 r
.40511 .5096 .41228 .51665 .42433 .51384 .4172 .50679 Mtetra
.408 .653 .959 r
.4172 .50679 .42433 .51384 .43635 .51486 .42924 .50791 Mtetra
0 .086 .584 r
.42924 .50791 .43635 .51486 .44825 .52507 .44113 .51832 Mtetra
.779 .3 0 r
.44113 .51832 .44825 .52507 .46014 .54382 .45301 .53714 Mtetra
0 .092 .582 r
.45301 .53714 .46014 .54382 .47237 .55461 .46526 .54758 Mtetra
.835 .789 .808 r
.46526 .54758 .47237 .55461 .48505 .54166 .478 .53415 Mtetra
.904 .767 .7 r
.478 .53415 .48505 .54166 .49784 .51486 .49087 .50731 Mtetra
.883 .774 .737 r
.49087 .50731 .49784 .51486 .51049 .49347 .50359 .48644 Mtetra
.803 .791 .841 r
.50359 .48644 .51049 .49347 .52305 .4821 .51621 .47586 Mtetra
.7 .798 .925 r
.51621 .47586 .52305 .4821 .53564 .47606 .52884 .47043 Mtetra
.646 .804 .959 r
.52884 .47043 .53564 .47606 .54828 .47211 .54153 .46645 Mtetra
.58 .782 .975 r
.54153 .46645 .54828 .47211 .56101 .47027 .55429 .46394 Mtetra
.269 .605 .954 r
.55429 .46394 .56101 .47027 .57389 .47379 .56718 .46658 Mtetra
0 .029 .541 r
.56718 .46658 .57389 .47379 .58707 .4874 .58037 .47961 Mtetra
.664 .191 0 r
.58037 .47961 .58707 .4874 .60059 .50649 .59387 .49868 Mtetra
.141 .479 .898 r
.59387 .49868 .60059 .50649 .61397 .51159 .60729 .50419 Mtetra
.881 .797 .762 r
.60729 .50419 .61397 .51159 .62675 .49262 .62015 .4855 Mtetra
.924 .791 .696 r
.62015 .4855 .62675 .49262 .63919 .46551 .63268 .45826 Mtetra
.886 .802 .761 r
.63268 .45826 .63919 .46551 .65184 .44706 .64539 .43953 Mtetra
.779 .792 .863 r
.64539 .43953 .65184 .44706 .66484 .43794 .65844 .43025 Mtetra
.687 .764 .91 r
.65844 .43025 .66484 .43794 .67805 .43273 .67169 .42496 Mtetra
.66 .753 .919 r
.67169 .42496 .67805 .43273 .69135 .42839 .68503 .42058 Mtetra
.656 .752 .92 r
.68503 .42058 .69135 .42839 .70472 .42416 .69845 .41631 Mtetra
.656 .751 .92 r
.69845 .41631 .70472 .42416 .71816 .41992 .71193 .41203 Mtetra
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Mtetra
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52525 Mtetra
.32609 .52525 .33352 .53219 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Mtetra
.34981 .51768 .35717 .52467 .36908 .52089 .36175 .51387 Mtetra
.36175 .51387 .36908 .52089 .38104 .5171 .37374 .51004 Mtetra
.655 .751 .92 r
.37374 .51004 .38104 .5171 .39305 .51329 .38579 .50621 Mtetra
.651 .75 .922 r
.38579 .50621 .39305 .51329 .40511 .5096 .39789 .50248 Mtetra
.616 .739 .934 r
.39789 .50248 .40511 .5096 .4172 .50679 .41 .49969 Mtetra
.399 .649 .958 r
.41 .49969 .4172 .50679 .42924 .50791 .42206 .50091 Mtetra
0 .072 .569 r
.42206 .50091 .42924 .50791 .44113 .51832 .43395 .51153 Mtetra
.781 .302 0 r
.43395 .51153 .44113 .51832 .45301 .53714 .44582 .53041 Mtetra
0 .116 .605 r
.44582 .53041 .45301 .53714 .46526 .54758 .45808 .54048 Mtetra
.839 .788 .803 r
.45808 .54048 .46526 .54758 .478 .53415 .47089 .5266 Mtetra
.904 .767 .7 r
.47089 .5266 .478 .53415 .49087 .50731 .48385 .4997 Mtetra
.882 .774 .739 r
.48385 .4997 .49087 .50731 .50359 .48644 .49663 .47901 Mtetra
.798 .782 .838 r
.49663 .47901 .50359 .48644 .51621 .47586 .5093 .46848 Mtetra
.699 .765 .903 r
.5093 .46848 .51621 .47586 .52884 .47043 .52198 .46297 Mtetra
.654 .751 .921 r
.52198 .46297 .52884 .47043 .54153 .46645 .5347 .45896 Mtetra
.599 .731 .937 r
.5347 .45896 .54153 .46645 .55429 .46394 .5475 .45645 Mtetra
.329 .602 .946 r
.5475 .45645 .55429 .46394 .56718 .46658 .56042 .45898 Mtetra
0 .055 .574 r
.56042 .45898 .56718 .46658 .58037 .47961 .57361 .47175 Mtetra
.663 .19 0 r
.57361 .47175 .58037 .47961 .59387 .49868 .58711 .4908 Mtetra
.11 .459 .887 r
.58711 .4908 .59387 .49868 .60729 .50419 .60055 .49671 Mtetra
.879 .797 .765 r
.60055 .49671 .60729 .50419 .62015 .4855 .61349 .47833 Mtetra
.924 .791 .695 r
.61349 .47833 .62015 .4855 .63268 .45826 .62611 .45096 Mtetra
.887 .802 .759 r
.62611 .45096 .63268 .45826 .64539 .43953 .63888 .43195 Mtetra
.781 .792 .862 r
.63888 .43195 .64539 .43953 .65844 .43025 .65198 .42249 Mtetra
.688 .764 .909 r
.65198 .42249 .65844 .43025 .67169 .42496 .66527 .41713 Mtetra
.66 .753 .919 r
.66527 .41713 .67169 .42496 .68503 .42058 .67866 .4127 Mtetra
.656 .752 .92 r
.67866 .4127 .68503 .42058 .69845 .41631 .69212 .40839 Mtetra
.656 .751 .92 r
.69212 .40839 .69845 .41631 .71193 .41203 .70564 .40407 Mtetra
.70564 .40407 .71193 .41203 .72548 .40773 .71923 .39974 Mtetra
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Mtetra
.35437 .50679 .36175 .51387 .37374 .51004 .36639 .50293 Mtetra
.655 .751 .92 r
.36639 .50293 .37374 .51004 .38579 .50621 .37847 .49906 Mtetra
.651 .75 .922 r
.37847 .49906 .38579 .50621 .39789 .50248 .3906 .49531 Mtetra
.615 .739 .934 r
.3906 .49531 .39789 .50248 .41 .49969 .40275 .49253 Mtetra
.389 .644 .958 r
.40275 .49253 .41 .49969 .42206 .50091 .41483 .49387 Mtetra
0 .056 .553 r
.41483 .49387 .42206 .50091 .43395 .51153 .42671 .50472 Mtetra
.782 .303 0 r
.42671 .50472 .43395 .51153 .44582 .53041 .43856 .52365 Mtetra
0 .143 .63 r
.43856 .52365 .44582 .53041 .45808 .54048 .45084 .5333 Mtetra
.843 .788 .798 r
.45084 .5333 .45808 .54048 .47089 .5266 .46372 .5189 Mtetra
.903 .766 .699 r
.46372 .5189 .47089 .5266 .48385 .4997 .47676 .49189 Mtetra
.879 .772 .74 r
.47676 .49189 .48385 .4997 .49663 .47901 .48962 .47135 Mtetra
.795 .778 .838 r
.48962 .47135 .49663 .47901 .5093 .46848 .50234 .46093 Mtetra
.698 .762 .902 r
.50234 .46093 .5093 .46848 .52198 .46297 .51505 .45544 Mtetra
.654 .75 .921 r
.51505 .45544 .52198 .46297 .5347 .45896 .52782 .45139 Mtetra
.602 .732 .936 r
.52782 .45139 .5347 .45896 .5475 .45645 .54065 .4488 Mtetra
.344 .607 .946 r
.54065 .4488 .5475 .45645 .56042 .45898 .55359 .45114 Mtetra
0 .073 .594 r
.55359 .45114 .56042 .45898 .57361 .47175 .56678 .46369 Mtetra
.658 .187 0 r
.56678 .46369 .57361 .47175 .58711 .4908 .58028 .48279 Mtetra
.08 .436 .875 r
.58028 .48279 .58711 .4908 .60055 .49671 .59376 .48915 Mtetra
.876 .797 .769 r
.59376 .48915 .60055 .49671 .61349 .47833 .60678 .47112 Mtetra
.924 .791 .695 r
.60678 .47112 .61349 .47833 .62611 .45096 .61948 .44363 Mtetra
.889 .802 .757 r
.61948 .44363 .62611 .45096 .63888 .43195 .63232 .42432 Mtetra
.784 .793 .86 r
.63232 .42432 .63888 .43195 .65198 .42249 .64546 .41466 Mtetra
.69 .765 .909 r
.64546 .41466 .65198 .42249 .66527 .41713 .65879 .40922 Mtetra
.66 .753 .919 r
.65879 .40922 .66527 .41713 .67866 .4127 .67223 .40475 Mtetra
.656 .752 .92 r
.67223 .40475 .67866 .4127 .69212 .40839 .68573 .40041 Mtetra
.656 .751 .92 r
.68573 .40041 .69212 .40839 .70564 .40407 .6993 .39605 Mtetra
.6993 .39605 .70564 .40407 .71923 .39974 .71294 .39167 Mtetra
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Mtetra
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Mtetra
.34692 .49965 .35437 .50679 .36639 .50293 .35898 .49575 Mtetra
.655 .751 .92 r
.35898 .49575 .36639 .50293 .37847 .49906 .37109 .49186 Mtetra
.65 .75 .922 r
.37109 .49186 .37847 .49906 .3906 .49531 .38325 .48808 Mtetra
.613 .738 .935 r
.38325 .48808 .3906 .49531 .40275 .49253 .39543 .48531 Mtetra
.378 .638 .957 r
.39543 .48531 .40275 .49253 .41483 .49387 .40753 .48678 Mtetra
0 .039 .536 r
.40753 .48678 .41483 .49387 .42671 .50472 .41941 .49787 Mtetra
.783 .305 0 r
.41941 .49787 .42671 .50472 .43856 .52365 .43124 .51685 Mtetra
0 .174 .658 r
.43124 .51685 .43856 .52365 .45084 .5333 .44354 .52604 Mtetra
.847 .787 .793 r
.44354 .52604 .45084 .5333 .46372 .5189 .45649 .51104 Mtetra
.903 .764 .699 r
.45649 .51104 .46372 .5189 .47676 .49189 .46962 .48385 Mtetra
.876 .77 .741 r
.46962 .48385 .47676 .49189 .48962 .47135 .48255 .46348 Mtetra
.79 .774 .839 r
.48255 .46348 .48962 .47135 .50234 .46093 .49532 .45327 Mtetra
.694 .759 .902 r
.49532 .45327 .50234 .46093 .51505 .45544 .50807 .44788 Mtetra
.654 .751 .921 r
.50807 .44788 .51505 .45544 .52782 .45139 .52087 .4438 Mtetra
.607 .735 .935 r
.52087 .4438 .52782 .45139 .54065 .4488 .53374 .44102 Mtetra
.362 .615 .947 r
.53374 .44102 .54065 .4488 .55359 .45114 .54671 .44309 Mtetra
0 .091 .614 r
.54671 .44309 .55359 .45114 .56678 .46369 .5599 .4554 Mtetra
.654 .186 0 r
.5599 .4554 .56678 .46369 .58028 .48279 .57339 .4746 Mtetra
.045 .409 .86 r
.57339 .4746 .58028 .48279 .59376 .48915 .5869 .4815 Mtetra
.872 .797 .773 r
.5869 .4815 .59376 .48915 .60678 .47112 .6 .46387 Mtetra
.924 .791 .695 r
.6 .46387 .60678 .47112 .61948 .44363 .61279 .43626 Mtetra
.891 .802 .755 r
.61279 .43626 .61948 .44363 .63232 .42432 .6257 .41663 Mtetra
.787 .794 .859 r
.6257 .41663 .63232 .42432 .64546 .41466 .63888 .40678 Mtetra
.691 .765 .909 r
.63888 .40678 .64546 .41466 .65879 .40922 .65226 .40125 Mtetra
.661 .753 .919 r
.65226 .40125 .65879 .40922 .67223 .40475 .66574 .39673 Mtetra
.656 .752 .92 r
.66574 .39673 .67223 .40475 .68573 .40041 .67929 .39235 Mtetra
.656 .751 .92 r
.67929 .39235 .68573 .40041 .6993 .39605 .69291 .38795 Mtetra
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Mtetra
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Mtetra
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Mtetra
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Mtetra
.33941 .49245 .34692 .49965 .35898 .49575 .3515 .48852 Mtetra
.655 .751 .92 r
.3515 .48852 .35898 .49575 .37109 .49186 .36365 .48459 Mtetra
.65 .75 .922 r
.36365 .48459 .37109 .49186 .38325 .48808 .37585 .48079 Mtetra
.611 .738 .936 r
.37585 .48079 .38325 .48808 .39543 .48531 .38806 .47804 Mtetra
.366 .632 .956 r
.38806 .47804 .39543 .48531 .40753 .48678 .40016 .47965 Mtetra
0 .023 .518 r
.40016 .47965 .40753 .48678 .41941 .49787 .41204 .49099 Mtetra
.784 .306 0 r
.41204 .49099 .41941 .49787 .43124 .51685 .42385 .51 Mtetra
0 .208 .688 r
.42385 .51 .43124 .51685 .44354 .52604 .43617 .5187 Mtetra
.851 .786 .788 r
.43617 .5187 .44354 .52604 .45649 .51104 .4492 .50314 Mtetra
.903 .765 .698 r
.4492 .50314 .45649 .51104 .46962 .48385 .46242 .47577 Mtetra
.877 .77 .74 r
.46242 .47577 .46962 .48385 .48255 .46348 .47542 .45519 Mtetra
.794 .766 .828 r
.47542 .45519 .48255 .46348 .49532 .45327 .48825 .44442 Mtetra
.702 .734 .875 r
.48825 .44442 .49532 .45327 .50807 .44788 .50104 .43847 Mtetra
.653 .705 .885 r
.50104 .43847 .50807 .44788 .52087 .4438 .51388 .43434 Mtetra
.596 .682 .901 r
.51388 .43434 .52087 .4438 .53374 .44102 .52677 .43205 Mtetra
.368 .584 .926 r
.52677 .43205 .53374 .44102 .54671 .44309 .53977 .43462 Mtetra
0 .096 .624 r
.53977 .43462 .54671 .44309 .5599 .4554 .55296 .44706 Mtetra
.658 .19 0 r
.55296 .44706 .5599 .4554 .57339 .4746 .56644 .46638 Mtetra
.004 .381 .843 r
.56644 .46638 .57339 .4746 .5869 .4815 .57998 .47377 Mtetra
.868 .797 .778 r
.57998 .47377 .5869 .4815 .6 .46387 .59316 .45657 Mtetra
.925 .792 .695 r
.59316 .45657 .6 .46387 .61279 .43626 .60604 .42885 Mtetra
.893 .803 .753 r
.60604 .42885 .61279 .43626 .6257 .41663 .61901 .4089 Mtetra
.79 .795 .857 r
.61901 .4089 .6257 .41663 .63888 .40678 .63225 .39883 Mtetra
.692 .766 .908 r
.63225 .39883 .63888 .40678 .65226 .40125 .64568 .3932 Mtetra
.661 .754 .919 r
.64568 .3932 .65226 .40125 .66574 .39673 .6592 .38864 Mtetra
.656 .752 .92 r
.6592 .38864 .66574 .39673 .67929 .39235 .67279 .38422 Mtetra
.656 .751 .92 r
.67279 .38422 .67929 .39235 .69291 .38795 .68645 .37978 Mtetra
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Mtetra
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Mtetra
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48518 Mtetra
.33184 .48518 .33941 .49245 .3515 .48852 .34396 .48123 Mtetra
.655 .751 .92 r
.34396 .48123 .3515 .48852 .36365 .48459 .35614 .47726 Mtetra
.65 .75 .923 r
.35614 .47726 .36365 .48459 .37585 .48079 .36837 .47344 Mtetra
.609 .737 .936 r
.36837 .47344 .37585 .48079 .38806 .47804 .38061 .47071 Mtetra
.354 .626 .955 r
.38061 .47071 .38806 .47804 .40016 .47965 .39274 .47247 Mtetra
.497 0 0 r
.39274 .47247 .40016 .47965 .41204 .49099 .40461 .48404 Mtetra
.779 .298 0 r
.40461 .48404 .41204 .49099 .42385 .51 .41641 .50282 Mtetra
0 .319 .786 r
.41641 .50282 .42385 .51 .43617 .5187 .42878 .51008 Mtetra
.858 .762 .756 r
.42878 .51008 .43617 .5187 .4492 .50314 .44194 .49175 Mtetra
.886 .724 .676 r
.44194 .49175 .4492 .50314 .46242 .47577 .45531 .46093 Mtetra
.836 .684 .694 r
.45531 .46093 .46242 .47577 .47542 .45519 .46841 .43708 Mtetra
.739 .618 .724 r
.46841 .43708 .47542 .45519 .48825 .44442 .48127 .42407 Mtetra
.66 .56 .731 r
.48127 .42407 .48825 .44442 .50104 .43847 .49407 .41712 Mtetra
.619 .53 .732 r
.49407 .41712 .50104 .43847 .51388 .43434 .50689 .41296 Mtetra
.574 .504 .738 r
.50689 .41296 .51388 .43434 .52677 .43205 .51977 .41157 Mtetra
.445 .433 .752 r
.51977 .41157 .52677 .43205 .53977 .43462 .53274 .41629 Mtetra
.022 .182 .691 r
.53274 .41629 .53977 .43462 .55296 .44706 .54592 .43191 Mtetra
0 0 .48 r
.54592 .43191 .55296 .44706 .56644 .46638 .5594 .45462 Mtetra
.026 .303 .794 r
.5594 .45462 .56644 .46638 .57998 .47377 .57297 .46473 Mtetra
.844 .772 .782 r
.57297 .46473 .57998 .47377 .59316 .45657 .58625 .44891 Mtetra
.921 .788 .696 r
.58625 .44891 .59316 .45657 .60604 .42885 .59923 .42136 Mtetra
.894 .802 .751 r
.59923 .42136 .60604 .42885 .61901 .4089 .61227 .4011 Mtetra
.793 .796 .855 r
.61227 .4011 .61901 .4089 .63225 .39883 .62556 .39081 Mtetra
.694 .766 .908 r
.62556 .39081 .63225 .39883 .64568 .3932 .63903 .38509 Mtetra
.661 .754 .919 r
.63903 .38509 .64568 .3932 .6592 .38864 .65259 .38048 Mtetra
.656 .752 .92 r
.65259 .38048 .6592 .38864 .67279 .38422 .66623 .37601 Mtetra
.656 .751 .92 r
.66623 .37601 .67279 .38422 .68645 .37978 .67994 .37154 Mtetra
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Mtetra
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34884 Mtetra
.74947 .34884 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48184 Mtetra
.31209 .48184 .31977 .48912 .33184 .48518 .3242 .47786 Mtetra
.3242 .47786 .33184 .48518 .34396 .48123 .33636 .47387 Mtetra
.655 .751 .92 r
.33636 .47387 .34396 .48123 .35614 .47726 .34858 .46987 Mtetra
.65 .75 .923 r
.34858 .46987 .35614 .47726 .36837 .47344 .36084 .46603 Mtetra
.607 .736 .937 r
.36084 .46603 .36837 .47344 .38061 .47071 .37311 .46331 Mtetra
.348 .623 .954 r
.37311 .46331 .38061 .47071 .39274 .47247 .38525 .46513 Mtetra
0 .029 .526 r
.38525 .46513 .39274 .47247 .40461 .48404 .39713 .47642 Mtetra
.717 .23 0 r
.39713 .47642 .40461 .48404 .41641 .50282 .40898 .49344 Mtetra
.323 .553 .917 r
.40898 .49344 .41641 .50282 .42878 .51008 .42147 .49666 Mtetra
.839 .698 .707 r
.42147 .49666 .42878 .51008 .44194 .49175 .43479 .4741 Mtetra
.847 .669 .661 r
.43479 .4741 .44194 .49175 .45531 .46093 .44825 .44232 Mtetra
.795 .642 .692 r
.44825 .44232 .45531 .46093 .46841 .43708 .46133 .42134 Mtetra
.709 .626 .762 r
.46133 .42134 .46841 .43708 .48127 .42407 .47416 .41243 Mtetra
.651 .659 .844 r
.47416 .41243 .48127 .42407 .49407 .41712 .48695 .40813 Mtetra
.655 .718 .895 r
.48695 .40813 .49407 .41712 .50689 .41296 .49981 .40392 Mtetra
.652 .716 .896 r
.49981 .40392 .50689 .41296 .51977 .41157 .51272 .3998 Mtetra
.506 .59 .873 r
.51272 .3998 .51977 .41157 .53274 .41629 .5257 .40032 Mtetra
.06 .242 .737 r
.5257 .40032 .53274 .41629 .54592 .43191 .53883 .41299 Mtetra
0 0 .538 r
.53883 .41299 .54592 .43191 .5594 .45462 .55226 .43655 Mtetra
.074 .226 .717 r
.55226 .43655 .5594 .45462 .57297 .46473 .56586 .45083 Mtetra
.758 .677 .772 r
.56586 .45083 .57297 .46473 .58625 .44891 .57924 .43902 Mtetra
.896 .76 .703 r
.57924 .43902 .58625 .44891 .59923 .42136 .59234 .41318 Mtetra
.886 .791 .75 r
.59234 .41318 .59923 .42136 .61227 .4011 .60547 .39313 Mtetra
.793 .793 .853 r
.60547 .39313 .61227 .4011 .62556 .39081 .61881 .38271 Mtetra
.695 .767 .907 r
.61881 .38271 .62556 .39081 .63903 .38509 .63232 .3769 Mtetra
.662 .754 .919 r
.63232 .3769 .63903 .38509 .65259 .38048 .64593 .37224 Mtetra
.656 .752 .92 r
.64593 .37224 .65259 .38048 .66623 .37601 .65962 .36774 Mtetra
.656 .751 .92 r
.65962 .36774 .66623 .37601 .67994 .37154 .67337 .36322 Mtetra
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Mtetra
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34884 .74314 .34031 Mtetra
.74314 .34031 .74947 .34884 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48184 .30436 .47448 Mtetra
.30436 .47448 .31209 .48184 .3242 .47786 .3165 .47047 Mtetra
.3165 .47047 .3242 .47786 .33636 .47387 .32869 .46645 Mtetra
.655 .751 .92 r
.32869 .46645 .33636 .47387 .34858 .46987 .34094 .46242 Mtetra
.649 .75 .923 r
.34094 .46242 .34858 .46987 .36084 .46603 .35324 .45854 Mtetra
.608 .736 .936 r
.35324 .45854 .36084 .46603 .37311 .46331 .36554 .45576 Mtetra
.374 .633 .955 r
.36554 .45576 .37311 .46331 .38525 .46513 .37772 .45725 Mtetra
0 .143 .648 r
.37772 .45725 .38525 .46513 .39713 .47642 .38965 .46708 Mtetra
0 0 .515 r
.38965 .46708 .39713 .47642 .40898 .49344 .40161 .48063 Mtetra
.542 .589 .851 r
.40161 .48063 .40898 .49344 .42147 .49666 .41423 .48024 Mtetra
.814 .666 .699 r
.41423 .48024 .42147 .49666 .43479 .4741 .42757 .45838 Mtetra
.84 .68 .683 r
.42757 .45838 .43479 .4741 .44825 .44232 .44096 .4321 Mtetra
.823 .737 .769 r
.44096 .4321 .44825 .44232 .46133 .42134 .45398 .41682 Mtetra
.712 .864 .954 r
.45398 .41682 .46133 .42134 .47416 .41243 .46682 .41071 Mtetra
.504 .881 .972 r
.46682 .41071 .47416 .41243 .48695 .40813 .47967 .40704 Mtetra
.508 .896 .953 r
.47967 .40704 .48695 .40813 .49981 .40392 .49259 .4028 Mtetra
.549 .913 .956 r
.49259 .4028 .49981 .40392 .51272 .3998 .50557 .398 Mtetra
.391 .826 .955 r
.50557 .398 .51272 .3998 .5257 .40032 .51861 .39564 Mtetra
0 .29 .703 r
.51861 .39564 .5257 .40032 .53883 .41299 .53175 .4025 Mtetra
0 0 .468 r
.53175 .4025 .53883 .41299 .55226 .43655 .54511 .42043 Mtetra
.032 .226 .729 r
.54511 .42043 .55226 .43655 .56586 .45083 .55867 .4339 Mtetra
.693 .614 .764 r
.55867 .4339 .56586 .45083 .57924 .43902 .57213 .42563 Mtetra
.849 .713 .712 r
.57213 .42563 .57924 .43902 .59234 .41318 .58536 .40323 Mtetra
.859 .761 .753 r
.58536 .40323 .59234 .41318 .60547 .39313 .59859 .3846 Mtetra
.783 .78 .85 r
.59859 .3846 .60547 .39313 .61881 .38271 .61199 .37445 Mtetra
.694 .764 .906 r
.61199 .37445 .61881 .38271 .63232 .3769 .62555 .36863 Mtetra
.662 .754 .918 r
.62555 .36863 .63232 .3769 .64593 .37224 .63921 .36393 Mtetra
.656 .752 .92 r
.63921 .36393 .64593 .37224 .65962 .36774 .65294 .35938 Mtetra
.656 .751 .92 r
.65294 .35938 .65962 .36774 .67337 .36322 .66673 .35483 Mtetra
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Mtetra
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Mtetra
.29656 .46707 .30436 .47448 .3165 .47047 .30873 .46303 Mtetra
.30873 .46303 .3165 .47047 .32869 .46645 .32096 .45897 Mtetra
.655 .751 .92 r
.32096 .45897 .32869 .46645 .34094 .46242 .33324 .4549 Mtetra
.65 .75 .922 r
.33324 .4549 .34094 .46242 .35324 .45854 .34558 .45096 Mtetra
.616 .738 .933 r
.34558 .45096 .35324 .45854 .36554 .45576 .35792 .44796 Mtetra
.44 .66 .954 r
.35792 .44796 .36554 .45576 .37772 .45725 .37016 .4485 Mtetra
0 .336 .815 r
.37016 .4485 .37772 .45725 .38965 .46708 .3822 .45579 Mtetra
0 .231 .75 r
.3822 .45579 .38965 .46708 .40161 .48063 .39428 .46586 Mtetra
.561 .568 .818 r
.39428 .46586 .40161 .48063 .41423 .48024 .40692 .46492 Mtetra
.794 .668 .725 r
.40692 .46492 .41423 .48024 .42757 .45838 .42016 .44769 Mtetra
.853 .734 .731 r
.42016 .44769 .42757 .45838 .44096 .4321 .43346 .42721 Mtetra
.846 .855 .85 r
.43346 .42721 .44096 .4321 .45398 .41682 .44649 .41476 Mtetra
.655 .927 .973 r
.44649 .41476 .45398 .41682 .46682 .41071 .45939 .409 Mtetra
.518 .888 .972 r
.45939 .409 .46682 .41071 .47967 .40704 .4723 .40509 Mtetra
.552 .897 .979 r
.4723 .40509 .47967 .40704 .49259 .4028 .48529 .40085 Mtetra
.573 .906 .978 r
.48529 .40085 .49259 .4028 .50557 .398 .49833 .39626 Mtetra
.416 .841 .957 r
.49833 .39626 .50557 .398 .51861 .39564 .51143 .39353 Mtetra
.208 0 0 r
.51143 .39353 .51861 .39564 .53175 .4025 .52461 .3975 Mtetra
.553 .009 0 r
.52461 .3975 .53175 .4025 .54511 .42043 .53795 .40952 Mtetra
.054 .347 .823 r
.53795 .40952 .54511 .42043 .55867 .4339 .55147 .41815 Mtetra
.694 .628 .778 r
.55147 .41815 .55867 .4339 .57213 .42563 .56495 .41024 Mtetra
.812 .682 .721 r
.56495 .41024 .57213 .42563 .58536 .40323 .57829 .39126 Mtetra
.82 .725 .76 r
.57829 .39126 .58536 .40323 .59859 .3846 .59163 .37517 Mtetra
.761 .756 .849 r
.59163 .37517 .59859 .3846 .61199 .37445 .60511 .36592 Mtetra
.688 .757 .904 r
.60511 .36592 .61199 .37445 .62555 .36863 .61872 .36026 Mtetra
.661 .753 .918 r
.61872 .36026 .62555 .36863 .63921 .36393 .63243 .35554 Mtetra
.656 .752 .92 r
.63243 .35554 .63921 .36393 .65294 .35938 .6462 .35095 Mtetra
.656 .751 .92 r
.6462 .35095 .65294 .35938 .66673 .35483 .66004 .34636 Mtetra
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Mtetra
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45551 Mtetra
.3009 .45551 .30873 .46303 .32096 .45897 .31316 .45142 Mtetra
.655 .751 .92 r
.31316 .45142 .32096 .45897 .33324 .4549 .32548 .44731 Mtetra
.652 .75 .922 r
.32548 .44731 .33324 .4549 .34558 .45096 .33785 .44329 Mtetra
.629 .742 .929 r
.33785 .44329 .34558 .45096 .35792 .44796 .35025 .43991 Mtetra
.522 .691 .945 r
.35025 .43991 .35792 .44796 .37016 .4485 .36258 .43904 Mtetra
.239 .505 .904 r
.36258 .43904 .37016 .4485 .3822 .45579 .37476 .44327 Mtetra
.156 .376 .827 r
.37476 .44327 .3822 .45579 .39428 .46586 .38693 .45058 Mtetra
.51 .535 .817 r
.38693 .45058 .39428 .46586 .40692 .46492 .3995 .45141 Mtetra
.752 .673 .774 r
.3995 .45141 .40692 .46492 .42016 .44769 .41258 .44031 Mtetra
.853 .792 .791 r
.41258 .44031 .42016 .44769 .43346 .42721 .42581 .4247 Mtetra
.846 .924 .883 r
.42581 .4247 .43346 .42721 .44649 .41476 .4389 .41312 Mtetra
.701 .947 .957 r
.4389 .41312 .44649 .41476 .45939 .409 .45189 .40614 Mtetra
.628 .9 .986 r
.45189 .40614 .45939 .409 .4723 .40509 .46488 .40121 Mtetra
.615 .866 .99 r
.46488 .40121 .4723 .40509 .48529 .40085 .47792 .39697 Mtetra
.575 .854 .996 r
.47792 .39697 .48529 .40085 .49833 .39626 .49101 .39341 Mtetra
.381 .797 .977 r
.49101 .39341 .49833 .39626 .51143 .39353 .50416 .39187 Mtetra
.164 0 0 r
.50416 .39187 .51143 .39353 .52461 .3975 .51739 .39496 Mtetra
.411 0 0 r
.51739 .39496 .52461 .3975 .53795 .40952 .53075 .40203 Mtetra
.317 .615 .955 r
.53075 .40203 .53795 .40952 .55147 .41815 .54425 .40426 Mtetra
.736 .671 .787 r
.54425 .40426 .55147 .41815 .56495 .41024 .55774 .39427 Mtetra
.787 .668 .732 r
.55774 .39427 .56495 .41024 .57829 .39126 .57116 .37797 Mtetra
.778 .695 .772 r
.57116 .37797 .57829 .39126 .59163 .37517 .5846 .36497 Mtetra
.729 .732 .853 r
.5846 .36497 .59163 .37517 .60511 .36592 .59816 .35712 Mtetra
.678 .748 .904 r
.59816 .35712 .60511 .36592 .61872 .36026 .61183 .35178 Mtetra
.659 .751 .918 r
.61183 .35178 .61872 .36026 .63243 .35554 .62558 .34708 Mtetra
.656 .751 .92 r
.62558 .34708 .63243 .35554 .6462 .35095 .6394 .34245 Mtetra
.6394 .34245 .6462 .35095 .66004 .34636 .65329 .33781 Mtetra
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.28076 .45205 .28869 .45959 .3009 .45551 .293 .44794 Mtetra
.293 .44794 .3009 .45551 .31316 .45142 .30529 .44381 Mtetra
.30529 .44381 .31316 .45142 .32548 .44731 .31765 .43966 Mtetra
.654 .751 .921 r
.31765 .43966 .32548 .44731 .33785 .44329 .33006 .43554 Mtetra
.642 .746 .924 r
.33006 .43554 .33785 .44329 .35025 .43991 .34251 .43175 Mtetra
.589 .717 .932 r
.34251 .43175 .35025 .43991 .36258 .43904 .35494 .42939 Mtetra
.443 .612 .921 r
.35494 .42939 .36258 .43904 .37476 .44327 .36728 .43047 Mtetra
.319 .471 .855 r
.36728 .43047 .37476 .44327 .38693 .45058 .37956 .43512 Mtetra
.44 .494 .818 r
.37956 .43512 .38693 .45058 .3995 .45141 .39204 .43802 Mtetra
.658 .638 .818 r
.39204 .43802 .3995 .45141 .41258 .44031 .40493 .43298 Mtetra
.809 .797 .841 r
.40493 .43298 .41258 .44031 .42581 .4247 .41808 .42167 Mtetra
.833 .913 .891 r
.41808 .42167 .42581 .4247 .4389 .41312 .43123 .41065 Mtetra
.742 .933 .951 r
.43123 .41065 .4389 .41312 .45189 .40614 .4443 .403 Mtetra
.649 .898 .983 r
.4443 .403 .45189 .40614 .46488 .40121 .45736 .39776 Mtetra
.596 .875 .993 r
.45736 .39776 .46488 .40121 .47792 .39697 .47046 .3936 Mtetra
.523 .851 .997 r
.47046 .3936 .47792 .39697 .49101 .39341 .4836 .39053 Mtetra
.298 .751 .957 r
.4836 .39053 .49101 .39341 .50416 .39187 .4968 .38988 Mtetra
0 .48 .74 r
.4968 .38988 .50416 .39187 .51739 .39496 .51008 .39257 Mtetra
0 .52 .79 r
.51008 .39257 .51739 .39496 .53075 .40203 .52348 .39504 Mtetra
.657 .789 .945 r
.52348 .39504 .53075 .40203 .54425 .40426 .53698 .39041 Mtetra
.768 .684 .771 r
.53698 .39041 .54425 .40426 .55774 .39427 .55049 .37788 Mtetra
.759 .653 .744 r
.55049 .37788 .55774 .39427 .57116 .37797 .56398 .36428 Mtetra
.734 .674 .792 r
.56398 .36428 .57116 .37797 .5846 .36497 .57752 .35455 Mtetra
.696 .718 .866 r
.57752 .35455 .5846 .36497 .59816 .35712 .59115 .34821 Mtetra
.667 .743 .907 r
.59115 .34821 .59816 .35712 .61183 .35178 .60488 .34322 Mtetra
.657 .75 .918 r
.60488 .34322 .61183 .35178 .62558 .34708 .61867 .33853 Mtetra
.656 .751 .92 r
.61867 .33853 .62558 .34708 .6394 .34245 .63254 .33387 Mtetra
.63254 .33387 .6394 .34245 .65329 .33781 .64648 .32918 Mtetra
.64648 .32918 .65329 .33781 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Mtetra
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Mtetra
.29736 .43613 .30529 .44381 .31765 .43966 .30975 .43194 Mtetra
.655 .751 .92 r
.30975 .43194 .31765 .43966 .33006 .43554 .3222 .42775 Mtetra
.651 .749 .921 r
.3222 .42775 .33006 .43554 .34251 .43175 .33469 .42366 Mtetra
.631 .736 .923 r
.33469 .42366 .34251 .43175 .35494 .42939 .34722 .42015 Mtetra
.568 .682 .917 r
.34722 .42015 .35494 .42939 .36728 .43047 .35972 .41841 Mtetra
.468 .57 .875 r
.35972 .41841 .36728 .43047 .37956 .43512 .37216 .41962 Mtetra
.435 .491 .819 r
.37216 .41962 .37956 .43512 .39204 .43802 .38463 .42258 Mtetra
.515 .538 .817 r
.38463 .42258 .39204 .43802 .40493 .43298 .39731 .42314 Mtetra
.663 .709 .881 r
.39731 .42314 .40493 .43298 .41808 .42167 .41027 .41842 Mtetra
.77 .913 .936 r
.41027 .41842 .41808 .42167 .43123 .41065 .42341 .41006 Mtetra
.732 .973 .928 r
.42341 .41006 .43123 .41065 .4443 .403 .43658 .40164 Mtetra
.657 .945 .959 r
.43658 .40164 .4443 .403 .45736 .39776 .44973 .39521 Mtetra
.551 .885 .988 r
.44973 .39521 .45736 .39776 .47046 .3936 .46289 .39123 Mtetra
.333 .783 .954 r
.46289 .39123 .47046 .3936 .4836 .39053 .47607 .38981 Mtetra
0 .561 .734 r
.47607 .38981 .4836 .39053 .4968 .38988 .48931 .39058 Mtetra
.055 0 0 r
.48931 .39058 .4968 .38988 .51008 .39257 .50267 .39058 Mtetra
.614 .924 .972 r
.50267 .39058 .51008 .39257 .52348 .39504 .51615 .38502 Mtetra
.789 .752 .819 r
.51615 .38502 .52348 .39504 .53698 .39041 .52968 .37351 Mtetra
.744 .642 .746 r
.52968 .37351 .53698 .39041 .55049 .37788 .54321 .36102 Mtetra
.711 .627 .761 r
.54321 .36102 .55049 .37788 .56398 .36428 .55676 .35135 Mtetra
.69 .669 .824 r
.55676 .35135 .56398 .36428 .57752 .35455 .57039 .34461 Mtetra
.671 .721 .886 r
.57039 .34461 .57752 .35455 .59115 .34821 .58409 .33937 Mtetra
.659 .745 .913 r
.58409 .33937 .59115 .34821 .60488 .34322 .59786 .3346 Mtetra
.656 .75 .919 r
.59786 .3346 .60488 .34322 .61867 .33853 .6117 .32991 Mtetra
.656 .751 .92 r
.6117 .32991 .61867 .33853 .63254 .33387 .62562 .32521 Mtetra
.62562 .32521 .63254 .33387 .64648 .32918 .6396 .32048 Mtetra
.6396 .32048 .64648 .32918 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Mtetra
.28935 .42838 .29736 .43613 .30975 .43194 .30178 .42416 Mtetra
.30178 .42416 .30975 .43194 .3222 .42775 .31426 .41992 Mtetra
.655 .751 .92 r
.31426 .41992 .3222 .42775 .33469 .42366 .3268 .41569 Mtetra
.65 .746 .92 r
.3268 .41569 .33469 .42366 .34722 .42015 .3394 .41159 Mtetra
.631 .725 .916 r
.3394 .41159 .34722 .42015 .35972 .41841 .35202 .40805 Mtetra
.586 .665 .893 r
.35202 .40805 .35972 .41841 .37216 .41962 .36464 .40588 Mtetra
.532 .574 .842 r
.36464 .40588 .37216 .41962 .38463 .42258 .37725 .40563 Mtetra
.508 .514 .798 r
.37725 .40563 .38463 .42258 .39731 .42314 .3899 .40658 Mtetra
.526 .53 .802 r
.3899 .40658 .39731 .42314 .41027 .41842 .40268 .4068 Mtetra
.577 .638 .875 r
.40268 .4068 .41027 .41842 .42341 .41006 .41563 .40492 Mtetra
.604 .826 .985 r
.41563 .40492 .42341 .41006 .43658 .40164 .42872 .40125 Mtetra
.44 .872 .914 r
.42872 .40125 .43658 .40164 .44973 .39521 .44189 .39715 Mtetra
.193 .716 .697 r
.44189 .39715 .44973 .39521 .46289 .39123 .45511 .39365 Mtetra
0 0 0 r
.45511 .39365 .46289 .39123 .47607 .38981 .4684 .39047 Mtetra
.424 .869 .856 r
.4684 .39047 .47607 .38981 .48931 .39058 .48179 .38553 Mtetra
.788 .873 .91 r
.48179 .38553 .48931 .39058 .50267 .39058 .49528 .37628 Mtetra
.759 .676 .77 r
.49528 .37628 .50267 .39058 .51615 .38502 .50881 .36423 Mtetra
.696 .585 .727 r
.50881 .36423 .51615 .38502 .52968 .37351 .52235 .35391 Mtetra
.668 .58 .747 r
.52235 .35391 .52968 .37351 .54321 .36102 .53591 .34635 Mtetra
.664 .632 .808 r
.53591 .34635 .54321 .36102 .55676 .35135 .54952 .34049 Mtetra
.663 .698 .873 r
.54952 .34049 .55676 .35135 .57039 .34461 .56321 .33543 Mtetra
.659 .737 .907 r
.56321 .33543 .57039 .34461 .58409 .33937 .57696 .33065 Mtetra
.656 .749 .918 r
.57696 .33065 .58409 .33937 .59786 .3346 .59078 .32593 Mtetra
.656 .751 .92 r
.59078 .32593 .59786 .3346 .6117 .32991 .60467 .32121 Mtetra
.60467 .32121 .6117 .32991 .62562 .32521 .61863 .31646 Mtetra
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Mtetra
.28128 .42057 .28935 .42838 .30178 .42416 .29374 .41631 Mtetra
.29374 .41631 .30178 .42416 .31426 .41992 .30626 .41203 Mtetra
.30626 .41203 .31426 .41992 .3268 .41569 .31884 .40773 Mtetra
.655 .75 .92 r
.31884 .40773 .3268 .41569 .3394 .41159 .33148 .40344 Mtetra
.651 .745 .918 r
.33148 .40344 .3394 .41159 .35202 .40805 .34417 .39923 Mtetra
.641 .725 .909 r
.34417 .39923 .35202 .40805 .36464 .40588 .35691 .39534 Mtetra
.619 .677 .883 r
.35691 .39534 .36464 .40588 .37725 .40563 .36967 .3921 Mtetra
.593 .609 .837 r
.36967 .3921 .37725 .40563 .3899 .40658 .38248 .38972 Mtetra
.575 .554 .793 r
.38248 .38972 .3899 .40658 .40268 .4068 .39533 .38794 Mtetra
.574 .532 .77 r
.39533 .38794 .40268 .4068 .41563 .40492 .40827 .38615 Mtetra
.588 .541 .77 r
.40827 .38615 .41563 .40492 .42872 .40125 .42131 .38369 Mtetra
.611 .567 .78 r
.42131 .38369 .42872 .40125 .44189 .39715 .43446 .38017 Mtetra
.637 .587 .782 r
.43446 .38017 .44189 .39715 .45511 .39365 .44772 .37533 Mtetra
.659 .585 .761 r
.44772 .37533 .45511 .39365 .4684 .39047 .46107 .36886 Mtetra
.669 .564 .728 r
.46107 .36886 .4684 .39047 .48179 .38553 .4745 .36057 Mtetra
.659 .538 .705 r
.4745 .36057 .48179 .38553 .49528 .37628 .48797 .35188 Mtetra
.631 .524 .715 r
.48797 .35188 .49528 .37628 .50881 .36423 .50145 .34576 Mtetra
.632 .571 .768 r
.50145 .34576 .50881 .36423 .52235 .35391 .51498 .34086 Mtetra
.648 .65 .839 r
.51498 .34086 .52235 .35391 .53591 .34635 .52858 .3361 Mtetra
.655 .71 .888 r
.52858 .3361 .53591 .34635 .54952 .34049 .54224 .33138 Mtetra
.656 .739 .91 r
.54224 .33138 .54952 .34049 .56321 .33543 .55597 .32666 Mtetra
.656 .748 .918 r
.55597 .32666 .56321 .33543 .57696 .33065 .56976 .32194 Mtetra
.656 .751 .92 r
.56976 .32194 .57696 .33065 .59078 .32593 .58363 .31719 Mtetra
.58363 .31719 .59078 .32593 .60467 .32121 .59757 .31243 Mtetra
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Mtetra
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Mtetra
.28563 .40839 .29374 .41631 .30626 .41203 .29819 .40407 Mtetra
.29819 .40407 .30626 .41203 .31884 .40773 .3108 .39974 Mtetra
.3108 .39974 .31884 .40773 .33148 .40344 .32348 .39538 Mtetra
.655 .75 .92 r
.32348 .39538 .33148 .40344 .34417 .39923 .33621 .39101 Mtetra
.654 .747 .918 r
.33621 .39101 .34417 .39923 .35691 .39534 .34901 .38666 Mtetra
.651 .735 .911 r
.34901 .38666 .35691 .39534 .36967 .3921 .36186 .3824 Mtetra
.644 .708 .894 r
.36186 .3824 .36967 .3921 .38248 .38972 .37477 .37832 Mtetra
.635 .669 .866 r
.37477 .37832 .38248 .38972 .39533 .38794 .38773 .37443 Mtetra
.628 .629 .832 r
.38773 .37443 .39533 .38794 .40827 .38615 .40076 .37059 Mtetra
.626 .599 .803 r
.40076 .37059 .40827 .38615 .42131 .38369 .41386 .36657 Mtetra
.629 .582 .782 r
.41386 .36657 .42131 .38369 .43446 .38017 .42704 .36213 Mtetra
.635 .575 .771 r
.42704 .36213 .43446 .38017 .44772 .37533 .4403 .35717 Mtetra
.642 .579 .768 r
.4403 .35717 .44772 .37533 .46107 .36886 .45364 .35172 Mtetra
.647 .593 .779 r
.45364 .35172 .46107 .36886 .4745 .36057 .46703 .34621 Mtetra
.645 .628 .818 r
.46703 .34621 .4745 .36057 .48797 .35188 .48047 .34137 Mtetra
.653 .702 .882 r
.48047 .34137 .48797 .35188 .50145 .34576 .49397 .33673 Mtetra
.655 .739 .911 r
.49397 .33673 .50145 .34576 .51498 .34086 .50754 .33207 Mtetra
.656 .746 .917 r
.50754 .33207 .51498 .34086 .52858 .3361 .52118 .32738 Mtetra
.656 .749 .919 r
.52118 .32738 .52858 .3361 .54224 .33138 .53489 .32266 Mtetra
.656 .751 .92 r
.53489 .32266 .54224 .33138 .55597 .32666 .54866 .31793 Mtetra
.54866 .31793 .55597 .32666 .56976 .32194 .56251 .31316 Mtetra
.56251 .31316 .56976 .32194 .58363 .31719 .57642 .30838 Mtetra
.57642 .30838 .58363 .31719 .59757 .31243 .5904 .30357 Mtetra
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Mtetra
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Mtetra
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .4004 Mtetra
.27745 .4004 .28563 .40839 .29819 .40407 .29004 .39605 Mtetra
.29004 .39605 .29819 .40407 .3108 .39974 .30269 .39167 Mtetra
.30269 .39167 .3108 .39974 .32348 .39538 .31541 .38727 Mtetra
.31541 .38727 .32348 .39538 .33621 .39101 .32818 .38285 Mtetra
.32818 .38285 .33621 .39101 .34901 .38666 .34102 .37842 Mtetra
.656 .75 .919 r
.34102 .37842 .34901 .38666 .36186 .3824 .35391 .37396 Mtetra
.655 .746 .916 r
.35391 .37396 .36186 .3824 .37477 .37832 .36687 .36949 Mtetra
.655 .736 .91 r
.36687 .36949 .37477 .37832 .38773 .37443 .3799 .36501 Mtetra
.653 .722 .899 r
.3799 .36501 .38773 .37443 .40076 .37059 .39298 .36054 Mtetra
.652 .708 .888 r
.39298 .36054 .40076 .37059 .41386 .36657 .40613 .35606 Mtetra
.652 .699 .88 r
.40613 .35606 .41386 .36657 .42704 .36213 .41935 .3515 Mtetra
.655 .698 .878 r
.41935 .3515 .42704 .36213 .4403 .35717 .43263 .34683 Mtetra
.656 .706 .884 r
.43263 .34683 .4403 .35717 .45364 .35172 .44598 .34212 Mtetra
.655 .723 .899 r
.44598 .34212 .45364 .35172 .46703 .34621 .4594 .33748 Mtetra
.656 .747 .917 r
.4594 .33748 .46703 .34621 .48047 .34137 .47288 .33281 Mtetra
.656 .752 .921 r
.47288 .33281 .48047 .34137 .49397 .33673 .48642 .32812 Mtetra
.48642 .32812 .49397 .33673 .50754 .33207 .50004 .32339 Mtetra
.656 .752 .92 r
.50004 .32339 .50754 .33207 .52118 .32738 .51372 .31866 Mtetra
.656 .751 .92 r
.51372 .31866 .52118 .32738 .53489 .32266 .52747 .3139 Mtetra
.52747 .3139 .53489 .32266 .54866 .31793 .54129 .30912 Mtetra
.54129 .30912 .54866 .31793 .56251 .31316 .55518 .30431 Mtetra
.55518 .30431 .56251 .31316 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Mtetra
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Mtetra
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .4004 .2692 .39235 Mtetra
.2692 .39235 .27745 .4004 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Mtetra
.29451 .38353 .30269 .39167 .31541 .38727 .30726 .3791 Mtetra
.30726 .3791 .31541 .38727 .32818 .38285 .32007 .37464 Mtetra
.32007 .37464 .32818 .38285 .34102 .37842 .33295 .37016 Mtetra
.33295 .37016 .34102 .37842 .35391 .37396 .34588 .36565 Mtetra
.655 .751 .92 r
.34588 .36565 .35391 .37396 .36687 .36949 .35888 .36114 Mtetra
.35888 .36114 .36687 .36949 .3799 .36501 .37195 .35661 Mtetra
.656 .751 .92 r
.37195 .35661 .3799 .36501 .39298 .36054 .38507 .35205 Mtetra
.656 .75 .919 r
.38507 .35205 .39298 .36054 .40613 .35606 .39827 .34744 Mtetra
.656 .747 .917 r
.39827 .34744 .40613 .35606 .41935 .3515 .41152 .34281 Mtetra
.656 .746 .917 r
.41152 .34281 .41935 .3515 .43263 .34683 .42485 .33817 Mtetra
.655 .748 .918 r
.42485 .33817 .43263 .34683 .44598 .34212 .43824 .33353 Mtetra
.656 .751 .92 r
.43824 .33353 .44598 .34212 .4594 .33748 .45169 .32883 Mtetra
.45169 .32883 .4594 .33748 .47288 .33281 .46521 .3241 Mtetra
.655 .75 .92 r
.46521 .3241 .47288 .33281 .48642 .32812 .4788 .31938 Mtetra
.656 .751 .92 r
.4788 .31938 .48642 .32812 .50004 .32339 .49246 .31463 Mtetra
.49246 .31463 .50004 .32339 .51372 .31866 .50619 .30985 Mtetra
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Mtetra
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Mtetra
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36183 Mtetra
.32481 .36183 .33295 .37016 .34588 .36565 .33778 .35728 Mtetra
.33778 .35728 .34588 .36565 .35888 .36114 .35082 .35271 Mtetra
.35082 .35271 .35888 .36114 .37195 .35661 .36392 .3481 Mtetra
.656 .75 .919 r
.36392 .3481 .37195 .35661 .38507 .35205 .37709 .34349 Mtetra
.655 .75 .919 r
.37709 .34349 .38507 .35205 .39827 .34744 .39032 .33887 Mtetra
.655 .751 .92 r
.39032 .33887 .39827 .34744 .41152 .34281 .40362 .33423 Mtetra
.656 .752 .92 r
.40362 .33423 .41152 .34281 .42485 .33817 .41699 .32955 Mtetra
.41699 .32955 .42485 .33817 .43824 .33353 .43042 .32483 Mtetra
.656 .751 .92 r
.43042 .32483 .43824 .33353 .45169 .32883 .44392 .3201 Mtetra
.655 .751 .92 r
.44392 .3201 .45169 .32883 .46521 .3241 .45748 .31536 Mtetra
.656 .752 .921 r
.45748 .31536 .46521 .3241 .4788 .31938 .47111 .31059 Mtetra
.656 .752 .92 r
.47111 .31059 .4788 .31938 .49246 .31463 .48482 .30579 Mtetra
.656 .751 .92 r
.48482 .30579 .49246 .31463 .50619 .30985 .49859 .30097 Mtetra
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Mtetra
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Mtetra
.31659 .35342 .32481 .36183 .33778 .35728 .32961 .34884 Mtetra
.32961 .34884 .33778 .35728 .35082 .35271 .34268 .34424 Mtetra
.655 .752 .921 r
.34268 .34424 .35082 .35271 .36392 .3481 .35583 .33962 Mtetra
.656 .752 .921 r
.35583 .33962 .36392 .3481 .37709 .34349 .36903 .33496 Mtetra
.656 .753 .921 r
.36903 .33496 .37709 .34349 .39032 .33887 .38231 .33028 Mtetra
.656 .752 .92 r
.38231 .33028 .39032 .33887 .40362 .33423 .39565 .32556 Mtetra
.656 .751 .92 r
.39565 .32556 .40362 .33423 .41699 .32955 .40905 .32084 Mtetra
.655 .751 .92 r
.40905 .32084 .41699 .32955 .43042 .32483 .42253 .31611 Mtetra
.655 .752 .921 r
.42253 .31611 .43042 .32483 .44392 .3201 .43607 .31135 Mtetra
.656 .752 .921 r
.43607 .31135 .44392 .3201 .45748 .31536 .44967 .30654 Mtetra
.656 .752 .92 r
.44967 .30654 .45748 .31536 .47111 .31059 .46335 .30172 Mtetra
.656 .751 .92 r
.46335 .30172 .47111 .31059 .48482 .30579 .4771 .29687 Mtetra
.656 .752 .92 r
.4771 .29687 .48482 .30579 .49859 .30097 .49091 .292 Mtetra
.656 .751 .92 r
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Mtetra
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.3083 .34494 .31659 .35342 .32961 .34884 .32136 .34031 Mtetra
.32136 .34031 .32961 .34884 .34268 .34424 .33447 .33565 Mtetra
.33447 .33565 .34268 .34424 .35583 .33962 .34766 .33097 Mtetra
.34766 .33097 .35583 .33962 .36903 .33496 .3609 .32628 Mtetra
.655 .75 .92 r
.3609 .32628 .36903 .33496 .38231 .33028 .37422 .32157 Mtetra
.655 .751 .92 r
.37422 .32157 .38231 .33028 .39565 .32556 .3876 .31683 Mtetra
.656 .752 .92 r
.3876 .31683 .39565 .32556 .40905 .32084 .40105 .31207 Mtetra
.40105 .31207 .40905 .32084 .42253 .31611 .41456 .30726 Mtetra
.656 .751 .92 r
.41456 .30726 .42253 .31611 .43607 .31135 .42815 .30244 Mtetra
.656 .75 .92 r
.42815 .30244 .43607 .31135 .44967 .30654 .4418 .2976 Mtetra
.656 .751 .92 r
.4418 .2976 .44967 .30654 .46335 .30172 .45552 .29275 Mtetra
.45552 .29275 .46335 .30172 .4771 .29687 .46931 .28786 Mtetra
.46931 .28786 .4771 .29687 .49091 .292 .48317 .28295 Mtetra
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Mtetra
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Mtetra
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Mtetra
.31303 .33171 .32136 .34031 .33447 .33565 .32619 .32702 Mtetra
.656 .752 .921 r
.32619 .32702 .33447 .33565 .34766 .33097 .33941 .32231 Mtetra
.33941 .32231 .34766 .33097 .3609 .32628 .3527 .31758 Mtetra
.3527 .31758 .3609 .32628 .37422 .32157 .36605 .3128 Mtetra
.656 .752 .92 r
.36605 .3128 .37422 .32157 .3876 .31683 .37947 .30801 Mtetra
.656 .751 .92 r
.37947 .30801 .3876 .31683 .40105 .31207 .39296 .3032 Mtetra
.655 .751 .92 r
.39296 .3032 .40105 .31207 .41456 .30726 .40652 .29837 Mtetra
.655 .752 .921 r
.40652 .29837 .41456 .30726 .42815 .30244 .42015 .29352 Mtetra
.656 .752 .921 r
.42015 .29352 .42815 .30244 .4418 .2976 .43384 .28863 Mtetra
.43384 .28863 .4418 .2976 .45552 .29275 .44761 .28372 Mtetra
.656 .752 .92 r
.44761 .28372 .45552 .29275 .46931 .28786 .46145 .27878 Mtetra
.656 .751 .92 r
.46145 .27878 .46931 .28786 .48317 .28295 .47535 .27381 Mtetra
.47535 .27381 .48317 .28295 .4971 .27801 .48933 .26883 Mtetra
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Mtetra
.30463 .32303 .31303 .33171 .32619 .32702 .31782 .31829 Mtetra
.31782 .31829 .32619 .32702 .33941 .32231 .33109 .31352 Mtetra
.33109 .31352 .33941 .32231 .3527 .31758 .34442 .30874 Mtetra
.34442 .30874 .3527 .31758 .36605 .3128 .35781 .30394 Mtetra
.655 .751 .92 r
.35781 .30394 .36605 .3128 .37947 .30801 .37127 .29911 Mtetra
.656 .752 .92 r
.37127 .29911 .37947 .30801 .39296 .3032 .38481 .29426 Mtetra
.38481 .29426 .39296 .3032 .40652 .29837 .39841 .28937 Mtetra
.656 .751 .92 r
.39841 .28937 .40652 .29837 .42015 .29352 .41208 .28445 Mtetra
.41208 .28445 .42015 .29352 .43384 .28863 .42582 .27952 Mtetra
.42582 .27952 .43384 .28863 .44761 .28372 .43963 .27457 Mtetra
.43963 .27457 .44761 .28372 .46145 .27878 .45351 .2696 Mtetra
.45351 .2696 .46145 .27878 .47535 .27381 .46746 .26459 Mtetra
.46746 .26459 .47535 .27381 .48933 .26883 .48148 .25956 Mtetra
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Mtetra
.29615 .31427 .30463 .32303 .31782 .31829 .30938 .30949 Mtetra
.656 .752 .921 r
.30938 .30949 .31782 .31829 .33109 .31352 .32268 .30469 Mtetra
.32268 .30469 .33109 .31352 .34442 .30874 .33605 .29987 Mtetra
.33605 .29987 .34442 .30874 .35781 .30394 .34949 .29501 Mtetra
.656 .752 .92 r
.34949 .29501 .35781 .30394 .37127 .29911 .363 .29012 Mtetra
.656 .751 .92 r
.363 .29012 .37127 .29911 .38481 .29426 .37657 .28522 Mtetra
.37657 .28522 .38481 .29426 .39841 .28937 .39022 .2803 Mtetra
.39022 .2803 .39841 .28937 .41208 .28445 .40393 .27535 Mtetra
.656 .752 .921 r
.40393 .27535 .41208 .28445 .42582 .27952 .41771 .27038 Mtetra
.41771 .27038 .42582 .27952 .43963 .27457 .43157 .26537 Mtetra
.656 .752 .92 r
.43157 .26537 .43963 .27457 .45351 .2696 .4455 .26034 Mtetra
.656 .751 .92 r
.4455 .26034 .45351 .2696 .46746 .26459 .45949 .25528 Mtetra
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Mtetra
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Mtetra
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Mtetra
.28759 .30542 .29615 .31427 .30938 .30949 .30086 .30059 Mtetra
.30086 .30059 .30938 .30949 .32268 .30469 .31421 .29574 Mtetra
.31421 .29574 .32268 .30469 .33605 .29987 .32762 .29087 Mtetra
.32762 .29087 .33605 .29987 .34949 .29501 .3411 .28597 Mtetra
.3411 .28597 .34949 .29501 .363 .29012 .35464 .28106 Mtetra
.656 .752 .92 r
.35464 .28106 .363 .29012 .37657 .28522 .36826 .27611 Mtetra
.36826 .27611 .37657 .28522 .39022 .2803 .38195 .27113 Mtetra
.656 .751 .92 r
.38195 .27113 .39022 .2803 .40393 .27535 .39571 .26612 Mtetra
.39571 .26612 .40393 .27535 .41771 .27038 .40954 .2611 Mtetra
.40954 .2611 .41771 .27038 .43157 .26537 .42343 .25605 Mtetra
.42343 .25605 .43157 .26537 .4455 .26034 .43741 .25098 Mtetra
.43741 .25098 .4455 .26034 .45949 .25528 .45145 .24588 Mtetra
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Mtetra
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Mtetra
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Mtetra
.27895 .2965 .28759 .30542 .30086 .30059 .29226 .29163 Mtetra
.656 .752 .92 r
.29226 .29163 .30086 .30059 .31421 .29574 .30565 .28674 Mtetra
.656 .752 .921 r
.30565 .28674 .31421 .29574 .32762 .29087 .3191 .28182 Mtetra
.3191 .28182 .32762 .29087 .3411 .28597 .33262 .27687 Mtetra
.656 .752 .92 r
.33262 .27687 .3411 .28597 .35464 .28106 .34621 .2719 Mtetra
.656 .751 .92 r
.34621 .2719 .35464 .28106 .36826 .27611 .35987 .2669 Mtetra
.35987 .2669 .36826 .27611 .38195 .27113 .3736 .26189 Mtetra
.3736 .26189 .38195 .27113 .39571 .26612 .3874 .25685 Mtetra
.656 .752 .921 r
.3874 .25685 .39571 .26612 .40954 .2611 .40128 .25177 Mtetra
.40128 .25177 .40954 .2611 .42343 .25605 .41522 .24667 Mtetra
.656 .752 .92 r
.41522 .24667 .42343 .25605 .43741 .25098 .42924 .24154 Mtetra
.656 .751 .92 r
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Mtetra
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Mtetra
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Mtetra
.27023 .28749 .27895 .2965 .29226 .29163 .28358 .28257 Mtetra
.28358 .28257 .29226 .29163 .30565 .28674 .29701 .27762 Mtetra
.29701 .27762 .30565 .28674 .3191 .28182 .3105 .27266 Mtetra
.3105 .27266 .3191 .28182 .33262 .27687 .32407 .26767 Mtetra
.32407 .26767 .33262 .27687 .34621 .2719 .3377 .26266 Mtetra
.656 .752 .92 r
.3377 .26266 .34621 .2719 .35987 .2669 .3514 .25762 Mtetra
.3514 .25762 .35987 .2669 .3736 .26189 .36518 .25254 Mtetra
.656 .751 .92 r
.36518 .25254 .3736 .26189 .3874 .25685 .37902 .24744 Mtetra
.37902 .24744 .3874 .25685 .40128 .25177 .39294 .24232 Mtetra
.39294 .24232 .40128 .25177 .41522 .24667 .40693 .23718 Mtetra
.40693 .23718 .41522 .24667 .42924 .24154 .42099 .232 Mtetra
.42099 .232 .42924 .24154 .44333 .23639 .43513 .2268 Mtetra
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Mtetra
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Mtetra
.26142 .27839 .27023 .28749 .28358 .28257 .27482 .27344 Mtetra
.656 .752 .92 r
.27482 .27344 .28358 .28257 .29701 .27762 .28829 .26845 Mtetra
.656 .752 .921 r
.28829 .26845 .29701 .27762 .3105 .27266 .30182 .26344 Mtetra
.30182 .26344 .3105 .27266 .32407 .26767 .31543 .2584 Mtetra
.656 .752 .92 r
.31543 .2584 .32407 .26767 .3377 .26266 .3291 .25332 Mtetra
.656 .751 .92 r
.3291 .25332 .3377 .26266 .3514 .25762 .34285 .24823 Mtetra
.34285 .24823 .3514 .25762 .36518 .25254 .35667 .24312 Mtetra
.35667 .24312 .36518 .25254 .37902 .24744 .37056 .23798 Mtetra
.656 .752 .921 r
.37056 .23798 .37902 .24744 .39294 .24232 .38452 .23281 Mtetra
.38452 .23281 .39294 .24232 .40693 .23718 .39856 .22761 Mtetra
.656 .752 .92 r
.39856 .22761 .40693 .23718 .42099 .232 .41267 .22238 Mtetra
.656 .751 .92 r
.41267 .22238 .42099 .232 .43513 .2268 .42685 .21713 Mtetra
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3ooomC0:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0oooo00<000000?ooo`3oool0AP3ooomE0:O0j`03
0000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo
F@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?oooe`0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo02P0oooo000T
0?ooo`800000B`3ooomM0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?oo
oe`0Yl3[0`0000020:O0j`030000002W`>/0Yl3[0180Yl3[4P3oool00`000000oooo0?ooo`0V0?oo
o`007`3oool3000004T0ooooG@2W`>/3000000D0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`03
0000003oool0oooo02H0oooo000M0?ooo`800000B`3ooomK0:O0j`<000002@2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0303oool2000000@0oooo0P0000030?ooo`@00000
2P3oool001D0oooo1@0000030?ooo`800000B@3ooomJ0:O0j`<000003@2W`>/00`000000Yl3[0:O0
j`0C0:O0ja40oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`0000140?oooe`0Yl3[0P00
000A0:O0j`030000002W`>/0Yl3[01<0Yl3[403oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000o0?oooed0Yl3[0`00000C0:O0j`030000002W`>/0Yl3[01<0Yl3[
4@3oool00`000000oooo0?ooo`030?ooo`@000000P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00T0oooo000?0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>`3ooomK0:O0j`<000005`2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo03P0ooooFP2W`>/3000001/0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`80
00002`3oool2000000X0oooo0P00000;0?ooo`005P3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0c0?oooe/0Yl3[0`00000O0:O0j`030000002W`>/0Yl3[0180Yl3[
4@3oool00`000000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03o
oomK0:O0j`<000008P2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0803o
ool001`0oooo0P0000080?ooo`030000003oool0oooo02/0ooooFP2W`>/3000002H0Yl3[00<00000
0:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0:03ooomI0:O0j`<00000:P2W`>/00`000000Yl3[0:O0j`0B0:O0
ja40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0S0?oooeX0Yl3[0`00000^0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000
oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<000000?ooo`3oool07`3ooomK0:O0j`800000
<@2W`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo00<000000?ooo`3oool07P3oool001/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooocl0Yl3[102W_n/I0:O0j`<00000=02W
`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07@3oool001/0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?oood40Yl3[102W_n/E0:O0j`<00000>02W`>/0
0`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000O0?ooo`006`3oool2000000l0oooo00<000000?oo
o`3oool05@3ooom40:O0j`80Yko[4`2W`>/3000003/0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?oo
o`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04@3ooomI0:O0j`<00000?`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3o
ool06`3oool000P0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0<0?oooeX0Yl3[0`0000130:O0j`030000002W`>/0Yl3[0180Yl3[
403oool00`000000oooo0?ooo`0K0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000<0oooo0P00000C0?ooo`030000003oool0oooo00X0ooooF02W`>/3000004L0
Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01X0oooo00070?ooo`040000
003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo
00L0oooo?02W`>/20:NojaP0Yl3[00@0Yko[0000000000000000BP2W`>/00`000000Yl3[0:O0j`0B
0:O0ja40oooo00<000000?ooo`3oool06@3oool000030?ooo`0000000000008000000P3oool01000
0000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0080oooo?P2W`>/50:NojaD0Yl3[0`0000040:Noj`X0Yl3[102W_n/50:O0j`@0Yko[<`2W`>/0
0`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool06@3oool000L0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`030?ooo`8000005P3oool00`000000Yl3[0:O0j`10
0:O0j`@0Yko[4`2W`>/2000000d0Yl3[1@2W_^X40:Noj`D0YkgX2@2W_n/^0:O0j`030000002W`>/0
Yl3[0140Yl3[403oool2000001X0oooo00080?ooo`8000002P3oool3000000<0oooo00<000000?oo
o`3oool04P3ooomJ0:O0j`<00000102W`>/30:NojP@0Yl3[1@2W_NT40:NnjPD0YkGS1@2W_NP40:Rl
j0X0Yko[:@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool05`3oool001T0
oooo00<000000?ooo`3oool04P3ooomG0:O0j`040:Noj`0000000000000000D0Yl3[1P2W_nX20:O0
j`80Yk?Q1@2W_NT20:NnjP80YJKF1@2W]N<50:Vbg`@0Z;cX1@2X_^T50:NojbP0Yl3[00<000000:O0
j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01L0oooo000I0?ooo`8000004@3ooom<0:O0j`D0
Yko[102W`>/20:NnjP<00000102W_n/50:NiiPD0YkoZ1@2W/n440:Nmj@D0YJKF0P2W]N<30:VQcPD0
ZK;O0P2X_>P20:^hhPD0Z;kY1@2X_n/X0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000
oooo0?ooo`0F0?ooo`006@3oool00`000000oooo0?ooo`0=0?ooodd0Yl3[202W_n/20:NojP<00000
102W_^X40:NdhPD0YkWV1@2UX=440:Nch@D0XI;4102UY]H60:VQcP@0ZK;O1@2[^>820:Rnj@<0Z[kX
102X_n/Y0:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0E0?ooo`006@3o
ool00`000000oooo0?ooo`090?ooodl0Yl3[2@2W_n/3000000<0YkoZ1@2W/^040:NdhPD0YIO71@2U
X=420:Nch@80XHJg1@2QT/@20:FVeP80ZiBo1@2YXLh50;2[dP@0ZkSR1P2Z_^P40:S0jbT0Yl3[00<0
00000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo01D0oooo000I0?ooo`8000001`3ooomD
0:O0j`@0Yko[0`0000030:Noj`80YkoZ0P2V/^450:Nbh080YkCR0P2TU<@40:FGa`D0YJ3A102QQ[L5
0:6Ba0@0ZiBo102YXLh20;JP`PD0/:_B102b]md30:Znj0<0[KoW102X`>/X0:O0j`030000002W`>/0
Yl3[0180Yl3[403oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`030?oo
oeP0Yl3[0`0000000`2W`>/0Yko[0:Noj`030:Noj`D0Y[;Q102W/^040:BDa0D0YIO70P2UX=430:R9
]0@0XHJg0`2QT/@20;:E^P@0ZiBo0P2YXLh30;JP`P@0/:_B0P2k[<X40;:gg@H0[KoW0`2X`>/Y0:O0
j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000
oooo0?ooo`030?oooeH0Yl3[0`0000050:O0j`D0Y[GS102V/^450::Ca@@0Y9C4102UUlL50:R9]0@0
XHJg0P2QT/@30;:E^P@0ZiBo1P2fX<820;2[dP<0^jc:0P2b]md30;ZkfPD0[KoW102Y`>/Y0:O0j`03
0000002W`>/0Yl3[0140Yl3[3`3oool2000001D0oooo000H0?ooo`040000003oool000000?oooeH0
Yl3[0P0000050:O0j`@0YkSV1@2V]N<40:6Db0@0XY?5102TU<@20:FGa`<0Zi2j102XRK@40:66]`H0
/YFj0P2[U;l20;jT_PD0]Z321@2k[<X60;ZkfPD0/<7W102Y`>/X0:O0j`030000002W`>/0Yl3[0140
Yl3[4@3oool00`000000oooo0?ooo`060?ooo`8000002P3oool001P0oooo00<000000:O0j`2W`>/0
E02W`>/3000000<0Yl3[1@2W_>P40:NhiP80Y[GS0`2PVLd30:6Db0D0XY?50`2TU<@50:^@^PD0Z8Vd
0P2QQ[L20<:]a@D0/YFj00@0ZiBo0;jT_P2nY;h0_ZBn102fX<820<:W_P<0^jc:0P37/LD40;ZkfP80
`/7I102``NL50:W1jbP0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000002@3oool00140oooo0P0000050?ooo`030000003oool0Yl3[0540
Yl3[0`0000030:O0j`@0YkkZ1@2W_>P30:NhiPD0X9W=102QU<P40::Ca@80Y9C40P2XUL840:^@^PD0
Z8Vd00@0XHJg0<:]a@32[LD0`Zg51@2bUKX50;jT_P80]Z321032Ykh00`2k[<X0ak750<Naa@020<Na
a@80^[_J1032`MT20;31i`80/L?W1@2Y`N/X0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0CP2W`>/3000000@0Yl3[0`2W_n/40:NnjP@0YkcX102PXM@5
0:2Ic@<0XIC8102RTlD40:RE`PD0Zi2j102XRK@50<:]a@<0/YFj0P39`=440;jT_PH0`ZNn1@37/LD6
0<;1f@D0/L?W1@2Y`N/X0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo0P00
00020?ooodX0Yl3[0`0000050:O0j`H0Yko[0`2W_^X50::[g@<0X:7D1@2PVLd30:6Db0D0XiK80`2X
UL850:^@^P<0Z8Vd0P39gnP40<:]a@80/YFj0`39`=440;jT_P030<B_a@32Ykh0`ZNn00<0`ZNn00<0
bJ^k0<Naa@37/LD00P37/LD0103A^L80`/7I0<;1f@32`MT30<S7f@<0/L?W0P2aa>P50:W1jbL0Yl3[
00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooodH0
Yl3[0`0000090:O0j`D0Yko[102T]N@50::[g@<0X:7D102PVLd409bAa`@0XiK8102XUL840:^@^P80
Z8Vd0`39gnP40<:]a@H0bL3A0P2nY;h20<B_a@@0`ZNn0P39Zk/30<Naa@<0dKW21P38amT50;74j0D0
ZL7[9`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P0000040?ooo`8000002P3oool00100oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?oood40Yl3[0`00000=0:O0j`D0
Y[cY102T]N@40::[g@<0X:7D1@2FR/D309bAa`D0XiK80`2XUL840:^@^PH0bMoX0P32[LD209g/n0D0
bL3A00<0_ZBn0<B_a@34[lD00P34[lD20<:W_P@0bJ^k00<0ak750=6i`P3A^L800P3A^L800`3K`/00
b<OI0<S7f@020<S7f@80bl_J1@2aa>P40:W1jbP0Yl3[00<000000:O0j`2W`>/04@2W`>/>0?ooo`<0
0000403oool00140oooo0P0000040?ooo`8000001`3ooolm0:O0j`<000003@2W`>/50:Noj`@0Y[cY
0`2T]N@509>=b`<0TXS5102FR/D409bAa`@0XiK80`2XUL8606cNf`@0bMoX1@2Mk?P40<W0d@D0a:o5
00<0`ZNn0<V[^`39Zk/00`39Zk/40=6i`P<0fl;00P38amT30<_;fPH0/LCX102Y`N/X0:O0j`030000
002W`>/0Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`0>0?ooo`005`3oool00`000000oooo0?oo
o`070?ooocT0Yl3[0`00000=0:O0j`T0Yko[102N[N8309NKeP@0Thg;0`2BR<D509J:a@<0W977102S
U/P408gRo0D0QMWo1P1Qc?X00`0Y000008G:0025bP050:S9l@@0a:o51P39Zk/0103?[[P0dKW20=6i
`P3A^L830=_2`0H0bl_J1@2aa>P50:W1jbL0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000
003oool0oooo00d0oooo000G0?ooo`030000003oool0oooo00P0oooo=@2W`>/300000140Yl3[102W
_n/50:Bij0<0WZgR0`2GVmH509>=b`<0TXS5102FR/D309bAa`04073Oj@2XlOD0Z?7e0:Sam@H0V=on
102Cf_h309;WnPD0I=?d00<008G:0:S9l@2XbO400P2XbO430<B_a@80_:_91039Zk/30<n^^0030=6i
`P3K`/00fl;00080fl;000<0h/Zo0<_;fP3;bmX0103;bmX50;74j0@0ZL7[:02W`>/00`000000Yl3[
0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0303oool001L0oooo0P0000090?oooc<0Yl3[0P00
000E0:O0j`@0Y[k[1@2T^NP309j]hP<0Ui_F102CSL/309:8a@@0UX[50P1`gnT20:Sam@D0Y^Gk1P2M
gOd209;WnP80S>Wd102V]nD4086Gg`@0Z<Wa00@0a:o50;b[b@2lZlT0_:_90`39Zk/40<n^^0@0fl;0
0`3Rb[l40<_;fP80b/_K1@2aa>P40:W0jbP0Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000
003oool0oooo00`0oooo000G0?ooo`030000003oool0oooo00X0oooo;P2W`>/3000001<0Yl3[1@2W
_n/40:Jnj`@0Y;WX0`2N[N8309NKeP@0Thg;0`2BR<D409[Co080^oW]102mk_<50:3Vo080SNGj1022
iO<30:Ngi@@0Y[OU0`21Uml0100??K`0DIgd056Mm01AWO@50;b[b@030<V[^`3?[[P0cjjh00<0cjjh
00@0fKJf0=_2`03K`/00fl;00`3Rb[l00`3TcL00bl_J0<_;fP040<[;f`D0/<?X102Y`>/X0:O0j`03
0000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?ooo`0;0?ooo`005P3oool00`000000oooo
0?ooo`0<0?ooobX0Yl3[0`00000G0:O0j`D0Yko[0`2V_^/509JZi0<0R9;G0`22Pl`408J7c@@0Tj?O
0P2knNd50;g^l`<0/o;d0P24hoP5087Qn0H0YkOU0`2V]nD4086Gg`0400lm_01AWO@0DIgd056Mm0@0
_:_91@3?[[P30=Vf]P040=_2`03Rb[l0h/Zo0>;:_`<0i<g0103:bm/20<W;f`@0/<?X1@2X`>/W0:O0
j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000h0
oooo9P2W`>/3000001/0Yl3[0`2W_n/20:Jnj`<0XKWZ102FZ^@308RBe`<0PX?<1@26Qld209>Sg`80
aNW_103EjN@20;?bm0@0Yngi0`2fgO@40:JXf0D0YkOU102BPK`01P1aK/00PIOO086Gg`0??K`0001g
00eHdP80DIgd0P2lZlT20;6Pa`<0cjjh103I][H30>;:_`D0i<g00P3:bm/40<W;f`@0/<?X1@2X`>/W
0:O0j`030000002W`>/0Yl3[0100Yl3[3`3oool2000000`0oooo000F0?ooo`030000003oool0oooo
00h0oooo8P2W`>/3000001l0Yl3[1@2V_^/30:6ijP@0UZ[T0`28T]L308:3c0@0QXO=0`35jNl40=GY
i080f>cR0`3Hf]T40;KMm080]J33102VZ=P509j7^`<0TX6l0`1aK/0200lm_0030000M`0=F=803ESB
00@0/J370`3?[[P40=Vf]P030>G2/`3Rb[l0i<g000D0i<g01@39bm/20<S;g0@0/<?X1@2X`>/W0:O0
j`030000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?ooo`090?ooo`005P3oool00`000000
oooo0?ooo`0@0?oooad0Yl3[0`00000S0:O0j`@0Y[k[102A[^X307NAg`<0R9;G0`22Pl`208J7c@@0
ZKGQ103EjN@20=S/hP<0f=[I0`3B_<@50;FP``80YZSH0P2XSk/409j7^`<0TX6l101aK/000`0??K`0
002900eHdP0200eHdP@0/J3700<0cjjh0=Vf]P3I][H00P3I][H20>G2/`L0i<g000@0i<g10<W;f`39
bm/0bL_K0`38bm`50;33j0@0Z<3[9`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?oo
o`3oool0203oool001H0oooo0P00000B0?oooaT0Yl3[0`00000W0:O0j`@0XKc/0`2A[^X407NAg`<0
KggA0P23RM450:Veh@<0clcG0`3Hk>830=SJf@@0d[c400<0bjBa0;FP``2eX<<00P2eX<<40:R?^`@0
WXNk102BPK`3075^`00500D^/00??K`0001g00Pi^P0=F=80102aX<L50=Vf]P80iL:c00<0jlVb0>C=
`03TcL000`3TcL030>C=`@@0b<_L0P37b]`50;33j0@0Z<3[9`2W`>/00`000000Yl3[0:O0j`0A0:O0
j`l0oooo00<000000?ooo`3oool0203oool001H0oooo00<000000?ooo`3oool04P3ooolE0:O0j`<0
00009P2W`>/50:Joj`@0XKc/0`2A[^X307NAg`<0KggA0`23RM430:Veh@<0clcG0`3Jb/X30=SJf@@0
d[c40P3;Y;430;FP``80_Iji0`2XSk/509j7^`<0TX6l0`1aK/0200D^/0040000R@08>KX023Vj00eH
dP80/J370P2aWL<30=Vf]P<0iL:c0P3[bK840>C=`0<0i<g100<0hlg10<S;g038bm`01037b]`50:o3
j0@0Z<3[9`2W`>/00`000000Yl3[0:O0j`0@0:O0j`l0oooo0P0000090?ooo`000`3oool2000000@0
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0D0?oooa40Yl3[0`00000Z0:O0j`D0
Y[o[102F]nh2076Lj`@0Mi7O0`1_OM4308>9d@@0clcG103Jb/X20=Zk^`@0d[c40`3;Y;420;FP``<0
_Iji102XSk/409j7^`<0TX6l0`1aK/0200D^/08000290P08>KX40;6M``<0fKJf0P3U`[<30>_9/P03
0>c:/@3TcL00i<g000<0i<g10`3ScL460<O:g0@0[l?X1@2X`>/W0:O0j`030000002W`>/0Yl3[0100
Yl3[2`3oool3000000030?ooo`000000oooo00P0oooo00020?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0E0?ooo`h0Yl3[0P00000^0:O0
j`D0Y;k/102F]nh2076Lj`<0DGSJ0`1_OM4208>9d@80Z:?A0P3?c=L40=[:bP<0f[^k00@0ejj^0=:l
a03B_<@0d[c40`3;Y;460;fN^@<0Z8nk102NQk/409R^iP80GYG]0`05;[00100008T023Vj00Pi^P08
>KX40;6M``040=Vf]P3U`[<0iL:c0>G2/`<0jlVb0P3/b[440>C=`@<0hlg100<0hlg20<O:g037b]`0
1037b]`40:o3j0D0Z<3[9P2W`>/00`000000Yl3[0:O0j`0A0:O0j`H0oooo100000040?ooo`030000
003oool0oooo00L0oooo00020?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool0
oooo0P00000G0?ooo`X0Yl3[0`00000b0:O0j`@0Y;k/0`2F]nh3076Lj`<0DGSJ0P1`O]450:RSd@D0
f/[:0P3J^k/30=N^[P030=:la03;Y;40bjBa0080bjBa00<0eZna0;fN^@2mW[T00`2mW[T30:R?^`D0
YkCR102H[^H205jEk@04000HW`05;[00001j0000R@8023Vj102aWL<30>G2/`<0jlVb103/b[420>C=
`@<0hlg10`3ScL850<O:g0D0[l?X1@2X`>/V0:O0j`030000002W`>/0Yl3[0140Yl3[0P3oool30000
00P0oooo00<000000?ooo`3oool01`3oool00080oooo00@000000?ooo`3oool000002@3oool20000
00@0oooo00<000000?ooo`3oool0603oool50:O0j`<00000=P2W`>/40:6mk@<0QK3a0P0mPNL3055h
fP<0L7kA0`2XXm430<2/aP80f/[:0`3J^k/30=N^[PD0bjBa00<0eZna0;fN^@2mW[T00`2mW[T40;>k
g`@0YkCR1@2K_>l205bMlP05000HW`05;[000029018i]`08>KX00`2aWL<20<:]a@80iL:c0`3[bK85
0>c:/@@0hlg10`3ScL800`3RcL80al[L0<O:g0030<K:g@D0[l?X102X`>/W0:O0j`030000002W`>/0
Yl3[0100Yl3[0P00000<0?ooo`030000003oool0oooo00H0oooo00020?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`040:O0j`000000
0000000003D0Yl3[1@2V_n`40:6mk@<0QK3a0P0mPNL00`0WH=<0DGSJ055hfP03071nd@030:RSd@30
[<H0`:c600<0`:c60`3J^k/40=N^[P040=R[Z@3;Y;40bjBa0<^T/@<0eZna0`2mW[T20<_4d`@0/k_O
102W`>/509^lk`80G9gb00@001NM0000NP0008T04SVg0P2aWL<40<:]a@@0jlVb1P3/b[420>?=`@<0
hlg20P3RcL860<K:g@D0[l?X102X`>/W0:O0j`030000002W`>/0Yl3[0100Yl3[3@3oool00`000000
oooo0?ooo`060?ooo`000`3oool2000000X0oooo0`0000030?ooo`800000603oool3000003T0Yl3[
1@2V_n`409flkP<0L:Sd00@005K@03f1i`0WH=<09f3C0`1`O]460<2/aP030<^[^@3J^k/0f[^k00<0
ejj^0P3HZjT30<^T/@<0eZna0P2mW[T40<_4d`80/k_O0P2a`^H40:O0j`D0V[__0P1HVo800`005id0
001j018i]`060<:]a@030=S5b03[bK80jlVb00P0k<Za0`3ScL830>;=`P040>;=``36b]d0a/[M0<K:
g@<0a/_M0P2_`nP30:o3j@@0Z<3[9P2W`>/00`000000Yl3[0:O0j`0@0:O0j`d0oooo00<000000?oo
o`3oool01P3oool001@0oooo00<000000?ooo`3oool05@3oool3000000@0oooo>@2W`>/50:Jok0@0
WKc^0`1`Z?@01000E]009f3C02MPd`0WH=<308:8d@@0`:c60P3;ZkT00`3J^k/0ejj^0=N^[P020=N^
[P<0f:^Y00<0bjBa0=J_/@3F[k400P3F[k460<_4d`D0/L;V102W_n/509Zkk`80F9_b00<001:H018i
]`0B>KL01032[LD30=S5b0030>_9/P3/b[40k<Za00L0k<Za00@0hlg20>;=`P3RcL80h/g20`3RcL<5
0<K;g@D0[l?Y1@2X`>/V0:O0j`030000002W`>/0Yl3[0100Yl3[303oool00`000000oooo0?ooo`06
0?ooo`00503oool00`000000oooo0?ooo`0B0?ooo`<00000203oooli0:O0j`D0Y[o/102K_>l205nR
m08005K@00<003^o02MPd`22R=400P22R=430<2/aP<0bj^i103G[Zh40=R[Z@030<^T/@3F[k40eZna
0080eZna00@0h<Fm0<_4d`3;a=<0blCC0`3:a]H20;72iP<0//?V102W_n/509Vkk`80E9[b00<001:H
018i]`32[LD00P32[LD40=S5b0X0k<Za103RcL830>;=``040>??a036bmd0a/_M0<K;g@80a/gO0`2_
`nT20:k4jPD0Z<3[9P2W`>/00`000000Yl3[0:O0j`0@0:O0j`/0oooo00<000000?ooo`3oool01P3o
ool001@0oooo0P00000@0?ooo`<00000303oooli0:O0j`D0Y[o/102K_>l205nRm004000TY@00E]00
03^o02MPd`<0PXSA00<0`:c60<^[^@3;ZkT00P3;ZkT0103@Z[80ejj^0=N^[P3G[Zh40=R[Z@@0eZna
0`3PaKd50<[6ePH0//?V102W`>/409Vkk`<0E9[b00<001:H018i]`32[LD0103HaLP30=k<a`P0k<Za
00<0k<Zb0>;=`P3RcL800`3RcL<30>??a0D0a/gO1@2^a>X50:S0jbH0Yl3[00<000000:O0j`2W`>/0
402W`>/:0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo00`0oooo0`00
000A0?ooocP0Yl3[1@2V_n`409^lk`80FIod00<002BU000k_`00>kl00`22R=440<^[^@80d:Zb0P3G
[Zh50=R[Z@040>:i[@3F[k40eZna0=J_/@@0h<Fm0`3:a]H20<_7eP<0//?V0`2b`nL40:O0j`@0U<Si
0`14V_@00`06CL/0f<G80=S5b0020=S5b0@0g/c700<0glc50>c:/@3/b[401@3/b[420>c:/P@0h/g3
0`3Scl@0103UelL0a/gO0<K=g`36cMl20<C@h`<0[/CZ0P2]a>/40:S0jbH0Yl3[00<000000:O0j`2W
`>/0402W`>/:0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo00X0oooo
0P00000E0?ooocP0Yl3[1@2V_n`409^lk`80FIod00<002BU000k_`00>kl00`2?TM430<^[^@<0d:Zb
00<0ejj^0=R[Z@3HZjT00P3HZjT20>:i[@80eZna1P3PaKd50<_7ePH0//?W102UcOD409C8n@<0A9[d
00<00F7G0=S5b03HaLP0103Nc<L20=o<a@H0k<Za0`3/b[800`3/bk80h/g30>;=``030>??a0<0iMO7
1@34d><50:g4j`@0Z<3[9P2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool0
1@3oool001@0oooo00<000000?ooo`3oool01`3oool3000001P0oooo>02W`>/50:Jok0@0Vkc_0P1J
X?@00`009:D003^o08nAd@0208nAd@80bj^i103@Z[850=R[Z@<0h[V]00<0eZna0>35_@3PaKd0103P
aKd0103QaKd0blOF0<_7eP3;amH20<c8eP<0//?W0`2cc>`40:G=m@@0Y9[<0P2PVLd2005Qe`@0g/c7
0`3Oc<D00`3Pc<@0k<Za0>c:/@030>c:/@<0k<Zb0P3/bk830>??a0<0iMO70P3Vh<h50<3Bj0D0Zl?[
102X`>/V0:O0j`030000002W`>/0Yl3[00l0Yl3[2P3oool00`000000oooo0?ooo`050?ooo`004`3o
ool3000000D0oooo0`00000L0?ooocP0Yl3[1@2V_n`409^lk`80FZ3d00<00023000k_`2?TM400P2?
TM400`3;ZkT0d:Zb0=2Z/P020=2Z/P040=Jb]03HZjT0f:^Y0=R[Z@@0h[V]1P3PaKd30>75_@030<_7
eP3<b=H0c<SF0080c<SF1@2cc>`30<3ZlP80Z9o>0`2TV/`30:2Ic@0400]Xg001HML0g/c70=k<a`<0
glc50`3Pc<@30>c:/@<0k<Zb0`3/bk800`3`d[80hlo40>GGa`020>GGa`<0i^3>00@0hNSG0<3Bj030
d^P0`=;X0P2id>/40:_3j`D0Z<3[9P2W`>/00`000000Yl3[0:O0j`0?0:O0j`T0oooo00<000000?oo
o`3oool01@3oool001<0oooo00<000000?ooo`3oool00P3oool300000200oooo>02W`>/50:Jok0@0
W;c_0P1MXO@0100008<0Si7A08nAd@2?TM440=2Z/P80e[:d0`3HZjT40>:i[@030>O3/P3PaKd0h<Fm
00<0h<Fm0`3QaKd40<c8eP<0cL[G00@0_Oc90>;kd@3Rnm40h__A102XWlh40:BJc0<0X9W=0P0;J=`4
0=o<a@<0h<c400<0hLc30>c:/@3/b[400`3/b[820>c;/P80l=:b0`3UelL30>KPcP<0hNSG1@2id>/4
0:W2k0@0Z<3[9P2W`>/00`000000Yl3[0:O0j`0@0:O0j`P0oooo00<000000?ooo`3oool01@3oool0
01<0oooo00<000000?ooo`0000000P00000T0?ooocP0Yl3[1@2V_n`409blk`80GJ7d00@0002308ZF
f@2:U]T0RYKI0`3@Z[830=Jb]0030=R[Z@3R^Jd0h[V]0080h[V]0`3W`k830>35_@@0hLFm0P3Qa[d4
0<g:e`030;glb@3Rnm40h__A00<0aKS=102XWlh30:BJc0<0YIk>0`0;J=`20=o<a@<0h<c40`3Qc<<3
0>c:/P<0k<^b0P3`d[820?GO]0<0i^3>0`3Qj=L20=KYh`80^M3[0`2ab^d40:W2k2X0Yl3[00<00000
0:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000009`3ooolh0:O0
j`D0Y[o/102L_>l2062Sm0030000P`2:U]T0RYKI0080d:Zb103F/[@00`3HZjT0h[V]0>:i[@020>:i
[@@0il>b0P3PaKd30>75_@<0hLJm00D0h/Jl0<g:e`3=b]L0_Oc90>;kd@050<Fhc@@0Z9o>102TWLh3
0:FNcP<056oO103Pc<@40>7<``80k<Zb0P3/bk820?3B/P<0mMnd0P3ejkX30>7Xe`<0e^WS1@2ab^d5
0:S1jbX0Yl3[00<000000:O0j`2W`>/03`2W`>/70?ooo`030000003oool0oooo00D0oooo000D0?oo
o`030000003oool0oooo02L0oooo>02W`>/50:Jok0@0W;c_0P1PXo@308ZFf@030=2Z/P3F/[@0e[:d
0080e[:d103R^Jd60>O3/P@0hLFm0P3Qa[d30>;6_0040;glb@3hkJl0n>f_0>cA^@@0aKS=1@2SW<h3
0:BMcP@0YIk>0`0DKml20>3<a0H0hLc30`3/bk820?3B/P80mMnd0`3ejkX00`3_ll<0e^WS0=KYh`02
0=KYh`<0aN;/102[a>`50:S1jbT0Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0
oooo00@0oooo000;0?ooo`D000001@3oool2000002T0oooo=`2W`>/50:Jok0@0WKg_0P1SY?D205:=
jPD0e[:d00@0fl?10>:i[@3R^Jd0h[V]1P3W`k800`3Wa;80hLFm0>75_@020>76_@@0h/Jl00<0lN>n
0?S][`3hkJl00P3/dKT20<Fhc@80]:K:102SW<h40:BMcP<0YIk>00@0U9SE01aeh`0LMN<077GS1`3Q
c<<0103UdL<0k<^b0?3B/P3`d[830?GO]080mN^j0P3_ll<20>KicP@0aN;/0P2ed^l40:_4k2h0Yl3[
00<000000:O0j`2W`>/0402W`>/60?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool09`3ooolg0:O0j`D0Y[o/102M_Nl206>Tm@80DXgZ0`3F
/[@30=_3`@030>:i[@3W`k80il>b00@0il>b0`3Wa;830>76_@<0h/Jl00<0lN>n0?S][`3hkJl00`3/
dKT40;BVbP@0Xic>102TWLh40:JUe@0409BHe@0LMN<077GS01aeh`D0hLc30P3UdL<30?3B/P80mMnd
0P3ejkX20>oc``80i_W>0`3Inm`50;GBk`@0Z<7/;P2W`>/00`000000Yl3[0:O0j`0@0:O0j`D0oooo
00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0W0?ooocL0Yl3[1@2V_n`409fmk`0306JVm@1BSNX0DXgZ00<0e[:d0`3K`l470>O3/P<0ilBb00<0
ilBc0>76_@3Ra[`00P3Ra[`20?7S_P80n>f_0`3/dKT00`3H_Kl0]:K:0;BVbP020;BVbP<0Xic>2@2V
YMD0102DV=D097[U02Aji@0TN^D30>7<``<0iM730P3^jLL30?GO]0030?G[^P3_ll<0ko?30080i_W>
0P3Inm`30<S^kPD0ZlG]102X`N`^0:O0j`030000002W`>/0Yl3[00l0Yl3[1@3oool00`000000oooo
0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo=`2W
`>/50:Jok0@0WKg_00@0IZKe001Ab@1BSNX0e[:d103K`l400`3IbLT0il>b0>O3/P030>O3/P<0ilBb
0P3Wa;<40>;6_0030?7S_P3hkJl0n>f_00<0k=6i0`3H_Kl30;BVbP@0Y:3A202VYMD209BHe@<097[U
00@0hLc30>GA``3UdL<0iM730`3^jLL20>?lb`030?G[^P3_ll<0ko?30080i_W>00<0fO_L0<S^kP38
k^h00P38k^h20;CCl0@0ZlG]<P2W`>/00`000000Yl3[0:O0j`0@0:O0j`@0oooo00<000000?ooo`3o
ool0103oool000d0oooo00<000000?ooo`3oool02P3oool2000002P0oooo=`2W`>/40:Jok0D0W[g^
0P00DLT40=_3`@<0fLW9103W`k830>O4/P<0ilBc0P3Ra[`20?7S_P80n>f_0`3/dKT30=Rm_`@0/:;9
102TX=440:JUe@@0Wj7F0P2<U]L2001`e0@0iM730P3^jLL20>?lb`030=Coe`3Dnn00e?_P0080f?_M
00@0e?oD0<SoeP38omH0b?oF1@2ddo040:S1jc80Yl3[00<000000:O0j`2W`>/03`2W`>/40?ooo`03
0000003oool0oooo00@0oooo000<0?ooo`8000003P3oool00`000000oooo0?ooo`0V0?ooocL0Yl3[
102V_n`509jmkP04000e/000DLT0fl?10=_3`@@0fLW900<0f<W;0>O3/P3W`k800`3Wa;850>O4/`80
lN>n0P3hkJl30>cA^@@0f;fo00<0bk700;2Rb@2`X/T00P2`X/T30:BPd@D0YJCD102OXMH308bFe`03
001`e03UdL<0iM730080k^W70P3So</00`3DomL0e?_P0=Ckh0020=Skg@030=Coe038omH0b?oF00<0
`>gb1@2Za>d40:S1jc80Yl3[00<000000:O0j`2W`>/03`2W`>/30?ooo`030000003oool0oooo00@0
oooo000M0?ooo`030000003oool0oooo02H0oooo=`2W`>/40:Jok0D0W[g^0P00=K040=W9b@<0f<W;
103Wa;850>O4/`80k/nd0P3jhJ/20?WKZ@@0f;fo0P3;/L040;2Rb@@0ZZC@102UY=@409nQeP<0S9KG
0P1PN]H20>kYa`030>?lb`3DomL0e?oG0080e?_P00@0f?_M0=Coe03Dom@0b?oF1030kO820:o<k`@0
Z/C]=`2W`>/00`000000Yl3[0:O0j`0>0:O0j`@0oooo00<000000?ooo`3oool00`3oool001h0oooo
00<000000?ooo`3oool09P3ooolg0:O0j`D0Y[o/102N_Nh0101ZZ?D003F`0=W9b@3IbLT40=S9b`03
0=O9c03Wa;80ilBb00H0ilBc0P3^ck@20?[QZ`80nM^Y00<0l=:c0=Rm_`3H_Kl0103;/L020;2Rb@80
]ZK9102ZY=030:FTe0D0W9_A0`2:SM0207=od@<0>F_G0`1h]oT20;;Tn0040;7jc@2eo=/0]OcK0;Gl
f`D0[lc_102X`>/f0:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?oo
o`007`3oool2000002P0oooo=`2W`>/40:Jok0@0W[g^00<0K:We000TX@3HbL/00`3HbL/30=O9c0H0
ilBc0P3^ck@20?[QZ`80nM^Y0`3`d[<50<^a`0D0]ZK90`2ZY=040:FNc`@0W9_A0`2:SM0307=od@<0
MI?R0`2bi?P20;Glf`D0]Mcd102X`^`40:S0jcH0Yl3[00<000000:O0j`2W`>/0402W`>/00`3oool0
00000?ooo`040?ooo`008@3oool00`000000oooo0?ooo`0V0?ooocL0Yl3[102V_n`309jmkP80K:We
00<002BQ0=S9b`3HbL/0103GbL`00`3FbLd0ilBc0>O4/`030>O4/`80k/nd0P3jhJ/20?WKZ@<0l=:c
00@0i<Zm0<^a`03;/L00bk700P39//@40;JVb@@0Zig9102UW/l309bKd@@0RXg@0`1cOm4407FChP04
07oOZ@2fkoH0]^of0;K_mPD0Z/C]102X`^`j0:O0j`030000002W`>/0Yl3[00l0Yl3[00<0oooo0000
003oool0103oool00280oooo00<000000?ooo`3oool09P3ooolg0:O0j`@0Y[o/102O_Nh00`1_Z_D0
01fJ0=O9c0030=O9c0<0e/W=0`3Wa;<30>k?]080n^6[00@0nM^Y0?3B/`3`d[<0l=:c0P3Tb[d20<^a
`0<0bK;40P2fY/T30;JRa0@0Zig90`2UW/l309bKd@@0RXg@0`1cOm430:7Xn`80]^of102/b^l40:[4
kCl0Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`008`3oool00`000000
oooo0?ooo`0V0?ooocL0Yl3[102V_n`409nnkP0407F^mP007IX0elW<0=O9c0@0e/W=00<0eLW>0>O4
/`3Wa;<00P3^ck@20?[QZ`80nM^Y0P3`d[<30>C:_@D0bK;41@2fX/@40:^Mb@@0XY320`2ERL@408Z;
cP@0RJGW0P2OmNL20:g@l`@0[<[_@P2W`>/00`000000Yl3[0:O0j`0?0:O0j`030000003oool0oooo
00<0oooo000T0?ooo`8000009`3ooolg0:O0j`@0Y[o/102O_^h00`1e[_H001ND0=K9c@030=K9c@<0
eLW>0`3^ck@20?[QZ`040?WKZ@3`d[<0l=:c0?3B/`<0i<Zm00@0g<k;0<Vba039//@0bK;40P37]/T4
0;JRa080Zig90`2_W/H30::@`P<0UHW4102:Rlh208VUi`80WoGW1@2]d?<40:S0jd80Yl3[00<00000
0:O0j`2W`>/02`2W`>/30?ooo`030000003oool0oooo00<0oooo000V0?ooo`030000003oool0oooo
02D0oooo=`2W`>/40:Jok0@0XKk^00@0PKCe000GU03FbLd0e/W=0`3EbLh30=O@dP80n^6[00@0nM^Y
0?3B/`3`d[<0l=:c0`3Tb[d30=c>b`040<Vba037]/T0akK90<Nfb@@0]Z;41@2_W/H40::@`P<0UHW4
0`2:Rlh50:_FmPD0Z<7/102X`>]20:O0j`030000002W`>/0Yl3[00H0Yl3[203oool00`000000oooo
0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0U0?oooc/0Yl3[102Q_^h00`2@^_<001ND0=G9
cP020=G9cP<0em3B0`3Tj]@00`3^llH0kO;80>gbb0030>C:_@@0g<k;1@37]/T20;JRa080`;[D102_
W/H40::@`P<0UHW41@2Vf?T40:S2k0@0Z<7/AP2W`>/00`000000Yl3[0:O0j`030:O0j`/0oooo00<0
00000?ooo`3oool00P3oool002P0oooo00<000000?ooo`3oool09P3ooolj0:O0j`@0Xko]00<0T;[c
000GU03EbLh00`3Gd=830>CZe0030>kcaP3]l/P0kO;800<0hOGH103Lc//20=7Ti@@0akK91030^]@4
0:nNaP@0XY3200<0DLk?0:7FnP2Qe_X00P2Qe_X40:S2k@@0Z<;/1@2W`>a50:O0j`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00000W0?ooocX0Yl3[102S_nd0102L
_O00em3B0=O@dP3Gd=830>CZe0030>kcaP3]l/P0kO;800<0hOGH0P2fn>h20=c>b`@0dNCU0P37]/T2
0<3^lP@0`;[D0`2_W/H205C@d@<0W];j1@2W`^d40:S2k@D0Yl3[202W_n/n0:O0j`<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`0U0?oo
ocX0Yl3[1@2U_n`01@2L_O00i>[D0>CZe03Tj]@0k_?60080kO;80P3QmMP50;KhkPD0dNCU1@30k_83
0<2je00309k6m02Mc?P0WLch0080WLch102W`Nd40:O2k@X0Yl3[0`2W_n/n0:O0j`P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?oo
ocl0Yl3[202S_nd409Jnl`@0W/3`102@`_P40:;2l0@0W/Kd102V`>`40:O1kD/0Yl3[2`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000]0?ooo`030000003oool0oooo02H0
oooo?@2W`>/50:K0k0<0Xko]1@2T`>d409k0l0@0Y<3]102R`_040:O0k0@0Y/3/B`2W`>/?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool002h0oooo00<000000?ooo`3oool0
9P3ooolm0:O0j`@0Y/3/102W`>`40:C0k@D0Y/3/0`2T`>d50:O0j`P0Yl3/4@2W`>/40:Nojc40Yl3[
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000_0?ooo`8000009`3o
oom10:O0j`@0Yl3/102W`>/40:K0k0d0Yl3[102W_n/A0:O0j`@0Yko[;@2W`>/H0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool09@3ooomF
0:O0j`P0Yko[?@2W`>/L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool0
0380oooo00<000000?ooo`3oool09@3ooomF0:O0j`@0Yko[?@2W`>/P0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00@3oool003<0oooo00<000000?ooo`3oool09@3ooonC0:O0jb@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`00=03oool2000002H0oooo
FP2W`>/40:Nojc00Yl3[:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0040oooo
000f0?ooo`030000003oool0oooo02D0ooooF@2W`>/30:Nojbd0Yl3[;03oool00`000000oooo0?oo
o`070?ooo`4000000@3oool10?ooo`00=`3oool00`000000oooo0?ooo`0U0?ooohD0Yl3[<03oool0
0`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00>03oool00`000000oooo0?ooo`0U0?oo
ogd0Yl3[>03oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>@3oool2000002H0
ooooN@2W`>/k0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo000k0?ooo`030000
003oool0oooo02@0ooooM@2W`>/o0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`40oooo
000l0?ooo`030000003oool0oooo02@0ooooL@2W`>]30?ooo`030000003oool0oooo00<0oooo0@00
00010?ooo`40oooo000m0?ooo`030000003oool0oooo02@0ooooK02W`>]80?ooo`030000003oool0
oooo0080oooo0@0000010?ooo`40oooo000n0?ooo`8000009@3ooomX0:O0jd/0oooo00<000000?oo
o`3oool00`3oool100000040oooo00100?ooo`030000003oool0oooo02<0ooooI02W`>]?0?ooo`03
0000003oool0oooo0080oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0S0?ooof00Yl3[
D`3oool01@000000oooo0?ooo`3oool000000040oooo00120?ooo`030000003oool0oooo02@0oooo
F`2W`>]G0?ooo`040000003oool0oooo00000040oooo00130?ooo`8000009@3ooomC0:O0jeh0oooo
00@000000?ooo`3oool000000@3oool004D0oooo00<000000?ooo`3oool08`3ooom?0:O0jf80oooo
00<000000?ooo`0000000@3oool004H0oooo00<000000?ooo`3oool08`3ooom;0:O0jfH0oooo0@00
00010?ooo`40000000170?ooo`030000003oool0oooo02<0ooooA`2W`>]Z0?ooo`80000000180?oo
o`8000009@3ooom20:O0jfd0oooo0P00000004X0oooo00<000000?ooo`3oool08`3oooln0:O0jg00
oooo0P00000004/0oooo00<000000?ooo`3oool08P3ooolk0:O0jfl0oooo100000020?ooo`00C03o
ool00`000000oooo0?ooo`0S0?oooc<0Yl3[L@3oool4000000H0oooo001=0?ooo`800000903oool_
0:O0jg00oooo1000000:0?ooo`00C`3oool00`000000oooo0?ooo`0R0?ooob/0Yl3[K`3oool40000
00h0oooo001@0?ooo`030000003oool0oooo02<0oooo9P2W`>]^0?ooo`@000004P3oool00540oooo
00<000000?ooo`3oool08`3ooolR0:O0jfh0oooo0`00000F0?ooo`00DP3oool2000002@0oooo7P2W
`>]]0?ooo`@000006@3oool005@0oooo00<000000?ooo`3oool08P3ooolG0:O0jfl0oooo1000000M
0?ooo`00E@3oool00`000000oooo0?ooo`0Q0?oooa@0Yl3[KP3oool400000240oooo001F0?ooo`03
0000003oool0oooo0280oooo3`2W`>]]0?ooo`@000009@3oool005L0oooo0P00000S0?ooo`/0Yl3[
K03oool4000002T0oooo001I0?ooo`030000003oool0oooo0240oooo102W`>]_0?ooo`<00000;@3o
ool005X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1Z0?ooo`@00000<03oool0
05/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1V0?ooo`@00000=03oool005`0
oooo0P00000Q0?ooo`030000003oool0oooo0680oooo1000000h0?ooo`00GP3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo05h0oooo1000000l0?ooo`00G`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo05X0oooo100000100?ooo`00H03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo05L0oooo0`0000140?ooo`00H@3oool2000001`0oooo00<000000?oo
o`3oool0D`3oool4000004L0oooo001S0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0C`3oool4000004/0oooo001T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
B`3oool4000004l0oooo001U0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3o
ool4000005<0oooo001V0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0@`3oool4
000005L0oooo001W0?ooo`8000005P3oool00`000000oooo0?ooo`100?ooo`<00000F`3oool006T0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0l0?ooo`@00000GP3oool006X0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0h0?ooo`@00000HP3oool006/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`@00000IP3oool006`0oooo0P00000@
0?ooo`030000003oool0oooo0340oooo1000001Z0?ooo`00KP3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02d0oooo1000001^0?ooo`00K`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02X0oooo0`00001b0?ooo`00L03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo02H0oooo1000001e0?ooo`00L@3oool2000000/0oooo00<000000?ooo`3oool08P3o
ool4000007T0oooo001c0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool4
000007d0oooo001d0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool40000
0840oooo001e0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool4000008D0
oooo001f0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`<00000R@3oool007P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`@00000S03oool007T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000T03oool007X0oooo00D000000?oo
o`3oool0oooo000000090?ooo`@00000U03oool007/0oooo0P0000000`3oool000000?ooo`040?oo
o`@00000V03oool007d0oooo0P0000000`3oool0000000000002000009`0oooo001n0?ooo`800000
X03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Mtetra
.59604 .63937 .60194 .6454 .6135 .64214 .60764 .63608 Mtetra
.60764 .63608 .6135 .64214 .62511 .63886 .61928 .63279 Mtetra
.655 .751 .921 r
.61928 .63279 .62511 .63886 .63677 .63556 .63098 .62948 Mtetra
.655 .752 .921 r
.63098 .62948 .63677 .63556 .64848 .63225 .64272 .62616 Mtetra
.656 .753 .921 r
.64272 .62616 .64848 .63225 .66023 .62894 .65451 .62283 Mtetra
.65451 .62283 .66023 .62894 .67204 .62561 .66635 .61947 Mtetra
.66635 .61947 .67204 .62561 .6839 .62227 .67824 .6161 Mtetra
.67824 .6161 .6839 .62227 .6958 .61891 .69018 .61272 Mtetra
.69018 .61272 .6958 .61891 .70776 .61553 .70217 .60932 Mtetra
.70217 .60932 .70776 .61553 .71976 .61215 .71421 .6059 Mtetra
.71421 .6059 .71976 .61215 .73182 .60877 .7263 .60247 Mtetra
.656 .752 .921 r
.7263 .60247 .73182 .60877 .74393 .60536 .73845 .59902 Mtetra
.656 .751 .92 r
.73845 .59902 .74393 .60536 .75609 .60194 .75064 .59557 Mtetra
.75064 .59557 .75609 .60194 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63279 .61341 .62665 Mtetra
.61341 .62665 .61928 .63279 .63098 .62948 .62514 .62331 Mtetra
.62514 .62331 .63098 .62948 .64272 .62616 .63691 .61994 Mtetra
.656 .75 .919 r
.63691 .61994 .64272 .62616 .65451 .62283 .64873 .61658 Mtetra
.64873 .61658 .65451 .62283 .66635 .61947 .66061 .6132 Mtetra
.66061 .6132 .66635 .61947 .67824 .6161 .67253 .6098 Mtetra
.67253 .6098 .67824 .6161 .69018 .61272 .68451 .60639 Mtetra
.68451 .60639 .69018 .61272 .70217 .60932 .69653 .60297 Mtetra
.69653 .60297 .70217 .60932 .71421 .6059 .70861 .59954 Mtetra
.656 .75 .92 r
.70861 .59954 .71421 .6059 .7263 .60247 .72074 .59609 Mtetra
.656 .751 .92 r
.72074 .59609 .7263 .60247 .73845 .59902 .73292 .59263 Mtetra
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Mtetra
.59578 .62383 .60173 .62998 .61341 .62665 .60749 .62048 Mtetra
.655 .751 .921 r
.60749 .62048 .61341 .62665 .62514 .62331 .61925 .61713 Mtetra
.655 .752 .921 r
.61925 .61713 .62514 .62331 .63691 .61994 .63106 .61376 Mtetra
.656 .753 .921 r
.63106 .61376 .63691 .61994 .64873 .61658 .64292 .61037 Mtetra
.64292 .61037 .64873 .61658 .66061 .6132 .65483 .60696 Mtetra
.65483 .60696 .66061 .6132 .67253 .6098 .66678 .60354 Mtetra
.66678 .60354 .67253 .6098 .68451 .60639 .67879 .60011 Mtetra
.67879 .60011 .68451 .60639 .69653 .60297 .69085 .59665 Mtetra
.69085 .59665 .69653 .60297 .70861 .59954 .70297 .59318 Mtetra
.70297 .59318 .70861 .59954 .72074 .59609 .71513 .58969 Mtetra
.656 .752 .92 r
.71513 .58969 .72074 .59609 .73292 .59263 .72735 .58619 Mtetra
.656 .751 .92 r
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Mtetra
.60153 .61426 .60749 .62048 .61925 .61713 .61332 .61086 Mtetra
.656 .751 .919 r
.61332 .61086 .61925 .61713 .63106 .61376 .62516 .60744 Mtetra
.656 .75 .919 r
.62516 .60744 .63106 .61376 .64292 .61037 .63705 .60402 Mtetra
.63705 .60402 .64292 .61037 .65483 .60696 .64899 .60059 Mtetra
.64899 .60059 .65483 .60696 .66678 .60354 .66099 .59714 Mtetra
.66099 .59714 .66678 .60354 .67879 .60011 .67303 .59367 Mtetra
.67303 .59367 .67879 .60011 .69085 .59665 .68513 .5902 Mtetra
.68513 .5902 .69085 .59665 .70297 .59318 .69728 .58671 Mtetra
.655 .75 .92 r
.69728 .58671 .70297 .59318 .71513 .58969 .70948 .58322 Mtetra
.656 .751 .92 r
.70948 .58322 .71513 .58969 .72735 .58619 .72173 .5797 Mtetra
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Mtetra
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Mtetra
.655 .751 .921 r
.59552 .60799 .60153 .61426 .61332 .61086 .60734 .60459 Mtetra
.655 .752 .921 r
.60734 .60459 .61332 .61086 .62516 .60744 .61922 .60117 Mtetra
.656 .753 .922 r
.61922 .60117 .62516 .60744 .63705 .60402 .63114 .59773 Mtetra
.63114 .59773 .63705 .60402 .64899 .60059 .64312 .59426 Mtetra
.64312 .59426 .64899 .60059 .66099 .59714 .65515 .59079 Mtetra
.65515 .59079 .66099 .59714 .67303 .59367 .66723 .5873 Mtetra
.66723 .5873 .67303 .59367 .68513 .5902 .67936 .58379 Mtetra
.656 .753 .921 r
.67936 .58379 .68513 .5902 .69728 .58671 .69154 .58026 Mtetra
.69154 .58026 .69728 .58671 .70948 .58322 .70378 .57671 Mtetra
.656 .752 .92 r
.70378 .57671 .70948 .58322 .72173 .5797 .71607 .57315 Mtetra
.656 .751 .92 r
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56958 Mtetra
.72841 .56958 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Mtetra
.656 .752 .92 r
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Mtetra
.656 .751 .92 r
.58946 .60167 .59552 .60799 .60734 .60459 .60132 .59821 Mtetra
.656 .751 .919 r
.60132 .59821 .60734 .60459 .61922 .60117 .61323 .59474 Mtetra
.656 .75 .919 r
.61323 .59474 .61922 .60117 .63114 .59773 .62519 .59126 Mtetra
.656 .749 .919 r
.62519 .59126 .63114 .59773 .64312 .59426 .6372 .58777 Mtetra
.6372 .58777 .64312 .59426 .65515 .59079 .64926 .58427 Mtetra
.64926 .58427 .65515 .59079 .66723 .5873 .66138 .58075 Mtetra
.66138 .58075 .66723 .5873 .67936 .58379 .67354 .57722 Mtetra
.655 .749 .919 r
.67354 .57722 .67936 .58379 .69154 .58026 .68576 .57368 Mtetra
.655 .75 .92 r
.68576 .57368 .69154 .58026 .70378 .57671 .69804 .57013 Mtetra
.656 .751 .92 r
.69804 .57013 .70378 .57671 .71607 .57315 .71036 .56656 Mtetra
.71036 .56656 .71607 .57315 .72841 .56958 .72274 .56296 Mtetra
.72274 .56296 .72841 .56958 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60562 Mtetra
.54798 .60562 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59875 Mtetra
.57151 .59875 .57765 .6051 .58946 .60167 .58335 .5953 Mtetra
.655 .751 .921 r
.58335 .5953 .58946 .60167 .60132 .59821 .59525 .59185 Mtetra
.655 .752 .921 r
.59525 .59185 .60132 .59821 .61323 .59474 .60719 .58838 Mtetra
.655 .753 .922 r
.60719 .58838 .61323 .59474 .62519 .59126 .61918 .58488 Mtetra
.656 .754 .922 r
.61918 .58488 .62519 .59126 .6372 .58777 .63123 .58136 Mtetra
.63123 .58136 .6372 .58777 .64926 .58427 .64333 .57783 Mtetra
.655 .754 .922 r
.64333 .57783 .64926 .58427 .66138 .58075 .65548 .57429 Mtetra
.656 .754 .922 r
.65548 .57429 .66138 .58075 .67354 .57722 .66768 .57072 Mtetra
.66768 .57072 .67354 .57722 .68576 .57368 .67994 .56713 Mtetra
.656 .753 .921 r
.67994 .56713 .68576 .57368 .69804 .57013 .69225 .56352 Mtetra
.656 .752 .92 r
.69225 .56352 .69804 .57013 .71036 .56656 .70461 .5599 Mtetra
.656 .751 .92 r
.70461 .5599 .71036 .56656 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60562 .54172 .59929 Mtetra
.54172 .59929 .54798 .60562 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59875 .56532 .59237 Mtetra
.656 .752 .92 r
.56532 .59237 .57151 .59875 .58335 .5953 .5772 .58887 Mtetra
.656 .751 .92 r
.5772 .58887 .58335 .5953 .59525 .59185 .58912 .58536 Mtetra
.657 .75 .919 r
.58912 .58536 .59525 .59185 .60719 .58838 .6011 .58182 Mtetra
.656 .749 .918 r
.6011 .58182 .60719 .58838 .61918 .58488 .61313 .57829 Mtetra
.61313 .57829 .61918 .58488 .63123 .58136 .62521 .57475 Mtetra
.62521 .57475 .63123 .58136 .64333 .57783 .63735 .57119 Mtetra
.63735 .57119 .64333 .57783 .65548 .57429 .64953 .56761 Mtetra
.656 .748 .918 r
.64953 .56761 .65548 .57429 .66768 .57072 .66177 .56402 Mtetra
.655 .749 .919 r
.66177 .56402 .66768 .57072 .67994 .56713 .67407 .56044 Mtetra
.655 .75 .919 r
.67407 .56044 .67994 .56713 .69225 .56352 .68641 .55683 Mtetra
.656 .751 .92 r
.68641 .55683 .69225 .56352 .70461 .5599 .69881 .5532 Mtetra
.69881 .5532 .70461 .5599 .71703 .55628 .71127 .54955 Mtetra
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58941 Mtetra
.54723 .58941 .5535 .59583 .56532 .59237 .55909 .58592 Mtetra
.655 .751 .92 r
.55909 .58592 .56532 .59237 .5772 .58887 .571 .58242 Mtetra
.655 .752 .921 r
.571 .58242 .5772 .58887 .58912 .58536 .58296 .57891 Mtetra
.655 .753 .922 r
.58296 .57891 .58912 .58536 .6011 .58182 .59497 .5754 Mtetra
.655 .754 .923 r
.59497 .5754 .6011 .58182 .61313 .57829 .60703 .57185 Mtetra
.656 .755 .923 r
.60703 .57185 .61313 .57829 .62521 .57475 .61915 .56827 Mtetra
.655 .755 .923 r
.61915 .56827 .62521 .57475 .63735 .57119 .63132 .56468 Mtetra
.63132 .56468 .63735 .57119 .64953 .56761 .64354 .56108 Mtetra
.656 .755 .923 r
.64354 .56108 .64953 .56761 .66177 .56402 .65582 .55745 Mtetra
.656 .755 .922 r
.65582 .55745 .66177 .56402 .67407 .56044 .66815 .55379 Mtetra
.656 .753 .921 r
.66815 .55379 .67407 .56044 .68641 .55683 .68053 .55012 Mtetra
.656 .752 .92 r
.68053 .55012 .68641 .55683 .69881 .5532 .69297 .54644 Mtetra
.656 .751 .92 r
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Mtetra
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Mtetra
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Mtetra
.52907 .58646 .53542 .5929 .54723 .58941 .54091 .58295 Mtetra
.54091 .58295 .54723 .58941 .55909 .58592 .5528 .57943 Mtetra
.656 .752 .921 r
.5528 .57943 .55909 .58592 .571 .58242 .56474 .5759 Mtetra
.656 .752 .92 r
.56474 .5759 .571 .58242 .58296 .57891 .57674 .57234 Mtetra
.656 .751 .92 r
.57674 .57234 .58296 .57891 .59497 .5754 .58879 .56878 Mtetra
.655 .75 .92 r
.58879 .56878 .59497 .5754 .60703 .57185 .60089 .56522 Mtetra
.655 .751 .92 r
.60089 .56522 .60703 .57185 .61915 .56827 .61304 .56165 Mtetra
.656 .752 .921 r
.61304 .56165 .61915 .56827 .63132 .56468 .62524 .55804 Mtetra
.657 .752 .92 r
.62524 .55804 .63132 .56468 .64354 .56108 .6375 .55437 Mtetra
.657 .751 .919 r
.6375 .55437 .64354 .56108 .65582 .55745 .64981 .55069 Mtetra
.656 .75 .919 r
.64981 .55069 .65582 .55745 .66815 .55379 .66218 .54702 Mtetra
.656 .751 .92 r
.66218 .54702 .66815 .55379 .68053 .55012 .6746 .54334 Mtetra
.656 .752 .92 r
.6746 .54334 .68053 .55012 .69297 .54644 .68707 .53964 Mtetra
.68707 .53964 .69297 .54644 .70546 .54276 .69961 .53592 Mtetra
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53219 Mtetra
.656 .751 .92 r
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Mtetra
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57998 Mtetra
.655 .751 .921 r
.52266 .57998 .52907 .58646 .54091 .58295 .53454 .57647 Mtetra
.653 .751 .922 r
.53454 .57647 .54091 .58295 .5528 .57943 .54646 .573 Mtetra
.648 .753 .926 r
.54646 .573 .5528 .57943 .56474 .5759 .55844 .56965 Mtetra
.641 .757 .933 r
.55844 .56965 .56474 .5759 .57674 .57234 .57048 .56645 Mtetra
.634 .768 .944 r
.57048 .56645 .57674 .57234 .58879 .56878 .58257 .56334 Mtetra
.632 .784 .955 r
.58257 .56334 .58879 .56878 .60089 .56522 .59472 .56018 Mtetra
.635 .801 .962 r
.59472 .56018 .60089 .56522 .61304 .56165 .60692 .55681 Mtetra
.644 .812 .964 r
.60692 .55681 .61304 .56165 .62524 .55804 .61917 .55316 Mtetra
.655 .815 .96 r
.61917 .55316 .62524 .55804 .6375 .55437 .63146 .54924 Mtetra
.664 .809 .953 r
.63146 .54924 .6375 .55437 .64981 .55069 .6438 .54512 Mtetra
.669 .796 .943 r
.6438 .54512 .64981 .55069 .66218 .54702 .65619 .54093 Mtetra
.667 .778 .933 r
.65619 .54093 .66218 .54702 .6746 .54334 .66863 .53683 Mtetra
.662 .764 .926 r
.66863 .53683 .6746 .54334 .68707 .53964 .68114 .53289 Mtetra
.658 .756 .922 r
.68114 .53289 .68707 .53964 .69961 .53592 .6937 .52905 Mtetra
.657 .753 .921 r
.6937 .52905 .69961 .53592 .71219 .53219 .70633 .52526 Mtetra
.656 .752 .92 r
.70633 .52526 .71219 .53219 .72483 .52844 .71901 .52148 Mtetra
.656 .751 .92 r
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Mtetra
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Mtetra
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Mtetra
.655 .751 .921 r
.49255 .58051 .49907 .587 .51084 .58349 .50435 .577 Mtetra
.653 .751 .922 r
.50435 .577 .51084 .58349 .52266 .57998 .51621 .57354 Mtetra
.644 .751 .927 r
.51621 .57354 .52266 .57998 .53454 .57647 .52812 .57029 Mtetra
.625 .754 .939 r
.52812 .57029 .53454 .57647 .54646 .573 .54008 .56748 Mtetra
.59 .766 .963 r
.54008 .56748 .54646 .573 .55844 .56965 .55211 .56527 Mtetra
.535 .79 .991 r
.55211 .56527 .55844 .56965 .57048 .56645 .5642 .56357 Mtetra
.456 .814 .996 r
.5642 .56357 .57048 .56645 .58257 .56334 .57637 .56199 Mtetra
.371 .817 .947 r
.57637 .56199 .58257 .56334 .59472 .56018 .58859 .56003 Mtetra
.325 .809 .872 r
.58859 .56003 .59472 .56018 .60692 .55681 .60087 .55732 Mtetra
.35 .827 .836 r
.60087 .55732 .60692 .55681 .61917 .55316 .61318 .55366 Mtetra
.443 .879 .864 r
.61318 .55366 .61917 .55316 .63146 .54924 .62552 .54904 Mtetra
.566 .932 .923 r
.62552 .54904 .63146 .54924 .6438 .54512 .63788 .54365 Mtetra
.661 .94 .965 r
.63788 .54365 .6438 .54512 .65619 .54093 .65026 .53788 Mtetra
.699 .898 .968 r
.65026 .53788 .65619 .54093 .66863 .53683 .6627 .53221 Mtetra
.696 .841 .953 r
.6627 .53221 .66863 .53683 .68114 .53289 .6752 .52705 Mtetra
.679 .794 .936 r
.6752 .52705 .68114 .53289 .6937 .52905 .68777 .52249 Mtetra
.665 .767 .926 r
.68777 .52249 .6937 .52905 .70633 .52526 .70042 .51838 Mtetra
.659 .756 .922 r
.70042 .51838 .70633 .52526 .71901 .52148 .71314 .51448 Mtetra
.656 .752 .921 r
.71314 .51448 .71901 .52148 .73175 .51768 .72591 .51063 Mtetra
.656 .752 .92 r
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Mtetra
.656 .751 .92 r
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Mtetra
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Mtetra
.655 .751 .921 r
.47419 .57752 .48079 .58403 .49255 .58051 .48597 .574 Mtetra
.65 .751 .923 r
.48597 .574 .49255 .58051 .50435 .577 .49781 .5706 Mtetra
.633 .75 .932 r
.49781 .5706 .50435 .577 .51621 .57354 .5097 .56762 Mtetra
.584 .75 .957 r
.5097 .56762 .51621 .57354 .52812 .57029 .52164 .56568 Mtetra
.458 .749 .992 r
.52164 .56568 .52812 .57029 .54008 .56748 .53365 .56522 Mtetra
.176 .676 .913 r
.53365 .56522 .54008 .56748 .55211 .56527 .54574 .56587 Mtetra
.121 0 0 r
.54574 .56587 .55211 .56527 .5642 .56357 .55792 .56638 Mtetra
.186 0 0 r
.55792 .56638 .5642 .56357 .57637 .56199 .57016 .56559 Mtetra
.111 0 0 r
.57016 .56559 .57637 .56199 .58859 .56003 .58245 .56326 Mtetra
0 0 0 r
.58245 .56326 .58859 .56003 .60087 .55732 .59478 .55996 Mtetra
.59478 .55996 .60087 .55732 .61318 .55366 .60716 .55628 Mtetra
.60716 .55628 .61318 .55366 .62552 .54904 .61959 .55221 Mtetra
.61959 .55221 .62552 .54904 .63788 .54365 .63204 .54717 Mtetra
.63204 .54717 .63788 .54365 .65026 .53788 .64448 .54056 Mtetra
.489 .881 .708 r
.64448 .54056 .65026 .53788 .6627 .53221 .65691 .53262 Mtetra
.687 .979 .885 r
.65691 .53262 .6627 .53221 .6752 .52705 .66935 .52452 Mtetra
.738 .927 .953 r
.66935 .52452 .6752 .52705 .68777 .52249 .68187 .51753 Mtetra
.706 .835 .944 r
.68187 .51753 .68777 .52249 .70042 .51838 .69449 .51203 Mtetra
.674 .78 .929 r
.69449 .51203 .70042 .51838 .71314 .51448 .70722 .50757 Mtetra
.661 .758 .922 r
.70722 .50757 .71314 .51448 .72591 .51063 .72003 .50355 Mtetra
.657 .753 .921 r
.72003 .50355 .72591 .51063 .73875 .50679 .73291 .49965 Mtetra
.656 .752 .92 r
.73291 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Mtetra
.656 .751 .92 r
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Mtetra
.655 .751 .921 r
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57098 Mtetra
.65 .75 .923 r
.46753 .57098 .47419 .57752 .48597 .574 .47935 .56756 Mtetra
.628 .748 .933 r
.47935 .56756 .48597 .574 .49781 .5706 .49121 .5647 Mtetra
.551 .74 .964 r
.49121 .5647 .49781 .5706 .5097 .56762 .50312 .56338 Mtetra
.308 .688 .977 r
.50312 .56338 .5097 .56762 .52164 .56568 .5151 .56441 Mtetra
.141 0 0 r
.5151 .56441 .52164 .56568 .53365 .56522 .52716 .5668 Mtetra
.233 0 0 r
.52716 .5668 .53365 .56522 .54574 .56587 .5393 .56757 Mtetra
0 0 0 r
.5393 .56757 .54574 .56587 .55792 .56638 .55151 .56452 Mtetra
.7 .932 .965 r
.55151 .56452 .55792 .56638 .57016 .56559 .56374 .55844 Mtetra
.735 .764 .876 r
.56374 .55844 .57016 .56559 .58245 .56326 .57599 .55176 Mtetra
.685 .656 .815 r
.57599 .55176 .58245 .56326 .59478 .55996 .5883 .54625 Mtetra
.642 .604 .796 r
.5883 .54625 .59478 .55996 .60716 .55628 .6007 .54254 Mtetra
.605 .585 .805 r
.6007 .54254 .60716 .55628 .61959 .55221 .6132 .54063 Mtetra
.573 .604 .846 r
.6132 .54063 .61959 .55221 .63204 .54717 .6258 .5399 Mtetra
.565 .708 .937 r
.6258 .5399 .63204 .54717 .64448 .54056 .63846 .53856 Mtetra
.593 .906 .983 r
.63846 .53856 .64448 .54056 .65691 .53262 .65108 .53417 Mtetra
.614 .954 .815 r
.65108 .53417 .65691 .53262 .66935 .52452 .6636 .52589 Mtetra
.718 .987 .825 r
.6636 .52589 .66935 .52452 .68187 .51753 .67606 .51595 Mtetra
.775 .962 .927 r
.67606 .51595 .68187 .51753 .69449 .51203 .6886 .50737 Mtetra
.725 .853 .942 r
.6886 .50737 .69449 .51203 .70722 .50757 .70129 .50117 Mtetra
.678 .783 .929 r
.70129 .50117 .70722 .50757 .72003 .50355 .71411 .49654 Mtetra
.661 .758 .922 r
.71411 .49654 .72003 .50355 .73291 .49965 .72701 .49247 Mtetra
.656 .752 .921 r
.72701 .49247 .73291 .49965 .74584 .49575 .73999 .48852 Mtetra
.656 .751 .92 r
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Mtetra
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Mtetra
.655 .751 .92 r
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56794 Mtetra
.653 .751 .922 r
.44902 .56794 .45576 .57452 .46753 .57098 .46082 .56445 Mtetra
.636 .748 .929 r
.46082 .56445 .46753 .57098 .47935 .56756 .47266 .56139 Mtetra
.562 .736 .957 r
.47266 .56139 .47935 .56756 .49121 .5647 .48454 .55992 Mtetra
.29 .66 .971 r
.48454 .55992 .49121 .5647 .50312 .56338 .49646 .56148 Mtetra
.233 0 0 r
.49646 .56148 .50312 .56338 .5151 .56441 .50847 .56527 Mtetra
.234 0 0 r
.50847 .56527 .5151 .56441 .52716 .5668 .52058 .56667 Mtetra
.532 .917 .927 r
.52058 .56667 .52716 .5668 .5393 .56757 .53276 .56189 Mtetra
.792 .813 .869 r
.53276 .56189 .5393 .56757 .55151 .56452 .54497 .55289 Mtetra
.736 .673 .79 r
.54497 .55289 .55151 .56452 .56374 .55844 .5572 .54417 Mtetra
.686 .618 .775 r
.5572 .54417 .56374 .55844 .57599 .55176 .56947 .53772 Mtetra
.658 .608 .787 r
.56947 .53772 .57599 .55176 .5883 .54625 .58181 .53302 Mtetra
.643 .612 .803 r
.58181 .53302 .5883 .54625 .6007 .54254 .59422 .52928 Mtetra
.623 .602 .809 r
.59422 .52928 .6007 .54254 .6132 .54063 .6067 .52649 Mtetra
.584 .57 .805 r
.6067 .52649 .6132 .54063 .6258 .5399 .6193 .52546 Mtetra
.528 .537 .808 r
.6193 .52546 .6258 .5399 .63846 .53856 .63205 .52672 Mtetra
.501 .565 .853 r
.63205 .52672 .63846 .53856 .65108 .53417 .64491 .52827 Mtetra
.605 .773 .961 r
.64491 .52827 .65108 .53417 .6636 .52589 .6577 .52554 Mtetra
.757 .985 .903 r
.6577 .52554 .6636 .52589 .67606 .51595 .67028 .51654 Mtetra
.81 .999 .844 r
.67028 .51654 .67606 .51595 .6886 .50737 .68276 .5051 Mtetra
.801 .945 .918 r
.68276 .5051 .6886 .50737 .70129 .50117 .69536 .4959 Mtetra
.722 .834 .934 r
.69536 .4959 .70129 .50117 .71411 .49654 .70815 .48979 Mtetra
.673 .772 .925 r
.70815 .48979 .71411 .49654 .72701 .49247 .72108 .48529 Mtetra
.659 .755 .921 r
.72108 .48529 .72701 .49247 .73999 .48852 .73409 .48124 Mtetra
.656 .752 .92 r
.73409 .48124 .73999 .48852 .75302 .48458 .74716 .47725 Mtetra
.656 .751 .92 r
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Mtetra
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Mtetra
.655 .751 .921 r
.43044 .5649 .43727 .57151 .44902 .56794 .44222 .56133 Mtetra
.647 .749 .924 r
.44222 .56133 .44902 .56794 .46082 .56445 .45405 .55796 Mtetra
.604 .741 .941 r
.45405 .55796 .46082 .56445 .47266 .56139 .46591 .55565 Mtetra
.413 .688 .976 r
.46591 .55565 .47266 .56139 .48454 .55992 .47779 .55635 Mtetra
0 .386 .754 r
.47779 .55635 .48454 .55992 .49646 .56148 .48972 .56102 Mtetra
.403 0 0 r
.48972 .56102 .49646 .56148 .50847 .56527 .50176 .56542 Mtetra
.326 .811 .859 r
.50176 .56542 .50847 .56527 .52058 .56667 .51393 .56249 Mtetra
.826 .858 .87 r
.51393 .56249 .52058 .56667 .53276 .56189 .52616 .55217 Mtetra
.782 .719 .793 r
.52616 .55217 .53276 .56189 .54497 .55289 .5384 .54108 Mtetra
.723 .667 .794 r
.5384 .54108 .54497 .55289 .5572 .54417 .55066 .53314 Mtetra
.685 .665 .824 r
.55066 .53314 .5572 .54417 .56947 .53772 .56297 .5277 Mtetra
.666 .677 .851 r
.56297 .5277 .56947 .53772 .58181 .53302 .57534 .52337 Mtetra
.653 .681 .864 r
.57534 .52337 .58181 .53302 .59422 .52928 .58777 .5196 Mtetra
.638 .675 .869 r
.58777 .5196 .59422 .52928 .6067 .52649 .60028 .51639 Mtetra
.606 .653 .869 r
.60028 .51639 .6067 .52649 .6193 .52546 .61287 .51428 Mtetra
.532 .595 .863 r
.61287 .51428 .6193 .52546 .63205 .52672 .62561 .5147 Mtetra
.426 .522 .853 r
.62561 .5147 .63205 .52672 .64491 .52827 .63855 .5183 Mtetra
.42 .565 .893 r
.63855 .5183 .64491 .52827 .6577 .52554 .65157 .52112 Mtetra
.666 .849 .97 r
.65157 .52112 .6577 .52554 .67028 .51654 .6644 .51644 Mtetra
.846 .989 .853 r
.6644 .51644 .67028 .51654 .68276 .5051 .67693 .50431 Mtetra
.863 .976 .857 r
.67693 .50431 .68276 .5051 .69536 .4959 .68945 .49187 Mtetra
.784 .889 .92 r
.68945 .49187 .69536 .4959 .70815 .48979 .70217 .48348 Mtetra
.697 .796 .926 r
.70217 .48348 .70815 .48979 .72108 .48529 .7151 .47815 Mtetra
.664 .76 .922 r
.7151 .47815 .72108 .48529 .73409 .48124 .72814 .4739 Mtetra
.657 .752 .92 r
.72814 .4739 .73409 .48124 .74716 .47725 .74126 .46986 Mtetra
.656 .751 .92 r
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Mtetra
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Mtetra
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55824 Mtetra
.654 .751 .921 r
.42355 .55824 .43044 .5649 .44222 .56133 .43536 .55467 Mtetra
.638 .747 .928 r
.43536 .55467 .44222 .56133 .45405 .55796 .44722 .55151 Mtetra
.553 .726 .954 r
.44722 .55151 .45405 .55796 .46591 .55565 .45909 .55023 Mtetra
.161 .562 .931 r
.45909 .55023 .46591 .55565 .47779 .55635 .47096 .55349 Mtetra
.485 0 0 r
.47096 .55349 .47779 .55635 .48972 .56102 .48288 .56098 Mtetra
.361 0 0 r
.48288 .56098 .48972 .56102 .50176 .56542 .49497 .56453 Mtetra
.766 .963 .93 r
.49497 .56453 .50176 .56542 .51393 .56249 .50723 .55635 Mtetra
.859 .798 .789 r
.50723 .55635 .51393 .56249 .52616 .55217 .51952 .54122 Mtetra
.786 .701 .771 r
.51952 .54122 .52616 .55217 .5384 .54108 .53179 .52878 Mtetra
.71 .655 .794 r
.53179 .52878 .5384 .54108 .55066 .53314 .54407 .5215 Mtetra
.665 .647 .823 r
.54407 .5215 .55066 .53314 .56297 .5277 .55642 .51695 Mtetra
.651 .658 .844 r
.55642 .51695 .56297 .5277 .57534 .52337 .56882 .51313 Mtetra
.652 .669 .854 r
.56882 .51313 .57534 .52337 .58777 .5196 .58128 .50932 Mtetra
.651 .669 .854 r
.58128 .50932 .58777 .5196 .60028 .51639 .59379 .50554 Mtetra
.631 .65 .85 r
.59379 .50554 .60028 .51639 .61287 .51428 .60639 .50248 Mtetra
.557 .597 .849 r
.60639 .50248 .61287 .51428 .62561 .5147 .61912 .50217 Mtetra
.38 .487 .843 r
.61912 .50217 .62561 .5147 .63855 .5183 .6321 .50707 Mtetra
.211 .413 .842 r
.6321 .50707 .63855 .5183 .65157 .52112 .64532 .5147 Mtetra
.439 .686 .969 r
.64532 .5147 .65157 .52112 .6644 .51644 .65839 .51528 Mtetra
.842 .971 .88 r
.65839 .51528 .6644 .51644 .67693 .50431 .67104 .50393 Mtetra
.906 .968 .807 r
.67104 .50393 .67693 .50431 .68945 .49187 .6835 .48856 Mtetra
.843 .913 .883 r
.6835 .48856 .68945 .49187 .70217 .48348 .69616 .4775 Mtetra
.728 .817 .919 r
.69616 .4775 .70217 .48348 .7151 .47815 .70907 .47105 Mtetra
.671 .766 .921 r
.70907 .47105 .7151 .47815 .72814 .4739 .72214 .46652 Mtetra
.658 .753 .92 r
.72214 .46652 .72814 .4739 .74126 .46986 .7353 .46241 Mtetra
.656 .752 .92 r
.7353 .46241 .74126 .46986 .75443 .46583 .74852 .45834 Mtetra
.656 .751 .92 r
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Mtetra
.40481 .55516 .41179 .56185 .42355 .55824 .41661 .55152 Mtetra
.652 .751 .922 r
.41661 .55152 .42355 .55824 .43536 .55467 .42845 .54796 Mtetra
.629 .744 .931 r
.42845 .54796 .43536 .55467 .44722 .55151 .44033 .54503 Mtetra
.493 .701 .962 r
.44033 .54503 .44722 .55151 .45909 .55023 .45221 .54482 Mtetra
0 .368 .8 r
.45221 .54482 .45909 .55023 .47096 .55349 .46406 .55068 Mtetra
.642 .084 0 r
.46406 .55068 .47096 .55349 .48288 .56098 .47597 .56095 Mtetra
.275 0 0 r
.47597 .56095 .48288 .56098 .49497 .56453 .48811 .56353 Mtetra
.888 .936 .842 r
.48811 .56353 .49497 .56453 .50723 .55635 .50047 .55001 Mtetra
.886 .787 .746 r
.50047 .55001 .50723 .55635 .51952 .54122 .51284 .5303 Mtetra
.794 .705 .766 r
.51284 .5303 .51952 .54122 .53179 .52878 .52514 .5171 Mtetra
.694 .659 .811 r
.52514 .5171 .53179 .52878 .54407 .5215 .53746 .51099 Mtetra
.647 .662 .85 r
.53746 .51099 .54407 .5215 .55642 .51695 .54984 .50735 Mtetra
.646 .681 .869 r
.54984 .50735 .55642 .51695 .56882 .51313 .56227 .50381 Mtetra
.654 .691 .873 r
.56227 .50381 .56882 .51313 .58128 .50932 .57476 .49997 Mtetra
.661 .694 .87 r
.57476 .49997 .58128 .50932 .59379 .50554 .5873 .49585 Mtetra
.657 .686 .865 r
.5873 .49585 .59379 .50554 .60639 .50248 .59989 .49182 Mtetra
.588 .636 .866 r
.59989 .49182 .60639 .50248 .61912 .50217 .61261 .49027 Mtetra
.33 .471 .851 r
.61261 .49027 .61912 .50217 .6321 .50707 .62562 .49588 Mtetra
0 .231 .749 r
.62562 .49588 .6321 .50707 .64532 .5147 .639 .50807 Mtetra
.059 .451 .88 r
.639 .50807 .64532 .5147 .65839 .51528 .65232 .514 Mtetra
.819 .971 .897 r
.65232 .514 .65839 .51528 .67104 .50393 .66508 .50357 Mtetra
.936 .949 .768 r
.66508 .50357 .67104 .50393 .6835 .48856 .6775 .4853 Mtetra
.884 .907 .839 r
.6775 .4853 .6835 .48856 .69616 .4775 .69009 .4715 Mtetra
.757 .824 .905 r
.69009 .4715 .69616 .4775 .70907 .47105 .70299 .4639 Mtetra
.679 .769 .919 r
.70299 .4639 .70907 .47105 .72214 .46652 .71609 .45908 Mtetra
.659 .754 .92 r
.71609 .45908 .72214 .46652 .7353 .46241 .72929 .45489 Mtetra
.656 .752 .92 r
.72929 .45489 .7353 .46241 .74852 .45834 .74255 .45079 Mtetra
.656 .751 .92 r
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Mtetra
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43837 Mtetra
.78271 .43837 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Mtetra
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Mtetra
.655 .751 .92 r
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54475 Mtetra
.651 .75 .922 r
.40961 .54475 .41661 .55152 .42845 .54796 .42148 .54119 Mtetra
.621 .742 .933 r
.42148 .54119 .42845 .54796 .44033 .54503 .43339 .53842 Mtetra
.439 .675 .963 r
.43339 .53842 .44033 .54503 .45221 .54482 .44528 .53906 Mtetra
0 .195 .659 r
.44528 .53906 .45221 .54482 .46406 .55068 .4571 .54725 Mtetra
.73 .204 0 r
.4571 .54725 .46406 .55068 .47597 .56095 .46897 .56061 Mtetra
.275 0 0 r
.46897 .56061 .47597 .56095 .48811 .56353 .48115 .56347 Mtetra
.932 .925 .78 r
.48115 .56347 .48811 .56353 .50047 .55001 .49364 .5455 Mtetra
.924 .806 .712 r
.49364 .5455 .50047 .55001 .51284 .5303 .50611 .52034 Mtetra
.825 .727 .756 r
.50611 .52034 .51284 .5303 .52514 .5171 .51847 .50458 Mtetra
.688 .645 .802 r
.51847 .50458 .52514 .5171 .53746 .51099 .5308 .49853 Mtetra
.622 .617 .824 r
.5308 .49853 .53746 .51099 .54984 .50735 .5432 .49572 Mtetra
.628 .634 .837 r
.5432 .49572 .54984 .50735 .56227 .50381 .55566 .49275 Mtetra
.65 .655 .842 r
.55566 .49275 .56227 .50381 .57476 .49997 .56817 .48888 Mtetra
.669 .663 .835 r
.56817 .48888 .57476 .49997 .5873 .49585 .58072 .48412 Mtetra
.67 .653 .824 r
.58072 .48412 .5873 .49585 .59989 .49182 .59332 .47918 Mtetra
.593 .603 .831 r
.59332 .47918 .59989 .49182 .61261 .49027 .60605 .47752 Mtetra
.23 .394 .82 r
.60605 .47752 .61261 .49027 .62562 .49588 .61914 .48565 Mtetra
0 0 .525 r
.61914 .48565 .62562 .49588 .639 .50807 .63268 .50329 Mtetra
.436 0 0 r
.63268 .50329 .639 .50807 .65232 .514 .6462 .51366 Mtetra
.809 .989 .88 r
.6462 .51366 .65232 .514 .66508 .50357 .65903 .50288 Mtetra
.955 .921 .733 r
.65903 .50288 .66508 .50357 .6775 .4853 .6714 .48139 Mtetra
.903 .881 .802 r
.6714 .48139 .6775 .4853 .69009 .4715 .68395 .46516 Mtetra
.775 .819 .887 r
.68395 .46516 .69009 .4715 .70299 .4639 .69686 .45661 Mtetra
.685 .768 .915 r
.69686 .45661 .70299 .4639 .71609 .45908 .70999 .45156 Mtetra
.66 .754 .92 r
.70999 .45156 .71609 .45908 .72929 .45489 .72323 .44731 Mtetra
.656 .752 .92 r
.72323 .44731 .72929 .45489 .74255 .45079 .73653 .44317 Mtetra
.656 .751 .92 r
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Mtetra
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43837 .77683 .43065 Mtetra
.77683 .43065 .78271 .43837 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .5599 Mtetra
.33216 .5599 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Mtetra
.655 .751 .92 r
.39069 .54162 .39778 .54842 .40961 .54475 .40255 .53793 Mtetra
.651 .75 .922 r
.40255 .53793 .40961 .54475 .42148 .54119 .41446 .53434 Mtetra
.617 .74 .934 r
.41446 .53434 .42148 .54119 .43339 .53842 .4264 .53165 Mtetra
.406 .655 .96 r
.4264 .53165 .43339 .53842 .44528 .53906 .43829 .53281 Mtetra
0 .093 .575 r
.43829 .53281 .44528 .53906 .4571 .54725 .45009 .54266 Mtetra
.779 .279 0 r
.45009 .54266 .4571 .54725 .46897 .56061 .46191 .55903 Mtetra
.377 0 0 r
.46191 .55903 .46897 .56061 .48115 .56347 .4741 .56408 Mtetra
.944 .925 .758 r
.4741 .56408 .48115 .56347 .49364 .5455 .4867 .54427 Mtetra
.96 .838 .678 r
.4867 .54427 .49364 .5455 .50611 .52034 .49931 .51404 Mtetra
.889 .791 .745 r
.49931 .51404 .50611 .52034 .51847 .50458 .51175 .49403 Mtetra
.727 .693 .817 r
.51175 .49403 .51847 .50458 .5308 .49853 .52411 .48641 Mtetra
.622 .624 .831 r
.52411 .48641 .5308 .49853 .5432 .49572 .53652 .4836 Mtetra
.621 .623 .832 r
.53652 .4836 .5432 .49572 .55566 .49275 .549 .48082 Mtetra
.647 .639 .828 r
.549 .48082 .55566 .49275 .56817 .48888 .56153 .47692 Mtetra
.671 .65 .821 r
.56153 .47692 .56817 .48888 .58072 .48412 .5741 .4719 Mtetra
.668 .645 .818 r
.5741 .4719 .58072 .48412 .59332 .47918 .58672 .46691 Mtetra
.549 .588 .845 r
.58672 .46691 .59332 .47918 .60605 .47752 .5995 .46677 Mtetra
0 .2 .729 r
.5995 .46677 .60605 .47752 .61914 .48565 .6127 .47911 Mtetra
.777 .308 0 r
.6127 .47911 .61914 .48565 .63268 .50329 .62641 .50182 Mtetra
.671 .12 0 r
.62641 .50182 .63268 .50329 .6462 .51366 .64002 .51399 Mtetra
.853 .993 .836 r
.64002 .51399 .6462 .51366 .65903 .50288 .65286 .50091 Mtetra
.961 .881 .71 r
.65286 .50091 .65903 .50288 .6714 .48139 .66519 .47629 Mtetra
.904 .847 .777 r
.66519 .47629 .6714 .48139 .68395 .46516 .67773 .45829 Mtetra
.782 .807 .872 r
.67773 .45829 .68395 .46516 .69686 .45661 .69066 .44916 Mtetra
.688 .766 .911 r
.69066 .44916 .69686 .45661 .70999 .45156 .70383 .44396 Mtetra
.66 .753 .919 r
.70383 .44396 .70999 .45156 .72323 .44731 .71711 .43967 Mtetra
.656 .752 .92 r
.71711 .43967 .72323 .44731 .73653 .44317 .73046 .43549 Mtetra
.656 .751 .92 r
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Mtetra
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .5599 .32486 .5532 Mtetra
.32486 .5532 .33216 .5599 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Mtetra
.655 .751 .92 r
.38355 .53477 .39069 .54162 .40255 .53793 .39544 .53105 Mtetra
.651 .75 .922 r
.39544 .53105 .40255 .53793 .41446 .53434 .40738 .52744 Mtetra
.615 .739 .934 r
.40738 .52744 .41446 .53434 .4264 .53165 .41935 .52477 Mtetra
.39 .646 .959 r
.41935 .52477 .4264 .53165 .43829 .53281 .43126 .52616 Mtetra
0 .052 .543 r
.43126 .52616 .43829 .53281 .45009 .54266 .44304 .53684 Mtetra
.794 .311 0 r
.44304 .53684 .45009 .54266 .46191 .55903 .45481 .55515 Mtetra
.446 0 0 r
.45481 .55515 .46191 .55903 .4741 .56408 .46699 .56313 Mtetra
.925 .909 .787 r
.46699 .56313 .4741 .56408 .4867 .54427 .47965 .54534 Mtetra
.975 .862 .663 r
.47965 .54534 .4867 .54427 .49931 .51404 .49239 .51368 Mtetra
.958 .88 .714 r
.49239 .51368 .49931 .51404 .51175 .49403 .50495 .48909 Mtetra
.847 .84 .838 r
.50495 .48909 .51175 .49403 .52411 .48641 .51738 .47674 Mtetra
.693 .7 .852 r
.51738 .47674 .52411 .48641 .53652 .4836 .52981 .4712 Mtetra
.642 .629 .823 r
.52981 .4712 .53652 .4836 .549 .48082 .5423 .46748 Mtetra
.643 .616 .808 r
.5423 .46748 .549 .48082 .56153 .47692 .55484 .46354 Mtetra
.647 .618 .807 r
.55484 .46354 .56153 .47692 .5741 .4719 .56744 .4594 Mtetra
.608 .614 .832 r
.56744 .4594 .5741 .4719 .58672 .46691 .58013 .45709 Mtetra
.307 .511 .892 r
.58013 .45709 .58672 .46691 .5995 .46677 .59303 .46163 Mtetra
.708 .2 0 r
.59303 .46163 .5995 .46677 .6127 .47911 .60636 .47856 Mtetra
.849 .395 .114 r
.60636 .47856 .6127 .47911 .62641 .50182 .62012 .50265 Mtetra
.653 .106 0 r
.62012 .50265 .62641 .50182 .64002 .51399 .63372 .51272 Mtetra
.913 .945 .809 r
.63372 .51272 .64002 .51399 .65286 .50091 .64652 .49659 Mtetra
.948 .835 .699 r
.64652 .49659 .65286 .50091 .66519 .47629 .65887 .46993 Mtetra
.897 .819 .762 r
.65887 .46993 .66519 .47629 .67773 .45829 .67144 .45102 Mtetra
.784 .798 .863 r
.67144 .45102 .67773 .45829 .69066 .44916 .68441 .44159 Mtetra
.689 .765 .91 r
.68441 .44159 .69066 .44916 .70383 .44396 .69762 .43629 Mtetra
.66 .753 .919 r
.69762 .43629 .70383 .44396 .71711 .43967 .71095 .43195 Mtetra
.656 .752 .92 r
.71095 .43195 .71711 .43967 .73046 .43549 .72434 .42774 Mtetra
.656 .751 .92 r
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Mtetra
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40208 Mtetra
.80604 .40208 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Mtetra
.655 .751 .92 r
.37634 .52786 .38355 .53477 .39544 .53105 .38827 .52411 Mtetra
.651 .75 .922 r
.38827 .52411 .39544 .53105 .40738 .52744 .40024 .52048 Mtetra
.613 .738 .935 r
.40024 .52048 .40738 .52744 .41935 .52477 .41224 .51782 Mtetra
.38 .64 .958 r
.41224 .51782 .41935 .52477 .43126 .52616 .42417 .51934 Mtetra
0 .035 .529 r
.42417 .51934 .43126 .52616 .44304 .53684 .43594 .53036 Mtetra
.792 .314 0 r
.43594 .53036 .44304 .53684 .45481 .55515 .44769 .54924 Mtetra
0 .138 .606 r
.44769 .54924 .45481 .55515 .46699 .56313 .45985 .55843 Mtetra
.874 .836 .806 r
.45985 .55843 .46699 .56313 .47965 .54534 .47255 .54324 Mtetra
.951 .835 .694 r
.47255 .54324 .47965 .54534 .49239 .51368 .48537 .515 Mtetra
.96 .92 .723 r
.48537 .515 .49239 .51368 .50495 .48909 .49802 .49229 Mtetra
.802 .995 .767 r
.49802 .49229 .50495 .48909 .51738 .47674 .51055 .47903 Mtetra
.576 .936 .794 r
.51055 .47903 .51738 .47674 .52981 .4712 .52306 .47103 Mtetra
.574 .935 .926 r
.52306 .47103 .52981 .4712 .5423 .46748 .53561 .46544 Mtetra
.56 .894 .984 r
.53561 .46544 .5423 .46748 .55484 .46354 .54821 .46148 Mtetra
.43 .836 .975 r
.54821 .46148 .55484 .46354 .56744 .4594 .56088 .45917 Mtetra
.01 .585 .727 r
.56088 .45917 .56744 .4594 .58013 .45709 .57367 .45929 Mtetra
.527 0 0 r
.57367 .45929 .58013 .45709 .59303 .46163 .58665 .46471 Mtetra
.76 .284 .113 r
.58665 .46471 .59303 .46163 .60636 .47856 .59998 .47967 Mtetra
.82 .357 .119 r
.59998 .47967 .60636 .47856 .62012 .50265 .61367 .50025 Mtetra
.418 0 0 r
.61367 .50025 .62012 .50265 .63372 .51272 .62721 .50761 Mtetra
.898 .849 .787 r
.62721 .50761 .63372 .51272 .64652 .49659 .64005 .4902 Mtetra
.931 .802 .695 r
.64005 .4902 .64652 .49659 .65887 .46993 .65246 .46289 Mtetra
.892 .806 .756 r
.65246 .46289 .65887 .46993 .67144 .45102 .66508 .44357 Mtetra
.786 .795 .86 r
.66508 .44357 .67144 .45102 .68441 .44159 .6781 .43393 Mtetra
.69 .765 .909 r
.6781 .43393 .68441 .44159 .69762 .43629 .69136 .42855 Mtetra
.661 .753 .919 r
.69136 .42855 .69762 .43629 .71095 .43195 .70473 .42417 Mtetra
.656 .752 .92 r
.70473 .42417 .71095 .43195 .72434 .42774 .71816 .41992 Mtetra
.656 .751 .92 r
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Mtetra
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40208 .80014 .39403 Mtetra
.80014 .39403 .80604 .40208 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53218 Mtetra
.33352 .53218 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Mtetra
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .5209 Mtetra
.655 .751 .92 r
.36908 .5209 .37634 .52786 .38827 .52411 .38103 .51711 Mtetra
.65 .75 .922 r
.38103 .51711 .38827 .52411 .40024 .52048 .39304 .51346 Mtetra
.611 .738 .935 r
.39304 .51346 .40024 .52048 .41224 .51782 .40507 .51082 Mtetra
.368 .634 .957 r
.40507 .51082 .41224 .51782 .42417 .51934 .41701 .51247 Mtetra
0 .019 .513 r
.41701 .51247 .42417 .51934 .43594 .53036 .42878 .52374 Mtetra
.791 .313 0 r
.42878 .52374 .43594 .53036 .44769 .54924 .44052 .54269 Mtetra
0 .186 .667 r
.44052 .54269 .44769 .54924 .45985 .55843 .4527 .55158 Mtetra
.851 .79 .791 r
.4527 .55158 .45985 .55843 .47255 .54324 .46545 .53643 Mtetra
.909 .774 .701 r
.46545 .53643 .47255 .54324 .48537 .515 .47835 .50958 Mtetra
.898 .811 .753 r
.47835 .50958 .48537 .515 .49802 .49229 .49105 .48966 Mtetra
.824 .918 .9 r
.49105 .48966 .49802 .49229 .51055 .47903 .50363 .47962 Mtetra
.511 .913 .882 r
.50363 .47962 .51055 .47903 .52306 .47103 .51621 .47415 Mtetra
0 0 0 r
.51621 .47415 .52306 .47103 .53561 .46544 .52884 .46985 Mtetra
.52884 .46985 .53561 .46544 .54821 .46148 .54152 .46587 Mtetra
.03 0 0 r
.54152 .46587 .54821 .46148 .56088 .45917 .55427 .46222 Mtetra
.55427 .46222 .56088 .45917 .57367 .45929 .5671 .45974 Mtetra
.24 0 0 r
.5671 .45974 .57367 .45929 .58665 .46471 .58007 .46186 Mtetra
.641 .087 0 r
.58007 .46186 .58665 .46471 .59998 .47967 .59336 .47396 Mtetra
.733 .239 0 r
.59336 .47396 .59998 .47967 .61367 .50025 .60702 .49307 Mtetra
0 .38 .837 r
.60702 .49307 .61367 .50025 .62721 .50761 .62058 .50033 Mtetra
.873 .803 .778 r
.62058 .50033 .62721 .50761 .64005 .4902 .63349 .48315 Mtetra
.926 .793 .694 r
.63349 .48315 .64005 .4902 .65246 .46289 .64599 .4557 Mtetra
.893 .804 .754 r
.64599 .4557 .65246 .46289 .66508 .44357 .65868 .43606 Mtetra
.789 .795 .858 r
.65868 .43606 .66508 .44357 .6781 .43393 .67174 .42621 Mtetra
.692 .766 .908 r
.67174 .42621 .6781 .43393 .69136 .42855 .68504 .42075 Mtetra
.661 .754 .919 r
.68504 .42075 .69136 .42855 .70473 .42417 .69845 .41633 Mtetra
.656 .752 .92 r
.69845 .41633 .70473 .42417 .71816 .41992 .71193 .41203 Mtetra
.656 .751 .92 r
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Mtetra
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38592 Mtetra
.79418 .38592 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53218 .32609 .52525 Mtetra
.32609 .52525 .33352 .53218 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Mtetra
.34981 .51768 .35717 .52467 .36908 .5209 .36175 .51387 Mtetra
.655 .751 .92 r
.36175 .51387 .36908 .5209 .38103 .51711 .37374 .51006 Mtetra
.65 .75 .923 r
.37374 .51006 .38103 .51711 .39304 .51346 .38578 .50638 Mtetra
.609 .737 .936 r
.38578 .50638 .39304 .51346 .40507 .51082 .39784 .50376 Mtetra
.356 .628 .956 r
.39784 .50376 .40507 .51082 .41701 .51247 .4098 .50556 Mtetra
.505 0 0 r
.4098 .50556 .41701 .51247 .42878 .52374 .42156 .51708 Mtetra
.792 .314 0 r
.42156 .51708 .42878 .52374 .44052 .54269 .43329 .53607 Mtetra
0 .222 .699 r
.43329 .53607 .44052 .54269 .4527 .55158 .44548 .54447 Mtetra
.853 .785 .784 r
.44548 .54447 .4527 .55158 .46545 .53643 .45831 .52877 Mtetra
.902 .764 .699 r
.45831 .52877 .46545 .53643 .47835 .50958 .47129 .5018 Mtetra
.874 .77 .744 r
.47129 .5018 .47835 .50958 .49105 .48966 .48406 .482 Mtetra
.787 .774 .841 r
.48406 .482 .49105 .48966 .50363 .47962 .49669 .47207 Mtetra
.694 .758 .901 r
.49669 .47207 .50363 .47962 .51621 .47415 .50931 .46676 Mtetra
.659 .753 .92 r
.50931 .46676 .51621 .47415 .52884 .46985 .52198 .46261 Mtetra
.654 .757 .925 r
.52198 .46261 .52884 .46985 .54152 .46587 .5347 .4586 Mtetra
.648 .755 .927 r
.5347 .4586 .54152 .46587 .55427 .46222 .54749 .45473 Mtetra
.606 .735 .936 r
.54749 .45473 .55427 .46222 .5671 .45974 .56034 .45203 Mtetra
.377 .621 .948 r
.56034 .45203 .5671 .45974 .58007 .46186 .57334 .45397 Mtetra
0 .12 .641 r
.57334 .45397 .58007 .46186 .59336 .47396 .58664 .46587 Mtetra
.646 .178 0 r
.58664 .46587 .59336 .47396 .60702 .49307 .60029 .48502 Mtetra
0 .369 .835 r
.60029 .48502 .60702 .49307 .62058 .50033 .61388 .49277 Mtetra
.867 .799 .781 r
.61388 .49277 .62058 .50033 .63349 .48315 .62688 .47602 Mtetra
.926 .793 .694 r
.62688 .47602 .63349 .48315 .64599 .4557 .63946 .44847 Mtetra
.895 .804 .751 r
.63946 .44847 .64599 .4557 .65868 .43606 .65221 .4285 Mtetra
.792 .796 .856 r
.65221 .4285 .65868 .43606 .67174 .42621 .66532 .41844 Mtetra
.693 .766 .908 r
.66532 .41844 .67174 .42621 .68504 .42075 .67867 .41288 Mtetra
.661 .754 .919 r
.67867 .41288 .68504 .42075 .69845 .41633 .69212 .40841 Mtetra
.656 .752 .92 r
.69212 .40841 .69845 .41633 .71193 .41203 .70564 .40408 Mtetra
.656 .751 .92 r
.70564 .40408 .71193 .41203 .72548 .40773 .71923 .39974 Mtetra
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38592 .78817 .37773 Mtetra
.78817 .37773 .79418 .38592 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Mtetra
.655 .751 .92 r
.35437 .50679 .36175 .51387 .37374 .51006 .36639 .50294 Mtetra
.65 .75 .923 r
.36639 .50294 .37374 .51006 .38578 .50638 .37846 .49924 Mtetra
.607 .736 .937 r
.37846 .49924 .38578 .50638 .39784 .50376 .39055 .49665 Mtetra
.342 .621 .954 r
.39055 .49665 .39784 .50376 .4098 .50556 .40253 .49861 Mtetra
.524 .016 0 r
.40253 .49861 .4098 .50556 .42156 .51708 .41428 .5104 Mtetra
.793 .315 0 r
.41428 .5104 .42156 .51708 .43329 .53607 .42599 .52941 Mtetra
0 .26 .731 r
.42599 .52941 .43329 .53607 .44548 .54447 .43821 .53728 Mtetra
.857 .784 .779 r
.43821 .53728 .44548 .54447 .45831 .52877 .45111 .52098 Mtetra
.901 .763 .699 r
.45111 .52098 .45831 .52877 .47129 .5018 .46418 .49393 Mtetra
.873 .77 .746 r
.46418 .49393 .47129 .5018 .48406 .482 .47702 .47434 Mtetra
.785 .775 .844 r
.47702 .47434 .48406 .482 .49669 .47207 .48969 .46457 Mtetra
.692 .761 .904 r
.48969 .46457 .49669 .47207 .50931 .46676 .50235 .4593 Mtetra
.659 .753 .919 r
.50235 .4593 .50931 .46676 .52198 .46261 .51505 .45512 Mtetra
.654 .752 .922 r
.51505 .45512 .52198 .46261 .5347 .4586 .52782 .45108 Mtetra
.649 .75 .923 r
.52782 .45108 .5347 .4586 .54749 .45473 .54064 .44716 Mtetra
.61 .735 .934 r
.54064 .44716 .54749 .45473 .56034 .45203 .55353 .44433 Mtetra
.387 .629 .95 r
.55353 .44433 .56034 .45203 .57334 .45397 .56656 .44604 Mtetra
0 .134 .652 r
.56656 .44604 .57334 .45397 .58664 .46587 .57986 .45767 Mtetra
.644 .177 0 r
.57986 .45767 .58664 .46587 .60029 .48502 .5935 .47685 Mtetra
0 .341 .817 r
.5935 .47685 .60029 .48502 .61388 .49277 .60713 .48513 Mtetra
.862 .799 .786 r
.60713 .48513 .61388 .49277 .62688 .47602 .62021 .46885 Mtetra
.926 .793 .694 r
.62021 .46885 .62688 .47602 .63946 .44847 .63288 .44121 Mtetra
.897 .804 .749 r
.63288 .44121 .63946 .44847 .65221 .4285 .64569 .42089 Mtetra
.795 .797 .854 r
.64569 .42089 .65221 .4285 .66532 .41844 .65885 .41059 Mtetra
.695 .767 .907 r
.65885 .41059 .66532 .41844 .67867 .41288 .67224 .40494 Mtetra
.661 .754 .919 r
.67224 .40494 .67867 .41288 .69212 .40841 .68573 .40042 Mtetra
.656 .752 .92 r
.68573 .40042 .69212 .40841 .70564 .40408 .6993 .39605 Mtetra
.656 .751 .92 r
.6993 .39605 .70564 .40408 .71923 .39974 .71294 .39167 Mtetra
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51505 Mtetra
.29922 .51505 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Mtetra
.655 .751 .92 r
.34692 .49965 .35437 .50679 .36639 .50294 .35898 .49577 Mtetra
.649 .75 .923 r
.35898 .49577 .36639 .50294 .37846 .49924 .37108 .49205 Mtetra
.604 .736 .937 r
.37108 .49205 .37846 .49924 .39055 .49665 .38319 .48949 Mtetra
.326 .613 .953 r
.38319 .48949 .39055 .49665 .40253 .49861 .39519 .49162 Mtetra
.543 .034 0 r
.39519 .49162 .40253 .49861 .41428 .5104 .40693 .50371 Mtetra
.793 .315 0 r
.40693 .50371 .41428 .5104 .42599 .52941 .41862 .52272 Mtetra
0 .302 .766 r
.41862 .52272 .42599 .52941 .43821 .53728 .43087 .52999 Mtetra
.861 .783 .773 r
.43087 .52999 .43821 .53728 .45111 .52098 .44385 .51307 Mtetra
.901 .762 .699 r
.44385 .51307 .45111 .52098 .46418 .49393 .457 .48601 Mtetra
.871 .771 .749 r
.457 .48601 .46418 .49393 .47702 .47434 .46991 .46673 Mtetra
.783 .778 .848 r
.46991 .46673 .47702 .47434 .48969 .46457 .48263 .4571 Mtetra
.695 .764 .905 r
.48263 .4571 .48969 .46457 .50235 .4593 .49533 .45168 Mtetra
.664 .752 .916 r
.49533 .45168 .50235 .4593 .51505 .45512 .50807 .44731 Mtetra
.654 .744 .916 r
.50807 .44731 .51505 .45512 .52782 .45108 .52087 .44322 Mtetra
.644 .741 .919 r
.52087 .44322 .52782 .45108 .54064 .44716 .53374 .43944 Mtetra
.606 .732 .934 r
.53374 .43944 .54064 .44716 .55353 .44433 .54667 .43671 Mtetra
.393 .637 .953 r
.54667 .43671 .55353 .44433 .56656 .44604 .55972 .43821 Mtetra
0 .15 .664 r
.55972 .43821 .56656 .44604 .57986 .45767 .57302 .44943 Mtetra
.644 .176 0 r
.57302 .44943 .57986 .45767 .5935 .47685 .58665 .46854 Mtetra
0 .312 .798 r
.58665 .46854 .5935 .47685 .60713 .48513 .60031 .47738 Mtetra
.857 .798 .792 r
.60031 .47738 .60713 .48513 .62021 .46885 .61347 .46164 Mtetra
.926 .794 .694 r
.61347 .46164 .62021 .46885 .63288 .44121 .62623 .43392 Mtetra
.899 .805 .746 r
.62623 .43392 .63288 .44121 .64569 .42089 .63911 .41323 Mtetra
.798 .799 .852 r
.63911 .41323 .64569 .42089 .65885 .41059 .65232 .40269 Mtetra
.696 .768 .907 r
.65232 .40269 .65885 .41059 .67224 .40494 .66575 .39693 Mtetra
.662 .754 .919 r
.66575 .39693 .67224 .40494 .68573 .40042 .67929 .39236 Mtetra
.656 .752 .92 r
.67929 .39236 .68573 .40042 .6993 .39605 .69291 .38795 Mtetra
.656 .751 .92 r
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Mtetra
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51505 .29158 .50797 Mtetra
.29158 .50797 .29922 .51505 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Mtetra
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Mtetra
.655 .751 .92 r
.33941 .49245 .34692 .49965 .35898 .49577 .3515 .48854 Mtetra
.649 .749 .923 r
.3515 .48854 .35898 .49577 .37108 .49205 .36364 .4848 Mtetra
.602 .735 .938 r
.36364 .4848 .37108 .49205 .38319 .48949 .37578 .48228 Mtetra
.309 .604 .95 r
.37578 .48228 .38319 .48949 .39519 .49162 .38778 .4846 Mtetra
.561 .052 0 r
.38778 .4846 .39519 .49162 .40693 .50371 .39951 .49698 Mtetra
.792 .314 0 r
.39951 .49698 .40693 .50371 .41862 .52272 .41119 .51595 Mtetra
0 .361 .812 r
.41119 .51595 .41862 .52272 .43087 .52999 .42348 .52241 Mtetra
.866 .777 .761 r
.42348 .52241 .43087 .52999 .44385 .51307 .43656 .50422 Mtetra
.898 .75 .69 r
.43656 .50422 .44385 .51307 .457 .48601 .44983 .47555 Mtetra
.859 .732 .722 r
.44983 .47555 .457 .48601 .46991 .46673 .46284 .45394 Mtetra
.772 .683 .766 r
.46284 .45394 .46991 .46673 .48263 .4571 .47563 .44154 Mtetra
.694 .619 .768 r
.47563 .44154 .48263 .4571 .49533 .45168 .48836 .43388 Mtetra
.651 .575 .756 r
.48836 .43388 .49533 .45168 .50807 .44731 .50112 .42833 Mtetra
.625 .551 .751 r
.50112 .42833 .50807 .44731 .52087 .44322 .51391 .4242 Mtetra
.601 .538 .755 r
.51391 .4242 .52087 .44322 .53374 .43944 .52677 .42148 Mtetra
.561 .526 .773 r
.52677 .42148 .53374 .43944 .54667 .43671 .5397 .42089 Mtetra
.423 .472 .807 r
.5397 .42089 .54667 .43671 .55972 .43821 .55277 .42509 Mtetra
0 .181 .714 r
.55277 .42509 .55972 .43821 .57302 .44943 .56609 .43859 Mtetra
0 0 .405 r
.56609 .43859 .57302 .44943 .58665 .46854 .57973 .45927 Mtetra
0 .268 .772 r
.57973 .45927 .58665 .46854 .60031 .47738 .59342 .46934 Mtetra
.847 .793 .799 r
.59342 .46934 .60031 .47738 .61347 .46164 .60667 .45434 Mtetra
.926 .794 .695 r
.60667 .45434 .61347 .46164 .62623 .43392 .61953 .4266 Mtetra
.901 .805 .744 r
.61953 .4266 .62623 .43392 .63911 .41323 .63248 .40553 Mtetra
.802 .8 .85 r
.63248 .40553 .63911 .41323 .65232 .40269 .64573 .39472 Mtetra
.698 .769 .906 r
.64573 .39472 .65232 .40269 .66575 .39693 .65921 .38886 Mtetra
.662 .754 .918 r
.65921 .38886 .66575 .39693 .67929 .39236 .67279 .38423 Mtetra
.656 .752 .92 r
.67279 .38423 .67929 .39236 .69291 .38795 .68645 .37978 Mtetra
.656 .751 .92 r
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Mtetra
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Mtetra
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48519 Mtetra
.655 .751 .921 r
.33184 .48519 .33941 .49245 .3515 .48854 .34396 .48124 Mtetra
.648 .749 .923 r
.34396 .48124 .3515 .48854 .36364 .4848 .35613 .47749 Mtetra
.598 .734 .939 r
.35613 .47749 .36364 .4848 .37578 .48228 .3683 .47501 Mtetra
.292 .595 .948 r
.3683 .47501 .37578 .48228 .38778 .4846 .38032 .47751 Mtetra
.571 .061 0 r
.38032 .47751 .38778 .4846 .39951 .49698 .39203 .49007 Mtetra
.775 .292 0 r
.39203 .49007 .39951 .49698 .41119 .51595 .40372 .50835 Mtetra
.195 .531 .923 r
.40372 .50835 .41119 .51595 .42348 .52241 .4161 .51226 Mtetra
.863 .737 .722 r
.4161 .51226 .42348 .52241 .43656 .50422 .42936 .49013 Mtetra
.869 .698 .667 r
.42936 .49013 .43656 .50422 .44983 .47555 .44278 .45814 Mtetra
.81 .655 .69 r
.44278 .45814 .44983 .47555 .46284 .45394 .45584 .43558 Mtetra
.716 .604 .731 r
.45584 .43558 .46284 .45394 .47563 .44154 .46862 .42476 Mtetra
.648 .584 .769 r
.46862 .42476 .47563 .44154 .48836 .43388 .48133 .41967 Mtetra
.632 .607 .807 r
.48133 .41967 .48836 .43388 .50112 .42833 .49408 .41588 Mtetra
.646 .641 .831 r
.49408 .41588 .50112 .42833 .51391 .4242 .5069 .41171 Mtetra
.654 .645 .829 r
.5069 .41171 .51391 .4242 .52677 .42148 .51977 .40717 Mtetra
.62 .601 .81 r
.51977 .40717 .52677 .42148 .5397 .42089 .53271 .40393 Mtetra
.481 .492 .792 r
.53271 .40393 .5397 .42089 .55277 .42509 .54576 .40646 Mtetra
.093 .227 .712 r
.54576 .40646 .55277 .42509 .56609 .43859 .55904 .42079 Mtetra
0 0 .521 r
.55904 .42079 .56609 .43859 .57973 .45927 .57268 .4447 Mtetra
0 .2 .722 r
.57268 .4447 .57973 .45927 .59342 .46934 .58643 .45866 Mtetra
.794 .736 .799 r
.58643 .45866 .59342 .46934 .60667 .45434 .59979 .44619 Mtetra
.917 .784 .698 r
.59979 .44619 .60667 .45434 .61953 .4266 .61276 .41907 Mtetra
.9 .802 .742 r
.61276 .41907 .61953 .4266 .63248 .40553 .62578 .39776 Mtetra
.805 .8 .847 r
.62578 .39776 .63248 .40553 .64573 .39472 .63908 .38669 Mtetra
.7 .769 .905 r
.63908 .38669 .64573 .39472 .65921 .38886 .6526 .38071 Mtetra
.663 .754 .918 r
.6526 .38071 .65921 .38886 .67279 .38423 .66623 .37603 Mtetra
.656 .752 .92 r
.66623 .37603 .67279 .38423 .68645 .37978 .67994 .37154 Mtetra
.656 .751 .92 r
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Mtetra
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34883 Mtetra
.74947 .34883 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48183 Mtetra
.31209 .48183 .31977 .48912 .33184 .48519 .3242 .47786 Mtetra
.655 .751 .921 r
.3242 .47786 .33184 .48519 .34396 .48124 .33636 .47389 Mtetra
.648 .749 .923 r
.33636 .47389 .34396 .48124 .35613 .47749 .34856 .47011 Mtetra
.596 .733 .94 r
.34856 .47011 .35613 .47749 .3683 .47501 .36076 .46765 Mtetra
.289 .592 .947 r
.36076 .46765 .3683 .47501 .38032 .47751 .37279 .47019 Mtetra
.53 .024 0 r
.37279 .47019 .38032 .47751 .39203 .49007 .38452 .48221 Mtetra
.677 .188 0 r
.38452 .48221 .39203 .49007 .40372 .50835 .39629 .4981 Mtetra
.527 .633 .899 r
.39629 .4981 .40372 .50835 .4161 .51226 .40883 .49777 Mtetra
.84 .688 .694 r
.40883 .49777 .4161 .51226 .42936 .49013 .42221 .47306 Mtetra
.843 .671 .668 r
.42221 .47306 .42936 .49013 .44278 .45814 .43563 .44335 Mtetra
.797 .671 .725 r
.43563 .44335 .44278 .45814 .45584 .43558 .44862 .42622 Mtetra
.704 .723 .865 r
.44862 .42622 .45584 .43558 .46862 .42476 .46136 .42009 Mtetra
.564 .817 .993 r
.46136 .42009 .46862 .42476 .48133 .41967 .47408 .41732 Mtetra
.5 .864 .986 r
.47408 .41732 .48133 .41967 .49408 .41588 .48688 .41419 Mtetra
.543 .899 .974 r
.48688 .41419 .49408 .41588 .5069 .41171 .49976 .40998 Mtetra
.614 .924 .972 r
.49976 .40998 .5069 .41171 .51977 .40717 .5127 .40469 Mtetra
.658 .919 .977 r
.5127 .40469 .51977 .40717 .53271 .40393 .5257 .39902 Mtetra
.534 .801 .995 r
.5257 .39902 .53271 .40393 .54576 .40646 .53876 .39674 Mtetra
0 .32 .808 r
.53876 .39674 .54576 .40646 .55904 .42079 .552 .40557 Mtetra
0 0 .52 r
.552 .40557 .55904 .42079 .57268 .4447 .56556 .42712 Mtetra
0 .159 .684 r
.56556 .42712 .57268 .4447 .58643 .45866 .57932 .44358 Mtetra
.703 .64 .782 r
.57932 .44358 .58643 .45866 .59979 .44619 .5928 .43533 Mtetra
.884 .748 .707 r
.5928 .43533 .59979 .44619 .61276 .41907 .6059 .41058 Mtetra
.888 .787 .743 r
.6059 .41058 .61276 .41907 .62578 .39776 .61901 .38974 Mtetra
.804 .795 .844 r
.61901 .38974 .62578 .39776 .63908 .38669 .63238 .37857 Mtetra
.702 .769 .904 r
.63238 .37857 .63908 .38669 .6526 .38071 .64594 .37249 Mtetra
.663 .754 .918 r
.64594 .37249 .6526 .38071 .66623 .37603 .65962 .36776 Mtetra
.656 .752 .92 r
.65962 .36776 .66623 .37603 .67994 .37154 .67337 .36322 Mtetra
.656 .751 .92 r
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Mtetra
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34883 .74314 .34031 Mtetra
.74314 .34031 .74947 .34883 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48183 .30436 .47448 Mtetra
.30436 .47448 .31209 .48183 .3242 .47786 .3165 .47048 Mtetra
.655 .751 .921 r
.3165 .47048 .3242 .47786 .33636 .47389 .32869 .46647 Mtetra
.648 .749 .923 r
.32869 .46647 .33636 .47389 .34856 .47011 .34093 .46266 Mtetra
.598 .733 .939 r
.34093 .46266 .34856 .47011 .36076 .46765 .35316 .46013 Mtetra
.326 .609 .951 r
.35316 .46013 .36076 .46765 .37279 .47019 .36523 .46223 Mtetra
0 .105 .614 r
.36523 .46223 .37279 .47019 .38452 .48221 .37703 .47257 Mtetra
0 .046 .585 r
.37703 .47257 .38452 .48221 .39629 .4981 .38892 .48498 Mtetra
.615 .618 .831 r
.38892 .48498 .39629 .4981 .40883 .49777 .40156 .48201 Mtetra
.821 .673 .698 r
.40156 .48201 .40883 .49777 .42221 .47306 .41493 .45947 Mtetra
.846 .698 .699 r
.41493 .45947 .42221 .47306 .43563 .44335 .42826 .43534 Mtetra
.823 .776 .809 r
.42826 .43534 .43563 .44335 .44862 .42622 .44121 .42234 Mtetra
.661 .873 .978 r
.44121 .42234 .44862 .42622 .46136 .42009 .45397 .41737 Mtetra
.505 .857 .992 r
.45397 .41737 .46136 .42009 .47408 .41732 .46675 .41439 Mtetra
.542 .866 .995 r
.46675 .41439 .47408 .41732 .48688 .41419 .47961 .41099 Mtetra
.6 .88 .992 r
.47961 .41099 .48688 .41419 .49976 .40998 .49255 .40679 Mtetra
.643 .894 .984 r
.49255 .40679 .49976 .40998 .5127 .40469 .50555 .40176 Mtetra
.656 .907 .98 r
.50555 .40176 .5127 .40469 .5257 .39902 .51861 .3963 Mtetra
.531 .871 .991 r
.51861 .3963 .5257 .39902 .53876 .39674 .53173 .3928 Mtetra
0 .435 .796 r
.53173 .3928 .53876 .39674 .552 .40557 .54496 .39732 Mtetra
0 0 .462 r
.54496 .39732 .552 .40557 .56556 .42712 .55845 .41308 Mtetra
0 .175 .709 r
.55845 .41308 .56556 .42712 .57932 .44358 .57215 .42722 Mtetra
.656 .603 .783 r
.57215 .42722 .57932 .44358 .5928 .43533 .5857 .42152 Mtetra
.84 .707 .716 r
.5857 .42152 .5928 .43533 .6059 .41058 .59895 .40022 Mtetra
.86 .757 .747 r
.59895 .40022 .6059 .41058 .61901 .38974 .61217 .38105 Mtetra
.792 .78 .841 r
.61217 .38105 .61901 .38974 .63238 .37857 .6256 .37025 Mtetra
.7 .766 .903 r
.6256 .37025 .63238 .37857 .64594 .37249 .63922 .36418 Mtetra
.663 .754 .918 r
.63922 .36418 .64594 .37249 .65962 .36776 .65294 .3594 Mtetra
.656 .752 .92 r
.65294 .3594 .65962 .36776 .67337 .36322 .66673 .35483 Mtetra
.656 .751 .92 r
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Mtetra
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .48701 Mtetra
.23653 .48701 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Mtetra
.29656 .46707 .30436 .47448 .3165 .47048 .30873 .46303 Mtetra
.655 .751 .921 r
.30873 .46303 .3165 .47048 .32869 .46647 .32096 .45899 Mtetra
.649 .749 .923 r
.32096 .45899 .32869 .46647 .34093 .46266 .33323 .45511 Mtetra
.607 .735 .936 r
.33323 .45511 .34093 .46266 .35316 .46013 .3455 .45232 Mtetra
.406 .643 .953 r
.3455 .45232 .35316 .46013 .36523 .46223 .35764 .45341 Mtetra
0 .303 .792 r
.35764 .45341 .36523 .46223 .37703 .47257 .36956 .46118 Mtetra
0 .268 .775 r
.36956 .46118 .37703 .47257 .38892 .48498 .38156 .47051 Mtetra
.606 .595 .813 r
.38156 .47051 .38892 .48498 .40156 .48201 .3942 .4678 Mtetra
.805 .681 .728 r
.3942 .4678 .40156 .48201 .41493 .45947 .40745 .45011 Mtetra
.856 .752 .747 r
.40745 .45011 .41493 .45947 .42826 .43534 .4207 .43107 Mtetra
.83 .874 .876 r
.4207 .43107 .42826 .43534 .44121 .42234 .43366 .42005 Mtetra
.64 .916 .98 r
.43366 .42005 .44121 .42234 .45397 .41737 .44649 .41475 Mtetra
.561 .882 .991 r
.44649 .41475 .45397 .41737 .46675 .41439 .45935 .41087 Mtetra
.596 .869 .993 r
.45935 .41087 .46675 .41439 .47961 .41099 .47227 .40688 Mtetra
.623 .86 .988 r
.47227 .40688 .47961 .41099 .49255 .40679 .48526 .40263 Mtetra
.635 .863 .985 r
.48526 .40263 .49255 .40679 .50555 .40176 .49832 .39811 Mtetra
.63 .879 .988 r
.49832 .39811 .50555 .40176 .51861 .3963 .51143 .39345 Mtetra
.513 .861 .992 r
.51143 .39345 .51861 .3963 .53173 .3928 .52461 .39024 Mtetra
0 .521 .802 r
.52461 .39024 .53173 .3928 .54496 .39732 .53788 .39282 Mtetra
.501 0 0 r
.53788 .39282 .54496 .39732 .55845 .41308 .55135 .40342 Mtetra
0 .313 .803 r
.55135 .40342 .55845 .41308 .57215 .42722 .56498 .41249 Mtetra
.671 .631 .801 r
.56498 .41249 .57215 .42722 .5857 .42152 .57854 .40633 Mtetra
.809 .684 .726 r
.57854 .40633 .5857 .42152 .59895 .40022 .5919 .38805 Mtetra
.823 .724 .756 r
.5919 .38805 .59895 .40022 .61217 .38105 .60525 .37145 Mtetra
.768 .756 .842 r
.60525 .37145 .61217 .38105 .6256 .37025 .61876 .36164 Mtetra
.693 .758 .901 r
.61876 .36164 .6256 .37025 .63922 .36418 .63243 .35576 Mtetra
.662 .753 .918 r
.63243 .35576 .63922 .36418 .65294 .3594 .6462 .35097 Mtetra
.656 .752 .92 r
.6462 .35097 .65294 .3594 .66673 .35483 .66004 .34636 Mtetra
.656 .751 .92 r
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Mtetra
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .48701 .2285 .4797 Mtetra
.2285 .4797 .23653 .48701 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45552 Mtetra
.655 .751 .92 r
.3009 .45552 .30873 .46303 .32096 .45899 .31316 .45143 Mtetra
.651 .75 .922 r
.31316 .45143 .32096 .45899 .33323 .45511 .32547 .44746 Mtetra
.623 .739 .931 r
.32547 .44746 .33323 .45511 .3455 .45232 .3378 .44426 Mtetra
.496 .679 .947 r
.3378 .44426 .3455 .45232 .35764 .45341 .35003 .44389 Mtetra
.193 .475 .892 r
.35003 .44389 .35764 .45341 .36956 .46118 .3621 .44874 Mtetra
.164 .383 .83 r
.3621 .44874 .36956 .46118 .38156 .47051 .37418 .45583 Mtetra
.549 .564 .821 r
.37418 .45583 .38156 .47051 .3942 .4678 .38674 .45529 Mtetra
.772 .692 .775 r
.38674 .45529 .3942 .4678 .40745 .45011 .39982 .44309 Mtetra
.855 .798 .794 r
.39982 .44309 .40745 .45011 .4207 .43107 .41302 .4276 Mtetra
.834 .897 .885 r
.41302 .4276 .4207 .43107 .43366 .42005 .42606 .41656 Mtetra
.717 .899 .961 r
.42606 .41656 .43366 .42005 .44649 .41475 .43898 .41001 Mtetra
.65 .847 .976 r
.43898 .41001 .44649 .41475 .45935 .41087 .45191 .40541 Mtetra
.637 .821 .971 r
.45191 .40541 .45935 .41087 .47227 .40688 .46488 .40126 Mtetra
.638 .817 .969 r
.46488 .40126 .47227 .40688 .48526 .40263 .47792 .3971 Mtetra
.638 .821 .971 r
.47792 .3971 .48526 .40263 .49832 .39811 .49102 .39288 Mtetra
.616 .825 .981 r
.49102 .39288 .49832 .39811 .51143 .39345 .50418 .38905 Mtetra
.491 .805 1 r
.50418 .38905 .51143 .39345 .52461 .39024 .51741 .38703 Mtetra
.033 .563 .858 r
.51741 .38703 .52461 .39024 .53788 .39282 .53073 .38942 Mtetra
.334 0 0 r
.53073 .38942 .53788 .39282 .55135 .40342 .5442 .39623 Mtetra
.233 .575 .942 r
.5442 .39623 .55135 .40342 .56498 .41249 .55779 .39946 Mtetra
.722 .678 .807 r
.55779 .39946 .56498 .41249 .57854 .40633 .57134 .39083 Mtetra
.789 .674 .737 r
.57134 .39083 .57854 .40633 .5919 .38805 .58479 .37474 Mtetra
.785 .698 .769 r
.58479 .37474 .5919 .38805 .60525 .37145 .59826 .36111 Mtetra
.737 .733 .847 r
.59826 .36111 .60525 .37145 .61876 .36164 .61186 .35275 Mtetra
.682 .749 .902 r
.61186 .35275 .61876 .36164 .63243 .35576 .62559 .34722 Mtetra
.66 .751 .917 r
.62559 .34722 .63243 .35576 .6462 .35097 .6394 .34246 Mtetra
.656 .751 .92 r
.6394 .34246 .6462 .35097 .66004 .34636 .65329 .33781 Mtetra
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.28076 .45205 .28869 .45959 .3009 .45552 .293 .44794 Mtetra
.293 .44794 .3009 .45552 .31316 .45143 .30529 .44381 Mtetra
.653 .75 .921 r
.30529 .44381 .31316 .45143 .32547 .44746 .31764 .43974 Mtetra
.638 .744 .925 r
.31764 .43974 .32547 .44746 .3378 .44426 .33003 .43608 Mtetra
.571 .709 .935 r
.33003 .43608 .3378 .44426 .35003 .44389 .34237 .43416 Mtetra
.401 .589 .919 r
.34237 .43416 .35003 .44389 .3621 .44874 .3546 .43601 Mtetra
.297 .459 .853 r
.3546 .43601 .3621 .44874 .37418 .45583 .36677 .441 Mtetra
.471 .52 .827 r
.36677 .441 .37418 .45583 .38674 .45529 .37922 .44288 Mtetra
.695 .668 .819 r
.37922 .44288 .38674 .45529 .39982 .44309 .39212 .43623 Mtetra
.82 .806 .838 r
.39212 .43623 .39982 .44309 .41302 .4276 .40525 .42435 Mtetra
.825 .907 .896 r
.40525 .42435 .41302 .4276 .42606 .41656 .41834 .41378 Mtetra
.736 .923 .954 r
.41834 .41378 .42606 .41656 .43898 .41001 .43135 .40645 Mtetra
.667 .89 .979 r
.43135 .40645 .43898 .41001 .45191 .40541 .44435 .40104 Mtetra
.643 .86 .982 r
.44435 .40104 .45191 .40541 .46488 .40126 .45739 .3964 Mtetra
.629 .841 .981 r
.45739 .3964 .46488 .40126 .47792 .3971 .47048 .39218 Mtetra
.609 .834 .986 r
.47048 .39218 .47792 .3971 .49102 .39288 .48363 .38838 Mtetra
.554 .829 .997 r
.48363 .38838 .49102 .39288 .50418 .38905 .49684 .38539 Mtetra
.373 .771 .986 r
.49684 .38539 .50418 .38905 .51741 .38703 .51012 .38444 Mtetra
0 .542 .816 r
.51012 .38444 .51741 .38703 .53073 .38942 .52349 .38674 Mtetra
0 .502 .79 r
.52349 .38674 .53073 .38942 .5442 .39623 .53698 .38965 Mtetra
.595 .782 .969 r
.53698 .38965 .5442 .39623 .55779 .39946 .55056 .38647 Mtetra
.763 .695 .787 r
.55056 .38647 .55779 .39946 .57134 .39083 .56411 .37493 Mtetra
.766 .661 .747 r
.56411 .37493 .57134 .39083 .58479 .37474 .57763 .36101 Mtetra
.744 .679 .788 r
.57763 .36101 .58479 .37474 .59826 .36111 .5912 .35052 Mtetra
.704 .718 .86 r
.5912 .35052 .59826 .36111 .61186 .35275 .60489 .34374 Mtetra
.67 .743 .905 r
.60489 .34374 .61186 .35275 .62559 .34722 .61868 .3386 Mtetra
.658 .75 .918 r
.61868 .3386 .62559 .34722 .6394 .34246 .63254 .33387 Mtetra
.656 .751 .92 r
.63254 .33387 .6394 .34246 .65329 .33781 .64648 .32919 Mtetra
.64648 .32919 .65329 .33781 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Mtetra
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Mtetra
.655 .751 .921 r
.29736 .43613 .30529 .44381 .31764 .43974 .30975 .43197 Mtetra
.649 .748 .922 r
.30975 .43197 .31764 .43974 .33003 .43608 .32218 .42797 Mtetra
.62 .73 .925 r
.32218 .42797 .33003 .43608 .34237 .43416 .33463 .42477 Mtetra
.537 .665 .919 r
.33463 .42477 .34237 .43416 .3546 .43601 .34702 .42379 Mtetra
.427 .545 .873 r
.34702 .42379 .3546 .43601 .36677 .441 .35934 .42596 Mtetra
.429 .495 .825 r
.35934 .42596 .36677 .441 .37922 .44288 .37172 .42894 Mtetra
.564 .586 .834 r
.37172 .42894 .37922 .44288 .39212 .43623 .38441 .42771 Mtetra
.73 .758 .875 r
.38441 .42771 .39212 .43623 .40525 .42435 .39741 .42045 Mtetra
.808 .891 .904 r
.39741 .42045 .40525 .42435 .41834 .41378 .41055 .41062 Mtetra
.775 .915 .934 r
.41055 .41062 .41834 .41378 .43135 .40645 .42366 .40212 Mtetra
.708 .876 .96 r
.42366 .40212 .43135 .40645 .44435 .40104 .43674 .39588 Mtetra
.657 .84 .97 r
.43674 .39588 .44435 .40104 .45739 .3964 .44983 .39109 Mtetra
.625 .827 .978 r
.44983 .39109 .45739 .3964 .47048 .39218 .46297 .38703 Mtetra
.585 .82 .988 r
.46297 .38703 .47048 .39218 .48363 .38838 .47616 .38372 Mtetra
.475 .792 .999 r
.47616 .38372 .48363 .38838 .49684 .38539 .48941 .382 Mtetra
.197 .675 .933 r
.48941 .382 .49684 .38539 .51012 .38444 .50273 .38276 Mtetra
.007 .573 .793 r
.50273 .38276 .51012 .38444 .52349 .38674 .51615 .38408 Mtetra
.492 .861 .986 r
.51615 .38408 .52349 .38674 .53698 .38965 .52969 .38081 Mtetra
.775 .775 .853 r
.52969 .38081 .53698 .38965 .55056 .38647 .54326 .37093 Mtetra
.755 .661 .758 r
.54326 .37093 .55056 .38647 .56411 .37493 .55683 .3584 Mtetra
.725 .638 .76 r
.55683 .3584 .56411 .37493 .57763 .36101 .57043 .34779 Mtetra
.701 .67 .816 r
.57043 .34779 .57763 .36101 .5912 .35052 .5841 .34032 Mtetra
.677 .718 .88 r
.5841 .34032 .5912 .35052 .60489 .34374 .59786 .33479 Mtetra
.661 .744 .911 r
.59786 .33479 .60489 .34374 .61868 .3386 .6117 .32993 Mtetra
.657 .75 .919 r
.6117 .32993 .61868 .3386 .63254 .33387 .62562 .32521 Mtetra
.656 .751 .92 r
.62562 .32521 .63254 .33387 .64648 .32919 .6396 .32048 Mtetra
.6396 .32048 .64648 .32919 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Mtetra
.28935 .42838 .29736 .43613 .30975 .43197 .30178 .42417 Mtetra
.654 .75 .921 r
.30178 .42417 .30975 .43197 .32218 .42797 .31426 .41998 Mtetra
.645 .744 .921 r
.31426 .41998 .32218 .42797 .33463 .42477 .32678 .41603 Mtetra
.615 .715 .916 r
.32678 .41603 .33463 .42477 .34702 .42379 .33932 .41297 Mtetra
.551 .639 .891 r
.33932 .41297 .34702 .42379 .35934 .42596 .35182 .41182 Mtetra
.49 .544 .839 r
.35182 .41182 .35934 .42596 .37172 .42894 .36429 .41287 Mtetra
.489 .515 .811 r
.36429 .41287 .37172 .42894 .38441 .42771 .37685 .4143 Mtetra
.557 .593 .846 r
.37685 .4143 .38441 .42771 .39741 .42045 .38962 .4132 Mtetra
.667 .778 .933 r
.38962 .4132 .39741 .42045 .41055 .41062 .40262 .40844 Mtetra
.704 .936 .963 r
.40262 .40844 .41055 .41062 .42366 .40212 .41575 .40155 Mtetra
.648 .955 .941 r
.41575 .40155 .42366 .40212 .43674 .39588 .42892 .39477 Mtetra
.579 .925 .957 r
.42892 .39477 .43674 .39588 .44983 .39109 .44209 .38942 Mtetra
.461 .865 .962 r
.44209 .38942 .44983 .39109 .46297 .38703 .45528 .38601 Mtetra
.195 .719 .858 r
.45528 .38601 .46297 .38703 .47616 .38372 .4685 .38493 Mtetra
.164 0 0 r
.4685 .38493 .47616 .38372 .48941 .382 .48179 .38575 Mtetra
.141 0 0 r
.48179 .38575 .48941 .382 .50273 .38276 .49521 .38444 Mtetra
.612 .955 .834 r
.49521 .38444 .50273 .38276 .51615 .38408 .50876 .37583 Mtetra
.82 .795 .828 r
.50876 .37583 .51615 .38408 .52969 .38081 .52234 .36317 Mtetra
.727 .627 .747 r
.52234 .36317 .52969 .38081 .54326 .37093 .53593 .35181 Mtetra
.687 .594 .747 r
.53593 .35181 .54326 .37093 .55683 .3584 .54954 .34302 Mtetra
.676 .629 .795 r
.54954 .34302 .55683 .3584 .57043 .34779 .56322 .33631 Mtetra
.669 .689 .86 r
.56322 .33631 .57043 .34779 .5841 .34032 .57696 .33087 Mtetra
.661 .732 .902 r
.57696 .33087 .5841 .34032 .59786 .33479 .59078 .32597 Mtetra
.657 .748 .917 r
.59078 .32597 .59786 .33479 .6117 .32993 .60467 .32121 Mtetra
.656 .751 .92 r
.60467 .32121 .6117 .32993 .62562 .32521 .61863 .31646 Mtetra
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Mtetra
.28128 .42057 .28935 .42838 .30178 .42417 .29374 .41631 Mtetra
.655 .751 .92 r
.29374 .41631 .30178 .42417 .31426 .41998 .30626 .41204 Mtetra
.654 .749 .92 r
.30626 .41204 .31426 .41998 .32678 .41603 .31884 .4078 Mtetra
.647 .74 .918 r
.31884 .4078 .32678 .41603 .33932 .41297 .33146 .40376 Mtetra
.626 .709 .906 r
.33146 .40376 .33932 .41297 .35182 .41182 .34411 .40034 Mtetra
.589 .644 .873 r
.34411 .40034 .35182 .41182 .36429 .41287 .35676 .3981 Mtetra
.552 .569 .825 r
.35676 .3981 .36429 .41287 .37685 .4143 .36943 .39722 Mtetra
.537 .53 .795 r
.36943 .39722 .37685 .4143 .38962 .4132 .38215 .39701 Mtetra
.55 .549 .806 r
.38215 .39701 .38962 .4132 .40262 .40844 .39499 .39626 Mtetra
.583 .631 .865 r
.39499 .39626 .40262 .40844 .41575 .40155 .40798 .39418 Mtetra
.61 .76 .951 r
.40798 .39418 .41575 .40155 .42892 .39477 .42108 .39089 Mtetra
.577 .858 .996 r
.42108 .39089 .42892 .39477 .44209 .38942 .43427 .38715 Mtetra
.52 .88 .982 r
.43427 .38715 .44209 .38942 .45528 .38601 .44753 .38335 Mtetra
.577 .893 .987 r
.44753 .38335 .45528 .38601 .4685 .38493 .46087 .3789 Mtetra
.748 .841 .921 r
.46087 .3789 .4685 .38493 .48179 .38575 .47433 .3712 Mtetra
.763 .675 .765 r
.47433 .3712 .48179 .38575 .49521 .38444 .48789 .35853 Mtetra
.671 .54 .697 r
.48789 .35853 .49521 .38444 .50876 .37583 .50143 .34836 Mtetra
.622 .503 .697 r
.50143 .34836 .50876 .37583 .52234 .36317 .51498 .34218 Mtetra
.631 .548 .743 r
.51498 .34218 .52234 .36317 .53593 .35181 .52858 .3368 Mtetra
.648 .621 .809 r
.52858 .3368 .53593 .35181 .54954 .34302 .54224 .33168 Mtetra
.657 .688 .867 r
.54224 .33168 .54954 .34302 .56322 .33631 .55597 .32676 Mtetra
.658 .729 .902 r
.55597 .32676 .56322 .33631 .57696 .33087 .56977 .32196 Mtetra
.656 .746 .916 r
.56977 .32196 .57696 .33087 .59078 .32597 .58363 .3172 Mtetra
.656 .75 .919 r
.58363 .3172 .59078 .32597 .60467 .32121 .59757 .31243 Mtetra
.656 .751 .92 r
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Mtetra
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Mtetra
.28563 .40839 .29374 .41631 .30626 .41204 .29819 .40408 Mtetra
.29819 .40408 .30626 .41204 .31884 .4078 .3108 .39974 Mtetra
.655 .749 .92 r
.3108 .39974 .31884 .4078 .33146 .40376 .32348 .39542 Mtetra
.651 .742 .916 r
.32348 .39542 .33146 .40376 .34411 .40034 .3362 .39119 Mtetra
.642 .719 .904 r
.3362 .39119 .34411 .40034 .35676 .3981 .34898 .38722 Mtetra
.625 .674 .877 r
.34898 .38722 .35676 .3981 .36943 .39722 .36179 .38373 Mtetra
.607 .618 .836 r
.36179 .38373 .36943 .39722 .38215 .39701 .37465 .38075 Mtetra
.595 .573 .799 r
.37465 .38075 .38215 .39701 .39499 .39626 .38757 .37808 Mtetra
.594 .551 .776 r
.38757 .37808 .39499 .39626 .40798 .39418 .40057 .37531 Mtetra
.603 .549 .767 r
.40057 .37531 .40798 .39418 .42108 .39089 .41367 .372 Mtetra
.619 .558 .764 r
.41367 .372 .42108 .39089 .43427 .38715 .42687 .36778 Mtetra
.637 .564 .756 r
.42687 .36778 .43427 .38715 .44753 .38335 .44016 .36237 Mtetra
.652 .559 .738 r
.44016 .36237 .44753 .38335 .46087 .3789 .45355 .35556 Mtetra
.654 .545 .718 r
.45355 .35556 .46087 .3789 .47433 .3712 .467 .34784 Mtetra
.637 .535 .722 r
.467 .34784 .47433 .3712 .48789 .35853 .48047 .34146 Mtetra
.633 .587 .785 r
.48047 .34146 .48789 .35853 .50143 .34836 .49397 .33671 Mtetra
.65 .678 .863 r
.49397 .33671 .50143 .34836 .51498 .34218 .50754 .33204 Mtetra
.653 .713 .891 r
.50754 .33204 .51498 .34218 .52858 .3368 .52118 .32738 Mtetra
.655 .731 .905 r
.52118 .32738 .52858 .3368 .54224 .33168 .53489 .32267 Mtetra
.656 .743 .914 r
.53489 .32267 .54224 .33168 .55597 .32676 .54866 .31793 Mtetra
.656 .749 .918 r
.54866 .31793 .55597 .32676 .56977 .32196 .56251 .31317 Mtetra
.656 .751 .92 r
.56251 .31317 .56977 .32196 .58363 .3172 .57642 .30838 Mtetra
.57642 .30838 .58363 .3172 .59757 .31243 .5904 .30357 Mtetra
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Mtetra
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Mtetra
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .40041 Mtetra
.27745 .40041 .28563 .40839 .29819 .40408 .29004 .39605 Mtetra
.29004 .39605 .29819 .40408 .3108 .39974 .30269 .39167 Mtetra
.30269 .39167 .3108 .39974 .32348 .39542 .31541 .38728 Mtetra
.655 .75 .92 r
.31541 .38728 .32348 .39542 .3362 .39119 .32818 .38287 Mtetra
.654 .746 .917 r
.32818 .38287 .3362 .39119 .34898 .38722 .34101 .37847 Mtetra
.652 .735 .91 r
.34101 .37847 .34898 .38722 .36179 .38373 .35391 .37412 Mtetra
.647 .714 .896 r
.35391 .37412 .36179 .38373 .37465 .38075 .36685 .36988 Mtetra
.641 .684 .875 r
.36685 .36988 .37465 .38075 .38757 .37808 .37986 .36574 Mtetra
.637 .655 .85 r
.37986 .36574 .38757 .37808 .40057 .37531 .39294 .3616 Mtetra
.637 .632 .829 r
.39294 .3616 .40057 .37531 .41367 .372 .40609 .35728 Mtetra
.64 .619 .813 r
.40609 .35728 .41367 .372 .42687 .36778 .41931 .35266 Mtetra
.645 .616 .806 r
.41931 .35266 .42687 .36778 .44016 .36237 .43261 .3477 Mtetra
.651 .626 .812 r
.43261 .3477 .44016 .36237 .45355 .35556 .44597 .34254 Mtetra
.655 .654 .837 r
.44597 .34254 .45355 .35556 .467 .34784 .4594 .33746 Mtetra
.655 .707 .885 r
.4594 .33746 .467 .34784 .48047 .34146 .47288 .33274 Mtetra
.654 .748 .918 r
.47288 .33274 .48047 .34146 .49397 .33671 .48642 .32811 Mtetra
.655 .752 .921 r
.48642 .32811 .49397 .33671 .50754 .33204 .50004 .32342 Mtetra
.656 .753 .921 r
.50004 .32342 .50754 .33204 .52118 .32738 .51372 .31866 Mtetra
.656 .752 .92 r
.51372 .31866 .52118 .32738 .53489 .32267 .52747 .3139 Mtetra
.656 .751 .92 r
.52747 .3139 .53489 .32267 .54866 .31793 .54129 .30912 Mtetra
.54129 .30912 .54866 .31793 .56251 .31317 .55518 .30431 Mtetra
.55518 .30431 .56251 .31317 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Mtetra
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Mtetra
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .40041 .2692 .39235 Mtetra
.2692 .39235 .27745 .40041 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Mtetra
.29451 .38353 .30269 .39167 .31541 .38728 .30726 .3791 Mtetra
.30726 .3791 .31541 .38728 .32818 .38287 .32007 .37464 Mtetra
.32007 .37464 .32818 .38287 .34101 .37847 .33295 .37016 Mtetra
.656 .75 .919 r
.33295 .37016 .34101 .37847 .35391 .37412 .34588 .36567 Mtetra
.656 .747 .917 r
.34588 .36567 .35391 .37412 .36685 .36988 .35888 .36114 Mtetra
.656 .741 .912 r
.35888 .36114 .36685 .36988 .37986 .36574 .37195 .35658 Mtetra
.655 .731 .905 r
.37195 .35658 .37986 .36574 .39294 .3616 .38508 .35201 Mtetra
.654 .722 .898 r
.38508 .35201 .39294 .3616 .40609 .35728 .39827 .34744 Mtetra
.654 .716 .894 r
.39827 .34744 .40609 .35728 .41931 .35266 .41152 .34282 Mtetra
.655 .718 .895 r
.41152 .34282 .41931 .35266 .43261 .3477 .42485 .33815 Mtetra
.656 .726 .901 r
.42485 .33815 .43261 .3477 .44597 .34254 .43824 .33347 Mtetra
.655 .739 .911 r
.43824 .33347 .44597 .34254 .4594 .33746 .45169 .32881 Mtetra
.656 .751 .92 r
.45169 .32881 .4594 .33746 .47288 .33274 .46521 .3241 Mtetra
.656 .752 .921 r
.46521 .3241 .47288 .33274 .48642 .32811 .4788 .31935 Mtetra
.655 .75 .92 r
.4788 .31935 .48642 .32811 .50004 .32342 .49246 .31462 Mtetra
.49246 .31462 .50004 .32342 .51372 .31866 .50619 .30985 Mtetra
.656 .751 .92 r
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Mtetra
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Mtetra
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36182 Mtetra
.32481 .36182 .33295 .37016 .34588 .36567 .33778 .35728 Mtetra
.655 .751 .92 r
.33778 .35728 .34588 .36567 .35888 .36114 .35082 .35273 Mtetra
.655 .751 .921 r
.35082 .35273 .35888 .36114 .37195 .35658 .36392 .34817 Mtetra
.655 .752 .921 r
.36392 .34817 .37195 .35658 .38508 .35201 .37709 .34358 Mtetra
.656 .753 .921 r
.37709 .34358 .38508 .35201 .39827 .34744 .39032 .33895 Mtetra
.39032 .33895 .39827 .34744 .41152 .34282 .40362 .33429 Mtetra
.40362 .33429 .41152 .34282 .42485 .33815 .41698 .32961 Mtetra
.655 .753 .922 r
.41698 .32961 .42485 .33815 .43824 .33347 .43041 .32492 Mtetra
.656 .754 .922 r
.43041 .32492 .43824 .33347 .45169 .32881 .44391 .32019 Mtetra
.44391 .32019 .45169 .32881 .46521 .3241 .45748 .31542 Mtetra
.656 .753 .921 r
.45748 .31542 .46521 .3241 .4788 .31935 .47111 .31063 Mtetra
.657 .754 .921 r
.47111 .31063 .4788 .31935 .49246 .31462 .48482 .3058 Mtetra
.656 .752 .921 r
.48482 .3058 .49246 .31462 .50619 .30985 .49859 .30097 Mtetra
.656 .751 .92 r
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Mtetra
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36182 .31659 .35342 Mtetra
.656 .752 .92 r
.31659 .35342 .32481 .36182 .33778 .35728 .32961 .34884 Mtetra
.32961 .34884 .33778 .35728 .35082 .35273 .34268 .34422 Mtetra
.656 .751 .92 r
.34268 .34422 .35082 .35273 .36392 .34817 .35583 .33957 Mtetra
.656 .75 .919 r
.35583 .33957 .36392 .34817 .37709 .34358 .36904 .33489 Mtetra
.656 .748 .918 r
.36904 .33489 .37709 .34358 .39032 .33895 .38231 .33022 Mtetra
.38231 .33022 .39032 .33895 .40362 .33429 .39565 .32552 Mtetra
.656 .749 .918 r
.39565 .32552 .40362 .33429 .41698 .32961 .40905 .32079 Mtetra
.656 .748 .918 r
.40905 .32079 .41698 .32961 .43041 .32492 .42253 .31603 Mtetra
.656 .748 .917 r
.42253 .31603 .43041 .32492 .44391 .32019 .43607 .31125 Mtetra
.655 .747 .917 r
.43607 .31125 .44391 .32019 .45748 .31542 .44968 .30646 Mtetra
.655 .748 .918 r
.44968 .30646 .45748 .31542 .47111 .31063 .46335 .30168 Mtetra
.655 .749 .919 r
.46335 .30168 .47111 .31063 .48482 .3058 .4771 .29687 Mtetra
.656 .751 .92 r
.4771 .29687 .48482 .3058 .49859 .30097 .49091 .292 Mtetra
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Mtetra
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.3083 .34494 .31659 .35342 .32961 .34884 .32136 .34031 Mtetra
.655 .751 .92 r
.32136 .34031 .32961 .34884 .34268 .34422 .33447 .33567 Mtetra
.655 .752 .921 r
.33447 .33567 .34268 .34422 .35583 .33957 .34765 .33101 Mtetra
.655 .753 .922 r
.34765 .33101 .35583 .33957 .36904 .33489 .3609 .32633 Mtetra
.656 .754 .922 r
.3609 .32633 .36904 .33489 .38231 .33022 .37422 .32162 Mtetra
.37422 .32162 .38231 .33022 .39565 .32552 .3876 .31687 Mtetra
.3876 .31687 .39565 .32552 .40905 .32079 .40104 .31211 Mtetra
.655 .754 .922 r
.40104 .31211 .40905 .32079 .42253 .31603 .41456 .30733 Mtetra
.655 .755 .923 r
.41456 .30733 .42253 .31603 .43607 .31125 .42814 .30253 Mtetra
.656 .755 .923 r
.42814 .30253 .43607 .31125 .44968 .30646 .4418 .29768 Mtetra
.657 .755 .922 r
.4418 .29768 .44968 .30646 .46335 .30168 .45552 .29278 Mtetra
.657 .753 .921 r
.45552 .29278 .46335 .30168 .4771 .29687 .46931 .28787 Mtetra
.656 .752 .92 r
.46931 .28787 .4771 .29687 .49091 .292 .48317 .28295 Mtetra
.656 .751 .92 r
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Mtetra
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Mtetra
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Mtetra
.656 .752 .92 r
.31303 .33171 .32136 .34031 .33447 .33567 .32619 .32701 Mtetra
.656 .751 .92 r
.32619 .32701 .33447 .33567 .34765 .33101 .33941 .32228 Mtetra
.656 .75 .919 r
.33941 .32228 .34765 .33101 .3609 .32633 .3527 .31753 Mtetra
.656 .749 .919 r
.3527 .31753 .3609 .32633 .37422 .32162 .36605 .31276 Mtetra
.36605 .31276 .37422 .32162 .3876 .31687 .37948 .30797 Mtetra
.37948 .30797 .3876 .31687 .40104 .31211 .39297 .30316 Mtetra
.39297 .30316 .40104 .31211 .41456 .30733 .40652 .29831 Mtetra
.656 .749 .918 r
.40652 .29831 .41456 .30733 .42814 .30253 .42015 .29345 Mtetra
.656 .748 .918 r
.42015 .29345 .42814 .30253 .4418 .29768 .43385 .28857 Mtetra
.655 .748 .918 r
.43385 .28857 .4418 .29768 .45552 .29278 .44761 .28369 Mtetra
.655 .75 .92 r
.44761 .28369 .45552 .29278 .46931 .28787 .46145 .27877 Mtetra
.656 .751 .92 r
.46145 .27877 .46931 .28787 .48317 .28295 .47535 .27382 Mtetra
.656 .752 .92 r
.47535 .27382 .48317 .28295 .4971 .27801 .48933 .26883 Mtetra
.656 .751 .92 r
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Mtetra
.30463 .32303 .31303 .33171 .32619 .32701 .31782 .3183 Mtetra
.655 .752 .921 r
.31782 .3183 .32619 .32701 .33941 .32228 .33108 .31355 Mtetra
.33108 .31355 .33941 .32228 .3527 .31753 .34441 .30878 Mtetra
.656 .753 .922 r
.34441 .30878 .3527 .31753 .36605 .31276 .35781 .30397 Mtetra
.35781 .30397 .36605 .31276 .37948 .30797 .37127 .29914 Mtetra
.37127 .29914 .37948 .30797 .39297 .30316 .38481 .29429 Mtetra
.38481 .29429 .39297 .30316 .40652 .29831 .39841 .28941 Mtetra
.656 .754 .922 r
.39841 .28941 .40652 .29831 .42015 .29345 .41208 .28452 Mtetra
.41208 .28452 .42015 .29345 .43385 .28857 .42582 .27958 Mtetra
.657 .754 .922 r
.42582 .27958 .43385 .28857 .44761 .28369 .43963 .2746 Mtetra
.656 .753 .921 r
.43963 .2746 .44761 .28369 .46145 .27877 .45351 .2696 Mtetra
.656 .751 .92 r
.45351 .2696 .46145 .27877 .47535 .27382 .46746 .26459 Mtetra
.46746 .26459 .47535 .27382 .48933 .26883 .48148 .25956 Mtetra
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Mtetra
.656 .752 .92 r
.29615 .31427 .30463 .32303 .31782 .3183 .30938 .30948 Mtetra
.656 .751 .92 r
.30938 .30948 .31782 .3183 .33108 .31355 .32269 .30466 Mtetra
.656 .751 .919 r
.32269 .30466 .33108 .31355 .34441 .30878 .33606 .29983 Mtetra
.656 .75 .919 r
.33606 .29983 .34441 .30878 .35781 .30397 .34949 .29497 Mtetra
.34949 .29497 .35781 .30397 .37127 .29914 .363 .2901 Mtetra
.363 .2901 .37127 .29914 .38481 .29429 .37657 .28519 Mtetra
.37657 .28519 .38481 .29429 .39841 .28941 .39022 .28026 Mtetra
.39022 .28026 .39841 .28941 .41208 .28452 .40393 .2753 Mtetra
.656 .749 .919 r
.40393 .2753 .41208 .28452 .42582 .27958 .41772 .27033 Mtetra
.655 .749 .919 r
.41772 .27033 .42582 .27958 .43963 .2746 .43157 .26535 Mtetra
.655 .75 .92 r
.43157 .26535 .43963 .2746 .45351 .2696 .4455 .26033 Mtetra
.656 .751 .92 r
.4455 .26033 .45351 .2696 .46746 .26459 .45949 .25528 Mtetra
.656 .752 .92 r
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Mtetra
.656 .751 .92 r
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Mtetra
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Mtetra
.28759 .30542 .29615 .31427 .30938 .30948 .30086 .3006 Mtetra
.655 .752 .921 r
.30086 .3006 .30938 .30948 .32269 .30466 .31421 .29577 Mtetra
.656 .752 .921 r
.31421 .29577 .32269 .30466 .33606 .29983 .32762 .2909 Mtetra
.656 .753 .921 r
.32762 .2909 .33606 .29983 .34949 .29497 .3411 .28601 Mtetra
.3411 .28601 .34949 .29497 .363 .2901 .35464 .28108 Mtetra
.35464 .28108 .363 .2901 .37657 .28519 .36826 .27613 Mtetra
.36826 .27613 .37657 .28519 .39022 .28026 .38195 .27116 Mtetra
.656 .753 .922 r
.38195 .27116 .39022 .28026 .40393 .2753 .39571 .26617 Mtetra
.39571 .26617 .40393 .2753 .41772 .27033 .40953 .26114 Mtetra
.656 .753 .921 r
.40953 .26114 .41772 .27033 .43157 .26535 .42343 .25607 Mtetra
.656 .752 .921 r
.42343 .25607 .43157 .26535 .4455 .26033 .43741 .25098 Mtetra
.656 .751 .92 r
.43741 .25098 .4455 .26033 .45949 .25528 .45145 .24588 Mtetra
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Mtetra
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Mtetra
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Mtetra
.656 .752 .92 r
.27895 .2965 .28759 .30542 .30086 .3006 .29226 .29162 Mtetra
.656 .751 .92 r
.29226 .29162 .30086 .3006 .31421 .29577 .30565 .28672 Mtetra
.30565 .28672 .31421 .29577 .32762 .2909 .3191 .28179 Mtetra
.656 .75 .919 r
.3191 .28179 .32762 .2909 .3411 .28601 .33262 .27684 Mtetra
.33262 .27684 .3411 .28601 .35464 .28108 .34621 .27188 Mtetra
.34621 .27188 .35464 .28108 .36826 .27613 .35987 .26688 Mtetra
.35987 .26688 .36826 .27613 .38195 .27116 .3736 .26186 Mtetra
.3736 .26186 .38195 .27116 .39571 .26617 .38741 .2568 Mtetra
.38741 .2568 .39571 .26617 .40953 .26114 .40128 .25174 Mtetra
.655 .75 .919 r
.40128 .25174 .40953 .26114 .42343 .25607 .41522 .24665 Mtetra
.655 .751 .92 r
.41522 .24665 .42343 .25607 .43741 .25098 .42924 .24154 Mtetra
.656 .751 .92 r
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Mtetra
.656 .752 .92 r
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Mtetra
.656 .751 .92 r
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Mtetra
.27023 .28749 .27895 .2965 .29226 .29162 .28358 .28258 Mtetra
.655 .751 .921 r
.28358 .28258 .29226 .29162 .30565 .28672 .29701 .27765 Mtetra
.656 .752 .921 r
.29701 .27765 .30565 .28672 .3191 .28179 .3105 .27269 Mtetra
.656 .753 .921 r
.3105 .27269 .3191 .28179 .33262 .27684 .32406 .2677 Mtetra
.32406 .2677 .33262 .27684 .34621 .27188 .3377 .26268 Mtetra
.656 .752 .921 r
.3377 .26268 .34621 .27188 .35987 .26688 .3514 .25764 Mtetra
.3514 .25764 .35987 .26688 .3736 .26186 .36518 .25257 Mtetra
.656 .753 .921 r
.36518 .25257 .3736 .26186 .38741 .2568 .37902 .24748 Mtetra
.37902 .24748 .38741 .2568 .40128 .25174 .39294 .24235 Mtetra
.39294 .24235 .40128 .25174 .41522 .24665 .40693 .23719 Mtetra
.656 .752 .921 r
.40693 .23719 .41522 .24665 .42924 .24154 .42099 .23201 Mtetra
.656 .751 .92 r
.42099 .23201 .42924 .24154 .44333 .23639 .43513 .2268 Mtetra
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Mtetra
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .2784 Mtetra
.656 .752 .92 r
.26142 .2784 .27023 .28749 .28358 .28258 .27482 .27343 Mtetra
.656 .751 .92 r
.27482 .27343 .28358 .28258 .29701 .27765 .28829 .26843 Mtetra
.28829 .26843 .29701 .27765 .3105 .27269 .30183 .26341 Mtetra
.656 .75 .919 r
.30183 .26341 .3105 .27269 .32406 .2677 .31543 .25837 Mtetra
.31543 .25837 .32406 .2677 .3377 .26268 .32911 .25331 Mtetra
.656 .75 .92 r
.32911 .25331 .3377 .26268 .3514 .25764 .34285 .24822 Mtetra
.656 .75 .919 r
.34285 .24822 .3514 .25764 .36518 .25257 .35667 .24309 Mtetra
.35667 .24309 .36518 .25257 .37902 .24748 .37056 .23795 Mtetra
.37056 .23795 .37902 .24748 .39294 .24235 .38452 .23278 Mtetra
.655 .75 .92 r
.38452 .23278 .39294 .24235 .40693 .23719 .39856 .2276 Mtetra
.655 .751 .92 r
.39856 .2276 .40693 .23719 .42099 .23201 .41267 .22238 Mtetra
.656 .751 .92 r
.41267 .22238 .42099 .23201 .43513 .2268 .42685 .21713 Mtetra
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3oool30:Noje00Yl3[00<000000:O0j`2W`>/0402W`>/A0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`<000000`3oool00`000000oooo0?ooo`160?ooo`H0
Yko[C`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0:@3oool002T0oooo
0P00001;0?ooo`X0Yko[C`2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0
:03oool002H0oooo0`00001:0?ooo`T0Yko[D`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<0
00000?ooo`3oool0:03oool002@0oooo0P00001;0?ooo`X0Yko[D`2W`>/2000001D0Yl3[403oool2
000002T0oooo000Q0?ooo`<00000B`3oool:0:Noj`L0Yl3[0`2W_n]80:O0j`<000000P2W`>/00`00
0000Yl3[0:O0j`0B0:O0ja80oooo00<000000?ooo`3oool09P3oool001l0oooo0`0000190?ooo`X0
Yko[2@2W`>/60:Nojd@0Yl3[0`0000050:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000
oooo0?ooo`0V0?ooo`007@3oool2000004/0oooo1`2W_n/:0:O0j`T0Yko[@@2W`>/3000000T0Yl3[
00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`800000
0`3oool4000000X0oooo000E0?ooo`D000000`3oool2000004T0oooo1`2W_n/80:O0j`X0Yko[@@2W
`>/3000000d0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0;0?ooo`005`3oool00`000000oooo0?oo
o`030?ooo`<00000A03oool90:Noj`P0Yl3[2P2W_n/30:O0k0D0Yl3[102W_n/e0:O0j`8000004@2W
`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00X0oooo000G0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000?`3oool50:O0j`D0Yko[2@2W`>/:0:Noj`H0Yl3/0P2W`>/70:Nojc40Yl3[
0`00000C0:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo0?ooo`030?ooo`@00000
0P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00T0oooo000?0?ooo`@00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
>`3ooolA0:O0j`T0Yko[2P2W`>`90:Nojbh0Yl3[0`00000G0:O0j`030000002W`>/0Yl3[01<0Yl3[
4@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000002P3oool001L0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3o
ool0>03oool?0:O0j`X0Yko[1@2W`>/40:O0k0X0Yko[;P2W`>/3000001/0Yl3[00<000000:O0j`2W
`>/04P2W`>/@0?ooo`8000002`3oool2000000X0oooo0P00000;0?ooo`005P3oool2000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?oooa40Yl3[2P2W_n/80:O0j`T0Yko[
1@2X`N`Z0:O0j`<000007`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool0
8@3oool001`0oooo00<000000?ooo`3oool01@3oool200000300oooo4P2W`>/:0:Noj`P0Yl3[2@2W
_n/30:O1k0D0Z<7/1@2W_n/Q0:O0j`<000008P2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<0
00000?ooo`3oool0803oool001`0oooo0P0000080?ooo`030000003oool0oooo02/0oooo5P2W`>/4
0:Noj`X0Yl3[2@2W_n/60:O1k080Z<7/202W_n/M0:O0j`<000009P2W`>/00`000000Yl3[0:O0j`0B
0:O0ja40oooo00<000000?ooo`3oool0803oool001`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0X0?ooob80Yl3[2P2W_n/90:O1k0P0Yko[0`2X`>/I0:O0j`<00000:P2W`>/00`00
0000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0S0?ooob<0Yl3[2@2W_n/50:O0k0D0Yl7/2@2W_n/60:S0jaD0
Yl3[0`00000^0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0N0?ooo`00
6`3oool2000000`0oooo00<000000?ooo`3oool07`3ooolT0:O0j`L0Yko[2P2W`>`90:Noj`D0Z<7/
1@2X`>/C0:O0j`800000<@2W`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo00<000000?ooo`3oool0
7P3oool001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooobH0Yl3[202W
_n/90:O0k0P0Yko[102W`N`50:S1k0D0Yko[3`2W`>/3000003@0Yl3[00<000000:O0j`2W`>/04P2W
`>/A0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0603ooolX0:O0j`D0Yko[2@2W`>`80:Noj`L0Yl7/2P2W_n/;0:O0j`<00000>02W`>/0
0`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000O0?ooo`006`3oool2000000l0oooo00<000000?oo
o`3oool05@3oool[0:O0j`X0Yl3/2@2W_n/80:O1k080YkoZ1@2W_n/50:S1j`L0Yl3[0`00000k0:O0
j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo;`2W`>/50:O0k0T0Yko[2P2W`N`50:NojP80
Yko[0`2W`>/50:S1j`80Yl3[00@0Yko[0000000000000000?`2W`>/00`000000Yl3[0:O0j`0B0:O0
ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P0000040?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?oooc@0Yl3[2P2W_n/90:O1k0T0
YkoZ1P2W`>/40:S1j`<000000`2W_n/90:O0j`D0Yko[102W`>/50:NojbT0Yl3[00<000000:O0j`2W
`>/04P2W`>/@0?ooo`030000003oool0oooo01/0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool2000001<0oooo00<000000?ooo`3oool02P3ooold0:O0
j`L0Yko[2P2W`N`40:Noj`D0YkoZ1@2W`N`40:O0j`040:Noj`0000000000000000H0Yko[1`2W`>/3
0:Nnj@@0Yko[0P2W`>/30:NnjPD0Yko[:@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<00000
0?ooo`3oool06P3oool000L0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3o
ool0000001D0oooo00<000000?ooo`3oool01`3ooold0:O0j`P0Yko[1`2W`N`90:Noj`X0Yl7/00@0
Yl3[00000000000000001@2W_n/90:O0j`H0YkkY0`2W_n/60:NnjP80Yko[0`2X_nXX0:O0j`030000
002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0I0?ooo`0000<0oooo0000000000000P00
00020?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P3oooli0:O0j`D0Yko[1`2W`N`:0:Noj`80Yl3/1@2W`N`20:O0j`<00000
3P2W`>/40:Nki`D0YkkY102X^^H50:NnjPH0Z;oZ0P2W`>/20:Rojb@0Yl3[00<000000:O0j`2W`>/0
4P2W`>/@0?ooo`030000003oool0oooo01T0oooo00070?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool00`3oool2000001H0oooo00<000000:O0j`2W`>/0>`2W`>/50:O0k0@0Yl7/
2P2W_n/50:O0k080Yl7/0P2W_NT2000000@0Yl3[102W_n/50:O0j`D0YkKT102W^nL50:R`g@@0Z;[V
1@2Y^nH50:RojPD0Z;o[902W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000J0?ooo`00203o
ool2000000X0oooo0`0000030?ooo`030000003oool0oooo0180oooo@P2W`>/50:O0k0T0Yko[1@2W
`>/40:O0k0040:Nmj@000000000000000080YkgY0P2W`>/30:NdhP@0Yko[1@2V[M`40:Nfi0D0YIk?
1@2X/=d40:^`g0D0ZK_V1@2Y_^T40:RojbD0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000
003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo0180ooooA02W`>/:0:Noj`T0Yl3[00@0
YkWV00000000000000001@2W_NT60:NdhP80Yko[0P2RU/P50:J]g080YkKT0P2QS;h50:FNc`80Z;3M
0`2]XL/40:^`g0D0[KOQ1@2Y_^T40:Rojb@0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000
003oool0oooo01L0oooo000I0?ooo`8000004@3ooom70:O0j`D0Yko[2@2W`>/20:Ngi@<00000102W
^NH50:NWePD0YkCR102RU/P50:J]g0@0XHbn1@2UW/l60:fQb`80Zk3L0P2cZm050:fgh@D0ZkkW102X
_n/T0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0F0?ooo`006@3oool0
0`000000oooo0?ooo`0=0?oood/0Yl3[0P2W_n/80:O0j`80YkOT0`0000040:Ngi@@0YZ3?1@2WYmH5
0:>8^0@0XYK80P2V[M`309n0/P@0XHbn0`2UW/l20:nH_`D0[J7;1@2cZm020:fgh@<0];OL102[_^L5
0:S0jR@0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01D0oooo000I0?oo
o`030000003oool0oooo00T0ooooE`2W`>/0102W^>D000000000000000030:Ngi080YkOU0`2UWLh3
0:JPc`@0YjOF0P2WRkL40:>8^0@0XYK81@2OP;840:6<_P80YIk?0`2_V;l40:fQb`80^J?2102cZm06
0;Bgg080ZkkW0P2^_nH50:S0jR@0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0
oooo01D0oooo000I0?ooo`8000001`3ooomH0:O0j`<000000`2W^>D30:Ngi0D0YIg>102VX<l20:NW
eP<0Yh^g1@2SR;P20::Fb080ZhZb102OP;840:6<_PH0[iRo0P2]XL/30;VS`P<0/j_@0P2n[LT50;Bg
g0D0[[oV0P2X`>X30:W0jb<0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo
01@0oooo000I0?ooo`030000003oool0oooo00<0ooooF02W`>/3000000030:Nki`2W^>D0YkSU00<0
YkSU102SW]050:FMcP<0YZ3?1@2WRkL50:>8^0@0ZhZb1@2OP;820:6<_P80^Z2o1@2_V;l60;VS`P03
0;>[d02n[LT0_Zg90080_Zg90P2d]m`30;bkf0@0[[oV1P2Y`>/S0:O0j`030000002W`>/0Yl3[0180
Yl3[403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`030?oooeD0Yl3[
00D0YkgY00000000000000000:Nmj@040:Nki`D0Xj7D0`2SW]050:FMcP@0YXnl1@2WRkL30:>8^080
`jc30`2[R[8509n0/P040:6<_P2jX;l0^Z2o0;ZP_`@0[iRo0P31ZL850;VS`PD0_Zg91P2l^mP40;72
iPD0ZL3[902W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo0P00000E0?ooo`00603oool010000000
oooo0000003ooomD0:O0j`80YkoZ0P0000050:Nmj@@0XjOI102SXM@40:>Nd080YIg>0`2ST<430:J?
_0D0Yh^g0P2SR;P30<>/``@0ZhZb102OP;850;ZP_`80[iRo0`31ZL840;VS`P80a:Vo102n[LT00`38
//@0_;_H0;bkf0020;bkf080a<7G102a`^H50:W1jb<0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?oo
o`030000003oool0oooo00H0oooo0P00000:0?ooo`00603oool00`000000Yl3[0:O0j`1A0:O0j`<0
Yko[0`0000030:NojPD0Y:oO0`2SYmT50:>Qe0<0Xik@1@2ST<430:J?_0D0Yh^g00<0XhRh0<>/``33
[<<00P33[<<40:^:/P<0Wh2b0P3Abm<40;ZP_`030:nH_`31ZL80`JW200<0`JW20P2iXl830<BY_`<0
_Zg90`38//@20;bkf0<0a<7G1@2ca>L50:W1jb<0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool000002@3oool00140oooo0P0000050?ooo`03
0000003oool0Yl3[0540Yl3[0`0000030:Noj`@0YKKU102T[ml40:>Wf@@0Xj7D102NS/<40:>@`@@0
YXnl102WRkL60<>/``<0ZhZb0P2OP;830=7;d`@0^Z2o1P31ZL800`2iXl80a:Vo0<BY_`030<BY_`03
0;j]b@38//@0b;;40080b;;41034`ML20<[7e`D0/lCW1@2Y`N/S0:O0j`030000002W`>/0Yl3[0140
Yl3[403oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo000@0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0CP2W`>/300000080Yl3[0P2W_n/30:Jl
j0@0YKKU102T[ml30:>Wf@D0VXc40`2NS/<50:>@`@<0YXnl0P2WRkL30;oGj`D0`jc30`2[R[860=7;
d`80^Z2o0P36a]X50<6Y`PH0a:Vo1038//@20=:i`@80a<7G103:amL50;?4i`@0ZL7[902W`>/00`00
0000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000009
0?ooo`00403oool010000000oooo0?ooo`0000040?ooo`8000000P3ooom:0:O0j`<000001@2W`>/6
0:Jlj0<0YKKU102T[ml409R=aP@0VXc4102NS/<40:>@`@<0YXnl1@2oen/50<>/``80ZhZb0P2Lm=D5
0=7;d`@0a/KJ1031ZL820<>ab@@0a:Vo0P39[;`20<Rba0@0d[W11@3:amL60;?4i`@0ZL7[8`2W`>/0
0`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080ooooAP2W
`>/3000000D0Yl3[102W_^X50:Jlj0@0VikF102HT/`309R=aPD0VXc40`2NS/<40:>@`@D0TnCl102o
en/40<>/``D0W?CE1@1mg?`40<K6fP80`JW20`33/LT30<BY_`<0bJbl00<0b;;40=:i`@3B^L400`3B
^L40103L`Kl0b/OG0<[7e`3:amL20<g;f0H0/lCW102Y`N/S0:O0j`030000002W`>/0Yl3[0140Yl3[
403oool2000000@0oooo0P00000:0?ooo`00403oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00D0oooo@@2W`>/3000000D0Yl3[102W_n/40:NnjPD0WjcP0`2KW]H409RBc0@0V8g6
102JS<@309j>``H0QN7k0P0a^=/509GAo0H0SMCo101OaO`00`00R]00OMcl07gLo00207gLo0<0a/KJ
1P33/LT00`34ZKl0bJbl0<V/_0020<V/_0D0d[W10`3L`Kl00`3:amL0cL_H0<g;f0020<g;f0D0/lCW
1@2Y`N/S0:O0j`030000002W`>/0Yl3[0140Yl3[3P3oool300000100oooo000A0?ooo`800000103o
ool2000000L0oooo?@2W`>/3000000T0Yl3[102W_n/40:Bhi`@0WjcP102KW]H409RBc0<0V8g6102J
S<@509?KoP80M]gf1P2OdoX509_Eo0D0WM?k101mc_l200R@f`80083:102Hb?P50<>ab@D0bJbl00@0
cjni0=:i`@3B^L40d[W1103L`Kl40<g;f080c/cH0`2ca>L20;;4i`D0ZL7[8`2W`>/00`000000Yl3[
0:O0j`0A0:O0j`l0oooo00<000000?ooo`3oool03P3oool001L0oooo00<000000?ooo`3oool01`3o
ooli0:O0j`<000003@2W`>/40:JmjP@0Y;SW102O[>0309^NeP@0V9;<0`2HSLH609c2l`80U>cd1@2X
eoP50:7Gn`<0VmGl0P2Sd_P509gCn`80Pmcm1027g_d00`00Kl/008G=0800000309S8n080`k790`2h
[Lh30<V/_0<0cjni00<0d[W10=c1_`3L`Kl00`3L`Kl00`3SbKh0cL_H0<g;f0040<k<f0D0//CW1@2Y
`N/R0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0=0?ooo`005`3oool0
0`000000oooo0?ooo`080?ooocD0Yl3[0`00000<0:O0j`D0Yko[102V_NX40:Bhi`<0WjcP0`2KW]H5
08b<cP<0UJ7M0`2L`_<20:Gdl0<0]N3e0`2XeoP20:CLn`D0XMOk1@2Sd_P40:7Qo0@0YnSj0`27g_d2
001_b`030800000kTo40>i?a00D0^:g>0`39[;`30<n_^@D0g<6o0P3SbKh50<k<f080cLcI102ba>L5
0:W1jb<0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00`0oooo000G0?oo
o`8000002@3ooolc0:O0j`800000402W`>/50:Noj`@0X;GW102FY=l308fAd`<0RHO;102<S<h409FQ
g@80YOC`1P2eh?D50:CLn`H0Xm7h1@2Rg?`40:OXnP@0Z>_j0P28cOh00`00DLh006o;0800000203^C
l@D0^:g>00<0bJbl0<n_^@3?[kT00P3?[kT0103G];L0g<6o0=c1_`3L`Kl30>?9_P040>K=_@3>c=P0
c/cH0<k<f0@0cLcI102ba>P40:W1jb@0Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003o
ool0oooo00`0oooo000G0?ooo`030000003oool0oooo00X0oooo;P2W`>/3000001<0Yl3[1@2U_N/3
0:2ei`@0UZCO0`2=TM<308V7b`D0S8c>0P2EXMd20;C_mP<0a^[_1P2ZhoX50:?Bn0H0Wmcl1@2Ti?/2
0:S[nPD0WYW?0P1kOLX2001AcP030800000kTo40^:g>00@0^:g>103?[kT30=Nd]`040=c1_`3SbKh0
hlVn0>?9_P<0i/fm1@3=c=T20<c<fP@0//CX102Y`N/T0:O0j`030000002W`>/0Yl3[0100Yl3[403o
ool00`000000oooo0?ooo`0;0?ooo`005P3oool00`000000oooo0?ooo`0<0?ooobX0Yl3[0`00000E
0:O0j`80Yko[1@2U_N/30:2ei`@0UZCO0`2=TM<308V7b`@0S8c>0P2dkoH40<KZk`@0_>cd1@2Vf?T5
09SNoPH0VN7m102Mk?P20:NUe0@0WYW?0`1kOLX2001AcP04001@c@0kTo40^:g>0;R]cP<0Zj7=0`3?
[kT30=Nd]`@0hlVn0`3VcKd0103Vc[h0cLcI0<g<f@3=c=T30<c<fPD0/LCX102Y`N/S0:O0j`030000
002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000h0oooo9P2W
`>/3000001H0Yl3[1@2W_n/40:Fmj`<0X;GW102FY=l308fAd`<0RHO;1@2Zanh30<kTi`@0_>cd102g
i_H508oQo@D0R]gn1P2;i_T40:NUe0@0WYW?0`1kOLX0100G>[H0057>001@c@00D<d50:^Qc@80cjni
103G];L00`3R_k@0hlVn0>?9_P030>K=_@<0i/jn103<c=X20<_<fPD0/LCX102Y`N/S0:O0j`030000
002W`>/0Yl3[0100Yl3[3`3oool2000000`0oooo000F0?ooo`030000003oool0oooo00h0oooo8P2W
`>/3000001X0Yl3[1@2W_n/409fgjP<0SJ?T101mRmH307f3c`<0SYOH0`2Zanh30<kTi`<0dnSU102g
i_H40:?ZnPD0PM_m1@1ogO`50:FTe0@0YjGD0`2NVLl407]mbP0401Lj]P00DLh0053=001@c@D0Zj7=
00<0cjni0=Nd]`3G];L00P3G];L20>:o]0@0i/fm103Vc[h20<c<fP@0blcJ1@2aa>P40:W1jb<0Yl3[
00<000000:O0j`2W`>/0402W`>/@0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000003o
ool0oooo0100oooo7@2W`>/3000001h0Yl3[1@2U_^/409fgjP<0SJ?T0`1mRmH307f3c`@0SYOH103>
i>L30=?Xi@<0eNGR0P2Sj_X60:WOnPD0T=7n102QVlh50:FTe0<0YjGD0`2NVLl407]mbP805cZf00<0
02be001@c@2[XLd0102[XLd40=Nd]`<0h[nd00<0j/Rb0>K=_@3VcKd01P3Vc[h40<_<fP80b/_K102a
a>P50:W1jb80Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00P0oooo000F
0?ooo`8000004P3ooolI0:O0j`<000007P2W`>/40:Noj`D0YKk[0`2M]nX308fSi0@0OH_F0`1mPll2
08jGf0@0^/;O0`3Cj>D30=GUhP<0e=oP0P3Ba/l50;Big@D0YIG4102QVlh40:FTe0@0VHW10`2?Q/D3
06ahcP<05cZf00@002be001@c@2[XLd0Zj7=0`2WV/P30=Nd]`<0h[nd0P3Zb;870>K>_P030>G=_`3;
c=X0blcJ00@0b/_K102aa>P50:W1jb80Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003o
ool0oooo00P0oooo000F0?ooo`030000003oool0oooo0180oooo5@2W`>/300000280Yl3[102W_n/5
09jjk0<0RJ[[0`1]Rml306end`<0OH??1@2j`]l30=7>eP<0eNGR0`3Dgn030=;6c`040<b[^@2d^Md0
];WM0;Big@80]iZk1@2UUL@30:6KcPD0Whg00`2IRL4308n6a@@0K7S>0P0G>[H2000/]@D0Yi[80P3G
];L30>:o]0<0j/Rb00<0kL^a0>K>_P3Vc[h00`3Vc[h30>G=_`@0b/_K0P39bm/40;74j0D0ZL3[8P2W
`>/00`000000Yl3[0:O0j`0@0:O0j`l0oooo0P0000090?ooo`000`3oool2000000@0oooo0P000004
0?ooo`800000103oool00`000000oooo0?ooo`0D0?oooa40Yl3[0`00000V0:O0j`@0Y[o/1@2N^^`3
08VZj`80KH_O101]O]<3092Fe@<0^/;O0`3Ac]H30=[<b`<0e=oP0`3Ba/l30<b[^@040;Big@2gV[/0
]iZk0;NJ^`D0YIG4102VTl4409n=`0@0VHW10`2?Q/D306ahcP03000^]P0G>[H05cZf008002be1@2W
V/P0103G];L0h[nd0>:o]03R_k@20>[8/P<0kL^a0`3Vc[h40>G=_`030>G=`03:bm/0b/_K00<0bL_K
1@2``nP40:W0jb<0Yl3[00<000000:O0j`2W`>/0402W`>/;0?ooo`<0000000<0oooo0000003oool0
203oool00080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo01D0oooo3P2W`>/2000002X0Yl3[102V_n`409jjk0<0RJ[[0`1]Rml306end`@0
T9KE103Ac]H40=[<b`80fl2o103Ba/l30<b[^@D0]iZk0P2UUL@30;6Na0<0YY?1102OSL0409V9`@<0
ShK5101/N<h01000;[H05cZf000X[`00;;D50:NJb0@0h[nd0P3Zb;840>g;/@030>K>_P3UcKl0iLfo
0080iLfo0P3UcL040<W;f`80bL_L1@2``nP40:S0jb80Yl3[00<000000:O0j`2W`>/04@2W`>/60?oo
o`@00000103oool00`000000oooo0?ooo`070?ooo`000P3oool010000000oooo0?ooo`00000;0?oo
o`040000003oool0oooo0?ooo`8000005`3oool:0:O0j`<00000;@2W`>/40:>nk0@0T[G_0`1VU^/2
04aefP@0KGkC0P2@U]D20;6[d@80dLkF103Jc</30=_0_`030=Rb/P3Ba/l0d/K?00@0c:^i00<0cjN`
0;NJ^`2gV[/00P2gV[/50;6Na0@0YY?10`2OSL0409V9`@@0Vk__0`1TXo<2000^]P030000Q@00::l0
02be0080Yi[80`2cXlP20>:o]080j/Rb1@3]bk440>G=_`<0iLg000<0i<g10<W;f`39bm/01039bm`5
0;33j0@0Z<3[8P2W`>/00`000000Yl3[0:O0j`0A0:O0j`80oooo0`0000080?ooo`030000003oool0
oooo00L0oooo00020?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0
oooo01P0oooo1@2W`>/3000002d0Yl3[102W_n/40:>nk0@0T[G_0`1VU^/204aefP<0N8GC1@2aZm44
0=[<b`<0fl2o0`3H/[840<b[^@80cjN`102gV[/00`35[/@0/Ik40;6Na0030;6Na0<0YY?10`2OSL05
0:Bmj`@0Vk__0`1TXo<2000^]P8002R_1P2cXlP00`3R_k@0j/Rb0>[8/P060>g;/@80iLfo0`3UcL03
0>C=`@D0bL_L1@2``nP50:S0jb80Yl3[00<000000:O0j`2W`>/0402W`>/2000000`0oooo00<00000
0?ooo`3oool01P3oool00080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01T0oooo00@0Yl3[0000000000000000<@2W`>/40:Noj`D0Wkg^0`1n
[O82035ii080C7GJ101hQM<30;6[d@80aK760P3Jc</30=_0_`@0f;:b00@0ej^[0<b[^@3<ZkT0c:^i
0`3?Yk020;NJ^`80aJk41@2aW/@30:JC`@@0YkkZ1@2T_N/409blk`<0Hj7c00@002jf0000I`00::l0
02R_1@2cXlP20>[8/PP0kL^a103UcL030>C=`@040>C>`@39bm`0bL_L0<W;g080b<cL0`2``nP20;34
j@D0Z<3[8P2W`>/00`000000Yl3[0:O0j`0@0:O0j`d0oooo00<000000?ooo`3oool01P3oool000<0
oooo0P00000:0?ooo`<000000`3oool2000001P0oooo0`00000e0:O0j`@0Y[o/1@2O_Nh307j]lP80
<GWT00<0:F;D04aefP1hQM<00`1hQM<00`2aZm40aK760<FaaP020<FaaP@0fl2o0`3H/[820=N[Z`80
c:^i103?Yk000`2gV[/0aJk40<F^a0020<F^a0@0/Ik4102Y`>X40:NnjPD0Y[o/102L_>l306>Ql`03
0000I`00<kP002R_00@0/j?80P3;_<`00`3Zb;80kL^a0>g;/@070>g;/@80iLg00`3TcL430>C>`@D0
b<cL1@2`a>T50:S1jb40Yl3[00<000000:O0j`2W`>/0402W`>/=0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`030000003oool0oooo01D0oooo0`0000040?ooocD0Yl3[102V_n`509^lk`80IjCc
0P0aNN@202URe0@0N8GC1@35/LH00`3>[[X0fl2o0=_0_`040=Rb/P<0ej^[00<0c:^i0<nW/03?Yk00
0P3?Yk050<F^a080/Ik40`2a`nL40:W0jP@0Yl3/1@2V_n`409^lk`80H9kb00@002:V0000I`00<kP0
02R_0P2cXlP30<^lc0/0kL^a103TcL430>C>`@030>GA``38c=`0b<cL00<0b<kO0P2`a>T30:o4jP@0
Z<7[8P2W`>/00`000000Yl3[0:O0j`0@0:O0j``0oooo00<000000?ooo`3oool01P3oool001@0oooo
00<000000?ooo`3oool04P3oool3000000P0oooo=@2W`>/40:Jok0D0Vkc_0P1WY?<01000CLX0<GWT
02URe00YH]@408b@dP<0aK760`3>[[X40=Rb/P@0ej^[1@3?Yk000`3K^kP0aJk40<F^a0020<F^a0D0
/L?W1@2X`>/40:O0k0D0YL7]102K_>l2062NlP03000NY000<kP003>h00D0bkc<00<0f<_<0>g;/@3]
bk402@3]bk420>C=`@<0i<k10P3UdL<50<S>g`H0[lCZ102X`N/R0:O0j`030000002W`>/0Yl3[0100
Yl3[2`3oool00`000000oooo0?ooo`060?ooo`00503oool200000100oooo0`00000<0?ooocD0Yl3[
102V_n`509Vkl080Di_c00<004g:02URe00YH]@0102<T=830<FaaP<0cZjj00@0dZbb0=Rb/P3H/[80
f;:b103GZj/0103N/ZX0cjN`0<nW/03?Yk030=^k^080aJk40P38amT30;73i`80/L;W1@2X`>/40:O1
k0@0YL7]00<0K]Ki0:FNcP2UW/h00P2UW/h209^Me003000NY000A<D003>h00<0bkc<0`3Hbl`;0>g;
/@<0i<k10`3UdL<0103Wf<H0b<kO0<S>g`38c]l30<KAh`D0[LC[102X`N/R0:O0j`030000002W`>/0
Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0<0?oo
o`<000004@3ooold0:O0j`@0YKo/1@2I^o0205>Kl`03001=bP00A<H0:F;D00@0S93B00@0aK760<j^
^P3>[[X0cZjj0P3B[;820=Rb/P@0ej^[0P3N/ZX20<nW/0@0fk^h1@38amT50;72i`D0Z<3[102W`N`5
0:BMcP<0YIk>102KWM@00`00A<D003>h0<^lc0040=S;c0030=_<bP3]bk40kL^a00P0kL^a00<0k/fa
0>C>`@3UdL<00P3UdL<30>OHaP@0a]7S0P31d^L40:g4j`D0Z<3[8@2W`>/00`000000Yl3[0:O0j`0@
0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool02P3oool20000
01D0oooo=02W`>/40:Fok0D0V;_`0P19Uo800`00CLX004C608b@dP0308b@dP@0cZjj0`3B[;800`3H
/[80ej^[0=N[Z`020=N[Z`80g[:Z0P3?Yk040=^k^0040=k5_`38amT0b<OI0<S7f@80b<KH0`2a`^L2
0;72iPD0Z<3[102TXM840:BMcP@0YIk>0P2KWM@00`2[YM4004C50014a@040=S;c0<0flc:203]bk42
0>k=/@@0iM730`3Wf<H00`3WhLd0a]7S0<KAh`040<7Bi`@0ZlC[102X`>/R0:O0j`030000002W`>/0
Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`050?ooo`00503oool00`000000oooo0?ooo`070?oo
o`<00000603ooold0:O0j`@0YKo/1@2H^o0204VGlP8004C6102KV=020<j^^P@0dZbb103GZj/30=jb
ZP030<nW/03K^kP0fk^h0080fk^h0`3NaKl50<S6f0D0/L;V00<0P^WQ09?_b`2a/mX00P2a/mX30:BQ
dP@0Y9g>102UW/h40:^Ud@04001?c000A<D0f<_<0=S;c0<0flc:0P3Lc<T70>g;/@80k/fa00<0l]Fb
0>GA``3UdL<00`3Wf<H30>OQc@<0`M;W0`2jdN/40:_4j`@0Z<3[8P2W`>/00`000000Yl3[0:O0j`0?
0:O0j`X0oooo00<000000?ooo`3oool01@3oool001<0oooo0`0000050?ooo`<00000703ooold0:O0
j`@0YKo/1@2I^o0204ZHlP030014aP2KV=00ViS@00<0ViS@00<0cZjj0=://P3B[;800P3B[;80103G
/;40ej^[0=N[Z`3GZj/30=jbZP@0fk^h103NaKl0103OaKh0b<KH0<S6f038a]P20<W6e`<0/L;V00<0
P^WQ0;6cfP2a/mX00`2a/mX40:BQdP<0Y9g>1@2[Y]840:^Ud@8004o<0`3Kc<X40=c<b@D0kL^a0`3^
cK420?;E/P<0imS60`3WhLd20>;XePD0^]7[1@2Y`^`40:S0jb80Yl3[00<000000:O0j`2W`>/03`2W
`>/90?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000003oool0oooo0080oooo0`00000P
0?oooc@0Yl3[102U_n`509Vkl080BYSb00<004C609^Hd02KV=000P2KV=040=://P80ek2a0P3GZj/4
0=jbZP030>Fo/03K^kP0fk^h00@0g/Fo0`3OaKh50<W6e`80P^WQ0P3HemH50;6cfP<0Y:7B102UXm<4
0:^VdP@0ZjGA00@0Ui[D001Gd@00Cl`0flc:103Lc<T20=g<a`@0kL^a0P3^cK430?;E/P80m^6e0`3W
hLd20>;XeP80enWR0`2jdN/20;;;k@@0ZL;/9P2W`>/00`000000Yl3[0:O0j`0@0:O0j`P0oooo00<0
00000?ooo`3oool01@3oool001<0oooo00<000000?ooo`0000000P00000T0?oooc@0Yl3[102U_n`5
09Zll080Ci[c1@2MW]@30=://P<0ek2a00<0ej^[0=jbZP3N/ZX00P3N/ZX20>Fo/0@0g/Fo1@3OaKh2
0<W6e`<0d^_V103HemH40;6cfP@0WYoD102UXm<30:^VdPD0ZjOB00<0Ui[D001Gd@3Lc<T00`3Lc<T4
0=g<a`80kL^a0`3^cK420?;E/P<0m^6e00@0m>^k0>;XeP3Rj=H0h^SF103GjN850;;;k@@0Z<7[9P2W
`>/00`000000Yl3[0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool01@3oool001<0oooo0`00000W
0?oooc@0Yl3[102V_n`509Zll080Ci[c102MW]@20=://P@0ek2a103N/ZX30>Fo/0030>K3/P3NaKl0
g/Fo00H0glFn103BjnH40=SGeP80^[7A102OWm@409jOe0<0YJ?C102[ZMD50:^WdP0409NJe000G]D0
g<c90=c<b@@0gLc70P3OcLL30>k=/@<0l]Fb0P3fhKD20?C[^`80ko;40`3GjN830<SSj`D0[<G/102X
`N/V0:O0j`030000002W`>/0Yl3[00l0Yl3[1`3oool00`000000oooo0?ooo`050?ooo`00503oool0
0`000000oooo0?ooo`0W0?oooc@0Yl3[102V_n`509Zlk`0305>Ll`2MW]@0WIkD0080WIkD0P3B[;84
0=N`/@040=bl^03N/ZX0g[:Z0=jbZP<0iKn`0P3V`k870=o5_P80iLo00P3ejkT00`3ehKH0f=OF0=SG
eP030;Zad@@0WioD102NWm@40:JWe`@0ZjWE102[Ym800`2GV]@005kE001Ne@040=g<a`<0glg700<0
iMW90>k=/@3^cK400P3beK820?KQ]@80m>^k0`3_l/@00`3Wmlh0b>?[0<SSj`020<SSj`80^=G_1@2/
aN`Y0:O0j`030000002W`>/0Yl3[0100Yl3[1`3oool00`000000oooo0?ooo`040?ooo`002`3oool5
000000D0oooo0P00000Y0?oooc<0Yl3[102V_n`509Zlk`0505>Ll`2MW]@0WIkD09fNe03B[;80103G
/;420=bl^080g[:Z0`3U_k040>K3/PD0glFn0`3Ucl020?G[^@80mN6f1@2j/M4309nOe0D0X:;F102V
YmL30:^Ye@D0Z:oM00<0UZ;M001QeP00G]D00P3Mc<L30=o=a`<0iMW90`3beK820?KQ]@80m>^k0P3_
l/@0103Wmlh0g?WK0=cif`3LnM/50;SEk`D0ZL;/:@2W`>/00`000000Yl3[0:O0j`0@0:O0j`H0oooo
00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0W0?oooc<0Yl3[102V_n`509^lk`<0WIkD103G/;440=bl^0040=jbZP3U_k00iKn`0>Fo/0D0i/>b
103OaKh20>G?`080mN^i0`3ehKH00`3Sb[h0^[7A0;Zad@020;Zad@@0WigB102PX]H40:JWe`@0ZK7N
102X[md209JRg@80067F103OcLL30>GIb@80jO7?0P3fhKD20?C[^`80ko;400@0ioO>0=cif`3LnM/0
g?WK0`3=lN/40:g8k@@0ZL;/:P2W`>/00`000000Yl3[0:O0j`0@0:O0j`D0oooo00<000000?ooo`3o
ool0103oool000d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?oooc<0Yl3[
102V_n`509^lk`<0QZ;V0`3G/;440=bl^0@0iKn`1@3V`k830=o5_P<0iLo00P3ejkT20?GQ]P<0hlZn
102`YLd409nMdP<0X:;F1@2W/=l40:VagP<0Z:oM102FX]d00`00HMH0glg70=o=a`030>GIb@80jO7?
0P3Jo]H20?C[^`80ko;400<0ioO>0=cif`3LnM/00`3=lN/30;WJl@@0[LS]102X`>/Z0:O0j`030000
002W`>/0Yl3[00l0Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02L0oooo<`2W`>/40:Jok0D0Vkc_0`26X^H00`3G/;40g;bh0=bl
^0030=bl^0030=g6`P3U_k00iKn`00L0i/>b0P3OaKh20>G?`080mN^i0`3ehKH30>?:_P030=>j`@2`
YLd0/:G=0080/:G=0`2OWM840:F^gPD0Yk3O0`2Y/Mh40:6Vf@@0SYSI00<0HGcG0>GIb@3UfLT00P3U
fLT00`3YlLl0f_kF0=[neP020<omh@80dOSU0P3Gn>400`3HoMX0cooH0<oof0050;WJl@D0ZL;/102X
`>/Y0:O0j`030000002W`>/0Yl3[0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool0
0`000000oooo0?ooo`0:0?ooo`800000:03ooolc0:O0j`@0Y[o/102K_>l00`1KX?@0<HO/0367k005
0=bl^0<0gLK200<0iKn`0>K3/P3V`k801P3V`k830>G?`080mN^i0P3ehKH30>?:_P80dk[1102`YLd4
0:FYf@@0YJkN102W/=l40:J[fP@0XJKI0`2>V=T2065le`80iMW900<0jO7?0=[neP3Jo]H00P3?oN42
0=7hi@80eoSQ00<0f?gJ0<oof03?omP00`36m^d40:c7k@@0ZL;/;P2W`>/00`000000Yl3[0:O0j`0?
0:O0j`@0oooo00<000000?ooo`3oool0103oool000`0oooo0P00000>0?ooo`030000003oool0oooo
02H0oooo<`2W`>/40:Jok0@0W;c_00<0GZ;d0367k00aQn`00`3L_;P40=g6`PT0i/>b0P3Xa[<20?G[
^@80mN6f0`3Sb[h40=>j`@80/:G=0P2aZ<l40:FYf@<0YJkN2@2VZmX30:6Vf@<0SYSI0`1QO=L00`3Y
lLl0f_kF0=[neP020<omh@060=7hi@3Gn>40eoSQ0=Ohh@3HoMX0cooH0`36m^d30;CEl@@0[<O]<P2W
`>/00`000000Yl3[0:O0j`0?0:O0j`<0oooo00<000000?ooo`3oool0103oool001d0oooo00<00000
0?ooo`3oool09P3ooolc0:O0j`@0Y[o/102L_>l0101NX_@005c?0367k03L_;P40=g6`P80g<S5203V
`k820>S6/`80lmFa0P3ig:T00`3eeZd0hlZn0=>j`@040=>j`@D0/JS?0`2UZMT40:JXf0@0YZ_J1@2S
[=h309^WgP<0R9SL0`1]QMX303IYe`@0L:oh00@0f?gJ0<7li`2go=<0]ocC1@2deO450:S1k380Yl3[
00<000000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo00<0oooo000N0?ooo`030000003o
ool0oooo02H0oooo<`2W`>/40:Jok0@0W;c_00<0HJ?e001Lc`3Ma/800`3Ma/840=c8a@H0i/>b0`3X
a[<00`3ceK40nMbY0?WLZ@020?GF[@D0dk[10P3;]<@40;6Xc`@0ZZGB102VZ=P40:N^g@@0XjcN102K
Ymh308RHg0<0KHGJ0P1[T>@40:[In0030<7li`2go=<0]ocC00<0_>gc102Za>d40:S1k380Yl3[00<0
00000:O0j`2W`>/0402W`>/20?ooo`030000003oool0oooo00<0oooo000O0?ooo`800000:03ooolb
0:O0j`D0Y[o/0`2L_>l0101QXoD004g40=g6`P3Ma/840=c8a@80flS71@3V`k820>S6/`80lmFa0P3i
g:T20?GF[@040>c>]P3C^/40dk[10=>j`@<0bkC40P2aZ<l30;FWb`@0ZZGB0P2VZ=P20:Z]f@@0YjkM
0`2S[=h409^WgP<0R9SL101]QMX306^@i080`OcW00<0]ocC0;c]l`2lkO<0102]bnl40:[4kCH0Yl3[
00<000000:O0j`2W`>/0402W`>/00`3oool000000?ooo`040?ooo`008@3oool00`000000oooo0?oo
o`0V0?oooc<0Yl3[102V_n`309fmk`0306>Um@00CL@0g<S500<0g<S5103Kb<L30>K3/P<0j<Jc00<0
lmFa0?WLZ@3ig:T00P3eeZd30>c>]PD0bkC41@2eYl/40:ZUdPD0ZZgI0`2W[]d409nJc`@0UI7>0`27
RLh3082@fP<0V/Gf0P2Mm=00102_n^80/]Oc0;;Gl`2beo<40:g;k`@0Z<3[=P2W`>/00`000000Yl3[
0:O0j`0?0:O0j`030?ooo`000000oooo00@0oooo000R0?ooo`030000003oool0oooo02H0oooo<`2W
`>/40:Jok0<0WKg_00@0HjGe0012^`3Lb<D0g<S5103Kb<L20=[8b080i/>b0`3Xa[<00`3ceK40nMbY
0?WLZ@020?GF[@<0k<jf00@0h/Vn0<^da03;]<@0bkC40P39/lD40;FWb`D0[j[B102Z[MT40:BLc@<0
Wi[?102ETLh408N9cP<0P93J0P2Mm=000`2_n^80/]Oc0;;Gl`030;;Gl`D0Z<7/102X`>/f0:O0j`03
0000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002<0oooo00<000000?ooo`3oool0
9P3ooolc0:O0j`@0Y[o/102M_Nl00`00@[/0flS70=_8a`020=_8a`@0f/S80`3Xa[<00`3ceK40nMbY
0?WLZ@020?GF[@<0k<jf0`3RbKh00`3;]<@0bK?50<Vca@020<Vca@80]JO;0P2iZ//40:nZdPD0Z9_9
102TW<d309nJc`<0UI7>1027RLh309OWn`D0/^Gg102Y`nd40:S1k3X0Yl3[00<000000:O0j`2W`>/0
3`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2000002L0oooo<`2W`>/40:Jok0@0W[g^00<0
03Rb0=_8a`3Kb<L0103Jb<P20=W:bP80j<Jc00<0lmFa0?WLZ@3ig:T00P3eeZd30>c>]P<0h/Vn1@39
/lD50;VZb`80[j[B0P2_W/H40:RKb@@0Y9c=0`2OV/l309FAcPD0T;G_00@000000:W`m`2Yl?L0ZO3g
102Zanh40:W3kCh0Yl3[00<000000:O0j`2W`>/02`2W`>/30?ooo`030000003oool0oooo00<0oooo
000V0?ooo`030000003oool0oooo02D0oooo<`2W`>/40:Jok0@0W[g^00<003Rb0=[8b03Jb<P00P3J
b<P40=W:bP030??E/@3ig:T0nMbY0080mMJ]0`3/c[H40>;9_P040=_<b@39/lD0bK?50<Vca@80b;S;
102iZ//40:nNaP@0Z9_91@2TV//309ZEcP<0TY[H0`2@]Nl00`2Yl?L0Zl_a0:_;l@030:_;l@@0Z/O^
@P2W`>/00`000000Yl3[0:O0j`060:O0j`P0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool09@3ooolc0:O0j`@0Y[o/102Q_^h00`1n/oH0f/S80=[8b0040=W:bP80gmK>0P3/
j<T20?7/`P80k^c7103RbKh30=_<b@030<Vca@38^</0b;S;0080b;S;0P2iZ//20;b/bP@0[ik60P2X
VlT20:nWd0@0Y9[;102JULh309:Jf0@0ZLoc102[bo560:O0j`030000002W`>/0Yl3[00<0Yl3[2`3o
ool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`0V0?oooc80Yl3[102V`>`4
0:6nkP0307jcmP3Ib/X0fL[:0080fL[:0P3Oe/h20>cXb@80lNc20`3^k<L00`3SkmL0h/Vn0>;9_P04
0=_<b@D0b;S;102l[<X40:nNaP@0[jO@102TV//409ZEcP@0Ym3e102Yco<50:NojdD0Yl3[00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00:@3oool2000002L0oooo<P2W`>/40:K0
k0@0Xko]00<0SKWd0=W:bP3Ib/X00`3Oe/h20>cXb@80lNc20P3^k<L30>?_e`@0flc90P3Cfmh30<Rh
b`80b]3N102l[<X20:nNaP80_<?P102_Ym030:BJb`D0Y<of102Wd?D50:S0j`@0Yl7/@P2W`>/30?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3o
ool09@3ooolf0:O0j`@0Xko]00@0V[g`0=oFcP3Oe/h0gmK>0P3/j<T20?7/`P80k^c70`3SkmL20<Cf
kP80flc9103Cfmh00`38^</0b]3N0<[@gP020<[@gP<0_:c:1@2l`n030:nWd0@0X/gf102TcoH50:S0
j`P0Yl7/1@2W_n/i0:O0j`P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`0U0?ooocD0Yl3[1@2U_n`209Zml080k>S90P3ak<820>k/a`80
hnoG1@34m^h50=?KgPD0b]3N102ck_L40;c3h0@0XLSd102RcOH50:O0j`P0Yl7/202W_n/f0:O0j`/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`000000oooo
0?ooo`0V0?ooocD0Yl3[102W`>`40::ok@@0X;o^0P2=_OH505??f`D0R>[]1@0000040;?^m`@0X/Ca
102Qb?@50:O0j`P0Yl7/202W_n/f0:O0j`l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`010?ooo`00;P3oool00`000000oooo0?ooo`0V0?ooocD0Yl3[102W`>`40:Jok0@0X;o^102R
_nh409Fom0D0Wl7`0`2Ga?H50:C1kP@0X/Ca102W_n/90:O1k0P0Yko[102W`N`a0:O0ja@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00;`3oool2000002L0oooo>@2W`>/4
0:Jok0@0Y/3/102R_nh40:C0k@@0Wl7`1@2U`>d80:O0j`P0Yl7/202W_n/90:O1k0@0Yko[:@2W`>/H
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool09@3ooolm0:O0j`@0Y/3/1@2W`>`30:C0k@D0Yl3/202W`>/40:O0k0@0Yl7/202W_n/80:O1
k0P0Yko[9@2W`>/L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00380
oooo00<000000?ooo`3oool09@3ooomF0:O0j`@0Yl3/202W_n/80:O1k0P0Yko[9@2W`>/P0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool003<0oooo00<000000?ooo`3oool0
9@3ooomF0:O0j`@0Z;o[102W_n/80:O1k0P0Yko[1@2W`>/40:Noja`0Yl3[903oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0040oooo000d0?ooo`8000009P3ooomF0:O0j`@0Z;o[102W
`>`40:O1k0@0Yko[202W`>`80:NojaP0Yl3[:@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0040oooo000f0?ooo`030000003oool0oooo02D0ooooF@2W`>/30:O0k0D0Yko[202W`>`8
0:NojaP0Yl3[;03oool00`000000oooo0?ooo`070?ooo`4000000@3oool10?ooo`00=`3oool00`00
0000oooo0?ooo`0U0?oooeT0Yl3[102W_n/80:O0k0P0Yko[602W`>/`0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`40oooo000h0?ooo`030000003oool0oooo02D0ooooF@2W`>/80:O0k0P0
Yko[202W`>/40:Noj`P0Yl3[>03oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00
>@3oool2000002H0ooooF@2W`>/30:O0k0P0Yko[202W`>/80:Noj`D0Yl3[>`3oool00`000000oooo
0?ooo`050?ooo`4000000@3oool10?ooo`00>`3oool00`000000oooo0?ooo`0T0?oooeP0Yl3[202W
_n/80:O0j`D0Yko[202W`>/o0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`40oooo000l
0?ooo`030000003oool0oooo02@0ooooF02W`>/40:Noj`D0Yl3[202W_n/80:O0jd<0oooo00<00000
0?ooo`3oool00`3oool100000040oooo0@3oool003d0oooo00<000000?ooo`3oool0903ooomM0:O0
j`L0Yko[202W`>]80?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40oooo000n0?ooo`80
00009@3ooomH0:O0j`P0Yko[202W`>];0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00
@03oool00`000000oooo0?ooo`0S0?oooeP0Yl3[102W_n/80:O0jdl0oooo00<000000?ooo`3oool0
0P3oool100000040oooo00110?ooo`030000003oool0oooo02<0ooooH02W`>]C0?ooo`050000003o
ool0oooo0?ooo`0000000@3oool00480oooo00<000000?ooo`3oool0903ooomK0:O0jeL0oooo00@0
00000?ooo`3oool000000@3oool004<0oooo0P00000U0?oooe<0Yl3[GP3oool010000000oooo0?oo
o`0000010?ooo`00A@3oool00`000000oooo0?ooo`0S0?ooodl0Yl3[HP3oool00`000000oooo0000
00010?ooo`00AP3oool00`000000oooo0?ooo`0S0?oood/0Yl3[IP3oool100000040oooo0@000000
04L0oooo00<000000?ooo`3oool08`3ooom70:O0jfX0oooo0P00000004P0oooo0P00000U0?oood80
Yl3[K@3oool200000000BP3oool00`000000oooo0?ooo`0S0?oooch0Yl3[L03oool200000000B`3o
ool00`000000oooo0?ooo`0R0?oooc/0Yl3[K`3oool400000080oooo001<0?ooo`030000003oool0
oooo02<0oooo<`2W`>]a0?ooo`@000001P3oool004d0oooo0P00000T0?ooobl0Yl3[L03oool40000
00X0oooo001?0?ooo`030000003oool0oooo0280oooo:`2W`>]_0?ooo`@000003P3oool00500oooo
00<000000?ooo`3oool08`3ooolV0:O0jfh0oooo1000000B0?ooo`00D@3oool00`000000oooo0?oo
o`0S0?ooob80Yl3[KP3oool3000001H0oooo001B0?ooo`800000903ooolN0:O0jfd0oooo1000000I
0?ooo`00E03oool00`000000oooo0?ooo`0R0?oooaL0Yl3[K`3oool4000001d0oooo001E0?ooo`03
0000003oool0oooo0240oooo502W`>]^0?ooo`@000008@3oool005H0oooo00<000000?ooo`3oool0
8P3oool?0:O0jfd0oooo1000000U0?ooo`00E`3oool2000002<0oooo2`2W`>]/0?ooo`@00000:@3o
ool005T0oooo00<000000?ooo`3oool08@3oool40:O0jfl0oooo0`00000]0?ooo`00FP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo06X0oooo1000000`0?ooo`00F`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo06H0oooo1000000d0?ooo`00G03oool200000240oooo
00<000000?ooo`3oool0HP3oool4000003P0oooo001N0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0GP3oool4000003`0oooo001O0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0FP3oool400000400oooo001P0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0E`3oool3000004@0oooo001Q0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`@0
0000A`3oool006<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000
B`3oool006@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`@00000C`3o
ool006D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`170?ooo`@00000D`3oool0
06H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`130?ooo`@00000E`3oool006L0
oooo0P00000F0?ooo`030000003oool0oooo0400oooo0`00001K0?ooo`00J@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo03`0oooo1000001N0?ooo`00JP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo03P0oooo1000001R0?ooo`00J`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo03@0oooo1000001V0?ooo`00K03oool200000100oooo00<000000?oo
o`3oool0<@3oool4000006X0oooo001^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0;@3oool4000006h0oooo001_0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
:P3oool300000780oooo001`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3o
ool4000007D0oooo001a0?ooo`8000002`3oool00`000000oooo0?ooo`0R0?ooo`@00000N@3oool0
07<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000O@3oool007@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000P@3oool007D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`@00000Q@3oool007H0oooo0P00
00060?ooo`030000003oool0oooo01<0oooo0`0000290?ooo`00N03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00l0oooo1000002<0?ooo`00N@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo1000002@0?ooo`00NP3oool01@000000oooo0?ooo`3oool00000
00T0oooo1000002D0?ooo`00N`3oool2000000030?ooo`000000oooo00@0oooo1000002H0?ooo`00
O@3oool2000000030?ooo`000000000000800000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .64539 .59604 .63937 Mtetra
.59604 .63937 .60194 .64539 .6135 .64213 .60764 .63608 Mtetra
.656 .752 .92 r
.60764 .63608 .6135 .64213 .62511 .63886 .61928 .63278 Mtetra
.61928 .63278 .62511 .63886 .63677 .63559 .63097 .62946 Mtetra
.656 .751 .919 r
.63097 .62946 .63677 .63559 .64848 .6323 .64272 .62612 Mtetra
.656 .75 .919 r
.64272 .62612 .64848 .6323 .66024 .629 .65451 .62276 Mtetra
.656 .749 .918 r
.65451 .62276 .66024 .629 .67204 .62567 .66634 .61941 Mtetra
.66634 .61941 .67204 .62567 .6839 .62233 .67823 .61604 Mtetra
.67823 .61604 .6839 .62233 .6958 .61898 .69017 .61265 Mtetra
.656 .748 .918 r
.69017 .61265 .6958 .61898 .70776 .6156 .70217 .60927 Mtetra
.655 .749 .919 r
.70217 .60927 .70776 .6156 .71977 .61219 .71421 .60587 Mtetra
.655 .75 .92 r
.71421 .60587 .71977 .61219 .73182 .60877 .7263 .60246 Mtetra
.656 .752 .921 r
.7263 .60246 .73182 .60877 .74393 .60535 .73845 .59903 Mtetra
.73845 .59903 .74393 .60535 .75609 .60193 .75064 .59557 Mtetra
.656 .752 .92 r
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.656 .751 .92 r
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Mtetra
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62666 Mtetra
.655 .751 .92 r
.61341 .62666 .61928 .63278 .63097 .62946 .62514 .62333 Mtetra
.655 .752 .921 r
.62514 .62333 .63097 .62946 .64272 .62612 .63691 .61999 Mtetra
.655 .753 .922 r
.63691 .61999 .64272 .62612 .65451 .62276 .64874 .61664 Mtetra
.655 .754 .922 r
.64874 .61664 .65451 .62276 .66634 .61941 .66061 .61326 Mtetra
.66061 .61326 .66634 .61941 .67823 .61604 .67253 .60987 Mtetra
.656 .754 .923 r
.67253 .60987 .67823 .61604 .69017 .61265 .68451 .60646 Mtetra
.656 .754 .922 r
.68451 .60646 .69017 .61265 .70217 .60927 .69653 .60302 Mtetra
.69653 .60302 .70217 .60927 .71421 .60587 .70861 .59956 Mtetra
.656 .752 .921 r
.70861 .59956 .71421 .60587 .7263 .60246 .72074 .5961 Mtetra
.656 .751 .92 r
.72074 .5961 .7263 .60246 .73845 .59903 .73292 .59263 Mtetra
.73292 .59263 .73845 .59903 .75064 .59557 .74515 .58915 Mtetra
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62384 Mtetra
.656 .752 .92 r
.59578 .62384 .60173 .62998 .61341 .62666 .60749 .62048 Mtetra
.60749 .62048 .61341 .62666 .62514 .62333 .61925 .61711 Mtetra
.656 .751 .919 r
.61925 .61711 .62514 .62333 .63691 .61999 .63106 .61371 Mtetra
.656 .75 .919 r
.63106 .61371 .63691 .61999 .64874 .61664 .64291 .6103 Mtetra
.656 .749 .918 r
.64291 .6103 .64874 .61664 .66061 .61326 .65482 .60689 Mtetra
.656 .748 .918 r
.65482 .60689 .66061 .61326 .67253 .60987 .66678 .60347 Mtetra
.66678 .60347 .67253 .60987 .68451 .60646 .67879 .60004 Mtetra
.67879 .60004 .68451 .60646 .69653 .60302 .69085 .5966 Mtetra
.655 .749 .919 r
.69085 .5966 .69653 .60302 .70861 .59956 .70297 .59315 Mtetra
.655 .75 .92 r
.70297 .59315 .70861 .59956 .72074 .5961 .71513 .58969 Mtetra
.656 .752 .92 r
.71513 .58969 .72074 .5961 .73292 .59263 .72735 .58619 Mtetra
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.656 .751 .92 r
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62384 .58979 .61763 Mtetra
.58979 .61763 .59578 .62384 .60749 .62048 .60153 .61426 Mtetra
.655 .751 .92 r
.60153 .61426 .60749 .62048 .61925 .61711 .61332 .61088 Mtetra
.655 .752 .921 r
.61332 .61088 .61925 .61711 .63106 .61371 .62516 .6075 Mtetra
.655 .753 .922 r
.62516 .6075 .63106 .61371 .64291 .6103 .63705 .60409 Mtetra
.655 .754 .923 r
.63705 .60409 .64291 .6103 .65482 .60689 .649 .60066 Mtetra
.655 .755 .923 r
.649 .60066 .65482 .60689 .66678 .60347 .66099 .59722 Mtetra
.656 .755 .923 r
.66099 .59722 .66678 .60347 .67879 .60004 .67304 .59375 Mtetra
.656 .755 .922 r
.67304 .59375 .67879 .60004 .69085 .5966 .68513 .59026 Mtetra
.656 .754 .922 r
.68513 .59026 .69085 .5966 .70297 .59315 .69728 .58674 Mtetra
.656 .752 .921 r
.69728 .58674 .70297 .59315 .71513 .58969 .70948 .58322 Mtetra
.656 .751 .92 r
.70948 .58322 .71513 .58969 .72735 .58619 .72173 .57969 Mtetra
.72173 .57969 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61763 .58374 .6114 Mtetra
.656 .752 .92 r
.58374 .6114 .58979 .61763 .60153 .61426 .59552 .60799 Mtetra
.59552 .60799 .60153 .61426 .61332 .61088 .60734 .60456 Mtetra
.657 .751 .919 r
.60734 .60456 .61332 .61088 .62516 .6075 .61922 .6011 Mtetra
.657 .749 .918 r
.61922 .6011 .62516 .6075 .63705 .60409 .63114 .59764 Mtetra
.656 .748 .918 r
.63114 .59764 .63705 .60409 .649 .60066 .64312 .59417 Mtetra
.64312 .59417 .649 .60066 .66099 .59722 .65515 .5907 Mtetra
.65515 .5907 .66099 .59722 .67304 .59375 .66723 .58721 Mtetra
.66723 .58721 .67304 .59375 .68513 .59026 .67936 .58372 Mtetra
.655 .749 .919 r
.67936 .58372 .68513 .59026 .69728 .58674 .69154 .58023 Mtetra
.655 .75 .92 r
.69154 .58023 .69728 .58674 .70948 .58322 .70378 .57671 Mtetra
.656 .752 .92 r
.70378 .57671 .70948 .58322 .72173 .57969 .71607 .57316 Mtetra
.71607 .57316 .72173 .57969 .73404 .57616 .72841 .56959 Mtetra
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.656 .751 .92 r
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Mtetra
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .6114 .57765 .60509 Mtetra
.57765 .60509 .58374 .6114 .59552 .60799 .58946 .60167 Mtetra
.655 .751 .92 r
.58946 .60167 .59552 .60799 .60734 .60456 .60132 .59824 Mtetra
.655 .752 .921 r
.60132 .59824 .60734 .60456 .61922 .6011 .61323 .59481 Mtetra
.655 .754 .922 r
.61323 .59481 .61922 .6011 .63114 .59764 .62519 .59135 Mtetra
.655 .755 .923 r
.62519 .59135 .63114 .59764 .64312 .59417 .6372 .58787 Mtetra
.6372 .58787 .64312 .59417 .65515 .5907 .64926 .58437 Mtetra
.656 .756 .923 r
.64926 .58437 .65515 .5907 .66723 .58721 .66138 .58084 Mtetra
.656 .755 .923 r
.66138 .58084 .66723 .58721 .67936 .58372 .67355 .57729 Mtetra
.656 .754 .922 r
.67355 .57729 .67936 .58372 .69154 .58023 .68577 .57372 Mtetra
.656 .753 .921 r
.68577 .57372 .69154 .58023 .70378 .57671 .69804 .57013 Mtetra
.656 .751 .92 r
.69804 .57013 .70378 .57671 .71607 .57316 .71036 .56655 Mtetra
.71036 .56655 .71607 .57316 .72841 .56959 .72274 .56296 Mtetra
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Mtetra
.55972 .6022 .56589 .60851 .57765 .60509 .57151 .59876 Mtetra
.656 .752 .92 r
.57151 .59876 .57765 .60509 .58946 .60167 .58335 .5953 Mtetra
.58335 .5953 .58946 .60167 .60132 .59824 .59525 .59181 Mtetra
.657 .751 .919 r
.59525 .59181 .60132 .59824 .61323 .59481 .60719 .58829 Mtetra
.657 .749 .918 r
.60719 .58829 .61323 .59481 .62519 .59135 .61918 .58477 Mtetra
.656 .747 .917 r
.61918 .58477 .62519 .59135 .6372 .58787 .63123 .58124 Mtetra
.63123 .58124 .6372 .58787 .64926 .58437 .64333 .57771 Mtetra
.64333 .57771 .64926 .58437 .66138 .58084 .65548 .57417 Mtetra
.655 .747 .917 r
.65548 .57417 .66138 .58084 .67355 .57729 .66768 .57063 Mtetra
.655 .748 .918 r
.66768 .57063 .67355 .57729 .68577 .57372 .67994 .56709 Mtetra
.655 .75 .92 r
.67994 .56709 .68577 .57372 .69804 .57013 .69225 .56352 Mtetra
.656 .752 .92 r
.69225 .56352 .69804 .57013 .71036 .56655 .70461 .55991 Mtetra
.70461 .55991 .71036 .56655 .72274 .56296 .71703 .55628 Mtetra
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.656 .751 .92 r
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Mtetra
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Mtetra
.56532 .59236 .57151 .59876 .58335 .5953 .5772 .58888 Mtetra
.655 .751 .92 r
.5772 .58888 .58335 .5953 .59525 .59181 .58913 .5854 Mtetra
.654 .752 .922 r
.58913 .5854 .59525 .59181 .60719 .58829 .6011 .58193 Mtetra
.655 .755 .923 r
.6011 .58193 .60719 .58829 .61918 .58477 .61313 .57843 Mtetra
.655 .756 .924 r
.61313 .57843 .61918 .58477 .63123 .58124 .62522 .57489 Mtetra
.655 .757 .925 r
.62522 .57489 .63123 .58124 .64333 .57771 .63735 .57133 Mtetra
.656 .757 .925 r
.63735 .57133 .64333 .57771 .65548 .57417 .64954 .56775 Mtetra
.656 .757 .924 r
.64954 .56775 .65548 .57417 .66768 .57063 .66178 .56413 Mtetra
.657 .755 .923 r
.66178 .56413 .66768 .57063 .67994 .56709 .67407 .56048 Mtetra
.657 .753 .921 r
.67407 .56048 .67994 .56709 .69225 .56352 .68641 .55684 Mtetra
.656 .751 .92 r
.68641 .55684 .69225 .56352 .70461 .55991 .69881 .55319 Mtetra
.69881 .55319 .70461 .55991 .71703 .55628 .71127 .54954 Mtetra
.71127 .54954 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Mtetra
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Mtetra
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Mtetra
.655 .751 .921 r
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58593 Mtetra
.656 .752 .921 r
.55909 .58593 .56532 .59236 .5772 .58888 .571 .58242 Mtetra
.656 .752 .92 r
.571 .58242 .5772 .58888 .58913 .5854 .58296 .57888 Mtetra
.657 .751 .919 r
.58296 .57888 .58913 .5854 .6011 .58193 .59497 .57531 Mtetra
.656 .749 .918 r
.59497 .57531 .6011 .58193 .61313 .57843 .60703 .57174 Mtetra
.656 .747 .917 r
.60703 .57174 .61313 .57843 .62522 .57489 .61915 .56817 Mtetra
.61915 .56817 .62522 .57489 .63735 .57133 .63132 .56458 Mtetra
.63132 .56458 .63735 .57133 .64954 .56775 .64354 .56097 Mtetra
.64354 .56097 .64954 .56775 .66178 .56413 .65582 .55737 Mtetra
.655 .748 .918 r
.65582 .55737 .66178 .56413 .67407 .56048 .66815 .55376 Mtetra
.655 .75 .92 r
.66815 .55376 .67407 .56048 .68641 .55684 .68053 .55012 Mtetra
.656 .752 .921 r
.68053 .55012 .68641 .55684 .69881 .55319 .69297 .54646 Mtetra
.69297 .54646 .69881 .55319 .71127 .54954 .70546 .54276 Mtetra
.656 .752 .92 r
.70546 .54276 .71127 .54954 .72378 .54588 .71801 .53906 Mtetra
.656 .751 .92 r
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Mtetra
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Mtetra
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58647 Mtetra
.655 .751 .921 r
.52907 .58647 .53542 .5929 .54723 .58942 .54091 .58298 Mtetra
.654 .752 .921 r
.54091 .58298 .54723 .58942 .55909 .58593 .5528 .5795 Mtetra
.651 .752 .924 r
.5528 .5795 .55909 .58593 .571 .58242 .56475 .5761 Mtetra
.646 .755 .928 r
.56475 .5761 .571 .58242 .58296 .57888 .57675 .5728 Mtetra
.642 .762 .936 r
.57675 .5728 .58296 .57888 .59497 .57531 .5888 .56955 Mtetra
.641 .774 .944 r
.5888 .56955 .59497 .57531 .60703 .57174 .60091 .56626 Mtetra
.644 .786 .95 r
.60091 .56626 .60703 .57174 .61915 .56817 .61307 .56282 Mtetra
.649 .793 .951 r
.61307 .56282 .61915 .56817 .63132 .56458 .62528 .55921 Mtetra
.656 .795 .949 r
.62528 .55921 .63132 .56458 .64354 .56097 .63754 .55541 Mtetra
.662 .791 .944 r
.63754 .55541 .64354 .56097 .65582 .55737 .64984 .55147 Mtetra
.664 .781 .936 r
.64984 .55147 .65582 .55737 .66815 .55376 .6622 .54748 Mtetra
.663 .769 .929 r
.6622 .54748 .66815 .55376 .68053 .55012 .67461 .54355 Mtetra
.66 .759 .924 r
.67461 .54355 .68053 .55012 .69297 .54646 .68708 .53971 Mtetra
.657 .754 .921 r
.68708 .53971 .69297 .54646 .70546 .54276 .69961 .53594 Mtetra
.656 .752 .921 r
.69961 .53594 .70546 .54276 .71801 .53906 .71219 .53219 Mtetra
.656 .752 .92 r
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Mtetra
.656 .751 .92 r
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Mtetra
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Mtetra
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Mtetra
.655 .751 .921 r
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58351 Mtetra
.653 .751 .922 r
.51084 .58351 .51728 .58995 .52907 .58647 .52266 .58008 Mtetra
.646 .752 .926 r
.52266 .58008 .52907 .58647 .54091 .58298 .53454 .57681 Mtetra
.632 .755 .936 r
.53454 .57681 .54091 .58298 .5528 .5795 .54647 .57385 Mtetra
.611 .767 .955 r
.54647 .57385 .5528 .5795 .56475 .5761 .55846 .57129 Mtetra
.581 .789 .978 r
.55846 .57129 .56475 .5761 .57675 .5728 .57051 .56903 Mtetra
.548 .818 .996 r
.57051 .56903 .57675 .5728 .5888 .56955 .58263 .56681 Mtetra
.518 .846 .998 r
.58263 .56681 .5888 .56955 .60091 .56626 .59481 .56434 Mtetra
.508 .87 .985 r
.59481 .56434 .60091 .56626 .61307 .56282 .60703 .56137 Mtetra
.528 .891 .974 r
.60703 .56137 .61307 .56282 .62528 .55921 .6193 .55773 Mtetra
.576 .91 .975 r
.6193 .55773 .62528 .55921 .63754 .55541 .63159 .55343 Mtetra
.632 .915 .98 r
.63159 .55343 .63754 .55541 .64984 .55147 .64392 .54861 Mtetra
.672 .897 .977 r
.64392 .54861 .64984 .55147 .6622 .54748 .65629 .54353 Mtetra
.687 .861 .965 r
.65629 .54353 .6622 .54748 .67461 .54355 .6687 .53849 Mtetra
.684 .821 .948 r
.6687 .53849 .67461 .54355 .68708 .53971 .68118 .53374 Mtetra
.673 .787 .934 r
.68118 .53374 .68708 .53971 .69961 .53594 .69372 .5294 Mtetra
.664 .765 .926 r
.69372 .5294 .69961 .53594 .71219 .53219 .70633 .52537 Mtetra
.658 .756 .922 r
.70633 .52537 .71219 .53219 .72483 .52844 .71901 .5215 Mtetra
.656 .752 .921 r
.71901 .5215 .72483 .52844 .73753 .52467 .73175 .51769 Mtetra
.656 .752 .92 r
.73175 .51769 .73753 .52467 .75029 .52089 .74454 .51387 Mtetra
.656 .751 .92 r
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Mtetra
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58404 Mtetra
.654 .751 .921 r
.48079 .58404 .48735 .59049 .49907 .587 .49255 .58056 Mtetra
.649 .751 .924 r
.49255 .58056 .49907 .587 .51084 .58351 .50435 .57721 Mtetra
.632 .751 .934 r
.50435 .57721 .51084 .58351 .52266 .58008 .51621 .5743 Mtetra
.589 .755 .957 r
.51621 .5743 .52266 .58008 .53454 .57681 .52812 .57223 Mtetra
.495 .765 .991 r
.52812 .57223 .53454 .57681 .54647 .57385 .5401 .57126 Mtetra
.303 .744 .965 r
.5401 .57126 .54647 .57385 .55846 .57129 .55215 .57108 Mtetra
.049 .616 .75 r
.55215 .57108 .55846 .57129 .57051 .56903 .56429 .57087 Mtetra
.082 0 0 r
.56429 .57087 .57051 .56903 .58263 .56681 .57649 .56984 Mtetra
.085 0 0 r
.57649 .56984 .58263 .56681 .59481 .56434 .58874 .56772 Mtetra
.033 0 0 r
.58874 .56772 .59481 .56434 .60703 .56137 .60103 .5647 Mtetra
0 0 0 r
.60103 .5647 .60703 .56137 .6193 .55773 .61337 .56104 Mtetra
.61337 .56104 .6193 .55773 .63159 .55343 .62575 .55676 Mtetra
.62575 .55676 .63159 .55343 .64392 .54861 .63814 .55156 Mtetra
.63814 .55156 .64392 .54861 .65629 .54353 .65054 .54524 Mtetra
.525 .914 .789 r
.65054 .54524 .65629 .54353 .6687 .53849 .66294 .53809 Mtetra
.684 .97 .924 r
.66294 .53809 .6687 .53849 .68118 .53374 .67537 .53089 Mtetra
.723 .913 .96 r
.67537 .53089 .68118 .53374 .69372 .5294 .68787 .52447 Mtetra
.701 .834 .946 r
.68787 .52447 .69372 .5294 .70633 .52537 .70046 .51915 Mtetra
.675 .783 .931 r
.70046 .51915 .70633 .52537 .71901 .5215 .71315 .5147 Mtetra
.662 .76 .923 r
.71315 .5147 .71901 .5215 .73175 .51769 .72592 .51068 Mtetra
.657 .753 .921 r
.72592 .51068 .73175 .51769 .74454 .51387 .73875 .50679 Mtetra
.656 .752 .92 r
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Mtetra
.656 .751 .92 r
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Mtetra
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58106 Mtetra
.654 .751 .921 r
.46245 .58106 .46909 .58754 .48079 .58404 .47419 .57757 Mtetra
.647 .75 .925 r
.47419 .57757 .48079 .58404 .49255 .58056 .48597 .57428 Mtetra
.618 .748 .939 r
.48597 .57428 .49255 .58056 .50435 .57721 .4978 .57169 Mtetra
.532 .744 .973 r
.4978 .57169 .50435 .57721 .51621 .5743 .50969 .5706 Mtetra
.296 .702 .975 r
.50969 .5706 .51621 .5743 .52812 .57223 .52164 .57136 Mtetra
0 .511 .713 r
.52164 .57136 .52812 .57223 .5401 .57126 .53367 .57282 Mtetra
.156 0 0 r
.53367 .57282 .5401 .57126 .55215 .57108 .54579 .5728 Mtetra
0 0 0 r
.54579 .5728 .55215 .57108 .56429 .57087 .55795 .56998 Mtetra
.597 .93 .959 r
.55795 .56998 .56429 .57087 .57649 .56984 .57015 .56499 Mtetra
.714 .83 .937 r
.57015 .56499 .57649 .56984 .58874 .56772 .58238 .55943 Mtetra
.688 .72 .874 r
.58238 .55943 .58874 .56772 .60103 .5647 .59467 .55454 Mtetra
.652 .666 .85 r
.59467 .55454 .60103 .5647 .61337 .56104 .60703 .55086 Mtetra
.62 .652 .86 r
.60703 .55086 .61337 .56104 .62575 .55676 .61948 .54839 Mtetra
.594 .685 .905 r
.61948 .54839 .62575 .55676 .63814 .55156 .63202 .5466 Mtetra
.578 .792 .98 r
.63202 .5466 .63814 .55156 .65054 .54524 .64461 .54423 Mtetra
.552 .915 .956 r
.64461 .54423 .65054 .54524 .66294 .53809 .65718 .53965 Mtetra
.553 .928 .804 r
.65718 .53965 .66294 .53809 .67537 .53089 .66968 .53224 Mtetra
.667 .973 .827 r
.66968 .53224 .67537 .53089 .68787 .52447 .68214 .5233 Mtetra
.755 .97 .928 r
.68214 .5233 .68787 .52447 .70046 .51915 .69465 .51506 Mtetra
.73 .874 .948 r
.69465 .51506 .70046 .51915 .71315 .5147 .70728 .50869 Mtetra
.686 .796 .933 r
.70728 .50869 .71315 .5147 .72592 .51068 .72005 .50384 Mtetra
.664 .763 .924 r
.72005 .50384 .72592 .51068 .73875 .50679 .73291 .4997 Mtetra
.657 .753 .921 r
.73291 .4997 .73875 .50679 .75164 .50293 .74584 .49576 Mtetra
.656 .752 .92 r
.74584 .49576 .75164 .50293 .76459 .49905 .75883 .49184 Mtetra
.656 .751 .92 r
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Mtetra
.655 .751 .921 r
.44404 .57807 .45077 .58457 .46245 .58106 .45576 .57456 Mtetra
.648 .75 .924 r
.45576 .57456 .46245 .58106 .47419 .57757 .46753 .57122 Mtetra
.617 .746 .938 r
.46753 .57122 .47419 .57757 .48597 .57428 .47933 .56864 Mtetra
.507 .731 .974 r
.47933 .56864 .48597 .57428 .4978 .57169 .49118 .56799 Mtetra
.171 .627 .936 r
.49118 .56799 .4978 .57169 .50969 .5706 .50308 .56989 Mtetra
.212 0 0 r
.50308 .56989 .50969 .5706 .52164 .57136 .51507 .5724 Mtetra
.028 0 0 r
.51507 .5724 .52164 .57136 .53367 .57282 .52716 .57167 Mtetra
.648 .938 .965 r
.52716 .57167 .53367 .57282 .54579 .5728 .5393 .56617 Mtetra
.765 .781 .866 r
.5393 .56617 .54579 .5728 .55795 .56998 .55146 .5582 Mtetra
.716 .662 .796 r
.55146 .5582 .55795 .56998 .57015 .56499 .56365 .55078 Mtetra
.676 .613 .778 r
.56365 .55078 .57015 .56499 .58238 .55943 .57589 .54499 Mtetra
.654 .6 .782 r
.57589 .54499 .58238 .55943 .59467 .55454 .5882 .54048 Mtetra
.641 .599 .791 r
.5882 .54048 .59467 .55454 .60703 .55086 .60057 .53676 Mtetra
.625 .591 .795 r
.60057 .53676 .60703 .55086 .61948 .54839 .61302 .53385 Mtetra
.598 .572 .795 r
.61302 .53385 .61948 .54839 .63202 .5466 .62557 .53222 Mtetra
.561 .554 .804 r
.62557 .53222 .63202 .5466 .64461 .54423 .63824 .53223 Mtetra
.536 .579 .845 r
.63824 .53223 .64461 .54423 .65718 .53965 .65103 .5328 Mtetra
.584 .73 .944 r
.65103 .5328 .65718 .53965 .66968 .53224 .6638 .53088 Mtetra
.696 .955 .951 r
.6638 .53088 .66968 .53224 .68214 .5233 .67643 .52409 Mtetra
.752 .994 .851 r
.67643 .52409 .68214 .5233 .69465 .51506 .68893 .51401 Mtetra
.793 .977 .907 r
.68893 .51401 .69465 .51506 .70728 .50869 .70147 .50453 Mtetra
.745 .876 .941 r
.70147 .50453 .70728 .50869 .72005 .50384 .71417 .49764 Mtetra
.687 .793 .93 r
.71417 .49764 .72005 .50384 .73291 .4997 .72703 .49271 Mtetra
.663 .76 .923 r
.72703 .49271 .73291 .4997 .74584 .49576 .73999 .48856 Mtetra
.657 .753 .921 r
.73999 .48856 .74584 .49576 .75883 .49184 .75302 .48458 Mtetra
.656 .752 .92 r
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Mtetra
.656 .751 .92 r
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Mtetra
.655 .751 .92 r
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57152 Mtetra
.652 .751 .922 r
.43727 .57152 .44404 .57807 .45576 .57456 .44901 .56806 Mtetra
.63 .747 .931 r
.44901 .56806 .45576 .57456 .46753 .57122 .4608 .56516 Mtetra
.539 .73 .963 r
.4608 .56516 .46753 .57122 .47933 .56864 .47262 .56409 Mtetra
.208 .621 .951 r
.47262 .56409 .47933 .56864 .49118 .56799 .48447 .56629 Mtetra
.274 0 0 r
.48447 .56629 .49118 .56799 .50308 .56989 .49639 .57025 Mtetra
.089 0 0 r
.49639 .57025 .50308 .56989 .51507 .5724 .50844 .57069 Mtetra
.704 .934 .963 r
.50844 .57069 .51507 .5724 .52716 .57167 .52058 .56451 Mtetra
.786 .771 .839 r
.52058 .56451 .52716 .57167 .5393 .56617 .53275 .55499 Mtetra
.733 .679 .797 r
.53275 .55499 .5393 .56617 .55146 .5582 .54493 .54667 Mtetra
.694 .658 .811 r
.54493 .54667 .55146 .5582 .56365 .55078 .55716 .54065 Mtetra
.674 .676 .844 r
.55716 .54065 .56365 .55078 .57589 .54499 .56945 .53598 Mtetra
.664 .697 .871 r
.56945 .53598 .57589 .54499 .5882 .54048 .58179 .53188 Mtetra
.655 .705 .883 r
.58179 .53188 .5882 .54048 .60057 .53676 .59419 .52814 Mtetra
.644 .701 .887 r
.59419 .52814 .60057 .53676 .61302 .53385 .60666 .52475 Mtetra
.627 .683 .883 r
.60666 .52475 .61302 .53385 .62557 .53222 .6192 .52195 Mtetra
.588 .64 .869 r
.6192 .52195 .62557 .53222 .63824 .53223 .63185 .52049 Mtetra
.523 .578 .852 r
.63185 .52049 .63824 .53223 .65103 .5328 .64466 .52135 Mtetra
.478 .561 .862 r
.64466 .52135 .65103 .5328 .6638 .53088 .65761 .52342 Mtetra
.563 .705 .937 r
.65761 .52342 .6638 .53088 .67643 .52409 .67052 .52211 Mtetra
.761 .95 .938 r
.67052 .52211 .67643 .52409 .68893 .51401 .68319 .51406 Mtetra
.83 .994 .855 r
.68319 .51406 .68893 .51401 .70147 .50453 .6957 .50241 Mtetra
.816 .951 .907 r
.6957 .50241 .70147 .50453 .71417 .49764 .70831 .49256 Mtetra
.734 .845 .933 r
.70831 .49256 .71417 .49764 .72703 .49271 .72112 .48602 Mtetra
.677 .777 .925 r
.72112 .48602 .72703 .49271 .73999 .48856 .7341 .48136 Mtetra
.659 .756 .921 r
.7341 .48136 .73999 .48856 .75302 .48458 .74716 .47726 Mtetra
.656 .752 .92 r
.74716 .47726 .75302 .48458 .76612 .48061 .7603 .47325 Mtetra
.656 .751 .92 r
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Mtetra
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56849 Mtetra
.655 .751 .921 r
.4187 .56849 .42557 .57507 .43727 .57152 .43043 .56494 Mtetra
.645 .749 .925 r
.43043 .56494 .43727 .57152 .44901 .56806 .44221 .56163 Mtetra
.596 .739 .944 r
.44221 .56163 .44901 .56806 .4608 .56516 .45401 .55951 Mtetra
.376 .674 .974 r
.45401 .55951 .4608 .56516 .47262 .56409 .46582 .56062 Mtetra
0 .343 .712 r
.46582 .56062 .47262 .56409 .48447 .56629 .47766 .56566 Mtetra
.37 0 0 r
.47766 .56566 .48447 .56629 .49639 .57025 .48963 .56974 Mtetra
.487 .891 .939 r
.48963 .56974 .49639 .57025 .50844 .57069 .50175 .56587 Mtetra
.83 .835 .851 r
.50175 .56587 .50844 .57069 .52058 .56451 .51395 .55487 Mtetra
.785 .72 .791 r
.51395 .55487 .52058 .56451 .53275 .55499 .52616 .54362 Mtetra
.727 .674 .798 r
.52616 .54362 .53275 .55499 .54493 .54667 .53837 .53563 Mtetra
.687 .665 .823 r
.53837 .53563 .54493 .54667 .55716 .54065 .55063 .53014 Mtetra
.666 .666 .841 r
.55063 .53014 .55716 .54065 .56945 .53598 .56295 .52577 Mtetra
.656 .669 .851 r
.56295 .52577 .56945 .53598 .58179 .53188 .57532 .52182 Mtetra
.652 .672 .856 r
.57532 .52182 .58179 .53188 .59419 .52814 .58774 .51805 Mtetra
.648 .67 .857 r
.58774 .51805 .59419 .52814 .60666 .52475 .60023 .51444 Mtetra
.636 .661 .857 r
.60023 .51444 .60666 .52475 .6192 .52195 .61279 .51127 Mtetra
.605 .64 .859 r
.61279 .51127 .6192 .52195 .63185 .52049 .62544 .50923 Mtetra
.53 .593 .862 r
.62544 .50923 .63185 .52049 .64466 .52135 .63826 .5097 Mtetra
.413 .522 .86 r
.63826 .5097 .64466 .52135 .65761 .52342 .65128 .51348 Mtetra
.388 .548 .892 r
.65128 .51348 .65761 .52342 .67052 .52211 .66442 .51698 Mtetra
.635 .815 .969 r
.66442 .51698 .67052 .52211 .68319 .51406 .67734 .51324 Mtetra
.849 .978 .867 r
.67734 .51324 .68319 .51406 .6957 .50241 .68992 .5014 Mtetra
.871 .971 .852 r
.68992 .5014 .6957 .50241 .70831 .49256 .70244 .48857 Mtetra
.794 .893 .914 r
.70244 .48857 .70831 .49256 .72112 .48602 .71519 .47974 Mtetra
.702 .8 .925 r
.71519 .47974 .72112 .48602 .7341 .48136 .72816 .47421 Mtetra
.665 .761 .922 r
.72816 .47421 .7341 .48136 .74716 .47726 .74126 .4699 Mtetra
.657 .753 .92 r
.74126 .4699 .74716 .47726 .7603 .47325 .75443 .46583 Mtetra
.656 .751 .92 r
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Mtetra
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Mtetra
.40007 .56545 .40702 .57206 .4187 .56849 .41179 .56186 Mtetra
.653 .751 .921 r
.41179 .56186 .4187 .56849 .43043 .56494 .42355 .55831 Mtetra
.636 .747 .928 r
.42355 .55831 .43043 .56494 .44221 .56163 .43535 .55523 Mtetra
.542 .722 .957 r
.43535 .55523 .44221 .56163 .45401 .55951 .44716 .55416 Mtetra
.117 .537 .916 r
.44716 .55416 .45401 .55951 .46582 .56062 .45895 .55776 Mtetra
.496 0 0 r
.45895 .55776 .46582 .56062 .47766 .56566 .47077 .56533 Mtetra
.292 0 0 r
.47077 .56533 .47766 .56566 .48963 .56974 .48279 .5683 Mtetra
.8 .947 .919 r
.48279 .5683 .48963 .56974 .50175 .56587 .49502 .55941 Mtetra
.855 .789 .785 r
.49502 .55941 .50175 .56587 .51395 .55487 .50729 .54424 Mtetra
.783 .704 .777 r
.50729 .54424 .51395 .55487 .52616 .54362 .51953 .53231 Mtetra
.708 .669 .81 r
.51953 .53231 .52616 .54362 .53837 .53563 .53178 .52556 Mtetra
.664 .675 .851 r
.53178 .52556 .53837 .53563 .55063 .53014 .54407 .52131 Mtetra
.654 .7 .88 r
.54407 .52131 .55063 .53014 .56295 .52577 .55642 .51757 Mtetra
.655 .717 .894 r
.55642 .51757 .56295 .52577 .57532 .52182 .56883 .51381 Mtetra
.656 .723 .899 r
.56883 .51381 .57532 .52182 .58774 .51805 .58129 .51001 Mtetra
.656 .724 .898 r
.58129 .51001 .58774 .51805 .60023 .51444 .59381 .50617 Mtetra
.656 .718 .894 r
.59381 .50617 .60023 .51444 .61279 .51127 .60638 .50229 Mtetra
.641 .695 .885 r
.60638 .50229 .61279 .51127 .62544 .50923 .61903 .49894 Mtetra
.566 .633 .877 r
.61903 .49894 .62544 .50923 .63826 .5097 .63182 .4981 Mtetra
.382 .507 .86 r
.63182 .4981 .63826 .5097 .65128 .51348 .64487 .5025 Mtetra
.201 .412 .844 r
.64487 .5025 .65128 .51348 .66442 .51698 .65819 .51018 Mtetra
.409 .657 .961 r
.65819 .51018 .66442 .51698 .67734 .51324 .67138 .51148 Mtetra
.833 .959 .893 r
.67138 .51148 .67734 .51324 .68992 .5014 .68408 .50069 Mtetra
.909 .963 .808 r
.68408 .50069 .68992 .5014 .70244 .48857 .69656 .48521 Mtetra
.849 .913 .877 r
.69656 .48521 .70244 .48857 .71519 .47974 .70922 .47376 Mtetra
.734 .82 .918 r
.70922 .47376 .71519 .47974 .72816 .47421 .72218 .46709 Mtetra
.673 .767 .921 r
.72218 .46709 .72816 .47421 .74126 .4699 .7353 .46248 Mtetra
.658 .753 .92 r
.7353 .46248 .74126 .4699 .75443 .46583 .74852 .45835 Mtetra
.656 .752 .92 r
.74852 .45835 .75443 .46583 .76767 .46178 .7618 .45426 Mtetra
.656 .751 .92 r
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Mtetra
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .5624 Mtetra
.38137 .5624 .38841 .56904 .40007 .56545 .39307 .55879 Mtetra
.655 .751 .92 r
.39307 .55879 .40007 .56545 .41179 .56186 .40481 .55517 Mtetra
.652 .75 .922 r
.40481 .55517 .41179 .56186 .42355 .55831 .4166 .55164 Mtetra
.626 .744 .932 r
.4166 .55164 .42355 .55831 .43535 .55523 .42843 .54879 Mtetra
.477 .696 .964 r
.42843 .54879 .43535 .55523 .44716 .55416 .44024 .54882 Mtetra
0 .338 .773 r
.44024 .54882 .44716 .55416 .45895 .55776 .45199 .55496 Mtetra
.638 .079 0 r
.45199 .55496 .45895 .55776 .47077 .56533 .4638 .56503 Mtetra
.168 0 0 r
.4638 .56503 .47077 .56533 .48279 .5683 .47588 .56676 Mtetra
.891 .916 .835 r
.47588 .56676 .48279 .5683 .49502 .55941 .48823 .55283 Mtetra
.879 .782 .749 r
.48823 .55283 .49502 .55941 .50729 .54424 .50059 .53368 Mtetra
.791 .708 .773 r
.50059 .53368 .50729 .54424 .51953 .53231 .51287 .52106 Mtetra
.696 .667 .817 r
.51287 .52106 .51953 .53231 .53178 .52556 .52514 .51499 Mtetra
.651 .661 .847 r
.52514 .51499 .53178 .52556 .54407 .52131 .53746 .51122 Mtetra
.645 .669 .859 r
.53746 .51122 .54407 .52131 .55642 .51757 .54984 .50769 Mtetra
.649 .676 .862 r
.54984 .50769 .55642 .51757 .56883 .51381 .56227 .50403 Mtetra
.653 .681 .863 r
.56227 .50403 .56883 .51381 .58129 .51001 .57476 .50019 Mtetra
.657 .682 .862 r
.57476 .50019 .58129 .51001 .59381 .50617 .5873 .49618 Mtetra
.66 .68 .859 r
.5873 .49618 .59381 .50617 .60638 .50229 .5999 .49204 Mtetra
.652 .672 .857 r
.5999 .49204 .60638 .50229 .61903 .49894 .61256 .48815 Mtetra
.589 .634 .864 r
.61256 .48815 .61903 .49894 .63182 .4981 .62534 .48657 Mtetra
.348 .49 .86 r
.62534 .48657 .63182 .4981 .64487 .5025 .63843 .49161 Mtetra
0 .252 .764 r
.63843 .49161 .64487 .5025 .65819 .51018 .6519 .50326 Mtetra
.052 .436 .873 r
.6519 .50326 .65819 .51018 .67138 .51148 .66534 .50961 Mtetra
.802 .958 .915 r
.66534 .50961 .67138 .51148 .68408 .50069 .67818 .50001 Mtetra
.935 .946 .772 r
.67818 .50001 .68408 .50069 .69656 .48521 .69061 .4819 Mtetra
.887 .907 .835 r
.69061 .4819 .69656 .48521 .70922 .47376 .7032 .46779 Mtetra
.763 .828 .903 r
.7032 .46779 .70922 .47376 .72218 .46709 .71614 .45993 Mtetra
.681 .77 .918 r
.71614 .45993 .72218 .46709 .7353 .46248 .72929 .45501 Mtetra
.659 .754 .92 r
.72929 .45501 .7353 .46248 .74852 .45835 .74255 .4508 Mtetra
.656 .752 .92 r
.74255 .4508 .74852 .45835 .7618 .45426 .75588 .44667 Mtetra
.656 .751 .92 r
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Mtetra
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43838 Mtetra
.78271 .43838 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57013 Mtetra
.32789 .57013 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .5624 .37428 .55572 Mtetra
.37428 .55572 .38137 .5624 .39307 .55879 .386 .55208 Mtetra
.655 .751 .92 r
.386 .55208 .39307 .55879 .40481 .55517 .39778 .54843 Mtetra
.651 .75 .922 r
.39778 .54843 .40481 .55517 .4166 .55164 .4096 .5449 Mtetra
.617 .741 .934 r
.4096 .5449 .4166 .55164 .42843 .54879 .42145 .54224 Mtetra
.417 .666 .964 r
.42145 .54224 .42843 .54879 .44024 .54882 .43326 .54318 Mtetra
0 .159 .622 r
.43326 .54318 .44024 .54882 .45199 .55496 .44498 .55166 Mtetra
.724 .194 0 r
.44498 .55166 .45199 .55496 .4638 .56503 .45675 .56453 Mtetra
.119 0 0 r
.45675 .56453 .4638 .56503 .47588 .56676 .46888 .56599 Mtetra
.93 .903 .776 r
.46888 .56599 .47588 .56676 .48823 .55283 .48136 .5475 Mtetra
.911 .795 .719 r
.48136 .5475 .48823 .55283 .50059 .53368 .49384 .52361 Mtetra
.81 .721 .766 r
.49384 .52361 .50059 .53368 .51287 .52106 .50617 .50946 Mtetra
.677 .654 .82 r
.50617 .50946 .51287 .52106 .52514 .51499 .51847 .50427 Mtetra
.617 .645 .856 r
.51847 .50427 .52514 .51499 .53746 .51122 .53081 .50176 Mtetra
.624 .676 .879 r
.53081 .50176 .53746 .51122 .54984 .50769 .54322 .49898 Mtetra
.642 .702 .89 r
.54322 .49898 .54984 .50769 .56227 .50403 .55568 .49557 Mtetra
.655 .714 .892 r
.55568 .49557 .56227 .50403 .57476 .50019 .5682 .4917 Mtetra
.667 .719 .887 r
.5682 .4917 .57476 .50019 .5873 .49618 .58078 .48739 Mtetra
.683 .718 .875 r
.58078 .48739 .5873 .49618 .5999 .49204 .59339 .48244 Mtetra
.686 .701 .858 r
.59339 .48244 .5999 .49204 .61256 .48815 .60604 .4772 Mtetra
.615 .644 .856 r
.60604 .4772 .61256 .48815 .62534 .48657 .61882 .47467 Mtetra
.284 .445 .846 r
.61882 .47467 .62534 .48657 .63843 .49161 .63197 .48119 Mtetra
0 .028 .589 r
.63197 .48119 .63843 .49161 .6519 .50326 .64561 .49759 Mtetra
0 .12 .6 r
.64561 .49759 .6519 .50326 .66534 .50961 .65926 .50851 Mtetra
.78 .977 .913 r
.65926 .50851 .66534 .50961 .67818 .50001 .67219 .49911 Mtetra
.953 .922 .739 r
.67219 .49911 .67818 .50001 .69061 .4819 .68457 .47807 Mtetra
.907 .884 .799 r
.68457 .47807 .69061 .4819 .7032 .46779 .69711 .4615 Mtetra
.782 .823 .885 r
.69711 .4615 .7032 .46779 .71614 .45993 .71005 .45264 Mtetra
.688 .77 .914 r
.71005 .45264 .71614 .45993 .72929 .45501 .72324 .44746 Mtetra
.66 .754 .92 r
.72324 .44746 .72929 .45501 .74255 .4508 .73653 .44318 Mtetra
.656 .752 .92 r
.73653 .44318 .74255 .4508 .75588 .44667 .7499 .43902 Mtetra
.656 .751 .92 r
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Mtetra
.76333 .43484 .76926 .44253 .78271 .43838 .77683 .43065 Mtetra
.77683 .43065 .78271 .43838 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .42221 Mtetra
.80401 .42221 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57013 .32061 .56351 Mtetra
.32061 .56351 .32789 .57013 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Mtetra
.655 .751 .92 r
.37888 .54531 .386 .55208 .39778 .54843 .39069 .54164 Mtetra
.65 .75 .922 r
.39069 .54164 .39778 .54843 .4096 .5449 .40255 .53809 Mtetra
.612 .739 .936 r
.40255 .53809 .4096 .5449 .42145 .54224 .41442 .53554 Mtetra
.375 .642 .96 r
.41442 .53554 .42145 .54224 .43326 .54318 .42624 .53708 Mtetra
.474 0 0 r
.42624 .53708 .43326 .54318 .44498 .55166 .43792 .54737 Mtetra
.776 .273 0 r
.43792 .54737 .44498 .55166 .45675 .56453 .44963 .56312 Mtetra
.193 0 0 r
.44963 .56312 .45675 .56453 .46888 .56599 .46178 .56604 Mtetra
.947 .902 .747 r
.46178 .56604 .46888 .56599 .48136 .5475 .47439 .5449 Mtetra
.946 .822 .689 r
.47439 .5449 .48136 .5475 .49384 .52361 .48702 .51604 Mtetra
.862 .769 .758 r
.48702 .51604 .49384 .52361 .50617 .50946 .49943 .49842 Mtetra
.699 .673 .821 r
.49943 .49842 .50617 .50946 .51847 .50427 .51175 .49222 Mtetra
.61 .618 .835 r
.51175 .49222 .51847 .50427 .53081 .50176 .52411 .48992 Mtetra
.611 .623 .839 r
.52411 .48992 .53081 .50176 .54322 .49898 .53654 .48757 Mtetra
.631 .641 .842 r
.53654 .48757 .54322 .49898 .55568 .49557 .54903 .48442 Mtetra
.65 .654 .841 r
.54903 .48442 .55568 .49557 .5682 .4917 .56157 .48052 Mtetra
.666 .661 .836 r
.56157 .48052 .5682 .4917 .58078 .48739 .57416 .47587 Mtetra
.681 .662 .825 r
.57416 .47587 .58078 .48739 .59339 .48244 .58679 .47042 Mtetra
.679 .654 .818 r
.58679 .47042 .59339 .48244 .60604 .4772 .59946 .46491 Mtetra
.589 .608 .839 r
.59946 .46491 .60604 .4772 .61882 .47467 .61228 .46335 Mtetra
.064 .318 .801 r
.61228 .46335 .61882 .47467 .63197 .48119 .62554 .47333 Mtetra
.697 .236 0 r
.62554 .47333 .63197 .48119 .64561 .49759 .63936 .49469 Mtetra
.665 .12 0 r
.63936 .49469 .64561 .49759 .65926 .50851 .65314 .50822 Mtetra
.808 .991 .877 r
.65314 .50822 .65926 .50851 .67219 .49911 .66608 .49727 Mtetra
.961 .889 .713 r
.66608 .49727 .67219 .49911 .68457 .47807 .67842 .47321 Mtetra
.911 .854 .773 r
.67842 .47321 .68457 .47807 .69711 .4615 .69094 .45473 Mtetra
.791 .812 .869 r
.69094 .45473 .69711 .4615 .71005 .45264 .7039 .44518 Mtetra
.691 .769 .911 r
.7039 .44518 .71005 .45264 .72324 .44746 .71712 .43983 Mtetra
.661 .754 .919 r
.71712 .43983 .72324 .44746 .73653 .44318 .73046 .4355 Mtetra
.656 .752 .92 r
.73046 .4355 .73653 .44318 .7499 .43902 .74387 .4313 Mtetra
.656 .751 .92 r
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Mtetra
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .42221 .79816 .41434 Mtetra
.79816 .41434 .80401 .42221 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Mtetra
.655 .751 .92 r
.3717 .53849 .37888 .54531 .39069 .54164 .38354 .53478 Mtetra
.65 .75 .923 r
.38354 .53478 .39069 .54164 .40255 .53809 .39543 .53122 Mtetra
.609 .737 .936 r
.39543 .53122 .40255 .53809 .41442 .53554 .40734 .52871 Mtetra
.352 .628 .956 r
.40734 .52871 .41442 .53554 .42624 .53708 .41916 .53057 Mtetra
.519 .005 0 r
.41916 .53057 .42624 .53708 .43792 .54737 .43082 .54191 Mtetra
.799 .314 0 r
.43082 .54191 .43792 .54737 .44963 .56312 .44248 .55985 Mtetra
0 .287 .645 r
.44248 .55985 .44963 .56312 .46178 .56604 .4546 .56538 Mtetra
.94 .894 .756 r
.4546 .56538 .46178 .56604 .47439 .5449 .4673 .54487 Mtetra
.968 .846 .668 r
.4673 .54487 .47439 .5449 .48702 .51604 .48008 .51306 Mtetra
.93 .843 .736 r
.48008 .51306 .48702 .51604 .49943 .49842 .49262 .49082 Mtetra
.779 .767 .842 r
.49262 .49082 .49943 .49842 .51175 .49222 .505 .48149 Mtetra
.633 .654 .853 r
.505 .48149 .51175 .49222 .52411 .48992 .51738 .47832 Mtetra
.606 .626 .845 r
.51738 .47832 .52411 .48992 .53654 .48757 .52982 .47614 Mtetra
.625 .639 .844 r
.52982 .47614 .53654 .48757 .54903 .48442 .54233 .47321 Mtetra
.649 .654 .841 r
.54233 .47321 .54903 .48442 .56157 .48052 .5549 .46928 Mtetra
.671 .664 .834 r
.5549 .46928 .56157 .48052 .57416 .47587 .56751 .46435 Mtetra
.685 .665 .825 r
.56751 .46435 .57416 .47587 .58679 .47042 .58016 .45866 Mtetra
.664 .653 .829 r
.58016 .45866 .58679 .47042 .59946 .46491 .59287 .45396 Mtetra
.479 .58 .878 r
.59287 .45396 .59946 .46491 .61228 .46335 .60579 .45548 Mtetra
0 0 .528 r
.60579 .45548 .61228 .46335 .62554 .47333 .61919 .47006 Mtetra
.841 .375 .017 r
.61919 .47006 .62554 .47333 .63936 .49469 .63312 .49437 Mtetra
.703 .166 0 r
.63312 .49437 .63936 .49469 .65314 .50822 .64691 .50719 Mtetra
.879 .968 .845 r
.64691 .50719 .65314 .50822 .66608 .49727 .65982 .49351 Mtetra
.953 .847 .7 r
.65982 .49351 .66608 .49727 .67842 .47321 .67216 .46716 Mtetra
.906 .826 .757 r
.67216 .46716 .67842 .47321 .69094 .45473 .6847 .44754 Mtetra
.794 .803 .86 r
.6847 .44754 .69094 .45473 .7039 .44518 .69769 .4376 Mtetra
.693 .767 .908 r
.69769 .4376 .7039 .44518 .71712 .43983 .71096 .43213 Mtetra
.661 .754 .919 r
.71096 .43213 .71712 .43983 .73046 .4355 .72434 .42775 Mtetra
.656 .752 .92 r
.72434 .42775 .73046 .4355 .74387 .4313 .73779 .42351 Mtetra
.656 .751 .92 r
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Mtetra
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40207 Mtetra
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Mtetra
.655 .751 .92 r
.36447 .53161 .3717 .53849 .38354 .53478 .37634 .52788 Mtetra
.65 .75 .923 r
.37634 .52788 .38354 .53478 .39543 .53122 .38826 .52429 Mtetra
.606 .736 .937 r
.38826 .52429 .39543 .53122 .40734 .52871 .40019 .52181 Mtetra
.337 .619 .954 r
.40019 .52181 .40734 .52871 .41916 .53057 .41203 .52386 Mtetra
.539 .028 0 r
.41203 .52386 .41916 .53057 .43082 .54191 .42367 .53567 Mtetra
.801 .324 0 r
.42367 .53567 .43082 .54191 .44248 .55985 .4353 .55451 Mtetra
0 .252 .693 r
.4353 .55451 .44248 .55985 .4546 .56538 .44741 .56176 Mtetra
.902 .848 .781 r
.44741 .56176 .4546 .56538 .4673 .54487 .46013 .54394 Mtetra
.96 .843 .682 r
.46013 .54394 .4673 .54487 .48008 .51306 .473 .514 Mtetra
.961 .906 .719 r
.473 .514 .48008 .51306 .49262 .49082 .48566 .49043 Mtetra
.885 .957 .843 r
.48566 .49043 .49262 .49082 .505 .48149 .49815 .47697 Mtetra
.762 .858 .921 r
.49815 .47697 .505 .48149 .51738 .47832 .51059 .46953 Mtetra
.68 .717 .877 r
.51059 .46953 .51738 .47832 .52982 .47614 .52306 .46469 Mtetra
.65 .651 .837 r
.52306 .46469 .52982 .47614 .54233 .47321 .53559 .46067 Mtetra
.646 .631 .821 r
.53559 .46067 .54233 .47321 .5549 .46928 .54817 .4567 Mtetra
.644 .63 .822 r
.54817 .4567 .5549 .46928 .56751 .46435 .56081 .45278 Mtetra
.627 .64 .844 r
.56081 .45278 .56751 .46435 .58016 .45866 .57353 .44971 Mtetra
.532 .657 .915 r
.57353 .44971 .58016 .45866 .59287 .45396 .58636 .44926 Mtetra
0 .397 .804 r
.58636 .44926 .59287 .45396 .60579 .45548 .59941 .45491 Mtetra
.767 .259 0 r
.59941 .45491 .60579 .45548 .61919 .47006 .61288 .47077 Mtetra
.833 .374 .12 r
.61288 .47077 .61919 .47006 .63312 .49437 .62677 .4931 Mtetra
.599 .027 0 r
.62677 .4931 .63312 .49437 .64691 .50719 .6405 .50314 Mtetra
.892 .883 .817 r
.6405 .50314 .64691 .50719 .65982 .49351 .65342 .48764 Mtetra
.938 .812 .695 r
.65342 .48764 .65982 .49351 .67216 .46716 .6658 .4603 Mtetra
.901 .81 .75 r
.6658 .4603 .67216 .46716 .6847 .44754 .67839 .44012 Mtetra
.796 .799 .855 r
.67839 .44012 .6847 .44754 .69769 .4376 .69143 .42992 Mtetra
.695 .767 .907 r
.69143 .42992 .69769 .4376 .71096 .43213 .70474 .42436 Mtetra
.661 .754 .919 r
.70474 .42436 .71096 .43213 .72434 .42775 .71816 .41993 Mtetra
.656 .752 .92 r
.71816 .41993 .72434 .42775 .73779 .42351 .73166 .41566 Mtetra
.656 .751 .92 r
.73166 .41566 .73779 .42351 .75131 .41926 .74523 .41137 Mtetra
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40207 .80014 .39403 Mtetra
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Mtetra
.33352 .53219 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52468 Mtetra
.655 .751 .92 r
.35717 .52468 .36447 .53161 .37634 .52788 .36907 .52091 Mtetra
.649 .75 .923 r
.36907 .52091 .37634 .52788 .38826 .52429 .38103 .5173 Mtetra
.604 .736 .938 r
.38103 .5173 .38826 .52429 .40019 .52181 .39299 .51486 Mtetra
.322 .611 .952 r
.39299 .51486 .40019 .52181 .41203 .52386 .40484 .51708 Mtetra
.556 .045 0 r
.40484 .51708 .41203 .52386 .42367 .53567 .41647 .52919 Mtetra
.8 .323 0 r
.41647 .52919 .42367 .53567 .4353 .55451 .42808 .54816 Mtetra
0 .296 .757 r
.42808 .54816 .4353 .55451 .44741 .56176 .4402 .55538 Mtetra
.868 .795 .776 r
.4402 .55538 .44741 .56176 .46013 .54394 .45298 .53849 Mtetra
.92 .79 .701 r
.45298 .53849 .46013 .54394 .473 .514 .4659 .51133 Mtetra
.924 .862 .761 r
.4659 .51133 .473 .514 .48566 .49043 .4786 .49135 Mtetra
.814 .995 .863 r
.4786 .49135 .48566 .49043 .49815 .47697 .49115 .48023 Mtetra
.436 .853 .697 r
.49115 .48023 .49815 .47697 .51059 .46953 .50368 .47294 Mtetra
0 0 0 r
.50368 .47294 .51059 .46953 .52306 .46469 .51623 .46688 Mtetra
.323 .799 .72 r
.51623 .46688 .52306 .46469 .53559 .46067 .52883 .46178 Mtetra
.315 .804 .789 r
.52883 .46178 .53559 .46067 .54817 .4567 .54148 .4578 Mtetra
.197 .724 .739 r
.54148 .4578 .54817 .4567 .56081 .45278 .55421 .45493 Mtetra
.008 0 0 r
.55421 .45493 .56081 .45278 .57353 .44971 .56701 .45304 Mtetra
.206 0 0 r
.56701 .45304 .57353 .44971 .58636 .44926 .57991 .45238 Mtetra
.441 0 0 r
.57991 .45238 .58636 .44926 .59941 .45491 .59298 .45559 Mtetra
.707 .179 0 r
.59298 .45559 .59941 .45491 .61288 .47077 .60639 .46777 Mtetra
.79 .293 0 r
.60639 .46777 .61288 .47077 .62677 .4931 .6202 .48724 Mtetra
0 .236 .703 r
.6202 .48724 .62677 .4931 .6405 .50314 .63393 .49626 Mtetra
.865 .815 .799 r
.63393 .49626 .6405 .50314 .65342 .48764 .64691 .48072 Mtetra
.929 .797 .694 r
.64691 .48072 .65342 .48764 .6658 .4603 .65938 .45318 Mtetra
.9 .806 .746 r
.65938 .45318 .6658 .4603 .67839 .44012 .67203 .43263 Mtetra
.799 .799 .852 r
.67203 .43263 .67839 .44012 .69143 .42992 .68511 .42219 Mtetra
.697 .768 .907 r
.68511 .42219 .69143 .42992 .70474 .42436 .69846 .41653 Mtetra
.662 .754 .919 r
.69846 .41653 .70474 .42436 .71816 .41993 .71193 .41205 Mtetra
.656 .752 .92 r
.71193 .41205 .71816 .41993 .73166 .41566 .72548 .40773 Mtetra
.656 .751 .92 r
.72548 .40773 .73166 .41566 .74523 .41137 .73909 .40341 Mtetra
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52525 Mtetra
.32609 .52525 .33352 .53219 .34532 .52844 .33793 .52148 Mtetra
.33793 .52148 .34532 .52844 .35717 .52468 .34981 .51768 Mtetra
.655 .751 .92 r
.34981 .51768 .35717 .52468 .36907 .52091 .36175 .51389 Mtetra
.649 .749 .923 r
.36175 .51389 .36907 .52091 .38103 .5173 .37373 .51026 Mtetra
.601 .735 .938 r
.37373 .51026 .38103 .5173 .39299 .51486 .38572 .50785 Mtetra
.305 .602 .95 r
.38572 .50785 .39299 .51486 .40484 .51708 .39759 .51026 Mtetra
.574 .063 0 r
.39759 .51026 .40484 .51708 .41647 .52919 .40921 .52267 Mtetra
.8 .323 0 r
.40921 .52267 .41647 .52919 .42808 .54816 .4208 .54164 Mtetra
0 .344 .797 r
.4208 .54164 .42808 .54816 .4402 .55538 .43295 .54827 Mtetra
.864 .781 .768 r
.43295 .54827 .4402 .55538 .45298 .53849 .44581 .53085 Mtetra
.901 .762 .7 r
.44581 .53085 .45298 .53849 .4659 .51133 .4588 .50398 Mtetra
.872 .777 .753 r
.4588 .50398 .4659 .51133 .4786 .49135 .47156 .48516 Mtetra
.789 .81 .869 r
.47156 .48516 .4786 .49135 .49115 .48023 .48414 .47592 Mtetra
.679 .855 .966 r
.48414 .47592 .49115 .48023 .50368 .47294 .4967 .47088 Mtetra
.569 .896 .984 r
.4967 .47088 .50368 .47294 .51623 .46688 .50931 .46679 Mtetra
.431 .87 .899 r
.50931 .46679 .51623 .46688 .52883 .46178 .52198 .46278 Mtetra
.328 .812 .802 r
.52198 .46278 .52883 .46178 .54148 .4578 .5347 .45877 Mtetra
.328 .812 .803 r
.5347 .45877 .54148 .4578 .55421 .45493 .54749 .45475 Mtetra
.422 .865 .898 r
.54749 .45475 .55421 .45493 .56701 .45304 .56033 .45081 Mtetra
.483 .859 .983 r
.56033 .45081 .56701 .45304 .57991 .45238 .57325 .44784 Mtetra
.271 .673 .969 r
.57325 .44784 .57991 .45238 .59298 .45559 .58632 .44912 Mtetra
0 .126 .619 r
.58632 .44912 .59298 .45559 .60639 .46777 .59972 .46006 Mtetra
.651 .178 0 r
.59972 .46006 .60639 .46777 .6202 .48724 .61352 .47915 Mtetra
0 .281 .775 r
.61352 .47915 .6202 .48724 .63393 .49626 .62727 .48864 Mtetra
.852 .8 .799 r
.62727 .48864 .63393 .49626 .64691 .48072 .64034 .47363 Mtetra
.928 .795 .694 r
.64034 .47363 .64691 .48072 .65938 .45318 .6529 .44602 Mtetra
.902 .806 .743 r
.6529 .44602 .65938 .45318 .67203 .43263 .66561 .42509 Mtetra
.802 .8 .85 r
.66561 .42509 .67203 .43263 .68511 .42219 .67874 .41439 Mtetra
.698 .769 .906 r
.67874 .41439 .68511 .42219 .69846 .41653 .69213 .40862 Mtetra
.662 .754 .918 r
.69213 .40862 .69846 .41653 .71193 .41205 .70565 .40409 Mtetra
.656 .752 .92 r
.70565 .40409 .71193 .41205 .72548 .40773 .71923 .39974 Mtetra
.656 .751 .92 r
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Mtetra
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Mtetra
.655 .751 .921 r
.34239 .51063 .34981 .51768 .36175 .51389 .35436 .50681 Mtetra
.648 .749 .923 r
.35436 .50681 .36175 .51389 .37373 .51026 .36638 .50316 Mtetra
.598 .734 .939 r
.36638 .50316 .37373 .51026 .38572 .50785 .3784 .5008 Mtetra
.286 .592 .947 r
.3784 .5008 .38572 .50785 .39759 .51026 .39027 .50341 Mtetra
.593 .082 0 r
.39027 .50341 .39759 .51026 .40921 .52267 .40188 .51614 Mtetra
.8 .322 0 r
.40188 .51614 .40921 .52267 .4208 .54164 .41346 .53508 Mtetra
0 .391 .832 r
.41346 .53508 .4208 .54164 .43295 .54827 .42564 .54104 Mtetra
.867 .78 .762 r
.42564 .54104 .43295 .54827 .44581 .53085 .43858 .52297 Mtetra
.899 .76 .7 r
.43858 .52297 .44581 .53085 .4588 .50398 .45166 .49608 Mtetra
.866 .769 .753 r
.45166 .49608 .4588 .50398 .47156 .48516 .46448 .47754 Mtetra
.774 .773 .852 r
.46448 .47754 .47156 .48516 .48414 .47592 .4771 .46846 Mtetra
.686 .759 .907 r
.4771 .46846 .48414 .47592 .4967 .47088 .4897 .46343 Mtetra
.658 .752 .919 r
.4897 .46343 .4967 .47088 .50931 .46679 .50235 .45929 Mtetra
.655 .751 .92 r
.50235 .45929 .50931 .46679 .52198 .46278 .51505 .45524 Mtetra
.654 .75 .92 r
.51505 .45524 .52198 .46278 .5347 .45877 .52782 .4512 Mtetra
.653 .75 .921 r
.52782 .4512 .5347 .45877 .54749 .45475 .54064 .44716 Mtetra
.65 .75 .922 r
.54064 .44716 .54749 .45475 .56033 .45081 .55352 .44321 Mtetra
.618 .739 .932 r
.55352 .44321 .56033 .45081 .57325 .44784 .56648 .44014 Mtetra
.429 .651 .952 r
.56648 .44014 .57325 .44784 .58632 .44912 .57958 .44115 Mtetra
0 .2 .71 r
.57958 .44115 .58632 .44912 .59972 .46006 .59298 .45174 Mtetra
.625 .161 0 r
.59298 .45174 .59972 .46006 .61352 .47915 .60677 .4708 Mtetra
0 .254 .757 r
.60677 .4708 .61352 .47915 .62727 .48864 .62056 .48089 Mtetra
.845 .798 .806 r
.62056 .48089 .62727 .48864 .64034 .47363 .63371 .46649 Mtetra
.928 .796 .694 r
.63371 .46649 .64034 .47363 .6529 .44602 .64636 .43884 Mtetra
.904 .807 .741 r
.64636 .43884 .6529 .44602 .66561 .42509 .65914 .41752 Mtetra
.806 .802 .847 r
.65914 .41752 .66561 .42509 .67874 .41439 .67231 .40654 Mtetra
.7 .77 .906 r
.67231 .40654 .67874 .41439 .69213 .40862 .68575 .40065 Mtetra
.663 .754 .918 r
.68575 .40065 .69213 .40862 .70565 .40409 .6993 .39607 Mtetra
.656 .752 .92 r
.6993 .39607 .70565 .40409 .71923 .39974 .71294 .39167 Mtetra
.656 .751 .92 r
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Mtetra
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Mtetra
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Mtetra
.655 .751 .921 r
.33491 .50352 .34239 .51063 .35436 .50681 .34692 .49967 Mtetra
.648 .749 .923 r
.34692 .49967 .35436 .50681 .36638 .50316 .35897 .49601 Mtetra
.594 .733 .94 r
.35897 .49601 .36638 .50316 .3784 .5008 .37101 .49369 Mtetra
.264 .58 .943 r
.37101 .49369 .3784 .5008 .39027 .50341 .38289 .49653 Mtetra
.611 .101 0 r
.38289 .49653 .39027 .50341 .40188 .51614 .39448 .50959 Mtetra
.799 .321 0 r
.39448 .50959 .40188 .51614 .41346 .53508 .40605 .52847 Mtetra
.015 .443 .868 r
.40605 .52847 .41346 .53508 .42564 .54104 .41827 .53369 Mtetra
.871 .778 .756 r
.41827 .53369 .42564 .54104 .43858 .52297 .4313 .51486 Mtetra
.898 .758 .698 r
.4313 .51486 .43858 .52297 .45166 .49608 .44447 .48761 Mtetra
.864 .76 .746 r
.44447 .48761 .45166 .49608 .46448 .47754 .45737 .46839 Mtetra
.783 .743 .816 r
.45737 .46839 .46448 .47754 .4771 .46846 .47006 .45775 Mtetra
.716 .695 .829 r
.47006 .45775 .4771 .46846 .4897 .46343 .48271 .45065 Mtetra
.682 .648 .81 r
.48271 .45065 .4897 .46343 .50235 .45929 .49539 .44468 Mtetra
.657 .612 .792 r
.49539 .44468 .50235 .45929 .51505 .45524 .50811 .4396 Mtetra
.635 .589 .785 r
.50811 .4396 .51505 .45524 .52782 .4512 .52088 .4355 Mtetra
.616 .579 .79 r
.52088 .4355 .52782 .4512 .54064 .44716 .53372 .4324 Mtetra
.598 .582 .806 r
.53372 .4324 .54064 .44716 .55352 .44321 .54662 .43018 Mtetra
.568 .594 .839 r
.54662 .43018 .55352 .44321 .56648 .44014 .55962 .42915 Mtetra
.422 .559 .887 r
.55962 .42915 .56648 .44014 .57958 .44115 .57276 .43169 Mtetra
0 .209 .73 r
.57276 .43169 .57958 .44115 .59298 .45174 .58617 .44289 Mtetra
.612 .156 0 r
.58617 .44289 .59298 .45174 .60677 .4708 .59996 .46222 Mtetra
0 .221 .733 r
.59996 .46222 .60677 .4708 .62056 .48089 .61378 .473 Mtetra
.836 .797 .814 r
.61378 .473 .62056 .48089 .63371 .46649 .62702 .4593 Mtetra
.928 .796 .695 r
.62702 .4593 .63371 .46649 .64636 .43884 .63976 .43164 Mtetra
.906 .807 .738 r
.63976 .43164 .64636 .43884 .65914 .41752 .65261 .4099 Mtetra
.81 .803 .845 r
.65261 .4099 .65914 .41752 .67231 .40654 .66582 .39862 Mtetra
.703 .771 .905 r
.66582 .39862 .67231 .40654 .68575 .40065 .6793 .39261 Mtetra
.663 .755 .918 r
.6793 .39261 .68575 .40065 .6993 .39607 .69291 .38797 Mtetra
.656 .752 .92 r
.69291 .38797 .6993 .39607 .71294 .39167 .70659 .38354 Mtetra
.656 .751 .92 r
.70659 .38354 .71294 .39167 .72664 .38727 .72033 .3791 Mtetra
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .3428 Mtetra
.83275 .3428 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Mtetra
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Mtetra
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49636 Mtetra
.655 .751 .921 r
.32737 .49636 .33491 .50352 .34692 .49967 .33941 .49247 Mtetra
.647 .749 .924 r
.33941 .49247 .34692 .49967 .35897 .49601 .35149 .48879 Mtetra
.591 .731 .941 r
.35149 .48879 .35897 .49601 .37101 .49369 .36355 .48654 Mtetra
.241 .567 .938 r
.36355 .48654 .37101 .49369 .38289 .49653 .37545 .48962 Mtetra
.628 .118 0 r
.37545 .48962 .38289 .49653 .39448 .50959 .38702 .50301 Mtetra
.794 .314 0 r
.38702 .50301 .39448 .50959 .40605 .52847 .39858 .52165 Mtetra
.162 .534 .923 r
.39858 .52165 .40605 .52847 .41827 .53369 .41087 .52544 Mtetra
.874 .762 .735 r
.41087 .52544 .41827 .53369 .4313 .51486 .42403 .50422 Mtetra
.887 .728 .679 r
.42403 .50422 .4313 .51486 .44447 .48761 .43736 .47405 Mtetra
.835 .693 .706 r
.43736 .47405 .44447 .48761 .45737 .46839 .45037 .45197 Mtetra
.743 .632 .737 r
.45037 .45197 .45737 .46839 .47006 .45775 .46311 .43971 Mtetra
.67 .582 .748 r
.46311 .43971 .47006 .45775 .48271 .45065 .47576 .43282 Mtetra
.638 .567 .759 r
.47576 .43282 .48271 .45065 .49539 .44468 .48843 .42812 Mtetra
.632 .577 .775 r
.48843 .42812 .49539 .44468 .50811 .4396 .50115 .42405 Mtetra
.635 .591 .787 r
.50115 .42405 .50811 .4396 .52088 .4355 .51392 .41992 Mtetra
.636 .591 .787 r
.51392 .41992 .52088 .4355 .53372 .4324 .52676 .41574 Mtetra
.621 .572 .778 r
.52676 .41574 .53372 .4324 .54662 .43018 .53966 .41217 Mtetra
.577 .534 .77 r
.53966 .41217 .54662 .43018 .55962 .42915 .55265 .41079 Mtetra
.452 .458 .774 r
.55265 .41079 .55962 .42915 .57276 .43169 .56579 .41482 Mtetra
.058 .226 .722 r
.56579 .41482 .57276 .43169 .58617 .44289 .57922 .42882 Mtetra
0 0 .485 r
.57922 .42882 .58617 .44289 .59996 .46222 .59304 .45105 Mtetra
0 .174 .71 r
.59304 .45105 .59996 .46222 .61378 .473 .60692 .4642 Mtetra
.81 .775 .82 r
.60692 .4642 .61378 .473 .62702 .4593 .62027 .45187 Mtetra
.926 .794 .696 r
.62027 .45187 .62702 .4593 .63976 .43164 .6331 .42439 Mtetra
.908 .807 .735 r
.6331 .42439 .63976 .43164 .65261 .4099 .64601 .40225 Mtetra
.814 .804 .842 r
.64601 .40225 .65261 .4099 .66582 .39862 .65928 .39064 Mtetra
.705 .772 .904 r
.65928 .39064 .66582 .39862 .6793 .39261 .6728 .3845 Mtetra
.664 .755 .918 r
.6728 .3845 .6793 .39261 .69291 .38797 .68645 .37981 Mtetra
.656 .752 .92 r
.68645 .37981 .69291 .38797 .70659 .38354 .70018 .37533 Mtetra
.656 .751 .92 r
.70018 .37533 .70659 .38354 .72033 .3791 .71397 .37085 Mtetra
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .3428 .82677 .33423 Mtetra
.82677 .33423 .83275 .3428 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Mtetra
.30775 .49305 .31539 .50024 .32737 .49636 .31976 .48913 Mtetra
.655 .751 .921 r
.31976 .48913 .32737 .49636 .33941 .49247 .33184 .48521 Mtetra
.646 .749 .924 r
.33184 .48521 .33941 .49247 .35149 .48879 .34395 .48152 Mtetra
.586 .73 .942 r
.34395 .48152 .35149 .48879 .36355 .48654 .35604 .47933 Mtetra
.22 .555 .934 r
.35604 .47933 .36355 .48654 .37545 .48962 .36794 .48262 Mtetra
.629 .12 0 r
.36794 .48262 .37545 .48962 .38702 .50301 .3795 .49606 Mtetra
.759 .271 0 r
.3795 .49606 .38702 .50301 .39858 .52165 .39109 .51344 Mtetra
.468 .659 .944 r
.39109 .51344 .39858 .52165 .41087 .52544 .40352 .51379 Mtetra
.862 .717 .7 r
.40352 .51379 .41087 .52544 .42403 .50422 .41687 .48863 Mtetra
.857 .683 .666 r
.41687 .48863 .42403 .50422 .43736 .47405 .43031 .45719 Mtetra
.796 .652 .703 r
.43031 .45719 .43736 .47405 .45037 .45197 .44329 .43771 Mtetra
.701 .637 .782 r
.44329 .43771 .45037 .45197 .46311 .43971 .45596 .4301 Mtetra
.616 .684 .891 r
.45596 .4301 .46311 .43971 .47576 .43282 .46858 .42726 Mtetra
.567 .786 .981 r
.46858 .42726 .47576 .43282 .48843 .42812 .48126 .42484 Mtetra
.552 .857 .997 r
.48126 .42484 .48843 .42812 .50115 .42405 .49403 .42159 Mtetra
.579 .893 .988 r
.49403 .42159 .50115 .42405 .51392 .41992 .50687 .41741 Mtetra
.634 .91 .982 r
.50687 .41741 .51392 .41992 .52676 .41574 .51977 .4123 Mtetra
.692 .898 .971 r
.51977 .4123 .52676 .41574 .53966 .41217 .53272 .40637 Mtetra
.693 .822 .944 r
.53272 .40637 .53966 .41217 .55265 .41079 .54572 .40089 Mtetra
.537 .647 .905 r
.54572 .40089 .55265 .41079 .56579 .41482 .55882 .40022 Mtetra
.092 .285 .767 r
.55882 .40022 .56579 .41482 .57922 .42882 .5722 .4115 Mtetra
0 0 .531 r
.5722 .4115 .57922 .42882 .59304 .45105 .58599 .43488 Mtetra
0 .128 .67 r
.58599 .43488 .59304 .45105 .60692 .4642 .59993 .45193 Mtetra
.732 .69 .811 r
.59993 .45193 .60692 .4642 .62027 .45187 .61341 .44303 Mtetra
.909 .777 .703 r
.61341 .44303 .62027 .45187 .6331 .42439 .62637 .41676 Mtetra
.905 .801 .734 r
.62637 .41676 .6331 .42439 .64601 .40225 .63936 .3945 Mtetra
.817 .804 .839 r
.63936 .3945 .64601 .40225 .65928 .39064 .65268 .3826 Mtetra
.708 .773 .903 r
.65268 .3826 .65928 .39064 .6728 .3845 .66625 .37632 Mtetra
.664 .755 .918 r
.66625 .37632 .6728 .3845 .68645 .37981 .67994 .37156 Mtetra
.657 .752 .92 r
.67994 .37156 .68645 .37981 .70018 .37533 .69371 .36704 Mtetra
.656 .751 .92 r
.69371 .36704 .70018 .37533 .71397 .37085 .70755 .36252 Mtetra
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34884 Mtetra
.74947 .34884 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Mtetra
.30005 .48579 .30775 .49305 .31976 .48913 .31209 .48184 Mtetra
.655 .751 .921 r
.31209 .48184 .31976 .48913 .33184 .48521 .3242 .47789 Mtetra
.646 .749 .924 r
.3242 .47789 .33184 .48521 .34395 .48152 .33634 .47418 Mtetra
.584 .729 .943 r
.33634 .47418 .34395 .48152 .35604 .47933 .34846 .47202 Mtetra
.222 .555 .933 r
.34846 .47202 .35604 .47933 .36794 .48262 .36038 .4753 Mtetra
.574 .068 0 r
.36038 .4753 .36794 .48262 .3795 .49606 .37197 .48794 Mtetra
.617 .128 0 r
.37197 .48794 .3795 .49606 .39109 .51344 .38366 .50247 Mtetra
.637 .664 .86 r
.38366 .50247 .39109 .51344 .40352 .51379 .39626 .49886 Mtetra
.842 .684 .687 r
.39626 .49886 .40352 .51379 .41687 .48863 .40969 .47289 Mtetra
.842 .678 .679 r
.40969 .47289 .41687 .48863 .43031 .45719 .42307 .44549 Mtetra
.799 .706 .762 r
.42307 .44549 .43031 .45719 .44329 .43771 .43597 .43122 Mtetra
.676 .79 .935 r
.43597 .43122 .44329 .43771 .45596 .4301 .44862 .42642 Mtetra
.51 .828 1 r
.44862 .42642 .45596 .4301 .46858 .42726 .46128 .42402 Mtetra
.518 .846 .998 r
.46128 .42402 .46858 .42726 .48126 .42484 .47402 .42123 Mtetra
.577 .858 .996 r
.47402 .42123 .48126 .42484 .49403 .42159 .48684 .4177 Mtetra
.619 .863 .989 r
.48684 .4177 .49403 .42159 .50687 .41741 .49973 .41353 Mtetra
.65 .874 .982 r
.49973 .41353 .50687 .41741 .51977 .4123 .51269 .4087 Mtetra
.678 .891 .975 r
.51269 .4087 .51977 .4123 .53272 .40637 .5257 .40309 Mtetra
.692 .905 .971 r
.5257 .40309 .53272 .40637 .54572 .40089 .53876 .39702 Mtetra
.585 .856 .995 r
.53876 .39702 .54572 .40089 .55882 .40022 .55189 .39334 Mtetra
.013 .43 .864 r
.55189 .39334 .55882 .40022 .5722 .4115 .56521 .39928 Mtetra
0 0 .511 r
.56521 .39928 .5722 .4115 .58599 .43488 .5789 .41852 Mtetra
0 .102 .653 r
.5789 .41852 .58599 .43488 .59993 .45193 .59282 .43631 Mtetra
.647 .606 .794 r
.59282 .43631 .59993 .45193 .61341 .44303 .60642 .43135 Mtetra
.872 .738 .713 r
.60642 .43135 .61341 .44303 .62637 .41676 .61955 .40791 Mtetra
.89 .782 .736 r
.61955 .40791 .62637 .41676 .63936 .3945 .63264 .3864 Mtetra
.815 .797 .835 r
.63264 .3864 .63936 .3945 .65268 .3826 .64602 .37445 Mtetra
.709 .772 .902 r
.64602 .37445 .65268 .3826 .66625 .37632 .65963 .36806 Mtetra
.665 .755 .918 r
.65963 .36806 .66625 .37632 .67994 .37156 .67337 .36325 Mtetra
.657 .752 .92 r
.67337 .36325 .67994 .37156 .69371 .36704 .68718 .35868 Mtetra
.656 .751 .92 r
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Mtetra
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34884 .74314 .34031 Mtetra
.74314 .34031 .74947 .34884 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Mtetra
.29228 .47847 .30005 .48579 .31209 .48184 .30436 .47449 Mtetra
.655 .751 .921 r
.30436 .47449 .31209 .48184 .3242 .47789 .3165 .4705 Mtetra
.646 .749 .924 r
.3165 .4705 .3242 .47789 .33634 .47418 .32867 .46676 Mtetra
.587 .729 .942 r
.32867 .46676 .33634 .47418 .34846 .47202 .34083 .46451 Mtetra
.272 .58 .942 r
.34083 .46451 .34846 .47202 .36038 .4753 .35278 .46727 Mtetra
0 .072 .583 r
.35278 .46727 .36038 .4753 .37197 .48794 .36446 .47803 Mtetra
0 .123 .658 r
.36446 .47803 .37197 .48794 .38366 .50247 .37629 .48919 Mtetra
.667 .638 .812 r
.37629 .48919 .38366 .50247 .39626 .49886 .38896 .48385 Mtetra
.828 .68 .699 r
.38896 .48385 .39626 .49886 .40969 .47289 .40234 .46096 Mtetra
.849 .714 .714 r
.40234 .46096 .40969 .47289 .42307 .44549 .41562 .43888 Mtetra
.813 .807 .846 r
.41562 .43888 .42307 .44549 .43597 .43122 .42848 .42781 Mtetra
.612 .874 .991 r
.42848 .42781 .43597 .43122 .44862 .42642 .44117 .42364 Mtetra
.496 .85 .993 r
.44117 .42364 .44862 .42642 .46128 .42402 .4539 .42086 Mtetra
.546 .86 .997 r
.4539 .42086 .46128 .42402 .47402 .42123 .4667 .41757 Mtetra
.595 .863 .994 r
.4667 .41757 .47402 .42123 .48684 .4177 .47958 .41372 Mtetra
.622 .863 .988 r
.47958 .41372 .48684 .4177 .49973 .41353 .49252 .40949 Mtetra
.64 .867 .984 r
.49252 .40949 .49973 .41353 .51269 .4087 .50553 .40487 Mtetra
.66 .881 .98 r
.50553 .40487 .51269 .4087 .5257 .40309 .5186 .3997 Mtetra
.671 .898 .978 r
.5186 .3997 .5257 .40309 .53876 .39702 .53173 .39409 Mtetra
.585 .887 .991 r
.53173 .39409 .53876 .39702 .55189 .39334 .54492 .38984 Mtetra
.046 .563 .872 r
.54492 .38984 .55189 .39334 .56521 .39928 .55824 .39244 Mtetra
.511 .008 0 r
.55824 .39244 .56521 .39928 .5789 .41852 .57184 .40612 Mtetra
0 .134 .681 r
.57184 .40612 .5789 .41852 .59282 .43631 .58568 .4206 Mtetra
.614 .59 .802 r
.58568 .4206 .59282 .43631 .60642 .43135 .59934 .41728 Mtetra
.831 .703 .722 r
.59934 .41728 .60642 .43135 .61955 .40791 .61261 .3972 Mtetra
.86 .753 .743 r
.61261 .3972 .61955 .40791 .63264 .3864 .62583 .37755 Mtetra
.801 .78 .833 r
.62583 .37755 .63264 .3864 .64602 .37445 .63929 .36608 Mtetra
.707 .768 .9 r
.63929 .36608 .64602 .37445 .65963 .36806 .65295 .35971 Mtetra
.665 .755 .917 r
.65295 .35971 .65963 .36806 .67337 .36325 .66674 .35486 Mtetra
.657 .752 .92 r
.66674 .35486 .67337 .36325 .68718 .35868 .6806 .35025 Mtetra
.656 .751 .92 r
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Mtetra
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Mtetra
.28444 .47109 .29228 .47847 .30436 .47449 .29656 .46707 Mtetra
.655 .751 .921 r
.29656 .46707 .30436 .47449 .3165 .4705 .30873 .46305 Mtetra
.647 .749 .924 r
.30873 .46305 .3165 .4705 .32867 .46676 .32094 .45924 Mtetra
.598 .732 .938 r
.32094 .45924 .32867 .46676 .34083 .46451 .33314 .45671 Mtetra
.365 .622 .951 r
.33314 .45671 .34083 .46451 .35278 .46727 .34517 .45837 Mtetra
0 .272 .769 r
.34517 .45837 .35278 .46727 .36446 .47803 .35697 .46657 Mtetra
.018 .309 .8 r
.35697 .46657 .36446 .47803 .37629 .48919 .36891 .47507 Mtetra
.645 .617 .807 r
.36891 .47507 .37629 .48919 .38896 .48385 .38156 .47064 Mtetra
.815 .694 .731 r
.38156 .47064 .38896 .48385 .40234 .46096 .39481 .45258 Mtetra
.858 .767 .76 r
.39481 .45258 .40234 .46096 .41562 .43888 .408 .43468 Mtetra
.817 .876 .889 r
.408 .43468 .41562 .43888 .42848 .42781 .42091 .42449 Mtetra
.665 .891 .979 r
.42091 .42449 .42848 .42781 .44117 .42364 .43368 .41921 Mtetra
.621 .846 .985 r
.43368 .41921 .44117 .42364 .4539 .42086 .44648 .41521 Mtetra
.633 .811 .968 r
.44648 .41521 .4539 .42086 .4667 .41757 .45934 .41129 Mtetra
.641 .794 .956 r
.45934 .41129 .4667 .41757 .47958 .41372 .47227 .40727 Mtetra
.647 .791 .952 r
.47227 .40727 .47958 .41372 .49252 .40949 .48526 .4031 Mtetra
.652 .796 .952 r
.48526 .4031 .49252 .40949 .50553 .40487 .49831 .39875 Mtetra
.657 .808 .955 r
.49831 .39875 .50553 .40487 .5186 .3997 .51143 .3942 Mtetra
.656 .828 .966 r
.51143 .3942 .5186 .3997 .53173 .39409 .52461 .38955 Mtetra
.58 .836 .993 r
.52461 .38955 .53173 .39409 .54492 .38984 .53786 .38616 Mtetra
.143 .628 .919 r
.53786 .38616 .54492 .38984 .55824 .39244 .55122 .38785 Mtetra
.424 0 0 r
.55122 .38785 .55824 .39244 .57184 .40612 .56479 .39731 Mtetra
0 .281 .777 r
.56479 .39731 .57184 .40612 .58568 .4206 .57855 .40676 Mtetra
.641 .63 .823 r
.57855 .40676 .58568 .4206 .59934 .41728 .5922 .40233 Mtetra
.805 .686 .733 r
.5922 .40233 .59934 .41728 .61261 .3972 .60559 .38486 Mtetra
.826 .724 .752 r
.60559 .38486 .61261 .3972 .62583 .37755 .61895 .36779 Mtetra
.777 .756 .834 r
.61895 .36779 .62583 .37755 .63929 .36608 .63249 .35739 Mtetra
.699 .759 .898 r
.63249 .35739 .63929 .36608 .65295 .35971 .64621 .35124 Mtetra
.664 .753 .917 r
.64621 .35124 .65295 .35971 .66674 .35486 .66004 .34638 Mtetra
.657 .752 .92 r
.66004 .34638 .66674 .35486 .6806 .35025 .67395 .34174 Mtetra
.656 .751 .92 r
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Mtetra
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Mtetra
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Mtetra
.655 .751 .92 r
.28869 .45959 .29656 .46707 .30873 .46305 .3009 .45553 Mtetra
.65 .749 .922 r
.3009 .45553 .30873 .46305 .32094 .45924 .31315 .45162 Mtetra
.615 .737 .933 r
.31315 .45162 .32094 .45924 .33314 .45671 .3254 .44863 Mtetra
.467 .665 .949 r
.3254 .44863 .33314 .45671 .34517 .45837 .33754 .44879 Mtetra
.148 .446 .879 r
.33754 .44879 .34517 .45837 .35697 .46657 .34948 .4542 Mtetra
.182 .396 .836 r
.34948 .4542 .35697 .46657 .36891 .47507 .36149 .46093 Mtetra
.588 .591 .823 r
.36149 .46093 .36891 .47507 .38156 .47064 .37404 .45894 Mtetra
.788 .707 .774 r
.37404 .45894 .38156 .47064 .39481 .45258 .38713 .44583 Mtetra
.854 .802 .799 r
.38713 .44583 .39481 .45258 .408 .43468 .4003 .43075 Mtetra
.817 .885 .894 r
.4003 .43075 .408 .43468 .42091 .42449 .41326 .42058 Mtetra
.698 .882 .966 r
.41326 .42058 .42091 .42449 .43368 .41921 .42612 .41467 Mtetra
.636 .848 .981 r
.42612 .41467 .43368 .41921 .44648 .41521 .43897 .41035 Mtetra
.629 .837 .98 r
.43897 .41035 .44648 .41521 .45934 .41129 .45189 .40624 Mtetra
.634 .833 .977 r
.45189 .40624 .45934 .41129 .47227 .40727 .46486 .40207 Mtetra
.637 .831 .975 r
.46486 .40207 .47227 .40727 .48526 .4031 .47791 .39783 Mtetra
.638 .83 .974 r
.47791 .39783 .48526 .4031 .49831 .39875 .49101 .39355 Mtetra
.636 .832 .976 r
.49101 .39355 .49831 .39875 .51143 .3942 .50418 .38927 Mtetra
.616 .836 .984 r
.50418 .38927 .51143 .3942 .52461 .38955 .51741 .38531 Mtetra
.518 .823 1 r
.51741 .38531 .52461 .38955 .53786 .38616 .53072 .38276 Mtetra
.145 .639 .914 r
.53072 .38276 .53786 .38616 .55122 .38785 .54412 .38416 Mtetra
0 .306 .679 r
.54412 .38416 .55122 .38785 .56479 .39731 .5577 .39037 Mtetra
.158 .536 .923 r
.5577 .39037 .56479 .39731 .57855 .40676 .57139 .39443 Mtetra
.702 .683 .828 r
.57139 .39443 .57855 .40676 .5922 .40233 .58502 .38725 Mtetra
.79 .68 .742 r
.58502 .38725 .5922 .40233 .60559 .38486 .5985 .37152 Mtetra
.791 .701 .765 r
.5985 .37152 .60559 .38486 .61895 .36779 .61198 .3573 Mtetra
.746 .734 .841 r
.61198 .3573 .61895 .36779 .63249 .35739 .62562 .3484 Mtetra
.687 .749 .899 r
.62562 .3484 .63249 .35739 .64621 .35124 .63941 .34265 Mtetra
.661 .751 .917 r
.63941 .34265 .64621 .35124 .66004 .34638 .65329 .33783 Mtetra
.656 .751 .92 r
.65329 .33783 .66004 .34638 .67395 .34174 .66725 .33315 Mtetra
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Mtetra
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Mtetra
.655 .751 .92 r
.28076 .45205 .28869 .45959 .3009 .45553 .293 .44795 Mtetra
.652 .75 .921 r
.293 .44795 .3009 .45553 .31315 .45162 .30529 .44392 Mtetra
.633 .742 .927 r
.30529 .44392 .31315 .45162 .3254 .44863 .3176 .44043 Mtetra
.551 .699 .938 r
.3176 .44043 .3254 .44863 .33754 .44879 .32985 .43898 Mtetra
.359 .564 .915 r
.32985 .43898 .33754 .44879 .34948 .4542 .34196 .44155 Mtetra
.285 .453 .852 r
.34196 .44155 .34948 .4542 .36149 .46093 .35404 .44668 Mtetra
.505 .548 .834 r
.35404 .44668 .36149 .46093 .37404 .45894 .36646 .44744 Mtetra
.725 .693 .819 r
.36646 .44744 .37404 .45894 .38713 .44583 .37937 .43938 Mtetra
.829 .814 .836 r
.37937 .43938 .38713 .44583 .4003 .43075 .39249 .42708 Mtetra
.821 .893 .894 r
.39249 .42708 .4003 .43075 .41326 .42058 .40553 .41669 Mtetra
.743 .889 .946 r
.40553 .41669 .41326 .42058 .42612 .41467 .41849 .40944 Mtetra
.687 .84 .957 r
.41849 .40944 .42612 .41467 .43897 .41035 .43142 .40402 Mtetra
.661 .801 .95 r
.43142 .40402 .43897 .41035 .45189 .40624 .44439 .3994 Mtetra
.651 .784 .945 r
.44439 .3994 .45189 .40624 .46486 .40207 .45742 .3951 Mtetra
.646 .78 .945 r
.45742 .3951 .46486 .40207 .47791 .39783 .4705 .39091 Mtetra
.644 .782 .947 r
.4705 .39091 .47791 .39783 .49101 .39355 .48365 .38676 Mtetra
.637 .784 .952 r
.48365 .38676 .49101 .39355 .50418 .38927 .49686 .38275 Mtetra
.606 .783 .966 r
.49686 .38275 .50418 .38927 .51741 .38531 .51014 .37943 Mtetra
.478 .752 .99 r
.51014 .37943 .51741 .38531 .53072 .38276 .52349 .3783 Mtetra
.14 .606 .925 r
.52349 .3783 .53072 .38276 .54412 .38416 .53695 .38056 Mtetra
0 .507 .832 r
.53695 .38056 .54412 .38416 .5577 .39037 .55054 .38395 Mtetra
.522 .758 .982 r
.55054 .38395 .5577 .39037 .57139 .39443 .5642 .38221 Mtetra
.754 .705 .805 r
.5642 .38221 .57139 .39443 .58502 .38725 .5778 .37184 Mtetra
.772 .67 .75 r
.5778 .37184 .58502 .38725 .5985 .37152 .59135 .35777 Mtetra
.754 .683 .783 r
.59135 .35777 .5985 .37152 .61198 .3573 .60496 .34654 Mtetra
.713 .719 .854 r
.60496 .34654 .61198 .3573 .62562 .3484 .6187 .33927 Mtetra
.674 .743 .903 r
.6187 .33927 .62562 .3484 .63941 .34265 .63254 .33398 Mtetra
.659 .75 .917 r
.63254 .33398 .63941 .34265 .65329 .33783 .64648 .32919 Mtetra
.656 .751 .92 r
.64648 .32919 .65329 .33783 .66725 .33315 .66048 .32448 Mtetra
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Mtetra
.27275 .44444 .28076 .45205 .293 .44795 .28503 .4403 Mtetra
.654 .751 .921 r
.28503 .4403 .293 .44795 .30529 .44392 .29736 .43617 Mtetra
.646 .747 .923 r
.29736 .43617 .30529 .44392 .3176 .44043 .30973 .43228 Mtetra
.608 .724 .928 r
.30973 .43228 .3176 .44043 .32985 .43898 .32209 .42944 Mtetra
.504 .646 .92 r
.32209 .42944 .32985 .43898 .34196 .44155 .33437 .42923 Mtetra
.393 .524 .87 r
.33437 .42923 .34196 .44155 .35404 .44668 .34656 .43214 Mtetra
.44 .509 .833 r
.34656 .43214 .35404 .44668 .36646 .44744 .35889 .43469 Mtetra
.613 .628 .842 r
.35889 .43469 .36646 .44744 .37937 .43938 .37159 .43168 Mtetra
.766 .783 .867 r
.37159 .43168 .37937 .43938 .39249 .42708 .38461 .42292 Mtetra
.808 .882 .899 r
.38461 .42292 .39249 .42708 .40553 .41669 .3977 .41303 Mtetra
.757 .899 .941 r
.3977 .41303 .40553 .41669 .41849 .40944 .41074 .40525 Mtetra
.69 .875 .968 r
.41074 .40525 .41849 .40944 .43142 .40402 .42374 .39949 Mtetra
.651 .857 .978 r
.42374 .39949 .43142 .40402 .44439 .3994 .43677 .39472 Mtetra
.632 .848 .982 r
.43677 .39472 .44439 .3994 .45742 .3951 .44985 .39037 Mtetra
.616 .842 .986 r
.44985 .39037 .45742 .3951 .4705 .39091 .46298 .38634 Mtetra
.592 .841 .992 r
.46298 .38634 .4705 .39091 .48365 .38676 .47618 .38267 Mtetra
.546 .84 .999 r
.47618 .38267 .48365 .38676 .49686 .38275 .48943 .37956 Mtetra
.439 .82 .99 r
.48943 .37956 .49686 .38275 .51014 .37943 .50276 .37743 Mtetra
.216 .719 .905 r
.50276 .37743 .51014 .37943 .52349 .3783 .51617 .37691 Mtetra
.046 .607 .803 r
.51617 .37691 .52349 .3783 .53695 .38056 .52968 .3776 Mtetra
.398 .807 .979 r
.52968 .3776 .53695 .38056 .55054 .38395 .54329 .37574 Mtetra
.742 .784 .886 r
.54329 .37574 .55054 .38395 .5642 .38221 .55693 .36781 Mtetra
.759 .677 .771 r
.55693 .36781 .5642 .38221 .5778 .37184 .57055 .35573 Mtetra
.738 .648 .76 r
.57055 .35573 .5778 .37184 .59135 .35777 .58418 .34434 Mtetra
.713 .673 .809 r
.58418 .34434 .59135 .35777 .60496 .34654 .59789 .33609 Mtetra
.684 .716 .874 r
.59789 .33609 .60496 .34654 .6187 .33927 .61171 .33021 Mtetra
.663 .742 .909 r
.61171 .33021 .6187 .33927 .63254 .33398 .62562 .32525 Mtetra
.657 .75 .919 r
.62562 .32525 .63254 .33398 .64648 .32919 .6396 .32048 Mtetra
.656 .751 .92 r
.6396 .32048 .64648 .32919 .66048 .32448 .65365 .31573 Mtetra
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Mtetra
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Mtetra
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Mtetra
.655 .751 .92 r
.27699 .43259 .28503 .4403 .29736 .43617 .28935 .4284 Mtetra
.653 .75 .921 r
.28935 .4284 .29736 .43617 .30973 .43228 .30177 .42426 Mtetra
.639 .74 .922 r
.30177 .42426 .30973 .43228 .32209 .42944 .31422 .42051 Mtetra
.595 .702 .918 r
.31422 .42051 .32209 .42944 .33437 .42923 .32666 .41802 Mtetra
.514 .612 .888 r
.32666 .41802 .33437 .42923 .34656 .43214 .33903 .41791 Mtetra
.46 .526 .839 r
.33903 .41791 .34656 .43214 .35889 .43469 .35139 .4198 Mtetra
.501 .538 .827 r
.35139 .4198 .35889 .43469 .37159 .43168 .3639 .42067 Mtetra
.623 .668 .873 r
.3639 .42067 .37159 .43168 .38461 .42292 .37671 .41731 Mtetra
.746 .84 .922 r
.37671 .41731 .38461 .42292 .3977 .41303 .38976 .40993 Mtetra
.773 .916 .935 r
.38976 .40993 .3977 .41303 .41074 .40525 .40288 .40146 Mtetra
.739 .896 .95 r
.40288 .40146 .41074 .40525 .42374 .39949 .416 .39418 Mtetra
.693 .844 .955 r
.416 .39418 .42374 .39949 .43677 .39472 .4291 .38847 Mtetra
.659 .808 .955 r
.4291 .38847 .43677 .39472 .44985 .39037 .44224 .38379 Mtetra
.636 .792 .957 r
.44224 .38379 .44985 .39037 .46298 .38634 .45542 .37973 Mtetra
.601 .781 .966 r
.45542 .37973 .46298 .38634 .47618 .38267 .46865 .37648 Mtetra
.479 .745 .987 r
.46865 .37648 .47618 .38267 .48943 .37956 .48193 .37539 Mtetra
.09 .583 .9 r
.48193 .37539 .48943 .37956 .50276 .37743 .49527 .37783 Mtetra
.124 0 0 r
.49527 .37783 .50276 .37743 .51617 .37691 .50874 .37884 Mtetra
.447 .876 .785 r
.50874 .37884 .51617 .37691 .52968 .3776 .52233 .37223 Mtetra
.818 .87 .884 r
.52233 .37223 .52968 .3776 .54329 .37574 .53596 .36128 Mtetra
.749 .673 .776 r
.53596 .36128 .54329 .37574 .55693 .36781 .5496 .34993 Mtetra
.708 .617 .753 r
.5496 .34993 .55693 .36781 .57055 .35573 .56326 .34003 Mtetra
.69 .632 .786 r
.56326 .34003 .57055 .35573 .58418 .34434 .57698 .33231 Mtetra
.678 .683 .848 r
.57698 .33231 .58418 .34434 .59789 .33609 .59079 .32636 Mtetra
.665 .728 .896 r
.59079 .32636 .59789 .33609 .61171 .33021 .60467 .32129 Mtetra
.658 .746 .915 r
.60467 .32129 .61171 .33021 .62562 .32525 .61863 .31647 Mtetra
.656 .751 .92 r
.61863 .31647 .62562 .32525 .6396 .32048 .63266 .3117 Mtetra
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Mtetra
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Mtetra
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Mtetra
.26888 .42481 .27699 .43259 .28935 .4284 .28128 .42057 Mtetra
.655 .751 .92 r
.28128 .42057 .28935 .4284 .30177 .42426 .29374 .41633 Mtetra
.652 .748 .92 r
.29374 .41633 .30177 .42426 .31422 .42051 .30625 .41217 Mtetra
.639 .734 .917 r
.30625 .41217 .31422 .42051 .32666 .41802 .3188 .40838 Mtetra
.605 .69 .903 r
.3188 .40838 .32666 .41802 .33903 .41791 .33135 .40562 Mtetra
.552 .61 .865 r
.33135 .40562 .33903 .41791 .35139 .4198 .34387 .40456 Mtetra
.515 .542 .822 r
.34387 .40456 .35139 .4198 .3639 .42067 .3564 .40497 Mtetra
.521 .539 .815 r
.3564 .40497 .3639 .42067 .37671 .41731 .36904 .40522 Mtetra
.574 .627 .867 r
.36904 .40522 .37671 .41731 .38976 .40993 .38187 .40342 Mtetra
.648 .796 .954 r
.38187 .40342 .38976 .40993 .40288 .40146 .39488 .3991 Mtetra
.652 .921 .977 r
.39488 .3991 .40288 .40146 .416 .39418 .40801 .39334 Mtetra
.587 .932 .95 r
.40801 .39334 .416 .39418 .4291 .38847 .42118 .38769 Mtetra
.495 .895 .939 r
.42118 .38769 .4291 .38847 .44224 .38379 .43438 .38321 Mtetra
.321 .804 .887 r
.43438 .38321 .44224 .38379 .45542 .37973 .4476 .38051 Mtetra
.023 0 0 r
.4476 .38051 .45542 .37973 .46865 .37648 .46085 .38013 Mtetra
.222 0 0 r
.46085 .38013 .46865 .37648 .48193 .37539 .47419 .38003 Mtetra
.409 .82 .624 r
.47419 .38003 .48193 .37539 .49527 .37783 .48774 .37132 Mtetra
.863 .833 .816 r
.48774 .37132 .49527 .37783 .50874 .37884 .50137 .35622 Mtetra
.673 .561 .72 r
.50137 .35622 .50874 .37884 .52233 .37223 .51496 .3472 Mtetra
.641 .528 .71 r
.51496 .3472 .52233 .37223 .53596 .36128 .52858 .34004 Mtetra
.647 .556 .738 r
.52858 .34004 .53596 .36128 .5496 .34993 .54225 .33344 Mtetra
.656 .607 .787 r
.54225 .33344 .5496 .34993 .56326 .34003 .55598 .32755 Mtetra
.662 .669 .846 r
.55598 .32755 .56326 .34003 .57698 .33231 .56977 .32222 Mtetra
.66 .718 .891 r
.56977 .32222 .57698 .33231 .59079 .32636 .58363 .31727 Mtetra
.658 .743 .913 r
.58363 .31727 .59079 .32636 .60467 .32129 .59757 .31244 Mtetra
.656 .75 .919 r
.59757 .31244 .60467 .32129 .61863 .31647 .61158 .30764 Mtetra
.656 .751 .92 r
.61158 .30764 .61863 .31647 .63266 .3117 .62565 .30283 Mtetra
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Mtetra
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Mtetra
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46271 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Mtetra
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Mtetra
.27314 .41269 .28128 .42057 .29374 .41633 .28563 .4084 Mtetra
.655 .751 .92 r
.28563 .4084 .29374 .41633 .30625 .41217 .29819 .40409 Mtetra
.653 .747 .919 r
.29819 .40409 .30625 .41217 .3188 .40838 .3108 .39984 Mtetra
.645 .734 .914 r
.3108 .39984 .3188 .40838 .33135 .40562 .32345 .39583 Mtetra
.626 .697 .896 r
.32345 .39583 .33135 .40562 .34387 .40456 .33613 .39238 Mtetra
.597 .635 .86 r
.33613 .39238 .34387 .40456 .3564 .40497 .34883 .38986 Mtetra
.571 .575 .818 r
.34883 .38986 .3564 .40497 .36904 .40522 .36156 .38825 Mtetra
.56 .545 .795 r
.36156 .38825 .36904 .40522 .38187 .40342 .37436 .38708 Mtetra
.568 .558 .803 r
.37436 .38708 .38187 .40342 .39488 .3991 .38725 .38556 Mtetra
.591 .612 .841 r
.38725 .38556 .39488 .3991 .40801 .39334 .40027 .38315 Mtetra
.62 .692 .895 r
.40027 .38315 .40801 .39334 .42118 .38769 .4134 .37977 Mtetra
.639 .758 .934 r
.4134 .37977 .42118 .38769 .43438 .38321 .42663 .37569 Mtetra
.665 .778 .933 r
.42663 .37569 .43438 .38321 .4476 .38051 .43994 .3708 Mtetra
.708 .737 .873 r
.43994 .3708 .4476 .38051 .46085 .38013 .45336 .36408 Mtetra
.725 .642 .766 r
.45336 .36408 .46085 .38013 .47419 .38003 .46689 .35378 Mtetra
.681 .545 .693 r
.46689 .35378 .47419 .38003 .48774 .37132 .48045 .34244 Mtetra
.611 .49 .69 r
.48045 .34244 .48774 .37132 .50137 .35622 .49397 .33684 Mtetra
.626 .56 .761 r
.49397 .33684 .50137 .35622 .51496 .3472 .50754 .33208 Mtetra
.637 .615 .811 r
.50754 .33208 .51496 .3472 .52858 .34004 .52118 .32746 Mtetra
.647 .661 .849 r
.52118 .32746 .52858 .34004 .54225 .33344 .53489 .32277 Mtetra
.655 .703 .882 r
.53489 .32277 .54225 .33344 .55598 .32755 .54866 .31798 Mtetra
.656 .73 .904 r
.54866 .31798 .55598 .32755 .56977 .32222 .56251 .31319 Mtetra
.656 .745 .915 r
.56251 .31319 .56977 .32222 .58363 .31727 .57642 .30838 Mtetra
.656 .75 .919 r
.57642 .30838 .58363 .31727 .59757 .31244 .5904 .30357 Mtetra
.656 .751 .92 r
.5904 .30357 .59757 .31244 .61158 .30764 .60446 .29873 Mtetra
.60446 .29873 .61158 .30764 .62565 .30283 .61858 .29388 Mtetra
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .28899 Mtetra
.63278 .28899 .6398 .29799 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Mtetra
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Mtetra
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46271 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Mtetra
.26492 .40474 .27314 .41269 .28563 .4084 .27745 .40041 Mtetra
.27745 .40041 .28563 .4084 .29819 .40409 .29004 .39605 Mtetra
.655 .751 .92 r
.29004 .39605 .29819 .40409 .3108 .39984 .30269 .39168 Mtetra
.654 .748 .919 r
.30269 .39168 .3108 .39984 .32345 .39583 .3154 .38732 Mtetra
.651 .739 .914 r
.3154 .38732 .32345 .39583 .33613 .39238 .32817 .38304 Mtetra
.644 .717 .901 r
.32817 .38304 .33613 .39238 .34883 .38986 .34098 .37897 Mtetra
.632 .678 .876 r
.34098 .37897 .34883 .38986 .36156 .38825 .35385 .3752 Mtetra
.619 .633 .842 r
.35385 .3752 .36156 .38825 .37436 .38708 .36676 .37174 Mtetra
.611 .594 .809 r
.36676 .37174 .37436 .38708 .38725 .38556 .37974 .36839 Mtetra
.61 .571 .786 r
.37974 .36839 .38725 .38556 .40027 .38315 .3928 .36489 Mtetra
.616 .563 .773 r
.3928 .36489 .40027 .38315 .4134 .37977 .40595 .36094 Mtetra
.627 .564 .764 r
.40595 .36094 .4134 .37977 .42663 .37569 .41919 .35625 Mtetra
.639 .566 .756 r
.41919 .35625 .42663 .37569 .43994 .3708 .43252 .35066 Mtetra
.649 .565 .747 r
.43252 .35066 .43994 .3708 .45336 .36408 .44593 .34427 Mtetra
.65 .569 .75 r
.44593 .34427 .45336 .36408 .46689 .35378 .45939 .33788 Mtetra
.65 .61 .796 r
.45939 .33788 .46689 .35378 .48045 .34244 .47288 .33248 Mtetra
.652 .716 .895 r
.47288 .33248 .48045 .34244 .49397 .33684 .48643 .32787 Mtetra
.649 .74 .916 r
.48643 .32787 .49397 .33684 .50754 .33208 .50004 .32338 Mtetra
.654 .75 .92 r
.50004 .32338 .50754 .33208 .52118 .32746 .51372 .31869 Mtetra
.656 .75 .919 r
.51372 .31869 .52118 .32746 .53489 .32277 .52747 .31391 Mtetra
.656 .749 .918 r
.52747 .31391 .53489 .32277 .54866 .31798 .54129 .30912 Mtetra
.656 .75 .919 r
.54129 .30912 .54866 .31798 .56251 .31319 .55518 .30431 Mtetra
.656 .751 .92 r
.55518 .30431 .56251 .31319 .57642 .30838 .56914 .29948 Mtetra
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Mtetra
.58317 .29463 .5904 .30357 .60446 .29873 .59727 .28975 Mtetra
.59727 .28975 .60446 .29873 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .28899 .62569 .27992 Mtetra
.62569 .27992 .63278 .28899 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .40041 .2692 .39235 Mtetra
.2692 .39235 .27745 .40041 .29004 .39605 .28183 .38795 Mtetra
.28183 .38795 .29004 .39605 .30269 .39168 .29451 .38353 Mtetra
.29451 .38353 .30269 .39168 .3154 .38732 .30726 .3791 Mtetra
.655 .75 .919 r
.30726 .3791 .3154 .38732 .32817 .38304 .32007 .37465 Mtetra
.655 .746 .917 r
.32007 .37465 .32817 .38304 .34098 .37897 .33295 .37019 Mtetra
.653 .737 .911 r
.33295 .37019 .34098 .37897 .35385 .3752 .34588 .36576 Mtetra
.65 .721 .9 r
.34588 .36576 .35385 .3752 .36676 .37174 .35887 .36138 Mtetra
.646 .699 .885 r
.35887 .36138 .36676 .37174 .37974 .36839 .37192 .35707 Mtetra
.644 .679 .868 r
.37192 .35707 .37974 .36839 .3928 .36489 .38504 .35274 Mtetra
.644 .664 .854 r
.38504 .35274 .3928 .36489 .40595 .36094 .39823 .34829 Mtetra
.647 .657 .845 r
.39823 .34829 .40595 .36094 .41919 .35625 .41149 .34363 Mtetra
.651 .659 .845 r
.41149 .34363 .41919 .35625 .43252 .35066 .42483 .33881 Mtetra
.655 .676 .858 r
.42483 .33881 .43252 .35066 .44593 .34427 .43823 .3339 Mtetra
.659 .709 .885 r
.43823 .3339 .44593 .34427 .45939 .33788 .45169 .32903 Mtetra
.658 .746 .915 r
.45169 .32903 .45939 .33788 .47288 .33248 .46521 .32423 Mtetra
.658 .763 .927 r
.46521 .32423 .47288 .33248 .48643 .32787 .4788 .31942 Mtetra
.658 .759 .925 r
.4788 .31942 .48643 .32787 .50004 .32338 .49246 .31461 Mtetra
.656 .751 .92 r
.49246 .31461 .50004 .32338 .51372 .31869 .50619 .30983 Mtetra
.655 .75 .919 r
.50619 .30983 .51372 .31869 .52747 .31391 .51998 .30505 Mtetra
.656 .751 .92 r
.51998 .30505 .52747 .31391 .54129 .30912 .53385 .30023 Mtetra
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Mtetra
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Mtetra
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Mtetra
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Mtetra
.29905 .37085 .30726 .3791 .32007 .37465 .3119 .36635 Mtetra
.3119 .36635 .32007 .37465 .33295 .37019 .32481 .36183 Mtetra
.655 .75 .92 r
.32481 .36183 .33295 .37019 .34588 .36576 .33778 .3573 Mtetra
.656 .749 .919 r
.33778 .3573 .34588 .36576 .35887 .36138 .35082 .35273 Mtetra
.657 .745 .915 r
.35082 .35273 .35887 .36138 .37192 .35707 .36392 .34811 Mtetra
.657 .739 .91 r
.36392 .34811 .37192 .35707 .38504 .35274 .37709 .34347 Mtetra
.656 .732 .905 r
.37709 .34347 .38504 .35274 .39823 .34829 .39033 .33881 Mtetra
.656 .728 .902 r
.39033 .33881 .39823 .34829 .41149 .34363 .40363 .33413 Mtetra
.656 .728 .903 r
.40363 .33413 .41149 .34363 .42483 .33881 .41699 .32942 Mtetra
.656 .732 .905 r
.41699 .32942 .42483 .33881 .43823 .3339 .43042 .32469 Mtetra
.655 .737 .91 r
.43042 .32469 .43823 .3339 .45169 .32903 .44392 .31999 Mtetra
.652 .742 .915 r
.44392 .31999 .45169 .32903 .46521 .32423 .45748 .31535 Mtetra
.653 .747 .919 r
.45748 .31535 .46521 .32423 .4788 .31942 .47111 .31066 Mtetra
.656 .752 .921 r
.47111 .31066 .4788 .31942 .49246 .31461 .48482 .30585 Mtetra
.657 .754 .921 r
.48482 .30585 .49246 .31461 .50619 .30983 .49859 .30099 Mtetra
.656 .753 .921 r
.49859 .30099 .50619 .30983 .51998 .30505 .51243 .29613 Mtetra
.656 .752 .92 r
.51243 .29613 .51998 .30505 .53385 .30023 .52634 .29125 Mtetra
.656 .751 .92 r
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Mtetra
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Mtetra
.31659 .35342 .32481 .36183 .33778 .3573 .32961 .34882 Mtetra
.655 .751 .92 r
.32961 .34882 .33778 .3573 .35082 .35273 .34268 .34423 Mtetra
.34268 .34423 .35082 .35273 .36392 .34811 .35582 .33963 Mtetra
.655 .752 .922 r
.35582 .33963 .36392 .34811 .37709 .34347 .36903 .33502 Mtetra
.655 .754 .923 r
.36903 .33502 .37709 .34347 .39033 .33881 .3823 .33036 Mtetra
.655 .756 .924 r
.3823 .33036 .39033 .33881 .40363 .33413 .39564 .32568 Mtetra
.655 .757 .924 r
.39564 .32568 .40363 .33413 .41699 .32942 .40905 .32097 Mtetra
.655 .758 .925 r
.40905 .32097 .41699 .32942 .43042 .32469 .42252 .31624 Mtetra
.656 .759 .926 r
.42252 .31624 .43042 .32469 .44392 .31999 .43606 .31145 Mtetra
.659 .759 .924 r
.43606 .31145 .44392 .31999 .45748 .31535 .44967 .30656 Mtetra
.659 .753 .92 r
.44967 .30656 .45748 .31535 .47111 .31066 .46335 .30164 Mtetra
.655 .747 .918 r
.46335 .30164 .47111 .31066 .48482 .30585 .4771 .29681 Mtetra
.655 .748 .919 r
.4771 .29681 .48482 .30585 .49859 .30099 .49092 .29199 Mtetra
.655 .75 .92 r
.49092 .29199 .49859 .30099 .51243 .29613 .5048 .28711 Mtetra
.656 .751 .92 r
.5048 .28711 .51243 .29613 .52634 .29125 .51876 .28219 Mtetra
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Mtetra
.656 .752 .92 r
.3083 .34494 .31659 .35342 .32961 .34882 .32135 .34032 Mtetra
.656 .752 .921 r
.32135 .34032 .32961 .34882 .34268 .34423 .33447 .33566 Mtetra
.657 .752 .92 r
.33447 .33566 .34268 .34423 .35582 .33963 .34766 .33096 Mtetra
.657 .75 .919 r
.34766 .33096 .35582 .33963 .36903 .33502 .36091 .32623 Mtetra
.656 .748 .918 r
.36091 .32623 .36903 .33502 .3823 .33036 .37422 .32149 Mtetra
.656 .747 .917 r
.37422 .32149 .3823 .33036 .39564 .32568 .3876 .31674 Mtetra
.656 .746 .916 r
.3876 .31674 .39564 .32568 .40905 .32097 .40105 .31196 Mtetra
.656 .745 .916 r
.40105 .31196 .40905 .32097 .42252 .31624 .41457 .30715 Mtetra
.655 .744 .915 r
.41457 .30715 .42252 .31624 .43606 .31145 .42815 .30235 Mtetra
.653 .744 .917 r
.42815 .30235 .43606 .31145 .44967 .30656 .4418 .29758 Mtetra
.653 .749 .92 r
.4418 .29758 .44967 .30656 .46335 .30164 .45552 .29281 Mtetra
.656 .755 .923 r
.45552 .29281 .46335 .30164 .4771 .29681 .46931 .28791 Mtetra
.657 .754 .922 r
.46931 .28791 .4771 .29681 .49092 .29199 .48317 .28296 Mtetra
.656 .752 .921 r
.48317 .28296 .49092 .29199 .5048 .28711 .4971 .27801 Mtetra
.656 .752 .92 r
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Mtetra
.656 .751 .92 r
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33637 Mtetra
.29994 .33637 .3083 .34494 .32135 .34032 .31303 .3317 Mtetra
.31303 .3317 .32135 .34032 .33447 .33566 .32619 .32702 Mtetra
.655 .751 .921 r
.32619 .32702 .33447 .33566 .34766 .33096 .33941 .32232 Mtetra
.655 .752 .922 r
.33941 .32232 .34766 .33096 .36091 .32623 .35269 .31761 Mtetra
.655 .754 .922 r
.35269 .31761 .36091 .32623 .37422 .32149 .36605 .31286 Mtetra
.655 .755 .923 r
.36605 .31286 .37422 .32149 .3876 .31674 .37947 .30809 Mtetra
.655 .756 .924 r
.37947 .30809 .3876 .31674 .40105 .31196 .39296 .30329 Mtetra
.39296 .30329 .40105 .31196 .41457 .30715 .40652 .29847 Mtetra
.656 .757 .924 r
.40652 .29847 .41457 .30715 .42815 .30235 .42015 .2936 Mtetra
.658 .757 .923 r
.42015 .2936 .42815 .30235 .4418 .29758 .43384 .28865 Mtetra
.658 .754 .921 r
.43384 .28865 .4418 .29758 .45552 .29281 .44761 .28367 Mtetra
.656 .749 .919 r
.44761 .28367 .45552 .29281 .46931 .28791 .46145 .27874 Mtetra
.655 .749 .919 r
.46145 .27874 .46931 .28791 .48317 .28296 .47535 .2738 Mtetra
.655 .751 .92 r
.47535 .2738 .48317 .28296 .4971 .27801 .48933 .26883 Mtetra
.656 .751 .92 r
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.27843 .33243 .28691 .34102 .29994 .33637 .2915 .32774 Mtetra
.656 .752 .92 r
.2915 .32774 .29994 .33637 .31303 .3317 .30463 .32303 Mtetra
.30463 .32303 .31303 .3317 .32619 .32702 .31782 .31829 Mtetra
.31782 .31829 .32619 .32702 .33941 .32232 .33109 .31351 Mtetra
.656 .751 .919 r
.33109 .31351 .33941 .32232 .35269 .31761 .34442 .30871 Mtetra
.656 .749 .918 r
.34442 .30871 .35269 .31761 .36605 .31286 .35781 .30388 Mtetra
.656 .748 .918 r
.35781 .30388 .36605 .31286 .37947 .30809 .37128 .29904 Mtetra
.656 .748 .917 r
.37128 .29904 .37947 .30809 .39296 .30329 .38481 .29418 Mtetra
.656 .747 .917 r
.38481 .29418 .39296 .30329 .40652 .29847 .39841 .28929 Mtetra
.655 .747 .917 r
.39841 .28929 .40652 .29847 .42015 .2936 .41208 .28439 Mtetra
.654 .747 .918 r
.41208 .28439 .42015 .2936 .43384 .28865 .42582 .2795 Mtetra
.654 .749 .92 r
.42582 .2795 .43384 .28865 .44761 .28367 .43963 .2746 Mtetra
.656 .753 .921 r
.43963 .2746 .44761 .28367 .46145 .27874 .45351 .26963 Mtetra
.45351 .26963 .46145 .27874 .47535 .2738 .46746 .2646 Mtetra
.656 .752 .921 r
.46746 .2646 .47535 .2738 .48933 .26883 .48148 .25956 Mtetra
.656 .751 .92 r
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Mtetra
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Mtetra
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31426 Mtetra
.29615 .31426 .30463 .32303 .31782 .31829 .30938 .30949 Mtetra
.655 .751 .92 r
.30938 .30949 .31782 .31829 .33109 .31351 .32268 .3047 Mtetra
.655 .752 .921 r
.32268 .3047 .33109 .31351 .34442 .30871 .33605 .29989 Mtetra
.655 .753 .922 r
.33605 .29989 .34442 .30871 .35781 .30388 .34949 .29505 Mtetra
.656 .754 .922 r
.34949 .29505 .35781 .30388 .37128 .29904 .363 .29018 Mtetra
.656 .755 .923 r
.363 .29018 .37128 .29904 .38481 .29418 .37657 .28529 Mtetra
.37657 .28529 .38481 .29418 .39841 .28929 .39021 .28037 Mtetra
.656 .756 .923 r
.39021 .28037 .39841 .28929 .41208 .28439 .40393 .27541 Mtetra
.657 .756 .923 r
.40393 .27541 .41208 .28439 .42582 .2795 .41771 .27039 Mtetra
.657 .753 .921 r
.41771 .27039 .42582 .2795 .43963 .2746 .43157 .26534 Mtetra
.656 .75 .919 r
.43157 .26534 .43963 .2746 .45351 .26963 .4455 .26031 Mtetra
.655 .75 .919 r
.4455 .26031 .45351 .26963 .46746 .2646 .45949 .25527 Mtetra
.656 .751 .92 r
.45949 .25527 .46746 .2646 .48148 .25956 .47356 .2502 Mtetra
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32919 Mtetra
.22219 .32919 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31023 Mtetra
.656 .752 .92 r
.27438 .31023 .28298 .31902 .29615 .31426 .28759 .30543 Mtetra
.28759 .30543 .29615 .31426 .30938 .30949 .30086 .3006 Mtetra
.30086 .3006 .30938 .30949 .32268 .3047 .31421 .29573 Mtetra
.656 .751 .919 r
.31421 .29573 .32268 .3047 .33605 .29989 .32762 .29084 Mtetra
.656 .75 .919 r
.32762 .29084 .33605 .29989 .34949 .29505 .3411 .28593 Mtetra
.656 .749 .918 r
.3411 .28593 .34949 .29505 .363 .29018 .35465 .281 Mtetra
.35465 .281 .363 .29018 .37657 .28529 .36827 .27605 Mtetra
.656 .748 .918 r
.36827 .27605 .37657 .28529 .39021 .28037 .38195 .27107 Mtetra
.38195 .27107 .39021 .28037 .40393 .27541 .39571 .26608 Mtetra
.655 .748 .918 r
.39571 .26608 .40393 .27541 .41771 .27039 .40954 .26108 Mtetra
.655 .75 .92 r
.40954 .26108 .41771 .27039 .43157 .26534 .42343 .25607 Mtetra
.656 .752 .921 r
.42343 .25607 .43157 .26534 .4455 .26031 .43741 .251 Mtetra
.656 .753 .921 r
.43741 .251 .4455 .26031 .45949 .25527 .45145 .24589 Mtetra
.656 .752 .921 r
.45145 .24589 .45949 .25527 .47356 .2502 .46557 .24075 Mtetra
.656 .751 .92 r
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32919 .21336 .32048 Mtetra
.21336 .32048 .22219 .32919 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31023 .2657 .30134 Mtetra
.2657 .30134 .27438 .31023 .28759 .30543 .27895 .29649 Mtetra
.27895 .29649 .28759 .30543 .30086 .3006 .29226 .29163 Mtetra
.655 .751 .92 r
.29226 .29163 .30086 .3006 .31421 .29573 .30565 .28675 Mtetra
.655 .752 .921 r
.30565 .28675 .31421 .29573 .32762 .29084 .3191 .28185 Mtetra
.655 .753 .922 r
.3191 .28185 .32762 .29084 .3411 .28593 .33262 .27691 Mtetra
.656 .754 .922 r
.33262 .27691 .3411 .28593 .35465 .281 .34621 .27195 Mtetra
.34621 .27195 .35465 .281 .36827 .27605 .35987 .26696 Mtetra
.35987 .26696 .36827 .27605 .38195 .27107 .3736 .26194 Mtetra
.656 .755 .922 r
.3736 .26194 .38195 .27107 .39571 .26608 .3874 .25689 Mtetra
.657 .754 .922 r
.3874 .25689 .39571 .26608 .40954 .26108 .40128 .25179 Mtetra
.657 .753 .921 r
.40128 .25179 .40954 .26108 .42343 .25607 .41522 .24665 Mtetra
.656 .751 .92 r
.41522 .24665 .42343 .25607 .43741 .251 .42924 .24152 Mtetra
.655 .75 .92 r
.42924 .24152 .43741 .251 .45145 .24589 .44333 .23638 Mtetra
.656 .751 .92 r
.44333 .23638 .45145 .24589 .46557 .24075 .45749 .23121 Mtetra
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Mtetra
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Mtetra
.25694 .29238 .2657 .30134 .27895 .29649 .27023 .28749 Mtetra
.656 .752 .92 r
.27023 .28749 .27895 .29649 .29226 .29163 .28358 .28257 Mtetra
.28358 .28257 .29226 .29163 .30565 .28675 .29701 .27762 Mtetra
.656 .751 .92 r
.29701 .27762 .30565 .28675 .3191 .28185 .31051 .27263 Mtetra
.656 .75 .919 r
.31051 .27263 .3191 .28185 .33262 .27691 .32407 .26763 Mtetra
.656 .749 .919 r
.32407 .26763 .33262 .27691 .34621 .27195 .3377 .26261 Mtetra
.3377 .26261 .34621 .27195 .35987 .26696 .35141 .25756 Mtetra
.656 .749 .918 r
.35141 .25756 .35987 .26696 .3736 .26194 .36518 .25249 Mtetra
.36518 .25249 .3736 .26194 .3874 .25689 .37902 .2474 Mtetra
.655 .749 .919 r
.37902 .2474 .3874 .25689 .40128 .25179 .39294 .24231 Mtetra
.655 .75 .92 r
.39294 .24231 .40128 .25179 .41522 .24665 .40693 .23719 Mtetra
.656 .752 .921 r
.40693 .23719 .41522 .24665 .42924 .24152 .42099 .23202 Mtetra
.42099 .23202 .42924 .24152 .44333 .23638 .43513 .22681 Mtetra
.656 .752 .92 r
.43513 .22681 .44333 .23638 .45749 .23121 .44934 .22157 Mtetra
.656 .751 .92 r
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Mtetra
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Mtetra
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Mtetra
.26142 .27839 .27023 .28749 .28358 .28257 .27482 .27343 Mtetra
.655 .751 .92 r
.27482 .27343 .28358 .28257 .29701 .27762 .28829 .26846 Mtetra
.655 .752 .921 r
.28829 .26846 .29701 .27762 .31051 .27263 .30182 .26346 Mtetra
.655 .753 .922 r
.30182 .26346 .31051 .27263 .32407 .26763 .31543 .25843 Mtetra
.656 .753 .922 r
.31543 .25843 .32407 .26763 .3377 .26261 .3291 .25337 Mtetra
.656 .754 .922 r
.3291 .25337 .3377 .26261 .35141 .25756 .34285 .24829 Mtetra
.34285 .24829 .35141 .25756 .36518 .25249 .35667 .24317 Mtetra
.35667 .24317 .36518 .25249 .37902 .2474 .37056 .23802 Mtetra
.657 .754 .922 r
.37056 .23802 .37902 .2474 .39294 .24231 .38452 .23282 Mtetra
.657 .753 .921 r
.38452 .23282 .39294 .24231 .40693 .23719 .39856 .22759 Mtetra
.656 .751 .92 r
.39856 .22759 .40693 .23719 .42099 .23202 .41267 .22237 Mtetra
.655 .751 .92 r
.41267 .22237 .42099 .23202 .43513 .22681 .42685 .21712 Mtetra
.656 .751 .92 r
.42685 .21712 .43513 .22681 .44934 .22157 .44111 .21185 Mtetra
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3oool30:S0je00Yl3[00<000000:O0j`2W`>/0402W`>/A0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`<000000`3oool00`000000oooo0?ooo`160?ooo`H0
Z<3[C`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0:@3oool002T0oooo
0P00001;0?ooo`D0Z<7/1@2X`>]?0:O0j`030000002W`>/0Yl3[0140Yl3[4P3oool00`000000oooo
0?ooo`0X0?ooo`009P3oool3000004X0oooo102W`N`50:S1k0D0Yko[1@2W`>/50:Nojd@0Yl3[00<0
00000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo02P0oooo000T0?ooo`800000B`3oool7
0:O1k0<0Z<7/1`2W_n/50:O0j`D0Yko[@P2W`>/2000001D0Yl3[403oool2000002T0oooo000Q0?oo
o`<00000B`3oool:0:O1k0L0Yko[0`2X`>/50:O0j`80Yko[@@2W`>/300000080Yl3[00<000000:O0
j`2W`>/04P2W`>/B0?ooo`030000003oool0oooo02H0oooo000O0?ooo`<00000B@3oool:0:O1k0T0
Yko[1P2X`>]40:O0j`<000001@2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3o
ool09P3oool001d0oooo0P00001;0?ooo`80Yl3/1@2W`N`:0:Noj`D0Z<7/102X`>]10:O0j`<00000
2@2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0303oool2000000@0oooo
0P0000030?ooo`@000002P3oool001D0oooo1@0000030?ooo`800000B@3oool50:O0k080Yl7/202W
_n/50:O1k0D0Z<7/1@2W_n/40:O0j`D0Yko[<`2W`>/3000000d0Yl3[00<000000:O0j`2W`>/04`2W
`>/A0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`0;0?ooo`005`3oool00`000000oooo0?ooo`030?ooo`<00000A03oool90:O0k0P0Yko[202W
`N`20:S1k140Yko[<02W`>/200000140Yl3[00<000000:O0j`2W`>/04`2W`>/@0?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0:0?ooo`005`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000003l0oooo1@2W`>/50:O0k0T0Yko[
2P2W`N`80:Noj`<0Z<3[1P2W_n/_0:O0j`<000004`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo
00<000000?ooo`3oool00`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`090?ooo`003`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03/0oooo1`2W`>/:0:Noj`T0Yl7/2P2W_n/60:S0j`<0Yko[
;P2W`>/3000001L0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000:0?ooo`005`3oool00`000000
oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0h0?ooo`X0Yl3[1@2W_n/:0:O1k0T0
Yko[1@2X`N`50:S0jbh0Yl3[0`00000K0:O0j`030000002W`>/0Yl3[0180Yl3[403oool2000000/0
oooo0P00000:0?ooo`8000002`3oool001H0oooo0P0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0<`3oool?0:O0j`80Yko[0`2W`>`70:O1k0P0Yko[102W`N`50:S1k0D0Yko[
1@2W`>/40:Nojb40Yl3[0`00000O0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo
0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03ooolB0:O0j`H0Yl3/102W
`N`80:Noj`L0Yl7/4`2W_n/M0:O0j`<000008P2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<0
00000?ooo`3oool0803oool001`0oooo0P0000080?ooo`030000003oool0oooo02/0oooo5P2W`>/4
0:O0k0X0Yko[202W`N`20:NojPL0Yko[0`2X`N/50:Noj`@0Z<7/6@2W`>/3000002H0Yl3[00<00000
0:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0:03ooolI0:O0j`T0Yko[2P2W`N`50:NojP@0Yko[1P2X`N/20:No
j`<0Yl7/102X`N`20:O0j`<0Yko[402W`>/3000002X0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?oo
o`030000003oool0oooo01l0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool08`3ooolN0:O0j`D0Yko[2@2W`N`:0:NojP@0Z<7/1@2X`N/60:O1k0<0Z<7/1P2W_n/<0:O0j`<0
0000;P2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07P3oool001/0oooo
0P00000<0?ooo`030000003oool0oooo01l0oooo8P2W`>/20:Noj`<0Yl3/102W`N`:0:NojPD0Yl7/
102X`N`50:Noj`D0Yl7/2@2W_n/:0:O0j`800000<@2W`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo
00<000000?ooo`3oool07P3oool001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0J0?ooobH0Yl3[1P2W`>`20:O1k080Yko[1`2W_nX80:O1k0@0YkkZ3P2W_n/;0:O0j`<00000=02W
`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07@3oool001/0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooobP0Yl3[1@2W`>`50:Noj`@0YkoZ202W`N`7
0:NnjPD0Z<3[1@2W_n/50:S1j`H0Yl3[0`00000h0:O0j`030000002W`>/0Yl3[0140Yl3[403oool2
000001l0oooo000K0?ooo`8000003`3oool00`000000oooo0?ooo`0E0?ooob/0Yl3[2P2W_n/90:O1
k0P0YkkZ0P2X`^`50:S0j`80Yko[0`2W`>/50:S1j`80Yko[0`0000040:O0j`D0Yko[102W`>/50:No
jbT0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01`0oooo000K0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool_0:O0j`D0Yko[2@2W`N`:0:NnjPD0
Z<;/102X`>/60:O0j`80Z<7[00@0Yl3[00000000000000003@2W_n/40:NnjPX0Yko[902W`>/00`00
0000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P0000040?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?oooc@0
Yl3[2P2W`N`90:NnjPD0Yl;]102X`^`50:Noj`D0Yl3[0`0000030:O0j`T0Yko[1@2W^^L40:NnjPD0
Z;kY1@2W_n/T0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0K0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00000C0?oo
o`030000003oool0oooo00X0oooo=02W`>/20:O0k0D0Yl7/1@2W_nX50:NnjP@0Yl;/1@2W`^d50:Jm
jP@0Yko[00D0Z<;/00000000000000000:S2k0050:O0j`L0Yko[0`2W/n440:Nji`80YkkZ0`2X]n@5
0:Rnj@D0Z;kZ902W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool06P3oool0
00L0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000001D0oooo00<0
00000?ooo`3oool01`3ooold0:O0j`D0Yl3/0`2W`N`20:Noj`D0YkoZ0P2W_^X30:O1k0@0Yl;/1@2W
_>P50:JmjP040:S3k@0000000000000000D0Z<;/2@2W_n/60:Nch@<0Yk[W1P2X]n@20:Rnj@<0Z[[U
102X_^X50:Rojal0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01T0oooo
00000`3oool000000000000200000080oooo00@000000?ooo`3oool000002@3oool2000000@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooocT0Yl3[1@2W`>`50:Noj`@0YkoZ
1P2W`N`20:O2k080Yk_W1@2W_>P20:RnjP<00000102X`nd50:JmjPD0Yko[102UZMT50:Nch@@0ZJ_H
1@2X]n@60:Zji@80Z;kZ0P2Y_NP50:Rojal0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000
003oool0oooo01T0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
0`3oool2000001H0oooo00<000000:O0j`2W`>/0>`2W`>/50:Roj`@0Yko[2P2W`N`50:Nki`80YkcX
0P2X]N82000000@0Z;kZ102V]nD50:JmjPD0Xig?102UZMT20:Nch@<0Yi_9102YZmP50:f^f@D0Z[[U
1@2Y_NP20:Roj`<0Z;oZ7`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000J0?ooo`00203o
ool2000000X0oooo0`0000030?ooo`030000003oool0oooo0180oooo?P2W`>/40:S0j`D0Z;o[2@2W
`N`50:Nji`@0Yk_W00@0Z;GR00000000000000000P2X]N820:RnjP<0YYc;102V]nD20:JmjP<0X8o2
102SWLl40:FYf@H0Yi_90P2YZmP20;2Qb@D0[JkI1@2_]ml40:Vmj0H0Z;oZ7`2W`>/00`000000Yl3[
0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool05`3oool001T0oooo00<000000?ooo`3oool04P3o
oom00:O0j`@0Z<3[1@2W`>`50:O1k0@0Yk[V1@2W^^L0102W[M/000000000000000050:RehPH0YYc;
0`2V]nD50:2?`P@0Xig?1@2US[`50:NKb@@0/:79102][]T20;J/c`D0[kOO102/_^L50:RojQl0Yl3[
00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01L0oooo000I0?ooo`8000004@3o
oom70:O0j`D0Yl3/1@2W^nL40:NjiP80YZSH0`0000040:N]f`D0YY6o1@2VW</409am/0D0X8o20P2S
WLl20:B7]@@0YHjl102WVlT20;FM`0@0/:790P2][]T40;J/c`80[kOO0`2f^=X40:bni`D0ZL3Z7`2W
`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool05P3oool001T0oooo00<00000
0?ooo`3oool03@3ooom;0:O0j`80Yl3/0`2X_NP50:Nki`80Yk[V0`0000040:JXf080YjgK0P2VT;l4
0:JA_`@0YYc;0P2^Rk4309am/0D0X8o2102TQkD50:F>_080Yi_90`2eWL040;2Qb@H0]Zc?1@2f^=X2
0:bni`<0[koV1@2Y`>X40:S0ja/0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0
oooo01D0oooo000I0?ooo`030000003oool0oooo00T0ooooC`2W`>/60:Rmj0<0Yk_W0`0000020:FX
f0D0YZSH102VT;l50:JA_`80YYc;0`2^Rk4409am/0<0X8o20P2/SkP30:B7]@D0YHjl1P2eWL020;2Q
b@80_:G2102f[<l20<6^b0@0][SJ1P2__nH50:W0jP@0Z<3[6`2W`>/00`000000Yl3[0:O0j`0A0:O0
ja00oooo00<000000?ooo`3oool05@3oool001T0oooo0P0000070?ooodl0Yl3[1@2X_^X40:Rmj0<0
00000P2TZMX40:FXf080YZSH0`2ST<430:J@_`D0YY6o1@2^Rk4409am/080X8o20`2/SkP40:B7]@<0
YHjl0P2o[<H50;FM`0030;2Qb@2lYL80_:G20080_:G20P2f[<l40<6^b080][SJ0P2n^mL30:noiP<0
//;U102Y`>X50:S0jaX0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01@0
oooo000I0?ooo`030000003oool0oooo00<0ooooCP2W`>/50:Noj`D0Z;kZ0`0000000`2T[Mh0Y:WJ
0:BYfP030:BYfP<0YJSH1@2ST<440:J@_`<0YY6o0P2iY<@40:j;/@@0W7f`1@2/SkP40:B7]@80YHjl
0`2o[<H50;FM`0D0_:G21P31[/P50;jke`H0//;U0P2Y`>X20:[1jPD0Z<3[6P2W`>/00`000000Yl3[
0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool04`3oool001P0oooo00<000000?ooo`3oool00`3o
oom<0:O0j`T0Yko[00D0YK;R00000000000000000:FbhP040:B]gP@0Y:WJ102PT<<40:>@`@@0YY2o
0P2VTKl30;VTa0D0[X^a0`2LOK000`3LeM00[8nh0:b?^0030:b?^0<0Y8Ne1P2o[<H30;FM`080`Zg5
102lYL800`35Zkl0`Jk80<6^b0020<6^b080b[?30`2n^mL20<K1e@D0//;U1@2Z`NX50:S0jaX0Yl3[
00<000000:O0j`2W`>/04@2W`>/?0?ooo`8000005@3oool001P0oooo00@000000?ooo`000000oooo
C`2W`>/50:Noj`80Y[SV0P0000050:FbhP<0Y:gN1@2MT<D30:2@``D0Xi310`2VT;l50;VTa0D0[X^a
0P2LOK020=cEd0D0[8nh0P2TQkD20=7NhPD0_jc60P2eWL030<:]a@<0_:G20P35Zkl30<6^b0@0b[?3
00<0_[_G0<K1e@36`MD00P36`MD50;C4iP@0Z/7Z1P2X`>/I0:O0j`030000002W`>/0Yl3[0140Yl3[
4@3oool00`000000oooo0?ooo`060?ooo`8000002P3oool001P0oooo00<000000:O0j`2W`>/0D@2W
`>/30:Nlj@<000000`2V^>H40:FbhP@0W9;9102MT<D40:2@``@0Xi310P2VT;l20;Flg`D0^JC4102^
Rk40102LOK00g=G@0=cEd03LeM050:b?^0040:B7]@3Ag^80dMkR0=7NhPD0_jc61P32[LD00`2lYL80
aJ^o0<F[_`020<F[_`030<6^b03:/l<0b[?300<0b[?31036`MD20<g7e@D0]<CV102Z`N/50:S0jaX0
Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000002@3oool00140oooo0P0000050?ooo`030000003oool0Yl3[0500Yl3[00@0YkkZ00000000
000000000`2W_>T30:JhiPD0W9S?0`2LT/T509f@a@<0X933102ST<440;Flg`D0^JC4102^Rk450=cE
d0@0[8nh1@3Ag^820;n/aP<0_LSR1@32[LD50<F[_`D0b[?30P3C^L020<K1e@@0cLOE0P2da>H30;G5
iP@0Z/7[1@2X`>/J0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0CP2W`>/300000080YkkZ102W_>T409jRe`@0W9S?102LT/T409f@a@<0X9331@2Zanh4
0;Flg`@0^JC40P2^Rk4406SAW`<0g=G@0P2/SkP407;Pb0<0dMkR1@2mb>840<:]a@80`KC>1035Zkl0
103:[[d0b[?30<Zc``3:/l<30=>i`0H0cLOE1@2eaNH50:W1j`@0Z<3[6`2W`>/00`000000Yl3[0:O0
j`0A0:O0ja00oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000090?ooo`00403o
ool010000000oooo0?ooo`0000040?ooo`8000000P3ooom90:O0j`050:Noj`00000000000000002W
_n/0102W_^X50:6]h0<0WZ;G1@2LV<l309bBb@@0WI35102S`^l50:[7kP<0]KcO102iY<@407Zno0H0
L=7m0`0g^>L400^Kc@80ILkj1@2mb>820<:]a@<0`KC>0`35Zkl30<Z^_@030<Zc``3C^L00dkW00080
dkW000<0g<2n0<g7e@3=amD00P3=amD20=3<e@<0]LGV0P2eaNL50:W1jah0Yl3[00<000000:O0j`2W
`>/04@2W`>/A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool00100
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooodH0Yl3[0`0000000`2W
`>/0Yko[0:Noj`020:Noj`@0Y;OV1@2Q[N0309jRe`@0W9S?0`2LT/T509jai@@0Xl;_0P1BcN<50:;:
m0@0VLOg1P2;eol609_8m`<0N/3m100SVn`00`00PM@0_LSR0;g8hP020;g8hPH0`KC>00<0aJ^o0<Z^
_@3:[[d00P3:[[d40=>i`0<0g<2n0P3=amD40=3<e@D0]LGW1@2Y`N/N0:O0j`030000002W`>/0Yl3[
0140Yl3[403oool2000000@0oooo0P00000:0?ooo`00403oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00D0oooo@@2W`>/3000000D0Yl3[102V_NT40:BgiP@0XJgP0`2NX]L409bH
c`@0UicG1@2N/ND207kUl0@0Z<kd1@2Rb_@509OGo@D0XlSc0`2Kb?L309gFn`@0Q=;o100UXnT408G2
n`D0`KC>1@3:[[d0103>[k/0dkW00=>i`03C^L030=c0_PD0d<cE0P3AcMH20;G5i`<0]<GW102Y`N/O
0:O0j`030000002W`>/0Yl3[0140Yl3[3P3oool300000100oooo000A0?ooo`800000103oool20000
00L0oooo?@2W`>/3000000@0Yl3[1@2W_n/40:Jmj@<0Y;OV1@2BTm4308n;b`@0THk=102GW=L209ja
i@80U^kc0`2af?@40:S>m0H0WMOl102Tb?850:?8l`D0WMKk1P2De_h302BPj`@0QL;k0P31]<h30;>^
d`<0bZjm0P3>[k/20=>i`0@0g<2n00@0hlRl0=3<e@3@c=D0d<cE0`3AcMH60;C5i`@0ZL7[7`2W`>/0
0`000000Yl3[0:O0j`0A0:O0j`l0oooo00<000000?ooo`3oool03P3oool001L0oooo00<000000?oo
o`3oool01`3oooli0:O0j`<00000202W`>/50:Noj`@0X;;U0`2HX]`409:Cd@<0Sh_;1@2AS/d309NL
e`80U^kc1P2af?@50:7In`D0YLOa102Tb?860:;Dn@D0Ym?g1P2Ehod200^@g`<0:8W/1@2c[]<20<Z^
_@@0cZnk00@0dkW00=c0_P3L`;h0g<2n0`3Sb;`40=7=eP80d<gG0`2daNL30;?5i`@0ZL7[7P2W`>/0
0`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?oo
o`3oool0203ooole0:O0j`<00000302W`>/50:Fkj@<0X;;U0`2HX]`509:Cd@<0Sh_;102AS/d40:K[
nP<0_NGc1P2VfoX40:K8l@D0YLOa1@2Se?T60:S>m0D0ZnGj1P2Efoh01003K]d0:8W/02R9k00XRN`4
0;>^d`030<Z^_@3>[k/0cZnk00<0cZnk103L`;h30>?8_0030>O=^`3AcMH0dLgF00@0d<gG1P2caNL4
0:W1jah0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00`0oooo000G0?oo
o`8000002@3ooolc0:O0j`800000302W`>/40:Noj`D0YK_Y0`2P/^D309RRg0@0TY?A0`2?Rl/60:G;
m0@0_NGc102`goL40:W=l`@0Y/Sa1P2Se?T40:K;l`<0Z<kd102XhOX50;7Wn0D0RJGW00@00fkM0017
aP0XRN`0:8W/0`2c[]<60<j_^`030=Bc^03L`;h0g<2n00<0hlRl0`3WcK/40=3=e`80clgH1@2caNL5
0:W1jah0Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003oool0oooo00`0oooo000G0?oo
o`030000003oool0oooo00X0oooo;P2W`>/3000000l0Yl3[102W_n/40:Fkj@<0X;;U0`2HX]`409:C
d@@0TZ3M0`2Ubo@40<GZk`@0/=og0`2_eo@40:W=l`D0X]Gj1@2Ub_<40:K;l`@0Z>7j102]i?T40;7B
l@@0RJGW00@05dS400=^g@00AlH004O6102TXM840<j_^`<0e;>h00@0g<2n0>?8_03Sb;`0hlRl0`3W
cK/00`3Xc[`0d<gG0=3=e`040<o=f0D0/lGW1@2Y`N/N0:O0j`030000002W`>/0Yl3[0100Yl3[403o
ool00`000000oooo0?ooo`0;0?ooo`005P3oool00`000000oooo0?ooo`0<0?ooobX0Yl3[0`00000C
0:O0j`<0Yko[1@2J/>L308fLg@<0Ph[B1025RM0409:Pg@D0aN[_0`31i_060:oGm0D0XMKj102Tbo@5
0:G:l`D0Xmgk102]i?T30;7Un0@0/M;a0`29YNL201M8a0030000PP00AlH004O600<0Y:7B0`3>[k/4
0=Bc^0<0hlRl0`3WcK/30>S>_0@0clgH0P3>cMP40;?5i`D0ZL7[7P2W`>/00`000000Yl3[0:O0j`0A
0:O0ja00oooo00<000000?ooo`3oool02P3oool001H0oooo0P00000>0?ooobH0Yl3[0`00000F0:O0
j`D0Xk_Z102J/>L208fLg@<0Ph[B1@25RM0209:Pg@@0_]O/1031i_030;kSlPH0X]Wk102RcoL40:C;
m0H0Wmcl1@2Vgo/50;7Un0D0ThS50P1cMLH301M8a0030000PP00AlH0Y:7B00<0Y:7B00<0cZnk0=Bc
^03D/kP00`3D/kP00`3O_;H0hlRl0>?8_0020>O=^`@0j<jl00<0iljl0<o=f03?cMP0103>cMP40;;4
i`@0ZL7[7`2W`>/00`000000Yl3[0:O0j`0@0:O0j`l0oooo0P00000<0?ooo`005P3oool00`000000
oooo0?ooo`0>0?ooob80Yl3[0`00000F0:O0j`@0Y[o[1@2S^nX309Z`i`<0SIcM0`23R]8408F9d0D0
_]O/0`3>hNH40;kSlP80/^7g0`2RfO/309kHo0@0X/og1@2Hg?h609kLo@D0X^Sk102NT/L409>8a@<0
LgG60P0GB<@00`0008L002:^0017aP030:BQdPD0e;>h0`3O_;H30>O=^`<0j<jl0P3Wc[`50<k=f080
cLcI102ba>L40:W1jal0Yl3[00<000000:O0j`2W`>/0402W`>/@0?ooo`030000003oool0oooo00T0
oooo000F0?ooo`030000003oool0oooo0100oooo7@2W`>/3000001X0Yl3[102V_n/509Rcj`<0PicS
0P1eQ]H308>:dPD0Wj_O0`2nen`30<kQiP<0d^CT1@2bhOL609kHo0D0Rmco1@2Cfoh609CTo0@0XYO9
0`2NT/L509>8a@80LgG600D03SVh01M8a00GB<@00022000R[P0409fGc@<0e;>h103O_;H00`3Xa[<0
ilfk0>S>_0020>S>_0<0iljl00@0iljm0<k=f03>cMP0c/gH0`3=c=T50;;4j0@0ZL7[7P2W`>/00`00
0000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0203oool001H0oooo0P00000B0?oooaT0
Yl3[0`00000N0:O0j`@0Xkg/1@2H/n/208>Lh`<0MHKF0`20RM<509n[g`@0c^7V0`3Bi>@30=7Ri0D0
Z^Cj1@1nfOh608CHo`D0SM_o202RUlT409jBa`@0ThS50`1cMLH01@0>>KP05dS40000Q`006ZL002:^
00<0WIO=0`3D/kP30=nl]P80j<Jc103Xc[`20>O>_0<0iljm103=c=T20<c<fPD0//CX102Y`N/N0:O0
j`030000002W`>/0Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`080?ooo`005P3oool00`000000
oooo0?ooo`0B0?oooaD0Yl3[0`00000N0:O0j`@0Yko[102S_N`409Rcj`<0PicS0P1eQ]H40829d`<0
Wj_O0`34b=d40=;Ti0<0dN;T0`3Ah><409cOo@<0[L[_0`22dol60979n`@0XI?6202RUlT309jBa`@0
ThS50`1cMLH200hi^0030000Q`00088001ZW00@0WIO=00<0e;>h0=nl]P3O_;H00P3O_;H20>S6/`03
0>g;/P3Xc[`0j<jl00<0iljl0`3Wc[d00`3Vc[h0cLcI0<g<f@040<c<fPD0/LCX102Y`N/N0:O0j`03
0000002W`>/0Yl3[0100Yl3[3`3oool2000000T0oooo00030?ooo`800000103oool2000000@0oooo
0P0000040?ooo`030000003oool0oooo01@0oooo4@2W`>/300000280Yl3[102W_n/409^ik@@0PJG[
0P1TQ]h307F6eP@0P8WC1034b=d30=C@eP@0dN;T0`3Ah><30=3>f0@0[L[_0P2cXlP409f_i0D0Xi72
0`2QTlH80::Gb@@0VIC>102AV=H206b?h`<03SVh00<00027000JY`006ZL00`2MUld40=nl]P<0j<Jc
0P3]bk830>O>_0<0iljm0`3Vc[h40<c<fP80blcJ102aa>P50:W1jah0Yl3[00<000000:O0j`2W`>/0
402W`>/;0?ooo`<0000000<0oooo0000003oool0203oool00080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo3P2W`>/2000002H0
Yl3[102U_n`409^ik@@0PJG[0P1TQ]h20722e@D0W:3G0P34b=d40=C@eP80f/g<103Ah><30=3>f0<0
c;C31@2cXlP209f_i080ZiBo102STL840:6CaP<0XYO91@2MU<X309VDcPD0TISF0P1/Sn<00`00=KX0
3SVh0000O002000JY`@0YI_;0`3O_;H20>S6/`<0kL^b00<0kL^a0>O>_03Wc[`00`3Wc[d40>K>_P80
c<cJ103;c=X40;74j0@0ZL7[7P2W`>/00`000000Yl3[0:O0j`0A0:O0j`H0oooo100000040?ooo`03
0000003oool0oooo00L0oooo00020?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3o
ool0oooo0P00000G0?ooo`X0Yl3[0`00000Y0:O0j`@0YKo/0`2K^Nd4086Uj`80I8KN0`1`P]D509bP
e`@0e=3F0`3JcL`20=_4`P@0d<kH103<]<<00`3;Y[<0/j?80;>Sb0020;>Sb0@0ZiBo1@2STL830:6C
aP@0XYK8102MU<X409VDcP@0TISF0`1/Sn<00`00=KX03SVh0000Q`02000JY`@0YI_;00@0gkbf0>S6
/`3Xa[<0j<Jc0`3]bk820>g;/@<0iljm1P3Vc[h40<_<fP80blgL102aa>P40:W1jah0Yl3[00<00000
0:O0j`2W`>/04@2W`>/20?ooo`<00000203oool00`000000oooo0?ooo`070?ooo`000P3oool01000
0000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0H0?ooo`D0Yl3[0`00000]
0:O0j`@0X[g]0`2=/_0405^@jP0304QcfP1TQ]h0L8;E0080L8;E0P2LX=L30;Vad@80e=3F0`3JcL`3
0=_4`P030=Vf]P3@c]P0d<kH00@0c;C30P3;Y[<30;>Sb080_Z6l102[U;l40:>A`P@0Z9c:0`2RU/P5
09fDbP<0VIC>1@2N_Nh306fVl`04000c]@0007`0022[000JY`@0YI_;0`3Xa[<30>g;/P@0kL^a0P3W
c[d60>K>_P030>K?_`3;c=X0blcJ00<0blgL1@2`a>T40:W1jah0Yl3[00<000000:O0j`2W`>/0402W
`>/2000000`0oooo00<000000?ooo`3oool01P3oool00080oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00@0Yl3[0000000000000000
;@2W`>/40:Joj`@0X[g]0`2=/_0305^@jP80B7?J0`1`P]D60;Vad@<0f/g<0`3Ka<830=Vf]P@0c;C3
103;Y[<0102cXlP0_Z6l0;jQ_02nXK`40:^D_`80Xi720`2^YLl30:RLbP@0XYK8102MU<X40:Jok0@0
W[g^101]Y_<01000<kD0001l000PZ`006ZL20:FKb`80^k3?0P3Xa[<30>g;/PD0kL^a1P3Vc[h20>K?
_`@0blgL0P3:cmh50;34j@@0Z<7[7P2W`>/00`000000Yl3[0:O0j`0@0:O0j`d0oooo00<000000?oo
o`3oool01P3oool000<0oooo0P00000:0?ooo`<000000`3oool2000001P0oooo0`00000a0:O0j`@0
Y[o[102M_>h307NZlP0302Ebh@1KT>X0Fi3Z0080B7?J0`21S=D40;Vad@<0bKC6103Ka<830=Vf]P04
0=N][@3<]<<0c;C30<bd``@0bjJc1@2nXK`30:^D_`D0[ZG?102XW<X30::Fb0D0Yko[102V_n`507_K
n`80AJch0P00<kD2000PZ`D0^k3?0`3]bk870>g;/@@0i/jn0`3Vckl00`3Wdl40blgL0<_=g0040<[?
gPD0/<GY102X`N/M0:O0j`030000002W`>/0Yl3[0100Yl3[3@3oool00`000000oooo0?ooo`060?oo
o`00503oool00`000000oooo0?ooo`0E0?ooo`<00000103ooola0:O0j`@0Y[o/102M_>h307NZlP80
9G;Q0P18LmX4086<e@80^K7A1039]<H00`3@/K/0flC20=_4`P040=Vf]P80ejf]00<0c;C30<^V/`3;
Y[<00`3;Y[<00`3E/K@0_Z6l0;jQ_0020;jQ_080ZiBo0P2g/M@40:jUc`@0Z9c:2@2W_n/506cMi@<0
X:?H1028Z>X00`00<kD0022[000PZ`030;^`c`80clKA0P3]bk870>g;/@@0i/jn0P3Vckl30>OC`@@0
b/oN0P38d^840;35j@D0Z<7[7@2W`>/00`000000Yl3[0:O0j`0@0:O0j``0oooo00<000000?ooo`3o
ool01P3oool001@0oooo00<000000?ooo`3oool04P3oool3000000P0oooo<@2W`>/40:Jok0<0WKc^
0`1gZ_8302Ebh@0302iUeP18LmX0PHcE0080PHcE1@39]<H30=2a^`040=_4`P3I][H0fKJf0=Vf]P<0
ejf]1@3;Y[<20=Fa]0@0_Z6l1@2g/M@30:jUc`D0Yl3[102W_n/205??c@80<[Vm102TXM840:2Sf0D0
ZJOD00@0022N000PZ`2k/<l0^k3?103?a]480>g;/@030>g</@3Vc[h0i/jn00<0i/no0`3Wdl400`3Y
f/D0b/oN0<[?gP040<SBhP@0[/G[102X`N/N0:O0j`030000002W`>/0Yl3[0100Yl3[2`3oool00`00
0000oooo0?ooo`060?ooo`00503oool200000100oooo0`00000<0?oooc40Yl3[102U_n`309Vkl0<0
GIoc00@004G402Ebh@0UL^40;VGF102FUm830<VdaP@0d;6k103I][H30=N][@040=^^ZP3;Y[<0bjJc
0<^V/`<0eK6d0`2nXK`20<Rnd0@0]k7D102X`>/50:O0j`80Dlo=00<0D<g90:FQdP2UXM800`2UXM84
0:BQdP80X:?H0P2_Z]<40:VWe00307ZDh000;;D0^k3?00@0clKA0P3Fc=070>g;/@80kLba0`3Vckl3
0>OC`@<0jM[51038d^820<?Ci`@0[/G[102X`>/N0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool0
0`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`<000004@3oool`0:O0
j`@0YKo/0`2I^o0305fOl`8004G40P0^IMH409JGdP030<VdaP3@/K/0d;6k00<0d;6k00<0djjb0=Vf
]P3I][H0103G[Jd0103K[ZX0bjJc0<^V/`3;Y[<30=Fa]080_Z6l1038_]020;Nae080[l;X102X`>/2
06kNiP80D/bh102VY]H50:FQdP<0Y:7B1@2_Z]<30:VWe080UY_F103?a]440=K<d0D0kL^a0`3]c;42
0?3?/@@0im?10P3Yf/D20>SRc080b=;R0`33dnL50:c4j`@0Z<3[7@2W`>/00`000000Yl3[0:O0j`0@
0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool02P3oool20000
01D0oooo<02W`>/40:Fok0<0U[[a0`15U?4010004YD004G400A?c00^IMH309JGdPD0d;6k0`3C[[80
103I][H0ejf]0=N][@3G[Jd30=^^ZP030<^V/`3E/K@0eK6d0080eK6d1P38_]050:o2j0@0TNGk102^
]n040:JVeP@0YJ7B102[ZMD40:nZd`@0[JOA00@0UY_F000h^`3?a]40clKA103Fc=020=S<cP@0kL^a
0`3]c;420?3?/@030??H/`3Wdl40im?10080jM[50`3Xh/`40<?Ci`80^m7[102/a>/50:S0jad0Yl3[
00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003o
ool0oooo00L0oooo0`00000H0?oooc00Yl3[102U_n`309Jjl@<0AICa00<001:E0015a004Cl`0102U
WLh30=2a^`@0djjb103G[Jd30=^^ZPD0eK6d00@0gL:n0<Rnd038_]00b;k@0`36aMX30:o2j0<0[M[g
0`33fn/40:jgh0<0YZKF1@2VYmL40:^Ye@80[j[C0P2^ZM<40:fWd@0309JKeP00@L40e/c@00<0e/c@
0`3Hc<h30>g;/@<0kLba0`3`ck420??H/`80jM[50`3Xh/`30>?Xe@D0^m7[102Z`^`40:S0jah0Yl3[
00<000000:O0j`2W`>/03`2W`>/:0?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000001@3o
ool3000001`0oooo<02W`>/40:Fok0<0UK[a0`0hS^h00`004YD014o<00A?c0030:FMcP<0d;6k103C
[[80103G[jl0ejf]0=N][@3G[Jd30=^^ZP040>>j[@3E/K@0eK6d0=Fa]0<0gL:n1P36aMX30:gJm`D0
`m_[102^]n0409nSf0@0YZOG102[ZMD50:jYd`<0[JOA0P2MY=/00`00@L40e/c@0=K<d0040=S<cP03
0=[<c03]bk40kL^a00<0kLba0P3`ck430??H/`040?KS]P3Xh/`0j>;<0>SRc0<0hnSE0P3IjN020;_A
j`<0/lc/102Z`^`R0:O0j`030000002W`>/0Yl3[00l0Yl3[2@3oool00`000000oooo0?ooo`050?oo
o`004`3oool00`000000oooo0?ooo`020?ooo`<00000803oool`0:O0j`@0YKo/0`2E^_4303R>kP03
000BU@04Cl`0YIg>00<0YIg>00<0d;6k0=>^/P3C[[800P3C[[820=N_[`80ejf]103K[ZX0103S^Zd0
eK6d0=Fa]03E/K@30=g2_P040=g4`036aMX0a/GJ0<K5fP<0bLoN0P3@o]`20>;de`@0XZOJ102KX=P4
09nSf0<0YZOG1@2ZZMH40:jYd`@0[k?K00<0WJCK0011`@00@L40103Hc<h30=[<c0<0kLba0`3`ck42
0??H/`80m^>f0P3ck;d30>?Xe@<0fNWP1@2cc>`50:S1jb40Yl3[00<000000:O0j`2W`>/0402W`>/8
0?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000003oool0000000800000903oool`0:O0
j`@0YKo/0`2F^_4303R>k`03000BU@04Cl`0YIg>0080YIg>1@3C[[830=N_[`040=N][@3K[ZX0fjjZ
0=^^ZP<0hkZ]00@0eK6d0=g2_P3M`[h0gL:n0`3Ma<040<W?gP80d?kL0P3Rm=L20<O4e`@0XZOJ102K
X=P309nSf0@0YZOG102ZZMH20:jYd`<0[[OO102_/m/00`2MY=/004O60011`@020=S<cP@0f/c<00<0
gM3<0>g</@3]c;400P3`ck420??H/`80m^>f0`3ck;d00`3_l/D0fNWP0=WYh0020=WYh0<0bnCY102]
a^`40:S1jb80Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00D0oooo000C
0?ooo`<000009`3oool`0:O0j`@0YKo/0`2F^_4303R>k`03000OZ02ZXll0ZZ??0080ZZ??0`3C[[84
0=N_[`@0fjjZ0`3S^Zd40=g2_P<0gLC000<0glK00<W?gP39cmh00P3@o]`20>;de`@0alCG0`2RYmX4
09^Pf0@0XJCG102VYmL30:ZYePH0[[OO0`2_/m/209fTf`8004O6103Jc<`30=g@c0<0l<na0P3cf;<2
0?KS]P80lnbm0P3_l/D20>SfcP@0bnCY0P2kf>h40:g6k0@0Z<3[8P2W`>/00`000000Yl3[0:O0j`0?
0:O0j`L0oooo00<000000?ooo`3oool01@3oool001@0oooo00<000000?ooo`3oool09`3oool`0:O0
j`@0YKo/102G^o0203fAl004000OZ02ZXll0ZZ??0:ZSc`<0djjb103G[jl0103L]k<0fjjZ0=^^ZP3K
[ZX30>>j[@030>G2/P3M`[h0gL:n00<0gLC00`3Oa/020=3ng080h_CG1@37a=L409bNe@@0W9oF102Q
Y=L30:JWe`@0Z[SS1@2^]ml40:J/f`<0UZ;M00<004O60=[<c03Jc<`00`3Md<`30>CRd@80lmRc0P3f
hkH20??/_@80ko;50P3Xm/h30=khfPD0^mS^102Y`^`40:S0jb40Yl3[00<000000:O0j`2W`>/0402W
`>/70?ooo`030000003oool0oooo00@0oooo000;0?ooo`D000001@3oool2000002T0oooo;`2W`>/4
0:Fok0@0V;_`0P13U?440:ZSc`030=>^/P3G[jl0ejn_0080ejn_0P3L]k<20=^^ZP<0hkZ]0`3U`[84
0=g4`0<0glK00P3/g<820?KW^0040>kG_037a=L0alCG0<O4e`80/ZcB0`2LW]D409bOeP@0XJCG102W
]^@40:Zhh`D0Z:kK102V[=/309JRg@04000l/`3Md<`0gM3<0=g@c0<0i>;A0P3QmmP30?KS]P030??/
_@3_l/D0ko;50080j?K>0`3Nn=X20=3cj0D0[l_^102Y`^`U0:O0j`030000002W`>/0Yl3[0100Yl3[
1P3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02L0oooo;`2W`>/40:Fok0@0V;_`0P13U?430:ZSc`D0ejn_0`3L]k<0103K[ZX0hkZ]0>>j
[@3S^Zd30>G2/P030>K2/`3Ma<00gLC000<0glK00P3/g<820?KW^0<0k]Nl1@2b[=8309bNe@<0W9oF
1@2T/n<40:Nfi0@0Z:kL102X[]/40:J/f`<0UZ;M00<0FGgL000l/`3Md<`00`3Th]420>7gf0<0c_gP
00<0lnbm0>oba@3_l/D00P3Xm/h30=khfP80d??X0P2nh?040:o;kPD0Z<3[9@2W`>/00`000000Yl3[
0:O0j`0@0:O0j`D0oooo00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0W0?ooobl0Yl3[102U_n`409Vkl00304VGlP2SZM`0XjWL0080XjWL0`3G
[jl40=bg/`<0hkZ]0`3U`[830>K2/`@0glK00P3/g<820?KW^080k]Nl0P3La<840;:/dP<0W9kE102O
[N440:Bch`D0YjkL102X[]`30:R^f`D0Y;7R0`2@X^00101QPM`0i>;A0>CRd@3Th]420>7gf080c_gP
0P37n^T20<gejP80eOGT0P3In]d20=3cj0D0_^3`102Y`n`40:S0jbH0Yl3[00<000000:O0j`2W`>/0
3`2W`>/50?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool09`3oool_0:O0j`@0YKo/102I^o001019Uo80XjWL0:>Yg02SZM`30=N_[`@0g;Nc
00<0gl>l0>>j[@3S^Zd00`3U`[830>K2/`030>K3/`3Oa/00glK00080k=c20P3fikP20>kG_0<0g<C2
0P2b[=830:fWd@<0WJGK102O[N440:J]g0D0YjkL0`2X[]`40:Ngi0@0Y;7R102@X^020661g080hOOH
00@0c_gP0<Ojj@37n^T0ao[Y0P3=mNX20=Gei080fO[M0P3Do]X20<_jj0D0[l_^102Y`n`Y0:O0j`03
0000002W`>/0Yl3[0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo
0?ooo`0:0?ooo`800000:03oool_0:O0j`@0YKo/102I_?001@1>V_<0XjWL0:>Yg02SZM`0ejn_00@0
g;Nc0P3O`k`0103S^Zd0iL:b0>G2/P3U`[830>K2/`<0i/>c0`3/g<820?KW^0030>kG_03La<80g<C2
0080g<C21P2]Ym4309fUf`@0YJ_K102V[M`40:N^g0@0YkWU102W]n@30:BahP@0T:;P0`1QPM`203=Y
f0803FoO0P3=mNX20=Gei080fO[M0P3Do]X20<_jj080^]ob102_bnh50:S0jbT0Yl3[00<000000:O0
j`2W`>/03`2W`>/40?ooo`030000003oool0oooo00@0oooo000<0?ooo`8000003P3oool00`000000
oooo0?ooo`0V0?ooobl0Yl3[102V_n`409Vll0<0XjWL103L]k<30=o3_0@0iL:b0`3V`[<30>K3/`80
jlZc0P3fikP00`3^ek`0g<C20=c4`P020=c4`P80ckS41@2]Ym440:JYf0@0YJ_K0`2V[M`50:NiiP@0
YkWU102RZM/309ZSf`@0QiOL0P1YQM`303=Yf0@0J:Sf0P3In]d00`3Do]X0bo[X0<_jj0050;[OlP@0
ZL;/102X`>/Z0:O0j`030000002W`>/0Yl3[00l0Yl3[0`3oool00`000000oooo0?ooo`040?ooo`00
7@3oool00`000000oooo0?ooo`0V0?ooobl0Yl3[102V_n`409Zll0<0MjSa0`3L]k<30=o3_0030=k7
`@3U`[80iL:b00<0i/:c0`3V`k<30>_:/`80mMN^00@0mmR[0?;B/03La<80g<C2103?^<@20:fWd@<0
/Z[A102VZMP30:F[f`@0YkOT102W^NH50:F[f`@0XZWK0`2JXm/408NGg080JHGL0`1SS>@30:;@n080
`_?`0P30o]T20<7hk@D0[<S^102Y`^`^0:O0j`030000002W`>/0Yl3[00h0Yl3[103oool00`000000
oooo0?ooo`030?ooo`007P3oool00`000000oooo0?ooo`0V0?ooobl0Yl3[102V_n`409Zll0<0MjSa
00@0g;Nc0=o3_03O`k`0gl>l0`3Nal440>K2/`<0i/>c0P3[b[<20?GG[P80mmR[0P3bd[050<nha0D0
/Z[A102VZMP40:Nch@@0YkOT102V[=/40:F[f`@0XZWK0`2JXm/408NGg0<0JHGL0`1SS>@30<;cl004
0<3nf@31n>d0`OS]0<7hk@80/mGb102/b>hb0:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`00
0000oooo0?ooo`030?ooo`007`3oool2000002P0oooo;P2W`>/40:Jok0@0Vkc_0P0YR>`40=o3_0<0
g/O100<0gLO30>K2/`3V`[<00`3V`k<30>_:/`80mMN^00D0mmR[0?;B/03bd[00l]:`0>W;^0030<nh
a080b[G5102bZ]450:V/f@@0Yk?Q102WZmT40:J/f`<0YJ_K1@2P[^8309JSgP@0QI?J0`1jSm`4092d
k`030;;dl`2ZnM<0Z_WC00D0/mGb102X`N`b0:O0j`030000002W`>/0Yl3[0100Yl3[00<0oooo0000
003oool0103oool00240oooo00<000000?ooo`3oool09P3oool^0:O0j`D0Y[o/0`2K_>l202V8k080
gl>l0`3Nal430=g7``@0i/>c0P3[b[<20?GG[P80mmR[0`3bd[020>W;^0030<nha03:]LD0b[G50080
b[G50P2bZ]420;F[c`@0ZJcI1@2ZZ]L40:N[f@<0YZcK102T/n<40:2^hP@0UZ?N0`25TmX407Z?g0<0
/_Cc1@2ijOD40:W3k@@0Z<7/<P2W`>/00`000000Yl3[0:O0j`0?0:O0j`030?ooo`000000oooo00@0
oooo000R0?ooo`030000003oool0oooo02H0oooo;`2W`>/40:Jok0<0Vkc_00<0FZ3d00=agP3Nal40
0`3Nal430=g7``030=g7a03V`k<0i/>c00<0jlZc0P3eejh20?OHZ`80l]:`0`3YbkP50<Zea@D0]J_?
0P2Y[=T20:nZdP@0ZZ[G102WZmT40:NdhP@0Y;?S0`2P[^8409JSgP<0QI?J1@2E^_430:ohk0D0[<W_
102Y`ndf0:O0j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002<0oooo00<0
00000?ooo`3oool09P3oool_0:O0j`@0Y[o/0`2K_>l0101JX?@006CD0=k7`@3Nal430=g7``<0gLO4
0`3[b[<20?GG[P80mmR[0`3bd[030>W;^0040>78_`3:]LD0b[G50<Zea@80b;C6102eZll50:nZdP<0
ZZ[G1@2Y/]h40:NdhP@0WiO;0`2IT//408n=c@<0RICH0`2E^_400`2_n>`0[m;b0:oBlP020:oBlP@0
[<W_>P2W`>/00`000000Yl3[0:O0j`0?0:O0j`030000003oool0oooo00<0oooo000T0?ooo`800000
9`3oool_0:O0j`@0Y[o/102L_Nl00`00I=@0gLO30=g7``020=g7``<0gLO400<0g/_60>_:/`3[b[<0
0P3eejh20?OHZ`80l]:`0`3YbkP30>78_`030<Zea@38]<H0b;C60080b;C60P2eZll20;Z/c0@0[j[B
102/[MP40:VbgPD0Y9W:0`2OUl/309VBb`D0Shg=0`29U=P208KYb@80[mcg102_d_840:S1jcX0Yl3[
00<000000:O0j`2W`>/02`2W`>/30?ooo`030000003oool0oooo00<0oooo000V0?ooo`030000003o
ool0oooo02D0oooo;`2W`>/40:Jok0@0WKg_00<005S<0=g7``3Mal<00`3Mal@30=k;aP80mMN^0P3g
f:/30?;B/0<0jL^h0`3Qb;l50<RdaPD0^Zc<0P2_Z]820;6Xc`@0[:gH102WVLP40:BIbP@0WiO;0`2I
T//408n=c@0308gZm026jLT0Q^W900D0[mcg102X`^`40:S1jcX0Yl3[00<000000:O0j`2W`>/01P2W
`>/80?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo02D0oooo;`2W`>/4
0:Jok0@0WKg_00<005S<0=g7a03Mal@00P3Mal@30=k;aP80i]W70P3`i<420?;V_`<0jL^h103Qb;l0
103JbLP0b;C60<RdaP38]<H20<RhbP@0^Zc<1@2aZ<l20:b]f080[Ic70`2WVLP40:BIbP@0WiO;0`2I
T//409?:nP@0[>Gj1@2Ya>d30:S2k3h0Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`030000003o
ool0oooo0080oooo000X0?ooo`030000003oool0oooo02H0oooo;P2W`>/40:Jok0@0X;k^00<004_1
0=g7a03Mal@00`3NblH20>KIa`80l>C10`3bi[l20>kWaP@0hLRo0`3JbLP00`38]<H0b;S:0<RhbP02
0<RhbP80^Zc<0P2k[L`40;6Xc`@0[Ic7102WVLP30:BIbPD0WZKL102H[nL30:7ZnPD0ZLO_0`2Ya>e2
0:O0j`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00000W0?oo
obd0Yl3[1@2V_n`40:2nkP03001;`@3NblH0g/_60080g/_60P3VfLL20?3T`@80l^Jo0P3^ilH20>CZ
e@80hLRo103JbLP50<RhbPD0^jg<0P2aZ<l20;NYb`@0[Ic70`2WVLP40:JZf@@0WZKL00@0000009?X
n@2Cj?T0TnSi1@2Yb_480:Nojch0Yl3[0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo000[0?ooo`030000003oool0oooo02D0oooo;@2W`>/40:Jok0D0X[o]00<0042a0=k;
aP3NblH00P3VfLL20?3T`@<0l^Jo00<0k^O60>CZe@3Tj]D00P3Tj]D40=[9b080e=GI0P38^<X30<W5
eP@0^jg<1@2gZL/30:fLa`@0/;SO102VZ]T20000000309?Xn@2Wbo80Yl_b00<0Yl_b1@2W_nX30:No
j`D0Z<3[>@2W`>/80?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002`0
oooo00<000000?ooo`3oool09@3ooolb0:O0j`<0X[o]0P2H_O430>KIa`80l>C10P3bi[l0103^ilH0
i>[E0>CZe@3Tj]D30<cbj`80f/W80`3DeMT50<W5eP80^jg<0`33amd40;NYb`@0]]C_102`^=l00`00
0000QnCi08OTn@050:K;l`P0YkoZ102X`N`40:S0jcH0Yl3[2`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo000]0?ooo`030000003oool0oooo02H0oooo<@2W`>/40:Fok080
V;ga0P3`i<420?;V_`040>kWaP3Tj]D0i>[E02/000@0c?;[103DeMT20;C_mP@0bLGF1@33amd20;NY
b`<0V>ke102fe>l308CHo`D0Y<Wc202W_nX40:O1k0@0Z<7/102W_n/b0:O0j`l0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`010?ooo`00;P3oool00`000000oooo0?ooo`0V0?oooc40
Yl3[102V`>`40:6okP@0WKk`0P21^oT507cTl0D0]>of102Ul?L40<?7g@D0V>ke102<dOh40:C6l@T0
YkoZ202W`N`80:Nojbd0Yl3[503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040
oooo000_0?ooo`8000009`3ooola0:O0j`@0Y/3/102U_n`409fnl0@0W[o`1028__T409K1m00407k3
o@2Ul?L0YO3g0:G`m`D0W<Cd0`2DbOX50:C3k`@0Yko[102W_nX80:O1k0D0YkoZ102W_n/]0:O0jaP0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`0U0?ooocD0Yl3[202U_n`409jol0@0XL3_102F`O@50:71k`@0Y/3/102U`Nd40:S0j`@0Yko[
202W`N`80:NojPD0Yl7/:02W`>/L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0@3oool00380oooo00<000000?ooo`3oool09@3oooli0:O0j`@0YKo/1@2V`>`30:70k`D0YL3]102W
`>/40:K0k0@0Yl3[102X`>/80:O1k0P0YkoZ202W`N`50:Nojb00Yl3[803oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0040oooo000c0?ooo`030000003oool0oooo02D0oooo@P2W`>/4
0:O0k100Yl3[102W`>`40:O1k0P0YkoZ1@2W`N`80:Nojb00Yl3[903oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0040oooo000d0?ooo`8000009P3ooomF0:O0j`@0Yl3/102X_n/40:No
jP@0Yl7/202W_n/50:O1k1/0Yl3[:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0040oooo000f0?ooo`030000003oool0oooo02D0ooooE02W`>/50:S0j`<0Z;o[1@2W`N`80:Noj`P0
Yl7/102W_n/D0:O0jb`0oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool003L0oooo
00<000000?ooo`3oool09@3ooomI0:O0j`@0Yl7/202W_n/80:O1k0P0Yko[402W`>/`0?ooo`030000
003oool0oooo00H0oooo0@0000010?ooo`40oooo000h0?ooo`030000003oool0oooo02D0ooooF@2W
`>/40:Roj`@0Yko[202W`N`80:Noj``0Yl3[>03oool00`000000oooo0?ooo`050?ooo`4000000@3o
ool10?ooo`00>@3oool2000002H0ooooE@2W`>/40:S0j`<0Z;o[202W`N`80:Noj`D0Yl7/202W`>/k
0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo000k0?ooo`030000003oool0oooo
02@0ooooE@2W`>/30:S0j`@0Yl3/102W`N`80:Noj`D0Yl7/202W_n/o0?ooo`030000003oool0oooo
00@0oooo0@0000010?ooo`40oooo000l0?ooo`030000003oool0oooo02@0ooooF02W`>/40:O0k0D0
Yko[202W`N`80:Nojd<0oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool003d0oooo
00<000000?ooo`3oool0903ooomH0:O0j`D0Yko[1`2W`N`80:NojdP0oooo00<000000?ooo`3oool0
0P3oool100000040oooo0@3oool003h0oooo0P00000U0?oooeP0Yl3[1@2W`>`30:O1k0P0Yko[B`3o
ool00`000000oooo0?ooo`030?ooo`4000000@3oool00400oooo00<000000?ooo`3oool08`3ooomH
0:O0j`@0Yl3/202W_n]?0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`0S0?oooeP0Yl3[202W_n]C0?ooo`050000003oool0oooo0?ooo`0000000@3oool0
0480oooo00<000000?ooo`3oool0903ooomH0:O0j`<0Yko[E`3oool010000000oooo0?ooo`000001
0?ooo`00@`3oool2000002D0ooooD`2W`>]N0?ooo`040000003oool0oooo00000040oooo00150?oo
o`030000003oool0oooo02<0ooooC`2W`>]R0?ooo`030000003oool000000040oooo00160?ooo`03
0000003oool0oooo02<0ooooB`2W`>]V0?ooo`4000000@3oool100000000A`3oool00`000000oooo
0?ooo`0S0?ooodL0Yl3[JP3oool200000000B03oool2000002D0oooo@P2W`>]]0?ooo`800000001:
0?ooo`030000003oool0oooo02<0oooo?P2W`>]`0?ooo`800000001;0?ooo`030000003oool0oooo
0280oooo>`2W`>]_0?ooo`@000000P3oool004`0oooo00<000000?ooo`3oool08`3ooolc0:O0jg40
oooo100000060?ooo`00C@3oool2000002@0oooo;`2W`>]`0?ooo`@000002P3oool004l0oooo00<0
00000?ooo`3oool08P3oool[0:O0jfl0oooo1000000>0?ooo`00D03oool00`000000oooo0?ooo`0S
0?ooobH0Yl3[KP3oool400000180oooo001A0?ooo`030000003oool0oooo02<0oooo8P2W`>]^0?oo
o`<000005P3oool00580oooo0P00000T0?oooah0Yl3[K@3oool4000001T0oooo001D0?ooo`030000
003oool0oooo0280oooo5`2W`>]_0?ooo`@000007@3oool005D0oooo00<000000?ooo`3oool08@3o
oolD0:O0jfh0oooo1000000Q0?ooo`00EP3oool00`000000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4
000002D0oooo001G0?ooo`8000008`3oool;0:O0jf`0oooo1000000Y0?ooo`00F@3oool00`000000
oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool3000002d0oooo001J0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0JP3oool400000300oooo001K0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0IP3oool4000003@0oooo001L0?ooo`8000008@3oool00`000000oooo0?ooo`1R
0?ooo`@00000>03oool005h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?oo
o`@00000?03oool005l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@0
0000@03oool00600oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`<00000
A03oool00640oooo0P00000L0?ooo`030000003oool0oooo05<0oooo100000170?ooo`00H`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04l0oooo1000001;0?ooo`00I03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo1000001?0?ooo`00I@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo04L0oooo1000001C0?ooo`00IP3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04<0oooo1000001G0?ooo`00I`3oool2000001H0oooo00<0
00000?ooo`3oool0@03oool3000005/0oooo001Y0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?03oool4000005h0oooo001Z0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0>03oool400000680oooo001[0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0=03oool4000006H0oooo001/0?ooo`800000403oool00`000000oooo0?ooo`0a0?ooo`@00000
JP3oool006h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3o
ool006l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Z0?ooo`<00000LP3oool0
0700oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`@00000M@3oool00740
oooo0P00000;0?ooo`030000003oool0oooo0280oooo1000001i0?ooo`00L`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01h0oooo1000001m0?ooo`00M03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000210?ooo`00M@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01H0oooo100000250?ooo`00MP3oool2000000H0oooo00<000000?oo
o`3oool04`3oool3000008T0oooo001h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03`3oool4000008`0oooo001i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool400000900oooo001j0?ooo`050000003oool0oooo0?ooo`0000002@3oool4000009@0oooo
001k0?ooo`80000000<0oooo0000003oool0103oool4000009P0oooo001m0?ooo`80000000<0oooo
0000000000000P00002L0?ooo`00OP3oool200000:00oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65187 .573 .6459 Mtetra
.573 .6459 .57895 .65187 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63936 Mtetra
.59604 .63936 .60194 .6454 .6135 .64214 .60764 .63607 Mtetra
.60764 .63607 .6135 .64214 .62511 .63887 .61928 .63277 Mtetra
.655 .751 .92 r
.61928 .63277 .62511 .63887 .63677 .63557 .63098 .62947 Mtetra
.655 .751 .921 r
.63098 .62947 .63677 .63557 .64848 .63225 .64272 .62617 Mtetra
.655 .753 .922 r
.64272 .62617 .64848 .63225 .66023 .62892 .65451 .62284 Mtetra
.655 .754 .922 r
.65451 .62284 .66023 .62892 .67204 .62558 .66635 .6195 Mtetra
.655 .755 .923 r
.66635 .6195 .67204 .62558 .68389 .62224 .67824 .61613 Mtetra
.656 .755 .923 r
.67824 .61613 .68389 .62224 .6958 .61889 .69018 .61274 Mtetra
.656 .754 .922 r
.69018 .61274 .6958 .61889 .70776 .61555 .70217 .60932 Mtetra
.657 .753 .921 r
.70217 .60932 .70776 .61555 .71977 .6122 .71421 .60588 Mtetra
.656 .75 .919 r
.71421 .60588 .71977 .6122 .73182 .6088 .7263 .60244 Mtetra
.7263 .60244 .73182 .6088 .74393 .60537 .73844 .59901 Mtetra
.655 .75 .92 r
.73844 .59901 .74393 .60537 .75609 .60193 .75064 .59556 Mtetra
.656 .751 .92 r
.75064 .59556 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.656 .752 .92 r
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.656 .751 .92 r
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.57853 .63659 .5845 .64264 .59604 .63936 .59011 .63329 Mtetra
.59011 .63329 .59604 .63936 .60764 .63607 .60173 .62999 Mtetra
.656 .752 .921 r
.60173 .62999 .60764 .63607 .61928 .63277 .61341 .62666 Mtetra
.61341 .62666 .61928 .63277 .63098 .62947 .62514 .62331 Mtetra
.657 .751 .92 r
.62514 .62331 .63098 .62947 .64272 .62617 .63691 .61994 Mtetra
.657 .75 .919 r
.63691 .61994 .64272 .62617 .65451 .62284 .64873 .61656 Mtetra
.656 .749 .918 r
.64873 .61656 .65451 .62284 .66635 .6195 .66061 .61317 Mtetra
.656 .748 .918 r
.66061 .61317 .66635 .6195 .67824 .61613 .67253 .60977 Mtetra
.67253 .60977 .67824 .61613 .69018 .61274 .6845 .60637 Mtetra
.655 .748 .918 r
.6845 .60637 .69018 .61274 .70217 .60932 .69653 .60297 Mtetra
.655 .75 .92 r
.69653 .60297 .70217 .60932 .71421 .60588 .70861 .59956 Mtetra
.655 .752 .921 r
.70861 .59956 .71421 .60588 .7263 .60244 .72074 .59611 Mtetra
.656 .753 .921 r
.72074 .59611 .7263 .60244 .73844 .59901 .73292 .59264 Mtetra
.656 .752 .921 r
.73292 .59264 .73844 .59901 .75064 .59556 .74515 .58915 Mtetra
.656 .752 .92 r
.74515 .58915 .75064 .59556 .76289 .5921 .75744 .58565 Mtetra
.656 .751 .92 r
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54248 Mtetra
.90908 .54248 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62999 .59578 .62383 Mtetra
.59578 .62383 .60173 .62999 .61341 .62666 .60749 .62047 Mtetra
.655 .751 .92 r
.60749 .62047 .61341 .62666 .62514 .62331 .61925 .61712 Mtetra
.655 .751 .921 r
.61925 .61712 .62514 .62331 .63691 .61994 .63106 .61376 Mtetra
.655 .753 .922 r
.63106 .61376 .63691 .61994 .64873 .61656 .64292 .61039 Mtetra
.655 .754 .923 r
.64292 .61039 .64873 .61656 .66061 .61317 .65483 .607 Mtetra
.655 .755 .923 r
.65483 .607 .66061 .61317 .67253 .60977 .66679 .60357 Mtetra
.656 .755 .923 r
.66679 .60357 .67253 .60977 .6845 .60637 .67879 .60013 Mtetra
.656 .754 .922 r
.67879 .60013 .6845 .60637 .69653 .60297 .69085 .59665 Mtetra
.657 .753 .921 r
.69085 .59665 .69653 .60297 .70861 .59956 .70297 .59316 Mtetra
.656 .751 .92 r
.70297 .59316 .70861 .59956 .72074 .59611 .71513 .58967 Mtetra
.656 .75 .92 r
.71513 .58967 .72074 .59611 .73292 .59264 .72735 .58618 Mtetra
.656 .751 .92 r
.72735 .58618 .73292 .59264 .74515 .58915 .73962 .58268 Mtetra
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54248 .90406 .53563 Mtetra
.90406 .53563 .90908 .54248 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Mtetra
.656 .752 .921 r
.58979 .61764 .59578 .62383 .60749 .62047 .60153 .61427 Mtetra
.60153 .61427 .60749 .62047 .61925 .61712 .61332 .61087 Mtetra
.657 .752 .92 r
.61332 .61087 .61925 .61712 .63106 .61376 .62516 .60744 Mtetra
.657 .75 .919 r
.62516 .60744 .63106 .61376 .64292 .61039 .63705 .604 Mtetra
.656 .749 .918 r
.63705 .604 .64292 .61039 .65483 .607 .64899 .60055 Mtetra
.656 .748 .917 r
.64899 .60055 .65483 .607 .66679 .60357 .66099 .5971 Mtetra
.66099 .5971 .66679 .60357 .67879 .60013 .67303 .59365 Mtetra
.655 .748 .918 r
.67303 .59365 .67879 .60013 .69085 .59665 .68513 .5902 Mtetra
.655 .75 .92 r
.68513 .5902 .69085 .59665 .70297 .59316 .69728 .58673 Mtetra
.655 .752 .921 r
.69728 .58673 .70297 .59316 .71513 .58967 .70948 .58324 Mtetra
.656 .752 .921 r
.70948 .58324 .71513 .58967 .72735 .58618 .72173 .57971 Mtetra
.72173 .57971 .72735 .58618 .73962 .58268 .73404 .57616 Mtetra
.656 .752 .92 r
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Mtetra
.656 .751 .92 r
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56903 Mtetra
.75881 .56903 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61816 Mtetra
.56034 .61816 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61138 Mtetra
.58374 .61138 .58979 .61764 .60153 .61427 .59552 .60798 Mtetra
.655 .751 .92 r
.59552 .60798 .60153 .61427 .61332 .61087 .60734 .60457 Mtetra
.655 .751 .921 r
.60734 .60457 .61332 .61087 .62516 .60744 .61922 .60117 Mtetra
.655 .753 .922 r
.61922 .60117 .62516 .60744 .63705 .604 .63115 .59775 Mtetra
.655 .755 .923 r
.63115 .59775 .63705 .604 .64899 .60055 .64312 .5943 Mtetra
.655 .756 .924 r
.64312 .5943 .64899 .60055 .66099 .5971 .65515 .59083 Mtetra
.656 .756 .923 r
.65515 .59083 .66099 .5971 .67303 .59365 .66723 .58732 Mtetra
.656 .755 .923 r
.66723 .58732 .67303 .59365 .68513 .5902 .67936 .58379 Mtetra
.657 .753 .921 r
.67936 .58379 .68513 .5902 .69728 .58673 .69154 .58024 Mtetra
.656 .751 .92 r
.69154 .58024 .69728 .58673 .70948 .58324 .70378 .57669 Mtetra
.656 .75 .92 r
.70378 .57669 .70948 .58324 .72173 .57971 .71607 .57314 Mtetra
.656 .751 .92 r
.71607 .57314 .72173 .57971 .73404 .57616 .72841 .56958 Mtetra
.72841 .56958 .73404 .57616 .7464 .5726 .74081 .566 Mtetra
.74081 .566 .7464 .5726 .75881 .56903 .75326 .56241 Mtetra
.75326 .56241 .75881 .56903 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61816 .55418 .61191 Mtetra
.55418 .61191 .56034 .61816 .57202 .61478 .56589 .60852 Mtetra
.655 .751 .92 r
.56589 .60852 .57202 .61478 .58374 .61138 .57765 .60511 Mtetra
.656 .752 .921 r
.57765 .60511 .58374 .61138 .59552 .60798 .58946 .60168 Mtetra
.58946 .60168 .59552 .60798 .60734 .60457 .60132 .59822 Mtetra
.657 .752 .92 r
.60132 .59822 .60734 .60457 .61922 .60117 .61323 .59473 Mtetra
.657 .75 .918 r
.61323 .59473 .61922 .60117 .63115 .59775 .62519 .59123 Mtetra
.657 .748 .917 r
.62519 .59123 .63115 .59775 .64312 .5943 .6372 .58772 Mtetra
.656 .747 .917 r
.6372 .58772 .64312 .5943 .65515 .59083 .64926 .58422 Mtetra
.656 .746 .917 r
.64926 .58422 .65515 .59083 .66723 .58732 .66137 .58072 Mtetra
.655 .747 .918 r
.66137 .58072 .66723 .58732 .67936 .58379 .67354 .57722 Mtetra
.655 .749 .919 r
.67354 .57722 .67936 .58379 .69154 .58024 .68576 .5737 Mtetra
.655 .751 .921 r
.68576 .5737 .69154 .58024 .70378 .57669 .69804 .57015 Mtetra
.656 .752 .921 r
.69804 .57015 .70378 .57669 .71607 .57314 .71036 .56657 Mtetra
.71036 .56657 .71607 .57314 .72841 .56958 .72274 .56296 Mtetra
.656 .752 .92 r
.72274 .56296 .72841 .56958 .74081 .566 .73518 .55935 Mtetra
.656 .751 .92 r
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.54798 .60563 .55418 .61191 .56589 .60852 .55972 .6022 Mtetra
.55972 .6022 .56589 .60852 .57765 .60511 .57151 .59874 Mtetra
.57151 .59874 .57765 .60511 .58946 .60168 .58335 .59528 Mtetra
.655 .75 .92 r
.58335 .59528 .58946 .60168 .60132 .59822 .59525 .59183 Mtetra
.654 .751 .921 r
.59525 .59183 .60132 .59822 .61323 .59473 .60719 .58838 Mtetra
.654 .753 .923 r
.60719 .58838 .61323 .59473 .62519 .59123 .61919 .58492 Mtetra
.655 .756 .924 r
.61919 .58492 .62519 .59123 .6372 .58772 .63123 .58142 Mtetra
.655 .757 .925 r
.63123 .58142 .6372 .58772 .64926 .58422 .64333 .57789 Mtetra
.656 .757 .924 r
.64333 .57789 .64926 .58422 .66137 .58072 .65548 .57433 Mtetra
.657 .756 .923 r
.65548 .57433 .66137 .58072 .67354 .57722 .66768 .57072 Mtetra
.657 .754 .922 r
.66768 .57072 .67354 .57722 .68576 .5737 .67994 .56711 Mtetra
.656 .751 .92 r
.67994 .56711 .68576 .5737 .69804 .57015 .69225 .5635 Mtetra
.656 .75 .919 r
.69225 .5635 .69804 .57015 .71036 .56657 .70461 .55989 Mtetra
.655 .751 .92 r
.70461 .55989 .71036 .56657 .72274 .56296 .71703 .55628 Mtetra
.656 .751 .92 r
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Mtetra
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59584 Mtetra
.655 .751 .921 r
.5535 .59584 .55972 .6022 .57151 .59874 .56532 .59238 Mtetra
.655 .752 .921 r
.56532 .59238 .57151 .59874 .58335 .59528 .5772 .58891 Mtetra
.656 .753 .921 r
.5772 .58891 .58335 .59528 .59525 .59183 .58913 .58539 Mtetra
.657 .752 .92 r
.58913 .58539 .59525 .59183 .60719 .58838 .6011 .58184 Mtetra
.657 .75 .918 r
.6011 .58184 .60719 .58838 .61919 .58492 .61313 .57827 Mtetra
.657 .747 .917 r
.61313 .57827 .61919 .58492 .63123 .58142 .62521 .57471 Mtetra
.656 .746 .916 r
.62521 .57471 .63123 .58142 .64333 .57789 .63734 .57115 Mtetra
.63734 .57115 .64333 .57789 .65548 .57433 .64953 .56759 Mtetra
.655 .747 .917 r
.64953 .56759 .65548 .57433 .66768 .57072 .66177 .56404 Mtetra
.655 .749 .919 r
.66177 .56404 .66768 .57072 .67994 .56711 .67407 .56047 Mtetra
.655 .752 .921 r
.67407 .56047 .67994 .56711 .69225 .5635 .68641 .55687 Mtetra
.656 .753 .921 r
.68641 .55687 .69225 .5635 .70461 .55989 .69881 .55322 Mtetra
.69881 .55322 .70461 .55989 .71703 .55628 .71127 .54955 Mtetra
.656 .752 .92 r
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Mtetra
.656 .751 .92 r
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Mtetra
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59637 Mtetra
.52366 .59637 .53 .60273 .54172 .59929 .53542 .59291 Mtetra
.655 .752 .921 r
.53542 .59291 .54172 .59929 .5535 .59584 .54723 .58943 Mtetra
.54723 .58943 .5535 .59584 .56532 .59238 .55909 .58596 Mtetra
.653 .751 .922 r
.55909 .58596 .56532 .59238 .5772 .58891 .571 .58252 Mtetra
.65 .752 .924 r
.571 .58252 .5772 .58891 .58913 .58539 .58296 .57914 Mtetra
.648 .757 .929 r
.58296 .57914 .58913 .58539 .6011 .58184 .59498 .57581 Mtetra
.647 .765 .935 r
.59498 .57581 .6011 .58184 .61313 .57827 .60705 .57245 Mtetra
.649 .774 .94 r
.60705 .57245 .61313 .57827 .62521 .57471 .61917 .569 Mtetra
.652 .779 .941 r
.61917 .569 .62521 .57471 .63734 .57115 .63134 .56541 Mtetra
.656 .781 .94 r
.63134 .56541 .63734 .57115 .64953 .56759 .64356 .56169 Mtetra
.66 .777 .936 r
.64356 .56169 .64953 .56759 .66177 .56404 .65583 .55787 Mtetra
.661 .77 .93 r
.65583 .55787 .66177 .56404 .67407 .56047 .66816 .55403 Mtetra
.66 .761 .925 r
.66816 .55403 .67407 .56047 .68641 .55687 .68053 .55022 Mtetra
.658 .755 .922 r
.68053 .55022 .68641 .55687 .69881 .55322 .69297 .54648 Mtetra
.657 .752 .921 r
.69297 .54648 .69881 .55322 .71127 .54955 .70546 .54278 Mtetra
.656 .752 .92 r
.70546 .54278 .71127 .54955 .72378 .54588 .71801 .53907 Mtetra
.71801 .53907 .72378 .54588 .73634 .54219 .73061 .53534 Mtetra
.656 .751 .92 r
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Mtetra
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Mtetra
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Mtetra
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59344 Mtetra
.655 .751 .921 r
.50554 .59344 .51196 .59982 .52366 .59637 .51728 .58998 Mtetra
.653 .751 .922 r
.51728 .58998 .52366 .59637 .53542 .59291 .52907 .58655 Mtetra
.648 .752 .925 r
.52907 .58655 .53542 .59291 .54723 .58943 .54091 .58325 Mtetra
.639 .755 .933 r
.54091 .58325 .54723 .58943 .55909 .58596 .55281 .58017 Mtetra
.625 .765 .946 r
.55281 .58017 .55909 .58596 .571 .58252 .56476 .57734 Mtetra
.61 .783 .964 r
.56476 .57734 .571 .58252 .58296 .57914 .57677 .57468 Mtetra
.596 .807 .981 r
.57677 .57468 .58296 .57914 .59498 .57581 .58885 .57203 Mtetra
.587 .831 .991 r
.58885 .57203 .59498 .57581 .60705 .57245 .60097 .56919 Mtetra
.589 .853 .994 r
.60097 .56919 .60705 .57245 .61917 .569 .61315 .56602 Mtetra
.604 .869 .992 r
.61315 .56602 .61917 .569 .63134 .56541 .62537 .56241 Mtetra
.628 .877 .988 r
.62537 .56241 .63134 .56541 .64356 .56169 .63763 .55836 Mtetra
.653 .872 .981 r
.63763 .55836 .64356 .56169 .65583 .55787 .64993 .55396 Mtetra
.67 .856 .971 r
.64993 .55396 .65583 .55787 .66816 .55403 .66227 .54938 Mtetra
.678 .831 .957 r
.66227 .54938 .66816 .55403 .68053 .55022 .67466 .5448 Mtetra
.676 .803 .943 r
.67466 .5448 .68053 .55022 .69297 .54648 .68711 .54038 Mtetra
.669 .779 .932 r
.68711 .54038 .69297 .54648 .70546 .54278 .69962 .53622 Mtetra
.662 .763 .925 r
.69962 .53622 .70546 .54278 .71801 .53907 .7122 .53228 Mtetra
.658 .755 .922 r
.7122 .53228 .71801 .53907 .73061 .53534 .72484 .52846 Mtetra
.656 .752 .921 r
.72484 .52846 .73061 .53534 .74327 .53161 .73753 .52468 Mtetra
.656 .752 .92 r
.73753 .52468 .74327 .53161 .75599 .52786 .75029 .52089 Mtetra
.656 .751 .92 r
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Mtetra
.655 .751 .92 r
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .5905 Mtetra
.654 .751 .921 r
.48735 .5905 .49385 .5969 .50554 .59344 .49907 .58706 Mtetra
.649 .751 .924 r
.49907 .58706 .50554 .59344 .51728 .58998 .51084 .58375 Mtetra
.633 .752 .934 r
.51084 .58375 .51728 .58998 .52907 .58655 .52266 .58082 Mtetra
.6 .759 .955 r
.52266 .58082 .52907 .58655 .54091 .58325 .53454 .57855 Mtetra
.535 .775 .986 r
.53454 .57855 .54091 .58325 .55281 .58017 .54649 .57708 Mtetra
.416 .785 .994 r
.54649 .57708 .55281 .58017 .56476 .57734 .55851 .57618 Mtetra
.236 .74 .896 r
.55851 .57618 .56476 .57734 .57677 .57468 .5706 .57533 Mtetra
.081 .64 .707 r
.5706 .57533 .57677 .57468 .58885 .57203 .58275 .574 Mtetra
0 0 0 r
.58275 .574 .58885 .57203 .60097 .56919 .59496 .57188 Mtetra
.59496 .57188 .60097 .56919 .61315 .56602 .60722 .56897 Mtetra
.60722 .56897 .61315 .56602 .62537 .56241 .61951 .56534 Mtetra
.61951 .56534 .62537 .56241 .63763 .55836 .63183 .561 Mtetra
.63183 .561 .63763 .55836 .64993 .55396 .64418 .55584 Mtetra
.408 .85 .746 r
.64418 .55584 .64993 .55396 .66227 .54938 .65654 .54989 Mtetra
.582 .945 .88 r
.65654 .54989 .66227 .54938 .67466 .5448 .66892 .54343 Mtetra
.688 .951 .955 r
.66892 .54343 .67466 .5448 .68711 .54038 .68133 .53701 Mtetra
.71 .891 .963 r
.68133 .53701 .68711 .54038 .69962 .53622 .69381 .53117 Mtetra
.693 .826 .946 r
.69381 .53117 .69962 .53622 .7122 .53228 .70637 .52612 Mtetra
.674 .782 .931 r
.70637 .52612 .7122 .53228 .72484 .52846 .71902 .52174 Mtetra
.662 .761 .924 r
.71902 .52174 .72484 .52846 .73753 .52468 .73175 .51774 Mtetra
.657 .754 .921 r
.73175 .51774 .73753 .52468 .75029 .52089 .74454 .51388 Mtetra
.656 .752 .92 r
.74454 .51388 .75029 .52089 .7631 .5171 .75739 .51004 Mtetra
.656 .751 .92 r
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Mtetra
.655 .751 .92 r
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58755 Mtetra
.653 .751 .922 r
.46909 .58755 .47568 .59397 .48735 .5905 .48079 .58412 Mtetra
.643 .75 .927 r
.48079 .58412 .48735 .5905 .49907 .58706 .49254 .58095 Mtetra
.612 .75 .943 r
.49254 .58095 .49907 .58706 .51084 .58375 .50434 .5785 Mtetra
.529 .751 .978 r
.50434 .5785 .51084 .58375 .52266 .58082 .5162 .57738 Mtetra
.327 .727 .981 r
.5162 .57738 .52266 .58082 .53454 .57855 .52812 .57766 Mtetra
.015 .585 .772 r
.52812 .57766 .53454 .57855 .54649 .57708 .54013 .57838 Mtetra
.096 0 0 r
.54013 .57838 .54649 .57708 .55851 .57618 .55221 .57799 Mtetra
0 0 0 r
.55221 .57799 .55851 .57618 .5706 .57533 .56434 .57559 Mtetra
.43 .871 .882 r
.56434 .57559 .5706 .57533 .58275 .574 .57651 .57152 Mtetra
.647 .9 .983 r
.57651 .57152 .58275 .574 .59496 .57188 .58872 .56684 Mtetra
.674 .814 .95 r
.58872 .56684 .59496 .57188 .60722 .56897 .60098 .56245 Mtetra
.654 .759 .927 r
.60098 .56245 .60722 .56897 .61951 .56534 .61331 .5588 Mtetra
.626 .75 .936 r
.61331 .5588 .61951 .56534 .63183 .561 .62572 .55589 Mtetra
.596 .79 .973 r
.62572 .55589 .63183 .561 .64418 .55584 .6382 .55327 Mtetra
.553 .87 .994 r
.6382 .55327 .64418 .55584 .65654 .54989 .65072 .55002 Mtetra
.491 .903 .892 r
.65072 .55002 .65654 .54989 .66892 .54343 .66323 .54509 Mtetra
.509 .906 .787 r
.66323 .54509 .66892 .54343 .68133 .53701 .67569 .53812 Mtetra
.637 .964 .841 r
.67569 .53812 .68133 .53701 .69381 .53117 .68814 .52999 Mtetra
.734 .967 .935 r
.68814 .52999 .69381 .53117 .70637 .52612 .70063 .5223 Mtetra
.726 .881 .952 r
.70063 .5223 .70637 .52612 .71902 .52174 .71322 .51601 Mtetra
.689 .805 .937 r
.71322 .51601 .71902 .52174 .73175 .51774 .72594 .51108 Mtetra
.666 .767 .925 r
.72594 .51108 .73175 .51774 .74454 .51388 .73875 .50688 Mtetra
.658 .755 .921 r
.73875 .50688 .74454 .51388 .75739 .51004 .75164 .50294 Mtetra
.656 .752 .92 r
.75164 .50294 .75739 .51004 .77031 .5062 .76459 .49905 Mtetra
.656 .751 .92 r
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Mtetra
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Mtetra
.655 .751 .92 r
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58458 Mtetra
.653 .751 .921 r
.45077 .58458 .45744 .59103 .46909 .58755 .46245 .58114 Mtetra
.641 .749 .927 r
.46245 .58114 .46909 .58755 .48079 .58412 .47418 .578 Mtetra
.598 .746 .947 r
.47418 .578 .48079 .58412 .49254 .58095 .48595 .57585 Mtetra
.462 .731 .985 r
.48595 .57585 .49254 .58095 .50434 .5785 .49777 .57563 Mtetra
.122 .622 .905 r
.49777 .57563 .50434 .5785 .5162 .57738 .50966 .57726 Mtetra
.143 0 0 r
.50966 .57726 .5162 .57738 .52812 .57766 .52163 .5786 Mtetra
.101 .654 .7 r
.52163 .5786 .52812 .57766 .54013 .57838 .53368 .57686 Mtetra
.657 .93 .971 r
.53368 .57686 .54013 .57838 .55221 .57799 .54578 .5715 Mtetra
.748 .781 .88 r
.54578 .5715 .55221 .57799 .56434 .57559 .5579 .56445 Mtetra
.708 .668 .809 r
.5579 .56445 .56434 .57559 .57651 .57152 .57005 .55779 Mtetra
.674 .617 .784 r
.57005 .55779 .57651 .57152 .58872 .56684 .58226 .55232 Mtetra
.653 .598 .78 r
.58226 .55232 .58872 .56684 .60098 .56245 .59453 .54788 Mtetra
.639 .591 .784 r
.59453 .54788 .60098 .56245 .61331 .5588 .60687 .54419 Mtetra
.625 .583 .787 r
.60687 .54419 .61331 .5588 .62572 .55589 .61928 .54127 Mtetra
.604 .573 .792 r
.61928 .54127 .62572 .55589 .6382 .55327 .63179 .53938 Mtetra
.578 .569 .807 r
.63179 .53938 .6382 .55327 .65072 .55002 .64442 .53868 Mtetra
.56 .602 .852 r
.64442 .53868 .65072 .55002 .66323 .54509 .65713 .53839 Mtetra
.587 .735 .945 r
.65713 .53839 .66323 .54509 .67569 .53812 .66986 .53637 Mtetra
.656 .934 .969 r
.66986 .53637 .67569 .53812 .68814 .52999 .68248 .53069 Mtetra
.699 .984 .863 r
.68248 .53069 .68814 .52999 .70063 .5223 .69499 .52186 Mtetra
.764 .986 .9 r
.69499 .52186 .70063 .5223 .71322 .51601 .7075 .51271 Mtetra
.753 .907 .945 r
.7075 .51271 .71322 .51601 .72594 .51108 .72014 .50545 Mtetra
.699 .814 .936 r
.72014 .50545 .72594 .51108 .73875 .50688 .73294 .50014 Mtetra
.668 .768 .925 r
.73294 .50014 .73875 .50688 .75164 .50294 .74584 .49584 Mtetra
.658 .754 .921 r
.74584 .49584 .75164 .50294 .76459 .49905 .75883 .49185 Mtetra
.656 .752 .92 r
.75883 .49185 .76459 .49905 .7776 .49515 .77188 .48791 Mtetra
.656 .751 .92 r
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Mtetra
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Mtetra
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Mtetra
.654 .751 .921 r
.43238 .5816 .43913 .58807 .45077 .58458 .44404 .57811 Mtetra
.645 .75 .925 r
.44404 .57811 .45077 .58458 .46245 .58114 .45575 .57487 Mtetra
.604 .744 .943 r
.45575 .57487 .46245 .58114 .47418 .578 .4675 .5726 Mtetra
.457 .718 .98 r
.4675 .5726 .47418 .578 .48595 .57585 .47928 .57259 Mtetra
.051 .561 .878 r
.47928 .57259 .48595 .57585 .49777 .57563 .49111 .57513 Mtetra
.202 0 0 r
.49111 .57513 .49777 .57563 .50966 .57726 .50303 .57734 Mtetra
.262 .77 .84 r
.50303 .57734 .50966 .57726 .52163 .5786 .51506 .5751 Mtetra
.758 .879 .933 r
.51506 .5751 .52163 .5786 .53368 .57686 .52716 .56809 Mtetra
.752 .726 .828 r
.52716 .56809 .53368 .57686 .54578 .5715 .53927 .55982 Mtetra
.707 .659 .801 r
.53927 .55982 .54578 .5715 .5579 .56445 .55142 .55301 Mtetra
.679 .652 .817 r
.55142 .55301 .5579 .56445 .57005 .55779 .56362 .54785 Mtetra
.667 .676 .849 r
.56362 .54785 .57005 .55779 .58226 .55232 .57587 .54355 Mtetra
.661 .7 .876 r
.57587 .54355 .58226 .55232 .59453 .54788 .58818 .53962 Mtetra
.655 .712 .889 r
.58818 .53962 .59453 .54788 .60687 .54419 .60055 .53591 Mtetra
.649 .709 .892 r
.60055 .53591 .60687 .54419 .61928 .54127 .61298 .53241 Mtetra
.638 .691 .884 r
.61298 .53241 .61928 .54127 .63179 .53938 .62548 .52928 Mtetra
.613 .653 .866 r
.62548 .52928 .63179 .53938 .64442 .53868 .63807 .52702 Mtetra
.569 .602 .846 r
.63807 .52702 .64442 .53868 .65713 .53839 .65079 .52642 Mtetra
.526 .575 .847 r
.65079 .52642 .65713 .53839 .66986 .53637 .66365 .5273 Mtetra
.546 .649 .902 r
.66365 .5273 .66986 .53637 .68248 .53069 .67655 .5269 Mtetra
.684 .875 .97 r
.67655 .5269 .68248 .53069 .69499 .52186 .6893 .52164 Mtetra
.78 .991 .887 r
.6893 .52164 .69499 .52186 .7075 .51271 .70185 .51183 Mtetra
.808 .982 .894 r
.70185 .51183 .7075 .51271 .72014 .50545 .7144 .50168 Mtetra
.762 .895 .936 r
.7144 .50168 .72014 .50545 .73294 .50014 .72712 .49412 Mtetra
.696 .803 .932 r
.72712 .49412 .73294 .50014 .74584 .49584 .74001 .48888 Mtetra
.665 .763 .923 r
.74001 .48888 .74584 .49584 .75883 .49185 .75303 .48463 Mtetra
.657 .753 .921 r
.75303 .48463 .75883 .49185 .77188 .48791 .76612 .48062 Mtetra
.656 .752 .92 r
.76612 .48062 .77188 .48791 .785 .48397 .77927 .47663 Mtetra
.656 .751 .92 r
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Mtetra
.655 .751 .921 r
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57508 Mtetra
.651 .75 .923 r
.42557 .57508 .43238 .5816 .44404 .57811 .43726 .57167 Mtetra
.625 .746 .934 r
.43726 .57167 .44404 .57811 .45575 .57487 .44899 .56892 Mtetra
.514 .723 .968 r
.44899 .56892 .45575 .57487 .4675 .5726 .46074 .56826 Mtetra
.129 .579 .923 r
.46074 .56826 .4675 .5726 .47928 .57259 .47251 .571 Mtetra
.291 0 0 r
.47251 .571 .47928 .57259 .49111 .57513 .48436 .57499 Mtetra
.072 .634 .759 r
.48436 .57499 .49111 .57513 .50303 .57734 .49635 .57453 Mtetra
.762 .903 .939 r
.49635 .57453 .50303 .57734 .51506 .5751 .50846 .5673 Mtetra
.785 .754 .825 r
.50846 .5673 .51506 .5751 .52716 .56809 .52059 .55744 Mtetra
.737 .687 .803 r
.52059 .55744 .52716 .56809 .53927 .55982 .53273 .54915 Mtetra
.702 .675 .821 r
.53273 .54915 .53927 .55982 .55142 .55301 .54491 .54301 Mtetra
.681 .68 .843 r
.54491 .54301 .55142 .55301 .56362 .54785 .55714 .53809 Mtetra
.668 .681 .853 r
.55714 .53809 .56362 .54785 .57587 .54355 .56942 .53377 Mtetra
.659 .678 .857 r
.56942 .53377 .57587 .54355 .58818 .53962 .58175 .5298 Mtetra
.653 .675 .859 r
.58175 .5298 .58818 .53962 .60055 .53591 .59415 .52605 Mtetra
.647 .673 .861 r
.59415 .52605 .60055 .53591 .61298 .53241 .60661 .52254 Mtetra
.637 .669 .864 r
.60661 .52254 .61298 .53241 .62548 .52928 .61913 .51937 Mtetra
.62 .662 .869 r
.61913 .51937 .62548 .52928 .63807 .52702 .63174 .51682 Mtetra
.584 .64 .872 r
.63174 .51682 .63807 .52702 .65079 .52642 .64445 .51549 Mtetra
.517 .592 .868 r
.64445 .51549 .65079 .52642 .66365 .5273 .65733 .51632 Mtetra
.459 .561 .871 r
.65733 .51632 .66365 .5273 .67655 .5269 .67038 .51874 Mtetra
.527 .668 .926 r
.67038 .51874 .67655 .5269 .6893 .52164 .6834 .51849 Mtetra
.745 .913 .95 r
.6834 .51849 .6893 .52164 .70185 .51183 .69616 .51134 Mtetra
.841 .987 .863 r
.69616 .51134 .70185 .51183 .7144 .50168 .7087 .49964 Mtetra
.829 .954 .897 r
.7087 .49964 .7144 .50168 .72712 .49412 .72131 .4892 Mtetra
.745 .854 .93 r
.72131 .4892 .72712 .49412 .74001 .48888 .73415 .48224 Mtetra
.681 .781 .926 r
.73415 .48224 .74001 .48888 .75303 .48463 .74718 .47742 Mtetra
.66 .757 .921 r
.74718 .47742 .75303 .48463 .76612 .48062 .7603 .47327 Mtetra
.656 .752 .92 r
.7603 .47327 .76612 .48062 .77927 .47663 .7735 .46924 Mtetra
.656 .751 .92 r
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Mtetra
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Mtetra
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Mtetra
.654 .751 .921 r
.40702 .57206 .41392 .57861 .42557 .57508 .4187 .56853 Mtetra
.644 .749 .926 r
.4187 .56853 .42557 .57508 .43726 .57167 .43042 .56528 Mtetra
.587 .737 .947 r
.43042 .56528 .43726 .57167 .44899 .56892 .44217 .56337 Mtetra
.337 .657 .971 r
.44217 .56337 .44899 .56892 .46074 .56826 .4539 .56488 Mtetra
0 .305 .673 r
.4539 .56488 .46074 .56826 .47251 .571 .46565 .57022 Mtetra
.33 0 0 r
.46565 .57022 .47251 .571 .48436 .57499 .47755 .57393 Mtetra
.599 .924 .968 r
.47755 .57393 .48436 .57499 .49635 .57453 .48963 .56917 Mtetra
.832 .817 .836 r
.48963 .56917 .49635 .57453 .50846 .5673 .50181 .55761 Mtetra
.783 .718 .791 r
.50181 .55761 .50846 .5673 .52059 .55744 .51398 .54641 Mtetra
.724 .678 .805 r
.51398 .54641 .52059 .55744 .53273 .54915 .52616 .53881 Mtetra
.681 .674 .837 r
.52616 .53881 .53273 .54915 .54491 .54301 .53837 .53378 Mtetra
.661 .691 .867 r
.53837 .53378 .54491 .54301 .55714 .53809 .55063 .52977 Mtetra
.656 .712 .889 r
.55063 .52977 .55714 .53809 .56942 .53377 .56295 .526 Mtetra
.656 .727 .902 r
.56295 .526 .56942 .53377 .58175 .5298 .57532 .52224 Mtetra
.656 .734 .907 r
.57532 .52224 .58175 .5298 .59415 .52605 .58775 .51847 Mtetra
.655 .734 .908 r
.58775 .51847 .59415 .52605 .60661 .52254 .60024 .51468 Mtetra
.655 .727 .902 r
.60024 .51468 .60661 .52254 .61913 .51937 .61278 .5109 Mtetra
.647 .709 .892 r
.61278 .5109 .61913 .51937 .63174 .51682 .62539 .50736 Mtetra
.617 .673 .881 r
.62539 .50736 .63174 .51682 .64445 .51549 .63809 .50485 Mtetra
.538 .61 .873 r
.63809 .50485 .64445 .51549 .65733 .51632 .65096 .50495 Mtetra
.41 .527 .865 r
.65096 .50495 .65733 .51632 .67038 .51874 .66407 .50868 Mtetra
.364 .532 .888 r
.66407 .50868 .67038 .51874 .6834 .51849 .67732 .51276 Mtetra
.603 .783 .967 r
.67732 .51276 .6834 .51849 .69616 .51134 .69034 .50991 Mtetra
.847 .967 .878 r
.69034 .50991 .69616 .51134 .7087 .49964 .70297 .49842 Mtetra
.878 .967 .848 r
.70297 .49842 .7087 .49964 .72131 .4892 .71551 .48525 Mtetra
.804 .897 .909 r
.71551 .48525 .72131 .4892 .73415 .48224 .72827 .476 Mtetra
.708 .804 .925 r
.72827 .476 .73415 .48224 .74718 .47742 .74128 .47025 Mtetra
.666 .762 .922 r
.74128 .47025 .74718 .47742 .7603 .47327 .75444 .46587 Mtetra
.657 .753 .92 r
.75444 .46587 .7603 .47327 .7735 .46924 .76767 .46178 Mtetra
.656 .752 .92 r
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Mtetra
.656 .751 .92 r
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Mtetra
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Mtetra
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56546 Mtetra
.653 .751 .921 r
.40007 .56546 .40702 .57206 .4187 .56853 .41178 .56194 Mtetra
.633 .746 .929 r
.41178 .56194 .4187 .56853 .43042 .56528 .42353 .55893 Mtetra
.529 .718 .959 r
.42353 .55893 .43042 .56528 .44217 .56337 .43527 .55809 Mtetra
.07 .509 .898 r
.43527 .55809 .44217 .56337 .4539 .56488 .44698 .56204 Mtetra
.507 0 0 r
.44698 .56204 .4539 .56488 .46565 .57022 .45871 .56966 Mtetra
.214 0 0 r
.45871 .56966 .46565 .57022 .47755 .57393 .47067 .57202 Mtetra
.82 .928 .905 r
.47067 .57202 .47755 .57393 .48963 .56917 .48287 .56246 Mtetra
.852 .782 .783 r
.48287 .56246 .48963 .56917 .50181 .55761 .49512 .54732 Mtetra
.782 .708 .782 r
.49512 .54732 .50181 .55761 .51398 .54641 .50734 .53579 Mtetra
.71 .681 .82 r
.50734 .53579 .51398 .54641 .52616 .53881 .51954 .52918 Mtetra
.671 .686 .856 r
.51954 .52918 .52616 .53881 .53837 .53378 .53178 .52474 Mtetra
.661 .697 .873 r
.53178 .52474 .53837 .53378 .55063 .52977 .54407 .52075 Mtetra
.658 .697 .875 r
.54407 .52075 .55063 .52977 .56295 .526 .55642 .51684 Mtetra
.656 .694 .873 r
.55642 .51684 .56295 .526 .57532 .52224 .56882 .513 Mtetra
.654 .692 .873 r
.56882 .513 .57532 .52224 .58775 .51847 .58128 .50919 Mtetra
.653 .691 .873 r
.58128 .50919 .58775 .51847 .60024 .51468 .59379 .50543 Mtetra
.65 .692 .875 r
.59379 .50543 .60024 .51468 .61278 .5109 .60637 .50173 Mtetra
.648 .693 .879 r
.60637 .50173 .61278 .5109 .62539 .50736 .619 .49812 Mtetra
.635 .687 .882 r
.619 .49812 .62539 .50736 .63809 .50485 .63171 .49496 Mtetra
.568 .643 .885 r
.63171 .49496 .63809 .50485 .65096 .50495 .64457 .49397 Mtetra
.386 .524 .872 r
.64457 .49397 .65096 .50495 .66407 .50868 .6577 .49798 Mtetra
.193 .414 .848 r
.6577 .49798 .66407 .50868 .67732 .51276 .67112 .50565 Mtetra
.38 .631 .953 r
.67112 .50565 .67732 .51276 .69034 .50991 .68442 .50762 Mtetra
.822 .947 .904 r
.68442 .50762 .69034 .50991 .70297 .49842 .69719 .49743 Mtetra
.91 .958 .809 r
.69719 .49743 .70297 .49842 .71551 .48525 .70967 .48186 Mtetra
.855 .913 .871 r
.70967 .48186 .71551 .48525 .72827 .476 .72235 .47004 Mtetra
.74 .823 .916 r
.72235 .47004 .72827 .476 .74128 .47025 .73534 .46312 Mtetra
.675 .768 .921 r
.73534 .46312 .74128 .47025 .75444 .46587 .74852 .45843 Mtetra
.658 .754 .92 r
.74852 .45843 .75444 .46587 .76767 .46178 .7618 .45426 Mtetra
.656 .752 .92 r
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45016 Mtetra
.656 .751 .92 r
.77514 .45016 .78097 .45771 .79433 .45363 .78855 .44603 Mtetra
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Mtetra
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Mtetra
.655 .751 .92 r
.38137 .56241 .38841 .56904 .40007 .56546 .39307 .5588 Mtetra
.651 .75 .922 r
.39307 .5588 .40007 .56546 .41178 .56194 .40481 .5553 Mtetra
.622 .743 .933 r
.40481 .5553 .41178 .56194 .42353 .55893 .41657 .55255 Mtetra
.46 .689 .966 r
.41657 .55255 .42353 .55893 .43527 .55809 .42831 .55283 Mtetra
0 .304 .742 r
.42831 .55283 .43527 .55809 .44698 .56204 .43998 .55927 Mtetra
.635 .075 0 r
.43998 .55927 .44698 .56204 .45871 .56966 .45169 .56912 Mtetra
0 .536 .708 r
.45169 .56912 .45871 .56966 .47067 .57202 .46371 .57 Mtetra
.892 .898 .826 r
.46371 .57 .47067 .57202 .48287 .56246 .47604 .55561 Mtetra
.873 .776 .751 r
.47604 .55561 .48287 .56246 .49512 .54732 .4884 .53691 Mtetra
.786 .709 .778 r
.4884 .53691 .49512 .54732 .50734 .53579 .50065 .52488 Mtetra
.692 .67 .824 r
.50065 .52488 .50734 .53579 .51954 .52918 .51288 .51915 Mtetra
.645 .669 .859 r
.51288 .51915 .51954 .52918 .53178 .52474 .52514 .51568 Mtetra
.639 .689 .881 r
.52514 .51568 .53178 .52474 .54407 .52075 .53747 .51245 Mtetra
.644 .712 .896 r
.53747 .51245 .54407 .52075 .55642 .51684 .54985 .50902 Mtetra
.651 .727 .905 r
.54985 .50902 .55642 .51684 .56882 .513 .56229 .50536 Mtetra
.655 .735 .908 r
.56229 .50536 .56882 .513 .58128 .50919 .57478 .50153 Mtetra
.66 .737 .907 r
.57478 .50153 .58128 .50919 .59379 .50543 .58733 .49752 Mtetra
.667 .733 .9 r
.58733 .49752 .59379 .50543 .60637 .50173 .59993 .49328 Mtetra
.671 .721 .887 r
.59993 .49328 .60637 .50173 .619 .49812 .61257 .48882 Mtetra
.662 .698 .873 r
.61257 .48882 .619 .49812 .63171 .49496 .62528 .48463 Mtetra
.598 .649 .871 r
.62528 .48463 .63171 .49496 .64457 .49397 .63813 .48271 Mtetra
.369 .509 .867 r
.63813 .48271 .64457 .49397 .6577 .49798 .65129 .48718 Mtetra
0 .273 .777 r
.65129 .48718 .6577 .49798 .67112 .50565 .66486 .4984 Mtetra
.046 .42 .865 r
.66486 .4984 .67112 .50565 .68442 .50762 .67842 .50522 Mtetra
.782 .945 .93 r
.67842 .50522 .68442 .50762 .69719 .49743 .69134 .49646 Mtetra
.933 .944 .776 r
.69134 .49646 .69719 .49743 .70967 .48186 .70378 .47852 Mtetra
.891 .907 .83 r
.70378 .47852 .70967 .48186 .72235 .47004 .71638 .46408 Mtetra
.769 .831 .9 r
.71638 .46408 .72235 .47004 .73534 .46312 .72935 .45595 Mtetra
.684 .772 .918 r
.72935 .45595 .73534 .46312 .74852 .45843 .74256 .45093 Mtetra
.66 .754 .92 r
.74256 .45093 .74852 .45843 .7618 .45426 .75588 .44668 Mtetra
.656 .752 .92 r
.75588 .44668 .7618 .45426 .77514 .45016 .76926 .44253 Mtetra
.656 .751 .92 r
.76926 .44253 .77514 .45016 .78855 .44603 .78271 .43837 Mtetra
.78271 .43837 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56655 Mtetra
.33941 .56655 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Mtetra
.655 .751 .92 r
.37428 .55572 .38137 .56241 .39307 .5588 .386 .55209 Mtetra
.65 .75 .923 r
.386 .55209 .39307 .5588 .40481 .5553 .39777 .5486 Mtetra
.613 .74 .936 r
.39777 .5486 .40481 .5553 .41657 .55255 .40956 .54606 Mtetra
.392 .655 .963 r
.40956 .54606 .41657 .55255 .42831 .55283 .4213 .54731 Mtetra
0 .123 .582 r
.4213 .54731 .42831 .55283 .43998 .55927 .43291 .55609 Mtetra
.717 .184 0 r
.43291 .55609 .43998 .55927 .45169 .56912 .44458 .56847 Mtetra
.051 .615 .776 r
.44458 .56847 .45169 .56912 .46371 .57 .45667 .56861 Mtetra
.928 .885 .771 r
.45667 .56861 .46371 .57 .47604 .55561 .46915 .54969 Mtetra
.901 .786 .725 r
.46915 .54969 .47604 .55561 .4884 .53691 .48163 .52692 Mtetra
.8 .719 .776 r
.48163 .52692 .4884 .53691 .50065 .52488 .49393 .51396 Mtetra
.675 .664 .832 r
.49393 .51396 .50065 .52488 .51288 .51915 .50617 .50903 Mtetra
.626 .661 .864 r
.50617 .50903 .51288 .51915 .52514 .51568 .51846 .50622 Mtetra
.634 .68 .876 r
.51846 .50622 .52514 .51568 .53747 .51245 .53081 .5031 Mtetra
.645 .687 .875 r
.53081 .5031 .53747 .51245 .54985 .50902 .54322 .49958 Mtetra
.651 .688 .872 r
.54322 .49958 .54985 .50902 .56229 .50536 .55569 .49585 Mtetra
.654 .688 .87 r
.55569 .49585 .56229 .50536 .57478 .50153 .56821 .49199 Mtetra
.657 .69 .869 r
.56821 .49199 .57478 .50153 .58733 .49752 .58079 .48798 Mtetra
.662 .693 .868 r
.58079 .48798 .58733 .49752 .59993 .49328 .59342 .48378 Mtetra
.671 .698 .866 r
.59342 .48378 .59993 .49328 .61257 .48882 .60609 .47917 Mtetra
.678 .698 .861 r
.60609 .47917 .61257 .48882 .62528 .48463 .61881 .47424 Mtetra
.622 .66 .866 r
.61881 .47424 .62528 .48463 .63813 .48271 .63165 .47143 Mtetra
.324 .483 .863 r
.63165 .47143 .63813 .48271 .65129 .48718 .64486 .47678 Mtetra
0 .082 .637 r
.64486 .47678 .65129 .48718 .66486 .4984 .6586 .49208 Mtetra
0 .131 .627 r
.6586 .49208 .66486 .4984 .67842 .50522 .67238 .50345 Mtetra
.746 .959 .939 r
.67238 .50345 .67842 .50522 .69134 .49646 .68541 .49536 Mtetra
.951 .924 .744 r
.68541 .49536 .69134 .49646 .70378 .47852 .69781 .47477 Mtetra
.911 .887 .795 r
.69781 .47477 .70378 .47852 .71638 .46408 .71034 .45785 Mtetra
.789 .828 .882 r
.71034 .45785 .71638 .46408 .72935 .45595 .72331 .44866 Mtetra
.691 .772 .914 r
.72331 .44866 .72935 .45595 .74256 .45093 .73654 .44335 Mtetra
.661 .754 .919 r
.73654 .44335 .74256 .45093 .75588 .44668 .7499 .43903 Mtetra
.656 .752 .92 r
.7499 .43903 .75588 .44668 .76926 .44253 .76333 .43484 Mtetra
.656 .751 .92 r
.76333 .43484 .76926 .44253 .78271 .43837 .77683 .43065 Mtetra
.77683 .43065 .78271 .43837 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56655 .33216 .5599 Mtetra
.33216 .5599 .33941 .56655 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Mtetra
.655 .751 .92 r
.36713 .54898 .37428 .55572 .386 .55209 .37888 .54533 Mtetra
.649 .75 .923 r
.37888 .54533 .386 .55209 .39777 .5486 .39068 .54182 Mtetra
.606 .737 .938 r
.39068 .54182 .39777 .5486 .40956 .54606 .4025 .53942 Mtetra
.341 .626 .957 r
.4025 .53942 .40956 .54606 .4213 .54731 .41423 .54136 Mtetra
.522 0 0 r
.41423 .54136 .4213 .54731 .43291 .55609 .4258 .55206 Mtetra
.771 .264 0 r
.4258 .55206 .43291 .55609 .44458 .56847 .43741 .56716 Mtetra
.022 .587 .792 r
.43741 .56716 .44458 .56847 .45667 .56861 .44952 .5681 Mtetra
.946 .883 .739 r
.44952 .5681 .45667 .56861 .46915 .54969 .46215 .54596 Mtetra
.933 .808 .698 r
.46215 .54596 .46915 .54969 .48163 .52692 .47479 .51849 Mtetra
.839 .752 .768 r
.47479 .51849 .48163 .52692 .49393 .51396 .48717 .50286 Mtetra
.677 .663 .829 r
.48717 .50286 .49393 .51396 .50617 .50903 .49944 .49779 Mtetra
.597 .627 .852 r
.49944 .49779 .50617 .50903 .51846 .50622 .51174 .49599 Mtetra
.602 .65 .87 r
.51174 .49599 .51846 .50622 .53081 .5031 .52411 .49394 Mtetra
.625 .685 .887 r
.52411 .49394 .53081 .5031 .54322 .49958 .53655 .4911 Mtetra
.642 .71 .896 r
.53655 .4911 .54322 .49958 .55569 .49585 .54905 .48765 Mtetra
.655 .723 .898 r
.54905 .48765 .55569 .49585 .56821 .49199 .56161 .48375 Mtetra
.668 .727 .894 r
.56161 .48375 .56821 .49199 .58079 .48798 .57421 .4794 Mtetra
.683 .725 .881 r
.57421 .4794 .58079 .48798 .59342 .48378 .58686 .47444 Mtetra
.698 .713 .86 r
.58686 .47444 .59342 .48378 .60609 .47917 .59954 .46867 Mtetra
.697 .689 .839 r
.59954 .46867 .60609 .47917 .61881 .47424 .61227 .46267 Mtetra
.618 .636 .846 r
.61227 .46267 .61881 .47424 .63165 .47143 .62513 .45998 Mtetra
.189 .397 .836 r
.62513 .45998 .63165 .47143 .64486 .47678 .63844 .46797 Mtetra
.604 .159 0 r
.63844 .46797 .64486 .47678 .6586 .49208 .65236 .48798 Mtetra
.646 .112 0 r
.65236 .48798 .6586 .49208 .67238 .50345 .66631 .50255 Mtetra
.754 .979 .916 r
.66631 .50255 .67238 .50345 .68541 .49536 .67937 .49358 Mtetra
.96 .895 .718 r
.67937 .49358 .68541 .49536 .69781 .47477 .69172 .47012 Mtetra
.917 .86 .769 r
.69172 .47012 .69781 .47477 .71034 .45785 .70423 .45117 Mtetra
.799 .818 .866 r
.70423 .45117 .71034 .45785 .72331 .44866 .7172 .4412 Mtetra
.695 .771 .91 r
.7172 .4412 .72331 .44866 .73654 .44335 .73047 .43569 Mtetra
.662 .754 .919 r
.73047 .43569 .73654 .44335 .7499 .43903 .74388 .43131 Mtetra
.656 .752 .92 r
.74388 .43131 .7499 .43903 .76333 .43484 .75735 .42709 Mtetra
.656 .751 .92 r
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Mtetra
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .5599 .32486 .5532 Mtetra
.32486 .5532 .33216 .5599 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Mtetra
.655 .751 .92 r
.35992 .54219 .36713 .54898 .37888 .54533 .3717 .53851 Mtetra
.649 .75 .923 r
.3717 .53851 .37888 .54533 .39068 .54182 .38354 .53499 Mtetra
.602 .735 .938 r
.38354 .53499 .39068 .54182 .4025 .53942 .39538 .53265 Mtetra
.309 .607 .952 r
.39538 .53265 .4025 .53942 .41423 .54136 .40711 .53501 Mtetra
.575 .057 0 r
.40711 .53501 .41423 .54136 .4258 .55206 .41865 .54695 Mtetra
.799 .312 0 r
.41865 .54695 .4258 .55206 .43741 .56716 .43019 .56435 Mtetra
0 .481 .787 r
.43019 .56435 .43741 .56716 .44952 .5681 .44229 .56742 Mtetra
.946 .878 .736 r
.44229 .56742 .44952 .5681 .46215 .54596 .45503 .5448 Mtetra
.958 .832 .676 r
.45503 .5448 .46215 .54596 .47479 .51849 .46783 .51368 Mtetra
.901 .816 .754 r
.46783 .51368 .47479 .51849 .48717 .50286 .48034 .49396 Mtetra
.732 .727 .845 r
.48034 .49396 .48717 .50286 .49944 .49779 .49266 .48674 Mtetra
.609 .637 .854 r
.49266 .48674 .49944 .49779 .51174 .49599 .50498 .48448 Mtetra
.6 .625 .848 r
.50498 .48448 .51174 .49599 .52411 .49394 .51737 .48252 Mtetra
.62 .636 .845 r
.51737 .48252 .52411 .49394 .53655 .4911 .52983 .4798 Mtetra
.636 .647 .844 r
.52983 .4798 .53655 .4911 .54905 .48765 .54235 .47642 Mtetra
.649 .654 .841 r
.54235 .47642 .54905 .48765 .56161 .48375 .55493 .47249 Mtetra
.661 .659 .837 r
.55493 .47249 .56161 .48375 .57421 .4794 .56755 .46801 Mtetra
.675 .663 .831 r
.56755 .46801 .57421 .4794 .58686 .47444 .58023 .46286 Mtetra
.689 .667 .823 r
.58023 .46286 .58686 .47444 .59954 .46867 .59293 .45696 Mtetra
.682 .662 .824 r
.59293 .45696 .59954 .46867 .61227 .46267 .60569 .45136 Mtetra
.557 .613 .864 r
.60569 .45136 .61227 .46267 .62513 .45998 .61864 .45075 Mtetra
0 .179 .708 r
.61864 .45075 .62513 .45998 .63844 .46797 .63209 .46281 Mtetra
.808 .336 0 r
.63209 .46281 .63844 .46797 .65236 .48798 .64615 .48646 Mtetra
.727 .198 0 r
.64615 .48646 .65236 .48798 .66631 .50255 .66015 .50146 Mtetra
.827 .978 .885 r
.66015 .50146 .66631 .50255 .67937 .49358 .67319 .49024 Mtetra
.957 .858 .702 r
.67319 .49024 .67937 .49358 .69172 .47012 .68552 .46436 Mtetra
.914 .833 .752 r
.68552 .46436 .69172 .47012 .70423 .45117 .69804 .44407 Mtetra
.803 .808 .855 r
.69804 .44407 .70423 .45117 .7172 .4412 .71104 .43361 Mtetra
.698 .77 .907 r
.71104 .43361 .7172 .4412 .73047 .43569 .72435 .42796 Mtetra
.662 .754 .919 r
.72435 .42796 .73047 .43569 .74388 .43131 .7378 .42353 Mtetra
.656 .752 .92 r
.7378 .42353 .74388 .43131 .75735 .42709 .75131 .41926 Mtetra
.656 .751 .92 r
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Mtetra
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40208 Mtetra
.80604 .40208 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Mtetra
.655 .751 .921 r
.35265 .53534 .35992 .54219 .3717 .53851 .36447 .53163 Mtetra
.648 .749 .923 r
.36447 .53163 .3717 .53851 .38354 .53499 .37633 .52809 Mtetra
.599 .734 .939 r
.37633 .52809 .38354 .53499 .39538 .53265 .3882 .5258 Mtetra
.288 .594 .948 r
.3882 .5258 .39538 .53265 .40711 .53501 .39994 .52841 Mtetra
.599 .086 0 r
.39994 .52841 .40711 .53501 .41865 .54695 .41145 .54099 Mtetra
.807 .329 0 r
.41145 .54099 .41865 .54695 .43019 .56435 .42295 .55958 Mtetra
0 .404 .803 r
.42295 .55958 .43019 .56435 .44229 .56742 .43503 .56461 Mtetra
.921 .85 .756 r
.43503 .56461 .44229 .56742 .45503 .5448 .44781 .5441 Mtetra
.961 .839 .676 r
.44781 .5441 .45503 .5448 .46783 .51368 .46073 .51305 Mtetra
.95 .881 .731 r
.46073 .51305 .46783 .51368 .48034 .49396 .47337 .49016 Mtetra
.845 .872 .861 r
.47337 .49016 .48034 .49396 .49266 .48674 .4858 .47867 Mtetra
.684 .735 .889 r
.4858 .47867 .49266 .48674 .50498 .48448 .49817 .47378 Mtetra
.617 .65 .86 r
.49817 .47378 .50498 .48448 .51737 .48252 .51058 .47117 Mtetra
.613 .636 .85 r
.51058 .47117 .51737 .48252 .52983 .4798 .52306 .46869 Mtetra
.63 .649 .85 r
.52306 .46869 .52983 .4798 .54235 .47642 .53561 .46555 Mtetra
.65 .663 .849 r
.53561 .46555 .54235 .47642 .55493 .47249 .54821 .46158 Mtetra
.669 .671 .842 r
.54821 .46158 .55493 .47249 .56755 .46801 .56086 .45679 Mtetra
.682 .671 .833 r
.56086 .45679 .56755 .46801 .58023 .46286 .57355 .45134 Mtetra
.677 .664 .83 r
.57355 .45134 .58023 .46286 .59293 .45696 .5863 .446 Mtetra
.625 .653 .857 r
.5863 .446 .59293 .45696 .60569 .45136 .59914 .44299 Mtetra
.304 .554 .923 r
.59914 .44299 .60569 .45136 .61864 .45075 .61224 .44666 Mtetra
.684 .157 0 r
.61224 .44666 .61864 .45075 .63209 .46281 .62581 .46188 Mtetra
.84 .376 .077 r
.62581 .46188 .63209 .46281 .64615 .48646 .63988 .4854 Mtetra
.684 .137 0 r
.63988 .4854 .64615 .48646 .66015 .50146 .65383 .49817 Mtetra
.872 .914 .854 r
.65383 .49817 .66015 .50146 .67319 .49024 .66686 .48489 Mtetra
.943 .822 .695 r
.66686 .48489 .67319 .49024 .68552 .46436 .67922 .45772 Mtetra
.909 .815 .743 r
.67922 .45772 .68552 .46436 .69804 .44407 .69178 .43671 Mtetra
.806 .804 .849 r
.69178 .43671 .69804 .44407 .71104 .43361 .70482 .42592 Mtetra
.7 .77 .906 r
.70482 .42592 .71104 .43361 .72435 .42796 .71818 .42016 Mtetra
.662 .754 .918 r
.71818 .42016 .72435 .42796 .7378 .42353 .73166 .41567 Mtetra
.656 .752 .92 r
.73166 .41567 .7378 .42353 .75131 .41926 .74523 .41137 Mtetra
.656 .751 .92 r
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Mtetra
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40208 .80014 .39403 Mtetra
.80014 .39403 .80604 .40208 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53218 Mtetra
.33352 .53218 .34088 .53906 .35265 .53534 .34532 .52844 Mtetra
.655 .751 .921 r
.34532 .52844 .35265 .53534 .36447 .53163 .35717 .5247 Mtetra
.648 .749 .923 r
.35717 .5247 .36447 .53163 .37633 .52809 .36906 .52114 Mtetra
.595 .733 .94 r
.36906 .52114 .37633 .52809 .3882 .5258 .38096 .5189 Mtetra
.267 .583 .944 r
.38096 .5189 .3882 .5258 .39994 .52841 .39271 .52172 Mtetra
.616 .105 0 r
.39271 .52172 .39994 .52841 .41145 .54099 .40421 .53468 Mtetra
.806 .329 0 r
.40421 .53468 .41145 .54099 .42295 .55958 .41569 .55352 Mtetra
0 .421 .846 r
.41569 .55352 .42295 .55958 .43503 .56461 .42777 .5589 Mtetra
.885 .802 .762 r
.42777 .5589 .43503 .56461 .44781 .5441 .44059 .54009 Mtetra
.932 .806 .698 r
.44059 .54009 .44781 .5441 .46073 .51305 .45354 .51213 Mtetra
.94 .889 .753 r
.45354 .51213 .46073 .51305 .47337 .49016 .46625 .49134 Mtetra
.85 .992 .842 r
.46625 .49134 .47337 .49016 .4858 .47867 .47877 .47883 Mtetra
.738 .982 .91 r
.47877 .47883 .4858 .47867 .49817 .47378 .49125 .47035 Mtetra
.73 .892 .953 r
.49125 .47035 .49817 .47378 .51058 .47117 .50373 .46384 Mtetra
.693 .761 .904 r
.50373 .46384 .51058 .47117 .52306 .46869 .51625 .45865 Mtetra
.663 .686 .861 r
.51625 .45865 .52306 .46869 .53561 .46555 .52882 .45426 Mtetra
.649 .656 .843 r
.52882 .45426 .53561 .46555 .54821 .46158 .54145 .45026 Mtetra
.639 .651 .846 r
.54145 .45026 .54821 .46158 .56086 .45679 .55413 .44666 Mtetra
.619 .668 .875 r
.55413 .44666 .56086 .45679 .57355 .45134 .56689 .44387 Mtetra
.555 .713 .945 r
.56689 .44387 .57355 .45134 .5863 .446 .57974 .44244 Mtetra
.272 .706 .965 r
.57974 .44244 .5863 .446 .59914 .44299 .59272 .44298 Mtetra
.393 0 0 r
.59272 .44298 .59914 .44299 .61224 .44666 .60589 .4476 Mtetra
.723 .203 0 r
.60589 .4476 .61224 .44666 .62581 .46188 .61944 .46062 Mtetra
.811 .325 .014 r
.61944 .46062 .62581 .46188 .63988 .4854 .63342 .48093 Mtetra
.482 0 0 r
.63342 .48093 .63988 .4854 .65383 .49817 .64733 .49192 Mtetra
.853 .834 .827 r
.64733 .49192 .65383 .49817 .66686 .48489 .66041 .4782 Mtetra
.933 .803 .694 r
.66041 .4782 .66686 .48489 .67922 .45772 .67285 .45071 Mtetra
.907 .809 .739 r
.67285 .45071 .67922 .45772 .69178 .43671 .68546 .42925 Mtetra
.809 .803 .846 r
.68546 .42925 .69178 .43671 .70482 .42592 .69855 .41817 Mtetra
.702 .771 .905 r
.69855 .41817 .70482 .42592 .71818 .42016 .71195 .41229 Mtetra
.663 .755 .918 r
.71195 .41229 .71818 .42016 .73166 .41567 .72548 .40775 Mtetra
.656 .752 .92 r
.72548 .40775 .73166 .41567 .74523 .41137 .73909 .40341 Mtetra
.656 .751 .92 r
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Mtetra
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38592 Mtetra
.79418 .38592 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53218 .32609 .52525 Mtetra
.32609 .52525 .33352 .53218 .34532 .52844 .33793 .52148 Mtetra
.655 .751 .921 r
.33793 .52148 .34532 .52844 .35717 .5247 .34981 .5177 Mtetra
.647 .749 .924 r
.34981 .5177 .35717 .5247 .36906 .52114 .36174 .51414 Mtetra
.592 .732 .941 r
.36174 .51414 .36906 .52114 .38096 .5189 .37366 .51195 Mtetra
.245 .57 .94 r
.37366 .51195 .38096 .5189 .39271 .52172 .38542 .51501 Mtetra
.633 .123 0 r
.38542 .51501 .39271 .52172 .40421 .53468 .3969 .5283 Mtetra
.804 .328 0 r
.3969 .5283 .40421 .53468 .41569 .55352 .40837 .5471 Mtetra
.052 .471 .885 r
.40837 .5471 .41569 .55352 .42777 .5589 .42049 .55186 Mtetra
.873 .779 .754 r
.42049 .55186 .42777 .5589 .44059 .54009 .43337 .53285 Mtetra
.902 .766 .701 r
.43337 .53285 .44059 .54009 .45354 .51213 .44639 .50616 Mtetra
.881 .802 .767 r
.44639 .50616 .45354 .51213 .46625 .49134 .45912 .48809 Mtetra
.806 .898 .908 r
.45912 .48809 .46625 .49134 .47877 .47883 .47166 .47889 Mtetra
.585 .94 .922 r
.47166 .47889 .47877 .47883 .49125 .47035 .48417 .47305 Mtetra
.307 .782 .685 r
.48417 .47305 .49125 .47035 .50373 .46384 .49673 .46772 Mtetra
0 0 0 r
.49673 .46772 .50373 .46384 .51625 .45865 .50933 .46253 Mtetra
.50933 .46253 .51625 .45865 .52882 .45426 .52198 .45781 Mtetra
.52198 .45781 .52882 .45426 .54145 .45026 .53469 .45379 Mtetra
.53469 .45379 .54145 .45026 .55413 .44666 .54746 .45049 Mtetra
.055 0 0 r
.54746 .45049 .55413 .44666 .56689 .44387 .5603 .44764 Mtetra
.065 0 0 r
.5603 .44764 .56689 .44387 .57974 .44244 .57321 .44493 Mtetra
.013 0 0 r
.57321 .44493 .57974 .44244 .59272 .44298 .5862 .44276 Mtetra
.103 0 0 r
.5862 .44276 .59272 .44298 .60589 .4476 .59935 .44401 Mtetra
.515 0 0 r
.59935 .44401 .60589 .4476 .61944 .46062 .61285 .45423 Mtetra
.693 .202 0 r
.61285 .45423 .61944 .46062 .63342 .48093 .62679 .47318 Mtetra
0 .189 .699 r
.62679 .47318 .63342 .48093 .64733 .49192 .64072 .4843 Mtetra
.833 .801 .821 r
.64072 .4843 .64733 .49192 .66041 .4782 .65388 .47114 Mtetra
.93 .798 .694 r
.65388 .47114 .66041 .4782 .67285 .45071 .66642 .44363 Mtetra
.909 .808 .736 r
.66642 .44363 .67285 .45071 .68546 .42925 .67909 .42175 Mtetra
.813 .805 .843 r
.67909 .42175 .68546 .42925 .69855 .41817 .69222 .41036 Mtetra
.704 .772 .904 r
.69222 .41036 .69855 .41817 .71195 .41229 .70566 .40435 Mtetra
.663 .755 .918 r
.70566 .40435 .71195 .41229 .72548 .40775 .71924 .39976 Mtetra
.656 .752 .92 r
.71924 .39976 .72548 .40775 .73909 .40341 .73289 .39538 Mtetra
.656 .751 .92 r
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Mtetra
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38592 .78817 .37773 Mtetra
.78817 .37773 .79418 .38592 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Mtetra
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Mtetra
.655 .751 .921 r
.33048 .51446 .33793 .52148 .34981 .5177 .34239 .51066 Mtetra
.647 .749 .924 r
.34239 .51066 .34981 .5177 .36174 .51414 .35435 .50707 Mtetra
.588 .73 .942 r
.35435 .50707 .36174 .51414 .37366 .51195 .3663 .50496 Mtetra
.219 .556 .934 r
.3663 .50496 .37366 .51195 .38542 .51501 .37807 .50827 Mtetra
.651 .142 0 r
.37807 .50827 .38542 .51501 .3969 .5283 .38952 .52191 Mtetra
.803 .325 0 r
.38952 .52191 .3969 .5283 .40837 .5471 .40098 .54062 Mtetra
.13 .522 .915 r
.40098 .54062 .40837 .5471 .42049 .55186 .41314 .54458 Mtetra
.875 .775 .748 r
.41314 .54458 .42049 .55186 .43337 .53285 .42612 .52489 Mtetra
.896 .758 .701 r
.42612 .52489 .43337 .53285 .44639 .50616 .43922 .49824 Mtetra
.86 .767 .759 r
.43922 .49824 .44639 .50616 .45912 .48809 .45201 .48048 Mtetra
.774 .772 .851 r
.45201 .48048 .45912 .48809 .47166 .47889 .46459 .47142 Mtetra
.708 .764 .896 r
.46459 .47142 .47166 .47889 .48417 .47305 .47714 .46561 Mtetra
.693 .761 .904 r
.47714 .46561 .48417 .47305 .49673 .46772 .48974 .46033 Mtetra
.688 .762 .908 r
.48974 .46033 .49673 .46772 .50933 .46253 .50238 .45522 Mtetra
.675 .762 .916 r
.50238 .45522 .50933 .46253 .52198 .45781 .51507 .45054 Mtetra
.654 .758 .926 r
.51507 .45054 .52198 .45781 .53469 .45379 .52781 .44649 Mtetra
.632 .75 .933 r
.52781 .44649 .53469 .45379 .54746 .45049 .54062 .44307 Mtetra
.615 .741 .936 r
.54062 .44307 .54746 .45049 .5603 .44764 .5535 .44009 Mtetra
.608 .736 .936 r
.5535 .44009 .5603 .44764 .57321 .44493 .56645 .4373 Mtetra
.587 .727 .94 r
.56645 .4373 .57321 .44493 .5862 .44276 .57948 .43503 Mtetra
.431 .652 .952 r
.57948 .43503 .5862 .44276 .59935 .44401 .59265 .43602 Mtetra
0 .25 .75 r
.59265 .43602 .59935 .44401 .61285 .45423 .60615 .44583 Mtetra
.604 .142 0 r
.60615 .44583 .61285 .45423 .62679 .47318 .62009 .46467 Mtetra
0 .178 .698 r
.62009 .46467 .62679 .47318 .64072 .4843 .63404 .47642 Mtetra
.821 .796 .828 r
.63404 .47642 .64072 .4843 .65388 .47114 .6473 .46402 Mtetra
.929 .798 .695 r
.6473 .46402 .65388 .47114 .66642 .44363 .65993 .43653 Mtetra
.911 .809 .733 r
.65993 .43653 .66642 .44363 .67909 .42175 .67266 .41421 Mtetra
.817 .806 .84 r
.67266 .41421 .67909 .42175 .69222 .41036 .68584 .40249 Mtetra
.707 .773 .904 r
.68584 .40249 .69222 .41036 .70566 .40435 .69932 .39634 Mtetra
.664 .755 .918 r
.69932 .39634 .70566 .40435 .71924 .39976 .71294 .3917 Mtetra
.657 .752 .92 r
.71294 .3917 .71924 .39976 .73289 .39538 .72664 .38727 Mtetra
.656 .751 .92 r
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Mtetra
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51505 Mtetra
.29922 .51505 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Mtetra
.655 .751 .921 r
.32296 .50738 .33048 .51446 .34239 .51066 .33491 .50355 Mtetra
.646 .749 .924 r
.33491 .50355 .34239 .51066 .35435 .50707 .3469 .49996 Mtetra
.583 .729 .943 r
.3469 .49996 .35435 .50707 .3663 .50496 .35887 .49791 Mtetra
.191 .54 .927 r
.35887 .49791 .3663 .50496 .37807 .50827 .37064 .5015 Mtetra
.668 .16 0 r
.37064 .5015 .37807 .50827 .38952 .52191 .38208 .51552 Mtetra
.801 .321 0 r
.38208 .51552 .38952 .52191 .40098 .54062 .39353 .53407 Mtetra
.224 .58 .943 r
.39353 .53407 .40098 .54062 .41314 .54458 .40575 .53702 Mtetra
.878 .77 .739 r
.40575 .53702 .41314 .54458 .42612 .52489 .41883 .5161 Mtetra
.894 .747 .693 r
.41883 .5161 .42612 .52489 .43922 .49824 .43205 .48812 Mtetra
.852 .733 .732 r
.43205 .48812 .43922 .49824 .45201 .48048 .44494 .4682 Mtetra
.77 .686 .771 r
.44494 .4682 .45201 .48048 .46459 .47142 .45761 .45634 Mtetra
.703 .626 .768 r
.45761 .45634 .46459 .47142 .47714 .46561 .47022 .44827 Mtetra
.665 .585 .756 r
.47022 .44827 .47714 .46561 .48974 .46033 .48283 .44203 Mtetra
.643 .565 .752 r
.48283 .44203 .48974 .46033 .50238 .45522 .49546 .43697 Mtetra
.632 .56 .755 r
.49546 .43697 .50238 .45522 .51507 .45054 .50815 .43257 Mtetra
.628 .561 .759 r
.50815 .43257 .51507 .45054 .52781 .44649 .52089 .42848 Mtetra
.623 .558 .761 r
.52089 .42848 .52781 .44649 .54062 .44307 .5337 .42468 Mtetra
.611 .548 .76 r
.5337 .42468 .54062 .44307 .5535 .44009 .54657 .42153 Mtetra
.589 .535 .762 r
.54657 .42153 .5535 .44009 .56645 .4373 .55952 .41956 Mtetra
.551 .522 .776 r
.55952 .41956 .56645 .4373 .57948 .43503 .57258 .41948 Mtetra
.437 .484 .81 r
.57258 .41948 .57948 .43503 .59265 .43602 .5858 .42327 Mtetra
0 .25 .758 r
.5858 .42327 .59265 .43602 .60615 .44583 .59934 .43521 Mtetra
0 0 .441 r
.59934 .43521 .60615 .44583 .62009 .46467 .6133 .45533 Mtetra
0 .144 .677 r
.6133 .45533 .62009 .46467 .63404 .47642 .6273 .46826 Mtetra
.805 .789 .837 r
.6273 .46826 .63404 .47642 .6473 .46402 .64065 .45681 Mtetra
.929 .799 .696 r
.64065 .45681 .6473 .46402 .65993 .43653 .65338 .42941 Mtetra
.913 .809 .73 r
.65338 .42941 .65993 .43653 .67266 .41421 .66618 .40665 Mtetra
.822 .807 .837 r
.66618 .40665 .67266 .41421 .68584 .40249 .6794 .39457 Mtetra
.71 .774 .903 r
.6794 .39457 .68584 .40249 .69932 .39634 .69292 .38827 Mtetra
.665 .755 .918 r
.69292 .38827 .69932 .39634 .71294 .3917 .70659 .38356 Mtetra
.657 .752 .92 r
.70659 .38356 .71294 .3917 .72664 .38727 .72033 .3791 Mtetra
.656 .751 .92 r
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Mtetra
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51505 .29158 .50797 Mtetra
.29158 .50797 .29922 .51505 .31107 .51122 .30346 .50412 Mtetra
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50025 Mtetra
.655 .751 .921 r
.31539 .50025 .32296 .50738 .33491 .50355 .32737 .49638 Mtetra
.645 .748 .924 r
.32737 .49638 .33491 .50355 .3469 .49996 .33939 .49278 Mtetra
.577 .727 .945 r
.33939 .49278 .3469 .49996 .35887 .49791 .35138 .49083 Mtetra
.161 .522 .918 r
.35138 .49083 .35887 .49791 .37064 .5015 .36316 .49471 Mtetra
.681 .175 0 r
.36316 .49471 .37064 .5015 .38208 .51552 .37457 .50903 Mtetra
.788 .304 0 r
.37457 .50903 .38208 .51552 .39353 .53407 .38602 .52702 Mtetra
.418 .669 .965 r
.38602 .52702 .39353 .53407 .40575 .53702 .39835 .52775 Mtetra
.877 .744 .712 r
.39835 .52775 .40575 .53702 .41883 .5161 .41161 .50354 Mtetra
.874 .708 .673 r
.41161 .50354 .41883 .5161 .43205 .48812 .42499 .47264 Mtetra
.813 .668 .703 r
.42499 .47264 .43205 .48812 .44494 .4682 .43795 .45179 Mtetra
.718 .62 .747 r
.43795 .45179 .44494 .4682 .45761 .45634 .4506 .44185 Mtetra
.643 .606 .797 r
.4506 .44185 .45761 .45634 .47022 .44827 .46315 .43757 Mtetra
.61 .655 .869 r
.46315 .43757 .47022 .44827 .48283 .44203 .47573 .43499 Mtetra
.6 .748 .947 r
.47573 .43499 .48283 .44203 .49546 .43697 .48838 .43232 Mtetra
.599 .827 .987 r
.48838 .43232 .49546 .43697 .50815 .43257 .50111 .42896 Mtetra
.616 .869 .99 r
.50111 .42896 .50815 .43257 .52089 .42848 .51391 .42482 Mtetra
.654 .879 .981 r
.51391 .42482 .52089 .42848 .5337 .42468 .52677 .41991 Mtetra
.694 .853 .959 r
.52677 .41991 .5337 .42468 .54657 .42153 .53967 .41433 Mtetra
.7 .78 .914 r
.53967 .41433 .54657 .42153 .55952 .41956 .55263 .40867 Mtetra
.646 .672 .861 r
.55263 .40867 .55952 .41956 .57258 .41948 .56566 .40468 Mtetra
.494 .528 .821 r
.56566 .40468 .57258 .41948 .5858 .42327 .57885 .40637 Mtetra
.119 .266 .741 r
.57885 .40637 .5858 .42327 .59934 .43521 .59238 .41914 Mtetra
0 0 .526 r
.59238 .41914 .59934 .43521 .6133 .45533 .60637 .44213 Mtetra
0 .105 .66 r
.60637 .44213 .6133 .45533 .6273 .46826 .62045 .45833 Mtetra
.756 .741 .838 r
.62045 .45833 .6273 .46826 .64065 .45681 .63393 .44908 Mtetra
.923 .793 .7 r
.63393 .44908 .64065 .45681 .65338 .42941 .64676 .42219 Mtetra
.915 .808 .727 r
.64676 .42219 .65338 .42941 .66618 .40665 .65963 .39904 Mtetra
.827 .809 .833 r
.65963 .39904 .66618 .40665 .6794 .39457 .6729 .38659 Mtetra
.713 .775 .901 r
.6729 .38659 .6794 .39457 .69292 .38827 .68647 .38013 Mtetra
.665 .756 .918 r
.68647 .38013 .69292 .38827 .70659 .38356 .70018 .37536 Mtetra
.657 .752 .92 r
.70018 .37536 .70659 .38356 .72033 .3791 .71397 .37085 Mtetra
.656 .751 .92 r
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Mtetra
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Mtetra
.29579 .49695 .30346 .50412 .31539 .50025 .30775 .49305 Mtetra
.655 .751 .921 r
.30775 .49305 .31539 .50025 .32737 .49638 .31976 .48916 Mtetra
.644 .748 .925 r
.31976 .48916 .32737 .49638 .33939 .49278 .33182 .48555 Mtetra
.572 .725 .946 r
.33182 .48555 .33939 .49278 .35138 .49083 .34383 .48368 Mtetra
.137 .507 .911 r
.34383 .48368 .35138 .49083 .36316 .49471 .35561 .48779 Mtetra
.673 .167 0 r
.35561 .48779 .36316 .49471 .37457 .50903 .36702 .50199 Mtetra
.728 .233 0 r
.36702 .50199 .37457 .50903 .38602 .52702 .37854 .51813 Mtetra
.628 .705 .902 r
.37854 .51813 .38602 .52702 .39835 .52775 .39104 .51492 Mtetra
.86 .704 .687 r
.39104 .51492 .39835 .52775 .41161 .50354 .40447 .48763 Mtetra
.849 .678 .67 r
.40447 .48763 .41161 .50354 .42499 .47264 .41788 .4578 Mtetra
.789 .666 .727 r
.41788 .4578 .42499 .47264 .43795 .45179 .43076 .44145 Mtetra
.686 .693 .851 r
.43076 .44145 .43795 .45179 .4506 .44185 .44333 .43596 Mtetra
.56 .77 .977 r
.44333 .43596 .4506 .44185 .46315 .43757 .45588 .43382 Mtetra
.512 .825 1 r
.45588 .43382 .46315 .43757 .47573 .43499 .46851 .43147 Mtetra
.552 .849 .998 r
.46851 .43147 .47573 .43499 .48838 .43232 .48122 .42838 Mtetra
.597 .853 .992 r
.48122 .42838 .48838 .43232 .50111 .42896 .494 .42471 Mtetra
.628 .853 .985 r
.494 .42471 .50111 .42896 .51391 .42482 .50685 .42056 Mtetra
.65 .86 .979 r
.50685 .42056 .51391 .42482 .52677 .41991 .51976 .41591 Mtetra
.673 .876 .975 r
.51976 .41591 .52677 .41991 .53967 .41433 .53273 .41063 Mtetra
.7 .892 .967 r
.53273 .41063 .53967 .41433 .55263 .40867 .54574 .40456 Mtetra
.708 .882 .962 r
.54574 .40456 .55263 .40867 .56566 .40468 .5588 .39836 Mtetra
.589 .775 .968 r
.5588 .39836 .56566 .40468 .57885 .40637 .57196 .39557 Mtetra
.102 .373 .835 r
.57196 .39557 .57885 .40637 .59238 .41914 .5854 .40372 Mtetra
0 0 .537 r
.5854 .40372 .59238 .41914 .60637 .44213 .59932 .42553 Mtetra
0 .072 .631 r
.59932 .42553 .60637 .44213 .62045 .45833 .61345 .44477 Mtetra
.662 .641 .819 r
.61345 .44477 .62045 .45833 .63393 .44908 .62708 .43945 Mtetra
.899 .768 .709 r
.62708 .43945 .63393 .44908 .64676 .42219 .64007 .41439 Mtetra
.909 .799 .727 r
.64007 .41439 .64676 .42219 .65963 .39904 .65303 .3913 Mtetra
.829 .807 .83 r
.65303 .3913 .65963 .39904 .6729 .38659 .66634 .37854 Mtetra
.716 .776 .9 r
.66634 .37854 .6729 .38659 .68647 .38013 .67996 .37191 Mtetra
.666 .756 .918 r
.67996 .37191 .68647 .38013 .70018 .37536 .69371 .36708 Mtetra
.657 .752 .92 r
.69371 .36708 .70018 .37536 .71397 .37085 .70755 .36253 Mtetra
.656 .751 .92 r
.70755 .36253 .71397 .37085 .72783 .36635 .72146 .35798 Mtetra
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34883 Mtetra
.74947 .34883 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .5053 Mtetra
.24061 .5053 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Mtetra
.28805 .48973 .29579 .49695 .30775 .49305 .30004 .48579 Mtetra
.655 .751 .921 r
.30004 .48579 .30775 .49305 .31976 .48916 .31209 .48187 Mtetra
.643 .748 .925 r
.31209 .48187 .31976 .48916 .33182 .48555 .32418 .47825 Mtetra
.569 .724 .947 r
.32418 .47825 .33182 .48555 .34383 .48368 .33621 .47642 Mtetra
.146 .511 .913 r
.33621 .47642 .34383 .48368 .35561 .48779 .34801 .48046 Mtetra
.608 .102 0 r
.34801 .48046 .35561 .48779 .36702 .50199 .35946 .49359 Mtetra
.528 .045 0 r
.35946 .49359 .36702 .50199 .37854 .51813 .37111 .50658 Mtetra
.701 .677 .824 r
.37111 .50658 .37854 .51813 .39104 .51492 .38377 .49997 Mtetra
.843 .684 .684 r
.38377 .49997 .39104 .51492 .40447 .48763 .39725 .47333 Mtetra
.842 .688 .691 r
.39725 .47333 .40447 .48763 .41788 .4578 .41056 .44825 Mtetra
.795 .739 .8 r
.41056 .44825 .41788 .4578 .43076 .44145 .42336 .43631 Mtetra
.629 .819 .974 r
.42336 .43631 .43076 .44145 .44333 .43596 .43593 .43253 Mtetra
.474 .82 .998 r
.43593 .43253 .44333 .43596 .45588 .43382 .44852 .43049 Mtetra
.507 .838 .998 r
.44852 .43049 .45588 .43382 .46851 .43147 .4612 .42793 Mtetra
.561 .853 .997 r
.4612 .42793 .46851 .43147 .48122 .42838 .47397 .42466 Mtetra
.596 .86 .993 r
.47397 .42466 .48122 .42838 .494 .42471 .48681 .42087 Mtetra
.619 .865 .989 r
.48681 .42087 .494 .42471 .50685 .42056 .49971 .41668 Mtetra
.637 .87 .985 r
.49971 .41668 .50685 .42056 .51976 .41591 .51268 .4121 Mtetra
.657 .879 .98 r
.51268 .4121 .51976 .41591 .53273 .41063 .5257 .40704 Mtetra
.684 .894 .973 r
.5257 .40704 .53273 .41063 .54574 .40456 .53878 .40127 Mtetra
.705 .909 .967 r
.53878 .40127 .54574 .40456 .5588 .39836 .55191 .39484 Mtetra
.63 .884 .987 r
.55191 .39484 .5588 .39836 .57196 .39557 .5651 .39011 Mtetra
.117 .55 .918 r
.5651 .39011 .57196 .39557 .5854 .40372 .57849 .39366 Mtetra
0 0 .524 r
.57849 .39366 .5854 .40372 .59932 .42553 .59228 .41055 Mtetra
0 .057 .622 r
.59228 .41055 .59932 .42553 .61345 .44477 .60636 .42902 Mtetra
.585 .573 .806 r
.60636 .42902 .61345 .44477 .62708 .43945 .62011 .42709 Mtetra
.858 .729 .719 r
.62011 .42709 .62708 .43945 .64007 .41439 .63327 .40517 Mtetra
.89 .778 .731 r
.63327 .40517 .64007 .41439 .65303 .3913 .64634 .38311 Mtetra
.825 .798 .826 r
.64634 .38311 .65303 .3913 .66634 .37854 .65973 .37036 Mtetra
.717 .775 .898 r
.65973 .37036 .66634 .37854 .67996 .37191 .67338 .36362 Mtetra
.667 .756 .917 r
.67338 .36362 .67996 .37191 .69371 .36708 .68719 .35872 Mtetra
.657 .752 .92 r
.68719 .35872 .69371 .36708 .70755 .36253 .70107 .35413 Mtetra
.656 .751 .92 r
.70107 .35413 .70755 .36253 .72146 .35798 .71502 .34954 Mtetra
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34883 .74314 .34031 Mtetra
.74314 .34031 .74947 .34883 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .5053 .23268 .49815 Mtetra
.23268 .49815 .24061 .5053 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Mtetra
.28025 .48244 .28805 .48973 .30004 .48579 .29228 .47848 Mtetra
.655 .751 .921 r
.29228 .47848 .30004 .48579 .31209 .48187 .30436 .47452 Mtetra
.644 .748 .925 r
.30436 .47452 .31209 .48187 .32418 .47825 .31647 .47087 Mtetra
.573 .725 .945 r
.31647 .47087 .32418 .47825 .33621 .47642 .32854 .46893 Mtetra
.211 .545 .929 r
.32854 .46893 .33621 .47642 .34801 .48046 .34039 .47235 Mtetra
0 .045 .557 r
.34039 .47235 .34801 .48046 .35946 .49359 .35194 .48346 Mtetra
0 .207 .729 r
.35194 .48346 .35946 .49359 .37111 .50658 .36372 .49326 Mtetra
.705 .653 .795 r
.36372 .49326 .37111 .50658 .38377 .49997 .37644 .48573 Mtetra
.833 .687 .701 r
.37644 .48573 .38377 .49997 .39725 .47333 .38983 .46278 Mtetra
.85 .73 .731 r
.38983 .46278 .39725 .47333 .41056 .44825 .40303 .44258 Mtetra
.799 .831 .876 r
.40303 .44258 .41056 .44825 .42336 .43631 .41582 .43288 Mtetra
.606 .87 .992 r
.41582 .43288 .42336 .43631 .43593 .43253 .42845 .42886 Mtetra
.56 .848 .997 r
.42845 .42886 .43593 .43253 .44852 .43049 .44112 .42569 Mtetra
.611 .829 .984 r
.44112 .42569 .44852 .43049 .4612 .42793 .45387 .42207 Mtetra
.636 .803 .963 r
.45387 .42207 .4612 .42793 .47397 .42466 .46669 .41816 Mtetra
.645 .786 .949 r
.46669 .41816 .47397 .42466 .48681 .42087 .47957 .4141 Mtetra
.65 .781 .943 r
.47957 .4141 .48681 .42087 .49971 .41668 .49252 .40991 Mtetra
.655 .784 .942 r
.49252 .40991 .49971 .41668 .51268 .4121 .50553 .40556 Mtetra
.662 .794 .945 r
.50553 .40556 .51268 .4121 .5257 .40704 .5186 .40097 Mtetra
.672 .813 .95 r
.5186 .40097 .5257 .40704 .53878 .40127 .53173 .39601 Mtetra
.679 .842 .961 r
.53173 .39601 .53878 .40127 .55191 .39484 .54492 .39074 Mtetra
.623 .864 .988 r
.54492 .39074 .55191 .39484 .5651 .39011 .55818 .38635 Mtetra
.193 .658 .939 r
.55818 .38635 .5651 .39011 .57849 .39366 .57158 .38762 Mtetra
0 .063 .541 r
.57158 .38762 .57849 .39366 .59228 .41055 .58529 .39944 Mtetra
0 .105 .654 r
.58529 .39944 .59228 .41055 .60636 .42902 .59926 .41401 Mtetra
.565 .574 .821 r
.59926 .41401 .60636 .42902 .62011 .42709 .61304 .41289 Mtetra
.821 .699 .73 r
.61304 .41289 .62011 .42709 .63327 .40517 .62636 .39414 Mtetra
.861 .749 .739 r
.62636 .39414 .63327 .40517 .64634 .38311 .63957 .37411 Mtetra
.809 .779 .825 r
.63957 .37411 .64634 .38311 .65973 .37036 .65304 .36192 Mtetra
.714 .77 .896 r
.65304 .36192 .65973 .37036 .67338 .36362 .66675 .35523 Mtetra
.667 .756 .917 r
.66675 .35523 .67338 .36362 .68719 .35872 .6806 .35029 Mtetra
.657 .752 .92 r
.6806 .35029 .68719 .35872 .70107 .35413 .69453 .34565 Mtetra
.656 .751 .92 r
.69453 .34565 .70107 .35413 .71502 .34954 .70853 .34102 Mtetra
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Mtetra
.27238 .4751 .28025 .48244 .29228 .47848 .28444 .4711 Mtetra
.655 .751 .921 r
.28444 .4711 .29228 .47848 .30436 .47452 .29656 .4671 Mtetra
.645 .748 .924 r
.29656 .4671 .30436 .47452 .31647 .47087 .30871 .46337 Mtetra
.586 .728 .941 r
.30871 .46337 .31647 .47087 .32854 .46893 .32083 .46112 Mtetra
.32 .598 .946 r
.32083 .46112 .32854 .46893 .34039 .47235 .33275 .46338 Mtetra
0 .244 .749 r
.33275 .46338 .34039 .47235 .35194 .48346 .34443 .47195 Mtetra
.088 .355 .824 r
.34443 .47195 .35194 .48346 .36372 .49326 .35631 .47949 Mtetra
.678 .636 .801 r
.35631 .47949 .36372 .49326 .37644 .48573 .36899 .47339 Mtetra
.823 .704 .734 r
.36899 .47339 .37644 .48573 .38983 .46278 .38224 .45506 Mtetra
.857 .778 .773 r
.38224 .45506 .38983 .46278 .40303 .44258 .39538 .43819 Mtetra
.801 .87 .899 r
.39538 .43819 .40303 .44258 .41582 .43288 .40821 .4288 Mtetra
.661 .866 .977 r
.40821 .4288 .41582 .43288 .42845 .42886 .42093 .4239 Mtetra
.615 .826 .981 r
.42093 .4239 .42845 .42886 .44112 .42569 .43366 .42022 Mtetra
.619 .811 .974 r
.43366 .42022 .44112 .42569 .45387 .42207 .44645 .41659 Mtetra
.626 .814 .973 r
.44645 .41659 .45387 .42207 .46669 .41816 .45931 .41278 Mtetra
.633 .821 .973 r
.45931 .41278 .46669 .41816 .47957 .4141 .47224 .40876 Mtetra
.638 .825 .972 r
.47224 .40876 .47957 .4141 .49252 .40991 .48524 .40457 Mtetra
.643 .827 .971 r
.48524 .40457 .49252 .40991 .50553 .40556 .4983 .40024 Mtetra
.647 .83 .971 r
.4983 .40024 .50553 .40556 .5186 .40097 .51143 .39579 Mtetra
.654 .838 .971 r
.51143 .39579 .5186 .40097 .53173 .39601 .52461 .3911 Mtetra
.662 .85 .972 r
.52461 .3911 .53173 .39601 .54492 .39074 .53786 .38612 Mtetra
.609 .844 .988 r
.53786 .38612 .54492 .39074 .55818 .38635 .55117 .38218 Mtetra
.27 .696 .967 r
.55117 .38218 .55818 .38635 .57158 .38762 .56461 .38287 Mtetra
0 .214 .642 r
.56461 .38287 .57158 .38762 .58529 .39944 .57829 .3912 Mtetra
0 .258 .755 r
.57829 .3912 .58529 .39944 .59926 .41401 .59217 .40093 Mtetra
.604 .625 .846 r
.59217 .40093 .59926 .41401 .61304 .41289 .60592 .39818 Mtetra
.8 .687 .74 r
.60592 .39818 .61304 .41289 .62636 .39414 .61935 .38166 Mtetra
.829 .724 .749 r
.61935 .38166 .62636 .39414 .63957 .37411 .63272 .36418 Mtetra
.785 .756 .827 r
.63272 .36418 .63957 .37411 .65304 .36192 .64628 .35315 Mtetra
.706 .76 .895 r
.64628 .35315 .65304 .36192 .66675 .35523 .66006 .34671 Mtetra
.665 .754 .916 r
.66006 .34671 .66675 .35523 .6806 .35029 .67396 .34177 Mtetra
.657 .752 .92 r
.67396 .34177 .6806 .35029 .69453 .34565 .68793 .3371 Mtetra
.656 .751 .92 r
.68793 .3371 .69453 .34565 .70853 .34102 .70198 .33243 Mtetra
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.26445 .46769 .27238 .4751 .28444 .4711 .27654 .46365 Mtetra
.655 .751 .921 r
.27654 .46365 .28444 .4711 .29656 .4671 .28869 .45962 Mtetra
.648 .749 .923 r
.28869 .45962 .29656 .4671 .30871 .46337 .30088 .45577 Mtetra
.606 .734 .935 r
.30088 .45577 .30871 .46337 .32083 .46112 .31306 .45302 Mtetra
.434 .649 .949 r
.31306 .45302 .32083 .46112 .33275 .46338 .32509 .45374 Mtetra
.105 .417 .865 r
.32509 .45374 .33275 .46338 .34443 .47195 .33691 .45966 Mtetra
.211 .415 .844 r
.33691 .45966 .34443 .47195 .35631 .47949 .34886 .46585 Mtetra
.625 .615 .821 r
.34886 .46585 .35631 .47949 .36899 .47339 .36142 .46241 Mtetra
.801 .719 .774 r
.36142 .46241 .36899 .47339 .38224 .45506 .37451 .4486 Mtetra
.851 .807 .806 r
.37451 .4486 .38224 .45506 .39538 .43819 .38763 .43405 Mtetra
.803 .878 .902 r
.38763 .43405 .39538 .43819 .40821 .4288 .40053 .42458 Mtetra
.696 .87 .964 r
.40053 .42458 .40821 .4288 .42093 .4239 .41332 .41883 Mtetra
.655 .835 .969 r
.41332 .41883 .42093 .4239 .43366 .42022 .42613 .41426 Mtetra
.653 .807 .957 r
.42613 .41426 .43366 .42022 .44645 .41659 .43899 .40989 Mtetra
.653 .786 .945 r
.43899 .40989 .44645 .41659 .45931 .41278 .4519 .40558 Mtetra
.652 .772 .936 r
.4519 .40558 .45931 .41278 .47224 .40876 .46488 .40132 Mtetra
.652 .766 .932 r
.46488 .40132 .47224 .40876 .48524 .40457 .47792 .39704 Mtetra
.654 .765 .931 r
.47792 .39704 .48524 .40457 .4983 .40024 .49102 .3927 Mtetra
.656 .766 .93 r
.49102 .3927 .4983 .40024 .51143 .39579 .50419 .38826 Mtetra
.651 .766 .933 r
.50419 .38826 .51143 .39579 .52461 .3911 .51742 .38397 Mtetra
.624 .77 .95 r
.51742 .38397 .52461 .3911 .53786 .38612 .53071 .38036 Mtetra
.55 .786 .987 r
.53071 .38036 .53786 .38612 .55117 .38218 .54409 .37796 Mtetra
.252 .684 .962 r
.54409 .37796 .55117 .38218 .56461 .38287 .55758 .37884 Mtetra
0 .365 .742 r
.55758 .37884 .56461 .38287 .57829 .3912 .57125 .38449 Mtetra
.094 .5 .902 r
.57125 .38449 .57829 .3912 .59217 .40093 .58506 .38923 Mtetra
.676 .684 .85 r
.58506 .38923 .59217 .40093 .60592 .39818 .59877 .38351 Mtetra
.789 .685 .749 r
.59877 .38351 .60592 .39818 .61935 .38166 .61228 .3683 Mtetra
.797 .704 .762 r
.61228 .3683 .61935 .38166 .63272 .36418 .62579 .35354 Mtetra
.754 .735 .835 r
.62579 .35354 .63272 .36418 .64628 .35315 .63946 .34406 Mtetra
.693 .75 .895 r
.63946 .34406 .64628 .35315 .66006 .34671 .6533 .33807 Mtetra
.663 .751 .916 r
.6533 .33807 .66006 .34671 .67396 .34177 .66725 .33317 Mtetra
.657 .751 .92 r
.66725 .33317 .67396 .34177 .68793 .3371 .68128 .32846 Mtetra
.656 .751 .92 r
.68128 .32846 .68793 .3371 .70198 .33243 .69537 .32375 Mtetra
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Mtetra
.655 .751 .92 r
.26857 .45614 .27654 .46365 .28869 .45962 .28076 .45206 Mtetra
.651 .75 .922 r
.28076 .45206 .28869 .45962 .30088 .45577 .29299 .44809 Mtetra
.626 .74 .929 r
.29299 .44809 .30088 .45577 .31306 .45302 .30523 .44479 Mtetra
.527 .688 .941 r
.30523 .44479 .31306 .45302 .32509 .45374 .31738 .44385 Mtetra
.317 .539 .909 r
.31738 .44385 .32509 .45374 .33691 .45966 .32937 .44709 Mtetra
.283 .454 .853 r
.32937 .44709 .33691 .45966 .34886 .46585 .34136 .45217 Mtetra
.543 .577 .838 r
.34136 .45217 .34886 .46585 .36142 .46241 .35378 .45169 Mtetra
.75 .713 .817 r
.35378 .45169 .36142 .46241 .37451 .4486 .3667 .4424 Mtetra
.833 .818 .835 r
.3667 .4424 .37451 .4486 .38763 .43405 .3798 .42989 Mtetra
.811 .878 .895 r
.3798 .42989 .38763 .43405 .40053 .42458 .39278 .41992 Mtetra
.73 .863 .944 r
.39278 .41992 .40053 .42458 .41332 .41883 .40566 .41322 Mtetra
.67 .824 .957 r
.40566 .41322 .41332 .41883 .42613 .41426 .41852 .40832 Mtetra
.646 .808 .961 r
.41852 .40832 .42613 .41426 .43899 .40989 .43142 .40408 Mtetra
.637 .811 .966 r
.43142 .40408 .43899 .40989 .4519 .40558 .44438 .39999 Mtetra
.634 .818 .971 r
.44438 .39999 .4519 .40558 .46488 .40132 .4574 .3959 Mtetra
.63 .823 .975 r
.4574 .3959 .46488 .40132 .47792 .39704 .47049 .39182 Mtetra
.625 .829 .979 r
.47049 .39182 .47792 .39704 .49102 .3927 .48364 .38778 Mtetra
.618 .838 .984 r
.48364 .38778 .49102 .3927 .50419 .38826 .49685 .38375 Mtetra
.623 .854 .986 r
.49685 .38375 .50419 .38826 .51742 .38397 .51014 .37945 Mtetra
.628 .856 .986 r
.51014 .37945 .51742 .38397 .53071 .38036 .52349 .37502 Mtetra
.529 .794 .994 r
.52349 .37502 .53071 .38036 .54409 .37796 .53692 .37275 Mtetra
.248 .652 .963 r
.53692 .37275 .54409 .37796 .55758 .37884 .55046 .37435 Mtetra
.022 .521 .872 r
.55046 .37435 .55758 .37884 .57125 .38449 .56414 .37799 Mtetra
.444 .719 .983 r
.56414 .37799 .57125 .38449 .58506 .38923 .5779 .37765 Mtetra
.74 .712 .825 r
.5779 .37765 .58506 .38923 .59877 .38351 .59158 .36859 Mtetra
.776 .678 .755 r
.59158 .36859 .59877 .38351 .61228 .3683 .60516 .35454 Mtetra
.763 .688 .779 r
.60516 .35454 .61228 .3683 .62579 .35354 .6188 .34261 Mtetra
.722 .72 .848 r
.6188 .34261 .62579 .35354 .63946 .34406 .63257 .33483 Mtetra
.678 .743 .9 r
.63257 .33483 .63946 .34406 .6533 .33807 .64648 .32933 Mtetra
.66 .75 .917 r
.64648 .32933 .6533 .33807 .66725 .33317 .66048 .32449 Mtetra
.656 .751 .92 r
.66048 .32449 .66725 .33317 .68128 .32846 .67456 .31975 Mtetra
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Mtetra
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Mtetra
.26054 .44857 .26857 .45614 .28076 .45206 .27275 .44445 Mtetra
.654 .751 .921 r
.27275 .44445 .28076 .45206 .29299 .44809 .28502 .44036 Mtetra
.642 .745 .924 r
.28502 .44036 .29299 .44809 .30523 .44479 .29733 .4366 Mtetra
.592 .717 .93 r
.29733 .4366 .30523 .44479 .31738 .44385 .3096 .43417 Mtetra
.468 .625 .92 r
.3096 .43417 .31738 .44385 .32937 .44709 .32176 .43472 Mtetra
.367 .508 .868 r
.32176 .43472 .32937 .44709 .34136 .45217 .33385 .43814 Mtetra
.463 .53 .841 r
.33385 .43814 .34136 .45217 .35378 .45169 .34614 .43997 Mtetra
.656 .664 .846 r
.34614 .43997 .35378 .45169 .3667 .4424 .35886 .43536 Mtetra
.787 .799 .863 r
.35886 .43536 .3667 .4424 .3798 .42989 .37188 .42566 Mtetra
.807 .878 .898 r
.37188 .42566 .3798 .42989 .39278 .41992 .38492 .41587 Mtetra
.753 .885 .939 r
.38492 .41587 .39278 .41992 .40566 .41322 .39789 .40829 Mtetra
.702 .853 .955 r
.39789 .40829 .40566 .41322 .41852 .40832 .41084 .40239 Mtetra
.675 .818 .952 r
.41084 .40239 .41852 .40832 .43142 .40408 .42381 .39733 Mtetra
.662 .791 .943 r
.42381 .39733 .43142 .40408 .44438 .39999 .43682 .39269 Mtetra
.655 .773 .936 r
.43682 .39269 .44438 .39999 .4574 .3959 .44989 .38827 Mtetra
.652 .764 .932 r
.44989 .38827 .4574 .3959 .47049 .39182 .46303 .38394 Mtetra
.648 .757 .929 r
.46303 .38394 .47049 .39182 .48364 .38778 .47622 .3797 Mtetra
.633 .747 .931 r
.47622 .3797 .48364 .38778 .49685 .38375 .48948 .37591 Mtetra
.58 .735 .949 r
.48948 .37591 .49685 .38375 .51014 .37945 .50279 .37342 Mtetra
.48 .75 .989 r
.50279 .37342 .51014 .37945 .52349 .37502 .51619 .37227 Mtetra
.313 .764 .957 r
.51619 .37227 .52349 .37502 .53692 .37275 .52968 .37128 Mtetra
.119 .66 .843 r
.52968 .37128 .53692 .37275 .55046 .37435 .54327 .3713 Mtetra
.323 .764 .965 r
.54327 .3713 .55046 .37435 .56414 .37799 .55696 .37039 Mtetra
.699 .79 .921 r
.55696 .37039 .56414 .37799 .5779 .37765 .57067 .36431 Mtetra
.759 .692 .788 r
.57067 .36431 .5779 .37765 .59158 .36859 .58434 .35296 Mtetra
.749 .659 .762 r
.58434 .35296 .59158 .36859 .60516 .35454 .59801 .34096 Mtetra
.724 .676 .803 r
.59801 .34096 .60516 .35454 .6188 .34261 .61176 .33192 Mtetra
.692 .715 .867 r
.61176 .33192 .6188 .34261 .63257 .33483 .62563 .32563 Mtetra
.666 .741 .906 r
.62563 .32563 .63257 .33483 .64648 .32933 .6396 .32054 Mtetra
.657 .75 .918 r
.6396 .32054 .64648 .32933 .66048 .32449 .65365 .31574 Mtetra
.656 .751 .92 r
.65365 .31574 .66048 .32449 .67456 .31975 .66778 .31096 Mtetra
.66778 .31096 .67456 .31975 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Mtetra
.25243 .44094 .26054 .44857 .27275 .44445 .26468 .43677 Mtetra
.655 .751 .92 r
.26468 .43677 .27275 .44445 .28502 .44036 .27699 .43261 Mtetra
.651 .749 .921 r
.27699 .43261 .28502 .44036 .29733 .4366 .28934 .42855 Mtetra
.631 .736 .923 r
.28934 .42855 .29733 .4366 .3096 .43417 .30172 .42505 Mtetra
.571 .686 .919 r
.30172 .42505 .3096 .43417 .32176 .43472 .31405 .4232 Mtetra
.476 .587 .885 r
.31405 .4232 .32176 .43472 .33385 .43814 .32629 .42403 Mtetra
.444 .519 .841 r
.32629 .42403 .33385 .43814 .34614 .43997 .33855 .42627 Mtetra
.534 .575 .842 r
.33855 .42627 .34614 .43997 .35886 .43536 .35106 .42595 Mtetra
.684 .724 .88 r
.35106 .42595 .35886 .43536 .37188 .42566 .36391 .4205 Mtetra
.778 .854 .907 r
.36391 .4205 .37188 .42566 .38492 .41587 .37696 .41187 Mtetra
.771 .889 .929 r
.37696 .41187 .38492 .41587 .39789 .40829 .39002 .4036 Mtetra
.718 .865 .951 r
.39002 .4036 .39789 .40829 .41084 .40239 .40305 .39714 Mtetra
.671 .84 .964 r
.40305 .39714 .41084 .40239 .42381 .39733 .41607 .39203 Mtetra
.645 .833 .973 r
.41607 .39203 .42381 .39733 .43682 .39269 .42913 .38755 Mtetra
.628 .834 .979 r
.42913 .38755 .43682 .39269 .44989 .38827 .44225 .38337 Mtetra
.616 .839 .985 r
.44225 .38337 .44989 .38827 .46303 .38394 .45542 .37935 Mtetra
.611 .848 .989 r
.45542 .37935 .46303 .38394 .47622 .3797 .46867 .37529 Mtetra
.63 .861 .986 r
.46867 .37529 .47622 .3797 .48948 .37591 .48199 .37074 Mtetra
.601 .829 .986 r
.48199 .37074 .48948 .37591 .50279 .37342 .49537 .36701 Mtetra
.333 .665 .974 r
.49537 .36701 .50279 .37342 .51619 .37227 .50879 .36819 Mtetra
.162 .635 .929 r
.50879 .36819 .51619 .37227 .52968 .37128 .52233 .36983 Mtetra
.443 .863 .947 r
.52233 .36983 .52968 .37128 .54327 .3713 .53598 .36624 Mtetra
.752 .876 .936 r
.53598 .36624 .54327 .3713 .55696 .37039 .54966 .3583 Mtetra
.756 .711 .809 r
.54966 .3583 .55696 .37039 .57067 .36431 .56336 .34788 Mtetra
.726 .641 .763 r
.56336 .34788 .57067 .36431 .58434 .35296 .57707 .33724 Mtetra
.706 .64 .781 r
.57707 .33724 .58434 .35296 .59801 .34096 .59083 .32847 Mtetra
.688 .68 .837 r
.59083 .32847 .59801 .34096 .61176 .33192 .60469 .3219 Mtetra
.67 .724 .89 r
.60469 .3219 .61176 .33192 .62563 .32563 .61863 .31659 Mtetra
.659 .745 .913 r
.61863 .31659 .62563 .32563 .6396 .32054 .63266 .31171 Mtetra
.656 .75 .919 r
.63266 .31171 .6396 .32054 .65365 .31574 .64676 .3069 Mtetra
.656 .751 .92 r
.64676 .3069 .65365 .31574 .66778 .31096 .66093 .30209 Mtetra
.66093 .30209 .66778 .31096 .68197 .30616 .67517 .29724 Mtetra
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Mtetra
.25654 .42903 .26468 .43677 .27699 .43261 .26888 .42482 Mtetra
.655 .751 .92 r
.26888 .42482 .27699 .43261 .28934 .42855 .28128 .42061 Mtetra
.649 .746 .92 r
.28128 .42061 .28934 .42855 .30172 .42505 .29372 .41656 Mtetra
.628 .726 .918 r
.29372 .41656 .30172 .42505 .31405 .4232 .30619 .41312 Mtetra
.577 .668 .9 r
.30619 .41312 .31405 .4232 .32629 .42403 .31862 .41117 Mtetra
.515 .581 .859 r
.31862 .41117 .32629 .42403 .33855 .42627 .33101 .41124 Mtetra
.493 .533 .826 r
.33101 .41124 .33855 .42627 .35106 .42595 .34344 .41228 Mtetra
.543 .582 .844 r
.34344 .41228 .35106 .42595 .36391 .4205 .35605 .41163 Mtetra
.647 .728 .908 r
.35605 .41163 .36391 .4205 .37696 .41187 .36893 .4075 Mtetra
.731 .877 .948 r
.36893 .4075 .37696 .41187 .39002 .4036 .38199 .40058 Mtetra
.74 .918 .953 r
.38199 .40058 .39002 .4036 .40305 .39714 .39512 .39311 Mtetra
.717 .887 .959 r
.39512 .39311 .40305 .39714 .41607 .39203 .40826 .38648 Mtetra
.68 .836 .958 r
.40826 .38648 .41607 .39203 .42913 .38755 .42139 .38112 Mtetra
.652 .803 .955 r
.42139 .38112 .42913 .38755 .44225 .38337 .43457 .37658 Mtetra
.612 .78 .961 r
.43457 .37658 .44225 .38337 .45542 .37935 .44778 .37309 Mtetra
.501 .754 .986 r
.44778 .37309 .45542 .37935 .46867 .37529 .46102 .37163 Mtetra
0 .456 .791 r
.46102 .37163 .46867 .37529 .48199 .37074 .47427 .37553 Mtetra
.552 .027 0 r
.47427 .37553 .48199 .37074 .49537 .36701 .48763 .38154 Mtetra
0 0 0 r
.48763 .38154 .49537 .36701 .50879 .36819 .50128 .36833 Mtetra
.808 .993 .87 r
.50128 .36833 .50879 .36819 .52233 .36983 .51493 .35657 Mtetra
.727 .681 .805 r
.51493 .35657 .52233 .36983 .53598 .36624 .52859 .3475 Mtetra
.687 .599 .752 r
.52859 .3475 .53598 .36624 .54966 .3583 .54228 .33885 Mtetra
.674 .586 .749 r
.54228 .33885 .54966 .3583 .56336 .34788 .55601 .33085 Mtetra
.673 .61 .776 r
.55601 .33085 .56336 .34788 .57707 .33724 .56979 .32375 Mtetra
.67 .656 .828 r
.56979 .32375 .57707 .33724 .59083 .32847 .58364 .31781 Mtetra
.666 .709 .88 r
.58364 .31781 .59083 .32847 .60469 .3219 .59757 .31256 Mtetra
.659 .738 .909 r
.59757 .31256 .60469 .3219 .61863 .31659 .61158 .30767 Mtetra
.657 .749 .918 r
.61158 .30767 .61863 .31659 .63266 .31171 .62565 .30282 Mtetra
.656 .751 .92 r
.62565 .30282 .63266 .31171 .64676 .3069 .6398 .298 Mtetra
.656 .752 .92 r
.6398 .298 .64676 .3069 .66093 .30209 .65402 .29312 Mtetra
.656 .751 .92 r
.65402 .29312 .66093 .30209 .67517 .29724 .66831 .28825 Mtetra
.656 .752 .92 r
.66831 .28825 .67517 .29724 .68949 .29238 .68268 .28333 Mtetra
.656 .751 .92 r
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .2784 Mtetra
.656 .752 .92 r
.69712 .2784 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.656 .751 .92 r
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26845 Mtetra
.72622 .26845 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46271 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Mtetra
.24832 .42123 .25654 .42903 .26888 .42482 .2607 .41697 Mtetra
.2607 .41697 .26888 .42482 .28128 .42061 .27314 .4127 Mtetra
.655 .75 .92 r
.27314 .4127 .28128 .42061 .29372 .41656 .28563 .40843 Mtetra
.649 .744 .919 r
.28563 .40843 .29372 .41656 .30619 .41312 .29817 .40431 Mtetra
.634 .722 .911 r
.29817 .40431 .30619 .41312 .31862 .41117 .31074 .40063 Mtetra
.601 .67 .888 r
.31074 .40063 .31862 .41117 .33101 .41124 .32332 .39796 Mtetra
.561 .598 .848 r
.32332 .39796 .33101 .41124 .34344 .41228 .33588 .39665 Mtetra
.536 .549 .815 r
.33588 .39665 .34344 .41228 .35605 .41163 .34848 .39632 Mtetra
.543 .558 .82 r
.34848 .39632 .35605 .41163 .36893 .4075 .36118 .39572 Mtetra
.581 .638 .873 r
.36118 .39572 .36893 .4075 .38199 .40058 .37405 .39366 Mtetra
.631 .781 .953 r
.37405 .39366 .38199 .40058 .39512 .39311 .38707 .38976 Mtetra
.631 .89 .987 r
.38707 .38976 .39512 .39311 .40826 .38648 .4002 .38483 Mtetra
.579 .915 .971 r
.4002 .38483 .40826 .38648 .42139 .38112 .4134 .37982 Mtetra
.497 .889 .956 r
.4134 .37982 .42139 .38112 .43457 .37658 .42663 .37567 Mtetra
.384 .837 .92 r
.42663 .37567 .43457 .37658 .44778 .37309 .43989 .37253 Mtetra
.29 .785 .875 r
.43989 .37253 .44778 .37309 .46102 .37163 .45322 .37009 Mtetra
.648 .943 .96 r
.45322 .37009 .46102 .37163 .47427 .37553 .46671 .36362 Mtetra
.831 .73 .753 r
.46671 .36362 .47427 .37553 .48763 .38154 .4804 .34612 Mtetra
.627 .477 .659 r
.4804 .34612 .48763 .38154 .50128 .36833 .49397 .33744 Mtetra
.593 .47 .682 r
.49397 .33744 .50128 .36833 .51493 .35657 .50754 .33303 Mtetra
.61 .519 .726 r
.50754 .33303 .51493 .35657 .52859 .3475 .52118 .32853 Mtetra
.63 .567 .765 r
.52118 .32853 .52859 .3475 .54228 .33885 .53489 .32358 Mtetra
.646 .619 .808 r
.53489 .32358 .54228 .33885 .55601 .33085 .54867 .31844 Mtetra
.655 .669 .852 r
.54867 .31844 .55601 .33085 .56979 .32375 .56251 .3134 Mtetra
.659 .714 .889 r
.56251 .3134 .56979 .32375 .58364 .31781 .57642 .30844 Mtetra
.657 .738 .909 r
.57642 .30844 .58364 .31781 .59757 .31256 .5904 .30359 Mtetra
.657 .749 .918 r
.5904 .30359 .59757 .31256 .61158 .30767 .60446 .29873 Mtetra
.656 .75 .92 r
.60446 .29873 .61158 .30767 .62565 .30282 .61858 .29388 Mtetra
.656 .752 .92 r
.61858 .29388 .62565 .30282 .6398 .298 .63278 .28899 Mtetra
.656 .751 .92 r
.63278 .28899 .6398 .298 .65402 .29312 .64705 .28409 Mtetra
.656 .752 .92 r
.64705 .28409 .65402 .29312 .66831 .28825 .66139 .27915 Mtetra
.656 .751 .92 r
.66139 .27915 .66831 .28825 .68268 .28333 .6758 .2742 Mtetra
.656 .752 .92 r
.6758 .2742 .68268 .28333 .69712 .2784 .69029 .26921 Mtetra
.656 .751 .92 r
.69029 .26921 .69712 .2784 .71163 .27343 .70486 .26421 Mtetra
.656 .752 .92 r
.70486 .26421 .71163 .27343 .72622 .26845 .7195 .25917 Mtetra
.656 .751 .92 r
.7195 .25917 .72622 .26845 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46271 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Mtetra
.25245 .40906 .2607 .41697 .27314 .4127 .26492 .40474 Mtetra
.26492 .40474 .27314 .4127 .28563 .40843 .27745 .40041 Mtetra
.655 .75 .92 r
.27745 .40041 .28563 .40843 .29817 .40431 .29004 .39608 Mtetra
.652 .745 .918 r
.29004 .39608 .29817 .40431 .31074 .40063 .30268 .39181 Mtetra
.644 .728 .91 r
.30268 .39181 .31074 .40063 .32332 .39796 .31537 .38777 Mtetra
.628 .69 .889 r
.31537 .38777 .32332 .39796 .33588 .39665 .3281 .3842 Mtetra
.606 .636 .854 r
.3281 .3842 .33588 .39665 .34848 .39632 .34085 .38129 Mtetra
.587 .586 .818 r
.34085 .38129 .34848 .39632 .36118 .39572 .35364 .37901 Mtetra
.578 .559 .797 r
.35364 .37901 .36118 .39572 .37405 .39366 .3665 .37701 Mtetra
.583 .563 .797 r
.3665 .37701 .37405 .39366 .38707 .38976 .37945 .37478 Mtetra
.6 .595 .818 r
.37945 .37478 .38707 .38976 .4002 .38483 .39251 .37191 Mtetra
.625 .64 .846 r
.39251 .37191 .4002 .38483 .4134 .37982 .40568 .3682 Mtetra
.65 .676 .861 r
.40568 .3682 .4134 .37982 .42663 .37567 .41895 .36359 Mtetra
.675 .678 .845 r
.41895 .36359 .42663 .37567 .43989 .37253 .43231 .35779 Mtetra
.693 .645 .797 r
.43231 .35779 .43989 .37253 .45322 .37009 .44578 .35025 Mtetra
.688 .589 .74 r
.44578 .35025 .45322 .37009 .46671 .36362 .45932 .34105 Mtetra
.661 .554 .724 r
.45932 .34105 .46671 .36362 .4804 .34612 .47287 .33299 Mtetra
.66 .656 .835 r
.47287 .33299 .4804 .34612 .49397 .33744 .48643 .32762 Mtetra
.65 .719 .899 r
.48643 .32762 .49397 .33744 .50754 .33303 .50004 .32309 Mtetra
.648 .717 .899 r
.50004 .32309 .50754 .33303 .52118 .32853 .51372 .3186 Mtetra
.652 .72 .898 r
.51372 .3186 .52118 .32853 .53489 .32358 .52747 .31394 Mtetra
.655 .729 .903 r
.52747 .31394 .53489 .32358 .54867 .31844 .54129 .30915 Mtetra
.656 .739 .911 r
.54129 .30915 .54867 .31844 .56251 .3134 .55518 .30433 Mtetra
.656 .746 .916 r
.55518 .30433 .56251 .3134 .57642 .30844 .56914 .29948 Mtetra
.656 .75 .919 r
.56914 .29948 .57642 .30844 .5904 .30359 .58317 .29463 Mtetra
.656 .751 .92 r
.58317 .29463 .5904 .30359 .60446 .29873 .59727 .28975 Mtetra
.59727 .28975 .60446 .29873 .61858 .29388 .61144 .28484 Mtetra
.61144 .28484 .61858 .29388 .63278 .28899 .62569 .27991 Mtetra
.62569 .27991 .63278 .28899 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .26421 .69802 .25489 Mtetra
.69802 .25489 .70486 .26421 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Mtetra
.25663 .39672 .26492 .40474 .27745 .40041 .2692 .39235 Mtetra
.2692 .39235 .27745 .40041 .29004 .39608 .28183 .38795 Mtetra
.655 .751 .92 r
.28183 .38795 .29004 .39608 .30268 .39181 .29451 .38355 Mtetra
.655 .748 .918 r
.29451 .38355 .30268 .39181 .31537 .38777 .30726 .37915 Mtetra
.652 .739 .913 r
.30726 .37915 .31537 .38777 .3281 .3842 .32006 .3748 Mtetra
.646 .719 .901 r
.32006 .3748 .3281 .3842 .34085 .38129 .33292 .3706 Mtetra
.638 .687 .879 r
.33292 .3706 .34085 .38129 .35364 .37901 .34583 .3666 Mtetra
.629 .65 .852 r
.34583 .3666 .35364 .37901 .3665 .37701 .3588 .36277 Mtetra
.624 .618 .824 r
.3588 .36277 .3665 .37701 .37945 .37478 .37183 .35895 Mtetra
.623 .595 .802 r
.37183 .35895 .37945 .37478 .39251 .37191 .38495 .35496 Mtetra
.626 .584 .787 r
.38495 .35496 .39251 .37191 .40568 .3682 .39814 .35061 Mtetra
.633 .581 .778 r
.39814 .35061 .40568 .3682 .41895 .36359 .41142 .34576 Mtetra
.642 .584 .774 r
.41142 .34576 .41895 .36359 .43231 .35779 .42478 .34035 Mtetra
.648 .591 .777 r
.42478 .34035 .43231 .35779 .44578 .35025 .4382 .33467 Mtetra
.65 .615 .801 r
.4382 .33467 .44578 .35025 .45932 .34105 .45168 .32927 Mtetra
.655 .679 .861 r
.45168 .32927 .45932 .34105 .47287 .33299 .46521 .32436 Mtetra
.658 .753 .92 r
.46521 .32436 .47287 .33299 .48643 .32762 .4788 .31955 Mtetra
.657 .769 .932 r
.4788 .31955 .48643 .32762 .50004 .32309 .49246 .31474 Mtetra
.658 .763 .927 r
.49246 .31474 .50004 .32309 .51372 .3186 .50619 .30988 Mtetra
.657 .754 .922 r
.50619 .30988 .51372 .3186 .52747 .31394 .51998 .30505 Mtetra
.656 .75 .919 r
.51998 .30505 .52747 .31394 .54129 .30915 .53385 .30022 Mtetra
.656 .75 .92 r
.53385 .30022 .54129 .30915 .55518 .30433 .54779 .29537 Mtetra
.656 .751 .92 r
.54779 .29537 .55518 .30433 .56914 .29948 .56179 .2905 Mtetra
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Mtetra
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27572 Mtetra
.60424 .27572 .61144 .28484 .62569 .27991 .61853 .27075 Mtetra
.61853 .27075 .62569 .27991 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Mtetra
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Mtetra
.27354 .37978 .28183 .38795 .29451 .38355 .28626 .37532 Mtetra
.28626 .37532 .29451 .38355 .30726 .37915 .29905 .37085 Mtetra
.655 .75 .92 r
.29905 .37085 .30726 .37915 .32006 .3748 .31189 .36636 Mtetra
.655 .747 .918 r
.31189 .36636 .32006 .3748 .33292 .3706 .32481 .36185 Mtetra
.655 .74 .913 r
.32481 .36185 .33292 .3706 .34583 .3666 .33778 .35733 Mtetra
.653 .728 .904 r
.33778 .35733 .34583 .3666 .3588 .36277 .35081 .35285 Mtetra
.65 .712 .893 r
.35081 .35285 .3588 .36277 .37183 .35895 .36391 .3484 Mtetra
.648 .698 .883 r
.36391 .3484 .37183 .35895 .38495 .35496 .37707 .34394 Mtetra
.649 .69 .875 r
.37707 .34394 .38495 .35496 .39814 .35061 .3903 .3394 Mtetra
.651 .687 .871 r
.3903 .3394 .39814 .35061 .41142 .34576 .4036 .33474 Mtetra
.654 .694 .874 r
.4036 .33474 .41142 .34576 .42478 .34035 .41697 .32997 Mtetra
.658 .71 .886 r
.41697 .32997 .42478 .34035 .4382 .33467 .43041 .3251 Mtetra
.663 .731 .9 r
.43041 .3251 .4382 .33467 .45168 .32927 .44392 .3201 Mtetra
.663 .742 .909 r
.44392 .3201 .45168 .32927 .46521 .32436 .45749 .31511 Mtetra
.652 .737 .912 r
.45749 .31511 .46521 .32436 .4788 .31955 .47112 .31044 Mtetra
.652 .742 .916 r
.47112 .31044 .4788 .31955 .49246 .31474 .48482 .30578 Mtetra
.655 .748 .918 r
.48482 .30578 .49246 .31474 .50619 .30988 .49859 .30099 Mtetra
.656 .751 .92 r
.49859 .30099 .50619 .30988 .51998 .30505 .51243 .29614 Mtetra
.656 .752 .921 r
.51243 .29614 .51998 .30505 .53385 .30022 .52634 .29126 Mtetra
.656 .752 .92 r
.52634 .29126 .53385 .30022 .54779 .29537 .54032 .28636 Mtetra
.656 .751 .92 r
.54032 .28636 .54779 .29537 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27572 .59697 .26652 Mtetra
.59697 .26652 .60424 .27572 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Mtetra
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Mtetra
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Mtetra
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Mtetra
.29076 .36252 .29905 .37085 .31189 .36636 .30364 .35798 Mtetra
.655 .751 .92 r
.30364 .35798 .31189 .36636 .32481 .36185 .31659 .35343 Mtetra
.31659 .35343 .32481 .36185 .33778 .35733 .3296 .34886 Mtetra
.656 .751 .92 r
.3296 .34886 .33778 .35733 .35081 .35285 .34268 .34426 Mtetra
.657 .749 .918 r
.34268 .34426 .35081 .35285 .36391 .3484 .35583 .3396 Mtetra
.657 .745 .915 r
.35583 .3396 .36391 .3484 .37707 .34394 .36904 .3349 Mtetra
.657 .74 .911 r
.36904 .3349 .37707 .34394 .3903 .3394 .38231 .33019 Mtetra
.656 .736 .909 r
.38231 .33019 .3903 .3394 .4036 .33474 .39565 .32546 Mtetra
.656 .735 .908 r
.39565 .32546 .4036 .33474 .41697 .32997 .40906 .32072 Mtetra
.654 .737 .91 r
.40906 .32072 .41697 .32997 .43041 .3251 .42253 .31601 Mtetra
.651 .741 .915 r
.42253 .31601 .43041 .3251 .44392 .3201 .43606 .31139 Mtetra
.65 .751 .924 r
.43606 .31139 .44392 .3201 .45749 .31511 .44967 .30679 Mtetra
.658 .766 .929 r
.44967 .30679 .45749 .31511 .47112 .31044 .46335 .3019 Mtetra
.661 .762 .925 r
.46335 .3019 .47112 .31044 .48482 .30578 .4771 .2969 Mtetra
.657 .753 .921 r
.4771 .2969 .48482 .30578 .49859 .30099 .49092 .29199 Mtetra
.656 .751 .92 r
.49092 .29199 .49859 .30099 .51243 .29614 .5048 .2871 Mtetra
.5048 .2871 .51243 .29614 .52634 .29126 .51876 .28219 Mtetra
.51876 .28219 .52634 .29126 .54032 .28636 .53279 .27725 Mtetra
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Mtetra
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Mtetra
.656 .752 .92 r
.29531 .34954 .30364 .35798 .31659 .35343 .3083 .34493 Mtetra
.656 .751 .92 r
.3083 .34493 .31659 .35343 .3296 .34886 .32136 .34029 Mtetra
.656 .75 .919 r
.32136 .34029 .3296 .34886 .34268 .34426 .33447 .33564 Mtetra
.655 .75 .92 r
.33447 .33564 .34268 .34426 .35583 .3396 .34765 .331 Mtetra
.654 .751 .921 r
.34765 .331 .35583 .3396 .36904 .3349 .3609 .32634 Mtetra
.655 .753 .922 r
.3609 .32634 .36904 .3349 .38231 .33019 .37421 .32166 Mtetra
.655 .755 .924 r
.37421 .32166 .38231 .33019 .39565 .32546 .38759 .31694 Mtetra
.656 .757 .925 r
.38759 .31694 .39565 .32546 .40906 .32072 .40104 .31218 Mtetra
.657 .758 .924 r
.40104 .31218 .40906 .32072 .42253 .31601 .41456 .30736 Mtetra
.659 .757 .922 r
.41456 .30736 .42253 .31601 .43606 .31139 .42815 .30243 Mtetra
.66 .751 .917 r
.42815 .30243 .43606 .31139 .44967 .30679 .4418 .29744 Mtetra
.655 .74 .912 r
.4418 .29744 .44967 .30679 .46335 .3019 .45552 .2926 Mtetra
.652 .741 .915 r
.45552 .2926 .46335 .3019 .4771 .2969 .46931 .28782 Mtetra
.654 .749 .919 r
.46931 .28782 .4771 .2969 .49092 .29199 .48317 .28296 Mtetra
.656 .752 .921 r
.48317 .28296 .49092 .29199 .5048 .2871 .4971 .27802 Mtetra
.4971 .27802 .5048 .2871 .51876 .28219 .51111 .27305 Mtetra
.656 .752 .92 r
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Mtetra
.656 .751 .92 r
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Mtetra
.28691 .34102 .29531 .34954 .3083 .34493 .29994 .33638 Mtetra
.655 .752 .921 r
.29994 .33638 .3083 .34493 .32136 .34029 .31303 .33172 Mtetra
.656 .752 .921 r
.31303 .33172 .32136 .34029 .33447 .33564 .32619 .32703 Mtetra
.657 .752 .921 r
.32619 .32703 .33447 .33564 .34765 .331 .33941 .32229 Mtetra
.657 .751 .92 r
.33941 .32229 .34765 .331 .3609 .32634 .3527 .31752 Mtetra
.657 .749 .918 r
.3527 .31752 .3609 .32634 .37421 .32166 .36606 .31273 Mtetra
.656 .748 .917 r
.36606 .31273 .37421 .32166 .38759 .31694 .37948 .30792 Mtetra
.656 .746 .916 r
.37948 .30792 .38759 .31694 .40104 .31218 .39297 .3031 Mtetra
.655 .746 .916 r
.39297 .3031 .40104 .31218 .41456 .30736 .40653 .29828 Mtetra
.653 .746 .918 r
.40653 .29828 .41456 .30736 .42815 .30243 .42015 .29351 Mtetra
.652 .751 .922 r
.42015 .29351 .42815 .30243 .4418 .29744 .43384 .28874 Mtetra
.656 .759 .926 r
.43384 .28874 .4418 .29744 .45552 .2926 .44761 .28382 Mtetra
.658 .759 .924 r
.44761 .28382 .45552 .2926 .46931 .28782 .46145 .27881 Mtetra
.657 .754 .921 r
.46145 .27881 .46931 .28782 .48317 .28296 .47535 .27381 Mtetra
.656 .751 .92 r
.47535 .27381 .48317 .28296 .4971 .27802 .48933 .26882 Mtetra
.48933 .26882 .4971 .27802 .51111 .27305 .50338 .26382 Mtetra
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .3371 Mtetra
.26543 .3371 .27395 .34565 .28691 .34102 .27843 .33243 Mtetra
.656 .752 .92 r
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Mtetra
.656 .751 .92 r
.2915 .32774 .29994 .33638 .31303 .33172 .30463 .32301 Mtetra
.30463 .32301 .31303 .33172 .32619 .32703 .31782 .31828 Mtetra
.655 .75 .92 r
.31782 .31828 .32619 .32703 .33941 .32229 .33108 .31354 Mtetra
.655 .751 .921 r
.33108 .31354 .33941 .32229 .3527 .31752 .34441 .30878 Mtetra
.655 .753 .922 r
.34441 .30878 .3527 .31752 .36606 .31273 .35781 .304 Mtetra
.655 .755 .923 r
.35781 .304 .36606 .31273 .37948 .30792 .37127 .29919 Mtetra
.656 .756 .923 r
.37127 .29919 .37948 .30792 .39297 .3031 .3848 .29434 Mtetra
.3848 .29434 .39297 .3031 .40653 .29828 .39841 .28944 Mtetra
.658 .756 .922 r
.39841 .28944 .40653 .29828 .42015 .29351 .41208 .28447 Mtetra
.659 .752 .919 r
.41208 .28447 .42015 .29351 .43384 .28874 .42582 .27945 Mtetra
.656 .746 .917 r
.42582 .27945 .43384 .28874 .44761 .28382 .43963 .27449 Mtetra
.654 .746 .917 r
.43963 .27449 .44761 .28382 .46145 .27881 .45351 .26956 Mtetra
.655 .749 .919 r
.45351 .26956 .46145 .27881 .47535 .27381 .46746 .26459 Mtetra
.656 .752 .92 r
.46746 .26459 .47535 .27381 .48933 .26882 .48148 .25957 Mtetra
.656 .752 .921 r
.48148 .25957 .48933 .26882 .50338 .26382 .49558 .2545 Mtetra
.656 .752 .92 r
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Mtetra
.656 .751 .92 r
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .3371 .25683 .32846 Mtetra
.25683 .32846 .26543 .3371 .27843 .33243 .26987 .32375 Mtetra
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31903 Mtetra
.655 .752 .921 r
.28298 .31903 .2915 .32774 .30463 .32301 .29614 .31428 Mtetra
.656 .752 .921 r
.29614 .31428 .30463 .32301 .31782 .31828 .30938 .3095 Mtetra
.30938 .3095 .31782 .31828 .33108 .31354 .32269 .30468 Mtetra
.657 .751 .92 r
.32269 .30468 .33108 .31354 .34441 .30878 .33606 .29982 Mtetra
.656 .75 .919 r
.33606 .29982 .34441 .30878 .35781 .304 .3495 .29495 Mtetra
.656 .749 .918 r
.3495 .29495 .35781 .304 .37127 .29919 .363 .29005 Mtetra
.656 .748 .918 r
.363 .29005 .37127 .29919 .3848 .29434 .37658 .28515 Mtetra
.655 .747 .917 r
.37658 .28515 .3848 .29434 .39841 .28944 .39022 .28023 Mtetra
.654 .748 .918 r
.39022 .28023 .39841 .28944 .41208 .28447 .40393 .27533 Mtetra
.654 .75 .921 r
.40393 .27533 .41208 .28447 .42582 .27945 .41771 .27043 Mtetra
.656 .755 .923 r
.41771 .27043 .42582 .27945 .43963 .27449 .43157 .26543 Mtetra
.657 .756 .923 r
.43157 .26543 .43963 .27449 .45351 .26956 .44549 .26036 Mtetra
.657 .753 .921 r
.44549 .26036 .45351 .26956 .46746 .26459 .45949 .25528 Mtetra
.656 .751 .92 r
.45949 .25528 .46746 .26459 .48148 .25957 .47356 .25019 Mtetra
.47356 .25019 .48148 .25957 .49558 .2545 .48771 .24509 Mtetra
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Mtetra
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Mtetra
.656 .752 .92 r
.26123 .315 .26987 .32375 .28298 .31903 .27438 .31022 Mtetra
.656 .751 .92 r
.27438 .31022 .28298 .31903 .29614 .31428 .28759 .30541 Mtetra
.28759 .30541 .29614 .31428 .30938 .3095 .30086 .30059 Mtetra
.655 .751 .92 r
.30086 .30059 .30938 .3095 .32269 .30468 .31421 .29575 Mtetra
.655 .751 .921 r
.31421 .29575 .32269 .30468 .33606 .29982 .32762 .29091 Mtetra
.655 .753 .922 r
.32762 .29091 .33606 .29982 .3495 .29495 .34109 .28603 Mtetra
.655 .754 .922 r
.34109 .28603 .3495 .29495 .363 .29005 .35464 .28112 Mtetra
.656 .755 .923 r
.35464 .28112 .363 .29005 .37658 .28515 .36826 .27617 Mtetra
.36826 .27617 .37658 .28515 .39022 .28023 .38195 .27119 Mtetra
.657 .755 .922 r
.38195 .27119 .39022 .28023 .40393 .27533 .39571 .26615 Mtetra
.658 .753 .92 r
.39571 .26615 .40393 .27533 .41771 .27043 .40954 .26106 Mtetra
.656 .749 .918 r
.40954 .26106 .41771 .27043 .43157 .26543 .42344 .25601 Mtetra
.655 .748 .918 r
.42344 .25601 .43157 .26543 .44549 .26036 .43741 .25096 Mtetra
.655 .75 .92 r
.43741 .25096 .44549 .26036 .45949 .25528 .45145 .24588 Mtetra
.656 .751 .92 r
.45145 .24588 .45949 .25528 .47356 .25019 .46557 .24075 Mtetra
.656 .752 .92 r
.46557 .24075 .47356 .25019 .48771 .24509 .47976 .23559 Mtetra
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.656 .751 .92 r
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Mtetra
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30135 Mtetra
.2657 .30135 .27438 .31022 .28759 .30541 .27895 .29651 Mtetra
.656 .752 .921 r
.27895 .29651 .28759 .30541 .30086 .30059 .29226 .29164 Mtetra
.29226 .29164 .30086 .30059 .31421 .29575 .30565 .28673 Mtetra
.657 .751 .92 r
.30565 .28673 .31421 .29575 .32762 .29091 .3191 .28179 Mtetra
.656 .75 .919 r
.3191 .28179 .32762 .29091 .34109 .28603 .33262 .27682 Mtetra
.656 .749 .918 r
.33262 .27682 .34109 .28603 .35464 .28112 .34622 .27184 Mtetra
.656 .748 .918 r
.34622 .27184 .35464 .28112 .36826 .27617 .35988 .26684 Mtetra
.655 .748 .918 r
.35988 .26684 .36826 .27617 .38195 .27119 .37361 .26183 Mtetra
.655 .748 .919 r
.37361 .26183 .38195 .27119 .39571 .26615 .3874 .25682 Mtetra
.654 .75 .92 r
.3874 .25682 .39571 .26615 .40954 .26106 .40128 .2518 Mtetra
.656 .753 .922 r
.40128 .2518 .40954 .26106 .42344 .25601 .41522 .24671 Mtetra
.657 .754 .922 r
.41522 .24671 .42344 .25601 .43741 .25096 .42924 .24156 Mtetra
.656 .753 .921 r
.42924 .24156 .43741 .25096 .45145 .24588 .44333 .23639 Mtetra
.656 .751 .92 r
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .2312 Mtetra
.45749 .2312 .46557 .24075 .47976 .23559 .47173 .226 Mtetra
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29725 Mtetra
.656 .752 .92 r
.24372 .29725 .25251 .30616 .2657 .30135 .25694 .29238 Mtetra
.656 .751 .92 r
.25694 .29238 .2657 .30135 .27895 .29651 .27023 .28748 Mtetra
.27023 .28748 .27895 .29651 .29226 .29164 .28358 .28256 Mtetra
.655 .751 .92 r
.28358 .28256 .29226 .29164 .30565 .28673 .29701 .27764 Mtetra
.655 .751 .921 r
.29701 .27764 .30565 .28673 .3191 .28179 .3105 .27269 Mtetra
.655 .753 .921 r
.3105 .27269 .3191 .28179 .33262 .27682 .32406 .26772 Mtetra
.656 .754 .922 r
.32406 .26772 .33262 .27682 .34622 .27184 .3377 .26271 Mtetra
.3377 .26271 .34622 .27184 .35988 .26684 .3514 .25767 Mtetra
.656 .755 .922 r
.3514 .25767 .35988 .26684 .37361 .26183 .36517 .2526 Mtetra
.657 .754 .922 r
.36517 .2526 .37361 .26183 .3874 .25682 .37902 .24747 Mtetra
.657 .753 .92 r
.37902 .24747 .3874 .25682 .40128 .2518 .39294 .2423 Mtetra
.656 .75 .919 r
.39294 .2423 .40128 .2518 .41522 .24671 .40693 .23714 Mtetra
.655 .749 .919 r
.40693 .23714 .41522 .24671 .42924 .24156 .42099 .23199 Mtetra
.655 .75 .92 r
.42099 .23199 .42924 .24156 .44333 .23639 .43513 .2268 Mtetra
.656 .751 .92 r
.43513 .2268 .44333 .23639 .45749 .2312 .44934 .22158 Mtetra
.656 .752 .92 r
.44934 .22158 .45749 .2312 .47173 .226 .46363 .21632 Mtetra
.656 .751 .92 r
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24372 .29725 .23483 .28824 Mtetra
.23483 .28824 .24372 .29725 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .28748 .26142 .2784 Mtetra
.656 .752 .921 r
.26142 .2784 .27023 .28748 .28358 .28256 .27482 .27344 Mtetra
.27482 .27344 .28358 .28256 .29701 .27764 .28829 .26844 Mtetra
.656 .751 .92 r
.28829 .26844 .29701 .27764 .3105 .27269 .30183 .26341 Mtetra
.656 .75 .919 r
.30183 .26341 .3105 .27269 .32406 .26772 .31543 .25835 Mtetra
.656 .749 .919 r
.31543 .25835 .32406 .26772 .3377 .26271 .32911 .25327 Mtetra
.656 .749 .918 r
.32911 .25327 .3377 .26271 .3514 .25767 .34285 .24818 Mtetra
.655 .748 .918 r
.34285 .24818 .3514 .25767 .36517 .2526 .35667 .24307 Mtetra
.655 .749 .919 r
.35667 .24307 .36517 .2526 .37902 .24747 .37056 .23796 Mtetra
.654 .75 .92 r
.37056 .23796 .37902 .24747 .39294 .2423 .38452 .23283 Mtetra
.656 .753 .921 r
.38452 .23283 .39294 .2423 .40693 .23714 .39856 .22764 Mtetra
.39856 .22764 .40693 .23714 .42099 .23199 .41267 .22239 Mtetra
.656 .752 .921 r
.41267 .22239 .42099 .23199 .43513 .2268 .42685 .21712 Mtetra
.656 .751 .92 r
.42685 .21712 .43513 .2268 .44934 .22158 .44111 .21184 Mtetra
.44111 .21184 .44934 .22158 .46363 .21632 .45544 .20654 Mtetra
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19584 Mtetra
.48434 .19584 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3oool80:O0j`D0Yko[AP2W`>/00`000000Yl3[0:O0j`0@0:O0
ja40oooo00<000000?ooo`3oool0:P3oool002/0oooo0`0000030?ooo`030000003oool0oooo04H0
oooo202W`>/80:NojdD0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo02T0
oooo000Y0?ooo`800000B`3oool50:Noj`D0Yl3[2P2W_n]50:O0j`030000002W`>/0Yl3[0140Yl3[
4P3oool00`000000oooo0?ooo`0X0?ooo`009P3oool3000004X0oooo4`2W_n]90:O0j`030000002W
`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0X0?ooo`00903oool2000004/0oooo2P2W_n/2
0:S0j`D0Yko[1@2X`Na70:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?oo
o`X0Yko[1@2X`>/20:Noj`<0Yl3/1@2X`N`20:O0j`<0Yko[?P2W`>/300000080Yl3[00<000000:O0
j`2W`>/04P2W`>/B0?ooo`030000003oool0oooo02H0oooo000O0?ooo`<00000B@3oool:0:Noj`D0
Z<7/102X`>/60:O0k0@0Z<7/1P2W_n/j0:O0j`<000001@2W`>/00`000000Yl3[0:O0j`0C0:O0ja40
oooo00<000000?ooo`3oool09P3oool001d0oooo0P00001;0?ooo`L0Yko[1@2W`N`50:S1k0D0Yko[
102W`>`:0:NojcL0Yl3[0`0000090:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo
0?ooo`0<0?ooo`800000103oool2000000<0oooo1000000:0?ooo`005@3oool5000000<0oooo0P00
00190?ooo`L0Yko[202W`N`C0:Noj`D0Z<3[<`2W`>/3000000d0Yl3[00<000000:O0j`2W`>/04`2W
`>/A0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`0;0?ooo`005`3oool00`000000oooo0?ooo`030?ooo`<00000A03oool90:Noj`P0Yl7/2P2W
_n/30:S0j`D0Yko[102X`N`50:S0jc00Yl3[0P00000A0:O0j`030000002W`>/0Yl3[01<0Yl3[403o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
2P3oool001L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000o0?ooo`D0Yl3[
1@2W_n/90:O1k0X0Yko[1P2X`>/20:Noj`<0Yl7/102X`N`20:S0j`<0Yko[;02W`>/3000001<0Yl3[
00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool02@3oool000l0oooo100000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo``0Yl3[
1@2W`N`90:Noj`D0Z<7/1@2X`>/60:O1k0<0Z<7/1P2W_n/X0:O0j`<000005`2W`>/00`000000Yl3[
0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo03P0oooo3`2W`>/:0:Noj`D0Yl7/102X`N`50:Noj`D0Yl7/1@2W_^X40:NojbD0
Yl3[0`00000K0:O0j`030000002W`>/0Yl3[0180Yl3[403oool2000000/0oooo0P00000:0?ooo`80
00002`3oool001H0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
<`3ooolA0:O0j`X0Yko[202W`N`90:Noj`X0YkkZ102X`N/Q0:O0j`<000007`2W`>/00`000000Yl3[
0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool08@3oool001`0oooo00<000000?ooo`3oool01@3o
ool200000300oooo4P2W`>/:0:Noj`P0Yl7/0`2W_nX60:Noj`<0Z<3[1@2W_^X50:S2k0@0Z<7[7@2W
`>/300000280Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo0200oooo000L
0?ooo`800000203oool00`000000oooo0?ooo`0[0?oooa40Yl3[1@2X`>/40:Noj`X0Yl7/1P2W_nX3
0:Noj`H0Z<3[0P2W_^X30:O2k@D0Z<;/102W_n/I0:O0j`<000009P2W`>/00`000000Yl3[0:O0j`0B
0:O0ja40oooo00<000000?ooo`3oool0803oool001`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0X0?oooa@0Yl3[1@2X`>/50:O0k0@0Yl7/1@2W_n/50:NojPD0Z<7/102X`>/60:O2
k@80Z<;/0`2V_NX40:NojaD0Yl3[0`00000Z0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`00
0000oooo0?ooo`0O0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0
oooo6@2W`>/20:S0j`<0Yl3[1@2W`>`90:Noj`D0Yl7/1@2X`N`40:K0k0D0Yl;]1P2V_NX30:Noja80
Yl3[0`00000^0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0N0?ooo`00
6`3oool2000000`0oooo00<000000?ooo`3oool07`3ooolR0:O0j`80Yl3/1`2W_n/:0:O1k0D0Ykk[
102V`>`50:Nmj@D0Y[gZ102X`>/=0:O0j`80Yko[0P0000050:O0j`<0Yko[1@2W`>/50:Nojal0Yl3[
00<000000:O0j`2W`>/04`2W`>/@0?ooo`030000003oool0oooo01h0oooo000K0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool06P3ooolV0:O0j`P0Yko[1`2W`N`50:NnjPD0Ykk[102X
`>X50:Nmj@D0ZL?/102X`>/:0:O0j`040:Noj`000000000000000080Yko[0`2W`>/60:Noj`80Yl3[
0`2X_n/40:Nojb00Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01d0oooo
000K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0603ooolS0:O0j`D0Z<3[1@2W
_n/80:O1k0L0YkkZ0P2W_^/30:S1k0@0Z<3Z1@2Xa>d50:W3k0D0Yko[102W`>/20:Noj`<000001@2W
_n/40:NnjPD0Yko[1P2X_n/20:Noj`80Z;o[802W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00
000O0?ooo`006`3oool2000000l0oooo00<000000?ooo`3oool05@3ooolW0:O0j`@0Z<3[1@2W`>`5
0:O1k0T0YkkZ1P2X`N`20:S0jP80Y/3/1@2Xa>d50:JmjPD0Yko[0P2X`N`3000000@0Yko[1@2W_NT4
0:NnjPD0Z;cX2P2X_n/O0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0L
0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo;`2W`>/50:O0
k0D0YkoZ102W_^X50:S2k0D0Z<7/1@2V`>`20:S4k@<0Y[cY1@2V_NX20:Noj`040:S3k@0000000000
000000<0Z<7/1@2W^^L50:Nmj@@0Z;KS2P2X_>P40:Roj`D0Yko[6`2W`>/00`000000Yl3[0:O0j`0B
0:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P0000040?ooo`800000103oool20000
00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooobd0Yl3[0`2W_n/40:O0
j`D0Z;o[1@2W_nX50:O1k0@0Z<;/1@2V_NX40:K0k0H0Y[cY102V_NX3000000<0Z<?]0P2X`N`20:Jh
i@D0Yk[W0P2W_NT30:N[fP@0Z;KS1@2Z]N450:Rlj0@0Z;kY1@2W_n/K0:O0j`030000002W`>/0Yl3[
0180Yl3[403oool00`000000oooo0?ooo`0K0?ooo`001`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000<0oooo0P00000C0?ooo`030000003oool0oooo00X0oooo;02W`>/6
0:Noj`80Yl3[0P2X`>/50:Roj`X0Yl7/102W_>P50:JmjPD0ZKgX102V_>T01@2Xa>h0000000000000
0000Z<C^00D0Z<?]1@2V^>D40:Nji`H0Yj_J0P2X]^<20:^Wd`D0Z[GQ0P2X_>P30:^ih`@0Z;kY1@2X
_n/K0:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0J0?ooo`001`3oool0
10000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo
0?ooo`070?ooobl0Yl3[1@2W_n/50:S0j`<0Z;o[0P2W`>`50:O1k0T0YkcX1@2Y^nH50:Vmj0040:S0
j`0000000000000000D0Z<C^1@2U]nH40:Jhi@D0YIk>1@2WZmX50:^Wd`@0Z[GQ1@2[^N<20:Rnj@<0
Z[gW1@2X_n/J0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0I0?ooo`00
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool00P3ooold0:O0j`X0Z<3[1@2W`>`20:O1k0X0
YkcX0P2X]N850:VkiP80YjgL0`0000040:S0j`D0Y[SV1@2U]nH40:6A``D0YIk>0P2WZmX30:bLaP@0
ZjOC1@2`[]H40:^ih`H0Z[gW1@2X_nXJ0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000
oooo0?ooo`0I0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0
oooo0P00000F0?ooo`030000002W`>/0Yl3[03L0Yl3[102X`>/50:O0j`@0Yl3/2P2W_>P50:RehP80
ZK_V0P2VWLd2000000@0YjgL102XYmD50:JhiPD0W8Bi0`2QTL<50:FNcPD0[9c60`2[Ym<20;BSa`D0
/:kF102a]md30:Zmi`<0[KkV1@2X_nX20:O0j`80Z<3[5P2W`>/00`000000Yl3[0:O0j`0A0:O0ja00
oooo0P00000J0?ooo`00203oool2000000X0oooo0`0000030?ooo`030000003oool0oooo0180oooo
?P2W`>/40:Noj`D0Yl3[1@2X_NT40:Nlj0D0Yk7O102X]N801@2VWLd00000000000000000YYg=00@0
YjgL0P2YSKT40:RWe@80Y[SV0`2GN:h409b4^@@0XI730P2UW/h30:bF_`@0[9c60P2[Ym<30;BSa`@0
/:kF0P2i[Ld40;6gg@H0[KkV102X_nX50:S0jaH0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`03
0000003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo0180oooo>`2W`>/90:Noj`D0Z;kZ
1@2X_NT40:J_gPD0Yk7O00@0YIO600000000000000001@2VWLd20:N]g0<0ZHfi102XYmD509Mh[P@0
W8Bi102QTL<50:bF_`@0[9c61P2dXlL20;2^eP@0^Jg=0P2a]md20;Rhf@D0[KkV1@2Y`>X40:S0jaH0
Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01L0oooo000I0?ooo`800000
4@3oooln0:O0j`D0Yko[102X_n/50:RnjPD0Y[3O102V[mh20:Nag`<000000`2UUlH50:JMc@H0ZHfi
0P2XYmD20:1jZ0@0UgR^102LQ;T20:6A``<0[iW01@2/U[l20:bLaP80^JC31@2dXlL60;V]c@D0^;SI
1@2a_nD40:W0jPD0Z<3[5P2W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool0
5P3oool001T0oooo00<000000?ooo`3oool03@3ooom20:O0j`80Yko[0`2W`>/40:Roj`80Z;kZ0`2U
/^850:J`g`80YZoN0`0000030:BEaP@0YIO60P2VWLd30;2F_@D0ZHfi102PNZP509Mh[P<0W8Bi1@2_
VL050:bF_`@0^JC3102dXlL20;nX``@0^Jg=0P33/<L30;Rhf@80`KcE1@2a_nD40:[1jPD0Z<3[5P2W
`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool05@3oool001T0oooo00<00000
0?ooo`3oool02@3ooom<0:O0j`<0Z;o[1P2U/^830:J`g`<000000P2RU<L50:BEaP<0YIO61@2`U[d5
0:V=^@040=Bj`02PNZP0X7ZX0:1jZ0D0UgR^0P2LQ;T20;Z^cPD0[iW00`2/U[l20<6fc`@0^JC30P2d
XlL40;nX``80^Jg=0`33/<L20;Rhf@@0`KcE0P2a_nD30;C2i@@0Z/7Z1@2X`>/F0:O0j`030000002W
`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0E0?ooo`006@3oool2000000L0ooooC`2W`>/5
0:Jfi0@0YK;R0`0000020:2Eb@<0XYC71@2TULH20:FGaP80/JG<102`U[d40:V=^@80e;[00`2PNZP5
09Mh[P0409b4^@2j[/h0^Zk>0;Z^cPD0[iW00P2/U[l30<6fc`@0^JC31P2oZ<<50<>`a`H0`KcE1@2d
`^D50:[1jPD0Z<3[5@2W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool0503o
ool001T0oooo00<000000?ooo`3oool00`3ooom>0:O0j`D0Yk[W1@2V]^@30000000309nHc@2PULT0
X9G90080X9G9102RU<L40:BEaP@0/JG<1@2`U[d20:V=^@<0e;[0102PNZP409Mh[PD0^Zk>102_VL06
0<6fc`80^JC30P32/LT40;nX``80aZg11033/<L00`3<]<<0`KcE0<6le@020<6le@80b<7C0`2d`^D2
0;K5i@D0Z/7Z1@2X`>/E0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0C
0?ooo`00603oool00`000000oooo0?ooo`030?oood`0Yl3[1@2W_NT40:Nji`0509nNdP0000000000
0000002OW]800`2OV<d50:2Eb@<0XYC70P2TULH30:b]f0@0/JG<102`U[d00`2YSKT0e;[00=Bj`002
0=Bj`0@0X7ZX0`2GN:h20<kngP@0^Zk>0P2_VL030<3Pk`D0`KK?00@0^JC30<:ab@32/LT0`[790`2o
Z<<30<J]`@<0`k370`3<]<<20<6le@@0b<7C1@2faND50:[1jP@0Z<3[5P2W`>/00`000000Yl3[0:O0
j`0A0:O0j`l0oooo0P00000E0?ooo`00603oool010000000oooo0000003ooom;0:O0j`@0Yko[1@2W
_NT20:6VfP800000102OW]8409nHc@@0X9G90`2RU<L50:b]f0@0/JG<102`U[d60=Bj`0<0X7ZX0P2G
N:h40<kngP<0^Zk>1P30h>l40<6fc`D0`[7900<0_jS30<J]`@36[L400`36[L400`33/<L0c;C30<bd
``020<bd``D0b<7C0P3?am<40;K5i@H0Z/7Z102X`>/E0:O0j`030000002W`>/0Yl3[0140Yl3[4@3o
ool00`000000oooo0?ooo`060?ooo`8000002P3oool001P0oooo00<000000:O0j`2W`>/0BP2W`>/7
0:Noj`80YkgY00@0XjoQ00000000000000000P2QY]X509nNdP<0WiS=102PULT40:J]g0D0[:gH0`2a
YL`50:Gam@D0e;[00`2PNZP60<kngP@0LMcb1@30h>l50;;:j`@0`[791P36[L450<bd``040=Bi_`38
`M<0b<7C0<S1d`@0clOC102ga^D50:[1jPD0Z<3[5@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`004@3oool2000000D0oooo
00<000000?ooo`2W`>/0B02W`>/90:Noj`<000000P2S[n440:6VfP@0WikB0`2OV<d509nSf0@0YZgL
102/[MP504[8g`@0YO7e103D^/020:1jZ080VMCl0`1EZ_T402VRk@<0LMcb1@1B`oL50;;:j`80`[79
0P2m]]<40<J]`@80bJno0`3<]<<30=Bi_`D0clOC0P3Cc=<40;O6i@D0Z/7[102X`>/F0:O0j`030000
002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0
oooo000@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0B@2W`>/50:Noj`<0
000000<0YKSV0:>_h@2S[n400`2S[n430:6VfP@0WikB102IV=4509nSf0<0YZgL0P1Re^/509c7mP@0
P<7l0P2Qg?`40=Bj`0030:1jZ02D_?80U;cb0080U;cb101j_od608O;oP0303nVmP1B`oL0D/?g0080
D/?g102bb^/40;ffd`<0aZg11039[kl00`3<]<<0e;Vo0=Bi_`020=Bi_`040=bo_@3?am<0clOC0<o7
d`<0dlcC0P2ga^D30;O6iP@0Z/7[1@2X`>/F0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo
000000@0oooo0P0000020?ooodT0Yl3[00D0Y[gY00000000000000000:Jmj@040:FhiP@0XjoQ102C
Sl`409F@c0@0VISA102OXmP207oSm0@0Y/gd1@2LaoH509cIo@D0X[o^1@2D_?850:3Ko0D0S<Wl0P10
[oH200F5g`D0LKSk102m]]<00`36[L40bJno0<V__`030<V__`@0e;Vo0`3L_kd00`3?am<0dlcC0=?<
d`020=?<d`H0]lKV102Z`N/50:S0jaD0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooodD0Yl3[00@0Yko[00000000000000001@2V_NT409^RfP@0
UYKA0`2CSl`409F@c0@0VISA102Dj_P30:kFm@@0Y/gd1P2Me_`40:G1k@D0X[o^1P2Of_`409o5l`D0
S<Wl0`10[oH2001M_@<0LKSk102m]]<60<V__`040<b__@3D^Kl0e;Vo0=Bi_`<0g;nm103Cc=<20=C>
e0<0]lKV0`2fa^H40:[1j`D0Z<3[5@2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P0000040?oo
o`8000002P3oool00100oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?oo
od40Yl3[0`0000040:Noj`D0X;3S0`2KX]X409JFd@@0Tho<102ET<`209VHd@<0XN?l1P2^e_D50:3E
nPD0Y/?^102U`Nd609kFn`D0Y/C^102OaO<509_Ho0@0AK;g00@005fm01QoiP1a^?/0LKSk0P2m]]<2
0:f_f@@0bJno0P3<[kd20=Bi_`@0g;nm00<0hlNk0=?<d`3Cc=<0103Dc]@50;K6iPD0Z/7[102X`>/F
0:O0j`030000002W`>/0Yl3[0140Yl3[3P3oool300000100oooo000A0?ooo`800000103oool20000
00L0oooo?@2W`>/3000000@0Yl3[102T^^P50:2`h`<0Vj;J102FU]4309>?c0@0UI3<102Qho`30;OS
m@H0YMGi102WaNl50:K3kPD0WmCj1@2Wa>h40:K4kPH0ZMWh1@2OgO`3036Xl003000@RP0HOnH067oV
00@0[JoI0`39[kl40<b__@040=Bi_`3L_kd0g;nm0=bo_@<0hlNk103Dc]@20=??e@<0]/KV0P2ea^L5
0:[1j`@0Z<3[5P2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo00<000000?ooo`3oool03P3oool0
01L0oooo00<000000?ooo`3oool01`3oooli0:O0j`<00000102W`>/40:Jnj`@0Y;[X102P/><309^R
fP@0UYKA0`2CSl`60:77l`@0]n?e0P2[eoH30:GEn@<0ZL[a102WaNl50:7Bn@<0WmCj0P2W`nh50:O4
kPD0YmKh1P2]eoH50:7Ro0807Hc[00<0012:01QoiP0HOnH0102][mT00`39[kl0c:nm0<b__@030<b_
_@<0g;nm103Sak/00`3Xc;X0e<kD0=C>e0040=??e@D0]LKW1@2Y`N/40:S0jaD0Yl3[00<000000:O0
j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00d0oooo000G0?ooo`030000003oool0oooo00P0
oooo=@2W`>/3000000<0Yl3[1@2W_n/40:Jnj`@0Y;[X102?VMT308V<d0@0RhkA0`2DXml30:77l`@0
_N_c1@2[eoH60:W:l@@0X]7h1@2Qd_T50:O3kPD0YMCh0`2We_P20:c@l`<0[MOf102dj?L409K6m`04
01YOe@0MS>/0012:01QoiP@0[JoI1P3<[kd00`3B/[X0g;nm0=bo_@030>?7^`<0j<bj103CcmD20=;>
eP<0]LKW0P2daNL40:W1jaX0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo
00`0oooo000G0?ooo`8000002@3ooolc0:O0j`8000001`2W`>/50:Noj`<0Y[k[1@2IZn<308nIf@<0
RHc@1@2;S]4309BSg`80_N_c1P2ggO<60:cAl`@0Xlog102RdOP50:K4kP<0Yl?^0P2TdoP50:GDn0D0
[=3c102dj?L30;GQmP@0U/Kg0P0JGmD00`0048X0VYoH09ZOf00309ZOf0@0c:nm0P3B/[X0103L_kd0
hlNk0>?7^`3Sak/40>S<^P030>[>^P3CcmD0dloE00@0d/kF1@2daNL40:W1jaX0Yl3[00<000000:O0
j`2W`>/04@2W`>/?0?ooo`030000003oool0oooo00`0oooo000G0?ooo`030000003oool0oooo00X0
oooo;P2W`>/3000000X0Yl3[102W_n/40::hj@D0VJ_S0`2?VMT308V<d0@0RhkA102kh?830<GSk@<0
]mgc0P2cf_@30:cAl`<0YLkf102ScoL40:K5k`D0Y/C^1@2TdoP60:W;l@D0[nCi1@2ehOH409K6m`<0
6UoE00<0012:09ZOf02JWmP00P2JWmP30<b__@<0d[:j103Sak/30>S<^P80j/jj1@3Bc]H20=7>e`@0
]<GW1@2Y`N/J0:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?ooo`0;0?ooo`00
5P3oool00`000000oooo0?ooo`0<0?ooobX0Yl3[0`00000>0:O0j`@0Y[k[102R^>T409V[h`<0SiWI
0`29S=050:Fjj080^n3b1@35hnd50;?Jm0H0YLkf102WbO440:K5k`H0Xm?h102Wb?430:W;l@@0Z>7j
1@2ci?L40:F/g0@0OXOB0P0JGmD00`0008H001ZW09ZOf00309ZOf0030<b__@3B/[X0d[:j0080d[:j
00<0fkZh0>?7^`3Sak/00`3Xc;X30>[>^P040>W?^P3Bc]H0d/kF0=;>eP<0dLkG1@2daNL50:W1jaT0
Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00X0oooo000F0?ooo`800000
3P3ooolV0:O0j`<000003@2W`>/50:Noj`@0Y[k[102CZnH408>Df`80OXSC102;U=P50:Fjj0@0aN?]
1030h_050:_Bm0D0Ylkd102WbO450:;Bn@D0Y/Oa102Wb?440:SQnP<0[>3i1@2canT30:F/g0@0OXOB
00@07TBm01YOe@0JGmD00026102JWmP40=:b^P<0fkZh103Xc;X20>[>^P<0jLnj103Ac]L20=3>e`D0
]<GW1@2Y`N/I0:O0j`030000002W`>/0Yl3[0100Yl3[3`3oool2000000`0oooo000F0?ooo`030000
003oool0oooo00h0oooo8P2W`>/300000140Yl3[1@2W_n/40:2ij`<0Tj_V1023U=/307j8d`@0RiCH
0P2U^^P40<OJj0@0`>;`102jg?440:OEn0D0Ylkd1@2Pd?T40:G9lPD0Y/Oa1@2Sg_`40:cPn@80/M[e
1@2canT30:F/g0@0OXOB00@07TBm01YOe@0008H000jO102@T]830=:b^P<0fkZh00<0i/Be0>S<^P3X
c;X00`3Zc[X30>W?^P030>W?^`3Ac]L0dLkG00@0d<kG1@2caNL40:W1jaX0Yl3[00<000000:O0j`2W
`>/0402W`>/@0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000003oool0oooo0100oooo
7@2W`>/3000001D0Yl3[1@2V_^/40:2ij`<0Tj_V1023U=/307j8d`<0RiCH1@37f^P30<kPi@@0^]ca
0`2bg_H40:OEn0H0W/oi102RcOH40:G9lPH0W]gm1@2Vg?X50;7Jm@@0/lOY0`2U[=`407j7dP807TBm
00<00029000>W`2@T]800`2@T]820=:b^P@0fkZh0P3Va;D30>[>^P<0jLnj0`3Yck/40=3>e`80clgH
102caNL50:W1jaT0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00P0oooo
000F0?ooo`8000004P3ooolI0:O0j`<000006P2W`>/40:Jnj`<0X;W[0`2CZnH408>Df`<0OXSC1P2_
^N440<kPi@<0cn3U1P2bg_H509gCn`D0W=Ck102RcOH509SLoPH0X=[l1@2WhO/409b<`P@0UXS30`2=
QLH306mkc`<07TBm0P003Yl4092BdP040=:b^P3K^[P0fkZh0=^j^0<0i/Be00<0k<^c0>[>^P3Zc[X0
0`3YckX30>W?^`030>S>_03@c]L0d<kG00@0clgH102caNL40:W1jaX0Yl3[00<000000:O0j`2W`>/0
4@2W`>/?0?ooo`030000003oool0oooo00P0oooo000F0?ooo`030000003oool0oooo0180oooo5@2W
`>/3000001h0Yl3[102Q_>`309:_j`<0NIKR101aQ=L308RCe`@0[kWQ0`39c=`40<oPi@<0cN3V1P2Y
gOX408oIo`@0W=Ck1P2?f_l509SJo@D0WMkm1@2OS/8309b<`P@0UXS30`2=QLH406mkc`807TBm00<0
0029000>W`2@T]800`2@T]840=^j^0<0i/Be0P3/bk<30>W?^P<0jLnk0P3Xc[`50<o=f080c/gI102c
aNL40:W1jaX0Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`8000002@3oool000<0oooo0P000004
0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0503ooolA0:O0j`<000007@2W`>/5
0:Joj`@0XKc/0`2B[n/207VFhP@0LHCG1028TmL20:nih@<0bLcL0`3EdMD40<gPiP<0cMkV1P2Kg_d3
08oIo`D0PMKo1P2=fOl509WCo0@0X8o2102OS/8409b<`P@0UXS30`2=QLH406mkc`0401i4_@0008H0
01:Q000>W`@0UI;>0P3K^[P30>K4]@<0k<^c00<0kLbb0>W?^P3YckX00P3Yck/30>S>_0040>S?_@3?
cMP0clgH0<o=f0<0c/gI1@2baNP40:W1jaX0Yl3[00<000000:O0j`2W`>/0402W`>/;0?ooo`<00000
00<0oooo0000003oool0203oool00080oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo01D0oooo3P2W`>/200000240Yl3[1@2V_n/30:6lk0<0
TZo[0`1iU^840764e`<0R9?G1039c=`30=GAe@80fLk>0P3=h>H30<gNiP<0c=CP1P2QdOT508o5nP<0
Pm?o1P2I_o840:6?`@<0X8o21@2OS/8309b<`P@0UXS30`2=QLH406mkc`04000o`P0008H00029000B
X@D0UI;>00@0fkZh0>K4]@3Va;D0i/Be0P3/bk<30>g</P<0jLnk0P3Xc[`30>S?_@@0c/gI0P3=c]X4
0;;5j0D0ZL7[6@2W`>/00`000000Yl3[0:O0j`0A0:O0j`H0oooo100000040?ooo`030000003oool0
oooo00L0oooo00020?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool0oooo0P00
000G0?ooo`X0Yl3[0`00000T0:O0j`D0Y;k/0`2G]nh307NOj`80GH;N101aQ=L40:NYf080bLcL0`3E
dMD40=W>cP<0cMkV0`3<e>030<^mc0D0[k7I0`2?aOX20:BKc0<0W:ON0`2I_o830:B@`0<0XHo1102P
Sl8409n>`P<0W8c21@2K_>l309Jjl0@0KZKc00@003o20000QP004Z4001:Q102ET/h40>K4]@80k<^c
0`3]c;800`3]c;40jLnk0>S>_0020>S>_0<0j<nm00<0j=2n0<k=f@3>cMT0103=c]X40;75j0D0ZL7[
6@2W`>/00`000000Yl3[0:O0j`0A0:O0j`80oooo0`0000080?ooo`030000003oool0oooo00L0oooo
00020?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01P0oooo
1@2W`>/3000002T0Yl3[102T_^`309NgkP<0Mio[0P1MP]h407J7e`@0YjWH0`3EdMD40=W>cP<0flO5
0`3<e>040<^mc0030<VZ^P2_/MT0[k7I00<0[k7I1@2TVl`309bWgPD0Y930102QSl430:2?`P@0Whk2
102M_Nl409^lk`@0U[[`0`1^Y_<01000?kl003o2000BX@004Z450:VTd@80i/Be0P3/bk<30>g</P80
kLba0`3Xc[`30>S?_@<0j=2n103=c]X20<cAg@@0/LGX1@2Y`N/I0:O0j`030000002W`>/0Yl3[0100
Yl3[0P00000<0?ooo`030000003oool0oooo00H0oooo00020?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`040:O0j`00000000000000
02d0Yl3[102P_Nd308J`l080DHWX0`1MP]h407J7e`80YjWH0`2o]]440=W>cP@0flO50P3I^[/40<^m
c0<0bJZj0P2_/MT30;NN_`@0Y9_<102ZUL440:B@`0@0XHo10`2PSl850:6okP@0WKg_0`2NZml408jf
l@@0WjOK00@0CHg/0000L0004Z4001:Q1@2YY=400`3Va;D0k<^c0>c;/`030>g</P80kLba00<0k/ba
0>S>_03Xc[`00`3Xckd30>S@_P030>WE`03=c]X0cLkJ00@0c=7M102`aNT40:W1jaX0Yl3[00<00000
0:O0j`2W`>/0402W`>/=0?ooo`030000003oool0oooo00H0oooo00030?ooo`8000002P3oool30000
00<0oooo0P00000H0?ooo`<00000;02W`>/50:Jok0@0X;g]0`26/?020569j080B7CJ101fQmL50;nf
d@030<fhaP3Ic/h0fLk>00@0flO50`3I^[/0103G/;00bkg<0<^mc03;_L`30<VZ^PH0]ijo0P2TVl`2
0;>Pa0<0ZYG1102TT<040:6?`@@0Yl;]1@2Q_nh20:>Vf0D0WZ_O102]ZM@409nWf`0304f=k0000700
01:Q00D0ZJCA0P3/bk<30>g</P<0kLba0P3^c;430>S?_@<0j=2n0P3YeL050<cAg@80bM?Q102`aNT4
0:S1jaT0Yl3[00<000000:O0j`2W`>/0402W`>/=0?ooo`030000003oool0oooo00H0oooo000D0?oo
o`030000003oool0oooo01D0oooo0`0000040?ooob`0Yl3[1@2V_n`30:2mk@<0Q[3`0`1ARNP204Qd
fP@0Ri?F0`2o]]430<fhaP@0flO50`3I^[/30=N`/0030<^mc039Z[X0bJZj0080bJZj00<0d:^c0;NN
_`2gW[l00`2gW[l40;>Pa0@0ZYG10`2TT<050:c3jP@0Yl;]0`2VYmL40:>Vf080WZ_O0`2^ZmD40:fY
e080WjOK0P2^ZM800`2>W=d001ZX000BX@020:VTd@<0`KgF00@0k<^c0>g</P3]c;80kLbb0P3]c;43
0>k</@030>k=/@3Xckd0j<nm0080j=2n0`3YeL00103Zg<@0c=7M0<cAg@3<dMd30<WCh@D0[lG[102X
`N/I0:O0j`030000002W`>/0Yl3[0100Yl3[303oool00`000000oooo0?ooo`060?ooo`00503oool0
0`000000oooo0?ooo`0B0?ooo`<00000203oool/0:O0j`D0YKo/0`2K^nl306nVlP806V[M0P18M=X5
08^CeP030;nfd@3=^<H0cKS60080cKS600<0d[Bk0=_7a@3KalD0103I^[/30=N`/0@0bJZj0P3@Zk<4
0;NN_`80aJo5102cX<@30:ZE`@80Y9300P2``nP50:c3jP<0ZJoL102VYmL30:>Vf0D0[Z_E102]ZM@5
0:jYdP0308jLg@006ZP0`KgF00@0`KgF0`3]c;830>g</@<0k/ba0P3^cK430>S@_P80jMG00`3Zg<@4
0<WCh@80a=CV102_aN/50:S1jaT0Yl3[00<000000:O0j`2W`>/0402W`>/;0?ooo`030000003oool0
oooo00H0oooo000D0?ooo`800000403oool3000000`0oooo;02W`>/50:Fok0<0Vk__0`1_Y_8201YZ
g@0303IZf018M=X0Ri?F00<0Ri?F103=^<H30=:d^`@0fKZk103G/;00103I[J/0bJZj0<VZ^P39Z[X3
0=2[/`80]ijo0`35[lD40;>Pa0<0ZYG11@2``nP30;72i`@0ZJoL102VYmL40:^[e`@0[Z_E1@2`Z]84
0:jYdP80WZ;H00@001ZX0<6meP31_MH0`KgF0P3>bMH20>g</P80kLba0`3^c;430>k=/@030?7B/@3X
d;h0jMG00080jMG00`3Zg<@00`3Yhl/0bM?Q0<WCh@040<CDiP@0[<C[102X`N/J0:O0j`030000002W
`>/0Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0<
0?ooo`<000004@3oool[0:O0j`D0YKo/0`2F^_03056IlP0301YZg@0fJ]P0=V[H00D0WigB0`3=^<H3
0=:d^`040=F_/`3I^[/0fKZk0=Vj^`<0ek2`0P3I[J/20<VZ^P@0d:^c00<0]ijo0<F_a@35[lD00P35
[lD40;>Pa0D0/L;W00<0C/R_0;[Tl`2ji?<0102a`^L30:V_g0D0YZWI102[ZmL20:j[e@80[:WD102`
Z]820:jYdP<0/[3F00@0WZ;H000T[@006ZP0`KgF103>bMH30>g</@<0k/ba0P3^cK420?7B/@<0jMG0
0`3Zg<@30>WSb`<0a=CV0`2md^X40:c4j`@0Z<3[6@2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo
00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool02P3oool2000001D0oooo;02W
`>/40:Fok0<0U[[`0`1AVO800`0JJ]d0=V[H03IZf00509nMdP040<fhaP3B];/0d[Bk0=:d^`<0eJnc
00<0fKZk0=N`/03G/;000P3G/;030=V]Z`030<VZ^P3@Zk<0d:^c0080d:^c1@35[lD50;G3i@<0/L;W
1@2ji?<30;72i`@0XJKI1@2VZMT30:^[e`D0[:WD0`2`Z]860;:`eP0309jRf000;K80c/WF00<0c/WF
0`3Bbm<30>k</@<0k/fa0P3ad[420?CK/`<0j]c40`3Yhl/20>CXe0D0_M;Z1@2Z`n`40:S0jaT0Yl3[
00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003o
ool0oooo00L0oooo0`00000H0?ooob`0Yl3[102T_n`309:il@80=X_]00<003jo03IZf00fJ]P01@2O
WM840=:d^`<0eJnc103G/;040=V]Z`D0d:^c00@0f[^k0<F_a@35[lD0aJo50P36aMT50;G3i@<0_?_X
1@2MY]`309bRf@@0XJKI102VZMT40:VXeP@0[:WD102b]]`50;:`eP80WjSM00<002fb0<k9eP3>bMH0
0`3Bbm<20=G=dP80k/ba0P3^cK430?7B/@80m=^c0P3eiKL30>WSb`80i>SD0P3JjMh30;gBjP80]Lg/
102Z`n`N0:O0j`030000002W`>/0Yl3[00l0Yl3[2P3oool00`000000oooo0?ooo`050?ooo`004`3o
ool3000000D0oooo0`00000L0?ooob`0Yl3[102T_n`309:il@80=X_]00<003jo01IJdP0fJ]P00P2O
WM830:fRc@80d[Bk103E[k<0103G[jl0ek2`0=N`/03G/;040=V]Z`040=ne[03@Zk<0d:^c0=2[/`<0
f[^k00<0aJo50<K5f@36aMT00P36aMT209G`k080_?_X102__><409fVg0@0W:;I0`2QY]T50:JWe`@0
ZJSF0P2/ZM@20:jih@@0/[KL0P2b/=H30:fbg080WjSM00@002fb0=;;d`3Bbm<0d/_C103EcM830>k=
/@80lM:a0P3dfk<30?GU]`040??/_P3Tj=@0i>SD0>CXe0@0f^WN1@2ecN`40:S1jah0Yl3[00<00000
0:O0j`2W`>/03`2W`>/90?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000003oool0oooo
0080oooo0`00000P0?ooob`0Yl3[102T_n`3096ilP809H;Y00<003jo01IJdP2]X/d01@2]X/d00`3B
];/0eJnc0=F_/`020=F_/`030=N_[`3G/;00ek2`00@0fJf[0P3O]J`30=2[/`<0f[^k1036aMT30<kU
j0030=Wme`3Hgm`0f=oL00@0[kcS0`2MY]`409bRf@@0XZGH102VYmL40:VXePD0[[WQ0`2b]]`50:fb
g0<0WjSM00<002fb0=;;d`3EcM800`3EcM820=[Ed`040>k=/@3ad[40lM:a0?7B/@80m=^c0P3eiKL2
0??/_P80k_760`3JjMh30<gUj0D0[/O]102X`N/M0:O0j`030000002W`>/0Yl3[0100Yl3[203oool0
0`000000oooo0?ooo`050?ooo`004`3oool00`000000oooo00000002000002@0oooo;02W`>/40:Bo
k0<0TKWb0P0UP^T201IJdPD0[J;=103E[k<30=N_[`030=N`/03I[J/0fJf[0080fJf[0`3O]J`00`3@
Zk<0f[^k0=Zk^`020=Zk^`030=c4`P36aMT0a/GI00<0c^GX00<0fOgG0=SOg03Hgm`00P3Hgm`30:nl
h`@0VIoI102NX]P40::Uf0<0YZOG1@2[^^@40:jih@@0Zk;M102]/]`409VVgP@0eLgB0`3JeM<30?7B
/@80m=^c0P3eiKL20??/_P<0k_7600<0j?G?0<gUj03=iNP00P3=iNP20;kJkP@0[/O]1@2X`>/M0:O0
j`030000002W`>/0Yl3[0100Yl3[1`3oool00`000000oooo0?ooo`050?ooo`004`3oool3000002L0
oooo;02W`>/40:Bok0<0T[Wb0P0SPNT01000=;X05U[B0:fRc@2]X/d30;BWb`<0eJnc0`3G[jl40=V]
Z`@0gkF/103J^k/30=c4`P<0c^GX00<0fOgG0=SOg03Hgm`00`3Hgm`409^SfP@0VIoI102NX]P30::U
f0@0YkWU102[^^@50:VagP@0Zk;M102Y/]l409VVgP80eLgB103JeM<00`3OjMX0lM:a0?7B/@020?CK
/`80mNFg0P3ck;h20>kaaP80j?G?0P3PmmT50;kJkP@0Z/?/1@2X`>/M0:O0j`030000002W`>/0Yl3[
00l0Yl3[1`3oool00`000000oooo0?ooo`050?ooo`00503oool00`000000oooo0?ooo`0W0?ooob`0
Yl3[102T_n`309:ilP808h7Y00<003Bj0;BWb`2dYl/00`2dYl/20=F_/`@0ejn_00@0g;B_0=V]Z`3I
[J/0fJf[103O]J`0103T_k40f[^k0=Zk^`3J^k/30=c4`P80hLg40P3`hl00103chK/0f=oL0=SOg03H
gm`20;^jf0@0Vj?J0`2IWmT409jRf0@0Y;GU102W^ND40:R`gPD0ZK7N102[^><40:Vbg`<0VJKN00<0
GX;M0=[Ed`3JeM<00P3JeM<30=oYfP80m=^c0P3eiKL20??/_P80k_760P3XmLl20>3gf@80e?CU0`2n
f^h20;;=kP@0Z/?/8@2W`>/00`000000Yl3[0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool0103o
ool000/0oooo1@0000050?ooo`800000:@3oool[0:O0j`@0YKo/0`2C^_4202V5j`03000d^P2dYl/0
]:O;00<0]:O;00<0eJnc0=N_[`3G[jl00P3G[jl00`3L]:l0fJf[0=V]Z`040=ne[0<0i;na00@0f[^k
0=c4`P3La<80g<C20`3QcL@0103`hl00ln6k0??Q^`3chK/50;^jf0<0Vj?J102JY]h409n_h`@0Y;GU
102W/=h40:R`gPD0Z[_V102[^><30:Vbg`<0VJKN0P1NP]d20=[Ed`<0gnWJ0P3Cn^820<7jjP80lnbn
0P3^lLH20>Sec`80h?OI103Dm>D50;;=kP@0Z<7[8@2W`>/00`000000Yl3[0:O0j`0@0:O0j`H0oooo
00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0W0?ooob/0Yl3[102U_n`309>jl@80:HG[1@2dYl/40=N_[`<0g;B_00<0fJf[0=ne[03O]J`00P3O
]J`30>Bo/@@0g<C20P3QcL@20?3S`0<0ln6k00<0i]310;^jf02k^]P00P2k^]P409RPfP@0VZKN0`2O
[n<50:J`g`@0Yk3N0P2X/=h20:Rlj0@0Z[_V102[^><40::_h@<0TJCR0P1RQ]l30=oYfP80do[R0P31
n^X20;kel080b?7^0P3Bl^L20>3gf@<0e?CU0`33iNl50:_4k0@0Z<7[8@2W`>/00`000000Yl3[0:O0
j`0@0:O0j`D0oooo00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0W0?ooob/0Yl3[102U_n`409Fjl@0308L;002dYl/0]:O;00<0/jgB0`3G[jl3
0=bd[`@0gkF/103T_k400`3U`[<0g<C20=c4`P020>7=a080l>?00`3chK/20>K@`@D0[JWD102HX=X3
09ZVgP@0YJoO102V/=l40:N`gPD0Z;cX0`2Z^nH50:Fah@@0XZoQ0`2AY>8306:6g`030=?jhP31n^X0
`O[Z00<0__G`0P38lNh20=;bi`80f?OP0P3Go=`40<?Uk`80/]3_102[a>`V0:O0j`030000002W`>/0
Yl3[00l0Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02L0oooo:`2W`>/40:Fok0@0U[[a1@2c[M820=N_[`@0g;B_00@0h;jf0=ne
[03O]J`0gkF/0`3T_k430>G2/`80hLg40`3`hl020??Q^`<0i]3100<0e/340:fYe02]ZM@00P2]ZM@4
09RPfP@0XZkP102U[ml30:J`g`D0YkcX102X_>P40:Jag`@0YK7Q1@2M[>4308VLg`<0J8KM0P0aJMT2
00][g@040<SakP3Bl^L0d_;W0=;bi`80f?OP0P3Go=`30<kki0D0/]3_102X`N/U0:O0j`030000002W
`>/0Yl3[0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0:
0?ooo`800000:03oool[0:O0j`@0YKo/102F^_450;>]dP030=N_[`3L]:l0g;B_0080g;B_0P3P_[H0
0`3O]J`0i;na0>Bo/@020>Bo/@<0iL:c00@0i/Bc0?3S`03`hl00l>?00P3chK/30>K@`@<0e/340`2]
ZM@50:2Yg@@0XZkP0`2U[ml40:Jji`D0YkcX102W/=l40:Jag`@0YKGT102M[>4408VLg`<0J8KM00<0
GHSS035Yf@1QXO<00`1QXO<00`3Hmn00eocL0=Olg0030<kki0<0`>Sa1@2Za>`40:S1jbD0Yl3[00<0
00000:O0j`2W`>/03`2W`>/40?ooo`030000003oool0oooo00@0oooo000<0?ooo`8000003P3oool0
0`000000oooo0?ooo`0V0?ooob/0Yl3[102U_n`409Nkl0@0/jgB103L]:l30>2n]P@0i;na0`3U`[<2
0>K4/`80k/jb0P3chK/30>K@`@@0e/34102/ZM@50:2Yg@@0Xk3Q0`2T]^D40:Jji`D0Yk7O102W/=l4
0:NjiP@0YKGT0`2M[>4408VLg`<0J8KM0P1MR><409[8m`80_^Wc0P37oN<20<3Xl@@0/<k_102Za>`Z
0:O0j`030000002W`>/0Yl3[00l0Yl3[0`3oool00`000000oooo0?ooo`040?ooo`007@3oool00`00
0000oooo0?ooo`0V0?ooob/0Yl3[102U_n`309Nkl0D0X;CV0`3L]:l30>2n]P040>35_@3T_k40i;na
0>Bo/@<0iL:c0P3Va;<20>k>/P80m]J]0P3ee:d40=K0a080c;S6102/ZM@50:F[f`@0Xk3Q0`2T]^D8
0:Nag`D0Yk_X102W^^H30:Fei0@0UJ?O1024Umh207F?gP@0GHSS0`2njO<20<Omh`040<?liP2ihO<0
^N7c0;WQl`@0/<k_102X`N/Z0:O0j`030000002W`>/0Yl3[00h0Yl3[103oool00`000000oooo0?oo
o`030?ooo`007P3oool00`000000oooo0?ooo`0V0?ooob/0Yl3[102U_n`309Rkl0@0X;CV0P3L]:l3
0>2n]P<0h<Fm00@0i;na0>G2/`3U`[<0iL:c0P3Va;<30>k>/P80m]J]0P3ee:d00`3^c[80e/340=K0
a0040<bhaP80[:WD0P2aZm840:F[f`@0Xk3Q102X/]l40:Nag`P0Yk_X1@2SZmd309jYgP@0UJ?O1024
Umh207F?gP@0QZ_]0P37oN<00`33o>H0^N7c0;WQl`030;WQl`D0ZL;/102X`N/Y0:O0j`030000002W
`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?ooo`007`3oool2000002P0oooo:P2W`>/4
0:Fok0<0V;_`102P]>H0103L]:l0h;jf0>2n]P3P_[H30>35_@@0iL:c0P3Va;<20>k>/P80m]J]0`3e
e:d20>k>/PD0c;S61@2aZm830:F[f`D0ZK;O102X/]l40:NjiP@0Yk_X102U[=`40:>[g@@0WZWN0`2E
Xml408BGgP<0MHoN102_goP0102bnm`0^oO_0;_gk`2kmnl40:c8kP@0ZL;/;P2W`>/00`000000Yl3[
0:O0j`0@0:O0j`030?ooo`000000oooo00@0oooo000Q0?ooo`030000003oool0oooo02H0oooo:P2W
`>/40:Fok0<0VK_`0`1[ZoL30>2n]P@0h<Fm00<0glJo0>G2/`3U`[<00`3Va;<20>k>/P80m]J]0P3e
e:d30>k>/P040>K9^@3<^<H0c;S60<bhaP80bKG7102aZm840:^_f`@0ZK;O1@2W]^<40:NjiP@0YjcK
102U[=`30:>[g@D0W:OM0`2AV]P408JCf0@0RjKV00<0/__L0;_gk`2kmnl0102ado840:c8kS80Yl3[
00<000000:O0j`2W`>/03`2W`>/00`3oool000000?ooo`040?ooo`008P3oool00`000000oooo0?oo
o`0V0?ooobX0Yl3[1@2U_n`209Vkl0<0Jj_g0P3P_[H30>35_@<0glJo0`3Va;<30>k>/P80m]J]0P3e
e:d20>k>/P<0i/Vi00<0c;S60<Vea`39]LL00P39]LL20;6[dP80]JkA102[[m/40:V`g@@0YkKS1@2X
[M/40:N/f`<0YJcL102S/>8409bWg@@0TI[H0`26TmP208^ViP80Ynoh00@0XoKG0;GTmP2ei?H0]NCf
102ado840:S1k380Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`008`3o
ool00`000000oooo0?ooo`0V0?ooob/0Yl3[102V_n`209Zll0<0>ICa103PaKd30=o6_`030=o7`@3V
a;<0i/Bc0080k/jb0P3feZd20?GD[@<0k/jb0`3VbKT50<Vea`D0]JkA102^[=H40:V`g@@0ZjkJ102X
[M/40:N/f`@0Y[GT102S/>8309bWg@@0TI[H0`26TmP20:O_n0030:?fe`2ei?H0]NCf00<0]NCf1@2Y
`n`30:S1k380Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2
000002L0oooo:`2W`>/40:Jok080V[c`0`0iU?420>35_@<0glJo0`3Oal430>k>/P80m]J]0P3ee:d2
0>k>/P@0i/Vi00@0glK00<Vea`39]LL0bKG70P38]LP30;F^d@80^Jg>102^[=H20:V`g@80[ZkG102[
[]X30:R]f`D0YkKS102V]N@30:>`hP@0Ti7>102?V]X209Jll@80P^O90`2`lo@40:_7kP@0ZL?/=P2W
`>/00`000000Yl3[0:O0j`0;0:O0j`<0oooo00<000000?ooo`3oool00`3oool002H0oooo00<00000
0?ooo`3oool09@3ooolZ0:O0j`D0Y[o/0P2K_?030265jP@0glJo0`3Oal420>;=``80m]J]0P3ee:d3
0>k>/P<0i/Vi0`3Oa/000`39]LL0b;G80<Reb0020<Reb0030;F^d@2i[Lh0^Jg>0080^Jg>0`2^[=H5
0:j^e`<0ZjkJ102Y/n040:Nfh`D0WiG90`2JT/X409>AcP<0Si[J0P22ilT20;3cm0@0[Lga102[anhj
0:O0j`030000002W`>/0Yl3[00H0Yl3[203oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`0U0?ooobX0Yl3[1@2V_n`209bmk`<08HGZ0P3Oa[l30=o7`@<0h/g30P3[fL420?;P
_080l^:m0`3VbKT40=o6`0D0b;G81@2i[Lh40;>/dP@0[ZkG102Z[MT40:Vch0@0XiO8102OULT409ZB
bP<0Ti7>0P1min@00`2DlN40[MCd0:gDm0030:gDm0<0[Lga1@2X`>/i0:O0j`030000002W`>/0Yl3[
00<0Yl3[2`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`0V0?ooobT0
Yl3[1@2V_n`309bmk`803GSR103Oal420>;=``80jmW10P3bh;`30?;R_@030>gRa@3VbKT0glK000<0
glK00P3Jb<P30<Reb080b;O:0P2i[Lh30;b_c@@0/jcB102]Y]440:Z]f@@0YiW70`2SUlP409nEb@@0
VY;:0`2=g_h206SI_P80Zm_h102]e?@50:S1k3d0Yl3[00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`020?ooo`00:@3oool2000002L0oooo:@2W`>/40:Jok0@0Wkk^00@006_H00ehhP3Oal40
glO10P3RcL<20>_I`@80l^2l0`3bh[d20>gRa@@0glK00`3Jb<P20<Reb0<0b;O:1@2l[ld20;>/dP<0
]:S=102]Y]420:Z]f@80[9g80`2WVLL40:>Gb0<0WiG91@2Hb_T206SI_PD0Zm_h1@2X`^`n0:O0j`<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo
0?ooo`0U0?ooobT0Yl3[102V_n`409nnkP8006_H0P3RcL<30>_I`@80l^2l0P3bh[d30>gRa@030>CU
d`3Oa/00glK000@0f/S81038]lX20<S1d`@0_:o=1@2dZ<d40:fVd@@0[9g8102WVLL30:>Gb0D0X;o_
0P0000050:OOn`@0ZLG^?P2W`>/80?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<000000?ooo`3oool09@3ooolY0:O0j`@0Y[o/102R_^d00`27]oD006O=0>_I
`@020>_I`@80l^2l0P3bh[d30>gRa@<0i>GC103Jb<P20=CAeP80b;O:1038`M<20;b_c@80`;WC102d
Z<d50;F[c`@0[9g80`2WVLL40:O2k@<0X;o_102Ph?`50:S6k`@0Yko[102W`>/50:Nojc40Yl3[2`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000]0?ooo`030000003oool0
oooo02H0oooo;@2W`>/30::nk@80U[cb00<007_90?;P_03bh;`00P3bh[d00`05U/X0kN;50>gRa@03
0>CUd`80dNgW0P3Jb<P40=CAePD0b<7C1@30^M<20;BXc@80_lOQ102eZll40:bMb0@0[=3c102W`^d3
09[No@D0YlO`102W_nX40:Noj`@0Yl3[102W_n/^0:O0j`l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`010?ooo`00;P3oool00`000000oooo0?ooo`0V0?ooobd0Yl3[102T_nd309Jl
lP0408>im`0=WLH03Ig600fMaP80i>GC00<008Ve0=7]i`3AkNL00P3AkNL40=CAeP80`nO`0`38`M<2
0<;QkP@0`;WC1@2oan430;F[c`D0YNKk102/d?<309KJoPD0Y/O`102W_^X40:NojP@0Z<7/<@2W`>/D
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool002l0oooo0P00000W0?oo
obd0Yl3[102V_n`409nnk`<0PkWg0`0QU>`509W/m`D0`nO`1@32hNh20<2id`80Z>kh102oan4506kN
h@<0V<kk102U`nl40:K6l0P0YkkZ2@2X`N`]0:O0jaP0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0U0?ooobd0Yl3[102V_n`40:Fok0@0
V[ka102I__8407Jko0D0@lGG0`32hNh50:S^n0<0J/Sn1@2Lb?H40:G1k@@0YL?_102X_nX40:NnjP@0
Yl7/102X`N`50:Noj`<0Yl3[1@2W_n/P0:O0ja`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`010?ooo`00<P3oool00`000000oooo0?ooo`0U0?oooc40Yl3[102U_n`40:Bok@@0VKkb
102L_o4408O0nPD0VL;d0`28a_`509o3lP@0Y/3/102U`Nd40:Roj`@0Z;oZ202W`N`80:NojbD0Yl3[
803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000c0?ooo`030000003o
ool0oooo02D0oooo=@2W`>/90:Bok@<0W;oa1@2R`>l40:G0k0@0Xl7^102W`>`40:K0k0@0Z<3[102X
_n/80:O1k0D0YkkZ0`2W_n/50:S0jb00Yl3[903oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0040oooo000d0?ooo`8000009P3ooole0:O0j`@0Yl3/1@2W`>/30:K0k0D0Yl3/0`2U`>`5
0:O0j`<0Yl3/1@2W`>/40:S0j`@0Yl3/102W`N`40:NojPP0Yl7/1@2W_n/30:O0j`D0Yko[4`2W`>/Y
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool003H0oooo00<000000?oo
o`3oool09@3ooom00:O0j`@0Yl3/5@2W`>/30:O0k0D0Z;oZ202W`N`80:Noj`@0Yl3[102W_n/@0:O0
jb`0oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool003L0oooo00<000000?ooo`3o
ool09@3ooom@0:O0j`D0Yko[102X`>/40:Roj`P0Yl7/102W_nX40:Noj`@0Z<3[502W`>/`0?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`40oooo000h0?ooo`030000003oool0oooo02D0oooo
E@2W`>/40:S0j`@0Yl3/102W`N`80:NojP@0Yl7/102X`>/80:O0j`@0Yko[>03oool00`000000oooo
0?ooo`050?ooo`4000000@3oool10?ooo`00>@3oool2000002H0ooooF@2W`>/30:O0k0D0Yko[0`2W
_nX80:O1k0D0Yko[0`2W`>/50:Nojc/0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool003/0oooo00<000000?ooo`3oool0903ooomH0:O0j`@0Z;o[102W_n/80:O1k0D0Yko[102X`>/4
0:Nojcl0oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool003`0oooo00<000000?oo
o`3oool0903ooomD0:O0j`@0Z<3[102X_n/50:O1k0P0Yko[102W`N`40:S0jd<0oooo00<000000?oo
o`3oool00`3oool100000040oooo0@3oool003d0oooo00<000000?ooo`3oool0903ooomE0:O0j`<0
Z<3[1@2W`>`70:Noj`P0Yl7/B03oool00`000000oooo0?ooo`020?ooo`4000000@3oool10?ooo`00
?P3oool2000002D0ooooF02W`>/50:Roj`<0Yko[202W`Na;0?ooo`030000003oool0oooo00<0oooo
0@0000010?ooo`00@03oool00`000000oooo0?ooo`0S0?oooe@0Yl3[102X`>/40:Roj`P0Yl7/C`3o
ool00`000000oooo0?ooo`020?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3ooomD
0:O0j`@0Z<3[102W`>`40:O1k5<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3oool0
0`000000oooo0?ooo`0T0?oooeP0Yl3[0`2W`>aG0?ooo`040000003oool0oooo00000040oooo0013
0?ooo`8000009@3ooomC0:O0jeh0oooo00@000000?ooo`3oool000000@3oool004D0oooo00<00000
0?ooo`3oool08`3ooom?0:O0jf80oooo00<000000?ooo`0000000@3oool004H0oooo00<000000?oo
o`3oool08`3ooom;0:O0jfH0oooo0@0000010?ooo`40000000170?ooo`030000003oool0oooo02<0
ooooA`2W`>]Z0?ooo`80000000180?ooo`8000009@3ooom20:O0jfd0oooo0P00000004X0oooo00<0
00000?ooo`3oool08`3oooln0:O0jg00oooo0P00000004/0oooo00<000000?ooo`3oool08P3ooolk
0:O0jfl0oooo100000020?ooo`00C03oool00`000000oooo0?ooo`0S0?oooc<0Yl3[L@3oool40000
00H0oooo001=0?ooo`800000903oool_0:O0jg00oooo1000000:0?ooo`00C`3oool00`000000oooo
0?ooo`0R0?ooob/0Yl3[K`3oool4000000h0oooo001@0?ooo`030000003oool0oooo02<0oooo9P2W
`>]^0?ooo`@000004P3oool00540oooo00<000000?ooo`3oool08`3ooolR0:O0jfh0oooo0`00000F
0?ooo`00DP3oool2000002@0oooo7P2W`>]]0?ooo`@000006@3oool005@0oooo00<000000?ooo`3o
ool08P3ooolG0:O0jfl0oooo1000000M0?ooo`00E@3oool00`000000oooo0?ooo`0Q0?oooa@0Yl3[
KP3oool400000240oooo001F0?ooo`030000003oool0oooo0280oooo3`2W`>]]0?ooo`@000009@3o
ool005L0oooo0P00000S0?ooo`/0Yl3[K03oool4000002T0oooo001I0?ooo`030000003oool0oooo
0240oooo102W`>]_0?ooo`<00000;@3oool005X0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`1Z0?ooo`@00000<03oool005/0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`1V0?ooo`@00000=03oool005`0oooo0P00000Q0?ooo`030000003oool0oooo0680oooo1000
000h0?ooo`00GP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo1000000l
0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo100000100?oo
o`00H03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo0`0000140?ooo`00
H@3oool2000001`0oooo00<000000?ooo`3oool0D`3oool4000004L0oooo001S0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0C`3oool4000004/0oooo001T0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0B`3oool4000004l0oooo001U0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0A`3oool4000005<0oooo001V0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0@`3oool4000005L0oooo001W0?ooo`8000005P3oool00`000000oooo
0?ooo`100?ooo`<00000F`3oool006T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0l0?ooo`@00000GP3oool006X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0h
0?ooo`@00000HP3oool006/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?oo
o`@00000IP3oool006`0oooo0P00000@0?ooo`030000003oool0oooo0340oooo1000001Z0?ooo`00
KP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo1000001^0?ooo`00K`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo0`00001b0?ooo`00L03oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo1000001e0?ooo`00L@3oool20000
00/0oooo00<000000?ooo`3oool08P3oool4000007T0oooo001c0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool07P3oool4000007d0oooo001d0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool06P3oool400000840oooo001e0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05P3oool4000008D0oooo001f0?ooo`8000001P3oool00`000000oooo0?ooo`0C
0?ooo`<00000R@3oool007P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?oo
o`@00000S03oool007T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@0
0000T03oool007X0oooo00D000000?ooo`3oool0oooo000000090?ooo`@00000U03oool007/0oooo
0P0000000`3oool000000?ooo`040?ooo`@00000V03oool007d0oooo0P0000000`3oool000000000
0002000009`0oooo001n0?ooo`800000X03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Mtetra
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Mtetra
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Mtetra
.655 .751 .92 r
.59604 .63937 .60194 .6454 .6135 .64212 .60764 .63609 Mtetra
.655 .752 .921 r
.60764 .63609 .6135 .64212 .62511 .63884 .61928 .6328 Mtetra
.656 .753 .921 r
.61928 .6328 .62511 .63884 .63677 .63556 .63098 .62948 Mtetra
.63098 .62948 .63677 .63556 .64848 .63228 .64272 .62614 Mtetra
.656 .751 .92 r
.64272 .62614 .64848 .63228 .66024 .62898 .65451 .62278 Mtetra
.656 .75 .919 r
.65451 .62278 .66024 .62898 .67204 .62566 .66635 .61942 Mtetra
.656 .749 .919 r
.66635 .61942 .67204 .62566 .6839 .62232 .67824 .61605 Mtetra
.655 .749 .919 r
.67824 .61605 .6839 .62232 .6958 .61894 .69018 .61268 Mtetra
.655 .75 .92 r
.69018 .61268 .6958 .61894 .70776 .61555 .70217 .6093 Mtetra
.655 .752 .921 r
.70217 .6093 .70776 .61555 .71976 .61216 .71421 .6059 Mtetra
.656 .752 .921 r
.71421 .6059 .71976 .61216 .73182 .60878 .7263 .60248 Mtetra
.656 .752 .92 r
.7263 .60248 .73182 .60878 .74393 .60537 .73845 .59902 Mtetra
.656 .751 .92 r
.73845 .59902 .74393 .60537 .75609 .60194 .75064 .59556 Mtetra
.75064 .59556 .75609 .60194 .7683 .59849 .76289 .59209 Mtetra
.76289 .59209 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Mtetra
.656 .752 .92 r
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.656 .751 .92 r
.59011 .63329 .59604 .63937 .60764 .63609 .60173 .62997 Mtetra
.60173 .62997 .60764 .63609 .61928 .6328 .61341 .62664 Mtetra
.656 .75 .919 r
.61341 .62664 .61928 .6328 .63098 .62948 .62513 .6233 Mtetra
.655 .75 .92 r
.62513 .6233 .63098 .62948 .64272 .62614 .63691 .61997 Mtetra
.655 .751 .921 r
.63691 .61997 .64272 .62614 .65451 .62278 .64873 .61662 Mtetra
.655 .753 .922 r
.64873 .61662 .65451 .62278 .66635 .61942 .66061 .61325 Mtetra
.656 .754 .922 r
.66061 .61325 .66635 .61942 .67824 .61605 .67253 .60986 Mtetra
.67253 .60986 .67824 .61605 .69018 .61268 .68451 .60643 Mtetra
.656 .753 .921 r
.68451 .60643 .69018 .61268 .70217 .6093 .69653 .60299 Mtetra
.656 .751 .92 r
.69653 .60299 .70217 .6093 .71421 .6059 .70861 .59954 Mtetra
.70861 .59954 .71421 .6059 .7263 .60248 .72074 .59609 Mtetra
.656 .75 .92 r
.72074 .59609 .7263 .60248 .73845 .59902 .73292 .59263 Mtetra
.656 .751 .92 r
.73292 .59263 .73845 .59902 .75064 .59556 .74515 .58915 Mtetra
.656 .752 .921 r
.74515 .58915 .75064 .59556 .76289 .59209 .75744 .58565 Mtetra
.75744 .58565 .76289 .59209 .77519 .58861 .76977 .58214 Mtetra
.656 .751 .92 r
.76977 .58214 .77519 .58861 .78754 .58511 .78217 .57861 Mtetra
.78217 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54248 Mtetra
.90908 .54248 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94825 .53132 Mtetra
.94825 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Mtetra
.655 .751 .92 r
.58412 .62717 .59011 .63329 .60173 .62997 .59578 .62384 Mtetra
.655 .752 .921 r
.59578 .62384 .60173 .62997 .61341 .62664 .60749 .6205 Mtetra
.656 .753 .921 r
.60749 .6205 .61341 .62664 .62513 .6233 .61925 .61713 Mtetra
.61925 .61713 .62513 .6233 .63691 .61997 .63106 .61374 Mtetra
.657 .751 .92 r
.63106 .61374 .63691 .61997 .64873 .61662 .64292 .61032 Mtetra
.656 .75 .919 r
.64292 .61032 .64873 .61662 .66061 .61325 .65482 .6069 Mtetra
.656 .749 .918 r
.65482 .6069 .66061 .61325 .67253 .60986 .66678 .60348 Mtetra
.655 .749 .919 r
.66678 .60348 .67253 .60986 .68451 .60643 .67879 .60006 Mtetra
.655 .75 .92 r
.67879 .60006 .68451 .60643 .69653 .60299 .69085 .59663 Mtetra
.655 .751 .92 r
.69085 .59663 .69653 .60299 .70861 .59954 .70297 .59318 Mtetra
.656 .752 .921 r
.70297 .59318 .70861 .59954 .72074 .59609 .71513 .5897 Mtetra
.71513 .5897 .72074 .59609 .73292 .59263 .72735 .58619 Mtetra
.656 .752 .92 r
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Mtetra
.656 .751 .92 r
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.76431 .57561 .76977 .58214 .78217 .57861 .77674 .57206 Mtetra
.77674 .57206 .78217 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .5613 Mtetra
.81435 .5613 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54248 .90406 .53563 Mtetra
.90406 .53563 .90908 .54248 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94825 .53132 .94336 .52438 Mtetra
.94336 .52438 .94825 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.656 .752 .92 r
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Mtetra
.656 .751 .92 r
.57809 .621 .58412 .62717 .59578 .62384 .58979 .61763 Mtetra
.58979 .61763 .59578 .62384 .60749 .6205 .60153 .61424 Mtetra
.656 .75 .919 r
.60153 .61424 .60749 .6205 .61925 .61713 .61332 .61085 Mtetra
.655 .75 .92 r
.61332 .61085 .61925 .61713 .63106 .61374 .62516 .60747 Mtetra
.655 .751 .921 r
.62516 .60747 .63106 .61374 .64292 .61032 .63705 .60407 Mtetra
.655 .753 .922 r
.63705 .60407 .64292 .61032 .65482 .6069 .649 .60065 Mtetra
.656 .754 .922 r
.649 .60065 .65482 .6069 .66678 .60348 .66099 .5972 Mtetra
.66099 .5972 .66678 .60348 .67879 .60006 .67303 .59372 Mtetra
.656 .753 .921 r
.67303 .59372 .67879 .60006 .69085 .59663 .68513 .59022 Mtetra
.656 .752 .92 r
.68513 .59022 .69085 .59663 .70297 .59318 .69728 .58671 Mtetra
.656 .751 .92 r
.69728 .58671 .70297 .59318 .71513 .5897 .70948 .5832 Mtetra
.655 .75 .92 r
.70948 .5832 .71513 .5897 .72735 .58619 .72173 .57969 Mtetra
.656 .751 .92 r
.72173 .57969 .72735 .58619 .73962 .58268 .73404 .57616 Mtetra
.656 .752 .92 r
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .57261 Mtetra
.7464 .57261 .75194 .57915 .76431 .57561 .75881 .56904 Mtetra
.656 .751 .92 r
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .5613 .809 .5546 Mtetra
.809 .5546 .81435 .5613 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Mtetra
.655 .751 .92 r
.57202 .61478 .57809 .621 .58979 .61763 .58374 .6114 Mtetra
.655 .752 .921 r
.58374 .6114 .58979 .61763 .60153 .61424 .59552 .60801 Mtetra
.656 .753 .921 r
.59552 .60801 .60153 .61424 .61332 .61085 .60734 .60459 Mtetra
.60734 .60459 .61332 .61085 .62516 .60747 .61922 .60114 Mtetra
.657 .752 .92 r
.61922 .60114 .62516 .60747 .63705 .60407 .63114 .59766 Mtetra
.657 .75 .919 r
.63114 .59766 .63705 .60407 .649 .60065 .64312 .59418 Mtetra
.656 .749 .918 r
.64312 .59418 .649 .60065 .66099 .5972 .65515 .59071 Mtetra
.655 .748 .918 r
.65515 .59071 .66099 .5972 .67303 .59372 .66723 .58724 Mtetra
.655 .749 .919 r
.66723 .58724 .67303 .59372 .68513 .59022 .67936 .58376 Mtetra
.655 .751 .92 r
.67936 .58376 .68513 .59022 .69728 .58671 .69154 .58026 Mtetra
.656 .752 .921 r
.69154 .58026 .69728 .58671 .70948 .5832 .70378 .57672 Mtetra
.656 .753 .921 r
.70378 .57672 .70948 .5832 .72173 .57969 .71607 .57316 Mtetra
.656 .752 .92 r
.71607 .57316 .72173 .57969 .73404 .57616 .72841 .56958 Mtetra
.656 .751 .92 r
.72841 .56958 .73404 .57616 .7464 .57261 .74081 .566 Mtetra
.74081 .566 .7464 .57261 .75881 .56904 .75326 .5624 Mtetra
.75326 .5624 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61192 Mtetra
.656 .752 .92 r
.55418 .61192 .56034 .61815 .57202 .61478 .56589 .60851 Mtetra
.56589 .60851 .57202 .61478 .58374 .6114 .57765 .60509 Mtetra
.656 .751 .919 r
.57765 .60509 .58374 .6114 .59552 .60801 .58946 .60164 Mtetra
.656 .75 .919 r
.58946 .60164 .59552 .60801 .60734 .60459 .60132 .5982 Mtetra
.655 .75 .919 r
.60132 .5982 .60734 .60459 .61922 .60114 .61323 .59477 Mtetra
.655 .751 .921 r
.61323 .59477 .61922 .60114 .63114 .59766 .62519 .59133 Mtetra
.655 .753 .922 r
.62519 .59133 .63114 .59766 .64312 .59418 .6372 .58786 Mtetra
.655 .755 .923 r
.6372 .58786 .64312 .59418 .65515 .59071 .64926 .58436 Mtetra
.656 .755 .923 r
.64926 .58436 .65515 .59071 .66723 .58724 .66138 .58082 Mtetra
.657 .754 .921 r
.66138 .58082 .66723 .58724 .67936 .58376 .67354 .57725 Mtetra
.657 .752 .92 r
.67354 .57725 .67936 .58376 .69154 .58026 .68576 .57368 Mtetra
.656 .75 .919 r
.68576 .57368 .69154 .58026 .70378 .57672 .69804 .57011 Mtetra
.655 .75 .919 r
.69804 .57011 .70378 .57672 .71607 .57316 .71036 .56655 Mtetra
.655 .751 .92 r
.71036 .56655 .71607 .57316 .72841 .56958 .72274 .56296 Mtetra
.656 .752 .92 r
.72274 .56296 .72841 .56958 .74081 .566 .73518 .55935 Mtetra
.73518 .55935 .74081 .566 .75326 .5624 .74767 .55572 Mtetra
.656 .751 .92 r
.74767 .55572 .75326 .5624 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61192 .54798 .60562 Mtetra
.54798 .60562 .55418 .61192 .56589 .60851 .55972 .6022 Mtetra
.655 .751 .92 r
.55972 .6022 .56589 .60851 .57765 .60509 .57151 .59877 Mtetra
.655 .752 .921 r
.57151 .59877 .57765 .60509 .58946 .60164 .58335 .59534 Mtetra
.656 .754 .922 r
.58335 .59534 .58946 .60164 .60132 .5982 .59525 .59187 Mtetra
.657 .754 .921 r
.59525 .59187 .60132 .5982 .61323 .59477 .60719 .58835 Mtetra
.657 .752 .92 r
.60719 .58835 .61323 .59477 .62519 .59133 .61918 .58481 Mtetra
.657 .75 .918 r
.61918 .58481 .62519 .59133 .6372 .58786 .63123 .58127 Mtetra
.656 .748 .918 r
.63123 .58127 .6372 .58786 .64926 .58436 .64333 .57774 Mtetra
.655 .748 .918 r
.64333 .57774 .64926 .58436 .66138 .58082 .65548 .57422 Mtetra
.655 .749 .919 r
.65548 .57422 .66138 .58082 .67354 .57725 .66768 .57069 Mtetra
.655 .751 .921 r
.66768 .57069 .67354 .57725 .68576 .57368 .67994 .56714 Mtetra
.656 .753 .922 r
.67994 .56714 .68576 .57368 .69804 .57011 .69225 .56355 Mtetra
.656 .754 .922 r
.69225 .56355 .69804 .57011 .71036 .56655 .70461 .55992 Mtetra
.656 .752 .921 r
.70461 .55992 .71036 .56655 .72274 .56296 .71703 .55628 Mtetra
.656 .751 .92 r
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Mtetra
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Mtetra
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Mtetra
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Mtetra
.53 .60273 .53629 .60904 .54798 .60562 .54172 .59929 Mtetra
.656 .752 .921 r
.54172 .59929 .54798 .60562 .55972 .6022 .5535 .59585 Mtetra
.5535 .59585 .55972 .6022 .57151 .59877 .56532 .59238 Mtetra
.655 .751 .921 r
.56532 .59238 .57151 .59877 .58335 .59534 .5772 .58892 Mtetra
.653 .751 .921 r
.5772 .58892 .58335 .59534 .59525 .59187 .58913 .58549 Mtetra
.651 .752 .924 r
.58913 .58549 .59525 .59187 .60719 .58835 .60111 .5821 Mtetra
.651 .757 .927 r
.60111 .5821 .60719 .58835 .61918 .58481 .61314 .5787 Mtetra
.652 .763 .931 r
.61314 .5787 .61918 .58481 .63123 .58127 .62523 .57524 Mtetra
.654 .767 .932 r
.62523 .57524 .63123 .58127 .64333 .57774 .63736 .57168 Mtetra
.657 .768 .931 r
.63736 .57168 .64333 .57774 .65548 .57422 .64955 .56802 Mtetra
.659 .765 .928 r
.64955 .56802 .65548 .57422 .66768 .57069 .66178 .56431 Mtetra
.659 .76 .924 r
.66178 .56431 .66768 .57069 .67994 .56714 .67407 .56058 Mtetra
.658 .755 .921 r
.67407 .56058 .67994 .56714 .69225 .56355 .68641 .55688 Mtetra
.656 .752 .92 r
.68641 .55688 .69225 .56355 .70461 .55992 .69881 .55322 Mtetra
.69881 .55322 .70461 .55992 .71703 .55628 .71127 .54956 Mtetra
.656 .752 .921 r
.71127 .54956 .71703 .55628 .7295 .55264 .72378 .54589 Mtetra
.656 .752 .92 r
.72378 .54589 .7295 .55264 .74203 .54898 .73634 .54219 Mtetra
.656 .751 .92 r
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62358 Mtetra
.43138 .62358 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61009 Mtetra
.47713 .61009 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Mtetra
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Mtetra
.655 .751 .921 r
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59639 Mtetra
.654 .751 .921 r
.52366 .59639 .53 .60273 .54172 .59929 .53542 .59297 Mtetra
.65 .752 .924 r
.53542 .59297 .54172 .59929 .5535 .59585 .54723 .58964 Mtetra
.644 .754 .929 r
.54723 .58964 .5535 .59585 .56532 .59238 .55909 .58646 Mtetra
.635 .762 .939 r
.55909 .58646 .56532 .59238 .5772 .58892 .57101 .58345 Mtetra
.627 .776 .953 r
.57101 .58345 .5772 .58892 .58913 .58549 .58298 .58053 Mtetra
.621 .794 .965 r
.58298 .58053 .58913 .58549 .60111 .5821 .59501 .57759 Mtetra
.619 .811 .974 r
.59501 .57759 .60111 .5821 .61314 .5787 .6071 .57451 Mtetra
.623 .826 .979 r
.6071 .57451 .61314 .5787 .62523 .57524 .61923 .57121 Mtetra
.632 .836 .979 r
.61923 .57121 .62523 .57524 .63736 .57168 .63141 .56763 Mtetra
.645 .84 .975 r
.63141 .56763 .63736 .57168 .64955 .56802 .64364 .56376 Mtetra
.657 .836 .969 r
.64364 .56376 .64955 .56802 .66178 .56431 .6559 .55966 Mtetra
.667 .825 .96 r
.6559 .55966 .66178 .56431 .67407 .56058 .66822 .55542 Mtetra
.671 .809 .949 r
.66822 .55542 .67407 .56058 .68641 .55688 .68058 .55116 Mtetra
.67 .79 .938 r
.68058 .55116 .68641 .55688 .69881 .55322 .69299 .54699 Mtetra
.665 .771 .929 r
.69299 .54699 .69881 .55322 .71127 .54956 .70547 .54298 Mtetra
.66 .76 .924 r
.70547 .54298 .71127 .54956 .72378 .54589 .71801 .53913 Mtetra
.657 .754 .921 r
.71801 .53913 .72378 .54589 .73634 .54219 .73061 .53536 Mtetra
.656 .752 .921 r
.73061 .53536 .73634 .54219 .74896 .53849 .74327 .53161 Mtetra
.656 .752 .92 r
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Mtetra
.656 .751 .92 r
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Mtetra
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62358 .42475 .61738 Mtetra
.42475 .61738 .43138 .62358 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61009 .47062 .60378 Mtetra
.47062 .60378 .47713 .61009 .48869 .60668 .48221 .60035 Mtetra
.655 .751 .92 r
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .59691 Mtetra
.654 .751 .921 r
.49385 .59691 .5003 .60325 .51196 .59982 .50554 .5935 Mtetra
.649 .751 .924 r
.50554 .5935 .51196 .59982 .52366 .59639 .51728 .59021 Mtetra
.636 .753 .933 r
.51728 .59021 .52366 .59639 .53542 .59297 .52907 .58722 Mtetra
.612 .761 .95 r
.52907 .58722 .53542 .59297 .54723 .58964 .54092 .58473 Mtetra
.569 .778 .977 r
.54092 .58473 .54723 .58964 .55909 .58646 .55283 .5828 Mtetra
.5 .801 .999 r
.55283 .5828 .55909 .58646 .57101 .58345 .56481 .58129 Mtetra
.396 .807 .978 r
.56481 .58129 .57101 .58345 .58298 .58053 .57685 .57987 Mtetra
.278 .774 .887 r
.57685 .57987 .58298 .58053 .59501 .57759 .58896 .57817 Mtetra
.193 .724 .769 r
.58896 .57817 .59501 .57759 .6071 .57451 .60113 .57592 Mtetra
.167 .698 .69 r
.60113 .57592 .6071 .57451 .61923 .57121 .61333 .573 Mtetra
0 0 0 r
.61333 .573 .61923 .57121 .63141 .56763 .62558 .5694 Mtetra
.265 .761 .703 r
.62558 .5694 .63141 .56763 .64364 .56376 .63786 .56511 Mtetra
.379 .839 .779 r
.63786 .56511 .64364 .56376 .6559 .55966 .65016 .56015 Mtetra
.517 .916 .875 r
.65016 .56015 .6559 .55966 .66822 .55542 .66249 .55461 Mtetra
.633 .947 .948 r
.66249 .55461 .66822 .55542 .68058 .55116 .67484 .54879 Mtetra
.689 .92 .971 r
.67484 .54879 .68058 .55116 .69299 .54699 .68724 .54305 Mtetra
.698 .866 .962 r
.68724 .54305 .69299 .54699 .70547 .54298 .6997 .53772 Mtetra
.685 .814 .944 r
.6997 .53772 .70547 .54298 .71801 .53913 .71223 .53296 Mtetra
.671 .779 .931 r
.71223 .53296 .71801 .53913 .73061 .53536 .72485 .5287 Mtetra
.661 .761 .924 r
.72485 .5287 .73061 .53536 .74327 .53161 .73754 .52474 Mtetra
.657 .754 .921 r
.73754 .52474 .74327 .53161 .75599 .52786 .75029 .52091 Mtetra
.656 .752 .92 r
.75029 .52091 .75599 .52786 .76876 .52409 .7631 .5171 Mtetra
.656 .751 .92 r
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Mtetra
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Mtetra
.655 .751 .921 r
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59399 Mtetra
.652 .751 .922 r
.47568 .59399 .48221 .60035 .49385 .59691 .48735 .59061 Mtetra
.641 .751 .928 r
.48735 .59061 .49385 .59691 .50554 .5935 .49907 .58752 Mtetra
.611 .752 .945 r
.49907 .58752 .50554 .5935 .51728 .59021 .51083 .5851 Mtetra
.539 .759 .978 r
.51083 .5851 .51728 .59021 .52907 .58722 .52266 .58378 Mtetra
.38 .754 .991 r
.52266 .58378 .52907 .58722 .54092 .58473 .53456 .58355 Mtetra
.124 .663 .847 r
.53456 .58355 .54092 .58473 .55283 .5828 .54653 .58367 Mtetra
.027 0 0 r
.54653 .58367 .55283 .5828 .56481 .58129 .55858 .58307 Mtetra
0 0 0 r
.55858 .58307 .56481 .58129 .57685 .57987 .57068 .58105 Mtetra
.246 .757 .75 r
.57068 .58105 .57685 .57987 .58896 .57817 .58282 .57773 Mtetra
.483 .891 .93 r
.58282 .57773 .58896 .57817 .60113 .57592 .595 .57377 Mtetra
.593 .895 .988 r
.595 .57377 .60113 .57592 .61333 .573 .60724 .5698 Mtetra
.609 .864 .991 r
.60724 .5698 .61333 .573 .62558 .5694 .61953 .56617 Mtetra
.588 .857 .994 r
.61953 .56617 .62558 .5694 .63786 .56511 .63189 .5629 Mtetra
.541 .876 .99 r
.63189 .5629 .63786 .56511 .65016 .56015 .64431 .55962 Mtetra
.471 .886 .927 r
.64431 .55962 .65016 .56015 .66249 .55461 .65677 .55567 Mtetra
.429 .87 .813 r
.65677 .55567 .66249 .55461 .67484 .54879 .66922 .55042 Mtetra
.491 .897 .783 r
.66922 .55042 .67484 .54879 .68724 .54305 .68164 .54371 Mtetra
.63 .963 .869 r
.68164 .54371 .68724 .54305 .6997 .53772 .69407 .53625 Mtetra
.72 .957 .947 r
.69407 .53625 .6997 .53772 .71223 .53296 .70654 .52914 Mtetra
.719 .879 .956 r
.70654 .52914 .71223 .53296 .72485 .5287 .7191 .52312 Mtetra
.689 .808 .939 r
.7191 .52312 .72485 .5287 .73754 .52474 .73178 .51821 Mtetra
.668 .77 .927 r
.73178 .51821 .73754 .52474 .75029 .52091 .74455 .514 Mtetra
.659 .756 .922 r
.74455 .514 .75029 .52091 .7631 .5171 .7574 .51006 Mtetra
.656 .752 .921 r
.7574 .51006 .7631 .5171 .77597 .51328 .77031 .5062 Mtetra
.656 .752 .92 r
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Mtetra
.656 .751 .92 r
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Mtetra
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Mtetra
.655 .751 .921 r
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59105 Mtetra
.651 .751 .923 r
.45744 .59105 .46405 .59743 .47568 .59399 .46909 .58769 Mtetra
.635 .749 .931 r
.46909 .58769 .47568 .59399 .48735 .59061 .48078 .58474 Mtetra
.583 .748 .955 r
.48078 .58474 .48735 .59061 .49907 .58752 .49253 .58288 Mtetra
.44 .737 .99 r
.49253 .58288 .49907 .58752 .51083 .5851 .50432 .58274 Mtetra
.13 .641 .896 r
.50432 .58274 .51083 .5851 .52266 .58378 .51618 .58388 Mtetra
.073 0 0 r
.51618 .58388 .52266 .58378 .53456 .58355 .52813 .5844 Mtetra
.15 .691 .731 r
.52813 .5844 .53456 .58355 .54653 .58367 .54015 .58234 Mtetra
.622 .925 .972 r
.54015 .58234 .54653 .58367 .55858 .58307 .55221 .57746 Mtetra
.735 .804 .907 r
.55221 .57746 .55858 .58307 .57068 .58105 .56429 .5712 Mtetra
.707 .689 .831 r
.56429 .5712 .57068 .58105 .58282 .57773 .57641 .56509 Mtetra
.676 .631 .797 r
.57641 .56509 .58282 .57773 .595 .57377 .58859 .55983 Mtetra
.655 .605 .786 r
.58859 .55983 .595 .57377 .60724 .5698 .60082 .55543 Mtetra
.64 .593 .785 r
.60082 .55543 .60724 .5698 .61953 .56617 .61313 .55178 Mtetra
.626 .585 .789 r
.61313 .55178 .61953 .56617 .63189 .5629 .62551 .54886 Mtetra
.609 .582 .798 r
.62551 .54886 .63189 .5629 .64431 .55962 .63798 .54683 Mtetra
.59 .59 .821 r
.63798 .54683 .64431 .55962 .65677 .55567 .65055 .54563 Mtetra
.578 .636 .873 r
.65055 .54563 .65677 .55567 .66922 .55042 .66321 .54459 Mtetra
.596 .767 .961 r
.66321 .54459 .66922 .55042 .68164 .54371 .67587 .54216 Mtetra
.627 .931 .969 r
.67587 .54216 .68164 .54371 .69407 .53625 .68847 .53687 Mtetra
.656 .971 .869 r
.68847 .53687 .69407 .53625 .70654 .52914 .70097 .52893 Mtetra
.733 .985 .9 r
.70097 .52893 .70654 .52914 .7191 .52312 .71347 .52035 Mtetra
.75 .924 .948 r
.71347 .52035 .7191 .52312 .73178 .51821 .72606 .51306 Mtetra
.706 .831 .942 r
.72606 .51306 .73178 .51821 .74455 .514 .73879 .50752 Mtetra
.673 .777 .928 r
.73879 .50752 .74455 .514 .7574 .51006 .75165 .50308 Mtetra
.66 .757 .922 r
.75165 .50308 .7574 .51006 .77031 .5062 .76459 .49907 Mtetra
.656 .752 .921 r
.76459 .49907 .77031 .5062 .78327 .50233 .7776 .49516 Mtetra
.656 .751 .92 r
.7776 .49516 .78327 .50233 .7963 .49845 .79067 .49124 Mtetra
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Mtetra
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Mtetra
.655 .751 .92 r
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58809 Mtetra
.652 .751 .922 r
.43913 .58809 .44583 .5945 .45744 .59105 .45076 .5847 Mtetra
.635 .749 .93 r
.45076 .5847 .45744 .59105 .46909 .58769 .46244 .58174 Mtetra
.573 .742 .956 r
.46244 .58174 .46909 .58769 .48078 .58474 .47415 .58008 Mtetra
.379 .708 .986 r
.47415 .58008 .48078 .58474 .49253 .58288 .4859 .58066 Mtetra
0 .544 .818 r
.4859 .58066 .49253 .58288 .50432 .58274 .49771 .58278 Mtetra
.076 0 0 r
.49771 .58278 .50432 .58274 .51618 .58388 .50963 .58337 Mtetra
.466 .88 .935 r
.50963 .58337 .51618 .58388 .52813 .5844 .52163 .5798 Mtetra
.755 .839 .915 r
.52163 .5798 .52813 .5844 .54015 .58234 .53367 .5729 Mtetra
.732 .705 .826 r
.53367 .5729 .54015 .58234 .55221 .57746 .54574 .56556 Mtetra
.693 .649 .802 r
.54574 .56556 .55221 .57746 .56429 .5712 .55785 .55953 Mtetra
.671 .644 .815 r
.55785 .55953 .56429 .5712 .57641 .56509 .57001 .55477 Mtetra
.662 .665 .842 r
.57001 .55477 .57641 .56509 .58859 .55983 .58223 .55067 Mtetra
.658 .688 .867 r
.58223 .55067 .58859 .55983 .60082 .55543 .59451 .54684 Mtetra
.655 .702 .881 r
.59451 .54684 .60082 .55543 .61313 .55178 .60685 .54316 Mtetra
.651 .7 .882 r
.60685 .54316 .61313 .55178 .62551 .54886 .61924 .53961 Mtetra
.642 .682 .872 r
.61924 .53961 .62551 .54886 .63798 .54683 .6317 .53634 Mtetra
.623 .648 .854 r
.6317 .53634 .63798 .54683 .65055 .54563 .64424 .53374 Mtetra
.59 .607 .837 r
.64424 .53374 .65055 .54563 .66321 .54459 .6569 .53242 Mtetra
.555 .585 .839 r
.6569 .53242 .66321 .54459 .67587 .54216 .66969 .53242 Mtetra
.555 .635 .885 r
.66969 .53242 .67587 .54216 .68847 .53687 .68254 .53197 Mtetra
.641 .82 .969 r
.68254 .53197 .68847 .53687 .70097 .52893 .69531 .52813 Mtetra
.733 .976 .923 r
.69531 .52813 .70097 .52893 .71347 .52035 .7079 .52003 Mtetra
.777 .99 .889 r
.7079 .52003 .71347 .52035 .72606 .51306 .72043 .51037 Mtetra
.773 .932 .936 r
.72043 .51037 .72606 .51306 .73879 .50752 .73307 .50227 Mtetra
.713 .832 .938 r
.73307 .50227 .73879 .50752 .75165 .50308 .74589 .49646 Mtetra
.673 .775 .927 r
.74589 .49646 .75165 .50308 .76459 .49907 .75884 .49197 Mtetra
.659 .756 .922 r
.75884 .49197 .76459 .49907 .7776 .49516 .77188 .48793 Mtetra
.656 .752 .92 r
.77188 .48793 .7776 .49516 .79067 .49124 .785 .48397 Mtetra
.656 .751 .92 r
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Mtetra
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58512 Mtetra
.654 .751 .921 r
.42076 .58512 .42755 .59156 .43913 .58809 .43237 .58166 Mtetra
.642 .749 .927 r
.43237 .58166 .43913 .58809 .45076 .5847 .44403 .57852 Mtetra
.589 .741 .948 r
.44403 .57852 .45076 .5847 .46244 .58174 .45572 .57657 Mtetra
.401 .7 .982 r
.45572 .57657 .46244 .58174 .47415 .58008 .46742 .57717 Mtetra
0 .502 .819 r
.46742 .57717 .47415 .58008 .4859 .58066 .47918 .58015 Mtetra
.148 0 0 r
.47918 .58015 .4859 .58066 .49771 .58278 .49104 .58185 Mtetra
.497 .887 .958 r
.49104 .58185 .49771 .58278 .50963 .58337 .50303 .57832 Mtetra
.776 .825 .891 r
.50303 .57832 .50963 .58337 .52163 .5798 .51508 .57043 Mtetra
.747 .711 .818 r
.51508 .57043 .52163 .5798 .53367 .5729 .52715 .56217 Mtetra
.71 .675 .814 r
.52715 .56217 .53367 .5729 .54574 .56556 .53925 .55558 Mtetra
.689 .682 .838 r
.53925 .55558 .54574 .56556 .55785 .55953 .5514 .55032 Mtetra
.678 .694 .858 r
.5514 .55032 .55785 .55953 .57001 .55477 .56359 .54571 Mtetra
.669 .695 .866 r
.56359 .54571 .57001 .55477 .58223 .55067 .57584 .54146 Mtetra
.661 .69 .866 r
.57584 .54146 .58223 .55067 .59451 .54684 .58814 .5375 Mtetra
.654 .685 .867 r
.58814 .5375 .59451 .54684 .60685 .54316 .6005 .53379 Mtetra
.647 .682 .869 r
.6005 .53379 .60685 .54316 .61924 .53961 .61292 .53032 Mtetra
.639 .681 .874 r
.61292 .53032 .61924 .53961 .6317 .53634 .62541 .52714 Mtetra
.628 .68 .88 r
.62541 .52714 .6317 .53634 .64424 .53374 .63798 .52433 Mtetra
.609 .667 .881 r
.63798 .52433 .64424 .53374 .6569 .53242 .65063 .52216 Mtetra
.569 .631 .873 r
.65063 .52216 .6569 .53242 .66969 .53242 .66341 .52135 Mtetra
.519 .589 .865 r
.66341 .52135 .66969 .53242 .68254 .53197 .67634 .52222 Mtetra
.519 .62 .891 r
.67634 .52222 .68254 .53197 .69531 .52813 .68935 .52271 Mtetra
.649 .806 .959 r
.68935 .52271 .69531 .52813 .7079 .52003 .70222 .51876 Mtetra
.789 .973 .913 r
.70222 .51876 .7079 .52003 .72043 .51037 .71484 .50945 Mtetra
.82 .982 .886 r
.71484 .50945 .72043 .51037 .73307 .50227 .7274 .49882 Mtetra
.779 .909 .93 r
.7274 .49882 .73307 .50227 .74589 .49646 .74012 .49062 Mtetra
.705 .813 .932 r
.74012 .49062 .74589 .49646 .75884 .49197 .75305 .48504 Mtetra
.668 .766 .924 r
.75305 .48504 .75884 .49197 .77188 .48793 .76612 .48068 Mtetra
.658 .754 .921 r
.76612 .48068 .77188 .48793 .785 .48397 .77927 .47664 Mtetra
.656 .752 .92 r
.77927 .47664 .785 .48397 .79817 .48 .79248 .47264 Mtetra
.656 .751 .92 r
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Mtetra
.655 .751 .921 r
.40232 .58214 .40919 .58861 .42076 .58512 .41392 .57863 Mtetra
.649 .75 .923 r
.41392 .57863 .42076 .58512 .43237 .58166 .42556 .57527 Mtetra
.618 .744 .936 r
.42556 .57527 .43237 .58166 .44403 .57852 .43724 .57268 Mtetra
.487 .715 .972 r
.43724 .57268 .44403 .57852 .45572 .57657 .44892 .57242 Mtetra
.054 .535 .89 r
.44892 .57242 .45572 .57657 .46742 .57717 .4606 .57563 Mtetra
.293 0 0 r
.4606 .57563 .46742 .57717 .47918 .58015 .47238 .57955 Mtetra
.232 .745 .866 r
.47238 .57955 .47918 .58015 .49104 .58185 .48432 .57821 Mtetra
.787 .872 .91 r
.48432 .57821 .49104 .58185 .50303 .57832 .49639 .5701 Mtetra
.784 .744 .816 r
.49639 .5701 .50303 .57832 .51508 .57043 .50849 .55996 Mtetra
.737 .69 .806 r
.50849 .55996 .51508 .57043 .52715 .56217 .5206 .55178 Mtetra
.699 .678 .827 r
.5206 .55178 .52715 .56217 .53925 .55558 .53273 .5459 Mtetra
.674 .684 .851 r
.53273 .5459 .53925 .55558 .5514 .55032 .5449 .54134 Mtetra
.661 .695 .871 r
.5449 .54134 .5514 .55032 .56359 .54571 .55713 .53739 Mtetra
.657 .711 .887 r
.55713 .53739 .56359 .54571 .57584 .54146 .56942 .53363 Mtetra
.656 .724 .899 r
.56942 .53363 .57584 .54146 .58814 .5375 .58176 .5299 Mtetra
.656 .731 .905 r
.58176 .5299 .58814 .5375 .6005 .53379 .59415 .52616 Mtetra
.59415 .52616 .6005 .53379 .61292 .53032 .6066 .5224 Mtetra
.654 .724 .9 r
.6066 .5224 .61292 .53032 .62541 .52714 .61911 .51866 Mtetra
.648 .707 .891 r
.61911 .51866 .62541 .52714 .63798 .52433 .63168 .51514 Mtetra
.63 .683 .882 r
.63168 .51514 .63798 .52433 .65063 .52216 .64434 .51221 Mtetra
.591 .649 .876 r
.64434 .51221 .65063 .52216 .66341 .52135 .65711 .51063 Mtetra
.519 .598 .873 r
.65711 .51063 .66341 .52135 .67634 .52222 .67005 .51136 Mtetra
.446 .557 .874 r
.67005 .51136 .67634 .52222 .68935 .52271 .68319 .51408 Mtetra
.495 .639 .919 r
.68319 .51408 .68935 .52271 .70222 .51876 .69633 .51472 Mtetra
.721 .879 .954 r
.69633 .51472 .70222 .51876 .71484 .50945 .70918 .50845 Mtetra
.846 .978 .871 r
.70918 .50845 .71484 .50945 .7274 .49882 .72176 .49678 Mtetra
.84 .955 .889 r
.72176 .49678 .7274 .49882 .74012 .49062 .73438 .48584 Mtetra
.756 .863 .927 r
.73438 .48584 .74012 .49062 .75305 .48504 .74725 .47845 Mtetra
.686 .785 .926 r
.74725 .47845 .75305 .48504 .76612 .48068 .76031 .47346 Mtetra
.661 .758 .922 r
.76031 .47346 .76612 .48068 .77927 .47664 .7735 .46926 Mtetra
.656 .752 .92 r
.7735 .46926 .77927 .47664 .79248 .47264 .78675 .46521 Mtetra
.656 .751 .92 r
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Mtetra
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Mtetra
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57562 Mtetra
.654 .751 .921 r
.39539 .57562 .40232 .58214 .41392 .57863 .40702 .57211 Mtetra
.642 .748 .926 r
.40702 .57211 .41392 .57863 .42556 .57527 .41869 .56893 Mtetra
.577 .734 .95 r
.41869 .56893 .42556 .57527 .43724 .57268 .43037 .56722 Mtetra
.296 .638 .966 r
.43037 .56722 .43724 .57268 .44892 .57242 .44203 .56913 Mtetra
.306 0 0 r
.44203 .56913 .44892 .57242 .4606 .57563 .45369 .57472 Mtetra
.283 0 0 r
.45369 .57472 .4606 .57563 .47238 .57955 .46552 .57801 Mtetra
.675 .931 .97 r
.46552 .57801 .47238 .57955 .48432 .57821 .47757 .5724 Mtetra
.831 .803 .824 r
.47757 .5724 .48432 .57821 .49639 .5701 .48972 .56044 Mtetra
.781 .716 .792 r
.48972 .56044 .49639 .5701 .50849 .55996 .50186 .54945 Mtetra
.722 .685 .814 r
.50186 .54945 .50849 .55996 .5206 .55178 .514 .54221 Mtetra
.682 .69 .851 r
.514 .54221 .5206 .55178 .53273 .5459 .52616 .53732 Mtetra
.668 .708 .878 r
.52616 .53732 .53273 .5459 .5449 .54134 .53836 .53314 Mtetra
.665 .717 .888 r
.53836 .53314 .5449 .54134 .55713 .53739 .55062 .5291 Mtetra
.662 .715 .887 r
.55062 .5291 .55713 .53739 .56942 .53363 .56294 .52512 Mtetra
.659 .709 .884 r
.56294 .52512 .56942 .53363 .58176 .5299 .57531 .52124 Mtetra
.655 .704 .883 r
.57531 .52124 .58176 .5299 .59415 .52616 .58773 .51746 Mtetra
.652 .703 .885 r
.58773 .51746 .59415 .52616 .6066 .5224 .60022 .5138 Mtetra
.648 .705 .888 r
.60022 .5138 .6066 .5224 .61911 .51866 .61276 .51023 Mtetra
.646 .709 .893 r
.61276 .51023 .61911 .51866 .63168 .51514 .62537 .50673 Mtetra
.642 .709 .896 r
.62537 .50673 .63168 .51514 .64434 .51221 .63804 .50335 Mtetra
.619 .689 .894 r
.63804 .50335 .64434 .51221 .65711 .51063 .6508 .50071 Mtetra
.545 .631 .887 r
.6508 .50071 .65711 .51063 .67005 .51136 .66373 .50044 Mtetra
.41 .537 .874 r
.66373 .50044 .67005 .51136 .68319 .51408 .67692 .50397 Mtetra
.345 .52 .886 r
.67692 .50397 .68319 .51408 .69633 .51472 .69027 .50848 Mtetra
.571 .753 .963 r
.69027 .50848 .69633 .51472 .70918 .50845 .7034 .50648 Mtetra
.841 .956 .887 r
.7034 .50648 .70918 .50845 .72176 .49678 .71609 .49538 Mtetra
.883 .963 .844 r
.71609 .49538 .72176 .49678 .73438 .48584 .72863 .48193 Mtetra
.813 .9 .903 r
.72863 .48193 .73438 .48584 .74725 .47845 .74141 .47225 Mtetra
.714 .808 .924 r
.74141 .47225 .74725 .47845 .76031 .47346 .75447 .46629 Mtetra
.668 .764 .922 r
.75447 .46629 .76031 .47346 .7735 .46926 .76768 .46184 Mtetra
.657 .753 .921 r
.76768 .46184 .7735 .46926 .78675 .46521 .78097 .45772 Mtetra
.656 .752 .92 r
.78097 .45772 .78675 .46521 .80007 .46115 .79433 .45363 Mtetra
.656 .751 .92 r
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Mtetra
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .57261 Mtetra
.3768 .57261 .38381 .57915 .39539 .57562 .38841 .56904 Mtetra
.652 .751 .922 r
.38841 .56904 .39539 .57562 .40702 .57211 .40007 .56555 Mtetra
.631 .746 .931 r
.40007 .56555 .40702 .57211 .41869 .56893 .41176 .56263 Mtetra
.516 .714 .962 r
.41176 .56263 .41869 .56893 .43037 .56722 .42344 .56202 Mtetra
.02 .478 .876 r
.42344 .56202 .43037 .56722 .44203 .56913 .43505 .56632 Mtetra
.516 0 0 r
.43505 .56632 .44203 .56913 .45369 .57472 .4467 .57395 Mtetra
.127 0 0 r
.4467 .57395 .45369 .57472 .46552 .57801 .4586 .57568 Mtetra
.834 .91 .889 r
.4586 .57568 .46552 .57801 .47757 .5724 .47077 .56548 Mtetra
.848 .776 .781 r
.47077 .56548 .47757 .5724 .48972 .56044 .48302 .55036 Mtetra
.78 .71 .786 r
.48302 .55036 .48972 .56044 .50186 .54945 .4952 .53913 Mtetra
.709 .685 .825 r
.4952 .53913 .50186 .54945 .514 .54221 .50735 .53267 Mtetra
.669 .687 .858 r
.50735 .53267 .514 .54221 .52616 .53732 .51954 .52833 Mtetra
.655 .695 .875 r
.51954 .52833 .52616 .53732 .53836 .53314 .53178 .52458 Mtetra
.651 .704 .886 r
.53178 .52458 .53836 .53314 .55062 .5291 .54407 .52098 Mtetra
.651 .717 .897 r
.54407 .52098 .55062 .5291 .56294 .52512 .55642 .51738 Mtetra
.653 .729 .905 r
.55642 .51738 .56294 .52512 .57531 .52124 .56883 .51368 Mtetra
.656 .736 .909 r
.56883 .51368 .57531 .52124 .58773 .51746 .58129 .50987 Mtetra
.658 .737 .908 r
.58129 .50987 .58773 .51746 .60022 .5138 .5938 .50596 Mtetra
.661 .731 .902 r
.5938 .50596 .60022 .5138 .61276 .51023 .60637 .50196 Mtetra
.66 .72 .893 r
.60637 .50196 .61276 .51023 .62537 .50673 .619 .49795 Mtetra
.655 .706 .885 r
.619 .49795 .62537 .50673 .63804 .50335 .63169 .4941 Mtetra
.637 .689 .881 r
.63169 .4941 .63804 .50335 .6508 .50071 .64445 .49083 Mtetra
.572 .646 .885 r
.64445 .49083 .6508 .50071 .66373 .50044 .65737 .48971 Mtetra
.395 .534 .878 r
.65737 .48971 .66373 .50044 .67692 .50397 .67058 .49343 Mtetra
.189 .415 .85 r
.67058 .49343 .67692 .50397 .69027 .50848 .6841 .50109 Mtetra
.352 .607 .945 r
.6841 .50109 .69027 .50848 .7034 .50648 .69752 .50372 Mtetra
.808 .935 .914 r
.69752 .50372 .7034 .50648 .71609 .49538 .71036 .49414 Mtetra
.911 .954 .809 r
.71036 .49414 .71609 .49538 .72863 .48193 .72286 .47851 Mtetra
.861 .914 .866 r
.72286 .47851 .72863 .48193 .74141 .47225 .73555 .46631 Mtetra
.746 .827 .914 r
.73555 .46631 .74141 .47225 .75447 .46629 .74857 .45915 Mtetra
.677 .77 .921 r
.74857 .45915 .75447 .46629 .76768 .46184 .76181 .45436 Mtetra
.659 .754 .92 r
.76181 .45436 .76768 .46184 .78097 .45772 .77514 .45016 Mtetra
.656 .752 .92 r
.77514 .45016 .78097 .45772 .79433 .45363 .78855 .44603 Mtetra
.656 .751 .92 r
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Mtetra
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.35814 .56959 .36524 .57616 .3768 .57261 .36973 .566 Mtetra
.655 .751 .92 r
.36973 .566 .3768 .57261 .38841 .56904 .38137 .56242 Mtetra
.651 .75 .922 r
.38137 .56242 .38841 .56904 .40007 .56555 .39306 .55895 Mtetra
.618 .742 .935 r
.39306 .55895 .40007 .56555 .41176 .56263 .40477 .55631 Mtetra
.44 .682 .967 r
.40477 .55631 .41176 .56263 .42344 .56202 .41644 .55685 Mtetra
0 .269 .708 r
.41644 .55685 .42344 .56202 .43505 .56632 .428 .56359 Mtetra
.632 .07 0 r
.428 .56359 .43505 .56632 .4467 .57395 .43963 .57321 Mtetra
.078 .635 .797 r
.43963 .57321 .4467 .57395 .4586 .57568 .4516 .57322 Mtetra
.892 .881 .816 r
.4516 .57322 .4586 .57568 .47077 .56548 .46392 .55837 Mtetra
.867 .77 .753 r
.46392 .55837 .47077 .56548 .48302 .55036 .47627 .54012 Mtetra
.781 .709 .784 r
.47627 .54012 .48302 .55036 .4952 .53913 .48849 .5287 Mtetra
.688 .677 .833 r
.48849 .5287 .4952 .53913 .50735 .53267 .50066 .52329 Mtetra
.646 .683 .871 r
.50066 .52329 .50735 .53267 .51954 .52833 .51288 .51983 Mtetra
.646 .705 .89 r
.51288 .51983 .51954 .52833 .53178 .52458 .52514 .51639 Mtetra
.653 .716 .895 r
.52514 .51639 .53178 .52458 .54407 .52098 .53747 .51269 Mtetra
.656 .716 .892 r
.53747 .51269 .54407 .52098 .55642 .51738 .54985 .50886 Mtetra
.656 .711 .888 r
.54985 .50886 .55642 .51738 .56883 .51368 .56228 .50501 Mtetra
.655 .707 .886 r
.56228 .50501 .56883 .51368 .58129 .50987 .57478 .50118 Mtetra
.654 .707 .886 r
.57478 .50118 .58129 .50987 .5938 .50596 .58732 .49736 Mtetra
.654 .71 .889 r
.58732 .49736 .5938 .50596 .60637 .50196 .59993 .49352 Mtetra
.658 .717 .892 r
.59993 .49352 .60637 .50196 .619 .49795 .61259 .48955 Mtetra
.665 .721 .891 r
.61259 .48955 .619 .49795 .63169 .4941 .6253 .48531 Mtetra
.663 .712 .884 r
.6253 .48531 .63169 .4941 .64445 .49083 .63807 .4811 Mtetra
.606 .666 .882 r
.63807 .4811 .64445 .49083 .65737 .48971 .65097 .47886 Mtetra
.388 .529 .877 r
.65097 .47886 .65737 .48971 .67058 .49343 .6642 .48271 Mtetra
.011 .293 .789 r
.6642 .48271 .67058 .49343 .6841 .50109 .67788 .49352 Mtetra
.039 .404 .857 r
.67788 .49352 .6841 .50109 .69752 .50372 .69156 .50082 Mtetra
.759 .929 .943 r
.69156 .50082 .69752 .50372 .71036 .49414 .70456 .49292 Mtetra
.932 .942 .779 r
.70456 .49292 .71036 .49414 .72286 .47851 .71703 .47517 Mtetra
.895 .908 .826 r
.71703 .47517 .72286 .47851 .73555 .46631 .72963 .46038 Mtetra
.775 .835 .898 r
.72963 .46038 .73555 .46631 .74857 .45915 .74263 .45197 Mtetra
.686 .774 .918 r
.74263 .45197 .74857 .45915 .76181 .45436 .75589 .44683 Mtetra
.66 .755 .92 r
.75589 .44683 .76181 .45436 .77514 .45016 .76926 .44255 Mtetra
.656 .752 .92 r
.76926 .44255 .77514 .45016 .78855 .44603 .78271 .43838 Mtetra
.656 .751 .92 r
.78271 .43838 .78855 .44603 .80202 .44189 .79623 .4342 Mtetra
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57013 Mtetra
.32789 .57013 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Mtetra
.655 .751 .92 r
.3626 .55935 .36973 .566 .38137 .56242 .37428 .55574 Mtetra
.649 .75 .923 r
.37428 .55574 .38137 .56242 .39306 .55895 .386 .55228 Mtetra
.607 .738 .938 r
.386 .55228 .39306 .55895 .40477 .55631 .39772 .54987 Mtetra
.364 .643 .962 r
.39772 .54987 .40477 .55631 .41644 .55685 .40938 .55145 Mtetra
.451 0 0 r
.40938 .55145 .41644 .55685 .428 .56359 .42089 .56053 Mtetra
.709 .172 0 r
.42089 .56053 .428 .56359 .43963 .57321 .43247 .57241 Mtetra
.22 .735 .87 r
.43247 .57241 .43963 .57321 .4516 .57322 .44451 .5713 Mtetra
.924 .869 .766 r
.44451 .5713 .4516 .57322 .46392 .55837 .457 .55199 Mtetra
.892 .779 .73 r
.457 .55199 .46392 .55837 .47627 .54012 .46947 .53017 Mtetra
.791 .717 .783 r
.46947 .53017 .47627 .54012 .48849 .5287 .48174 .5181 Mtetra
.673 .669 .838 r
.48174 .5181 .48849 .5287 .50066 .52329 .49394 .51335 Mtetra
.627 .665 .867 r
.49394 .51335 .50066 .52329 .51288 .51983 .50617 .51051 Mtetra
.63 .68 .879 r
.50617 .51051 .51288 .51983 .52514 .51639 .51846 .50756 Mtetra
.637 .696 .888 r
.51846 .50756 .52514 .51639 .53747 .51269 .53081 .50435 Mtetra
.643 .712 .897 r
.53081 .50435 .53747 .51269 .54985 .50886 .54323 .50092 Mtetra
.649 .725 .904 r
.54323 .50092 .54985 .50886 .56228 .50501 .5557 .49727 Mtetra
.656 .734 .907 r
.5557 .49727 .56228 .50501 .57478 .50118 .56823 .4934 Mtetra
.662 .736 .905 r
.56823 .4934 .57478 .50118 .58732 .49736 .58081 .48932 Mtetra
.667 .732 .898 r
.58081 .48932 .58732 .49736 .59993 .49352 .59344 .48501 Mtetra
.672 .722 .887 r
.59344 .48501 .59993 .49352 .61259 .48955 .60612 .4805 Mtetra
.677 .711 .874 r
.60612 .4805 .61259 .48955 .6253 .48531 .61885 .47571 Mtetra
.677 .7 .864 r
.61885 .47571 .6253 .48531 .63807 .4811 .63163 .47082 Mtetra
.626 .665 .867 r
.63163 .47082 .63807 .4811 .65097 .47886 .64453 .46784 Mtetra
.361 .511 .873 r
.64453 .46784 .65097 .47886 .6642 .48271 .6578 .47231 Mtetra
0 .13 .676 r
.6578 .47231 .6642 .48271 .67788 .49352 .67164 .48667 Mtetra
0 .137 .645 r
.67164 .48667 .67788 .49352 .69156 .50082 .68556 .49846 Mtetra
.707 .938 .961 r
.68556 .49846 .69156 .50082 .70456 .49292 .69869 .49162 Mtetra
.948 .926 .75 r
.69869 .49162 .70456 .49292 .71703 .47517 .71112 .47148 Mtetra
.916 .89 .791 r
.71112 .47148 .71703 .47517 .72963 .46038 .72365 .45422 Mtetra
.796 .832 .88 r
.72365 .45422 .72963 .46038 .74263 .45197 .73663 .44467 Mtetra
.694 .775 .913 r
.73663 .44467 .74263 .45197 .75589 .44683 .74992 .43922 Mtetra
.662 .755 .919 r
.74992 .43922 .75589 .44683 .76926 .44255 .76333 .43486 Mtetra
.656 .752 .92 r
.76333 .43486 .76926 .44255 .78271 .43838 .77683 .43065 Mtetra
.656 .751 .92 r
.77683 .43065 .78271 .43838 .79623 .4342 .79038 .42644 Mtetra
.79038 .42644 .79623 .4342 .8098 .43 .80401 .42221 Mtetra
.80401 .42221 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57013 .32061 .56351 Mtetra
.32061 .56351 .32789 .57013 .33941 .56656 .33216 .55991 Mtetra
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Mtetra
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Mtetra
.655 .751 .921 r
.35542 .55264 .3626 .55935 .37428 .55574 .36713 .549 Mtetra
.648 .749 .923 r
.36713 .549 .37428 .55574 .386 .55228 .37887 .54554 Mtetra
.599 .735 .94 r
.37887 .54554 .386 .55228 .39772 .54987 .39062 .5433 Mtetra
.302 .608 .953 r
.39062 .5433 .39772 .54987 .40938 .55145 .40227 .54566 Mtetra
.565 .035 0 r
.40227 .54566 .40938 .55145 .42089 .56053 .41372 .55674 Mtetra
.764 .252 0 r
.41372 .55674 .42089 .56053 .43247 .57241 .42524 .57115 Mtetra
.241 .743 .899 r
.42524 .57115 .43247 .57241 .44451 .5713 .43733 .57023 Mtetra
.943 .866 .733 r
.43733 .57023 .44451 .5713 .457 .55199 .44998 .54735 Mtetra
.921 .797 .706 r
.44998 .54735 .457 .55199 .46947 .53017 .46261 .52125 Mtetra
.819 .74 .777 r
.46261 .52125 .46947 .53017 .48174 .5181 .47495 .50734 Mtetra
.662 .663 .84 r
.47495 .50734 .48174 .5181 .49394 .51335 .48717 .50303 Mtetra
.597 .645 .869 r
.48717 .50303 .49394 .51335 .50617 .51051 .49941 .50119 Mtetra
.613 .675 .886 r
.49941 .50119 .50617 .51051 .51846 .50756 .51173 .49877 Mtetra
.636 .698 .89 r
.51173 .49877 .51846 .50756 .53081 .50435 .52411 .49556 Mtetra
.648 .703 .887 r
.52411 .49556 .53081 .50435 .54323 .50092 .53655 .49194 Mtetra
.652 .701 .882 r
.53655 .49194 .54323 .50092 .5557 .49727 .54905 .48814 Mtetra
.654 .699 .879 r
.54905 .48814 .5557 .49727 .56823 .4934 .56161 .48424 Mtetra
.656 .7 .879 r
.56161 .48424 .56823 .4934 .58081 .48932 .57423 .48025 Mtetra
.661 .705 .88 r
.57423 .48025 .58081 .48932 .59344 .48501 .58689 .47608 Mtetra
.672 .713 .879 r
.58689 .47608 .59344 .48501 .60612 .4805 .59961 .47148 Mtetra
.691 .719 .87 r
.59961 .47148 .60612 .4805 .61885 .47571 .61236 .46609 Mtetra
.701 .709 .855 r
.61236 .46609 .61885 .47571 .63163 .47082 .62514 .46012 Mtetra
.638 .662 .857 r
.62514 .46012 .63163 .47082 .64453 .46784 .63804 .45665 Mtetra
.273 .456 .859 r
.63804 .45665 .64453 .46784 .6578 .47231 .65139 .46292 Mtetra
0 0 .471 r
.65139 .46292 .6578 .47231 .67164 .48667 .66541 .48158 Mtetra
.62 .1 0 r
.66541 .48158 .67164 .48667 .68556 .49846 .67953 .49695 Mtetra
.691 .956 .949 r
.67953 .49695 .68556 .49846 .69869 .49162 .69272 .48984 Mtetra
.958 .901 .724 r
.69272 .48984 .69869 .49162 .71112 .47148 .7051 .46702 Mtetra
.923 .865 .764 r
.7051 .46702 .71112 .47148 .72365 .45422 .71758 .44763 Mtetra
.808 .823 .863 r
.71758 .44763 .72365 .45422 .73663 .44467 .73057 .43722 Mtetra
.699 .774 .909 r
.73057 .43722 .73663 .44467 .74992 .43922 .74389 .43154 Mtetra
.662 .755 .919 r
.74389 .43154 .74992 .43922 .76333 .43486 .75735 .42711 Mtetra
.656 .752 .92 r
.75735 .42711 .76333 .43486 .77683 .43065 .77089 .42286 Mtetra
.656 .751 .92 r
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Mtetra
.78449 .41861 .79038 .42644 .80401 .42221 .79816 .41434 Mtetra
.79816 .41434 .80401 .42221 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Mtetra
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Mtetra
.655 .751 .921 r
.34818 .54588 .35542 .55264 .36713 .549 .35991 .54221 Mtetra
.648 .749 .923 r
.35991 .54221 .36713 .549 .37887 .54554 .37169 .53874 Mtetra
.594 .733 .941 r
.37169 .53874 .37887 .54554 .39062 .5433 .38347 .5366 Mtetra
.26 .582 .944 r
.38347 .5366 .39062 .5433 .40227 .54566 .39511 .53946 Mtetra
.622 .103 0 r
.39511 .53946 .40227 .54566 .41372 .55674 .40652 .55196 Mtetra
.796 .305 0 r
.40652 .55196 .41372 .55674 .42524 .57115 .41796 .56869 Mtetra
.166 .669 .909 r
.41796 .56869 .42524 .57115 .43733 .57023 .43005 .56937 Mtetra
.948 .863 .723 r
.43005 .56937 .43733 .57023 .44998 .54735 .44283 .54511 Mtetra
.948 .82 .684 r
.44283 .54511 .44998 .54735 .46261 .52125 .45565 .51507 Mtetra
.874 .793 .767 r
.45565 .51507 .46261 .52125 .47495 .50734 .46811 .49763 Mtetra
.698 .698 .846 r
.46811 .49763 .47495 .50734 .48717 .50303 .48036 .49189 Mtetra
.593 .627 .855 r
.48036 .49189 .48717 .50303 .49941 .50119 .49262 .4902 Mtetra
.59 .63 .859 r
.49262 .4902 .49941 .50119 .51173 .49877 .50495 .48856 Mtetra
.61 .656 .87 r
.50495 .48856 .51173 .49877 .52411 .49556 .51736 .48621 Mtetra
.628 .684 .883 r
.51736 .48621 .52411 .49556 .53655 .49194 .52983 .48323 Mtetra
.642 .706 .893 r
.52983 .48323 .53655 .49194 .54905 .48814 .54237 .47974 Mtetra
.655 .72 .896 r
.54237 .47974 .54905 .48814 .56161 .48424 .55496 .47581 Mtetra
.668 .724 .891 r
.55496 .47581 .56161 .48424 .57423 .48025 .5676 .47143 Mtetra
.68 .719 .879 r
.5676 .47143 .57423 .48025 .58689 .47608 .58029 .46654 Mtetra
.691 .707 .86 r
.58029 .46654 .58689 .47608 .59961 .47148 .59302 .46103 Mtetra
.701 .693 .839 r
.59302 .46103 .59961 .47148 .61236 .46609 .60578 .45481 Mtetra
.695 .676 .827 r
.60578 .45481 .61236 .46609 .62514 .46012 .61858 .44863 Mtetra
.601 .631 .853 r
.61858 .44863 .62514 .46012 .63804 .45665 .63156 .44654 Mtetra
.01 .313 .803 r
.63156 .44654 .63804 .45665 .65139 .46292 .64505 .45633 Mtetra
.753 .281 0 r
.64505 .45633 .65139 .46292 .66541 .48158 .65923 .47892 Mtetra
.735 .213 0 r
.65923 .47892 .66541 .48158 .67953 .49695 .67343 .49563 Mtetra
.755 .973 .925 r
.67343 .49563 .67953 .49695 .69272 .48984 .68662 .4868 Mtetra
.958 .868 .706 r
.68662 .4868 .69272 .48984 .7051 .46702 .69896 .46154 Mtetra
.921 .839 .747 r
.69896 .46154 .7051 .46702 .71758 .44763 .71144 .44063 Mtetra
.813 .814 .851 r
.71144 .44063 .71758 .44763 .73057 .43722 .72445 .42962 Mtetra
.703 .773 .906 r
.72445 .42962 .73057 .43722 .74389 .43154 .73781 .42377 Mtetra
.663 .755 .918 r
.73781 .42377 .74389 .43154 .75735 .42711 .75132 .41929 Mtetra
.656 .752 .92 r
.75132 .41929 .75735 .42711 .77089 .42286 .7649 .415 Mtetra
.656 .751 .92 r
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Mtetra
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40207 Mtetra
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38455 Mtetra
.86182 .38455 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Mtetra
.655 .751 .921 r
.34088 .53906 .34818 .54588 .35991 .54221 .35264 .53537 Mtetra
.647 .749 .924 r
.35264 .53537 .35991 .54221 .37169 .53874 .36445 .53188 Mtetra
.59 .731 .942 r
.36445 .53188 .37169 .53874 .38347 .5366 .37625 .52981 Mtetra
.231 .564 .937 r
.37625 .52981 .38347 .5366 .39511 .53946 .3879 .53299 Mtetra
.65 .137 0 r
.3879 .53299 .39511 .53946 .40652 .55196 .39928 .5463 Mtetra
.809 .329 0 r
.39928 .5463 .40652 .55196 .41796 .56869 .41066 .56445 Mtetra
.104 .577 .911 r
.41066 .56445 .41796 .56869 .43005 .56937 .42273 .56706 Mtetra
.933 .846 .735 r
.42273 .56706 .43005 .56937 .44283 .54511 .43557 .5441 Mtetra
.958 .832 .676 r
.43557 .5441 .44283 .54511 .45565 .51507 .44853 .51276 Mtetra
.93 .857 .748 r
.44853 .51276 .45565 .51507 .46811 .49763 .46114 .4916 Mtetra
.789 .808 .868 r
.46114 .4916 .46811 .49763 .48036 .49189 .47349 .48253 Mtetra
.632 .684 .881 r
.47349 .48253 .48036 .49189 .49262 .4902 .48579 .47944 Mtetra
.595 .638 .864 r
.48579 .47944 .49262 .4902 .50495 .48856 .49814 .4776 Mtetra
.609 .641 .857 r
.49814 .4776 .50495 .48856 .51736 .48621 .51057 .47525 Mtetra
.628 .65 .853 r
.51057 .47525 .51736 .48621 .52983 .48323 .52306 .4722 Mtetra
.641 .655 .849 r
.52306 .4722 .52983 .48323 .54237 .47974 .53562 .46864 Mtetra
.65 .658 .845 r
.53562 .46864 .54237 .47974 .55496 .47581 .54823 .46468 Mtetra
.658 .662 .842 r
.54823 .46468 .55496 .47581 .5676 .47143 .5609 .46032 Mtetra
.67 .668 .839 r
.5609 .46032 .5676 .47143 .58029 .46654 .57361 .45544 Mtetra
.685 .675 .835 r
.57361 .45544 .58029 .46654 .59302 .46103 .58637 .44984 Mtetra
.694 .678 .83 r
.58637 .44984 .59302 .46103 .60578 .45481 .59916 .44373 Mtetra
.668 .67 .842 r
.59916 .44373 .60578 .45481 .61858 .44863 .61203 .4389 Mtetra
.471 .607 .905 r
.61203 .4389 .61858 .44863 .63156 .44654 .62514 .44014 Mtetra
0 .006 .506 r
.62514 .44014 .63156 .44654 .64505 .45633 .63878 .45364 Mtetra
.834 .362 .011 r
.63878 .45364 .64505 .45633 .65923 .47892 .65303 .4775 Mtetra
.729 .201 0 r
.65303 .4775 .65923 .47892 .67343 .49563 .6672 .49281 Mtetra
.831 .937 .897 r
.6672 .49281 .67343 .49563 .68662 .4868 .68036 .48193 Mtetra
.948 .833 .697 r
.68036 .48193 .68662 .4868 .69896 .46154 .69272 .45514 Mtetra
.917 .821 .737 r
.69272 .45514 .69896 .46154 .71144 .44063 .70523 .43333 Mtetra
.816 .809 .844 r
.70523 .43333 .71144 .44063 .72445 .42962 .71828 .42193 Mtetra
.705 .773 .904 r
.71828 .42193 .72445 .42962 .73781 .42377 .73168 .41594 Mtetra
.664 .755 .918 r
.73168 .41594 .73781 .42377 .75132 .41929 .74523 .4114 Mtetra
.656 .752 .92 r
.74523 .4114 .75132 .41929 .7649 .415 .75886 .40707 Mtetra
.656 .751 .92 r
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Mtetra
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40207 .80014 .39403 Mtetra
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38455 .85611 .37635 Mtetra
.85611 .37635 .86182 .38455 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Mtetra
.655 .751 .921 r
.33352 .53219 .34088 .53906 .35264 .53537 .34531 .52846 Mtetra
.646 .749 .924 r
.34531 .52846 .35264 .53537 .36445 .53188 .35715 .52497 Mtetra
.585 .73 .943 r
.35715 .52497 .36445 .53188 .37625 .52981 .36898 .52296 Mtetra
.205 .548 .931 r
.36898 .52296 .37625 .52981 .3879 .53299 .38063 .52642 Mtetra
.667 .158 0 r
.38063 .52642 .3879 .53299 .39928 .5463 .39199 .54018 Mtetra
.809 .332 0 r
.39199 .54018 .39928 .5463 .41066 .56445 .40334 .55874 Mtetra
.142 .553 .925 r
.40334 .55874 .41066 .56445 .42273 .56706 .41541 .56208 Mtetra
.901 .808 .746 r
.41541 .56208 .42273 .56706 .43557 .5441 .42828 .54116 Mtetra
.941 .816 .692 r
.42828 .54116 .43557 .5441 .44853 .51276 .44129 .5122 Mtetra
.944 .89 .747 r
.44129 .5122 .44853 .51276 .46114 .4916 .454 .49091 Mtetra
.87 .953 .861 r
.454 .49091 .46114 .4916 .47349 .48253 .46648 .47847 Mtetra
.757 .871 .93 r
.46648 .47847 .47349 .48253 .48579 .47944 .47888 .47124 Mtetra
.668 .728 .894 r
.47888 .47124 .48579 .47944 .49814 .4776 .49128 .46689 Mtetra
.627 .655 .858 r
.49128 .46689 .49814 .4776 .51057 .47525 .50373 .46387 Mtetra
.621 .64 .848 r
.50373 .46387 .51057 .47525 .52306 .4722 .51625 .46104 Mtetra
.633 .651 .85 r
.51625 .46104 .52306 .4722 .53562 .46864 .52882 .45774 Mtetra
.65 .664 .85 r
.52882 .45774 .53562 .46864 .54823 .46468 .54146 .45374 Mtetra
.666 .67 .844 r
.54146 .45374 .54823 .46468 .5609 .46032 .55415 .44903 Mtetra
.675 .668 .836 r
.55415 .44903 .5609 .46032 .57361 .45544 .56689 .44386 Mtetra
.669 .661 .833 r
.56689 .44386 .57361 .45544 .58637 .44984 .57968 .4389 Mtetra
.639 .661 .855 r
.57968 .4389 .58637 .44984 .59916 .44373 .59256 .43529 Mtetra
.535 .676 .928 r
.59256 .43529 .59916 .44373 .61203 .4389 .60557 .43457 Mtetra
0 .464 .842 r
.60557 .43457 .61203 .4389 .62514 .44014 .61882 .43915 Mtetra
.711 .175 0 r
.61882 .43915 .62514 .44014 .63878 .45364 .63249 .4527 Mtetra
.819 .34 .036 r
.63249 .4527 .63878 .45364 .65303 .4775 .64667 .47407 Mtetra
.619 .07 0 r
.64667 .47407 .65303 .4775 .6672 .49281 .66078 .48723 Mtetra
.833 .855 .862 r
.66078 .48723 .6672 .49281 .68036 .48193 .67397 .47555 Mtetra
.936 .81 .695 r
.67397 .47555 .68036 .48193 .69272 .45514 .6864 .44827 Mtetra
.914 .812 .732 r
.6864 .44827 .69272 .45514 .70523 .43333 .69896 .42592 Mtetra
.82 .808 .84 r
.69896 .42592 .70523 .43333 .71828 .42193 .71205 .41416 Mtetra
.708 .773 .903 r
.71205 .41416 .71828 .42193 .73168 .41594 .72549 .40803 Mtetra
.664 .755 .918 r
.72549 .40803 .73168 .41594 .74523 .4114 .73909 .40344 Mtetra
.657 .752 .92 r
.73909 .40344 .74523 .4114 .75886 .40707 .75276 .39907 Mtetra
.656 .751 .92 r
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Mtetra
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52526 Mtetra
.655 .751 .921 r
.32609 .52526 .33352 .53219 .34531 .52846 .33793 .52151 Mtetra
.646 .749 .924 r
.33793 .52151 .34531 .52846 .35715 .52497 .3498 .518 Mtetra
.581 .728 .944 r
.3498 .518 .35715 .52497 .36898 .52296 .36164 .51607 Mtetra
.175 .531 .923 r
.36164 .51607 .36898 .52296 .38063 .52642 .3733 .51981 Mtetra
.683 .176 0 r
.3733 .51981 .38063 .52642 .39199 .54018 .38463 .53395 Mtetra
.806 .328 0 r
.38463 .53395 .39199 .54018 .40334 .55874 .39598 .55245 Mtetra
.23 .588 .947 r
.39598 .55245 .40334 .55874 .41541 .56208 .40808 .55525 Mtetra
.882 .778 .742 r
.40808 .55525 .41541 .56208 .42828 .54116 .42102 .53469 Mtetra
.907 .775 .703 r
.42102 .53469 .42828 .54116 .44129 .5122 .43405 .50804 Mtetra
.898 .837 .776 r
.43405 .50804 .44129 .5122 .454 .49091 .44677 .49008 Mtetra
.824 .963 .899 r
.44677 .49008 .454 .49091 .46648 .47847 .45928 .4798 Mtetra
.649 .969 .869 r
.45928 .4798 .46648 .47847 .47888 .47124 .47177 .47193 Mtetra
.663 .971 .897 r
.47177 .47193 .47888 .47124 .49128 .46689 .48428 .46439 Mtetra
.738 .924 .953 r
.48428 .46439 .49128 .46689 .50373 .46387 .49682 .45735 Mtetra
.719 .793 .91 r
.49682 .45735 .50373 .46387 .51625 .46104 .50938 .45124 Mtetra
.679 .698 .861 r
.50938 .45124 .51625 .46104 .52882 .45774 .52199 .44619 Mtetra
.649 .652 .84 r
.52199 .44619 .52882 .45774 .54146 .45374 .53465 .44216 Mtetra
.623 .641 .848 r
.53465 .44216 .54146 .45374 .55415 .44903 .54738 .43916 Mtetra
.59 .663 .889 r
.54738 .43916 .55415 .44903 .56689 .44386 .56018 .43723 Mtetra
.518 .725 .968 r
.56018 .43723 .56689 .44386 .57968 .4389 .57308 .43622 Mtetra
.297 .749 .958 r
.57308 .43622 .57968 .4389 .59256 .43529 .58607 .43574 Mtetra
.03 0 0 r
.58607 .43574 .59256 .43529 .60557 .43457 .59916 .43562 Mtetra
.288 0 0 r
.59916 .43562 .60557 .43457 .61882 .43915 .61241 .43794 Mtetra
.607 .037 0 r
.61241 .43794 .61882 .43915 .63249 .4527 .62602 .44808 Mtetra
.741 .237 0 r
.62602 .44808 .63249 .4527 .64667 .47407 .64011 .46704 Mtetra
0 .088 .597 r
.64011 .46704 .64667 .47407 .66078 .48723 .65422 .47975 Mtetra
.809 .804 .847 r
.65422 .47975 .66078 .48723 .67397 .47555 .6675 .46855 Mtetra
.931 .802 .695 r
.6675 .46855 .67397 .47555 .6864 .44827 .68002 .44127 Mtetra
.916 .811 .728 r
.68002 .44127 .6864 .44827 .69896 .42592 .69264 .41846 Mtetra
.824 .809 .836 r
.69264 .41846 .69896 .42592 .71205 .41416 .70577 .40634 Mtetra
.711 .775 .902 r
.70577 .40634 .71205 .41416 .72549 .40803 .71925 .40006 Mtetra
.665 .756 .918 r
.71925 .40006 .72549 .40803 .73909 .40344 .73289 .39541 Mtetra
.657 .752 .92 r
.73289 .39541 .73909 .40344 .75276 .39907 .74661 .391 Mtetra
.656 .751 .92 r
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Mtetra
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.3068 .52206 .31431 .52902 .32609 .52526 .31861 .51827 Mtetra
.655 .751 .921 r
.31861 .51827 .32609 .52526 .33793 .52151 .33047 .51449 Mtetra
.645 .748 .925 r
.33047 .51449 .33793 .52151 .3498 .518 .34238 .51098 Mtetra
.575 .727 .945 r
.34238 .51098 .3498 .518 .36164 .51607 .35425 .50914 Mtetra
.143 .512 .913 r
.35425 .50914 .36164 .51607 .3733 .51981 .3659 .51319 Mtetra
.699 .194 0 r
.3659 .51319 .3733 .51981 .38463 .53395 .37721 .52771 Mtetra
.803 .324 0 r
.37721 .52771 .38463 .53395 .39598 .55245 .38855 .54603 Mtetra
.314 .633 .963 r
.38855 .54603 .39598 .55245 .40808 .55525 .40071 .5479 Mtetra
.88 .77 .736 r
.40071 .5479 .40808 .55525 .42102 .53469 .41374 .52663 Mtetra
.894 .755 .701 r
.41374 .52663 .42102 .53469 .43405 .50804 .42685 .50003 Mtetra
.858 .764 .758 r
.42685 .50003 .43405 .50804 .44677 .49008 .43963 .48235 Mtetra
.789 .77 .835 r
.43963 .48235 .44677 .49008 .45928 .4798 .45219 .47221 Mtetra
.75 .768 .867 r
.45219 .47221 .45928 .4798 .47177 .47193 .46472 .46448 Mtetra
.743 .771 .876 r
.46472 .46448 .47177 .47193 .48428 .46439 .47727 .45717 Mtetra
.734 .777 .887 r
.47727 .45717 .48428 .46439 .49682 .45735 .48984 .45034 Mtetra
.714 .779 .904 r
.48984 .45034 .49682 .45735 .50938 .45124 .50245 .44434 Mtetra
.686 .777 .92 r
.50245 .44434 .50938 .45124 .52199 .44619 .5151 .43931 Mtetra
.654 .769 .933 r
.5151 .43931 .52199 .44619 .53465 .44216 .5278 .43524 Mtetra
.618 .756 .945 r
.5278 .43524 .53465 .44216 .54738 .43916 .54057 .43214 Mtetra
.577 .739 .952 r
.54057 .43214 .54738 .43916 .56018 .43723 .55341 .43002 Mtetra
.538 .717 .955 r
.55341 .43002 .56018 .43723 .57308 .43622 .56634 .42876 Mtetra
.517 .701 .953 r
.56634 .42876 .57308 .43622 .58607 .43574 .57936 .42802 Mtetra
.501 .686 .95 r
.57936 .42802 .58607 .43574 .59916 .43562 .59248 .42767 Mtetra
.373 .614 .944 r
.59248 .42767 .59916 .43562 .61241 .43794 .60575 .42977 Mtetra
0 .263 .762 r
.60575 .42977 .61241 .43794 .62602 .44808 .61936 .43954 Mtetra
.586 .128 0 r
.61936 .43954 .62602 .44808 .64011 .46704 .63345 .45836 Mtetra
0 .112 .644 r
.63345 .45836 .64011 .46704 .65422 .47975 .64759 .47173 Mtetra
.79 .789 .852 r
.64759 .47173 .65422 .47975 .6675 .46855 .66096 .46142 Mtetra
.93 .801 .697 r
.66096 .46142 .6675 .46855 .68002 .44127 .67358 .43425 Mtetra
.918 .811 .725 r
.67358 .43425 .68002 .44127 .69264 .41846 .68626 .41097 Mtetra
.829 .81 .833 r
.68626 .41097 .69264 .41846 .70577 .40634 .69943 .39847 Mtetra
.714 .776 .901 r
.69943 .39847 .70577 .40634 .71925 .40006 .71296 .39203 Mtetra
.666 .756 .918 r
.71296 .39203 .71925 .40006 .73289 .39541 .72664 .38731 Mtetra
.657 .752 .92 r
.72664 .38731 .73289 .39541 .74661 .391 .74041 .38286 Mtetra
.656 .751 .92 r
.74041 .38286 .74661 .391 .7604 .38659 .75424 .37841 Mtetra
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Mtetra
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Mtetra
.655 .751 .921 r
.31107 .51122 .31861 .51827 .33047 .51449 .32296 .50742 Mtetra
.644 .748 .925 r
.32296 .50742 .33047 .51449 .34238 .51098 .33489 .5039 Mtetra
.569 .724 .947 r
.33489 .5039 .34238 .51098 .35425 .50914 .34678 .50216 Mtetra
.107 .49 .901 r
.34678 .50216 .35425 .50914 .3659 .51319 .35844 .50655 Mtetra
.714 .211 0 r
.35844 .50655 .3659 .51319 .37721 .52771 .36972 .52146 Mtetra
.797 .315 0 r
.36972 .52146 .37721 .52771 .38855 .54603 .38106 .53946 Mtetra
.426 .687 .972 r
.38106 .53946 .38855 .54603 .40071 .5479 .3933 .53989 Mtetra
.883 .759 .721 r
.3933 .53989 .40071 .5479 .41374 .52663 .40647 .51667 Mtetra
.886 .732 .686 r
.40647 .51667 .41374 .52663 .42685 .50003 .41973 .48779 Mtetra
.834 .703 .72 r
.41973 .48779 .42685 .50003 .43963 .48235 .43262 .46761 Mtetra
.746 .648 .751 r
.43262 .46761 .43963 .48235 .45219 .47221 .44524 .45611 Mtetra
.676 .602 .765 r
.44524 .45611 .45219 .47221 .46472 .46448 .45775 .44952 Mtetra
.637 .596 .791 r
.45775 .44952 .46472 .46448 .47727 .45717 .47026 .44548 Mtetra
.621 .639 .846 r
.47026 .44548 .47727 .45717 .48984 .45034 .48282 .44251 Mtetra
.616 .728 .926 r
.48282 .44251 .48984 .45034 .50245 .44434 .49544 .4396 Mtetra
.606 .825 .984 r
.49544 .4396 .50245 .44434 .5151 .43931 .50813 .43618 Mtetra
.602 .879 .992 r
.50813 .43618 .5151 .43931 .5278 .43524 .52089 .43208 Mtetra
.638 .89 .986 r
.52089 .43208 .5278 .43524 .54057 .43214 .5337 .42732 Mtetra
.685 .848 .961 r
.5337 .42732 .54057 .43214 .55341 .43002 .54657 .42205 Mtetra
.688 .753 .901 r
.54657 .42205 .55341 .43002 .56634 .42876 .55949 .41678 Mtetra
.648 .65 .838 r
.55949 .41678 .56634 .42876 .57936 .42802 .57248 .4126 Mtetra
.583 .567 .801 r
.57248 .4126 .57936 .42802 .59248 .42767 .58557 .41102 Mtetra
.46 .482 .795 r
.58557 .41102 .59248 .42767 .60575 .42977 .59887 .41443 Mtetra
.099 .275 .755 r
.59887 .41443 .60575 .42977 .61936 .43954 .61253 .42667 Mtetra
0 0 .505 r
.61253 .42667 .61936 .43954 .63345 .45836 .62666 .44774 Mtetra
0 .084 .636 r
.62666 .44774 .63345 .45836 .64759 .47173 .64087 .46303 Mtetra
.76 .768 .86 r
.64087 .46303 .64759 .47173 .66096 .46142 .65435 .45412 Mtetra
.928 .8 .699 r
.65435 .45412 .66096 .46142 .67358 .43425 .66708 .42721 Mtetra
.92 .811 .722 r
.66708 .42721 .67358 .43425 .68626 .41097 .67982 .40347 Mtetra
.834 .812 .829 r
.67982 .40347 .68626 .41097 .69943 .39847 .69304 .39055 Mtetra
.717 .778 .9 r
.69304 .39055 .69943 .39847 .71296 .39203 .70661 .38392 Mtetra
.666 .756 .917 r
.70661 .38392 .71296 .39203 .72664 .38731 .72033 .37913 Mtetra
.657 .752 .92 r
.72033 .37913 .72664 .38731 .74041 .38286 .73415 .37464 Mtetra
.656 .751 .92 r
.73415 .37464 .74041 .38286 .75424 .37841 .74803 .37016 Mtetra
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .3428 Mtetra
.83275 .3428 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Mtetra
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Mtetra
.655 .751 .921 r
.30346 .50412 .31107 .51122 .32296 .50742 .31538 .50028 Mtetra
.643 .748 .925 r
.31538 .50028 .32296 .50742 .33489 .5039 .32735 .49677 Mtetra
.562 .722 .948 r
.32735 .49677 .33489 .5039 .34678 .50216 .33926 .49515 Mtetra
.069 .466 .887 r
.33926 .49515 .34678 .50216 .35844 .50655 .35091 .49988 Mtetra
.723 .221 0 r
.35091 .49988 .35844 .50655 .36972 .52146 .36217 .51503 Mtetra
.773 .282 0 r
.36217 .51503 .36972 .52146 .38106 .53946 .37353 .53201 Mtetra
.601 .733 .937 r
.37353 .53201 .38106 .53946 .3933 .53989 .38592 .52946 Mtetra
.875 .728 .695 r
.38592 .52946 .3933 .53989 .40647 .51667 .3993 .50266 Mtetra
.862 .693 .672 r
.3993 .50266 .40647 .51667 .41973 .48779 .41268 .4721 Mtetra
.797 .66 .712 r
.41268 .4721 .41973 .48779 .43262 .46761 .42556 .45361 Mtetra
.698 .637 .784 r
.42556 .45361 .43262 .46761 .44524 .45611 .4381 .44631 Mtetra
.611 .674 .886 r
.4381 .44631 .44524 .45611 .45775 .44952 .45055 .44371 Mtetra
.553 .769 .978 r
.45055 .44371 .45775 .44952 .47026 .44548 .46307 .4417 Mtetra
.537 .833 .999 r
.46307 .4417 .47026 .44548 .48282 .44251 .47567 .43904 Mtetra
.568 .856 .997 r
.47567 .43904 .48282 .44251 .49544 .4396 .48834 .43571 Mtetra
.605 .855 .991 r
.48834 .43571 .49544 .4396 .50813 .43618 .50109 .43193 Mtetra
.629 .852 .984 r
.50109 .43193 .50813 .43618 .52089 .43208 .5139 .4278 Mtetra
.645 .856 .98 r
.5139 .4278 .52089 .43208 .5337 .42732 .52677 .4233 Mtetra
.66 .871 .978 r
.52677 .4233 .5337 .42732 .54657 .42205 .53969 .41835 Mtetra
.682 .887 .974 r
.53969 .41835 .54657 .42205 .55949 .41678 .55267 .41276 Mtetra
.71 .884 .961 r
.55267 .41276 .55949 .41678 .57248 .4126 .56568 .40652 Mtetra
.7 .816 .937 r
.56568 .40652 .57248 .4126 .58557 .41102 .57876 .40083 Mtetra
.551 .646 .897 r
.57876 .40083 .58557 .41102 .59887 .41443 .59198 .3999 Mtetra
.149 .323 .784 r
.59198 .3999 .59887 .41443 .61253 .42667 .60557 .41029 Mtetra
0 0 .548 r
.60557 .41029 .61253 .42667 .62666 .44774 .61971 .43298 Mtetra
0 .056 .622 r
.61971 .43298 .62666 .44774 .64087 .46303 .63402 .45184 Mtetra
.685 .692 .85 r
.63402 .45184 .64087 .46303 .65435 .45412 .64765 .44591 Mtetra
.916 .789 .705 r
.64765 .44591 .65435 .45412 .66708 .42721 .66051 .41997 Mtetra
.92 .808 .72 r
.66051 .41997 .66708 .42721 .67982 .40347 .67333 .39591 Mtetra
.839 .813 .825 r
.67333 .39591 .67982 .40347 .69304 .39055 .68659 .38257 Mtetra
.721 .779 .899 r
.68659 .38257 .69304 .39055 .70661 .38392 .7002 .37575 Mtetra
.667 .757 .917 r
.7002 .37575 .70661 .38392 .72033 .37913 .71397 .37089 Mtetra
.657 .752 .92 r
.71397 .37089 .72033 .37913 .73415 .37464 .72783 .36635 Mtetra
.656 .751 .92 r
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Mtetra
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .3428 .82677 .33423 Mtetra
.82677 .33423 .83275 .3428 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Mtetra
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49696 Mtetra
.654 .751 .921 r
.29579 .49696 .30346 .50412 .31538 .50028 .30775 .49309 Mtetra
.642 .748 .926 r
.30775 .49309 .31538 .50028 .32735 .49677 .31974 .48957 Mtetra
.555 .719 .95 r
.31974 .48957 .32735 .49677 .33926 .49515 .33167 .48807 Mtetra
.045 .45 .877 r
.33167 .48807 .33926 .49515 .35091 .49988 .34332 .49302 Mtetra
.706 .203 0 r
.34332 .49302 .35091 .49988 .36217 .51503 .35458 .50783 Mtetra
.676 .174 0 r
.35458 .50783 .36217 .51503 .37353 .53201 .36605 .52242 Mtetra
.713 .716 .851 r
.36605 .52242 .37353 .53201 .38592 .52946 .37864 .51582 Mtetra
.858 .696 .68 r
.37864 .51582 .38592 .52946 .3993 .50266 .39215 .48718 Mtetra
.843 .678 .678 r
.39215 .48718 .3993 .50266 .41268 .4721 .4055 .45943 Mtetra
.784 .686 .757 r
.4055 .45943 .41268 .4721 .42556 .45361 .41827 .4458 Mtetra
.658 .743 .912 r
.41827 .4458 .42556 .45361 .4381 .44631 .43075 .44167 Mtetra
.507 .792 .997 r
.43075 .44167 .4381 .44631 .45055 .44371 .44323 .43991 Mtetra
.498 .817 1 r
.44323 .43991 .45055 .44371 .46307 .4417 .4558 .4378 Mtetra
.545 .833 .998 r
.4558 .4378 .46307 .4417 .47567 .43904 .46845 .43505 Mtetra
.578 .843 .995 r
.46845 .43505 .47567 .43904 .48834 .43571 .48117 .43176 Mtetra
.601 .853 .992 r
.48117 .43176 .48834 .43571 .50109 .43193 .49397 .42802 Mtetra
.62 .862 .989 r
.49397 .42802 .50109 .43193 .5139 .4278 .50683 .42387 Mtetra
.639 .868 .984 r
.50683 .42387 .5139 .4278 .52677 .4233 .51975 .41933 Mtetra
.66 .873 .979 r
.51975 .41933 .52677 .4233 .53969 .41835 .53274 .41433 Mtetra
.685 .879 .971 r
.53274 .41433 .53969 .41835 .55267 .41276 .54577 .40871 Mtetra
.711 .885 .961 r
.54577 .40871 .55267 .41276 .56568 .40652 .55885 .4024 Mtetra
.722 .886 .956 r
.55885 .4024 .56568 .40652 .57876 .40083 .57197 .39577 Mtetra
.635 .834 .977 r
.57197 .39577 .57876 .40083 .59198 .3999 .58517 .39155 Mtetra
.16 .48 .898 r
.58517 .39155 .59198 .3999 .60557 .41029 .59867 .39697 Mtetra
0 0 .551 r
.59867 .39697 .60557 .41029 .61971 .43298 .61269 .41671 Mtetra
0 .029 .6 r
.61269 .41671 .61971 .43298 .63402 .45184 .62702 .43736 Mtetra
.585 .59 .824 r
.62702 .43736 .63402 .45184 .64765 .44591 .64082 .43549 Mtetra
.886 .759 .716 r
.64082 .43549 .64765 .44591 .66051 .41997 .65385 .41193 Mtetra
.911 .797 .721 r
.65385 .41193 .66051 .41997 .67333 .39591 .66677 .38816 Mtetra
.84 .81 .82 r
.66677 .38816 .67333 .39591 .68659 .38257 .68008 .37451 Mtetra
.724 .78 .897 r
.68008 .37451 .68659 .38257 .7002 .37575 .69373 .36751 Mtetra
.668 .757 .917 r
.69373 .36751 .7002 .37575 .71397 .37089 .70755 .36257 Mtetra
.657 .752 .92 r
.70755 .36257 .71397 .37089 .72783 .36635 .72146 .35799 Mtetra
.656 .751 .92 r
.72146 .35799 .72783 .36635 .74176 .36183 .73543 .35342 Mtetra
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34884 Mtetra
.74947 .34884 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Mtetra
.27611 .49365 .28388 .50084 .29579 .49696 .28805 .48973 Mtetra
.654 .751 .921 r
.28805 .48973 .29579 .49696 .30775 .49309 .30004 .48584 Mtetra
.641 .747 .926 r
.30004 .48584 .30775 .49309 .31974 .48957 .31206 .48232 Mtetra
.552 .718 .95 r
.31206 .48232 .31974 .48957 .33167 .48807 .32402 .48085 Mtetra
.064 .46 .884 r
.32402 .48085 .33167 .48807 .34332 .49302 .33569 .48566 Mtetra
.633 .128 0 r
.33569 .48566 .34332 .49302 .35458 .50783 .34701 .49915 Mtetra
0 .061 .584 r
.34701 .49915 .35458 .50783 .36605 .52242 .35862 .51044 Mtetra
.741 .683 .795 r
.35862 .51044 .36605 .52242 .37864 .51582 .37136 .5011 Mtetra
.845 .685 .684 r
.37136 .5011 .37864 .51582 .39215 .48718 .38486 .47427 Mtetra
.842 .7 .706 r
.38486 .47427 .39215 .48718 .4055 .45943 .39809 .45148 Mtetra
.786 .769 .838 r
.39809 .45148 .4055 .45943 .41827 .4458 .41079 .44145 Mtetra
.586 .831 .991 r
.41079 .44145 .41827 .4458 .43075 .44167 .42329 .43826 Mtetra
.488 .826 .999 r
.42329 .43826 .43075 .44167 .44323 .43991 .43583 .43604 Mtetra
.557 .84 .998 r
.43583 .43604 .44323 .43991 .4558 .4378 .44846 .43306 Mtetra
.613 .83 .983 r
.44846 .43306 .4558 .4378 .46845 .43505 .46118 .42941 Mtetra
.638 .809 .965 r
.46118 .42941 .46845 .43505 .48117 .43176 .47396 .42546 Mtetra
.647 .791 .951 r
.47396 .42546 .48117 .43176 .49397 .42802 .4868 .42136 Mtetra
.652 .783 .944 r
.4868 .42136 .49397 .42802 .50683 .42387 .49971 .41717 Mtetra
.655 .784 .943 r
.49971 .41717 .50683 .42387 .51975 .41933 .51267 .41287 Mtetra
.659 .793 .946 r
.51267 .41287 .51975 .41933 .53274 .41433 .5257 .40841 Mtetra
.664 .813 .955 r
.5257 .40841 .53274 .41433 .54577 .40871 .53879 .40371 Mtetra
.681 .849 .963 r
.53879 .40371 .54577 .40871 .55885 .4024 .55193 .39836 Mtetra
.704 .887 .965 r
.55193 .39836 .55885 .4024 .57197 .39577 .56512 .39216 Mtetra
.657 .89 .981 r
.56512 .39216 .57197 .39577 .58517 .39155 .57837 .38688 Mtetra
.232 .652 .958 r
.57837 .38688 .58517 .39155 .59867 .39697 .59182 .3885 Mtetra
0 .025 .558 r
.59182 .3885 .59867 .39697 .61269 .41671 .60571 .40307 Mtetra
0 .024 .596 r
.60571 .40307 .61269 .41671 .62702 .43736 .61995 .42175 Mtetra
.518 .539 .817 r
.61995 .42175 .62702 .43736 .64082 .43549 .63385 .42259 Mtetra
.844 .721 .728 r
.63385 .42259 .64082 .43549 .65385 .41193 .64707 .40234 Mtetra
.89 .774 .727 r
.64707 .40234 .65385 .41193 .66677 .38816 .66013 .37987 Mtetra
.834 .798 .817 r
.66013 .37987 .66677 .38816 .68008 .37451 .67351 .3663 Mtetra
.726 .778 .895 r
.67351 .3663 .68008 .37451 .69373 .36751 .68721 .35918 Mtetra
.669 .757 .917 r
.68721 .35918 .69373 .36751 .70755 .36257 .70107 .35417 Mtetra
.657 .752 .92 r
.70107 .35417 .70755 .36257 .72146 .35799 .71502 .34955 Mtetra
.656 .751 .92 r
.71502 .34955 .72146 .35799 .73543 .35342 .72905 .34494 Mtetra
.72905 .34494 .73543 .35342 .74947 .34884 .74314 .34031 Mtetra
.74314 .34031 .74947 .34884 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48245 Mtetra
.654 .751 .921 r
.28025 .48245 .28805 .48973 .30004 .48584 .29227 .47852 Mtetra
.641 .747 .926 r
.29227 .47852 .30004 .48584 .31206 .48232 .30433 .47497 Mtetra
.557 .719 .949 r
.30433 .47497 .31206 .48232 .32402 .48085 .31631 .47337 Mtetra
.145 .505 .91 r
.31631 .47337 .32402 .48085 .33569 .48566 .32803 .47748 Mtetra
0 .025 .537 r
.32803 .47748 .33569 .48566 .34701 .49915 .33946 .48883 Mtetra
0 .296 .793 r
.33946 .48883 .34701 .49915 .35862 .51044 .35122 .49716 Mtetra
.734 .664 .781 r
.35122 .49716 .35862 .51044 .37136 .5011 .36399 .48764 Mtetra
.837 .694 .705 r
.36399 .48764 .37136 .5011 .38486 .47427 .37738 .46482 Mtetra
.85 .745 .747 r
.37738 .46482 .38486 .47427 .39809 .45148 .39051 .44628 Mtetra
.784 .843 .896 r
.39051 .44628 .39809 .45148 .41079 .44145 .40322 .43757 Mtetra
.615 .858 .989 r
.40322 .43757 .41079 .44145 .42329 .43826 .41579 .43362 Mtetra
.59 .826 .989 r
.41579 .43362 .42329 .43826 .43583 .43604 .4284 .4304 Mtetra
.614 .801 .971 r
.4284 .4304 .43583 .43604 .44846 .43306 .44109 .42699 Mtetra
.624 .792 .962 r
.44109 .42699 .44846 .43306 .46118 .42941 .45384 .42342 Mtetra
.63 .797 .963 r
.45384 .42342 .46118 .42941 .47396 .42546 .46666 .41968 Mtetra
.635 .807 .965 r
.46666 .41968 .47396 .42546 .4868 .42136 .47955 .41575 Mtetra
.641 .815 .966 r
.47955 .41575 .4868 .42136 .49971 .41717 .4925 .4116 Mtetra
.648 .819 .966 r
.4925 .4116 .49971 .41717 .51267 .41287 .50552 .40726 Mtetra
.656 .822 .963 r
.50552 .40726 .51267 .41287 .5257 .40841 .5186 .40269 Mtetra
.67 .823 .957 r
.5186 .40269 .5257 .40841 .53879 .40371 .53174 .39775 Mtetra
.681 .82 .95 r
.53174 .39775 .53879 .40371 .55193 .39836 .54493 .39253 Mtetra
.685 .826 .951 r
.54493 .39253 .55193 .39836 .56512 .39216 .55818 .38714 Mtetra
.647 .843 .976 r
.55818 .38714 .56512 .39216 .57837 .38688 .5715 .38254 Mtetra
.322 .719 .98 r
.5715 .38254 .57837 .38688 .59182 .3885 .58497 .38278 Mtetra
0 .148 .614 r
.58497 .38278 .59182 .3885 .60571 .40307 .59878 .39296 Mtetra
0 .088 .634 r
.59878 .39296 .60571 .40307 .61995 .42175 .61289 .40743 Mtetra
.508 .554 .838 r
.61289 .40743 .61995 .42175 .63385 .42259 .62681 .40833 Mtetra
.811 .696 .739 r
.62681 .40833 .63385 .42259 .64707 .40234 .64018 .39103 Mtetra
.861 .747 .736 r
.64018 .39103 .64707 .40234 .66013 .37987 .65339 .37071 Mtetra
.817 .779 .817 r
.65339 .37071 .66013 .37987 .67351 .3663 .66687 .3578 Mtetra
.722 .772 .892 r
.66687 .3578 .67351 .3663 .68721 .35918 .68062 .35075 Mtetra
.669 .756 .916 r
.68062 .35075 .68721 .35918 .70107 .35417 .69453 .3457 Mtetra
.657 .752 .92 r
.69453 .3457 .70107 .35417 .71502 .34955 .70853 .34103 Mtetra
.656 .751 .92 r
.70853 .34103 .71502 .34955 .72905 .34494 .7226 .33638 Mtetra
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.26038 .47909 .26828 .4864 .28025 .48245 .27238 .4751 Mtetra
.654 .751 .921 r
.27238 .4751 .28025 .48245 .29227 .47852 .28444 .47114 Mtetra
.642 .748 .925 r
.28444 .47114 .29227 .47852 .30433 .47497 .29653 .4675 Mtetra
.573 .723 .944 r
.29653 .4675 .30433 .47497 .31631 .47337 .30856 .46556 Mtetra
.269 .569 .937 r
.30856 .46556 .31631 .47337 .32803 .47748 .32037 .46844 Mtetra
0 .222 .731 r
.32037 .46844 .32803 .47748 .33946 .48883 .33193 .47729 Mtetra
.165 .403 .846 r
.33193 .47729 .33946 .48883 .35122 .49716 .34378 .48376 Mtetra
.707 .653 .793 r
.34378 .48376 .35122 .49716 .36399 .48764 .35649 .47605 Mtetra
.83 .714 .737 r
.35649 .47605 .36399 .48764 .37738 .46482 .36973 .45759 Mtetra
.854 .786 .785 r
.36973 .45759 .37738 .46482 .39051 .44628 .38281 .44175 Mtetra
.783 .864 .909 r
.38281 .44175 .39051 .44628 .40322 .43757 .39558 .43318 Mtetra
.653 .853 .976 r
.39558 .43318 .40322 .43757 .41579 .43362 .40822 .42859 Mtetra
.62 .824 .979 r
.40822 .42859 .41579 .43362 .4284 .4304 .42089 .42486 Mtetra
.633 .812 .969 r
.42089 .42486 .4284 .4304 .44109 .42699 .43364 .42096 Mtetra
.645 .801 .958 r
.43364 .42096 .44109 .42699 .45384 .42342 .44644 .41684 Mtetra
.651 .787 .947 r
.44644 .41684 .45384 .42342 .46666 .41968 .45932 .41262 Mtetra
.653 .774 .937 r
.45932 .41262 .46666 .41968 .47955 .41575 .47225 .40836 Mtetra
.654 .766 .931 r
.47225 .40836 .47955 .41575 .4925 .4116 .48525 .40407 Mtetra
.656 .763 .929 r
.48525 .40407 .4925 .4116 .50552 .40726 .49831 .39972 Mtetra
.654 .764 .93 r
.49831 .39972 .50552 .40726 .5186 .40269 .51143 .3954 Mtetra
.647 .77 .938 r
.51143 .3954 .5186 .40269 .53174 .39775 .52461 .39126 Mtetra
.646 .795 .954 r
.52461 .39126 .53174 .39775 .54493 .39253 .53786 .387 Mtetra
.654 .829 .967 r
.53786 .387 .54493 .39253 .55818 .38714 .55117 .38234 Mtetra
.619 .843 .985 r
.55117 .38234 .55818 .38714 .5715 .38254 .56455 .37822 Mtetra
.355 .741 .987 r
.56455 .37822 .5715 .38254 .58497 .38278 .57807 .37798 Mtetra
0 .298 .716 r
.57807 .37798 .58497 .38278 .59878 .39296 .59184 .38516 Mtetra
0 .245 .74 r
.59184 .38516 .59878 .39296 .61289 .40743 .60584 .395 Mtetra
.558 .615 .866 r
.60584 .395 .61289 .40743 .62681 .40833 .61972 .39389 Mtetra
.793 .689 .749 r
.61972 .39389 .62681 .40833 .64018 .39103 .6332 .37842 Mtetra
.831 .724 .747 r
.6332 .37842 .64018 .39103 .65339 .37071 .64657 .36062 Mtetra
.792 .756 .82 r
.64657 .36062 .65339 .37071 .66687 .3578 .66015 .34894 Mtetra
.713 .762 .891 r
.66015 .34894 .66687 .3578 .68062 .35075 .67398 .34218 Mtetra
.667 .754 .915 r
.67398 .34218 .68062 .35075 .69453 .3457 .68794 .33714 Mtetra
.657 .752 .92 r
.68794 .33714 .69453 .3457 .70853 .34103 .70198 .33243 Mtetra
.656 .751 .92 r
.70198 .33243 .70853 .34103 .7226 .33638 .7161 .32774 Mtetra
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Mtetra
.655 .751 .921 r
.26445 .46769 .27238 .4751 .28444 .47114 .27654 .46368 Mtetra
.646 .748 .924 r
.27654 .46368 .28444 .47114 .29653 .4675 .28867 .45992 Mtetra
.595 .73 .938 r
.28867 .45992 .29653 .4675 .30856 .46556 .30077 .45744 Mtetra
.396 .63 .948 r
.30077 .45744 .30856 .46556 .32037 .46844 .31269 .45874 Mtetra
.068 .391 .851 r
.31269 .45874 .32037 .46844 .33193 .47729 .3244 .46509 Mtetra
.249 .44 .853 r
.3244 .46509 .33193 .47729 .34378 .48376 .33629 .4706 Mtetra
.658 .637 .818 r
.33629 .4706 .34378 .48376 .35649 .47605 .34886 .46573 Mtetra
.811 .73 .775 r
.34886 .46573 .35649 .47605 .36973 .45759 .36196 .45137 Mtetra
.848 .811 .814 r
.36196 .45137 .36973 .45759 .38281 .44175 .37503 .43737 Mtetra
.791 .87 .907 r
.37503 .43737 .38281 .44175 .39558 .43318 .38787 .42844 Mtetra
.695 .852 .958 r
.38787 .42844 .39558 .43318 .40822 .42859 .4006 .42283 Mtetra
.657 .813 .958 r
.4006 .42283 .40822 .42859 .42089 .42486 .41334 .41838 Mtetra
.646 .788 .95 r
.41334 .41838 .42089 .42486 .43364 .42096 .42613 .4143 Mtetra
.64 .782 .949 r
.42613 .4143 .43364 .42096 .44644 .41684 .43897 .41035 Mtetra
.638 .788 .954 r
.43897 .41035 .44644 .41684 .45932 .41262 .45188 .40642 Mtetra
.638 .798 .959 r
.45188 .40642 .45932 .41262 .47225 .40836 .46486 .4024 Mtetra
.639 .807 .963 r
.46486 .4024 .47225 .40836 .48525 .40407 .4779 .39829 Mtetra
.641 .814 .966 r
.4779 .39829 .48525 .40407 .49831 .39972 .49101 .39406 Mtetra
.65 .822 .966 r
.49101 .39406 .49831 .39972 .51143 .3954 .50418 .38955 Mtetra
.672 .823 .956 r
.50418 .38955 .51143 .3954 .52461 .39126 .51742 .3845 Mtetra
.674 .797 .94 r
.51742 .3845 .52461 .39126 .53786 .387 .53071 .37943 Mtetra
.644 .765 .936 r
.53071 .37943 .53786 .387 .55117 .38234 .54407 .37528 Mtetra
.577 .756 .963 r
.54407 .37528 .55117 .38234 .56455 .37822 .55752 .37273 Mtetra
.347 .698 .983 r
.55752 .37273 .56455 .37822 .57807 .37798 .57109 .37332 Mtetra
0 .423 .809 r
.57109 .37332 .57807 .37798 .59184 .38516 .58486 .37855 Mtetra
.046 .469 .883 r
.58486 .37855 .59184 .38516 .60584 .395 .59878 .38386 Mtetra
.643 .682 .872 r
.59878 .38386 .60584 .395 .61972 .39389 .61259 .37961 Mtetra
.787 .689 .757 r
.61259 .37961 .61972 .39389 .6332 .37842 .62615 .36505 Mtetra
.802 .706 .76 r
.62615 .36505 .6332 .37842 .64657 .36062 .63967 .34983 Mtetra
.763 .736 .828 r
.63967 .34983 .64657 .36062 .66015 .34894 .65337 .33975 Mtetra
.699 .751 .892 r
.65337 .33975 .66015 .34894 .67398 .34218 .66726 .33348 Mtetra
.665 .752 .915 r
.66726 .33348 .67398 .34218 .68794 .33714 .68128 .3285 Mtetra
.657 .751 .92 r
.68128 .3285 .68794 .33714 .70198 .33243 .69537 .32376 Mtetra
.656 .751 .92 r
.69537 .32376 .70198 .33243 .7161 .32774 .70954 .31902 Mtetra
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Mtetra
.655 .751 .921 r
.25645 .46022 .26445 .46769 .27654 .46368 .26857 .45616 Mtetra
.65 .749 .922 r
.26857 .45616 .27654 .46368 .28867 .45992 .28074 .45225 Mtetra
.619 .737 .931 r
.28074 .45225 .28867 .45992 .30077 .45744 .29291 .44917 Mtetra
.5 .675 .943 r
.29291 .44917 .30077 .45744 .31269 .45874 .30496 .44877 Mtetra
.276 .513 .901 r
.30496 .44877 .31269 .45874 .3244 .46509 .31683 .45262 Mtetra
.293 .462 .856 r
.31683 .45262 .3244 .46509 .33629 .4706 .32875 .45747 Mtetra
.581 .604 .84 r
.32875 .45747 .33629 .4706 .34886 .46573 .34117 .45569 Mtetra
.77 .729 .814 r
.34117 .45569 .34886 .46573 .36196 .45137 .35411 .44535 Mtetra
.834 .82 .836 r
.35411 .44535 .36196 .45137 .37503 .43737 .36717 .43288 Mtetra
.799 .868 .899 r
.36717 .43288 .37503 .43737 .38787 .42844 .38008 .4235 Mtetra
.716 .851 .946 r
.38008 .4235 .38787 .42844 .4006 .42283 .39289 .41727 Mtetra
.668 .823 .958 r
.39289 .41727 .4006 .42283 .41334 .41838 .40569 .41247 Mtetra
.655 .81 .958 r
.40569 .41247 .41334 .41838 .42613 .4143 .41853 .408 Mtetra
.655 .799 .952 r
.41853 .408 .42613 .4143 .43897 .41035 .43144 .40358 Mtetra
.655 .786 .944 r
.43144 .40358 .43897 .41035 .45188 .40642 .4444 .39918 Mtetra
.654 .773 .936 r
.4444 .39918 .45188 .40642 .46486 .4024 .45742 .39482 Mtetra
.653 .764 .931 r
.45742 .39482 .46486 .4024 .4779 .39829 .47051 .39049 Mtetra
.649 .758 .929 r
.47051 .39049 .4779 .39829 .49101 .39406 .48366 .38628 Mtetra
.632 .753 .935 r
.48366 .38628 .49101 .39406 .50418 .38955 .49687 .38253 Mtetra
.596 .764 .959 r
.49687 .38253 .50418 .38955 .51742 .3845 .51014 .37955 Mtetra
.584 .828 .991 r
.51014 .37955 .51742 .3845 .53071 .37943 .52349 .37615 Mtetra
.605 .888 .99 r
.52349 .37615 .53071 .37943 .54407 .37528 .53691 .37156 Mtetra
.55 .855 .997 r
.53691 .37156 .54407 .37528 .55752 .37273 .55041 .3681 Mtetra
.314 .71 .979 r
.55041 .3681 .55752 .37273 .57109 .37332 .56403 .36849 Mtetra
.064 .541 .895 r
.56403 .36849 .57109 .37332 .58486 .37855 .57781 .37198 Mtetra
.37 .678 .977 r
.57781 .37198 .58486 .37855 .59878 .38386 .59167 .37284 Mtetra
.719 .716 .847 r
.59167 .37284 .59878 .38386 .61259 .37961 .60543 .36516 Mtetra
.778 .685 .761 r
.60543 .36516 .61259 .37961 .62615 .36505 .61905 .35131 Mtetra
.771 .692 .776 r
.61905 .35131 .62615 .36505 .63967 .34983 .63271 .33873 Mtetra
.731 .721 .841 r
.63271 .33873 .63967 .34983 .65337 .33975 .64652 .3304 Mtetra
.683 .743 .896 r
.64652 .3304 .65337 .33975 .66726 .33348 .66049 .32468 Mtetra
.661 .75 .916 r
.66049 .32468 .66726 .33348 .68128 .3285 .67456 .31977 Mtetra
.656 .751 .92 r
.67456 .31977 .68128 .3285 .69537 .32376 .6887 .315 Mtetra
.6887 .315 .69537 .32376 .70954 .31902 .70292 .31022 Mtetra
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28105 Mtetra
.78974 .28105 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Mtetra
.655 .751 .92 r
.24838 .45268 .25645 .46022 .26857 .45616 .26053 .44858 Mtetra
.653 .75 .921 r
.26053 .44858 .26857 .45616 .28074 .45225 .27275 .44454 Mtetra
.637 .743 .925 r
.27275 .44454 .28074 .45225 .29291 .44917 .28498 .44093 Mtetra
.574 .708 .933 r
.28498 .44093 .29291 .44917 .30496 .44877 .29716 .43895 Mtetra
.431 .602 .918 r
.29716 .43895 .30496 .44877 .31683 .45262 .3092 .44024 Mtetra
.35 .498 .866 r
.3092 .44024 .31683 .45262 .32875 .45747 .32119 .44396 Mtetra
.493 .555 .847 r
.32119 .44396 .32875 .45747 .34117 .45569 .33345 .44486 Mtetra
.692 .693 .846 r
.33345 .44486 .34117 .45569 .35411 .44535 .3462 .4388 Mtetra
.801 .811 .859 r
.3462 .4388 .35411 .44535 .36717 .43288 .35921 .42846 Mtetra
.804 .871 .897 r
.35921 .42846 .36717 .43288 .38008 .4235 .3722 .41881 Mtetra
.747 .864 .934 r
.3722 .41881 .38008 .4235 .39289 .41727 .38511 .4115 Mtetra
.695 .825 .945 r
.38511 .4115 .39289 .41727 .40569 .41247 .39798 .40591 Mtetra
.665 .795 .944 r
.39798 .40591 .40569 .41247 .41853 .408 .41088 .40123 Mtetra
.65 .785 .946 r
.41088 .40123 .41853 .408 .43144 .40358 .42382 .39695 Mtetra
.644 .789 .952 r
.42382 .39695 .43144 .40358 .4444 .39918 .43682 .3928 Mtetra
.642 .797 .957 r
.43682 .3928 .4444 .39918 .45742 .39482 .44989 .38862 Mtetra
.646 .805 .959 r
.44989 .38862 .45742 .39482 .47051 .39049 .46302 .38429 Mtetra
.658 .81 .956 r
.46302 .38429 .47051 .39049 .48366 .38628 .47622 .37962 Mtetra
.686 .805 .938 r
.47622 .37962 .48366 .38628 .49687 .38253 .48949 .37415 Mtetra
.69 .759 .904 r
.48949 .37415 .49687 .38253 .51014 .37955 .50283 .36845 Mtetra
.605 .663 .88 r
.50283 .36845 .51014 .37955 .52349 .37615 .5162 .36562 Mtetra
.514 .635 .907 r
.5162 .36562 .52349 .37615 .53691 .37156 .52967 .36531 Mtetra
.444 .727 .986 r
.52967 .36531 .53691 .37156 .55041 .3681 .54323 .36483 Mtetra
.252 .714 .949 r
.54323 .36483 .55041 .3681 .56403 .36849 .5569 .36491 Mtetra
.283 .725 .963 r
.5569 .36491 .56403 .36849 .57781 .37198 .57068 .36486 Mtetra
.643 .788 .951 r
.57068 .36486 .57781 .37198 .59167 .37284 .58448 .36048 Mtetra
.754 .706 .806 r
.58448 .36048 .59167 .37284 .60543 .36516 .59822 .35003 Mtetra
.757 .67 .765 r
.59822 .35003 .60543 .36516 .61905 .35131 .61192 .33763 Mtetra
.735 .68 .797 r
.61192 .33763 .61905 .35131 .63271 .33873 .6257 .32781 Mtetra
.7 .715 .86 r
.6257 .32781 .63271 .33873 .64652 .3304 .63962 .32107 Mtetra
.67 .741 .903 r
.63962 .32107 .64652 .3304 .66049 .32468 .65366 .31582 Mtetra
.658 .749 .917 r
.65366 .31582 .66049 .32468 .67456 .31977 .66778 .31097 Mtetra
.656 .751 .92 r
.66778 .31097 .67456 .31977 .6887 .315 .68197 .30616 Mtetra
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Mtetra
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28105 .78336 .2719 Mtetra
.78336 .2719 .78974 .28105 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Mtetra
.24024 .44508 .24838 .45268 .26053 .44858 .25243 .44094 Mtetra
.655 .751 .921 r
.25243 .44094 .26053 .44858 .27275 .44454 .26468 .4368 Mtetra
.649 .748 .922 r
.26468 .4368 .27275 .44454 .28498 .44093 .27697 .43283 Mtetra
.621 .73 .925 r
.27697 .43283 .28498 .44093 .29716 .43895 .28926 .42964 Mtetra
.543 .669 .92 r
.28926 .42964 .29716 .43895 .3092 .44024 .30148 .42849 Mtetra
.442 .564 .882 r
.30148 .42849 .3092 .44024 .32119 .44396 .3136 .43012 Mtetra
.445 .524 .845 r
.3136 .43012 .32119 .44396 .33345 .44486 .32579 .43227 Mtetra
.577 .615 .854 r
.32579 .43227 .33345 .44486 .3462 .4388 .33831 .43051 Mtetra
.727 .761 .88 r
.33831 .43051 .3462 .4388 .35921 .42846 .35119 .42349 Mtetra
.788 .857 .902 r
.35119 .42349 .35921 .42846 .3722 .41881 .36421 .41446 Mtetra
.761 .877 .93 r
.36421 .41446 .3722 .41881 .38511 .4115 .3772 .40661 Mtetra
.712 .856 .951 r
.3772 .40661 .38511 .4115 .39798 .40591 .39016 .4004 Mtetra
.68 .832 .956 r
.39016 .4004 .39798 .40591 .41088 .40123 .40312 .39512 Mtetra
.667 .812 .953 r
.40312 .39512 .41088 .40123 .42382 .39695 .41613 .39026 Mtetra
.657 .793 .947 r
.41613 .39026 .42382 .39695 .43682 .3928 .42919 .38571 Mtetra
.652 .781 .942 r
.42919 .38571 .43682 .3928 .44989 .38862 .4423 .38132 Mtetra
.642 .772 .943 r
.4423 .38132 .44989 .38862 .46302 .38429 .45547 .3772 Mtetra
.628 .775 .952 r
.45547 .3772 .46302 .38429 .47622 .37962 .4687 .3734 Mtetra
.598 .793 .974 r
.4687 .3734 .47622 .37962 .48949 .37415 .482 .3701 Mtetra
.618 .869 .99 r
.482 .3701 .48949 .37415 .50283 .36845 .49538 .3656 Mtetra
.673 .92 .974 r
.49538 .3656 .50283 .36845 .5162 .36562 .50884 .3594 Mtetra
.409 .712 .985 r
.50884 .3594 .5162 .36562 .52967 .36531 .52234 .35939 Mtetra
.288 .656 .97 r
.52234 .35939 .52967 .36531 .54323 .36483 .53596 .36087 Mtetra
.41 .787 .992 r
.53596 .36087 .54323 .36483 .5569 .36491 .54967 .35948 Mtetra
.656 .845 .973 r
.54967 .35948 .5569 .36491 .57068 .36486 .56344 .35442 Mtetra
.747 .739 .845 r
.56344 .35442 .57068 .36486 .58448 .36048 .5772 .34542 Mtetra
.74 .664 .775 r
.5772 .34542 .58448 .36048 .59822 .35003 .59096 .33451 Mtetra
.721 .65 .778 r
.59096 .33451 .59822 .35003 .61192 .33763 .60476 .32476 Mtetra
.699 .679 .827 r
.60476 .32476 .61192 .33763 .6257 .32781 .61866 .3175 Mtetra
.676 .72 .883 r
.61866 .3175 .6257 .32781 .63962 .32107 .63267 .3119 Mtetra
.661 .743 .911 r
.63267 .3119 .63962 .32107 .65366 .31582 .64676 .30693 Mtetra
.657 .75 .919 r
.64676 .30693 .65366 .31582 .66778 .31097 .66093 .30209 Mtetra
.656 .751 .92 r
.66093 .30209 .66778 .31097 .68197 .30616 .67517 .29725 Mtetra
.67517 .29725 .68197 .30616 .69623 .30134 .68949 .29238 Mtetra
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26768 Mtetra
.76217 .26768 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Mtetra
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Mtetra
.24425 .43323 .25243 .44094 .26468 .4368 .25654 .42904 Mtetra
.654 .75 .921 r
.25654 .42904 .26468 .4368 .27697 .43283 .26887 .42488 Mtetra
.645 .743 .921 r
.26887 .42488 .27697 .43283 .28926 .42964 .28125 .42097 Mtetra
.612 .715 .918 r
.28125 .42097 .28926 .42964 .30148 .42849 .29362 .41799 Mtetra
.546 .644 .898 r
.29362 .41799 .30148 .42849 .3136 .43012 .30593 .41691 Mtetra
.483 .557 .856 r
.30593 .41691 .3136 .43012 .32579 .43227 .31819 .4179 Mtetra
.495 .544 .836 r
.31819 .4179 .32579 .43227 .33831 .43051 .33056 .41879 Mtetra
.591 .64 .868 r
.33056 .41879 .33831 .43051 .35119 .42349 .3432 .41649 Mtetra
.714 .794 .914 r
.3432 .41649 .35119 .42349 .36421 .41446 .35613 .41018 Mtetra
.764 .88 .93 r
.35613 .41018 .36421 .41446 .3772 .40661 .36919 .40216 Mtetra
.744 .875 .941 r
.36919 .40216 .3772 .40661 .39016 .4004 .38225 .39484 Mtetra
.699 .837 .949 r
.38225 .39484 .39016 .4004 .40312 .39512 .39529 .38901 Mtetra
.667 .814 .954 r
.39529 .38901 .40312 .39512 .41613 .39026 .40834 .38411 Mtetra
.645 .808 .961 r
.40834 .38411 .41613 .39026 .42919 .38571 .42144 .37975 Mtetra
.643 .814 .965 r
.42144 .37975 .42919 .38571 .4423 .38132 .4346 .37539 Mtetra
.632 .813 .97 r
.4346 .37539 .4423 .38132 .45547 .3772 .44782 .37124 Mtetra
.656 .82 .963 r
.44782 .37124 .45547 .3772 .4687 .3734 .46112 .3665 Mtetra
.521 .743 .976 r
.46112 .3665 .4687 .3734 .482 .3701 .47443 .36492 Mtetra
.591 .049 0 r
.47443 .36492 .482 .3701 .49538 .3656 .48767 .37764 Mtetra
.393 0 .078 r
.48767 .37764 .49538 .3656 .50884 .3594 .50122 .37683 Mtetra
.067 0 .034 r
.50122 .37683 .50884 .3594 .52234 .35939 .51491 .36422 Mtetra
.423 .821 .606 r
.51491 .36422 .52234 .35939 .53596 .36087 .5286 .35481 Mtetra
.758 .849 .919 r
.5286 .35481 .53596 .36087 .54967 .35948 .54232 .34655 Mtetra
.725 .687 .813 r
.54232 .34655 .54967 .35948 .56344 .35442 .55608 .33774 Mtetra
.705 .63 .77 r
.55608 .33774 .56344 .35442 .5772 .34542 .56986 .32861 Mtetra
.692 .622 .774 r
.56986 .32861 .5772 .34542 .59096 .33451 .58369 .32032 Mtetra
.683 .652 .813 r
.58369 .32032 .59096 .33451 .60476 .32476 .59759 .3135 Mtetra
.672 .699 .867 r
.59759 .3135 .60476 .32476 .61866 .3175 .61158 .30791 Mtetra
.662 .734 .903 r
.61158 .30791 .61866 .3175 .63267 .3119 .62565 .30287 Mtetra
.657 .748 .917 r
.62565 .30287 .63267 .3119 .64676 .30693 .6398 .298 Mtetra
.656 .751 .92 r
.6398 .298 .64676 .30693 .66093 .30209 .65402 .29313 Mtetra
.65402 .29313 .66093 .30209 .67517 .29725 .66831 .28824 Mtetra
.66831 .28824 .67517 .29725 .68949 .29238 .68268 .28333 Mtetra
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .2784 Mtetra
.69712 .2784 .70388 .28749 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26845 Mtetra
.72622 .26845 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26768 .75562 .25839 Mtetra
.75562 .25839 .76217 .26768 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Mtetra
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Mtetra
.236 .42546 .24425 .43323 .25654 .42904 .24832 .42123 Mtetra
.655 .751 .92 r
.24832 .42123 .25654 .42904 .26887 .42488 .2607 .41698 Mtetra
.653 .749 .92 r
.2607 .41698 .26887 .42488 .28125 .42097 .27313 .41278 Mtetra
.644 .74 .918 r
.27313 .41278 .28125 .42097 .29362 .41799 .2856 .40883 Mtetra
.618 .707 .909 r
.2856 .40883 .29362 .41799 .30593 .41691 .29808 .40566 Mtetra
.571 .641 .881 r
.29808 .40566 .30593 .41691 .31819 .4179 .31052 .40394 Mtetra
.526 .569 .841 r
.31052 .40394 .31819 .4179 .33056 .41879 .32295 .40377 Mtetra
.52 .549 .826 r
.32295 .40377 .33056 .41879 .3432 .41649 .33546 .40393 Mtetra
.565 .615 .861 r
.33546 .40393 .3432 .41649 .35613 .41018 .34815 .40242 Mtetra
.65 .76 .93 r
.34815 .40242 .35613 .41018 .36919 .40216 .36106 .39814 Mtetra
.706 .885 .963 r
.36106 .39814 .36919 .40216 .38225 .39484 .37413 .39184 Mtetra
.713 .916 .964 r
.37413 .39184 .38225 .39484 .39529 .38901 .38727 .38504 Mtetra
.696 .887 .968 r
.38727 .38504 .39529 .38901 .40834 .38411 .40043 .37891 Mtetra
.671 .846 .967 r
.40043 .37891 .40834 .38411 .42144 .37975 .41361 .37369 Mtetra
.634 .81 .967 r
.41361 .37369 .42144 .37975 .4346 .37539 .42682 .36951 Mtetra
.582 .8 .982 r
.42682 .36951 .4346 .37539 .44782 .37124 .44006 .3664 Mtetra
.358 .732 .988 r
.44006 .3664 .44782 .37124 .46112 .3665 .45331 .36623 Mtetra
.138 0 0 r
.45331 .36623 .46112 .3665 .47443 .36492 .46663 .3679 Mtetra
.791 .995 .779 r
.46663 .3679 .47443 .36492 .48767 .37764 .48029 .35411 Mtetra
.726 .585 .697 r
.48029 .35411 .48767 .37764 .50122 .37683 .49395 .33922 Mtetra
.566 .43 .655 r
.49395 .33922 .50122 .37683 .51491 .36422 .50752 .33645 Mtetra
.593 .484 .699 r
.50752 .33645 .51491 .36422 .5286 .35481 .52118 .33253 Mtetra
.629 .539 .734 r
.52118 .33253 .5286 .35481 .54232 .34655 .5349 .3269 Mtetra
.646 .57 .755 r
.5349 .3269 .54232 .34655 .55608 .33774 .54868 .32076 Mtetra
.656 .603 .783 r
.54868 .32076 .55608 .33774 .56986 .32861 .56252 .31466 Mtetra
.662 .647 .825 r
.56252 .31466 .56986 .32861 .58369 .32032 .57643 .30899 Mtetra
.662 .695 .87 r
.57643 .30899 .58369 .32032 .59759 .3135 .59041 .30375 Mtetra
.659 .73 .902 r
.59041 .30375 .59759 .3135 .61158 .30791 .60446 .29878 Mtetra
.657 .746 .915 r
.60446 .29878 .61158 .30791 .62565 .30287 .61858 .29388 Mtetra
.656 .75 .92 r
.61858 .29388 .62565 .30287 .6398 .298 .63278 .289 Mtetra
.656 .751 .92 r
.63278 .289 .6398 .298 .65402 .29313 .64705 .28409 Mtetra
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Mtetra
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Mtetra
.6758 .2742 .68268 .28333 .69712 .2784 .69029 .26921 Mtetra
.69029 .26921 .69712 .2784 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26845 .7195 .25917 Mtetra
.7195 .25917 .72622 .26845 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Mtetra
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Mtetra
.24004 .41335 .24832 .42123 .2607 .41698 .25245 .40906 Mtetra
.655 .751 .92 r
.25245 .40906 .2607 .41698 .27313 .41278 .26492 .40475 Mtetra
.654 .749 .92 r
.26492 .40475 .27313 .41278 .2856 .40883 .27745 .40048 Mtetra
.648 .739 .916 r
.27745 .40048 .2856 .40883 .29808 .40566 .29002 .39637 Mtetra
.632 .711 .904 r
.29002 .39637 .29808 .40566 .31052 .40394 .30262 .39273 Mtetra
.603 .658 .876 r
.30262 .39273 .31052 .40394 .32295 .40377 .31523 .38996 Mtetra
.572 .596 .838 r
.31523 .38996 .32295 .40377 .33546 .40393 .32785 .38824 Mtetra
.554 .559 .813 r
.32785 .38824 .33546 .40393 .34815 .40242 .34051 .3872 Mtetra
.559 .569 .82 r
.34051 .3872 .34815 .40242 .36106 .39814 .35327 .38597 Mtetra
.586 .634 .866 r
.35327 .38597 .36106 .39814 .37413 .39184 .36617 .38372 Mtetra
.622 .745 .935 r
.36617 .38372 .37413 .39184 .38727 .38504 .37921 .38016 Mtetra
.633 .846 .982 r
.37921 .38016 .38727 .38504 .40043 .37891 .39235 .37571 Mtetra
.611 .89 .989 r
.39235 .37571 .40043 .37891 .41361 .37369 .40557 .371 Mtetra
.577 .893 .988 r
.40557 .371 .41361 .37369 .42682 .36951 .41885 .36656 Mtetra
.571 .885 .991 r
.41885 .36656 .42682 .36951 .44006 .3664 .43218 .36232 Mtetra
.642 .877 .985 r
.43218 .36232 .44006 .3664 .45331 .36623 .44561 .35727 Mtetra
.754 .769 .865 r
.44561 .35727 .45331 .36623 .46663 .3679 .45917 .34848 Mtetra
.727 .613 .731 r
.45917 .34848 .46663 .3679 .48029 .35411 .47282 .3361 Mtetra
.68 .603 .762 r
.47282 .3361 .48029 .35411 .49395 .33922 .48642 .32819 Mtetra
.663 .698 .872 r
.48642 .32819 .49395 .33922 .50752 .33645 .50004 .32303 Mtetra
.638 .643 .839 r
.50004 .32303 .50752 .33645 .52118 .33253 .51372 .3186 Mtetra
.637 .635 .832 r
.51372 .3186 .52118 .33253 .5349 .3269 .52747 .31411 Mtetra
.647 .659 .848 r
.52747 .31411 .5349 .3269 .54868 .32076 .54129 .30935 Mtetra
.654 .69 .871 r
.54129 .30935 .54868 .32076 .56252 .31466 .55518 .30446 Mtetra
.657 .719 .894 r
.55518 .30446 .56252 .31466 .57643 .30899 .56914 .29954 Mtetra
.657 .737 .909 r
.56914 .29954 .57643 .30899 .59041 .30375 .58317 .29465 Mtetra
.656 .747 .917 r
.58317 .29465 .59041 .30375 .60446 .29878 .59727 .28975 Mtetra
.656 .75 .92 r
.59727 .28975 .60446 .29878 .61858 .29388 .61144 .28485 Mtetra
.656 .751 .92 r
.61144 .28485 .61858 .29388 .63278 .289 .62569 .27991 Mtetra
.62569 .27991 .63278 .289 .64705 .28409 .64001 .27496 Mtetra
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Mtetra
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Mtetra
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Mtetra
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Mtetra
.24413 .40107 .25245 .40906 .26492 .40475 .25663 .39672 Mtetra
.25663 .39672 .26492 .40475 .27745 .40048 .2692 .39235 Mtetra
.655 .749 .919 r
.2692 .39235 .27745 .40048 .29002 .39637 .28182 .38799 Mtetra
.652 .743 .916 r
.28182 .38799 .29002 .39637 .30262 .39273 .2945 .38369 Mtetra
.645 .725 .907 r
.2945 .38369 .30262 .39273 .31523 .38996 .30723 .37958 Mtetra
.632 .689 .886 r
.30723 .37958 .31523 .38996 .32785 .38824 .32 .37583 Mtetra
.615 .643 .854 r
.32 .37583 .32785 .38824 .34051 .3872 .3328 .37255 Mtetra
.601 .6 .822 r
.3328 .37255 .34051 .3872 .35327 .38597 .34566 .36967 Mtetra
.594 .574 .801 r
.34566 .36967 .35327 .38597 .36617 .38372 .35858 .36695 Mtetra
.596 .57 .795 r
.35858 .36695 .36617 .38372 .37921 .38016 .37159 .36408 Mtetra
.608 .585 .802 r
.37159 .36408 .37921 .38016 .39235 .37571 .38469 .36073 Mtetra
.627 .61 .814 r
.38469 .36073 .39235 .37571 .40557 .371 .3979 .35665 Mtetra
.648 .63 .818 r
.3979 .35665 .40557 .371 .41885 .36656 .41121 .35167 Mtetra
.666 .631 .805 r
.41121 .35167 .41885 .36656 .43218 .36232 .42461 .34565 Mtetra
.677 .614 .779 r
.42461 .34565 .43218 .36232 .44561 .35727 .4381 .33845 Mtetra
.672 .591 .756 r
.4381 .33845 .44561 .35727 .45917 .34848 .45164 .33084 Mtetra
.656 .595 .774 r
.45164 .33084 .45917 .34848 .47282 .3361 .46521 .32457 Mtetra
.659 .687 .865 r
.46521 .32457 .47282 .3361 .48642 .32819 .4788 .31952 Mtetra
.657 .753 .921 r
.4788 .31952 .48642 .32819 .50004 .32303 .49246 .31474 Mtetra
.655 .764 .929 r
.49246 .31474 .50004 .32303 .51372 .3186 .50619 .30997 Mtetra
.657 .756 .923 r
.50619 .30997 .51372 .3186 .52747 .31411 .51998 .30512 Mtetra
.657 .748 .917 r
.51998 .30512 .52747 .31411 .54129 .30935 .53385 .30025 Mtetra
.656 .746 .916 r
.53385 .30025 .54129 .30935 .55518 .30446 .54779 .29538 Mtetra
.656 .748 .918 r
.54779 .29538 .55518 .30446 .56914 .29954 .56179 .2905 Mtetra
.656 .75 .919 r
.56179 .2905 .56914 .29954 .58317 .29465 .57587 .2856 Mtetra
.656 .751 .92 r
.57587 .2856 .58317 .29465 .59727 .28975 .59002 .28068 Mtetra
.59002 .28068 .59727 .28975 .61144 .28485 .60424 .27573 Mtetra
.60424 .27573 .61144 .28485 .62569 .27991 .61853 .27075 Mtetra
.61853 .27075 .62569 .27991 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Mtetra
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Mtetra
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38422 Mtetra
.26087 .38422 .2692 .39235 .28182 .38799 .27353 .37978 Mtetra
.655 .75 .92 r
.27353 .37978 .28182 .38799 .2945 .38369 .28626 .37534 Mtetra
.655 .747 .918 r
.28626 .37534 .2945 .38369 .30723 .37958 .29904 .37089 Mtetra
.653 .739 .913 r
.29904 .37089 .30723 .37958 .32 .37583 .31189 .36647 Mtetra
.649 .722 .902 r
.31189 .36647 .32 .37583 .3328 .37255 .32479 .36215 Mtetra
.643 .697 .885 r
.32479 .36215 .3328 .37255 .34566 .36967 .33774 .35797 Mtetra
.637 .668 .864 r
.33774 .35797 .34566 .36967 .35858 .36695 .35076 .35387 Mtetra
.633 .642 .841 r
.35076 .35387 .35858 .36695 .37159 .36408 .36384 .34973 Mtetra
.633 .623 .822 r
.36384 .34973 .37159 .36408 .38469 .36073 .377 .34545 Mtetra
.635 .611 .809 r
.377 .34545 .38469 .36073 .3979 .35665 .39024 .34092 Mtetra
.639 .608 .802 r
.39024 .34092 .3979 .35665 .41121 .35167 .40355 .33608 Mtetra
.645 .613 .803 r
.40355 .33608 .41121 .35167 .42461 .34565 .41694 .33096 Mtetra
.649 .628 .815 r
.41694 .33096 .42461 .34565 .4381 .33845 .43039 .32578 Mtetra
.656 .664 .846 r
.43039 .32578 .4381 .33845 .45164 .33084 .4439 .32065 Mtetra
.668 .72 .888 r
.4439 .32065 .45164 .33084 .46521 .32457 .45748 .31539 Mtetra
.665 .744 .909 r
.45748 .31539 .46521 .32457 .4788 .31952 .47112 .31029 Mtetra
.653 .739 .913 r
.47112 .31029 .4788 .31952 .49246 .31474 .48482 .30559 Mtetra
.652 .742 .916 r
.48482 .30559 .49246 .31474 .50619 .30997 .49859 .3009 Mtetra
.654 .746 .917 r
.49859 .3009 .50619 .30997 .51998 .30512 .51243 .2961 Mtetra
.655 .749 .919 r
.51243 .2961 .51998 .30512 .53385 .30025 .52634 .29125 Mtetra
.656 .751 .92 r
.52634 .29125 .53385 .30025 .54779 .29538 .54032 .28636 Mtetra
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Mtetra
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Mtetra
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38422 .25247 .37601 Mtetra
.25247 .37601 .26087 .38422 .27353 .37978 .26517 .37154 Mtetra
.26517 .37154 .27353 .37978 .28626 .37534 .27793 .36704 Mtetra
.27793 .36704 .28626 .37534 .29904 .37089 .29076 .36253 Mtetra
.655 .75 .92 r
.29076 .36253 .29904 .37089 .31189 .36647 .30364 .358 Mtetra
.656 .748 .918 r
.30364 .358 .31189 .36647 .32479 .36215 .31659 .35344 Mtetra
.656 .743 .914 r
.31659 .35344 .32479 .36215 .33774 .35797 .32961 .34885 Mtetra
.655 .734 .908 r
.32961 .34885 .33774 .35797 .35076 .35387 .34268 .34426 Mtetra
.653 .723 .9 r
.34268 .34426 .35076 .35387 .36384 .34973 .35582 .3397 Mtetra
.651 .713 .893 r
.35582 .3397 .36384 .34973 .377 .34545 .36902 .33514 Mtetra
.652 .708 .889 r
.36902 .33514 .377 .34545 .39024 .34092 .3823 .33052 Mtetra
.653 .708 .887 r
.3823 .33052 .39024 .34092 .40355 .33608 .39564 .32582 Mtetra
.656 .713 .89 r
.39564 .32582 .40355 .33608 .41694 .33096 .40905 .32103 Mtetra
.659 .722 .896 r
.40905 .32103 .41694 .33096 .43039 .32578 .42252 .31613 Mtetra
.659 .73 .902 r
.42252 .31613 .43039 .32578 .4439 .32065 .43607 .31121 Mtetra
.652 .734 .909 r
.43607 .31121 .4439 .32065 .45748 .31539 .44967 .30655 Mtetra
.649 .749 .922 r
.44967 .30655 .45748 .31539 .47112 .31029 .46335 .30193 Mtetra
.656 .765 .93 r
.46335 .30193 .47112 .31029 .48482 .30559 .4771 .29708 Mtetra
.659 .763 .927 r
.4771 .29708 .48482 .30559 .49859 .3009 .49091 .2921 Mtetra
.658 .756 .923 r
.49091 .2921 .49859 .3009 .51243 .2961 .5048 .28713 Mtetra
.656 .753 .921 r
.5048 .28713 .51243 .2961 .52634 .29125 .51876 .2822 Mtetra
.656 .752 .92 r
.51876 .2822 .52634 .29125 .54032 .28636 .53279 .27725 Mtetra
.656 .751 .92 r
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Mtetra
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Mtetra
.26953 .35868 .27793 .36704 .29076 .36253 .28239 .35412 Mtetra
.28239 .35412 .29076 .36253 .30364 .358 .29532 .34954 Mtetra
.655 .751 .92 r
.29532 .34954 .30364 .358 .31659 .35344 .3083 .34494 Mtetra
.3083 .34494 .31659 .35344 .32961 .34885 .32135 .34034 Mtetra
.655 .752 .921 r
.32135 .34034 .32961 .34885 .34268 .34426 .33447 .33571 Mtetra
.656 .752 .92 r
.33447 .33571 .34268 .34426 .35582 .3397 .34765 .33102 Mtetra
.657 .75 .919 r
.34765 .33102 .35582 .3397 .36902 .33514 .3609 .3263 Mtetra
.657 .747 .916 r
.3609 .3263 .36902 .33514 .3823 .33052 .37422 .32154 Mtetra
.656 .744 .915 r
.37422 .32154 .3823 .33052 .39564 .32582 .3876 .31678 Mtetra
.655 .743 .915 r
.3876 .31678 .39564 .32582 .40905 .32103 .40105 .31203 Mtetra
.653 .745 .917 r
.40105 .31203 .40905 .32103 .42252 .31613 .41456 .30732 Mtetra
.653 .751 .922 r
.41456 .30732 .42252 .31613 .43607 .31121 .42814 .30259 Mtetra
.658 .758 .924 r
.42814 .30259 .43607 .31121 .44967 .30655 .4418 .29767 Mtetra
.66 .754 .92 r
.4418 .29767 .44967 .30655 .46335 .30193 .45552 .29267 Mtetra
.657 .744 .914 r
.45552 .29267 .46335 .30193 .4771 .29708 .46931 .28775 Mtetra
.654 .743 .915 r
.46931 .28775 .4771 .29708 .49091 .2921 .48317 .28287 Mtetra
.654 .746 .918 r
.48317 .28287 .49091 .2921 .5048 .28713 .4971 .27799 Mtetra
.655 .75 .92 r
.4971 .27799 .5048 .28713 .51876 .2822 .51111 .27305 Mtetra
.656 .751 .92 r
.51111 .27305 .51876 .2822 .53279 .27725 .52518 .26806 Mtetra
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Mtetra
.27395 .34565 .28239 .35412 .29532 .34954 .28691 .34103 Mtetra
.656 .752 .92 r
.28691 .34103 .29532 .34954 .3083 .34494 .29994 .33638 Mtetra
.656 .751 .92 r
.29994 .33638 .3083 .34494 .32135 .34034 .31303 .33168 Mtetra
.656 .75 .919 r
.31303 .33168 .32135 .34034 .33447 .33571 .32619 .32698 Mtetra
.655 .749 .919 r
.32619 .32698 .33447 .33571 .34765 .33102 .33941 .32228 Mtetra
.655 .75 .919 r
.33941 .32228 .34765 .33102 .3609 .3263 .3527 .31757 Mtetra
.655 .751 .921 r
.3527 .31757 .3609 .3263 .37422 .32154 .36605 .31283 Mtetra
.655 .753 .922 r
.36605 .31283 .37422 .32154 .3876 .31678 .37947 .30806 Mtetra
.656 .754 .922 r
.37947 .30806 .3876 .31678 .40105 .31203 .39296 .30323 Mtetra
.658 .754 .921 r
.39296 .30323 .40105 .31203 .41456 .30732 .40652 .29834 Mtetra
.658 .75 .918 r
.40652 .29834 .41456 .30732 .42814 .30259 .42015 .29341 Mtetra
.655 .745 .917 r
.42015 .29341 .42814 .30259 .4418 .29767 .43385 .28856 Mtetra
.653 .748 .919 r
.43385 .28856 .4418 .29767 .45552 .29267 .44761 .28374 Mtetra
.655 .754 .923 r
.44761 .28374 .45552 .29267 .46931 .28775 .46144 .27883 Mtetra
.656 .756 .923 r
.46144 .27883 .46931 .28775 .48317 .28287 .47535 .27387 Mtetra
.657 .755 .922 r
.47535 .27387 .48317 .28287 .4971 .27799 .48933 .26885 Mtetra
.656 .753 .921 r
.48933 .26885 .4971 .27799 .51111 .27305 .50338 .26382 Mtetra
.656 .751 .92 r
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Mtetra
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Mtetra
.26543 .33709 .27395 .34565 .28691 .34103 .27843 .33242 Mtetra
.27843 .33242 .28691 .34103 .29994 .33638 .2915 .32774 Mtetra
.655 .751 .921 r
.2915 .32774 .29994 .33638 .31303 .33168 .30462 .32305 Mtetra
.655 .752 .921 r
.30462 .32305 .31303 .33168 .32619 .32698 .31782 .31832 Mtetra
.656 .753 .921 r
.31782 .31832 .32619 .32698 .33941 .32228 .33108 .31355 Mtetra
.657 .753 .921 r
.33108 .31355 .33941 .32228 .3527 .31757 .34441 .30874 Mtetra
.657 .751 .92 r
.34441 .30874 .3527 .31757 .36605 .31283 .35781 .30391 Mtetra
.656 .75 .919 r
.35781 .30391 .36605 .31283 .37947 .30806 .37128 .29907 Mtetra
.655 .749 .919 r
.37128 .29907 .37947 .30806 .39296 .30323 .38481 .29422 Mtetra
.654 .749 .919 r
.38481 .29422 .39296 .30323 .40652 .29834 .39841 .28938 Mtetra
.654 .752 .921 r
.39841 .28938 .40652 .29834 .42015 .29341 .41208 .28453 Mtetra
.656 .755 .923 r
.41208 .28453 .42015 .29341 .43385 .28856 .42582 .27958 Mtetra
.657 .754 .921 r
.42582 .27958 .43385 .28856 .44761 .28374 .43963 .27457 Mtetra
.656 .751 .919 r
.43963 .27457 .44761 .28374 .46144 .27883 .45351 .26956 Mtetra
.656 .749 .919 r
.45351 .26956 .46144 .27883 .47535 .27387 .46746 .26455 Mtetra
.655 .749 .919 r
.46746 .26455 .47535 .27387 .48933 .26885 .48149 .25954 Mtetra
.655 .75 .92 r
.48149 .25954 .48933 .26885 .50338 .26382 .49558 .2545 Mtetra
.656 .751 .92 r
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24942 Mtetra
.656 .752 .92 r
.50975 .24942 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.656 .751 .92 r
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.25683 .32846 .26543 .33709 .27843 .33242 .26987 .32376 Mtetra
.656 .752 .92 r
.26987 .32376 .27843 .33242 .2915 .32774 .28298 .31902 Mtetra
.656 .751 .92 r
.28298 .31902 .2915 .32774 .30462 .32305 .29615 .31425 Mtetra
.656 .751 .919 r
.29615 .31425 .30462 .32305 .31782 .31832 .30938 .30946 Mtetra
.655 .75 .919 r
.30938 .30946 .31782 .31832 .33108 .31355 .32269 .30466 Mtetra
.655 .75 .92 r
.32269 .30466 .33108 .31355 .34441 .30874 .33605 .29986 Mtetra
.655 .751 .921 r
.33605 .29986 .34441 .30874 .35781 .30391 .34949 .29503 Mtetra
.655 .753 .921 r
.34949 .29503 .35781 .30391 .37128 .29907 .363 .29016 Mtetra
.656 .754 .922 r
.363 .29016 .37128 .29907 .38481 .29422 .37657 .28526 Mtetra
.657 .753 .921 r
.37657 .28526 .38481 .29422 .39841 .28938 .39022 .2803 Mtetra
.657 .752 .92 r
.39022 .2803 .39841 .28938 .41208 .28453 .40393 .2753 Mtetra
.655 .749 .918 r
.40393 .2753 .41208 .28453 .42582 .27958 .41772 .27033 Mtetra
.655 .749 .919 r
.41772 .27033 .42582 .27958 .43963 .27457 .43157 .26537 Mtetra
.655 .752 .921 r
.43157 .26537 .43963 .27457 .45351 .26956 .4455 .26035 Mtetra
.656 .753 .921 r
.4455 .26035 .45351 .26956 .46746 .26455 .45949 .2553 Mtetra
.45949 .2553 .46746 .26455 .48149 .25954 .47356 .25021 Mtetra
.656 .752 .921 r
.47356 .25021 .48149 .25954 .49558 .2545 .48771 .24509 Mtetra
.656 .752 .92 r
.48771 .24509 .49558 .2545 .50975 .24942 .50192 .23996 Mtetra
.656 .751 .92 r
.50192 .23996 .50975 .24942 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32919 Mtetra
.22219 .32919 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32376 .26123 .31499 Mtetra
.26123 .31499 .26987 .32376 .28298 .31902 .27438 .31022 Mtetra
.655 .751 .921 r
.27438 .31022 .28298 .31902 .29615 .31425 .28759 .30544 Mtetra
.655 .752 .921 r
.28759 .30544 .29615 .31425 .30938 .30946 .30086 .30063 Mtetra
.656 .753 .921 r
.30086 .30063 .30938 .30946 .32269 .30466 .31421 .29577 Mtetra
.657 .753 .921 r
.31421 .29577 .32269 .30466 .33605 .29986 .32762 .29087 Mtetra
.656 .751 .92 r
.32762 .29087 .33605 .29986 .34949 .29503 .3411 .28595 Mtetra
.656 .75 .919 r
.3411 .28595 .34949 .29503 .363 .29016 .35465 .28102 Mtetra
.656 .749 .919 r
.35465 .28102 .363 .29016 .37657 .28526 .36826 .27607 Mtetra
.655 .749 .919 r
.36826 .27607 .37657 .28526 .39022 .2803 .38195 .27113 Mtetra
.655 .751 .921 r
.38195 .27113 .39022 .2803 .40393 .2753 .39571 .26616 Mtetra
.656 .753 .922 r
.39571 .26616 .40393 .2753 .41772 .27033 .40953 .26113 Mtetra
.657 .753 .921 r
.40953 .26113 .41772 .27033 .43157 .26537 .42343 .25606 Mtetra
.656 .751 .92 r
.42343 .25606 .43157 .26537 .4455 .26035 .43741 .25097 Mtetra
.43741 .25097 .4455 .26035 .45949 .2553 .45145 .24586 Mtetra
.656 .75 .92 r
.45145 .24586 .45949 .2553 .47356 .25021 .46557 .24074 Mtetra
.655 .751 .92 r
.46557 .24074 .47356 .25021 .48771 .24509 .47976 .23559 Mtetra
.656 .751 .92 r
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Mtetra
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32919 .21336 .32048 Mtetra
.21336 .32048 .22219 .32919 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .31499 .25251 .30617 Mtetra
.656 .752 .92 r
.25251 .30617 .26123 .31499 .27438 .31022 .2657 .30134 Mtetra
.656 .751 .92 r
.2657 .30134 .27438 .31022 .28759 .30544 .27895 .29648 Mtetra
.27895 .29648 .28759 .30544 .30086 .30063 .29227 .2916 Mtetra
.655 .75 .919 r
.29227 .2916 .30086 .30063 .31421 .29577 .30565 .28672 Mtetra
.655 .75 .92 r
.30565 .28672 .31421 .29577 .32762 .29087 .3191 .28182 Mtetra
.655 .751 .921 r
.3191 .28182 .32762 .29087 .3411 .28595 .33262 .27689 Mtetra
.655 .753 .921 r
.33262 .27689 .3411 .28595 .35465 .28102 .34621 .27194 Mtetra
.656 .753 .922 r
.34621 .27194 .35465 .28102 .36826 .27607 .35987 .26694 Mtetra
.657 .753 .921 r
.35987 .26694 .36826 .27607 .38195 .27113 .3736 .26189 Mtetra
.657 .752 .92 r
.3736 .26189 .38195 .27113 .39571 .26616 .38741 .25681 Mtetra
.656 .75 .919 r
.38741 .25681 .39571 .26616 .40953 .26113 .40128 .25174 Mtetra
.655 .75 .92 r
.40128 .25174 .40953 .26113 .42343 .25606 .41522 .24666 Mtetra
.655 .751 .92 r
.41522 .24666 .42343 .25606 .43741 .25097 .42924 .24155 Mtetra
.656 .752 .921 r
.42924 .24155 .43741 .25097 .45145 .24586 .44333 .2364 Mtetra
.44333 .2364 .45145 .24586 .46557 .24074 .45749 .23122 Mtetra
.45749 .23122 .46557 .24074 .47976 .23559 .47173 .226 Mtetra
.656 .752 .92 r
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Mtetra
.656 .751 .92 r
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30208 Mtetra
.23056 .30208 .2394 .31096 .25251 .30617 .24372 .29724 Mtetra
.24372 .29724 .25251 .30617 .2657 .30134 .25694 .29238 Mtetra
.655 .751 .92 r
.25694 .29238 .2657 .30134 .27895 .29648 .27023 .2875 Mtetra
.655 .752 .921 r
.27023 .2875 .27895 .29648 .29227 .2916 .28358 .2826 Mtetra
.656 .753 .921 r
.28358 .2826 .29227 .2916 .30565 .28672 .29701 .27765 Mtetra
.656 .752 .921 r
.29701 .27765 .30565 .28672 .3191 .28182 .3105 .27266 Mtetra
.656 .751 .92 r
.3105 .27266 .3191 .28182 .33262 .27689 .32407 .26765 Mtetra
.656 .75 .919 r
.32407 .26765 .33262 .27689 .34621 .27194 .3377 .26262 Mtetra
.3377 .26262 .34621 .27194 .35987 .26694 .3514 .25758 Mtetra
.655 .75 .919 r
.3514 .25758 .35987 .26694 .3736 .26189 .36518 .25253 Mtetra
.655 .751 .92 r
.36518 .25253 .3736 .26189 .38741 .25681 .37902 .24747 Mtetra
.656 .752 .921 r
.37902 .24747 .38741 .25681 .40128 .25174 .39294 .24235 Mtetra
.656 .753 .921 r
.39294 .24235 .40128 .25174 .41522 .24666 .40693 .23718 Mtetra
.656 .752 .92 r
.40693 .23718 .41522 .24666 .42924 .24155 .42099 .232 Mtetra
.656 .751 .92 r
.42099 .232 .42924 .24155 .44333 .2364 .43513 .22679 Mtetra
.43513 .22679 .44333 .2364 .45749 .23122 .44934 .22156 Mtetra
.44934 .22156 .45749 .23122 .47173 .226 .46363 .21631 Mtetra
.46363 .21631 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30208 .22164 .29313 Mtetra
.22164 .29313 .23056 .30208 .24372 .29724 .23483 .28825 Mtetra
.656 .752 .92 r
.23483 .28825 .24372 .29724 .25694 .29238 .24809 .28333 Mtetra
.24809 .28333 .25694 .29238 .27023 .2875 .26143 .27838 Mtetra
.656 .751 .92 r
.26143 .27838 .27023 .2875 .28358 .2826 .27482 .27341 Mtetra
.656 .75 .919 r
.27482 .27341 .28358 .2826 .29701 .27765 .28829 .26843 Mtetra
.655 .75 .92 r
.28829 .26843 .29701 .27765 .3105 .27266 .30182 .26344 Mtetra
.655 .751 .921 r
.30182 .26344 .3105 .27266 .32407 .26765 .31543 .25842 Mtetra
.655 .753 .921 r
.31543 .25842 .32407 .26765 .3377 .26262 .3291 .25336 Mtetra
.656 .753 .922 r
.3291 .25336 .3377 .26262 .3514 .25758 .34285 .24827 Mtetra
.656 .753 .921 r
.34285 .24827 .3514 .25758 .36518 .25253 .35667 .24313 Mtetra
.657 .752 .92 r
.35667 .24313 .36518 .25253 .37902 .24747 .37056 .23796 Mtetra
.656 .751 .92 r
.37056 .23796 .37902 .24747 .39294 .24235 .38452 .23279 Mtetra
.655 .75 .92 r
.38452 .23279 .39294 .24235 .40693 .23718 .39856 .22761 Mtetra
.656 .751 .92 r
.39856 .22761 .40693 .23718 .42099 .232 .41267 .22239 Mtetra
.656 .752 .921 r
.41267 .22239 .42099 .232 .43513 .22679 .42685 .21713 Mtetra
.42685 .21713 .43513 .22679 .44934 .22156 .44111 .21185 Mtetra
.656 .752 .92 r
.44111 .21185 .44934 .22156 .46363 .21631 .45544 .20654 Mtetra
.656 .751 .92 r
.45544 .20654 .46363 .21631 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19584 Mtetra
.48434 .19584 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?oooe40Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3oool30:Noje00Yl3[00<000000:O0j`2W`>/0402W`>/A0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`<000000`3oool00`000000oooo0?ooo`160?ooo`H0
Yko[C`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0:@3oool002T0oooo
0P00001;0?ooo`D0Yl3[1@2W_n]?0:O0j`030000002W`>/0Yl3[0140Yl3[4P3oool00`000000oooo
0?ooo`0X0?ooo`009P3oool3000004X0oooo102X`>]H0:O0j`030000002W`>/0Yl3[0180Yl3[4@3o
ool00`000000oooo0?ooo`0X0?ooo`00903oool2000004/0oooo0`2W`>/40:S0ja@0Yl3[1@2W_n/m
0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?ooo`H0Yl3[102X`>/70:O0
j`<0Yko[2P2W`>/50:NojcT0Yl3[0`0000020:O0j`030000002W`>/0Yl3[0180Yl3[4P3oool00`00
0000oooo0?ooo`0V0?ooo`007`3oool3000004T0oooo1@2W`>`>0:O0j`H0Yko[2P2W`>/20:NojcP0
Yl3[0`0000050:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo0?ooo`0V0?ooo`00
7@3oool2000004/0oooo0P2W`>/50:O0k0D0Yko[1@2W`>/90:Noja80Yl3[0`2W_n//0:O0j`<00000
2@2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0303oool2000000@0oooo
0P0000030?ooo`@000002P3oool001D0oooo1@0000030?ooo`800000B@3oool50:O0j`80Yl3/202W
_n/50:S0j`D0Yko[1@2X`>/>0:O0j`H0Yko[:02W`>/3000000d0Yl3[00<000000:O0j`2W`>/04`2W
`>/A0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`0;0?ooo`005`3oool00`000000oooo0?ooo`030?ooo`<00000A03oool90:O0j`P0Yko[202X
`>/20:Noj`<0Yl3/1@2X`>/90:O0j`X0Yko[9P2W`>/200000140Yl3[00<000000:O0j`2W`>/04`2W
`>/@0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`0:0?ooo`005`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000003l0oooo
1@2W_n/50:O0j`T0Yko[2P2X`>/60:O0k080Z<3[0`2W_n/60:O0j`P0Yko[9`2W`>/3000001<0Yl3[
00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool02@3oool000l0oooo100000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`L0Yko[
1@2W`>/50:Noj`D0Yl3/102X`>/50:O0j`D0Yl3/1P2W_n/30:O0j`P0Yko[0`2X`N`S0:O0j`<00000
5`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0203oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`030000003oool0oooo03P0oooo202W_n/<0:O0j`D0Yl3/1@2W_n/40:O0j`X0
Yko[1@2W`>/40:Noj`H0Z<7/0P2W`>/30:NojaX0Yl3[0`00000K0:O0j`030000002W`>/0Yl3[0180
Yl3[403oool2000000/0oooo0P00000:0?ooo`8000002`3oool001H0oooo0P0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool50:O0j`D0Yko[3`2W`>/20:O0k0P0Yko[
102X`>/50:Noj`D0Z<7[1@2W`>/40:O1k0D0Z<7/1P2W_n/F0:O0j`<000007`2W`>/00`000000Yl3[
0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool08@3oool001`0oooo00<000000?ooo`3oool01@3o
ool200000300oooo702W`>/80:Noj`L0Z<3[0P2W_n/30:O1k0D0Z<7[2@2W`N`50:Nnj`D0Yko[4`2W
`>/300000280Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo0200oooo000L
0?ooo`800000203oool00`000000oooo0?ooo`0[0?oooa40Yl3[1@2W_n/40:O0j`X0Yko[2@2X`>/6
0:O1k080Z<7[0`2W_n/50:O1k0@0YkkZ1@2W_^/D0:O0j`<000009P2W`>/00`000000Yl3[0:O0j`0B
0:O0ja40oooo00<000000?ooo`3oool0803oool001`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0X0?ooo`l0Yl3[2P2W_n/50:O0j`@0Yko[1@2W`N`50:S0j`D0Yl3[102W`N`60:No
j`80Yl7/0`2X_^T40:NnjP80Ykk[0`2X`N`>0:O0j`80Yko[0`0000050:O0j`D0Yko[802W`>/00`00
0000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0S0?oooa@0Yl3[1`2W_n/30:S0j`T0Yl3[1@2W`N`50:Noj`D0
Yl3[102W_^X50:Noj`H0Z;kY0`2W_^X60:S1k080Yl3[0`2W_n/50:O0j`80Yko[0`0000040:Noj`D0
YkoZ2@2W_n/L0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0N0?ooo`00
6`3oool2000000`0oooo00<000000?ooo`3oool07`3ooolH0:O0j`@0Yko[1P2X`>/90:O0j`X0Yko[
1@2X_n/40:NnjPD0Z<7[1@2X_^T40:S3k@D0Z<7/1P2W_n/20:O0j`80YkkZ0P0000050:Noj`<0Z;cX
1@2W_nX50:RnjP@0Yko[6`2W`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo00<000000?ooo`3oool0
7P3oool001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooob40Yl3[1@2X
`>/80:O0j`T0Yko[0`2X`N/50:Roj`@0Z<;/1@2X`N/50:O3kP@0Z<?]1@2W_^X50:Noj`040:NnjP00
0000000000000080YkkZ0`2W_n/60:Rlj080YkoZ0`2X^^H40:RnjPD0Z;oZ6`2W`>/00`000000Yl3[
0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0H0?ooob<0Yl3[1@2W_n/50:O0j`T0Yko[1P2X`N/20:Roj`<0Yl3/102X
`^`50:Jok0D0Yl?^1@2V_NX40:NnjP80Z;oZ0`0000050:NnjP@0Z;ST1@2X_>P60:RjiP80Z;kZ0P2Y
^nL50:RojP80Yl3[0`2X_n/F0:O0j`030000002W`>/0Yl3[0140Yl3[403oool2000001l0oooo000K
0?ooo`8000003`3oool00`000000oooo0?ooo`0E0?ooob80Yl3[2@2W_n/50:S0j`D0Yko[102W`N`5
0:S1j`H0Yl3/0P2X`^`20:Jkj0D0Y[o/1@2W_NT50:JmjP80Z<7/0`0000040:RojPD0Yk3N102X^>@5
0:VagPD0Z;[V1@2Y^nL40:RojPH0Z;o[5@2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<00000
0?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?oo
obH0Yl3[1@2W_n/90:S0j`D0Yl3/102W`N`50:NnjPD0Yl3/1@2V^nP20:Jok0<0Z[kX1@2W_NT20:Jm
jP040:O3k@0000000000000000<0Z<7/1@2UZ=T50:N`gP80Z;ST0P2YYM<50:VagPD0[;;M102Y^nL5
0:Vnj@D0Z;o[5P2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06`3oool0
00P0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0<0?ooob/0Yl3[0P2W_n/30:O0j`@0Z<3[1@2W`>/50:O0k0T0YkkZ1@2X^^H40:Jk
j0H0Z[kX102W_NT3000000<0Yl?]0P2X`N`20:>Re0D0YJSI102W/=h50:VUd`80ZK7N0`2^Y]050:bb
g@@0[KSR1@2Y_^T50:RojQH0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo
01/0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool2
000001<0oooo00<000000?ooo`3oool02P3ooolb0:O0j`80Z<3[0P2W_n/50:O0j`X0YkkZ102X^>D5
0:RjiPD0ZkSS102Z_^P01@2X`>/00000000000000000Z<3[00D0Yl?]102SX]@50:FXf@D0Yi[8102Y
YM<60:jVd080[;;M0`2b[M<40:fhhPD0ZkgW1@2X_nXF0:O0j`030000002W`>/0Yl3[0140Yl3[4@3o
ool00`000000oooo0?ooo`0J0?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`050000003o
ool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`070?oooc@0Yl3[1@2W_n/30:O0j`80Z;oZ
1`2W_^X30:Nfh`@0Z;SU0P2X^^H30:NYf0D0ZkSS00@0Z:oM00000000000000001@2X`>/50:>TeP@0
Xj;D0P2UZ=T30:FA`@D0Yi[80P2YYM<20;6OaPD0[ZK@1@2b[M<20:fhhP<0/kOL1@2[_NL50:VojQD0
Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01T0oooo00000`3oool00000
0000000200000080oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`020?oooc@0Yl3[2P2W_n/50:RojP@0YkkZ1P2W]^<30:Rhi@H0
YjWH0P2[^><3000000@0Z:oM1@2Y/]l50:>TeP<0Xj;D1@2UTL450:NJb0@0/Io6102^Y]020;RVa`@0
/ZgC1P2c]m`20:^mi`<0[[kU102Y_nX50:S0ja40Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`03
0000003oool0oooo01T0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool00`3oool2000001H0oooo00<000000:O0j`2W`>/0<P2W`>/90:Noj`D0Z;o[102X_nX50:Neh`D0
YkKS102VX=050:NYf0800000102WV<H20:R_g@80[Y[31@2Y/]l40:>TeP@0XHVk1@2UTL430:NJb080
]:75102aWlH20:jVd0<0^:K70`2b[M<20;b^c0D0/kOL1P2^_^D20:VojP80Z/3Z1@2X`>/A0:O0j`03
0000002W`>/0Yl3[0140Yl3[403oool2000001X0oooo00080?ooo`8000002P3oool3000000<0oooo
00<000000?ooo`3oool04P3oooli0:O0j`D0Yko[102W`>/50:Roj`@0Y[GS1@2W]N<50:FLc@@0YZ3@
00D0YjWH00000000000000000:bG`@050:NHaPD0[Y[3102Y/]l509Mk/P<0XHVk1@2UTL420:NJb0<0
]:75102aWlH60;RVa`030;:]d`2l[/`0_:k<0080_:k<0P2c]m`30;^he`D0[[kU1@2Z`>X50:S0ja40
Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030000
003oool0oooo0180ooooA02W`>/50:Jfi0@0Y[GS0`2W]N<20:>Kc@@0YIc=0P2VX=03000000@0[9O1
102WV<H20;ZL^`@0[Y[31@2@KZL409Mk/P@0XHVk102UTL450;BQa@<0/Io60P2mZLH50;RVa`D0_:k<
1P2k^=L50;;0i0@0Z/3Z1P2X`>/@0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo
0?ooo`0G0?ooo`006@3oool200000140oooo@`2W`>/40:NiiPD0Y[KT102V]N<40:>Kc@<0YIc=0`00
00000`2VX=00[Ig70:fMa`050:bG`@80YiS60`2jW;/40:jJ``030;VE/P2@KZL0T6jW0080T6jW102G
Nk840:69^`80YI710`2i[m040;BQa@80/Io60`2mZLH40;RVa`80`J_30`2l[/`20<FaaP@0^kSG0P33
_=<40;;0i0D0Z/7Z1@2X`>/A0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?oo
o`0F0?ooo`006@3oool00`000000oooo0?ooo`0=0?oood@0Yl3[0`2W^nP40:NiiP@0Y[KT1@2RW<l3
0:>Kc@<000000P2UW<d40:fMa`D0[9O100<0YiS60;ZL^`2jW;/00`2jW;/20:jJ``80^IFb102@KZL4
09Mk/P@0XHVk1@2i[m040;BQa@H0_JW60P2hY/L40<6[``030;b^c035/LH0aK760080aK760P2k^=L4
0<>ld`80//3T0P2f`n@50:[1jPD0Z<3[4@2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<00000
0?ooo`3oool05@3oool001T0oooo00<000000?ooo`3oool02@3ooom60:O0j`H0Yk_X0`2W^NH50::O
dP@0XYc?0`0000000`2SVld0ZZ7>0:ZQcP030:ZQcP@0[Ig7102/Ul460;ZL^`040:jJ``2iUK80^IFb
0;VE/P@0T6jW102GNk820:69^`<0`]W[1@2i[m020;BQa@80_kgH1@2mZLH60<6[``D0aK761P33_=<5
0;K3i0D0Zl7Z102X`>/B0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0E
0?ooo`006@3oool2000000L0ooooAP2W`>/40:Nnj@D0Yk_X102RY=L40::OdP050::Lc`0000000000
0000002RW<l00P2SVld20:FQd@@0ZZ7>102]WLL20:bG`@<0`LCM1@2jW;/40;VE/PD0T6jW0`2GNk85
0<;Ij`D0^Jo@102o_MP40;fYaP80`KC>1031Zl<20<N_`P@0aK7600<0cKC20<>ld`33_=<00P33_=<2
0<[1d@80]/?T0`2haN@50:_1jP@0Z<3[4@2W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<00000
0?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00`3ooom50:O0j`D0Yko[102W_^T50:>[
g@@0XZCG00@0XYoB0000000000000000102RW<l40:FQd@D0ZZ7>0`2]WLL50<74g@@0^Ybk0P3:o/L3
0;VE/PD0T6jW0P2GNk8206cBV`D0`]W[0P2i[m030:OHn@@0_kgH0P2mZLH30<6dcP<0`J_30`37[l83
0<FaaP<0cKC20P33_=<30<[1d@H0^<GT1@2[`NX40:S0ja40Yl3[00<000000:O0j`2W`>/04P2W`>/@
0?ooo`030000003oool0oooo01<0oooo000H0?ooo`030000003oool0oooo00<0oooo@`2W`>/90:No
j`@0Y;;R102SZmd20::Te`<000000`2RWm850:2Ld0@0YJ7A102ZXLh40:CPo0D0`LCM0P2jW;/30<[n
a`@0^IFb102@KZL00`2GNk80K=:K06cBV`0206cBV`@0`]W[1P2Wf?T30;nmf0H0`KC>00<0`J_30<N_
`P37[l800`37[l800`35/LH0cKC20<fd`P020<fd`PD0b/7A00@0dLOA0;S5i02haN@0^<GT0`2ianD4
0:_1jPD0Z<3[4@2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo0P00000E0?ooo`00603oool01000
0000oooo0000003ooom60:O0j`D0Yko[102V^>H40:BbhP<0Xj_M0P0000030::Te`@0ViG=102PW=04
0:FQd@H0T^;m0`2Th?`40<74g@030;ZL^`3:o/L0b_k70080b_k7102iUK84091^Y`@0J;Kl0`19YoP4
06S9o@@0YmSi102TbO<50<6dcPH0ajo21@3=]<80103D^Kl0b/7A0<[1d@3:`M430=77d@H0^LOU102[
`NX50:S0ja00Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo00H0oooo0P00
000:0?ooo`00603oool00`000000Yl3[0:O0j`180:O0j`80Yko[0`2W_NT40:JhiP<0Y;;R0`000000
0`2SZmd0V97;09RAb`0309RAb`<0ViG=1@2PW=020:FQd@<0TnCl1@2Dc?/305^ko080Ym7f1@25__T2
0<[na`<0^IFb0`2@KZL209ZYh@@0Pj;X101a^_`4042flP<0B;Wf102TbO<20<6dcP<0^;OH1037[l82
0<V``@<0cKC20`3D^Kl00`3:`M40dLOA0=77d@020=77d@030=G<d@2ianD0^LOU00<0^LOU1@2[`NX5
0:S0ja00Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000002@3oool00140oooo0P0000050?ooo`030000003oool0Yl3[04P0Yl3[1P2W_NT3
0:JhiP<000000P2IVM8309RBc@@0V97;102KULd40:2Ld080TnCl102RcoL509C<n`D0Ym7f1@2IboT0
103:o/L0^IFb0;VE/P2iUK82091^Y`@0VZWQ1023X^P508cJo`@0D;Gj0P0@R^D30:C9l`D0^;OH0`37
[l830<V``@80cKC2103D^Kl40=77d@<0eLcA1@2ianD40:_1jPD0Z<3[4@2W`>/00`000000Yl3[0:O0
j`0A0:O0ja00oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`00403o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04D0Yl3[102W_n/50:Nmj@<00000
00<0WJCJ09VIdP2IVM800P2IVM8309RBc@D0V97;0`2KULd409cSo@<0ZmSg102RcoL60:7@n0@0X<Kc
0`2IboT20:o>l0<0^IFb0`2``^L309ZYh@H0V^?m102C`OH405Rbn`03001/c`0@R^D0GZgj0080GZgj
1@2h]mP00`37[l80bK310<V``@020<V``@030<fd`P3D^Kl0e;Vo00<0e;Vo00<0g;nl0=77d@3Aam40
103Ec=450;W7i@D0Z/7Z102X`>/B0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0
oooo0P0000020?oood00Yl3[2@2W_n/01@2Q/>800000000000000000XK3R00<0WJCJ1@2IVM8309RB
c@@0V97;1@2Rf?/60:_Hm`D0Y=3g1@2TaO440:36l`H0[lk`102``^L509GCo@D0Y<?_102C`OH405Rb
n`8006c?0`1N[OX40;Rgf0D0bK311@3D^Kl30=bo_0@0eLcA0P3Gcm430;W7i@80^<OV1@2Z`NX40:S0
ja40Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?oood40Yl3[102W_n/0102U^NP000000000000000050:6`hP<0WJCJ102IVM8309RBc@H0Wkk_1@2b
hoL50:G>mP<0Y=3g0P2Vao450:C5l@@0Z<od1@2_c_0609S3m@@0[<c`1@2T`nl509kGo0@0F[gl00<0
04bg00]hhP0;N>801@2T[]l40<V``@040<^`_`3D^Kl0e;Vo0=Bi_`@0g;nl00<0hlJj0=G<d@3Ec=40
103Gcm450;S7iPD0Z/7Z102X`>/A0:O0j`030000002W`>/0Yl3[0140Yl3[403oool2000000@0oooo
0P00000:0?ooo`00403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo
@02W`>/0102V_^X000000000000000040:Fij0@0XK3R0`2MY=X409VIdP@0UZ;M0`2O_^l40;KZmP@0
Z]3d1@2Uc_H50:K7l@D0YLke102Xco@50:70k`<0V<?e0`2/d_@40:c<l0D0YmCg1P2UeoT305:hnP03
001<]`00?[d02gSR00@0Y:kO0`39/<430<^`_`030=Bi_`3L_k`0g;nl0080g;nl0P3Sa[X50=O?d@80
e]3C0P2hanH30;O7iP@0Z/7Z1@2X`>/A0:O0j`030000002W`>/0Yl3[0140Yl3[3P3oool300000100
oooo000A0?ooo`800000103oool2000000L0oooo>`2W`>/20:Noj`<00000102V_^X30:Fij0D0TYSF
0`2=Sm0408nAd@@0UZ;M102fj_H30;;FlP@0Z]3d1P2Xbo840:C<m0D0YLke102V`^d50:70k`D0[=;d
1P2Ubo@50:oCl`H0Z>?k0P0kY_D00`00C;L003jm00]hhP040:B^g`030<V``@3;/;l0bk2o0080bk2o
103L_k`30>?6^P040>W<^03Gcm40eloA0=O?d@<0e]3C1P2ganH40:[1j`D0Z<3[4@2W`>/00`000000
Yl3[0:O0j`0A0:O0j`l0oooo00<000000?ooo`3oool03P3oool001L0oooo00<000000?ooo`3oool0
1`3oooli0:O0j`<00000102W_n/40:6fi`<0VZSP102BV=H308f?d0D0Si7A0P2FX]d30;CRmPH0/]Kb
102Zco<30:S;lP<0Y<Wc102Tc?@50:O3kP@0Y/;]1P2Vd_L40:G5l0<0YL_d0`2^dO<30:oCl`<0]>?g
1@2ReOX0100XN^D0>jKe000n_@00?[d40:B^g`D0bk2o00@0ck:m0=bo_03L_k`0g;nl0`3Sa[X20>W<
^0@0e]3C0P3Ecm@30;O7iP<0]/KV102Z`N/50:S0ja00Yl3[00<000000:O0j`2W`>/04@2W`>/@0?oo
o`030000003oool0oooo00d0oooo000G0?ooo`030000003oool0oooo00P0oooo=@2W`>/3000000<0
Yl3[0P2W_n/30:FmjP@0XKKW0`2JZ>0409:HeP<0SHo@102?TM440;CRmP<0_]o`1@2^e?@40:[?l`H0
Y<Wc102WaNl50:O3kPD0Y=3g1@2W`nh40:G5l0H0[]7c102dhoL20;SRm0@0X]Gj0P0XN^D00`001Xh0
01JR000n_@0408jMg@<0bk2o0`3?/[d0103L_k`0hlJj0>?6^P3Sa[X30>W<^0030>_>^03Fd=<0e]3C
00@0eLoD1@2fa^H50:[1j`@0Z<3[4@2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?oo
o`3oool0303oool001L0oooo0P0000090?oooc<0Yl3[0P0000060:O0j`H0YKgZ0`2Q]^L409ZXh0<0
TYSF0`2=Sm060:K2kP@0_]o`0`2ffo<40:kDm0H0Y/Sb102WbO440:O5k`H0Xlkf102W`nd50:O3kPD0
Zm;d1P2^fOH50;SRm0@0SJGU00D09U;802Qji@001Xh001JR000n_@0308jMg@<0bk2o0`3?/[d40>?6
^P<0jLbh0P3[c[P40=G?e080e<oE1@2fa^H50:[1j`@0Z<3[4@2W`>/00`000000Yl3[0:O0j`0A0:O0
j`l0oooo00<000000?ooo`3oool0303oool001L0oooo00<000000?ooo`3oool02P3oool^0:O0j`<0
00001@2W`>/50:Noj`@0YKgZ102BY>4408JAe`<0QHcC0`2@WM`30:K2kP@0`n7^1P2ffo<40:[;l@<0
Y/Sb0`2Wc?<40:O9l@@0Xlce0`2Sc_H30:O4kP@0Yl?]1@2Wd_H30:_Bm080ZM3d0`2^fOH30;KRmPD0
/m3_0`2=YND202IBb00302Qji@001Xh001JR00@0SYgM00<0bk2o0<nb_@3?/[d00P3?/[d00`3H^;X0
hlJj0>?6^P030>W<^0<0jljh00<0jlnh0=G?e03Ecm@0103DcmD50;K6iP80Z/7[0`2Y`N/40:S0ja40
Yl3[00<000000:O0j`2W`>/0402W`>/@0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000
003oool0oooo00`0oooo:P2W`>/3000000T0Yl3[1@2W_n/409jdj0<0TZCQ1026TML308F<d`@0T9gL
1@33hNh30<;PkPD0/M?a102Zbo460:O<l`@0XlWd102Sc?D60:O4kP@0YM7g1@2Wd_H50:W@m0@0]^;f
0P2eh_H50;?@k`<0SJGU0P0VD/P00`0008d000JH000FXP0308:=eP@0ck:m0`3H^;X0103Sa[X0jLbh
0>W<^03Yc;P30>_>^080jlnh103DcmD20=;?eP@0]/KV1@2Y`N/E0:O0j`030000002W`>/0Yl3[0140
Yl3[403oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000h0oooo9P2W`>/3000000d0Yl3[
1@2T_N/409jdj0<0TZCQ1026TML308F<d`80T9gL102fbnT40<;PkP80_mg_1@2ado450:O?m@D0XlSb
102SbO@40:O6k`<0YlC^0`2Td?L40:GAm`H0Z<_b1@2_hOP50;GRmPD0UI7=0P1eNl/302IBb0030000
S@001YP0PXgF00<0PXgF0`3?/[d30=Rh^P<0jLbh0`3[c[P30>_?^0030>_?^@3DcmD0e<oE00@0d/oF
102eaNL50:W1jaD0Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`800000303oool001H0oooo00<0
00000?ooo`3oool03P3ooolR0:O0j`<000003@2W`>/40:Noj`D0Y;g[0`2N]>P309:Th@@0QY7G0`25
S=<50;K;j@<0bM_V1@2ogNl60:_Bm@@0YLWc1@2Sb?840:K9lP@0YlK_1P2Td?L40:O8l@<0Z<_b0`2X
goX60:kSn@@0YJKF102ETLd307Ekb`809U;800<0002<0006V0001YP01022SMH00`3?/[d0f;Rj0=Rh
^P020=Rh^P030>;2]`3Yc;P0jLbh00<0jljh0P3[ckP20>_?^@D0d/oF0P3Ac]L40;G5i`D0ZL7[5@2W
`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo00<000000?ooo`3oool02@3oool001H0oooo00<00000
0?ooo`3oool0403ooolM0:O0j`<000004@2W`>/40:Noj`D0W;O[0`2;Y>D307^>f`@0OX_F0`2GXmh3
0;K;j@<0bM_V0P3=g^D30;oMk`<0]mWb1@2Xd?D40:G9l`D0YLge102VbO850:;>m`D0Y/Sa102Wb?44
0:SOnP<0Z=kj1@2``>H30:FVePD0UI7=0P1eNl/01@0IA/409U;802IBb00008d000JH00@0PXgF103H
^;X30>;2]`<0jljh0`3[ckP20>_?^@040>[?^P3BcmH0d/oF0=;?eP<0dLkG1@2daNL40:W1jaD0Yl3[
00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00P0oooo000F0?ooo`8000004P3o
oolI0:O0j`<000005@2W`>/50:Fnj`@0W;O[0`2;Y>D207^>f`@0OX_F102GXmh40<WKiP@0cMkU102g
fO820;7Jm@D0Z=3e102RcoP50:G=m@D0XLcf102Ub_<50:K8l@D0Xmkk102Xg_X20:oImPD0/<3V0`2U
Y]H409FAc@<0MG_;00D06DK102IBb00008`000NI0006V00408B9d@80f;Rj103R`[L00`3ZbK@0jljh
0>_>^0020>_?^080jlni0`3ZckX40=7>e`80d<oH102daNL50:W1jaD0Yl3[00<000000:O0j`2W`>/0
4@2W`>/?0?ooo`030000003oool0oooo00P0oooo000F0?ooo`030000003oool0oooo0180oooo5@2W
`>/3000001D0Yl3[102W_n/50:Fnj`<0W;O[0`2;Y>D307^>f`@0OX_F0P2GXmh30;[2h@@0cMkU103<
g^H50;7Jm@D0W];j102RcoP509o:mPD0Xlog102Ub_<609kLo@D0YM_j1@2_fOH40;30iP<0YJKF102E
TLd307Ekb`806DK10P0008`00`001iT0Q8WA08B9d@0208B9d@80f;Rj0`3R`[L30>[9]0<0jlnh0P3[
ckT30>[?^P030>W?^`3Ac]L0dLkG00@0d<oH102caNL50:W1jaD0Yl3[00<000000:O0j`2W`>/0402W
`>/?0?ooo`8000002@3oool000<0oooo0P0000040?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool0503ooolA0:O0j`<000006@2W`>/40:Noj`D0W[[/0`2;Zn/3076@h@80LHKH101nRmH4
0;[2h@<0cLoK103<g^H40<[Nj0D0Ym[i102Nd_X509g=n0@0W=Ck1@2ScoL509WJo@D0XM[k1P2Sho`4
09>ml`@0RKOd0`24/o<4082_l`<0Giga00<004?301U6`@0008`00P001iT308B9d@030=Rh^P3R`[L0
h/:g0080h/:g0`3ZbK@0103]c;80jlnh0>_?^@3[ckT30>[?^P<0jLnk103@cmP20=3@f@@0/lGW1@2Y
`N/E0:O0j`030000002W`>/0Yl3[0100Yl3[2`3oool3000000030?ooo`000000oooo00P0oooo0002
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0E0?ooo`h0Yl3[0P00000M0:O0j`@0Y[o/1@2N^^`308^[j`80LI3Q0`1aQ]P409>MfP80^/;Q
103=cm/20=GAePD0b]kX0`38gNP409gKo@D0Um?m1@2>eol309cDn`H0TmOn1@2Jf_d509[Qo@D0W/7a
102C_O<308Vgm0@0Q;?c0`20[o<405nMl@040013``0IA/40002<0007V@<0Q8WA103R`[L30>[9]080
kLbb0`3[ckT30>[?^P<0jLnk00<0j]:l0=3?f03@cmP00`3@d=T50;;6j0@0ZL7[5@2W`>/00`000000
Yl3[0:O0j`0A0:O0j`H0oooo100000040?ooo`030000003oool0oooo00L0oooo00020?ooo`040000
003oool0oooo000000/0oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`X0Yl3[0`00000P0:O0
j`@0Y[o/102N^^`308^[j`<0LI3Q0`1aQ]P409>MfP@0cLoK0`3EdMH20=W?d080b]kX0`38gNP30<SG
i@<0WM_m1P1ldol407oAo`@0RmGo1P2Afol509_Cn`@0YlC^1@2N`O4409NYh`@0Q;Wg1@2SZMX408R]
k@8004?300<00021000>W`001iT00`2EUm830>;2]`<0j/Vd0P3]c;820>k=/P<0j/nj0`3Yck/20>[B
_0@0d=3I0P3>d]`50;;6j0@0ZL7[5@2W`>/00`000000Yl3[0:O0j`0A0:O0j`80oooo0`0000080?oo
o`030000003oool0oooo00L0oooo00020?ooo`040000003oool0oooo000000T0oooo0P0000040?oo
o`030000003oool0oooo01P0oooo1@2W`>/3000002@0Yl3[102S_^`409:ekP<0KY[[0P1IOmd30766
f0D0/K7H0P3=cm/30=GAeP@0fLo@0`38gNP30<SGi@80bLCF102Fe?d6087:o`<0Om7o1@29eOl609fj
k@@0[lK[102Wa>h509nTf@@0UjWS102[ZMD40:>YfPD0Zj_G00@0N9_W0013``00084000jO102EUm80
103R`[L0j/Vd0>[9]03ZbK@30>g</P80k/fb00<0k/fa0>[?^P3ZckX00P3Yck/30>[B_0030>_F_`3@
d=T0d=3I00@0c];L1@2aa^T40:W1jaD0Yl3[00<000000:O0j`2W`>/0402W`>/2000000`0oooo00<0
00000?ooo`3oool01P3oool00080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01T0oooo00@0Yl3[0000000000000000902W`>/40:Noj`@0Xkk/
102B]Nh306jJj`80FGoM0`1nS]P50;6af0<0eM7F103Icm030=[9b0<0b=OU1039a=H50:Rnj@D0W:cR
102=a?X409jSf0<0WK[]0`2fanL40:o6j`@0YZKG102OY=T50:b[eP@0ZjWE0P2SZMX20;6]e0D0Zj_G
0P1hVnL2000>W`<0UIOB103ZbK@20>g</P<0k/fb0P3^cK430>W?^`80j]:l0`3[e[l40<kBg080bmCQ
102aa^T50:S1jaD0Yl3[00<000000:O0j`2W`>/0402W`>/=0?ooo`030000003oool0oooo00H0oooo
00030?ooo`8000002P3oool3000000<0oooo0P00000H0?ooo`<00000:02W`>/40:Noj`<0Xkk/1@1o
[?4204J3iP80FGoM101nS]P20;6af0@0aK[@103Icm040=[9b080fKjo1039a=H20<R_`@<0Z;kY0P2b
XlP509b/hP@0XiS:102NXmP50;K7i`D0[K;L102VY]L209nTf@80ZZ_H1@2/ZmH30:^Ye@D0/JgD0P2[
ZmL30;6]d`80VJ7J00<000jO0:naf@2_/MT00P2_/MT20>[9]0<0kLbb0P3^cK830>k=/@030>o?/@3Y
ck/0j]:l0080j]:l0`3[e[l00`3/gL<0c];L0<kBg0040<_Dh@@0[lK[102X`N/E0:O0j`030000002W
`>/0Yl3[0100Yl3[3@3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0E
0?ooo`<00000103ooolX0:O0j`@0Y[o/102N_>h407n/l@80AX?V00<0BgKK05Uog@1nS]P00P1nS]P5
0<Fjd080ck[60P3Icm040=[9b0<0fKjo00<0ek>d0<W4eP39a=H01038[l450;:Sb0D0[I[3102SV<X2
09jSf080^lKS0`2fanL20;S;j0D0[K;L0`2VY]L40:Z[f0D0[:_F102_[=D40;6]e0D0/JgC0`2IXMX0
0`003Yl0[k7I0:naf@020:naf@<0kLbb0`3^cK820>k=/@80klna0`3Zd[`30>_F_`<0k=g3103;e>42
0<KEi@@0[lK[102X`N/E0:O0j`030000002W`>/0Yl3[0100Yl3[303oool00`000000oooo0?ooo`06
0?ooo`00503oool00`000000oooo0?ooo`0B0?ooo`<00000203ooolX0:O0j`@0Y[o/102N_>h307n/
l@80AX?V0P1;M]/409BJe`<0aK[@103?^/H40=[9b0<0fKjo0`3G/k@50<R_`@040<bX]P2bXlP0/Z?8
0;:Sb080_ZG0102]V/<40:>HbPD0^lKS1@2hbnP40:fbg0@0YZWI102ZZmP20:b[eP<0Zj_F102_[=D2
0;6]e080/k7F102a[M<309VQfP04000EXP003Yl0[k7I0:naf@80`/CL0P3]c;830>k=/P80k/fa0P3_
ck400`3beK80j]:l0>[B_0030>_F_`80k=g30P3ZhlX20<_Dh@<0a]GU1@2]aN/40:S1jaD0Yl3[00<0
00000:O0j`2W`>/0402W`>/;0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000403oool3
000000`0oooo:02W`>/40:Fok0@0V;[`0`1UXO80100AI=T0AX?V04]ff`1;M]/409BJe`030<Fjd03?
^/H0ck[600<0ck[600<0e;Jl0=[9b03JbLP00`3I_[l40=Nc]0040=N][@38[l40b:o10<R_`@<0c:Rf
00@0/Z?80;jU`02nYL00_ZG0102]V/<20:>HbP<0_/GP0`2ka^<30;c/l`<0^<_X1@2RY]T40:JYf@<0
ZZ_H1@2[ZmH40:n/e@D0/k7F0P2a[M<20;>efP<0XjWK00<001FR0<;4g032a=`00`32a=`30>k=/P80
k/fa0`3_ck420?;E/P<0jmJo0P3/gL<30>[SbP@0a]GU0P2ndnT40:g5j`D0Z<3[5@2W`>/00`000000
Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool0
303oool300000140oooo9`2W`>/40:Fok0@0V;[`0`1UXO80100AI=T0BgKK04]ff`1;M]/309BJe`D0
ck[60`3D][`40=Vn_`<0ek>d0P3G[Jd30<R_`@<0c:Rf1@2nYL030:fJ``H0_/GP0P2lk?<40:2Wf`<0
WZ?I102RY]T40:JYf@@0Z:WG102[ZmH50;2dg0@0/k7F1@2c]MX20:>Yf`03000LY0005J80`/CL0080
`/CL0P3:bMX20>k=/P80k/fa0P3_ck430?;E/P80mMjd0P3/gL<30>[SbP<0iNSC1@2ndnT40:_3k0@0
Z<3[5@2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo
00<000000?ooo`3oool02P3oool2000001D0oooo9`2W`>/50:Bok0<0T[Wa0P14TNl2015Tf@80?g3J
102XXm430<njaP@0e;Jl00<0e[6d0=Vn_`3I_[l0103G/k@30=N][@030<R_`@3<Z;H0c:Rf0080c:Rf
00<0eK>h0;jU`02nYL000P2nYL020:fJ``80_lCM0`2naN050:^ji0<0X:OK102NXmT30::Vf@D0YZSH
102XZML40:jhh@@0/;CL1@2`^=h40;>efP<0XjWK00<001bT0<;4g032a=`0103:bMX20>k=/@<0klna
0`3beK820?GN]0040?GV^@3ZhlX0j^?:0>[SbP<0iNSC0P3LjMd20;kCj@<0]/k/102[`n`I0:O0j`03
0000002W`>/0Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`050?ooo`00503oool00`000000oooo
0?ooo`070?ooo`<00000603ooolW0:O0j`D0Y;o/0`2B^O4204BAk`04000h^`0AI=T0?g3J03m`fP@0
Z:?A00<0ck[60=Bf_03D][`00P3D][`30=Ja]0@0ek>d103G[Jd40<bX]P80eK>h102nYL050;o4g@03
0:KhgP31g^h0`Mk^00@0Zk[T102PYm/309jSf@@0Y:OI1@2VZ=P20:RYe`80ZkWT102^^>420;2dg080
[;KQ1@2`^=h20;>efP80[K?M0`2PZ]d50<[9fP80clgH00<0k/fa0>o?/@3_ck400`3beK820?GN]080
mNJi0P3bkKl30>GXd`<0g>WM1@2fc^`50:W2k1T0Yl3[00<000000:O0j`2W`>/03`2W`>/:0?ooo`03
0000003oool0oooo00D0oooo000C0?ooo`<000001@3oool3000001`0oooo9`2W`>/50:Bok@<0S[Sb
0P0UPNP00`00>;/0?g3J03m`fP040:RSd@@0e;Jl103F/K@0103H[jl0ek>d0=Nc]03G/k@40=N][@03
0=ba[03<Z;H0c:Rf00@0eK>h0P2nYL020<W5e@<0_lCM1@31g^h30:^ji0@0X:OK102PY]X40:BWf@@0
YZSH1@2[^N@30:jhh@D0[;KQ102`^=h50:fcg@<0X:[M0`3:bMX30<o=f0<0klna0`3beK800`3eg[@0
mNJi0?GV^@030?;]_`030>kaa`3LjMd0g>WM0080g>WM0`3@i^L40:o8k@@0ZL;/6P2W`>/00`000000
Yl3[0:O0j`0?0:O0j`T0oooo00<000000?ooo`3oool01@3oool001<0oooo00<000000?ooo`3oool0
0P3oool300000200oooo9`2W`>/50:Bok@<0S[Sb0P0UPNP00`00>;/0:VOH03m`fP020:RSd@80]:O;
0`3D][`30=Ja]080f:n_0P3G/k@40=N][@80g;6/0P3<Z;H40=Fc^0D0bLGE0P3Bm^H20=kcg0<0`Mk^
102HXmd409^Tf`@0X:KJ0`2TYmT50:Nhi@@0ZkWT102Y]>440:bfh@D0[KKO102]/md409^Zh@@0clgH
0`3Ef]`30?;E/P80mMjd0P3ei[T20?;]_`80k_770P3Ym<l30=3Vi`<0`Mc]102_b>d40:S1jaT0Yl3[
00<000000:O0j`2W`>/0402W`>/80?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000003o
ool0000000800000903ooolW0:O0j`D0Y;o]0`2=]o<2011ehP03000h^`0ZImP0]:O;00@0]:O;00<0
e;Jl0=Ja]03F/K@00P3F/K@30=R_[`030=Nc]03G[Jd0ejf]0080ejf]0P3L/J`00`3<Z;H0eK>h0=Fc
^0030=Fc^0040=_3`P39aMD0bLGE0<W5e@80d_KV0P3Nlm`20<W>gP<0XJoQ102HXmd309^Tf`@0X:KJ
102T]>@40:Nhi@D0Yk?Q102Y]>440:bhh`@0[KKO1@2Y]^8409^Zh@80clgH0`3Ef]`20=C_i@80l]Fb
00<0mMjd0?GV^@3ei[T00`3bkKl01@3^lLL0jOC?0>Wdc`3Ym<l0h_KH00D0`Mc]1@2[a>`40:S1jaT0
Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00D0oooo000C0?ooo`<00000
9`3ooolW0:O0j`D0Y;o]0`2=]o<2011ehP80:VOH102dYl/40=Ja]0@0f:n_103G[Jd30=ba[0D0eK>h
0`3K`l830=;fiP80g_?L1039c]h30:6_h@<0V:?M102LYmh40:2_hP@0Y;CT102W/^440:Nch@D0Z[_U
102/^><40:Zhi0@0ZKKR102KZ^40101SQn00eM[L0=GJg03Ef]`40=C_i@040?GN]03ei[T0mNJi0?GV
^@80l^fo0P3^lLL20>Wdc`030>;ff03Gm><0eoCS00<0`Mc]0P2dd>h50:_4k1d0Yl3[00<000000:O0
j`2W`>/03`2W`>/70?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003oool0oooo02L0
oooo9`2W`>/50:Bok@<0S[Sc0P0;Ln001000Bl/0:VOH0;BWb`2dYl/20;^Ya`<0e[6d103H[jl0103K
/Zh0ejf]0=N][@3G[Jd30=ba[0040>:k[`3E/kP0eK>h0=Fc^0@0fl?20P3Ue/H00`3Nlm`0bLkN0<W>
gP040<W>gP@0Uj3J0`2GXM/409bWgP@0X:oR102V/n440:Nbh@@0ZKcW1@2Z^nD40:Rgi0@0Z[ST0`2Y
]^8509:UhP80IHSP0`3DknD20<7ik0<0/?Cb0P3bkKl20>kaa`80jOC?00<0h_KH0=Odh`3Gm><00P3G
m><50;C@kPD0Z<7/702W`>/00`000000Yl3[0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool0103o
ool000/0oooo1@0000050?ooo`800000:@3ooolV0:O0j`D0Y;o]0`2>^?<200]ch003001;b`2kZLL0
^jW700<0^jW700<0e[6d0=R_[`3H[jl00P3H[jl20=^b[P80ejf]103L/J`20>:k[`030=Fc^03K`l80
fl?20080fl?20`3Ue/H00`3ahkl0k]^o0>kK_`050;:bf0@0Uj3J0`2GXM/309bWgPD0YK?S102V/n44
0:Nkj0@0ZKcW1@2W]N<40:Rgi0<0Z[ST102S/>4509:UhP80IHSP0P31nN`30;3dlP80]?3f0`32kO42
0>Wdc`030>;ff03Gm><0eoCS0080eoCS0`37j>h40:c6k@@0Z<7/7@2W`>/00`000000Yl3[0:O0j`0@
0:O0j`H0oooo00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0W0?ooobH0Yl3[1@2T_n`308nhlP03015gh`00Bl/004_;00@0^jW71@3H[jl30=^b
[P040=N][@3L/J`0g;6/0=ba[0<0h[^_103K`l830>GFaP050?7S_`3^fkl0k]^o0>kK_`3Obl@0102b
/]P409NPfP<0Uj7K102R/^<40:Fch`D0Y[WW102W^nP40:NdhP@0YkGS102X]n@40:NdhP@0Xk3Q102B
YN8306F8h080<6[I0P2dl?H40<;]l@80c^oY00@0eoCS0=SjgP3Hn]h0f?[N0`37j>h30;KDl0@0[<K]
8@2W`>/00`000000Yl3[0:O0j`0@0:O0j`D0oooo00<000000?ooo`3oool0103oool000d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?ooobL0Yl3[102T_n`308nhlP03015gh`00
Bl/0^jW70080^jW70P2m[//30=R_[`@0fk:^103L/J`30>:k[`030>C1/`3K`l80fl?200<0iMK60P3a
hkl20>kK_`<0gl_40`2b/]P509RUgP<0W:cR102R/^<40:Bfi@@0Y[WW2@2W]>830:Neh`D0Z;ST102W
]>8409j`i0@0Rj7S0P1XRMl3031Zf@<0FY_a0`3>knT0103Gm><0f?[N0=SjgP3Hn]h20=7khPD0]]C`
1@2X`N`Q0:O0j`030000002W`>/0Yl3[00l0Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo9`2W`>/40:Bok0<0TKWb00<0
6ggV001;b`2kZLL00`2m[//30=R_[`@0fk:^00@0gkZa0=ba[03L/J`0g;6/0`3R^jl20>C1/`<0iMK6
0P3ahkl30>kK_`<0gl_4102YZML409RUgP@0W:cR102S/^<40:Bfi@@0YkKS202W]>840:VkiP@0Z;ST
1@2T]ND409j`i0<0Rj7S0`1XRMl305R5hP<0FY_a0P3Gm><30=SjgP80dO_R0`35k^l40:c6k@@0Z<7/
8@2W`>/00`000000Yl3[0:O0j`0@0:O0j`@0oooo00<000000?ooo`3oool0103oool000d0oooo00<0
00000?ooo`3oool02P3oool2000002P0oooo9`2W`>/40:Bok0<0TKWb00<06ggV0;f^b`2m[//00`2m
[//00`3H[jl0fk:^0=^b[P020=^b[P80gkZa0P3L/J`30>:k[`<0i<6c0P3Xa[<30?7S_`80k]^o103O
bl@00`3A_LH0ZJWG0:VYe`020:VYe`<0V:GN1@2Q[^440:>bh`80Y;KU0P2W]n@40:Nfh`@0YkCR102X
_>P40:VkiP@0YKGT102T]ND409j`i0<0Rj7S101XRMl305R5hP80T/3f0`2hhO@20=7khP<0aNk_0`2d
e?440:c6kBD0Yl3[00<000000:O0j`2W`>/03`2W`>/40?ooo`030000003oool0oooo00@0oooo000<
0?ooo`8000003P3oool00`000000oooo0?ooo`0V0?ooobL0Yl3[102U_n`409>jl@@0_Jk;1@3K/Zh3
0=nj/@040=ba[03R^jl0h[^_0>:k[`<0i<6c0P3Xa[<20?3@/@80k]^o103Obl@30=6maP<0ZJWG102P
Z]d50:6^h@<0Xk;S1@2W]n@30:Nfh`D0YkcX102X_>P40:Fdh`@0YKGT102Q[^4409NVh0<0Q9WO0`1b
S]l305R5hP@0^>7d00@0bOWY0<Kmh`36oN<0a_gS1@2de?450:S1k2D0Yl3[00<000000:O0j`2W`>/0
3`2W`>/30?ooo`030000003oool0oooo00@0oooo000M0?ooo`030000003oool0oooo02H0oooo9`2W
`>/40:Fok0@0U;[a0P2m[//20;Jgf@<0fk:^103O^[430>:k[`<0i<6c0`3Xa[<20?3@/@80mMB]00<0
l]6_0=o;a03Obl@0103A_LH40:b[eP@0X:[M1@2U]><30:Ngi@@0YkOT102W^^L40:Nlj0D0Y[?R102U
]><40:Fdi0@0XJkQ102GY^0308BIg`<0LXkO101nXn/00`39nNT0a_gS0<Kmh`020<Kmh`<0_ncb102[
aNd40:S1k2H0Yl3[00<000000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo00<0oooo000N
0?ooo`030000003oool0oooo02H0oooo9`2W`>/40:Fok0<0U;[a102f]mT30=^b[P@0gkZa00<0h/:h
0>:k[`3R^jl00`3T`K<20>S6/`<0l=2a0P3ee:d20?;A[`@0dKg60P3:]lP40:b[eP@0YJkN102U]><4
0:Ngi@@0Y[OU102W^^L40:NdhP@0Y[?R1@2W^NH40:Fdi0<0XJkQ102GY^0308BIg`<0LXkO102Vc_D3
0;_ik0030;o/lP2`c_00/<k`00<0/<k`102[aNdY0:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool0
0`000000oooo0?ooo`030?ooo`007`3oool2000002P0oooo9P2W`>/40:Fok0<0UK[a102f]mT00`3K
/Zh0gkZa0=nj/@020=nj/@<0h/:h0`3T`K<30>S6/`80l=2a0P3ee:d30?;A[`030>_<]03A_LH0dKg6
00@0b[O80P2/ZmH20;2]e@@0YJkN0`2U]><50:JdhP@0Y[OU102X]N840:NdhP@0Yk_W102W^NH40:Fd
i0@0Vj[Q102AXMl308BFg@<0Q9kT0P2Vc_D30;_ik0030;_liP2hhO@0^>7d00@0/<k`1@2X`N/Y0:O0
j`030000002W`>/0Yl3[0100Yl3[00<0oooo0000003oool0103oool00240oooo00<000000?ooo`3o
ool09P3ooolU0:O0j`D0YKo/0`2E^_430;Jgf@@0gkZa103R`[P00`3QaK`0i<6c0>C1/`030>S6/`80
l=2a0P3ee:d20?;A[`<0jlbd1@3:]lP50;2]e@<0YJkN102W/Ml40:JdhPD0ZKOS102X]N880:Nki`@0
XjkO102P[^4409^Zh@<0TJ7O1024U]d308BNi080^oW/00<0^ocV0;SQm02hhO@00`2hhO@40:W2k0@0
Z<7[:P2W`>/00`000000Yl3[0:O0j`0?0:O0j`030?ooo`000000oooo00@0oooo000R0?ooo`030000
003oool0oooo02H0oooo9@2W`>/50:Fok080Uk_a102I^nl30=nj/@<0h/:h0`3QaK`30>S6/`<0l=2a
0P3ee:d20?;A[`<0jlbd00@0i<Nj0<Zgb03:]lP0b[O80P37]LP40;2]e@@0ZjoK102W/Ml40:Zgh`@0
ZKOS1@2W^NH40:Nki`@0YJkN102S[]l30:2^h@@0Vj[Q0`2AXMl408BFg@<0Y=7h0P2Wn=h30;SdlP@0
ZlO^102Y`^`^0:O0j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002<0oooo
00<000000?ooo`3oool09P3ooolU0:O0j`H0YKo/00<0Uk_a09Vkk`2I^nl00P2I^nl0103O^[40h/:h
0>;2^03R`[P40>75_0030>77_@3Xa[<0j<Jc0080l=2a0P3ee:d20?;A[`<0jlbd0`3TakX00`3:]lP0
akG80<Neb0020<Neb080/:gE0P2e[m<40:^_f`@0ZkGP102Z]n<40:Rfh`@0YkWV1@2W[md40:F^gP<0
XjkO102OYMX409NKeP<0SYGF102>X^820:OhgP030;SdlP2_d?40[m3a00<0[m3a0`2[anhb0:O0j`03
0000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002@0oooo0P00000W0?ooobH0Yl3[
1@2U_n`0102H^o00VK__09Vkk`2I^nl40>;2^0<0hLFl0`3Qakd30?3@/@80mMB]0P3bdJl20>_<]0@0
i<Nj1@37]LP50;F_d`@0[[3I102[]N040:VagP@0Z;KS102Y/=d40:N_g@@0YJkN102T[]l409nUfP<0
Ui_F102>UMH30:3^n080XOKN0P2bgOH40:o@l@D0Z<7[<@2W`>/00`000000Yl3[0:O0j`0;0:O0j`<0
oooo00<000000?ooo`3oool00`3oool002H0oooo00<000000?ooo`3oool09@3ooolV0:O0j`@0YKo/
0`2H^o0206f_n080h/:h0`3QaK`40>77_@80i/jn0P3ee:d20?;A[`<0jlbd103TakX0103MaL00akG8
0<Neb037]LP20<Neb@80]JoC0`2h[m040:j`f@@0[:oI102Y/Mh40:^ag@@0ZK3M0`2W[md50:Jch@@0
Y:kO0`2OYMX309NKePD0V<Cf0P2Qm]h50;;MmPD0Z<;/=@2W`>/00`000000Yl3[0:O0j`060:O0j`P0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool09@3ooolV0:O0j`@0YKo/
0`2I_?02052RmP@0hLFl0`3Qakd30>K>_P80k]Rl00@0l]bi0>_<]03[c;@0jlbd103TakX20=g5`080
akG80`37]LT50;R_d080[[3I0`2b[M<40:b_f@80ZK7N0P2]/M/40:^ag@<0ZK3M102W/n440:Jch@@0
Y:kO102GUm8309>Rg`<0V<Cf102`joP50:[5kCT0Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`03
0000003oool0oooo0080oooo000X0?ooo`030000003oool0oooo02H0oooo9@2W`>/40:Fok0<0Vkc`
0P1@X_H20>75_0<0hLNm0`3Vc[h20>kH_080l]bi0P3agK/40>C7^P<0gLG01037]LT20<NgbP@0^:o@
1@2b[M<40:b_f@D0[K7K0`2[/Md40:R`g@@0Yk?Q102PULT409^Dc0@0UiOB0`2CX]l30:;blPD0Zl[`
?@2W`>/00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo000Y0?ooo`8000009`3o
oolU0:O0j`@0Y[o/0`2K_?0203ZFlP@0hLNm0P3Vc[h30>kH_0050?;L^@3agK/0lMfk0?7M^`3/g/@0
0P3TakX40=g5`0030=W6a`37]LT0akG900@0akO:0P2h[m020;b`cP@0/ZgC1@2`[]H40:faf`@0ZJ[G
102X/=d40:>Gb0<0X9G9102KU<`409NGdP0306gNd02Rl_80X_;b00D0Zlob?P2W`>/30?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool09@3o
oolU0:O0j`@0Y[o/0`2N_Nl203ZFlP80hLNm0`3Vc[h20>kH_080l]bi0P3agK/30>cNa0@0gLG00`3I
a/L50<NgbPD0_;3>0P2b[M<20;F/d0@0/:kF1@2[Y=040:VZe`@0Yi[90`2SUlP40:2Eb@<0ViC<0P1h
h^d208CZg`@0Z]?e1@2X`N/i0:O0j`P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`00;03oool00`000000oooo0?ooo`0U0?ooobD0Yl3[102V_n`409jmk`0402B=k03Vc[h0
i/jn0>K>_P<0k]Rl00@0l]bi0?7M^`3agK/0lMfk0`3/g/@00`3ThM00gLG00=g5`0030=W6a`80e<gB
0`37]lX20<Rnd0@0_;3>1@2e[=020;2^eP80/JK=102[Y=020:VZe`<0[J7<0`2WV/T40:>Gb0<0X9G9
102:h?d40:SFn0@0Z<;/102X`N/50:O1k340Yl3[2`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo000]0?ooo`030000003oool0oooo02H0oooo902W`>/40:Jok0@0XKk^00<0
Q;Kf01ZCj@3^f;`00P3^f;`20?;L^@80lMfk0`3/g/@30>CQd0<0fLK7103DcM800`37]lX0b;k@0<Rn
d0020<Rnd080_;3>0P2o]]440;F/d0D0/JK=0`2[Y=050:fQc0@0Yi[90`2SUlP509KKoP<0YMOi102X
`nd40:S2k0@0Yl3/102W`N`^0:O0j`l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`010?ooo`00;P3oool00`000000oooo0?ooo`0V0?ooob@0Yl3[1@2V`>`30:6nkP80Tk_c00<0:Z_X
0?;L^@3bg;T00P3agK/00`0m_^H0k=k40>cNa0030>CQd0<0eNSS1@3DcM850<Rnd0D0_kKA0P2e[=02
0;^dd`@0/JK=102d/=@40:fQc0@0Yi[9102KgOd40:7FnP@0Z<C^102X`nd40:O0j`@0Yl3/102W_n/Y
0:O0ja@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00;`3oool20000
02L0oooo:@2W`>/40:Bok@<0Tk_c00@0O;Oh03RlgP0h_=h0>;cN0P3ThM00100CX/`0eNSS0=GXh`3E
j><20:c^n0<0e<gB0P39gnP30<Rnd080a]?T102o]]450;^dd`80/JK=0P2lcNP40;B`e0<0[J7<1@2G
iO`309oCnPD0YlC^0`2Xa>h50:Noj`@0Yl3[202W_n/U0:O0jaP0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0U0?ooobT0Yl3[102V_n`4
09jnk`<0O;Oh0`0=R><50:c^n0D0bMoX1@36dn@40<7FjP@0^kCC1@2lcNP30;B`e080NnC^00<0<KW4
09k?n@2NcoT00`2NcoT40:K3kP@0YlC^202W_n/50:S0j`<0Yko[9@2W`>/L0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3oool09@3ooolY0:O0
j`@0Y[o/102T_nd409JmlP<0I[?k00@0083A03^ng@0k_]d0>kkM1@1ohoD507OQk`@0`MKZ1@2Ok?P3
0;c=j0<0ILkj1@2NboL40:K1k@@0Y/?^202W_n/40:S1j`@0Z<3[1@2W`>/40:Noja`0Yl3[803oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000c0?ooo`030000003oool0oooo
02D0oooo;@2W`>/40:Bok@@0X[o^102B_O@409Fom0@0L;cm00@08JCU07OQk`1ghNl0Mn7_101Q`Od5
0977nP@0X/?`102Pa_<40:K0k0@0Y/7]102X_n/40:Noj`D0Yl7/0`2X`N/90:O0j`@0Yko[602W`>/T
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00@3oool003@0oooo0P00000V0?oo
obd0Yl3[102V`>`80::okP@0UKod102L`?450:;0kP<0W<;c1@2T`Nd30:;3l0D0Yl3[102V`>`40:S0
j`@0Z;o[102W`N`80:Nojb00Yl3[:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0040oooo000f0?ooo`030000003oool0oooo02D0oooo<02W`>/80:K0k0@0Y<3]102V`>`40:;0kP@0
Y/3/102T`Nd80:O0j`D0Z<7[0`2X`>/50:O0k0P0Yko[802W`>//0?ooo`030000003oool0oooo00L0
oooo0@0000010?ooo`40oooo000g0?ooo`030000003oool0oooo02D0oooo=02W`>/40:K0k0@0Yl3[
102V`>`40:O0j`@0Y/3/202W`>/50:O1k0@0Yko[102W`>/40:Roj`@0Yko[102W`N`<0:O0j`@0Yko[
302W`>/`0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo000h0?ooo`030000003o
ool0oooo02D0ooooD@2W`>/80:Noj`@0Z<3[102X_n/80:O1k0@0Yko[202W`>/40:Noj`@0Yl3[>03o
ool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>@3oool2000002H0ooooD@2W`>/4
0:Noj`@0Yl3[0`2X`>/50:O0k0<0Yl7/202W_n/=0:O0jc/0oooo00<000000?ooo`3oool01@3oool1
00000040oooo0@3oool003/0oooo00<000000?ooo`3oool0903ooomL0:O0j`@0Yl3/202W_n/=0:O0
jcl0oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool003`0oooo00<000000?ooo`3o
ool0903ooomD0:O0j`@0Yko[102W`>/50:Noj`P0Yl7/102W_n/40:O0jd<0oooo00<000000?ooo`3o
ool00`3oool100000040oooo0@3oool003d0oooo00<000000?ooo`3oool0903ooom@0:O0j`P0Yko[
1@2X`>/40:O0k0<0Yl7/202W_n]80?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40oooo
000n0?ooo`8000009@3ooomM0:O0j`<0Yl3/202W_n];0?ooo`030000003oool0oooo00<0oooo0@00
00010?ooo`00@03oool00`000000oooo0?ooo`0S0?oooe@0Yl3[102W_n/40:O0j`P0Yko[C`3oool0
0`000000oooo0?ooo`020?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3ooom@0:O0
j`P0Yko[102W`>/40:Noje<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3oool00`00
0000oooo0?ooo`0T0?ooodl0Yl3[102W_n/80:O0jeL0oooo00@000000?ooo`3oool000000@3oool0
04<0oooo0P00000U0?oooe<0Yl3[GP3oool010000000oooo0?ooo`0000010?ooo`00A@3oool00`00
0000oooo0?ooo`0S0?ooodl0Yl3[HP3oool00`000000oooo000000010?ooo`00AP3oool00`000000
oooo0?ooo`0S0?oood/0Yl3[IP3oool100000040oooo0@00000004L0oooo00<000000?ooo`3oool0
8`3ooom70:O0jfX0oooo0P00000004P0oooo0P00000U0?oood80Yl3[K@3oool200000000BP3oool0
0`000000oooo0?ooo`0S0?oooch0Yl3[L03oool200000000B`3oool00`000000oooo0?ooo`0R0?oo
oc/0Yl3[K`3oool400000080oooo001<0?ooo`030000003oool0oooo02<0oooo<`2W`>]a0?ooo`@0
00001P3oool004d0oooo0P00000T0?ooobl0Yl3[L03oool4000000X0oooo001?0?ooo`030000003o
ool0oooo0280oooo:`2W`>]_0?ooo`@000003P3oool00500oooo00<000000?ooo`3oool08`3ooolV
0:O0jfh0oooo1000000B0?ooo`00D@3oool00`000000oooo0?ooo`0S0?ooob80Yl3[KP3oool30000
01H0oooo001B0?ooo`800000903ooolN0:O0jfd0oooo1000000I0?ooo`00E03oool00`000000oooo
0?ooo`0R0?oooaL0Yl3[K`3oool4000001d0oooo001E0?ooo`030000003oool0oooo0240oooo502W
`>]^0?ooo`@000008@3oool005H0oooo00<000000?ooo`3oool08P3oool?0:O0jfd0oooo1000000U
0?ooo`00E`3oool2000002<0oooo2`2W`>]/0?ooo`@00000:@3oool005T0oooo00<000000?ooo`3o
ool08@3oool40:O0jfl0oooo0`00000]0?ooo`00FP3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo06X0oooo1000000`0?ooo`00F`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo06H0oooo1000000d0?ooo`00G03oool200000240oooo00<000000?ooo`3oool0HP3oool4
000003P0oooo001N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool40000
03`0oooo001O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool400000400
oooo001P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool3000004@0oooo
001Q0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`@00000A`3oool006<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000B`3oool006@0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1;0?ooo`@00000C`3oool006D0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`170?ooo`@00000D`3oool006H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`130?ooo`@00000E`3oool006L0oooo0P00000F0?ooo`030000003o
ool0oooo0400oooo0`00001K0?ooo`00J@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03`0oooo1000001N0?ooo`00JP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
03P0oooo1000001R0?ooo`00J`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0
oooo1000001V0?ooo`00K03oool200000100oooo00<000000?ooo`3oool0<@3oool4000006X0oooo
001^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;@3oool4000006h0oooo001_
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3oool300000780oooo001`0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool4000007D0oooo001a0?ooo`80
00002`3oool00`000000oooo0?ooo`0R0?ooo`@00000N@3oool007<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0N0?ooo`@00000O@3oool007@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000P@3oool007D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0F0?ooo`@00000Q@3oool007H0oooo0P0000060?ooo`030000003oool0oooo
01<0oooo0`0000290?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0
oooo1000002<0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
1000002@0?ooo`00NP3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002D0?ooo`00N`3o
ool2000000030?ooo`000000oooo00@0oooo1000002H0?ooo`00O@3oool2000000030?ooo`000000
000000800000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .6551 .56155 .64914 Mtetra
.56155 .64914 .56753 .6551 .57895 .65187 .573 .6459 Mtetra
.573 .6459 .57895 .65187 .59042 .64864 .5845 .64264 Mtetra
.656 .752 .921 r
.5845 .64264 .59042 .64864 .60194 .64539 .59604 .63937 Mtetra
.656 .752 .92 r
.59604 .63937 .60194 .64539 .6135 .64215 .60764 .63607 Mtetra
.656 .751 .92 r
.60764 .63607 .6135 .64215 .62511 .63889 .61928 .63275 Mtetra
.656 .75 .919 r
.61928 .63275 .62511 .63889 .63677 .63561 .63097 .62943 Mtetra
.656 .749 .918 r
.63097 .62943 .63677 .63561 .64848 .6323 .64272 .62611 Mtetra
.656 .749 .919 r
.64272 .62611 .64848 .6323 .66024 .62897 .65451 .62279 Mtetra
.656 .75 .92 r
.65451 .62279 .66024 .62897 .67204 .62564 .66635 .61944 Mtetra
.656 .751 .92 r
.66635 .61944 .67204 .62564 .6839 .6223 .67824 .61607 Mtetra
.67824 .61607 .6839 .6223 .6958 .61896 .69018 .61267 Mtetra
.657 .75 .919 r
.69018 .61267 .6958 .61896 .70776 .61559 .70216 .60925 Mtetra
.656 .749 .918 r
.70216 .60925 .70776 .61559 .71977 .61221 .71421 .60584 Mtetra
.655 .749 .919 r
.71421 .60584 .71977 .61221 .73182 .60882 .7263 .60244 Mtetra
.7263 .60244 .73182 .60882 .74393 .60538 .73845 .59903 Mtetra
.656 .751 .92 r
.73845 .59903 .74393 .60538 .75609 .60193 .75064 .59558 Mtetra
.656 .752 .92 r
.75064 .59558 .75609 .60193 .7683 .59849 .76289 .5921 Mtetra
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Mtetra
.656 .751 .92 r
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Mtetra
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64264 .57853 .63658 Mtetra
.57853 .63658 .5845 .64264 .59604 .63937 .59011 .63329 Mtetra
.655 .751 .92 r
.59011 .63329 .59604 .63937 .60764 .63607 .60173 .62999 Mtetra
.655 .752 .921 r
.60173 .62999 .60764 .63607 .61928 .63275 .61341 .62668 Mtetra
.655 .753 .922 r
.61341 .62668 .61928 .63275 .63097 .62943 .62514 .62335 Mtetra
.656 .754 .922 r
.62514 .62335 .63097 .62943 .64272 .62611 .63691 .62 Mtetra
.656 .753 .922 r
.63691 .62 .64272 .62611 .65451 .62279 .64873 .61662 Mtetra
.656 .753 .921 r
.64873 .61662 .65451 .62279 .66635 .61944 .66061 .61323 Mtetra
.656 .752 .921 r
.66061 .61323 .66635 .61944 .67824 .61607 .67253 .60983 Mtetra
.655 .752 .921 r
.67253 .60983 .67824 .61607 .69018 .61267 .68451 .60644 Mtetra
.655 .753 .922 r
.68451 .60644 .69018 .61267 .70216 .60925 .69653 .60303 Mtetra
.655 .754 .923 r
.69653 .60303 .70216 .60925 .71421 .60584 .70861 .5996 Mtetra
.656 .754 .922 r
.70861 .5996 .71421 .60584 .7263 .60244 .72074 .59613 Mtetra
.657 .753 .921 r
.72074 .59613 .7263 .60244 .73845 .59903 .73292 .59264 Mtetra
.656 .752 .92 r
.73292 .59264 .73845 .59903 .75064 .59558 .74515 .58914 Mtetra
.656 .751 .92 r
.74515 .58914 .75064 .59558 .76289 .5921 .75744 .58564 Mtetra
.75744 .58564 .76289 .5921 .77519 .58861 .76977 .58214 Mtetra
.76977 .58214 .77519 .58861 .78754 .58511 .78217 .57861 Mtetra
.78217 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Mtetra
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54248 Mtetra
.90908 .54248 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63658 .57251 .63049 Mtetra
.656 .752 .92 r
.57251 .63049 .57853 .63658 .59011 .63329 .58412 .62717 Mtetra
.58412 .62717 .59011 .63329 .60173 .62999 .59578 .62382 Mtetra
.657 .751 .92 r
.59578 .62382 .60173 .62999 .61341 .62668 .60749 .62045 Mtetra
.656 .75 .919 r
.60749 .62045 .61341 .62668 .62514 .62335 .61925 .61708 Mtetra
.656 .749 .918 r
.61925 .61708 .62514 .62335 .63691 .62 .63106 .61371 Mtetra
.655 .749 .919 r
.63106 .61371 .63691 .62 .64873 .61662 .64292 .61033 Mtetra
.656 .75 .92 r
.64292 .61033 .64873 .61662 .66061 .61323 .65482 .60693 Mtetra
.656 .751 .92 r
.65482 .60693 .66061 .61323 .67253 .60983 .66678 .60351 Mtetra
.66678 .60351 .67253 .60983 .68451 .60644 .67879 .60006 Mtetra
.657 .75 .919 r
.67879 .60006 .68451 .60644 .69653 .60303 .69085 .59659 Mtetra
.656 .749 .918 r
.69085 .59659 .69653 .60303 .70861 .5996 .70296 .59312 Mtetra
.656 .748 .918 r
.70296 .59312 .70861 .5996 .72074 .59613 .71513 .58965 Mtetra
.655 .749 .919 r
.71513 .58965 .72074 .59613 .73292 .59264 .72735 .58618 Mtetra
.655 .751 .92 r
.72735 .58618 .73292 .59264 .74515 .58914 .73962 .58268 Mtetra
.656 .752 .921 r
.73962 .58268 .74515 .58914 .75744 .58564 .75194 .57916 Mtetra
.656 .752 .92 r
.75194 .57916 .75744 .58564 .76977 .58214 .76431 .57561 Mtetra
.656 .751 .92 r
.76431 .57561 .76977 .58214 .78217 .57861 .77674 .57206 Mtetra
.77674 .57206 .78217 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54248 .90406 .53563 Mtetra
.90406 .53563 .90908 .54248 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62434 Mtetra
.56645 .62434 .57251 .63049 .58412 .62717 .57809 .62099 Mtetra
.655 .751 .92 r
.57809 .62099 .58412 .62717 .59578 .62382 .58979 .61764 Mtetra
.655 .752 .921 r
.58979 .61764 .59578 .62382 .60749 .62045 .60153 .61429 Mtetra
.655 .753 .922 r
.60153 .61429 .60749 .62045 .61925 .61708 .61332 .61091 Mtetra
.656 .754 .922 r
.61332 .61091 .61925 .61708 .63106 .61371 .62516 .6075 Mtetra
.62516 .6075 .63106 .61371 .64292 .61033 .63705 .60407 Mtetra
.656 .753 .921 r
.63705 .60407 .64292 .61033 .65482 .60693 .649 .60062 Mtetra
.656 .752 .921 r
.649 .60062 .65482 .60693 .66678 .60351 .66099 .59717 Mtetra
.655 .752 .921 r
.66099 .59717 .66678 .60351 .67879 .60006 .67303 .59372 Mtetra
.655 .753 .922 r
.67303 .59372 .67879 .60006 .69085 .59659 .68513 .59026 Mtetra
.655 .754 .922 r
.68513 .59026 .69085 .59659 .70296 .59312 .69728 .58678 Mtetra
.656 .755 .922 r
.69728 .58678 .70296 .59312 .71513 .58965 .70948 .58325 Mtetra
.656 .754 .922 r
.70948 .58325 .71513 .58965 .72735 .58618 .72173 .5797 Mtetra
.656 .752 .92 r
.72173 .5797 .72735 .58618 .73962 .58268 .73404 .57615 Mtetra
.656 .751 .92 r
.73404 .57615 .73962 .58268 .75194 .57916 .7464 .5726 Mtetra
.7464 .5726 .75194 .57916 .76431 .57561 .75881 .56904 Mtetra
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62434 .56034 .61816 Mtetra
.656 .752 .92 r
.56034 .61816 .56645 .62434 .57809 .62099 .57202 .61479 Mtetra
.57202 .61479 .57809 .62099 .58979 .61764 .58374 .61138 Mtetra
.657 .751 .92 r
.58374 .61138 .58979 .61764 .60153 .61429 .59552 .60795 Mtetra
.656 .749 .918 r
.59552 .60795 .60153 .61429 .61332 .61091 .60734 .60452 Mtetra
.656 .748 .918 r
.60734 .60452 .61332 .61091 .62516 .6075 .61922 .6011 Mtetra
.655 .749 .919 r
.61922 .6011 .62516 .6075 .63705 .60407 .63114 .59767 Mtetra
.655 .75 .919 r
.63114 .59767 .63705 .60407 .649 .60062 .64312 .59423 Mtetra
.656 .751 .92 r
.64312 .59423 .649 .60062 .66099 .59717 .65515 .59075 Mtetra
.65515 .59075 .66099 .59717 .67303 .59372 .66723 .58724 Mtetra
.657 .75 .919 r
.66723 .58724 .67303 .59372 .68513 .59026 .67936 .58371 Mtetra
.656 .749 .918 r
.67936 .58371 .68513 .59026 .69728 .58678 .69154 .58019 Mtetra
.655 .748 .918 r
.69154 .58019 .69728 .58678 .70948 .58325 .70378 .57667 Mtetra
.655 .749 .919 r
.70378 .57667 .70948 .58325 .72173 .5797 .71607 .57315 Mtetra
.655 .751 .92 r
.71607 .57315 .72173 .5797 .73404 .57615 .72841 .56959 Mtetra
.656 .752 .921 r
.72841 .56959 .73404 .57615 .7464 .5726 .74081 .56601 Mtetra
.656 .752 .92 r
.74081 .56601 .7464 .5726 .75881 .56904 .75326 .56241 Mtetra
.656 .751 .92 r
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.54252 .6153 .54871 .62151 .56034 .61816 .55418 .61191 Mtetra
.55418 .61191 .56034 .61816 .57202 .61479 .56589 .60851 Mtetra
.655 .751 .92 r
.56589 .60851 .57202 .61479 .58374 .61138 .57765 .60511 Mtetra
.655 .752 .921 r
.57765 .60511 .58374 .61138 .59552 .60795 .58946 .60171 Mtetra
.655 .754 .922 r
.58946 .60171 .59552 .60795 .60734 .60452 .60132 .59829 Mtetra
.656 .755 .923 r
.60132 .59829 .60734 .60452 .61922 .6011 .61323 .59482 Mtetra
.656 .755 .922 r
.61323 .59482 .61922 .6011 .63114 .59767 .62519 .59133 Mtetra
.656 .753 .921 r
.62519 .59133 .63114 .59767 .64312 .59423 .6372 .58782 Mtetra
.656 .752 .921 r
.6372 .58782 .64312 .59423 .65515 .59075 .64926 .58432 Mtetra
.655 .752 .921 r
.64926 .58432 .65515 .59075 .66723 .58724 .66138 .58082 Mtetra
.655 .753 .922 r
.66138 .58082 .66723 .58724 .67936 .58371 .67355 .57731 Mtetra
.655 .755 .923 r
.67355 .57731 .67936 .58371 .69154 .58019 .68577 .57377 Mtetra
.656 .755 .923 r
.68577 .57377 .69154 .58019 .70378 .57667 .69804 .57018 Mtetra
.657 .754 .922 r
.69804 .57018 .70378 .57667 .71607 .57315 .71036 .56656 Mtetra
.656 .752 .92 r
.71036 .56656 .71607 .57315 .72841 .56959 .72274 .56295 Mtetra
.656 .751 .92 r
.72274 .56295 .72841 .56959 .74081 .56601 .73518 .55934 Mtetra
.73518 .55934 .74081 .56601 .75326 .56241 .74767 .55572 Mtetra
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Mtetra
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Mtetra
.655 .752 .921 r
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .60222 Mtetra
.656 .752 .921 r
.55972 .60222 .56589 .60851 .57765 .60511 .57151 .59877 Mtetra
.656 .752 .92 r
.57151 .59877 .57765 .60511 .58946 .60171 .58335 .5953 Mtetra
.655 .75 .919 r
.58335 .5953 .58946 .60171 .60132 .59829 .59525 .59184 Mtetra
.654 .749 .92 r
.59525 .59184 .60132 .59829 .61323 .59482 .60719 .58841 Mtetra
.653 .751 .921 r
.60719 .58841 .61323 .59482 .62519 .59133 .61919 .58498 Mtetra
.654 .754 .923 r
.61919 .58498 .62519 .59133 .6372 .58782 .63124 .58151 Mtetra
.655 .757 .924 r
.63124 .58151 .6372 .58782 .64926 .58432 .64333 .57798 Mtetra
.657 .757 .924 r
.64333 .57798 .64926 .58432 .66138 .58082 .65548 .57438 Mtetra
.658 .755 .922 r
.65548 .57438 .66138 .58082 .67355 .57731 .66769 .57075 Mtetra
.658 .752 .92 r
.66769 .57075 .67355 .57731 .68577 .57377 .67994 .56711 Mtetra
.656 .75 .919 r
.67994 .56711 .68577 .57377 .69804 .57018 .69225 .56351 Mtetra
.655 .75 .919 r
.69225 .56351 .69804 .57018 .71036 .56656 .70461 .55992 Mtetra
.656 .752 .92 r
.70461 .55992 .71036 .56656 .72274 .56295 .71703 .5563 Mtetra
.656 .752 .921 r
.71703 .5563 .72274 .56295 .73518 .55934 .7295 .55265 Mtetra
.656 .752 .92 r
.7295 .55265 .73518 .55934 .74767 .55572 .74203 .54898 Mtetra
.656 .751 .92 r
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Mtetra
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Mtetra
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60616 Mtetra
.655 .751 .921 r
.51833 .60616 .52464 .61244 .53629 .60904 .53 .60274 Mtetra
.655 .752 .921 r
.53 .60274 .53629 .60904 .54798 .60563 .54173 .59934 Mtetra
.652 .752 .923 r
.54173 .59934 .54798 .60563 .55972 .60222 .5535 .59598 Mtetra
.648 .753 .926 r
.5535 .59598 .55972 .60222 .57151 .59877 .56533 .59273 Mtetra
.642 .759 .933 r
.56533 .59273 .57151 .59877 .58335 .5953 .57721 .58959 Mtetra
.637 .77 .943 r
.57721 .58959 .58335 .5953 .59525 .59184 .58915 .58652 Mtetra
.634 .783 .953 r
.58915 .58652 .59525 .59184 .60719 .58841 .60114 .58341 Mtetra
.634 .796 .96 r
.60114 .58341 .60719 .58841 .61919 .58498 .61318 .58019 Mtetra
.637 .806 .964 r
.61318 .58019 .61919 .58498 .63124 .58151 .62527 .57682 Mtetra
.643 .813 .965 r
.62527 .57682 .63124 .58151 .64333 .57798 .63741 .57326 Mtetra
.65 .815 .962 r
.63741 .57326 .64333 .57798 .65548 .57438 .6496 .56952 Mtetra
.657 .812 .958 r
.6496 .56952 .65548 .57438 .66769 .57075 .66184 .56562 Mtetra
.663 .805 .951 r
.66184 .56562 .66769 .57075 .67994 .56711 .67412 .56161 Mtetra
.666 .793 .943 r
.67412 .56161 .67994 .56711 .69225 .56351 .68645 .55756 Mtetra
.666 .779 .933 r
.68645 .55756 .69225 .56351 .70461 .55992 .69883 .55357 Mtetra
.662 .765 .926 r
.69883 .55357 .70461 .55992 .71703 .5563 .71128 .54969 Mtetra
.659 .757 .922 r
.71128 .54969 .71703 .5563 .7295 .55265 .72378 .54593 Mtetra
.657 .753 .921 r
.72378 .54593 .7295 .55265 .74203 .54898 .73634 .54221 Mtetra
.656 .752 .921 r
.73634 .54221 .74203 .54898 .75461 .54531 .74896 .53849 Mtetra
.656 .752 .92 r
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Mtetra
.656 .751 .92 r
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Mtetra
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61009 Mtetra
.47713 .61009 .4836 .61634 .49513 .61296 .48869 .60668 Mtetra
.655 .751 .92 r
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60327 Mtetra
.654 .751 .921 r
.5003 .60327 .5067 .60956 .51833 .60616 .51196 .59988 Mtetra
.65 .752 .924 r
.51196 .59988 .51833 .60616 .53 .60274 .52366 .59659 Mtetra
.64 .753 .931 r
.52366 .59659 .53 .60274 .54173 .59934 .53542 .59353 Mtetra
.623 .761 .945 r
.53542 .59353 .54173 .59934 .5535 .59598 .54724 .59084 Mtetra
.596 .777 .967 r
.54724 .59084 .5535 .59598 .56533 .59273 .55911 .58853 Mtetra
.557 .801 .99 r
.55911 .58853 .56533 .59273 .57721 .58959 .57105 .58651 Mtetra
.505 .824 1 r
.57105 .58651 .57721 .58959 .58915 .58652 .58305 .58458 Mtetra
.442 .837 .981 r
.58305 .58458 .58915 .58652 .60114 .58341 .59512 .5825 Mtetra
.387 .834 .933 r
.59512 .5825 .60114 .58341 .61318 .58019 .60723 .58003 Mtetra
.361 .83 .885 r
.60723 .58003 .61318 .58019 .62527 .57682 .61939 .57704 Mtetra
.377 .842 .864 r
.61939 .57704 .62527 .57682 .63741 .57326 .6316 .57346 Mtetra
.433 .873 .88 r
.6316 .57346 .63741 .57326 .6496 .56952 .64383 .5693 Mtetra
.518 .911 .92 r
.64383 .5693 .6496 .56952 .66184 .56562 .6561 .5646 Mtetra
.603 .932 .959 r
.6561 .5646 .66184 .56562 .67412 .56161 .66839 .55951 Mtetra
.66 .92 .976 r
.66839 .55951 .67412 .56161 .68645 .55756 .68072 .55426 Mtetra
.685 .884 .972 r
.68072 .55426 .68645 .55756 .69883 .55357 .6931 .5491 Mtetra
.687 .841 .957 r
.6931 .5491 .69883 .55357 .71128 .54969 .70554 .54421 Mtetra
.679 .803 .941 r
.70554 .54421 .71128 .54969 .72378 .54593 .71805 .53971 Mtetra
.668 .775 .93 r
.71805 .53971 .72378 .54593 .73634 .54221 .73063 .53557 Mtetra
.661 .76 .924 r
.73063 .53557 .73634 .54221 .74896 .53849 .74328 .53167 Mtetra
.657 .754 .921 r
.74328 .53167 .74896 .53849 .76164 .53477 .75599 .52787 Mtetra
.656 .752 .92 r
.75599 .52787 .76164 .53477 .77437 .53103 .76876 .5241 Mtetra
.656 .751 .92 r
.76876 .5241 .77437 .53103 .78716 .52728 .78159 .52031 Mtetra
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Mtetra
.45908 .6072 .46562 .61348 .47713 .61009 .47062 .60379 Mtetra
.655 .751 .921 r
.47062 .60379 .47713 .61009 .48869 .60668 .48221 .60038 Mtetra
.652 .751 .923 r
.48221 .60038 .48869 .60668 .5003 .60327 .49385 .59705 Mtetra
.641 .751 .929 r
.49385 .59705 .5003 .60327 .51196 .59988 .50554 .59398 Mtetra
.614 .755 .945 r
.50554 .59398 .51196 .59988 .52366 .59659 .51727 .59151 Mtetra
.556 .765 .975 r
.51727 .59151 .52366 .59659 .53542 .59353 .52907 .58992 Mtetra
.44 .775 .997 r
.52907 .58992 .53542 .59353 .54724 .59084 .54094 .58917 Mtetra
.243 .733 .921 r
.54094 .58917 .54724 .59084 .55911 .58853 .55288 .58877 Mtetra
.068 .631 .731 r
.55288 .58877 .55911 .58853 .57105 .58651 .56489 .58797 Mtetra
0 0 0 r
.56489 .58797 .57105 .58651 .58305 .58458 .57695 .58622 Mtetra
.57695 .58622 .58305 .58458 .59512 .5825 .58906 .58347 Mtetra
.277 .779 .777 r
.58906 .58347 .59512 .5825 .60723 .58003 .60122 .58007 Mtetra
.403 .856 .885 r
.60122 .58007 .60723 .58003 .61939 .57704 .61342 .57644 Mtetra
.458 .878 .932 r
.61342 .57644 .61939 .57704 .6316 .57346 .62568 .57285 Mtetra
.453 .875 .931 r
.62568 .57285 .6316 .57346 .64383 .5693 .638 .56928 Mtetra
.413 .861 .887 r
.638 .56928 .64383 .5693 .6561 .5646 .65036 .5655 Mtetra
.375 .84 .811 r
.65036 .5655 .6561 .5646 .66839 .55951 .66275 .56104 Mtetra
.397 .848 .766 r
.66275 .56104 .66839 .55951 .68072 .55426 .67514 .55556 Mtetra
.504 .907 .81 r
.67514 .55556 .68072 .55426 .6931 .5491 .68753 .54911 Mtetra
.64 .963 .906 r
.68753 .54911 .6931 .5491 .70554 .54421 .69993 .54224 Mtetra
.71 .94 .959 r
.69993 .54224 .70554 .54421 .71805 .53971 .71239 .53571 Mtetra
.709 .869 .957 r
.71239 .53571 .71805 .53971 .73063 .53557 .72493 .53003 Mtetra
.686 .807 .94 r
.72493 .53003 .73063 .53557 .74328 .53167 .73757 .52524 Mtetra
.668 .772 .927 r
.73757 .52524 .74328 .53167 .75599 .52787 .7503 .52105 Mtetra
.659 .757 .922 r
.7503 .52105 .75599 .52787 .76876 .5241 .7631 .51713 Mtetra
.657 .753 .921 r
.7631 .51713 .76876 .5241 .78159 .52031 .77597 .51329 Mtetra
.656 .752 .92 r
.77597 .51329 .78159 .52031 .79448 .51651 .7889 .50945 Mtetra
.656 .751 .92 r
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Mtetra
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Mtetra
.654 .751 .921 r
.45248 .60088 .45908 .6072 .47062 .60379 .46405 .59747 Mtetra
.649 .751 .924 r
.46405 .59747 .47062 .60379 .48221 .60038 .47567 .5942 Mtetra
.63 .75 .934 r
.47567 .5942 .48221 .60038 .49385 .59705 .48734 .5914 Mtetra
.575 .751 .961 r
.48734 .5914 .49385 .59705 .50554 .59398 .49905 .58966 Mtetra
.44 .747 .993 r
.49905 .58966 .50554 .59398 .51727 .59151 .51082 .58937 Mtetra
.171 .675 .909 r
.51082 .58937 .51727 .59151 .52907 .58992 .52266 .58999 Mtetra
.011 0 0 r
.52266 .58999 .52907 .58992 .54094 .58917 .53458 .59002 Mtetra
.146 .689 .73 r
.53458 .59002 .54094 .58917 .55288 .58877 .54656 .58798 Mtetra
.547 .912 .957 r
.54656 .58798 .55288 .58877 .56489 .58797 .55858 .58371 Mtetra
.715 .846 .944 r
.55858 .58371 .56489 .58797 .57695 .58622 .57064 .57819 Mtetra
.708 .728 .866 r
.57064 .57819 .57695 .58622 .58906 .58347 .58273 .57258 Mtetra
.681 .659 .822 r
.58273 .57258 .58906 .58347 .60122 .58007 .59487 .56753 Mtetra
.659 .624 .804 r
.59487 .56753 .60122 .58007 .61342 .57644 .60708 .5632 Mtetra
.643 .608 .799 r
.60708 .5632 .61342 .57644 .62568 .57285 .61935 .55958 Mtetra
.629 .601 .802 r
.61935 .55958 .62568 .57285 .638 .56928 .6317 .55666 Mtetra
.614 .603 .816 r
.6317 .55666 .638 .56928 .65036 .5655 .64413 .55446 Mtetra
.6 .624 .847 r
.64413 .55446 .65036 .5655 .66275 .56104 .65665 .55282 Mtetra
.593 .686 .907 r
.65665 .55282 .66275 .56104 .67514 .55556 .66924 .55111 Mtetra
.6 .818 .983 r
.66924 .55111 .67514 .55556 .68753 .54911 .68185 .54812 Mtetra
.597 .933 .953 r
.68185 .54812 .68753 .54911 .69993 .54224 .6944 .54285 Mtetra
.622 .96 .869 r
.6944 .54285 .69993 .54224 .71239 .53571 .70688 .53548 Mtetra
.708 .98 .907 r
.70688 .53548 .71239 .53571 .72493 .53003 .71936 .52748 Mtetra
.74 .93 .952 r
.71936 .52748 .72493 .53003 .73757 .52524 .73192 .52041 Mtetra
.708 .842 .946 r
.73192 .52041 .73757 .52524 .7503 .52105 .7446 .5148 Mtetra
.677 .784 .931 r
.7446 .5148 .7503 .52105 .7631 .51713 .75741 .51028 Mtetra
.661 .76 .923 r
.75741 .51028 .7631 .51713 .77597 .51329 .77031 .50624 Mtetra
.657 .753 .921 r
.77031 .50624 .77597 .51329 .7889 .50945 .78327 .50234 Mtetra
.656 .752 .92 r
.78327 .50234 .7889 .50945 .80189 .5056 .7963 .49845 Mtetra
.656 .751 .92 r
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .60141 Mtetra
.42277 .60141 .42948 .60773 .44096 .60431 .43428 .59796 Mtetra
.655 .751 .921 r
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .59454 Mtetra
.648 .75 .924 r
.44583 .59454 .45248 .60088 .46405 .59747 .45743 .59127 Mtetra
.623 .748 .936 r
.45743 .59127 .46405 .59747 .47567 .5942 .46907 .58861 Mtetra
.544 .743 .968 r
.46907 .58861 .47567 .5942 .48734 .5914 .48075 .5874 Mtetra
.327 .705 .982 r
.48075 .5874 .48734 .5914 .49905 .58966 .49248 .58812 Mtetra
0 .563 .795 r
.49248 .58812 .49905 .58966 .51082 .58937 .50428 .58957 Mtetra
.038 .607 .716 r
.50428 .58957 .51082 .58937 .52266 .58999 .51617 .58907 Mtetra
.543 .907 .963 r
.51617 .58907 .52266 .58999 .53458 .59002 .52813 .58502 Mtetra
.745 .823 .912 r
.52813 .58502 .53458 .59002 .54656 .58798 .54013 .5785 Mtetra
.721 .699 .829 r
.54013 .5785 .54656 .58798 .55858 .58371 .55216 .57178 Mtetra
.686 .645 .803 r
.55216 .57178 .55858 .58371 .57064 .57819 .56423 .56612 Mtetra
.667 .635 .808 r
.56423 .56612 .57064 .57819 .58273 .57258 .57636 .56151 Mtetra
.658 .648 .828 r
.57636 .56151 .58273 .57258 .59487 .56753 .58854 .55749 Mtetra
.655 .667 .849 r
.58854 .55749 .59487 .56753 .60708 .5632 .60079 .55372 Mtetra
.654 .679 .861 r
.60079 .55372 .60708 .5632 .61935 .55958 .61308 .55006 Mtetra
.65 .677 .862 r
.61308 .55006 .61935 .55958 .6317 .55666 .62544 .54652 Mtetra
.642 .661 .853 r
.62544 .54652 .6317 .55666 .64413 .55446 .63786 .54323 Mtetra
.626 .634 .838 r
.63786 .54323 .64413 .55446 .65665 .55282 .65036 .54054 Mtetra
.6 .604 .827 r
.65036 .54054 .65665 .55282 .66924 .55111 .66297 .53889 Mtetra
.572 .591 .834 r
.66297 .53889 .66924 .55111 .68185 .54812 .6757 .53832 Mtetra
.568 .638 .88 r
.6757 .53832 .68185 .54812 .6944 .54285 .6885 .53755 Mtetra
.625 .798 .965 r
.6885 .53755 .6944 .54285 .70688 .53548 .70125 .53426 Mtetra
.696 .96 .946 r
.70125 .53426 .70688 .53548 .71936 .52748 .71386 .52734 Mtetra
.741 .988 .893 r
.71386 .52734 .71936 .52748 .73192 .52041 .72638 .51843 Mtetra
.767 .953 .935 r
.72638 .51843 .73192 .52041 .7446 .5148 .73897 .51025 Mtetra
.725 .859 .944 r
.73897 .51025 .7446 .5148 .75741 .51028 .75172 .50403 Mtetra
.681 .788 .931 r
.75172 .50403 .75741 .51028 .77031 .50624 .76461 .4993 Mtetra
.662 .76 .923 r
.76461 .4993 .77031 .50624 .78327 .50234 .77761 .49519 Mtetra
.657 .753 .921 r
.77761 .49519 .78327 .50234 .7963 .49845 .79067 .49124 Mtetra
.656 .752 .92 r
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Mtetra
.656 .751 .92 r
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.40452 .59849 .41132 .60484 .42277 .60141 .41601 .59504 Mtetra
.655 .751 .921 r
.41601 .59504 .42277 .60141 .43428 .59796 .42754 .59158 Mtetra
.65 .75 .923 r
.42754 .59158 .43428 .59796 .44583 .59454 .43913 .58825 Mtetra
.627 .748 .934 r
.43913 .58825 .44583 .59454 .45743 .59127 .45075 .5855 Mtetra
.543 .737 .965 r
.45075 .5855 .45743 .59127 .46907 .58861 .46239 .58435 Mtetra
.287 .675 .973 r
.46239 .58435 .46907 .58861 .48075 .5874 .47407 .58562 Mtetra
0 .496 .755 r
.47407 .58562 .48075 .5874 .49248 .58812 .48582 .5879 Mtetra
.074 .636 .766 r
.48582 .5879 .49248 .58812 .50428 .58957 .49768 .5875 Mtetra
.664 .912 .978 r
.49768 .5875 .50428 .58957 .51617 .58907 .50963 .58247 Mtetra
.758 .776 .867 r
.50963 .58247 .51617 .58907 .52813 .58502 .52163 .5749 Mtetra
.722 .688 .817 r
.52163 .5749 .52813 .58502 .54013 .5785 .53366 .56784 Mtetra
.693 .669 .822 r
.53366 .56784 .54013 .5785 .55216 .57178 .54572 .56222 Mtetra
.68 .686 .849 r
.54572 .56222 .55216 .57178 .56423 .56612 .55783 .55749 Mtetra
.674 .705 .871 r
.55783 .55749 .56423 .56612 .57636 .56151 .56999 .55313 Mtetra
.669 .71 .879 r
.56999 .55313 .57636 .56151 .58854 .55749 .58221 .54899 Mtetra
.662 .706 .88 r
.58221 .54899 .58854 .55749 .60079 .55372 .59447 .54508 Mtetra
.655 .7 .88 r
.59447 .54508 .60079 .55372 .61308 .55006 .6068 .5414 Mtetra
.648 .698 .882 r
.6068 .5414 .61308 .55006 .62544 .54652 .61919 .53794 Mtetra
.642 .698 .887 r
.61919 .53794 .62544 .54652 .63786 .54323 .63165 .5347 Mtetra
.634 .697 .891 r
.63165 .5347 .63786 .54323 .65036 .54054 .64417 .53169 Mtetra
.623 .686 .888 r
.64417 .53169 .65036 .54054 .66297 .53889 .65677 .52907 Mtetra
.597 .652 .875 r
.65677 .52907 .66297 .53889 .6757 .53832 .66947 .52734 Mtetra
.558 .609 .86 r
.66947 .52734 .6757 .53832 .6885 .53755 .68231 .52705 Mtetra
.538 .61 .873 r
.68231 .52705 .6885 .53755 .70125 .53426 .69527 .52728 Mtetra
.602 .734 .937 r
.69527 .52728 .70125 .53426 .71386 .52734 .70817 .52492 Mtetra
.735 .935 .953 r
.70817 .52492 .71386 .52734 .72638 .51843 .72087 .51781 Mtetra
.79 .987 .893 r
.72087 .51781 .72638 .51843 .73897 .51025 .73343 .50797 Mtetra
.789 .948 .925 r
.73343 .50797 .73897 .51025 .75172 .50403 .74606 .49915 Mtetra
.728 .85 .939 r
.74606 .49915 .75172 .50403 .76461 .4993 .7589 .4928 Mtetra
.679 .782 .928 r
.7589 .4928 .76461 .4993 .77761 .49519 .7719 .4881 Mtetra
.661 .758 .922 r
.7719 .4881 .77761 .49519 .79067 .49124 .785 .48399 Mtetra
.656 .752 .921 r
.785 .48399 .79067 .49124 .8038 .48731 .79817 .48 Mtetra
.656 .751 .92 r
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Mtetra
.655 .751 .92 r
.39767 .5921 .40452 .59849 .41601 .59504 .40919 .58862 Mtetra
.653 .751 .922 r
.40919 .58862 .41601 .59504 .42754 .59158 .42076 .5852 Mtetra
.638 .748 .928 r
.42076 .5852 .42754 .59158 .43913 .58825 .43236 .58217 Mtetra
.573 .738 .954 r
.43236 .58217 .43913 .58825 .45075 .5855 .44398 .58055 Mtetra
.341 .678 .978 r
.44398 .58055 .45075 .5855 .46239 .58435 .45562 .58171 Mtetra
0 .454 .767 r
.45562 .58171 .46239 .58435 .47407 .58562 .46729 .58498 Mtetra
0 .522 .705 r
.46729 .58498 .47407 .58562 .48582 .5879 .4791 .58608 Mtetra
.634 .912 .981 r
.4791 .58608 .48582 .5879 .49768 .5875 .49105 .58143 Mtetra
.78 .793 .864 r
.49105 .58143 .49768 .5875 .50963 .58247 .50306 .57292 Mtetra
.746 .707 .815 r
.50306 .57292 .50963 .58247 .52163 .5749 .5151 .56464 Mtetra
.711 .683 .821 r
.5151 .56464 .52163 .5749 .53366 .56784 .52715 .55813 Mtetra
.689 .686 .842 r
.52715 .55813 .53366 .56784 .54572 .56222 .53924 .55295 Mtetra
.673 .691 .859 r
.53924 .55295 .54572 .56222 .55783 .55749 .55138 .54855 Mtetra
.662 .695 .87 r
.55138 .54855 .55783 .55749 .56999 .55313 .56358 .54459 Mtetra
.658 .704 .881 r
.56358 .54459 .56999 .55313 .58221 .54899 .57583 .54083 Mtetra
.656 .713 .89 r
.57583 .54083 .58221 .54899 .59447 .54508 .58813 .53712 Mtetra
.656 .72 .896 r
.58813 .53712 .59447 .54508 .6068 .5414 .60049 .5334 Mtetra
.655 .719 .896 r
.60049 .5334 .6068 .5414 .61919 .53794 .61291 .52968 Mtetra
.653 .712 .891 r
.61291 .52968 .61919 .53794 .63165 .5347 .62538 .52602 Mtetra
.647 .7 .885 r
.62538 .52602 .63165 .5347 .64417 .53169 .63792 .52256 Mtetra
.634 .685 .88 r
.63792 .52256 .64417 .53169 .65677 .52907 .65053 .51953 Mtetra
.611 .666 .879 r
.65053 .51953 .65677 .52907 .66947 .52734 .66324 .51728 Mtetra
.57 .636 .877 r
.66324 .51728 .66947 .52734 .68231 .52705 .67608 .51639 Mtetra
.514 .596 .873 r
.67608 .51639 .68231 .52705 .69527 .52728 .68909 .51729 Mtetra
.498 .603 .889 r
.68909 .51729 .69527 .52728 .70817 .52492 .7022 .51841 Mtetra
.614 .757 .947 r
.7022 .51841 .70817 .52492 .72087 .51781 .71519 .51559 Mtetra
.784 .949 .928 r
.71519 .51559 .72087 .51781 .73343 .50797 .72789 .50687 Mtetra
.83 .979 .883 r
.72789 .50687 .73343 .50797 .74606 .49915 .74047 .49592 Mtetra
.793 .92 .923 r
.74047 .49592 .74606 .49915 .7589 .4928 .7532 .48714 Mtetra
.715 .823 .932 r
.7532 .48714 .7589 .4928 .7719 .4881 .76616 .48121 Mtetra
.671 .77 .924 r
.76616 .48121 .7719 .4881 .785 .48399 .77928 .47673 Mtetra
.658 .754 .921 r
.77928 .47673 .785 .48399 .79817 .48 .79248 .47264 Mtetra
.656 .752 .92 r
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Mtetra
.656 .751 .92 r
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Mtetra
.655 .751 .921 r
.39077 .58565 .39767 .5921 .40919 .58862 .40232 .58217 Mtetra
.648 .75 .924 r
.40232 .58217 .40919 .58862 .42076 .5852 .41391 .57885 Mtetra
.612 .743 .939 r
.41391 .57885 .42076 .5852 .43236 .58217 .42553 .57644 Mtetra
.458 .706 .975 r
.42553 .57644 .43236 .58217 .44398 .58055 .43714 .57657 Mtetra
0 .491 .853 r
.43714 .57657 .44398 .58055 .45562 .58171 .44874 .5802 Mtetra
.283 0 0 r
.44874 .5802 .45562 .58171 .46729 .58498 .46045 .58396 Mtetra
.375 .825 .937 r
.46045 .58396 .46729 .58498 .4791 .58608 .47235 .58177 Mtetra
.8 .848 .886 r
.47235 .58177 .4791 .58608 .49105 .58143 .48439 .5729 Mtetra
.783 .736 .81 r
.48439 .5729 .49105 .58143 .50306 .57292 .49645 .56265 Mtetra
.734 .691 .81 r
.49645 .56265 .50306 .57292 .5151 .56464 .50852 .55477 Mtetra
.695 .686 .837 r
.50852 .55477 .5151 .56464 .52715 .55813 .5206 .54925 Mtetra
.672 .7 .867 r
.5206 .54925 .52715 .55813 .53924 .55295 .53272 .5449 Mtetra
.665 .719 .889 r
.53272 .5449 .53924 .55295 .55138 .54855 .5449 .54089 Mtetra
.664 .73 .898 r
.5449 .54089 .55138 .54855 .56358 .54459 .55713 .53692 Mtetra
.663 .73 .899 r
.55713 .53692 .56358 .54459 .57583 .54083 .56941 .53298 Mtetra
.659 .725 .897 r
.56941 .53298 .57583 .54083 .58813 .53712 .58174 .52913 Mtetra
.656 .72 .896 r
.58174 .52913 .58813 .53712 .60049 .5334 .59414 .52538 Mtetra
.652 .719 .898 r
.59414 .52538 .60049 .5334 .61291 .52968 .60659 .52175 Mtetra
.649 .721 .901 r
.60659 .52175 .61291 .52968 .62538 .52602 .6191 .5182 Mtetra
.647 .725 .905 r
.6191 .5182 .62538 .52602 .63792 .52256 .63167 .51468 Mtetra
.645 .723 .905 r
.63167 .51468 .63792 .52256 .65053 .51953 .6443 .51121 Mtetra
.635 .708 .9 r
.6443 .51121 .65053 .51953 .66324 .51728 .65701 .50808 Mtetra
.6 .671 .89 r
.65701 .50808 .66324 .51728 .67608 .51639 .66983 .50612 Mtetra
.525 .611 .881 r
.66983 .50612 .67608 .51639 .68909 .51729 .68283 .50656 Mtetra
.439 .556 .877 r
.68283 .50656 .68909 .51729 .7022 .51841 .69606 .50941 Mtetra
.468 .615 .913 r
.69606 .50941 .7022 .51841 .71519 .51559 .70932 .51082 Mtetra
.695 .848 .956 r
.70932 .51082 .71519 .51559 .72789 .50687 .72227 .5054 Mtetra
.847 .969 .877 r
.72227 .5054 .72789 .50687 .74047 .49592 .73489 .49386 Mtetra
.848 .955 .881 r
.73489 .49386 .74047 .49592 .7532 .48714 .74752 .48247 Mtetra
.767 .87 .924 r
.74752 .48247 .7532 .48714 .76616 .48121 .7604 .47467 Mtetra
.691 .79 .926 r
.7604 .47467 .76616 .48121 .77928 .47673 .77351 .46949 Mtetra
.662 .759 .922 r
.77351 .46949 .77928 .47673 .79248 .47264 .78676 .46523 Mtetra
.657 .752 .92 r
.78676 .46523 .79248 .47264 .80576 .46862 .80007 .46116 Mtetra
.656 .751 .92 r
.80007 .46116 .80576 .46862 .81909 .46458 .81345 .45709 Mtetra
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Mtetra
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57916 Mtetra
.654 .751 .921 r
.38381 .57916 .39077 .58565 .40232 .58217 .39539 .57568 Mtetra
.639 .748 .927 r
.39539 .57568 .40232 .58217 .41391 .57885 .40701 .57257 Mtetra
.566 .731 .953 r
.40701 .57257 .41391 .57885 .42553 .57644 .41862 .57107 Mtetra
.252 .617 .957 r
.41862 .57107 .42553 .57644 .43714 .57657 .4302 .57336 Mtetra
.34 0 0 r
.4302 .57336 .43714 .57657 .44874 .5802 .44178 .57915 Mtetra
.227 0 0 r
.44178 .57915 .44874 .5802 .46045 .58396 .45354 .58199 Mtetra
.725 .925 .959 r
.45354 .58199 .46045 .58396 .47235 .58177 .46556 .5756 Mtetra
.83 .792 .816 r
.46556 .5756 .47235 .58177 .48439 .5729 .47769 .56332 Mtetra
.779 .716 .794 r
.47769 .56332 .48439 .5729 .49645 .56265 .4898 .55255 Mtetra
.721 .691 .821 r
.4898 .55255 .49645 .56265 .50852 .55477 .50189 .54552 Mtetra
.684 .696 .855 r
.50189 .54552 .50852 .55477 .5206 .54925 .514 .54062 Mtetra
.669 .706 .875 r
.514 .54062 .5206 .54925 .53272 .5449 .52616 .53641 Mtetra
.661 .708 .882 r
.52616 .53641 .53272 .5449 .5449 .54089 .53836 .53248 Mtetra
.656 .709 .886 r
.53836 .53248 .5449 .54089 .55713 .53692 .55062 .52872 Mtetra
.654 .714 .892 r
.55062 .52872 .55713 .53692 .56941 .53298 .56294 .52503 Mtetra
.654 .722 .898 r
.56294 .52503 .56941 .53298 .58174 .52913 .57531 .52132 Mtetra
.656 .727 .902 r
.57531 .52132 .58174 .52913 .59414 .52538 .58773 .51754 Mtetra
.657 .728 .901 r
.58773 .51754 .59414 .52538 .60659 .52175 .60022 .51371 Mtetra
.657 .723 .897 r
.60022 .51371 .60659 .52175 .6191 .5182 .61275 .50985 Mtetra
.654 .715 .892 r
.61275 .50985 .6191 .5182 .63167 .51468 .62535 .50606 Mtetra
.649 .707 .889 r
.62535 .50606 .63167 .51468 .6443 .51121 .63801 .50244 Mtetra
.64 .7 .889 r
.63801 .50244 .6443 .51121 .65701 .50808 .65074 .4991 Mtetra
.619 .687 .892 r
.65074 .4991 .65701 .50808 .66983 .50612 .66356 .49647 Mtetra
.55 .64 .892 r
.66356 .49647 .66983 .50612 .68283 .50656 .67655 .49599 Mtetra
.413 .547 .881 r
.67655 .49599 .68283 .50656 .69606 .50941 .68982 .49931 Mtetra
.33 .511 .884 r
.68982 .49931 .69606 .50941 .70932 .51082 .70328 .50415 Mtetra
.541 .726 .959 r
.70328 .50415 .70932 .51082 .72227 .5054 .71653 .50295 Mtetra
.833 .945 .895 r
.71653 .50295 .72227 .5054 .73489 .49386 .72927 .49229 Mtetra
.887 .959 .841 r
.72927 .49229 .73489 .49386 .74752 .48247 .74183 .47859 Mtetra
.821 .903 .897 r
.74183 .47859 .74752 .48247 .7604 .47467 .75462 .4685 Mtetra
.72 .812 .923 r
.75462 .4685 .7604 .47467 .77351 .46949 .76771 .46231 Mtetra
.67 .765 .922 r
.76771 .46231 .77351 .46949 .78676 .46523 .78098 .45778 Mtetra
.658 .753 .921 r
.78098 .45778 .78676 .46523 .80007 .46116 .79434 .45363 Mtetra
.656 .752 .92 r
.79434 .45363 .80007 .46116 .81345 .45709 .80776 .44952 Mtetra
.656 .751 .92 r
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Mtetra
.655 .751 .92 r
.36524 .57616 .37228 .58268 .38381 .57916 .3768 .57261 Mtetra
.652 .751 .922 r
.3768 .57261 .38381 .57916 .39539 .57568 .38841 .56915 Mtetra
.628 .745 .932 r
.38841 .56915 .39539 .57568 .40701 .57257 .40004 .56632 Mtetra
.5 .709 .964 r
.40004 .56632 .40701 .57257 .41862 .57107 .41165 .56596 Mtetra
0 .445 .85 r
.41165 .56596 .41862 .57107 .4302 .57336 .42318 .57059 Mtetra
.523 0 0 r
.42318 .57059 .4302 .57336 .44178 .57915 .43474 .57821 Mtetra
0 .547 .742 r
.43474 .57821 .44178 .57915 .45354 .58199 .44658 .57929 Mtetra
.843 .893 .874 r
.44658 .57929 .45354 .58199 .46556 .5756 .45874 .56847 Mtetra
.845 .77 .778 r
.45874 .56847 .46556 .5756 .47769 .56332 .47097 .55337 Mtetra
.777 .711 .79 r
.47097 .55337 .47769 .56332 .4898 .55255 .48311 .54248 Mtetra
.706 .688 .83 r
.48311 .54248 .4898 .55255 .50189 .54552 .49522 .5363 Mtetra
.665 .692 .865 r
.49522 .5363 .50189 .54552 .514 .54062 .50736 .53219 Mtetra
.652 .707 .887 r
.50736 .53219 .514 .54062 .52616 .53641 .51954 .52856 Mtetra
.653 .723 .9 r
.51954 .52856 .52616 .53641 .53836 .53248 .53178 .5249 Mtetra
.657 .733 .906 r
.53178 .5249 .53836 .53248 .55062 .52872 .54407 .52111 Mtetra
.658 .733 .905 r
.54407 .52111 .55062 .52872 .56294 .52503 .55642 .51725 Mtetra
.657 .729 .902 r
.55642 .51725 .56294 .52503 .57531 .52132 .56882 .51341 Mtetra
.656 .726 .901 r
.56882 .51341 .57531 .52132 .58773 .51754 .58128 .5096 Mtetra
.654 .725 .901 r
.58128 .5096 .58773 .51754 .60022 .51371 .5938 .50585 Mtetra
.653 .728 .904 r
.5938 .50585 .60022 .51371 .61275 .50985 .60638 .50209 Mtetra
.654 .732 .907 r
.60638 .50209 .61275 .50985 .62535 .50606 .61901 .49827 Mtetra
.658 .734 .906 r
.61901 .49827 .62535 .50606 .63801 .50244 .63169 .49433 Mtetra
.658 .726 .899 r
.63169 .49433 .63801 .50244 .65074 .4991 .64444 .49034 Mtetra
.643 .704 .891 r
.64444 .49034 .65074 .4991 .66356 .49647 .65726 .48685 Mtetra
.58 .656 .889 r
.65726 .48685 .66356 .49647 .67655 .49599 .67023 .48545 Mtetra
.406 .545 .883 r
.67023 .48545 .67655 .49599 .68982 .49931 .68352 .48884 Mtetra
.19 .417 .851 r
.68352 .48884 .68982 .49931 .70328 .50415 .69714 .4965 Mtetra
.325 .582 .936 r
.69714 .4965 .70328 .50415 .71653 .50295 .71068 .49976 Mtetra
.793 .923 .924 r
.71068 .49976 .71653 .50295 .72927 .49229 .7236 .49081 Mtetra
.911 .951 .81 r
.7236 .49081 .72927 .49229 .74183 .47859 .73611 .47516 Mtetra
.867 .915 .86 r
.73611 .47516 .74183 .47859 .75462 .4685 .74881 .46259 Mtetra
.752 .83 .912 r
.74881 .46259 .75462 .4685 .76771 .46231 .76186 .45516 Mtetra
.679 .771 .92 r
.76186 .45516 .76771 .46231 .78098 .45778 .77515 .45028 Mtetra
.659 .754 .92 r
.77515 .45028 .78098 .45778 .79434 .45363 .78855 .44604 Mtetra
.656 .752 .92 r
.78855 .44604 .79434 .45363 .80776 .44952 .80202 .44189 Mtetra
.656 .751 .92 r
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Mtetra
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Mtetra
.655 .751 .92 r
.35814 .56959 .36524 .57616 .3768 .57261 .36973 .56602 Mtetra
.65 .75 .923 r
.36973 .56602 .3768 .57261 .38841 .56915 .38137 .56258 Mtetra
.614 .741 .936 r
.38137 .56258 .38841 .56915 .40004 .56632 .39302 .56005 Mtetra
.418 .673 .967 r
.39302 .56005 .40004 .56632 .41165 .56596 .40461 .56088 Mtetra
0 .233 .672 r
.40461 .56088 .41165 .56596 .42318 .57059 .41608 .56792 Mtetra
.627 .064 0 r
.41608 .56792 .42318 .57059 .43474 .57821 .42761 .57729 Mtetra
.205 .724 .87 r
.42761 .57729 .43474 .57821 .44658 .57929 .43954 .57644 Mtetra
.891 .866 .808 r
.43954 .57644 .44658 .57929 .45874 .56847 .45186 .56114 Mtetra
.862 .765 .754 r
.45186 .56114 .45874 .56847 .47097 .55337 .46419 .5433 Mtetra
.776 .709 .79 r
.46419 .5433 .47097 .55337 .48311 .54248 .47638 .53244 Mtetra
.687 .683 .84 r
.47638 .53244 .48311 .54248 .49522 .5363 .48851 .52719 Mtetra
.65 .69 .874 r
.48851 .52719 .49522 .5363 .50736 .53219 .50066 .5236 Mtetra
.649 .703 .886 r
.50066 .5236 .50736 .53219 .51954 .52856 .51287 .52005 Mtetra
.651 .707 .888 r
.51287 .52005 .51954 .52856 .53178 .5249 .52514 .51645 Mtetra
.65 .708 .89 r
.52514 .51645 .53178 .5249 .54407 .52111 .53747 .51285 Mtetra
.65 .714 .895 r
.53747 .51285 .54407 .52111 .55642 .51725 .54985 .50923 Mtetra
.652 .722 .9 r
.54985 .50923 .55642 .51725 .56882 .51341 .56229 .50551 Mtetra
.656 .728 .903 r
.56229 .50551 .56882 .51341 .58128 .5096 .57478 .50168 Mtetra
.659 .729 .901 r
.57478 .50168 .58128 .5096 .5938 .50585 .58733 .49772 Mtetra
.661 .725 .897 r
.58733 .49772 .5938 .50585 .60638 .50209 .59993 .49367 Mtetra
.661 .718 .891 r
.59993 .49367 .60638 .50209 .61901 .49827 .61259 .4896 Mtetra
.66 .713 .887 r
.61259 .4896 .61901 .49827 .63169 .49433 .62531 .48553 Mtetra
.661 .711 .885 r
.62531 .48553 .63169 .49433 .64444 .49034 .63808 .4814 Mtetra
.659 .707 .883 r
.63808 .4814 .64444 .49034 .65726 .48685 .65091 .47732 Mtetra
.61 .674 .886 r
.65091 .47732 .65726 .48685 .67023 .48545 .66388 .47493 Mtetra
.407 .547 .884 r
.66388 .47493 .67023 .48545 .68352 .48884 .67717 .47823 Mtetra
.035 .312 .8 r
.67717 .47823 .68352 .48884 .69714 .4965 .69094 .48863 Mtetra
.032 .388 .849 r
.69094 .48863 .69714 .4965 .71068 .49976 .70475 .4964 Mtetra
.733 .912 .955 r
.70475 .4964 .71068 .49976 .7236 .49081 .71786 .48936 Mtetra
.93 .941 .783 r
.71786 .48936 .7236 .49081 .73611 .47516 .73034 .47182 Mtetra
.9 .909 .821 r
.73034 .47182 .73611 .47516 .74881 .46259 .74294 .4567 Mtetra
.781 .839 .896 r
.74294 .4567 .74881 .46259 .76186 .45516 .75597 .44798 Mtetra
.689 .776 .917 r
.75597 .44798 .76186 .45516 .77515 .45028 .76928 .44272 Mtetra
.661 .755 .92 r
.76928 .44272 .77515 .45028 .78855 .44604 .78271 .43839 Mtetra
.656 .752 .92 r
.78271 .43839 .78855 .44604 .80202 .44189 .79623 .4342 Mtetra
.656 .751 .92 r
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Mtetra
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Mtetra
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56655 Mtetra
.33941 .56655 .3466 .57315 .35814 .56959 .35098 .56296 Mtetra
.655 .751 .921 r
.35098 .56296 .35814 .56959 .36973 .56602 .3626 .55937 Mtetra
.648 .75 .923 r
.3626 .55937 .36973 .56602 .38137 .56258 .37427 .55595 Mtetra
.602 .737 .94 r
.37427 .55595 .38137 .56258 .39302 .56005 .38594 .55369 Mtetra
.332 .629 .96 r
.38594 .55369 .39302 .56005 .40461 .56088 .39751 .5556 Mtetra
.491 0 0 r
.39751 .5556 .40461 .56088 .41608 .56792 .40892 .56497 Mtetra
.699 .159 0 r
.40892 .56497 .41608 .56792 .42761 .57729 .4204 .57635 Mtetra
.373 .825 .933 r
.4204 .57635 .42761 .57729 .43954 .57644 .43242 .57404 Mtetra
.92 .855 .761 r
.43242 .57404 .43954 .57644 .45186 .56114 .44492 .55435 Mtetra
.883 .772 .734 r
.44492 .55435 .45186 .56114 .46419 .5433 .45738 .53338 Mtetra
.782 .714 .789 r
.45738 .53338 .46419 .5433 .47638 .53244 .46961 .52211 Mtetra
.668 .671 .844 r
.46961 .52211 .47638 .53244 .48851 .52719 .48175 .51765 Mtetra
.624 .672 .875 r
.48175 .51765 .48851 .52719 .50066 .5236 .49392 .51492 Mtetra
.628 .695 .893 r
.49392 .51492 .50066 .5236 .51287 .52005 .50616 .51203 Mtetra
.64 .717 .904 r
.50616 .51203 .51287 .52005 .52514 .51645 .51846 .50872 Mtetra
.649 .73 .908 r
.51846 .50872 .52514 .51645 .53747 .51285 .53082 .5051 Mtetra
.654 .732 .906 r
.53082 .5051 .53747 .51285 .54985 .50923 .54323 .50131 Mtetra
.656 .728 .903 r
.54323 .50131 .54985 .50923 .56229 .50551 .5557 .49745 Mtetra
.655 .725 .9 r
.5557 .49745 .56229 .50551 .57478 .50168 .56823 .49359 Mtetra
.56823 .49359 .57478 .50168 .58733 .49772 .58081 .48971 Mtetra
.657 .729 .903 r
.58081 .48971 .58733 .49772 .59993 .49367 .59346 .48577 Mtetra
.661 .734 .904 r
.59346 .48577 .59993 .49367 .61259 .4896 .60615 .48166 Mtetra
.67 .737 .9 r
.60615 .48166 .61259 .4896 .62531 .48553 .6189 .47723 Mtetra
.68 .732 .889 r
.6189 .47723 .62531 .48553 .63808 .4814 .63168 .47238 Mtetra
.682 .716 .874 r
.63168 .47238 .63808 .4814 .65091 .47732 .64451 .46737 Mtetra
.634 .676 .872 r
.64451 .46737 .65091 .47732 .66388 .47493 .65747 .46411 Mtetra
.394 .535 .879 r
.65747 .46411 .66388 .47493 .67717 .47823 .6708 .46777 Mtetra
0 .174 .71 r
.6708 .46777 .67717 .47823 .69094 .48863 .68473 .48131 Mtetra
0 .142 .658 r
.68473 .48131 .69094 .48863 .70475 .4964 .69879 .49351 Mtetra
.664 .912 .978 r
.69879 .49351 .70475 .4964 .71786 .48936 .71204 .48787 Mtetra
.945 .927 .756 r
.71204 .48787 .71786 .48936 .73034 .47182 .72449 .46819 Mtetra
.919 .892 .787 r
.72449 .46819 .73034 .47182 .74294 .4567 .73701 .45059 Mtetra
.803 .837 .877 r
.73701 .45059 .74294 .4567 .75597 .44798 .75002 .44068 Mtetra
.698 .777 .913 r
.75002 .44068 .75597 .44798 .76928 .44272 .76335 .43508 Mtetra
.662 .756 .919 r
.76335 .43508 .76928 .44272 .78271 .43839 .77683 .43067 Mtetra
.656 .752 .92 r
.77683 .43067 .78271 .43839 .79623 .4342 .79039 .42644 Mtetra
.656 .751 .92 r
.79039 .42644 .79623 .4342 .8098 .43 .80401 .4222 Mtetra
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Mtetra
.32061 .56351 .32789 .57014 .33941 .56655 .33216 .5599 Mtetra
.33216 .5599 .33941 .56655 .35098 .56296 .34377 .55628 Mtetra
.655 .751 .921 r
.34377 .55628 .35098 .56296 .3626 .55937 .35542 .55266 Mtetra
.647 .749 .924 r
.35542 .55266 .3626 .55937 .37427 .55595 .36711 .54925 Mtetra
.592 .733 .942 r
.36711 .54925 .37427 .55595 .38594 .55369 .3788 .54718 Mtetra
.259 .586 .946 r
.3788 .54718 .38594 .55369 .39751 .5556 .39036 .54997 Mtetra
.603 .071 0 r
.39036 .54997 .39751 .5556 .40892 .56497 .4017 .5614 Mtetra
.754 .237 0 r
.4017 .5614 .40892 .56497 .4204 .57635 .41312 .57509 Mtetra
.431 .85 .958 r
.41312 .57509 .4204 .57635 .43242 .57404 .4252 .57244 Mtetra
.939 .852 .729 r
.4252 .57244 .43242 .57404 .44492 .55435 .43788 .54898 Mtetra
.91 .788 .713 r
.43788 .54898 .44492 .55435 .45738 .53338 .4505 .52418 Mtetra
.802 .732 .786 r
.4505 .52418 .45738 .53338 .46961 .52211 .46279 .51168 Mtetra
.654 .665 .848 r
.46279 .51168 .46961 .52211 .48175 .51765 .47495 .50776 Mtetra
.604 .657 .875 r
.47495 .50776 .48175 .51765 .49392 .51492 .48714 .50566 Mtetra
.621 .679 .884 r
.48714 .50566 .49392 .51492 .50616 .51203 .4994 .50298 Mtetra
.635 .691 .885 r
.4994 .50298 .50616 .51203 .51846 .50872 .51172 .49982 Mtetra
.641 .697 .886 r
.51172 .49982 .51846 .50872 .53082 .5051 .52411 .49645 Mtetra
.645 .706 .891 r
.52411 .49645 .53082 .5051 .54323 .50131 .53656 .49294 Mtetra
.65 .716 .896 r
.53656 .49294 .54323 .50131 .5557 .49745 .54906 .48926 Mtetra
.655 .723 .899 r
.54906 .48926 .5557 .49745 .56823 .49359 .56162 .48536 Mtetra
.661 .725 .897 r
.56162 .48536 .56823 .49359 .58081 .48971 .57424 .48124 Mtetra
.665 .721 .891 r
.57424 .48124 .58081 .48971 .59346 .48577 .58691 .47695 Mtetra
.668 .714 .883 r
.58691 .47695 .59346 .48577 .60615 .48166 .59963 .47253 Mtetra
.672 .709 .876 r
.59963 .47253 .60615 .48166 .6189 .47723 .6124 .46789 Mtetra
.683 .709 .868 r
.6124 .46789 .6189 .47723 .63168 .47238 .62522 .46276 Mtetra
.695 .708 .858 r
.62522 .46276 .63168 .47238 .64451 .46737 .63806 .45705 Mtetra
.648 .675 .862 r
.63806 .45705 .64451 .46737 .65747 .46411 .65102 .45318 Mtetra
.337 .501 .873 r
.65102 .45318 .65747 .46411 .6708 .46777 .66441 .45805 Mtetra
0 0 .545 r
.66441 .45805 .6708 .46777 .68473 .48131 .67852 .47542 Mtetra
.592 .087 0 r
.67852 .47542 .68473 .48131 .69879 .49351 .6928 .49141 Mtetra
.62 .923 .974 r
.6928 .49141 .69879 .49351 .71204 .48787 .70614 .48604 Mtetra
.956 .907 .73 r
.70614 .48604 .71204 .48787 .72449 .46819 .71854 .46391 Mtetra
.928 .87 .76 r
.71854 .46391 .72449 .46819 .73701 .45059 .73101 .44411 Mtetra
.816 .829 .86 r
.73101 .44411 .73701 .45059 .75002 .44068 .744 .43323 Mtetra
.704 .777 .908 r
.744 .43323 .75002 .44068 .76335 .43508 .75737 .42736 Mtetra
.663 .756 .919 r
.75737 .42736 .76335 .43508 .77683 .43067 .77089 .42288 Mtetra
.656 .752 .92 r
.77089 .42288 .77683 .43067 .79039 .42644 .78449 .41861 Mtetra
.656 .751 .92 r
.78449 .41861 .79039 .42644 .80401 .4222 .79816 .41434 Mtetra
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .5599 .32486 .5532 Mtetra
.32486 .5532 .33216 .5599 .34377 .55628 .33649 .54955 Mtetra
.655 .751 .921 r
.33649 .54955 .34377 .55628 .35542 .55266 .34818 .5459 Mtetra
.646 .749 .924 r
.34818 .5459 .35542 .55266 .36711 .54925 .3599 .54249 Mtetra
.585 .73 .943 r
.3599 .54249 .36711 .54925 .3788 .54718 .37161 .54055 Mtetra
.206 .553 .932 r
.37161 .54055 .3788 .54718 .39036 .54997 .38316 .54393 Mtetra
.662 .144 0 r
.38316 .54393 .39036 .54997 .4017 .5614 .39444 .55693 Mtetra
.79 .294 0 r
.39444 .55693 .4017 .5614 .41312 .57509 .40579 .57288 Mtetra
.395 .81 .976 r
.40579 .57288 .41312 .57509 .4252 .57244 .41788 .57128 Mtetra
.947 .85 .714 r
.41788 .57128 .4252 .57244 .43788 .54898 .43071 .54575 Mtetra
.937 .808 .692 r
.43071 .54575 .43788 .54898 .4505 .52418 .44352 .51698 Mtetra
.848 .774 .779 r
.44352 .51698 .4505 .52418 .46279 .51168 .45593 .50161 Mtetra
.669 .68 .851 r
.45593 .50161 .46279 .51168 .47495 .50776 .46812 .49709 Mtetra
.58 .631 .866 r
.46812 .49709 .47495 .50776 .48714 .50566 .48031 .49578 Mtetra
.588 .653 .881 r
.48031 .49578 .48714 .50566 .4994 .50298 .49258 .49413 Mtetra
.616 .69 .896 r
.49258 .49413 .4994 .50298 .51172 .49982 .50494 .49155 Mtetra
.637 .714 .903 r
.50494 .49155 .51172 .49982 .52411 .49645 .51735 .48827 Mtetra
.649 .721 .901 r
.51735 .48827 .52411 .49645 .53656 .49294 .52983 .4846 Mtetra
.653 .719 .897 r
.52983 .4846 .53656 .49294 .54906 .48926 .54237 .48075 Mtetra
.655 .717 .894 r
.54237 .48075 .54906 .48926 .56162 .48536 .55497 .47682 Mtetra
.657 .717 .893 r
.55497 .47682 .56162 .48536 .57424 .48124 .56762 .47281 Mtetra
.662 .723 .894 r
.56762 .47281 .57424 .48124 .58691 .47695 .58032 .46862 Mtetra
.672 .73 .893 r
.58032 .46862 .58691 .47695 .59963 .47253 .59308 .46404 Mtetra
.69 .733 .883 r
.59308 .46404 .59963 .47253 .6124 .46789 .60587 .45876 Mtetra
.709 .725 .862 r
.60587 .45876 .6124 .46789 .62522 .46276 .61869 .45252 Mtetra
.709 .702 .841 r
.61869 .45252 .62522 .46276 .63806 .45705 .63154 .44594 Mtetra
.632 .654 .853 r
.63154 .44594 .63806 .45705 .65102 .45318 .64454 .44264 Mtetra
.166 .406 .848 r
.64454 .44264 .65102 .45318 .66441 .45805 .65807 .45035 Mtetra
.679 .215 0 r
.65807 .45035 .66441 .45805 .67852 .47542 .67236 .47171 Mtetra
.731 .218 0 r
.67236 .47171 .67852 .47542 .6928 .49141 .68676 .48974 Mtetra
.662 .947 .958 r
.68676 .48974 .6928 .49141 .70614 .48604 .70011 .48322 Mtetra
.959 .877 .711 r
.70011 .48322 .70614 .48604 .71854 .46391 .71247 .45868 Mtetra
.928 .846 .742 r
.71247 .45868 .71854 .46391 .73101 .44411 .72492 .43721 Mtetra
.822 .82 .847 r
.72492 .43721 .73101 .44411 .744 .43323 .73793 .42564 Mtetra
.708 .776 .905 r
.73793 .42564 .744 .43323 .75737 .42736 .75134 .41957 Mtetra
.664 .756 .918 r
.75134 .41957 .75737 .42736 .77089 .42288 .7649 .41502 Mtetra
.657 .752 .92 r
.7649 .41502 .77089 .42288 .78449 .41861 .77855 .41071 Mtetra
.656 .751 .92 r
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Mtetra
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40208 Mtetra
.80604 .40208 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Mtetra
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Mtetra
.655 .751 .921 r
.32916 .54276 .33649 .54955 .34818 .5459 .34088 .53909 Mtetra
.645 .749 .924 r
.34088 .53909 .34818 .5459 .3599 .54249 .35263 .53566 Mtetra
.58 .728 .945 r
.35263 .53566 .3599 .54249 .37161 .54055 .36436 .53382 Mtetra
.167 .528 .921 r
.36436 .53382 .37161 .54055 .38316 .54393 .37591 .53761 Mtetra
.692 .182 0 r
.37591 .53761 .38316 .54393 .39444 .55693 .38714 .55158 Mtetra
.807 .323 0 r
.38714 .55158 .39444 .55693 .40579 .57288 .39843 .56911 Mtetra
.33 .729 .982 r
.39843 .56911 .40579 .57288 .41788 .57128 .4105 .56924 Mtetra
.939 .839 .718 r
.4105 .56924 .41788 .57128 .43071 .54575 .42342 .54416 Mtetra
.952 .824 .68 r
.42342 .54416 .43071 .54575 .44352 .51698 .43639 .51319 Mtetra
.907 .835 .764 r
.43639 .51319 .44352 .51698 .45593 .50161 .44895 .49412 Mtetra
.741 .761 .869 r
.44895 .49412 .45593 .50161 .46812 .49709 .46123 .48699 Mtetra
.605 .656 .873 r
.46123 .48699 .46812 .49709 .48031 .49578 .47346 .4848 Mtetra
.589 .631 .86 r
.47346 .4848 .48031 .49578 .49258 .49413 .48575 .48316 Mtetra
.605 .639 .858 r
.48575 .48316 .49258 .49413 .50494 .49155 .49811 .48097 Mtetra
.619 .654 .862 r
.49811 .48097 .50494 .49155 .51735 .48827 .51055 .47827 Mtetra
.631 .672 .871 r
.51055 .47827 .51735 .48827 .52983 .4846 .52306 .47515 Mtetra
.643 .69 .879 r
.52306 .47515 .52983 .4846 .54237 .48075 .53563 .47161 Mtetra
.654 .702 .882 r
.53563 .47161 .54237 .48075 .55497 .47682 .54825 .46765 Mtetra
.665 .706 .878 r
.54825 .46765 .55497 .47682 .56762 .47281 .56093 .46325 Mtetra
.674 .702 .867 r
.56093 .46325 .56762 .47281 .58032 .46862 .57366 .45845 Mtetra
.681 .692 .853 r
.57366 .45845 .58032 .46862 .59308 .46404 .58643 .45322 Mtetra
.689 .683 .839 r
.58643 .45322 .59308 .46404 .60587 .45876 .59924 .44746 Mtetra
.697 .678 .828 r
.59924 .44746 .60587 .45876 .61869 .45252 .61209 .44116 Mtetra
.686 .673 .832 r
.61209 .44116 .61869 .45252 .63154 .44594 .62499 .43542 Mtetra
.554 .631 .882 r
.62499 .43542 .63154 .44594 .64454 .44264 .63812 .43469 Mtetra
0 .18 .697 r
.63812 .43469 .64454 .44264 .65807 .45035 .65181 .44611 Mtetra
.81 .334 0 r
.65181 .44611 .65807 .45035 .67236 .47171 .6662 .46965 Mtetra
.754 .238 0 r
.6662 .46965 .67236 .47171 .68676 .48974 .68061 .48714 Mtetra
.76 .944 .941 r
.68061 .48714 .68676 .48974 .70011 .48322 .69393 .47877 Mtetra
.951 .844 .701 r
.69393 .47877 .70011 .48322 .71247 .45868 .7063 .45254 Mtetra
.924 .826 .731 r
.7063 .45254 .71247 .45868 .72492 .43721 .71876 .42999 Mtetra
.826 .814 .838 r
.71876 .42999 .72492 .43721 .73793 .42564 .73181 .41794 Mtetra
.711 .776 .903 r
.73181 .41794 .73793 .42564 .75134 .41957 .74525 .4117 Mtetra
.665 .756 .918 r
.74525 .4117 .75134 .41957 .7649 .41502 .75886 .4071 Mtetra
.657 .752 .92 r
.75886 .4071 .7649 .41502 .77855 .41071 .77255 .40274 Mtetra
.656 .751 .92 r
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Mtetra
.78631 .3984 .79226 .4064 .80604 .40208 .80014 .39403 Mtetra
.80014 .39403 .80604 .40208 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Mtetra
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Mtetra
.655 .751 .921 r
.32177 .53592 .32916 .54276 .34088 .53909 .33351 .53222 Mtetra
.645 .748 .925 r
.33351 .53222 .34088 .53909 .35263 .53566 .3453 .52879 Mtetra
.574 .726 .946 r
.3453 .52879 .35263 .53566 .36436 .53382 .35705 .52703 Mtetra
.133 .507 .91 r
.35705 .52703 .36436 .53382 .37591 .53761 .3686 .53116 Mtetra
.709 .205 0 r
.3686 .53116 .37591 .53761 .38714 .55158 .3798 .54569 Mtetra
.809 .33 0 r
.3798 .54569 .38714 .55158 .39843 .56911 .39105 .56379 Mtetra
.329 .676 .977 r
.39105 .56379 .39843 .56911 .4105 .56924 .40312 .56491 Mtetra
.914 .81 .731 r
.40312 .56491 .4105 .56924 .42342 .54416 .41607 .54179 Mtetra
.945 .819 .688 r
.41607 .54179 .42342 .54416 .43639 .51319 .42912 .51206 Mtetra
.937 .88 .752 r
.42912 .51206 .43639 .51319 .44895 .49412 .44181 .4912 Mtetra
.842 .897 .877 r
.44181 .4912 .44895 .49412 .46123 .48699 .45422 .48025 Mtetra
.692 .774 .914 r
.45422 .48025 .46123 .48699 .47346 .4848 .46654 .47521 Mtetra
.614 .673 .883 r
.46654 .47521 .47346 .4848 .48575 .48316 .47886 .47267 Mtetra
.605 .65 .868 r
.47886 .47267 .48575 .48316 .49811 .48097 .49125 .47043 Mtetra
.623 .657 .863 r
.49125 .47043 .49811 .48097 .51055 .47827 .50371 .46756 Mtetra
.64 .662 .856 r
.50371 .46756 .51055 .47827 .52306 .47515 .51624 .46404 Mtetra
.647 .658 .847 r
.51624 .46404 .52306 .47515 .53563 .47161 .52883 .46018 Mtetra
.649 .653 .841 r
.52883 .46018 .53563 .47161 .54825 .46765 .54148 .45619 Mtetra
.651 .655 .84 r
.54148 .45619 .54825 .46765 .56093 .46325 .55418 .45206 Mtetra
.66 .664 .843 r
.55418 .45206 .56093 .46325 .57366 .45845 .56694 .44758 Mtetra
.676 .677 .844 r
.56694 .44758 .57366 .45845 .58643 .45322 .57974 .44244 Mtetra
.689 .685 .841 r
.57974 .44244 .58643 .45322 .59924 .44746 .59259 .43669 Mtetra
.683 .683 .844 r
.59259 .43669 .59924 .44746 .61209 .44116 .60548 .43122 Mtetra
.621 .676 .881 r
.60548 .43122 .61209 .44116 .62499 .43542 .6185 .4283 Mtetra
.285 .586 .944 r
.6185 .4283 .62499 .43542 .63812 .43469 .63179 .43139 Mtetra
.636 .088 0 r
.63179 .43139 .63812 .43469 .65181 .44611 .64558 .44455 Mtetra
.822 .342 .017 r
.64558 .44455 .65181 .44611 .6662 .46965 .65994 .46676 Mtetra
.695 .161 0 r
.65994 .46676 .6662 .46965 .68061 .48714 .67427 .48218 Mtetra
.797 .875 .905 r
.67427 .48218 .68061 .48714 .69393 .47877 .68761 .47272 Mtetra
.94 .818 .697 r
.68761 .47272 .69393 .47877 .7063 .45254 .70003 .44583 Mtetra
.921 .816 .725 r
.70003 .44583 .7063 .45254 .71876 .42999 .71254 .42264 Mtetra
.83 .812 .833 r
.71254 .42264 .71876 .42999 .73181 .41794 .72563 .41017 Mtetra
.714 .777 .901 r
.72563 .41017 .73181 .41794 .74525 .4117 .73911 .40377 Mtetra
.666 .756 .918 r
.73911 .40377 .74525 .4117 .75886 .4071 .75276 .3991 Mtetra
.657 .752 .92 r
.75276 .3991 .75886 .4071 .77255 .40274 .7665 .39471 Mtetra
.656 .751 .92 r
.7665 .39471 .77255 .40274 .78631 .3984 .78031 .39032 Mtetra
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38592 Mtetra
.79418 .38592 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Mtetra
.655 .751 .921 r
.31431 .52902 .32177 .53592 .33351 .53222 .32609 .52529 Mtetra
.644 .748 .925 r
.32609 .52529 .33351 .53222 .3453 .52879 .33791 .52186 Mtetra
.568 .724 .947 r
.33791 .52186 .3453 .52879 .35705 .52703 .34968 .52021 Mtetra
.096 .484 .897 r
.34968 .52021 .35705 .52703 .3686 .53116 .36122 .52467 Mtetra
.724 .222 0 r
.36122 .52467 .3686 .53116 .3798 .54569 .3724 .53962 Mtetra
.805 .325 0 r
.3724 .53962 .3798 .54569 .39105 .56379 .38364 .55765 Mtetra
.393 .682 .976 r
.38364 .55765 .39105 .56379 .40312 .56491 .39575 .55842 Mtetra
.891 .779 .732 r
.39575 .55842 .40312 .56491 .41607 .54179 .40874 .53627 Mtetra
.915 .785 .703 r
.40874 .53627 .41607 .54179 .42912 .51206 .4218 .50929 Mtetra
.914 .861 .775 r
.4218 .50929 .42912 .51206 .44181 .4912 .43452 .49072 Mtetra
.86 .96 .869 r
.43452 .49072 .44181 .4912 .45422 .48025 .44703 .47874 Mtetra
.818 .947 .907 r
.44703 .47874 .45422 .48025 .46654 .47521 .4595 .46896 Mtetra
.778 .806 .875 r
.4595 .46896 .46654 .47521 .47886 .47267 .47196 .46033 Mtetra
.706 .66 .802 r
.47196 .46033 .47886 .47267 .49125 .47043 .48442 .45322 Mtetra
.657 .58 .757 r
.48442 .45322 .49125 .47043 .50371 .46756 .4969 .44759 Mtetra
.633 .544 .736 r
.4969 .44759 .50371 .46756 .51624 .46404 .50942 .44292 Mtetra
.623 .531 .729 r
.50942 .44292 .51624 .46404 .52883 .46018 .522 .43871 Mtetra
.62 .527 .727 r
.522 .43871 .52883 .46018 .54148 .45619 .53463 .43466 Mtetra
.617 .525 .727 r
.53463 .43466 .54148 .45619 .55418 .45206 .54732 .43078 Mtetra
.611 .523 .731 r
.54732 .43078 .55418 .45206 .56694 .44758 .56008 .42737 Mtetra
.597 .523 .742 r
.56008 .42737 .56694 .44758 .57974 .44244 .57291 .42495 Mtetra
.572 .534 .774 r
.57291 .42495 .57974 .44244 .59259 .43669 .58585 .42401 Mtetra
.52 .572 .848 r
.58585 .42401 .59259 .43669 .60548 .43122 .59891 .42464 Mtetra
.343 .64 .964 r
.59891 .42464 .60548 .43122 .6185 .4283 .6121 .42646 Mtetra
.214 0 0 r
.6121 .42646 .6185 .4283 .63179 .43139 .62547 .43051 Mtetra
.633 .07 0 r
.62547 .43051 .63179 .43139 .64558 .44455 .63921 .44129 Mtetra
.77 .266 0 r
.63921 .44129 .64558 .44455 .65994 .46676 .65347 .46062 Mtetra
.523 .015 0 r
.65347 .46062 .65994 .46676 .67427 .48218 .66778 .47498 Mtetra
.777 .808 .878 r
.66778 .47498 .67427 .48218 .68761 .47272 .68118 .46582 Mtetra
.932 .806 .698 r
.68118 .46582 .68761 .47272 .70003 .44583 .6937 .43892 Mtetra
.922 .813 .721 r
.6937 .43892 .70003 .44583 .71254 .42264 .70627 .41523 Mtetra
.835 .813 .829 r
.70627 .41523 .71254 .42264 .72563 .41017 .71939 .40235 Mtetra
.718 .778 .9 r
.71939 .40235 .72563 .41017 .73911 .40377 .73292 .39577 Mtetra
.667 .756 .917 r
.73292 .39577 .73911 .40377 .75276 .3991 .74661 .39103 Mtetra
.657 .752 .92 r
.74661 .39103 .75276 .3991 .7665 .39471 .7604 .3866 Mtetra
.656 .751 .92 r
.7604 .3866 .7665 .39471 .78031 .39032 .77425 .38217 Mtetra
.77425 .38217 .78031 .39032 .79418 .38592 .78817 .37773 Mtetra
.78817 .37773 .79418 .38592 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Mtetra
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Mtetra
.654 .751 .921 r
.3068 .52206 .31431 .52902 .32609 .52529 .31861 .51831 Mtetra
.642 .748 .925 r
.31861 .51831 .32609 .52529 .33791 .52186 .33045 .51487 Mtetra
.56 .722 .949 r
.33045 .51487 .33791 .52186 .34968 .52021 .34225 .51334 Mtetra
.056 .458 .882 r
.34225 .51334 .34968 .52021 .36122 .52467 .35378 .51817 Mtetra
.738 .239 0 r
.35378 .51817 .36122 .52467 .3724 .53962 .36493 .53352 Mtetra
.8 .317 0 r
.36493 .53352 .3724 .53962 .38364 .55765 .37617 .55128 Mtetra
.474 .713 .974 r
.37617 .55128 .38364 .55765 .39575 .55842 .38835 .55096 Mtetra
.885 .765 .724 r
.38835 .55096 .39575 .55842 .40874 .53627 .40144 .52804 Mtetra
.892 .751 .698 r
.40144 .52804 .40874 .53627 .4218 .50929 .41459 .50109 Mtetra
.859 .759 .751 r
.41459 .50109 .4218 .50929 .43452 .49072 .42736 .48278 Mtetra
.807 .765 .814 r
.42736 .48278 .43452 .49072 .44703 .47874 .43992 .47108 Mtetra
.779 .77 .844 r
.43992 .47108 .44703 .47874 .4595 .46896 .45242 .46168 Mtetra
.764 .778 .865 r
.45242 .46168 .4595 .46896 .47196 .46033 .46492 .45339 Mtetra
.74 .784 .889 r
.46492 .45339 .47196 .46033 .48442 .45322 .47742 .4464 Mtetra
.708 .781 .909 r
.47742 .4464 .48442 .45322 .4969 .44759 .48995 .44067 Mtetra
.681 .773 .92 r
.48995 .44067 .4969 .44759 .50942 .44292 .50251 .43585 Mtetra
.664 .764 .924 r
.50251 .43585 .50942 .44292 .522 .43871 .51513 .43152 Mtetra
.655 .759 .926 r
.51513 .43152 .522 .43871 .53463 .43466 .5278 .42745 Mtetra
.646 .757 .93 r
.5278 .42745 .53463 .43466 .54732 .43078 .54053 .42364 Mtetra
.627 .753 .937 r
.54053 .42364 .54732 .43078 .56008 .42737 .55332 .42031 Mtetra
.589 .743 .949 r
.55332 .42031 .56008 .42737 .57291 .42495 .5662 .4179 Mtetra
.528 .718 .96 r
.5662 .4179 .57291 .42495 .58585 .42401 .57917 .4168 Mtetra
.462 .683 .961 r
.57917 .4168 .58585 .42401 .59891 .42464 .59225 .41699 Mtetra
.408 .642 .952 r
.59225 .41699 .59891 .42464 .6121 .42646 .60547 .41834 Mtetra
.28 .555 .928 r
.60547 .41834 .6121 .42646 .62547 .43051 .61885 .42204 Mtetra
0 .241 .749 r
.61885 .42204 .62547 .43051 .63921 .44129 .63259 .43248 Mtetra
.575 .124 0 r
.63259 .43248 .63921 .44129 .65347 .46062 .64684 .4517 Mtetra
0 .051 .592 r
.64684 .4517 .65347 .46062 .66778 .47498 .66118 .46678 Mtetra
.749 .777 .876 r
.66118 .46678 .66778 .47498 .68118 .46582 .67469 .45867 Mtetra
.929 .804 .7 r
.67469 .45867 .68118 .46582 .6937 .43892 .68731 .43199 Mtetra
.924 .813 .718 r
.68731 .43199 .6937 .43892 .70627 .41523 .69994 .4078 Mtetra
.84 .815 .825 r
.69994 .4078 .70627 .41523 .71939 .40235 .7131 .39447 Mtetra
.721 .78 .899 r
.7131 .39447 .71939 .40235 .73292 .39577 .72667 .3877 Mtetra
.667 .757 .917 r
.72667 .3877 .73292 .39577 .74661 .39103 .74041 .38289 Mtetra
.657 .752 .92 r
.74041 .38289 .74661 .39103 .7604 .3866 .75424 .37841 Mtetra
.656 .751 .92 r
.75424 .37841 .7604 .3866 .77425 .38217 .76814 .37395 Mtetra
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Mtetra
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51505 Mtetra
.654 .751 .921 r
.29922 .51505 .3068 .52206 .31861 .51831 .31106 .51127 Mtetra
.641 .748 .926 r
.31106 .51127 .31861 .51831 .33045 .51487 .32294 .50784 Mtetra
.552 .719 .951 r
.32294 .50784 .33045 .51487 .34225 .51334 .33475 .50644 Mtetra
.011 .429 .863 r
.33475 .50644 .34225 .51334 .35378 .51817 .34628 .51166 Mtetra
.751 .254 0 r
.34628 .51166 .35378 .51817 .36493 .53352 .3574 .5274 Mtetra
.788 .3 0 r
.3574 .5274 .36493 .53352 .37617 .55128 .36865 .54457 Mtetra
.587 .748 .954 r
.36865 .54457 .37617 .55128 .38835 .55096 .38094 .54225 Mtetra
.884 .746 .706 r
.38094 .54225 .38835 .55096 .40144 .52804 .39421 .51668 Mtetra
.876 .716 .681 r
.39421 .51668 .40144 .52804 .41459 .50109 .40751 .48728 Mtetra
.816 .681 .716 r
.40751 .48728 .41459 .50109 .42736 .48278 .42036 .46791 Mtetra
.724 .636 .76 r
.42036 .46791 .42736 .48278 .43992 .47108 .43288 .45826 Mtetra
.65 .631 .817 r
.43288 .45826 .43992 .47108 .45242 .46168 .44529 .45396 Mtetra
.595 .721 .932 r
.44529 .45396 .45242 .46168 .46492 .45339 .45771 .45163 Mtetra
.413 .834 .964 r
.45771 .45163 .46492 .45339 .47742 .4464 .4702 .44928 Mtetra
0 0 0 r
.4702 .44928 .47742 .4464 .48995 .44067 .48277 .44619 Mtetra
.083 0 0 r
.48277 .44619 .48995 .44067 .50251 .43585 .49541 .44247 Mtetra
.127 0 0 r
.49541 .44247 .50251 .43585 .51513 .43152 .50812 .43844 Mtetra
.14 0 0 r
.50812 .43844 .51513 .43152 .5278 .42745 .52089 .43434 Mtetra
.135 0 0 r
.52089 .43434 .5278 .42745 .54053 .42364 .53371 .43016 Mtetra
.098 0 0 r
.53371 .43016 .54053 .42364 .55332 .42031 .54659 .42568 Mtetra
0 0 0 r
.54659 .42568 .55332 .42031 .5662 .4179 .55953 .42058 Mtetra
.323 .79 .68 r
.55953 .42058 .5662 .4179 .57917 .4168 .57251 .41472 Mtetra
.655 .93 .971 r
.57251 .41472 .57917 .4168 .59225 .41699 .58553 .40885 Mtetra
.645 .737 .916 r
.58553 .40885 .59225 .41699 .60547 .41834 .59865 .40497 Mtetra
.491 .549 .843 r
.59865 .40497 .60547 .41834 .61885 .42204 .61198 .4065 Mtetra
.148 .304 .767 r
.61198 .4065 .61885 .42204 .63259 .43248 .62574 .41791 Mtetra
0 0 .545 r
.62574 .41791 .63259 .43248 .64684 .4517 .64004 .43957 Mtetra
0 .04 .606 r
.64004 .43957 .64684 .4517 .66118 .46678 .65448 .45729 Mtetra
.698 .732 .877 r
.65448 .45729 .66118 .46678 .67469 .45867 .66812 .45116 Mtetra
.925 .8 .704 r
.66812 .45116 .67469 .45867 .68731 .43199 .68086 .42501 Mtetra
.926 .812 .715 r
.68086 .42501 .68731 .43199 .69994 .4078 .69356 .40036 Mtetra
.846 .816 .82 r
.69356 .40036 .69994 .4078 .7131 .39447 .70676 .38655 Mtetra
.726 .782 .897 r
.70676 .38655 .7131 .39447 .72667 .3877 .72036 .37957 Mtetra
.669 .757 .917 r
.72036 .37957 .72667 .3877 .74041 .38289 .73415 .37468 Mtetra
.657 .752 .92 r
.73415 .37468 .74041 .38289 .75424 .37841 .74803 .37016 Mtetra
.656 .751 .92 r
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Mtetra
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Mtetra
.27976 .51181 .28743 .51885 .29922 .51505 .29158 .50798 Mtetra
.654 .751 .921 r
.29158 .50798 .29922 .51505 .31106 .51127 .30345 .50417 Mtetra
.64 .747 .927 r
.30345 .50417 .31106 .51127 .32294 .50784 .31536 .50075 Mtetra
.543 .715 .952 r
.31536 .50075 .32294 .50784 .33475 .50644 .32718 .4995 Mtetra
0 .4 .843 r
.32718 .4995 .33475 .50644 .34628 .51166 .3387 .50511 Mtetra
.754 .258 0 r
.3387 .50511 .34628 .51166 .3574 .5274 .3498 .52096 Mtetra
.744 .244 0 r
.3498 .52096 .3574 .5274 .36865 .54457 .36111 .53661 Mtetra
.707 .749 .885 r
.36111 .53661 .36865 .54457 .38094 .54225 .37359 .53072 Mtetra
.872 .715 .684 r
.37359 .53072 .38094 .54225 .39421 .51668 .38707 .5019 Mtetra
.852 .685 .674 r
.38707 .5019 .39421 .51668 .40751 .48728 .40043 .47253 Mtetra
.785 .663 .729 r
.40043 .47253 .40751 .48728 .42036 .46791 .41321 .45671 Mtetra
.679 .67 .835 r
.41321 .45671 .42036 .46791 .43288 .45826 .42563 .45137 Mtetra
.568 .737 .955 r
.42563 .45137 .43288 .45826 .44529 .45396 .43801 .44945 Mtetra
.519 .799 .997 r
.43801 .44945 .44529 .45396 .45771 .45163 .45047 .4475 Mtetra
.544 .823 .997 r
.45047 .4475 .45771 .45163 .4702 .44928 .46301 .44494 Mtetra
.574 .828 .993 r
.46301 .44494 .4702 .44928 .48277 .44619 .47562 .44195 Mtetra
.59 .838 .992 r
.47562 .44195 .48277 .44619 .49541 .44247 .48831 .43862 Mtetra
.599 .855 .992 r
.48831 .43862 .49541 .44247 .50812 .43844 .50107 .43491 Mtetra
.611 .87 .991 r
.50107 .43491 .50812 .43844 .52089 .43434 .51389 .4308 Mtetra
.631 .877 .987 r
.51389 .4308 .52089 .43434 .53371 .43016 .52677 .42629 Mtetra
.656 .874 .98 r
.52677 .42629 .53371 .43016 .54659 .42568 .53971 .42137 Mtetra
.677 .866 .971 r
.53971 .42137 .54659 .42568 .55953 .42058 .5527 .41608 Mtetra
.695 .865 .963 r
.5527 .41608 .55953 .42058 .57251 .41472 .56573 .41036 Mtetra
.716 .876 .956 r
.56573 .41036 .57251 .41472 .58553 .40885 .57881 .40399 Mtetra
.719 .861 .949 r
.57881 .40399 .58553 .40885 .59865 .40497 .59193 .39759 Mtetra
.605 .747 .945 r
.59193 .39759 .59865 .40497 .61198 .4065 .60518 .39467 Mtetra
.187 .401 .839 r
.60518 .39467 .61198 .4065 .62574 .41791 .61882 .4024 Mtetra
0 0 .566 r
.61882 .4024 .62574 .41791 .64004 .43957 .63309 .42392 Mtetra
0 .018 .591 r
.63309 .42392 .64004 .43957 .65448 .45729 .64762 .44488 Mtetra
.602 .632 .853 r
.64762 .44488 .65448 .45729 .66812 .45116 .66144 .44235 Mtetra
.907 .783 .713 r
.66144 .44235 .66812 .45116 .68086 .42501 .67433 .41769 Mtetra
.923 .808 .714 r
.67433 .41769 .68086 .42501 .69356 .40036 .68711 .39286 Mtetra
.851 .816 .815 r
.68711 .39286 .69356 .40036 .70676 .38655 .70035 .37858 Mtetra
.73 .784 .895 r
.70035 .37858 .70676 .38655 .72036 .37957 .714 .37137 Mtetra
.67 .758 .917 r
.714 .37137 .72036 .37957 .73415 .37468 .72783 .3664 Mtetra
.657 .752 .92 r
.72783 .3664 .73415 .37468 .74803 .37016 .74176 .36183 Mtetra
.656 .751 .92 r
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Mtetra
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Mtetra
.27202 .50471 .27976 .51181 .29158 .50798 .28388 .50085 Mtetra
.654 .751 .921 r
.28388 .50085 .29158 .50798 .30345 .50417 .29578 .49701 Mtetra
.638 .747 .927 r
.29578 .49701 .30345 .50417 .31536 .50075 .30771 .4936 Mtetra
.534 .712 .954 r
.30771 .4936 .31536 .50075 .32718 .4995 .31956 .49249 Mtetra
0 .384 .832 r
.31956 .49249 .32718 .4995 .3387 .50511 .33107 .4983 Mtetra
.73 .23 0 r
.33107 .4983 .3387 .50511 .3498 .52096 .34219 .51355 Mtetra
.591 .086 0 r
.34219 .51355 .3498 .52096 .36111 .53661 .35363 .52637 Mtetra
.76 .715 .81 r
.35363 .52637 .36111 .53661 .37359 .53072 .36632 .51661 Mtetra
.856 .691 .676 r
.36632 .51661 .37359 .53072 .38707 .5019 .37989 .48724 Mtetra
.839 .683 .688 r
.37989 .48724 .38707 .5019 .40043 .47253 .39317 .46178 Mtetra
.776 .71 .79 r
.39317 .46178 .40043 .47253 .41321 .45671 .40582 .4505 Mtetra
.615 .776 .958 r
.40582 .4505 .41321 .45671 .42563 .45137 .41822 .44737 Mtetra
.468 .797 .999 r
.41822 .44737 .42563 .45137 .43801 .44945 .43063 .44583 Mtetra
.499 .822 1 r
.43063 .44583 .43801 .44945 .45047 .4475 .44314 .44364 Mtetra
.562 .84 .997 r
.44314 .44364 .45047 .4475 .46301 .44494 .45574 .44062 Mtetra
.606 .841 .988 r
.45574 .44062 .46301 .44494 .47562 .44195 .46841 .43701 Mtetra
.631 .828 .976 r
.46841 .43701 .47562 .44195 .48831 .43862 .48115 .43306 Mtetra
.643 .813 .965 r
.48115 .43306 .48831 .43862 .50107 .43491 .49396 .42897 Mtetra
.648 .803 .957 r
.49396 .42897 .50107 .43491 .51389 .4308 .50683 .4248 Mtetra
.651 .803 .956 r
.50683 .4248 .51389 .4308 .52677 .42629 .51975 .42056 Mtetra
.653 .813 .96 r
.51975 .42056 .52677 .42629 .53971 .42137 .53274 .41619 Mtetra
.66 .834 .967 r
.53274 .41619 .53971 .42137 .5527 .41608 .54579 .41151 Mtetra
.678 .861 .969 r
.54579 .41151 .5527 .41608 .56573 .41036 .55889 .40619 Mtetra
.704 .881 .963 r
.55889 .40619 .56573 .41036 .57881 .40399 .57203 .40005 Mtetra
.726 .894 .956 r
.57203 .40005 .57881 .40399 .59193 .39759 .5852 .39322 Mtetra
.67 .869 .974 r
.5852 .39322 .59193 .39759 .60518 .39467 .59846 .38794 Mtetra
.249 .589 .948 r
.59846 .38794 .60518 .39467 .61882 .4024 .612 .39095 Mtetra
0 .011 .577 r
.612 .39095 .61882 .4024 .63309 .42392 .62611 .4084 Mtetra
0 0 .574 r
.62611 .4084 .63309 .42392 .64762 .44488 .64062 .42982 Mtetra
.503 .538 .825 r
.64062 .42982 .64762 .44488 .66144 .44235 .65462 .43117 Mtetra
.87 .748 .726 r
.65462 .43117 .66144 .44235 .67433 .41769 .66771 .40936 Mtetra
.912 .793 .717 r
.66771 .40936 .67433 .41769 .68711 .39286 .68059 .38508 Mtetra
.851 .812 .811 r
.68059 .38508 .68711 .39286 .70035 .37858 .69389 .37052 Mtetra
.734 .784 .893 r
.69389 .37052 .70035 .37858 .714 .37137 .70758 .36309 Mtetra
.671 .759 .916 r
.70758 .36309 .714 .37137 .72783 .3664 .72146 .35804 Mtetra
.657 .752 .92 r
.72146 .35804 .72783 .3664 .74176 .36183 .73543 .35342 Mtetra
.656 .751 .92 r
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34883 Mtetra
.74947 .34883 .75575 .35728 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Mtetra
.26422 .49755 .27202 .50471 .28388 .50085 .27611 .49365 Mtetra
.654 .751 .921 r
.27611 .49365 .28388 .50085 .29578 .49701 .28805 .48979 Mtetra
.637 .746 .927 r
.28805 .48979 .29578 .49701 .30771 .4936 .3 .48638 Mtetra
.531 .711 .954 r
.3 .48638 .30771 .4936 .31956 .49249 .31187 .48532 Mtetra
0 .402 .846 r
.31187 .48532 .31956 .49249 .33107 .4983 .32341 .4909 Mtetra
.648 .145 0 r
.32341 .4909 .33107 .4983 .34219 .51355 .3346 .50459 Mtetra
0 .186 .702 r
.3346 .50459 .34219 .51355 .35363 .52637 .34621 .51407 Mtetra
.767 .686 .773 r
.34621 .51407 .35363 .52637 .36632 .51661 .35903 .50229 Mtetra
.846 .688 .686 r
.35903 .50229 .36632 .51661 .37989 .48724 .37254 .47562 Mtetra
.841 .712 .722 r
.37254 .47562 .37989 .48724 .39317 .46178 .38568 .45499 Mtetra
.771 .794 .872 r
.38568 .45499 .39317 .46178 .40582 .4505 .39829 .44643 Mtetra
.571 .835 .995 r
.39829 .44643 .40582 .4505 .41822 .44737 .41073 .4434 Mtetra
.538 .827 .999 r
.41073 .4434 .41822 .44737 .43063 .44583 .42321 .44081 Mtetra
.599 .815 .982 r
.42321 .44081 .43063 .44583 .44314 .44364 .43579 .43759 Mtetra
.627 .79 .96 r
.43579 .43759 .44314 .44364 .45574 .44062 .44844 .43403 Mtetra
.633 .776 .949 r
.44844 .43403 .45574 .44062 .46841 .43701 .46116 .43039 Mtetra
.636 .777 .948 r
.46116 .43039 .46841 .43701 .48115 .43306 .47394 .42665 Mtetra
.641 .786 .951 r
.47394 .42665 .48115 .43306 .49396 .42897 .48678 .42274 Mtetra
.647 .795 .953 r
.48678 .42274 .49396 .42897 .50683 .4248 .49969 .41862 Mtetra
.654 .8 .952 r
.49969 .41862 .50683 .4248 .51975 .42056 .51267 .41427 Mtetra
.662 .8 .948 r
.51267 .41427 .51975 .42056 .53274 .41619 .5257 .40968 Mtetra
.669 .796 .943 r
.5257 .40968 .53274 .41619 .54579 .41151 .5388 .40491 Mtetra
.673 .796 .94 r
.5388 .40491 .54579 .41151 .55889 .40619 .55195 .40001 Mtetra
.684 .813 .944 r
.55195 .40001 .55889 .40619 .57203 .40005 .56515 .39472 Mtetra
.701 .846 .952 r
.56515 .39472 .57203 .40005 .5852 .39322 .5784 .38882 Mtetra
.674 .871 .973 r
.5784 .38882 .5852 .39322 .59846 .38794 .59172 .3834 Mtetra
.343 .723 .985 r
.59172 .3834 .59846 .38794 .612 .39095 .60523 .38356 Mtetra
0 .099 .61 r
.60523 .38356 .612 .39095 .62611 .4084 .6192 .39597 Mtetra
0 .005 .575 r
.6192 .39597 .62611 .4084 .64062 .42982 .63358 .41453 Mtetra
.444 .502 .824 r
.63358 .41453 .64062 .42982 .65462 .43117 .64766 .41784 Mtetra
.828 .713 .737 r
.64766 .41784 .65462 .43117 .66771 .40936 .66095 .3994 Mtetra
.889 .77 .724 r
.66095 .3994 .66771 .40936 .68059 .38508 .67399 .37667 Mtetra
.843 .799 .808 r
.67399 .37667 .68059 .38508 .69389 .37052 .68737 .36228 Mtetra
.735 .782 .89 r
.68737 .36228 .69389 .37052 .70758 .36309 .7011 .35473 Mtetra
.672 .759 .916 r
.7011 .35473 .70758 .36309 .72146 .35804 .71503 .34961 Mtetra
.658 .752 .92 r
.71503 .34961 .72146 .35804 .73543 .35342 .72905 .34494 Mtetra
.656 .751 .92 r
.72905 .34494 .73543 .35342 .74947 .34883 .74314 .34031 Mtetra
.74314 .34031 .74947 .34883 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Mtetra
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Mtetra
.654 .751 .921 r
.26828 .4864 .27611 .49365 .28805 .48979 .28024 .48251 Mtetra
.637 .746 .927 r
.28024 .48251 .28805 .48979 .3 .48638 .29224 .47907 Mtetra
.538 .712 .952 r
.29224 .47907 .3 .48638 .31187 .48532 .30413 .47785 Mtetra
.073 .46 .885 r
.30413 .47785 .31187 .48532 .32341 .4909 .31573 .48265 Mtetra
0 .012 .525 r
.31573 .48265 .32341 .4909 .3346 .50459 .32704 .49411 Mtetra
.09 .381 .842 r
.32704 .49411 .3346 .50459 .34621 .51407 .33879 .5009 Mtetra
.756 .672 .769 r
.33879 .5009 .34621 .51407 .35903 .50229 .35162 .48957 Mtetra
.841 .701 .708 r
.35162 .48957 .35903 .50229 .37254 .47562 .365 .46702 Mtetra
.848 .757 .763 r
.365 .46702 .37254 .47562 .38568 .45499 .37805 .44998 Mtetra
.766 .847 .912 r
.37805 .44998 .38568 .45499 .39829 .44643 .39068 .44214 Mtetra
.614 .843 .987 r
.39068 .44214 .39829 .44643 .41073 .4434 .40319 .43839 Mtetra
.593 .814 .984 r
.40319 .43839 .41073 .4434 .42321 .44081 .41574 .43526 Mtetra
.612 .803 .973 r
.41574 .43526 .42321 .44081 .43579 .43759 .42836 .43189 Mtetra
.628 .804 .967 r
.42836 .43189 .43579 .43759 .44844 .43403 .44106 .42819 Mtetra
.64 .804 .962 r
.44106 .42819 .44844 .43403 .46116 .43039 .45382 .42422 Mtetra
.648 .797 .954 r
.45382 .42422 .46116 .43039 .47394 .42665 .46665 .42007 Mtetra
.652 .786 .946 r
.46665 .42007 .47394 .42665 .48678 .42274 .47955 .41585 Mtetra
.653 .778 .94 r
.47955 .41585 .48678 .42274 .49969 .41862 .4925 .4116 Mtetra
.653 .776 .938 r
.4925 .4116 .49969 .41862 .51267 .41427 .50552 .40733 Mtetra
.651 .778 .941 r
.50552 .40733 .51267 .41427 .5257 .40968 .5186 .40308 Mtetra
.651 .79 .948 r
.5186 .40308 .5257 .40968 .5388 .40491 .53174 .39879 Mtetra
.659 .808 .955 r
.53174 .39879 .5388 .40491 .55195 .40001 .54494 .39418 Mtetra
.671 .822 .956 r
.54494 .39418 .55195 .40001 .56515 .39472 .55821 .38918 Mtetra
.685 .837 .956 r
.55821 .38918 .56515 .39472 .5784 .38882 .57152 .38372 Mtetra
.661 .846 .971 r
.57152 .38372 .5784 .38882 .59172 .3834 .5849 .37875 Mtetra
.414 .76 .995 r
.5849 .37875 .59172 .3834 .60523 .38356 .59843 .37799 Mtetra
0 .241 .694 r
.59843 .37799 .60523 .38356 .6192 .39597 .61232 .38663 Mtetra
0 .084 .624 r
.61232 .38663 .6192 .39597 .63358 .41453 .62657 .40086 Mtetra
.443 .529 .851 r
.62657 .40086 .63358 .41453 .64766 .41784 .64063 .4036 Mtetra
.798 .693 .749 r
.64063 .4036 .64766 .41784 .66095 .3994 .65408 .38784 Mtetra
.86 .745 .734 r
.65408 .38784 .66095 .3994 .67399 .37667 .66729 .36735 Mtetra
.825 .779 .809 r
.66729 .36735 .67399 .37667 .68737 .36228 .68077 .35372 Mtetra
.731 .774 .888 r
.68077 .35372 .68737 .36228 .7011 .35473 .69456 .34626 Mtetra
.672 .758 .915 r
.69456 .34626 .7011 .35473 .71503 .34961 .70854 .34109 Mtetra
.658 .752 .92 r
.70854 .34109 .71503 .34961 .72905 .34494 .7226 .33638 Mtetra
.656 .751 .92 r
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Mtetra
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Mtetra
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Mtetra
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Mtetra
.654 .751 .921 r
.26038 .47909 .26828 .4864 .28024 .48251 .27238 .47516 Mtetra
.639 .747 .926 r
.27238 .47516 .28024 .48251 .29224 .47907 .2844 .47162 Mtetra
.556 .717 .948 r
.2844 .47162 .29224 .47907 .30413 .47785 .29635 .47003 Mtetra
.213 .537 .925 r
.29635 .47003 .30413 .47785 .31573 .48265 .30804 .47354 Mtetra
0 .205 .719 r
.30804 .47354 .31573 .48265 .32704 .49411 .31949 .48257 Mtetra
.243 .451 .863 r
.31949 .48257 .32704 .49411 .33879 .5009 .33132 .48786 Mtetra
.731 .666 .786 r
.33132 .48786 .33879 .5009 .35162 .48957 .34406 .47866 Mtetra
.835 .722 .74 r
.34406 .47866 .35162 .48957 .365 .46702 .3573 .46019 Mtetra
.849 .794 .797 r
.3573 .46019 .365 .46702 .37805 .44998 .37031 .44537 Mtetra
.767 .86 .918 r
.37031 .44537 .37805 .44998 .39068 .44214 .383 .43749 Mtetra
.654 .843 .973 r
.383 .43749 .39068 .44214 .40319 .43839 .39559 .43297 Mtetra
.634 .814 .969 r
.39559 .43297 .40319 .43839 .41574 .43526 .4082 .42906 Mtetra
.643 .793 .954 r
.4082 .42906 .41574 .43526 .42836 .43189 .42089 .42507 Mtetra
.645 .775 .943 r
.42089 .42507 .42836 .43189 .44106 .42819 .43363 .42108 Mtetra
.643 .767 .938 r
.43363 .42108 .44106 .42819 .45382 .42422 .44644 .41715 Mtetra
.642 .769 .94 r
.44644 .41715 .45382 .42422 .46665 .42007 .4593 .41321 Mtetra
.644 .777 .945 r
.4593 .41321 .46665 .42007 .47955 .41585 .47224 .4092 Mtetra
.647 .786 .948 r
.47224 .4092 .47955 .41585 .4925 .4116 .48523 .40504 Mtetra
.653 .791 .948 r
.48523 .40504 .4925 .4116 .50552 .40733 .4983 .40068 Mtetra
.663 .793 .944 r
.4983 .40068 .50552 .40733 .5186 .40308 .51142 .39604 Mtetra
.67 .784 .935 r
.51142 .39604 .5186 .40308 .53174 .39879 .52461 .39119 Mtetra
.665 .768 .927 r
.52461 .39119 .53174 .39879 .54494 .39418 .53786 .3865 Mtetra
.658 .764 .928 r
.53786 .3865 .54494 .39418 .55821 .38918 .55117 .382 Mtetra
.65 .777 .941 r
.55117 .382 .55821 .38918 .57152 .38372 .56455 .37769 Mtetra
.622 .805 .97 r
.56455 .37769 .57152 .38372 .5849 .37875 .578 .37385 Mtetra
.424 .758 .995 r
.578 .37385 .5849 .37875 .59843 .37799 .59159 .37306 Mtetra
0 .377 .785 r
.59159 .37306 .59843 .37799 .61232 .38663 .60544 .37918 Mtetra
0 .241 .732 r
.60544 .37918 .61232 .38663 .62657 .40086 .61957 .38902 Mtetra
.504 .6 .882 r
.61957 .38902 .62657 .40086 .64063 .4036 .63357 .38942 Mtetra
.785 .69 .759 r
.63357 .38942 .64063 .4036 .65408 .38784 .64713 .37513 Mtetra
.832 .724 .745 r
.64713 .37513 .65408 .38784 .66729 .36735 .6605 .35711 Mtetra
.8 .757 .813 r
.6605 .35711 .66729 .36735 .68077 .35372 .6741 .34477 Mtetra
.72 .763 .886 r
.6741 .34477 .68077 .35372 .69456 .34626 .68796 .33764 Mtetra
.67 .755 .914 r
.68796 .33764 .69456 .34626 .70854 .34109 .70199 .33249 Mtetra
.658 .752 .92 r
.70199 .33249 .70854 .34109 .7226 .33638 .7161 .32774 Mtetra
.656 .751 .92 r
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Mtetra
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Mtetra
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Mtetra
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Mtetra
.654 .751 .921 r
.25241 .47171 .26038 .47909 .27238 .47516 .26444 .46774 Mtetra
.643 .748 .925 r
.26444 .46774 .27238 .47516 .2844 .47162 .27651 .46406 Mtetra
.583 .725 .941 r
.27651 .46406 .2844 .47162 .29635 .47003 .28853 .46189 Mtetra
.354 .607 .944 r
.28853 .46189 .29635 .47003 .30804 .47354 .30033 .46379 Mtetra
.037 .37 .838 r
.30033 .46379 .30804 .47354 .31949 .48257 .31193 .47047 Mtetra
.294 .469 .862 r
.31193 .47047 .31949 .48257 .33132 .48786 .32378 .47517 Mtetra
.687 .656 .813 r
.32378 .47517 .33132 .48786 .34406 .47866 .33638 .4689 Mtetra
.819 .739 .775 r
.33638 .4689 .34406 .47866 .3573 .46019 .34948 .45415 Mtetra
.844 .815 .821 r
.34948 .45415 .3573 .46019 .37031 .44537 .36249 .44073 Mtetra
.778 .861 .911 r
.36249 .44073 .37031 .44537 .383 .43749 .37526 .43234 Mtetra
.687 .837 .955 r
.37526 .43234 .383 .43749 .39559 .43297 .38793 .42705 Mtetra
.649 .804 .957 r
.38793 .42705 .39559 .43297 .4082 .42906 .4006 .42283 Mtetra
.641 .793 .956 r
.4006 .42283 .4082 .42906 .42089 .42507 .41332 .41885 Mtetra
.642 .795 .956 r
.41332 .41885 .42089 .42507 .43363 .42108 .42611 .41482 Mtetra
.646 .796 .954 r
.42611 .41482 .43363 .42108 .44644 .41715 .43897 .41065 Mtetra
.65 .791 .95 r
.43897 .41065 .44644 .41715 .4593 .41321 .45188 .4064 Mtetra
.651 .783 .944 r
.45188 .4064 .4593 .41321 .47224 .4092 .46486 .40213 Mtetra
.65 .776 .94 r
.46486 .40213 .47224 .4092 .48523 .40504 .4779 .3979 Mtetra
.645 .773 .942 r
.4779 .3979 .48523 .40504 .4983 .40068 .49101 .39379 Mtetra
.633 .778 .951 r
.49101 .39379 .4983 .40068 .51142 .39604 .50418 .38995 Mtetra
.623 .801 .968 r
.50418 .38995 .51142 .39604 .52461 .39119 .51741 .38617 Mtetra
.64 .842 .978 r
.51741 .38617 .52461 .39119 .53786 .3865 .53072 .38169 Mtetra
.666 .857 .973 r
.53072 .38169 .53786 .3865 .55117 .382 .54408 .37649 Mtetra
.67 .837 .964 r
.54408 .37649 .55117 .382 .56455 .37769 .5575 .37134 Mtetra
.609 .792 .969 r
.5575 .37134 .56455 .37769 .578 .37385 .57101 .36785 Mtetra
.414 .717 .986 r
.57101 .36785 .578 .37385 .59159 .37306 .58466 .3678 Mtetra
0 .474 .863 r
.58466 .3678 .59159 .37306 .60544 .37918 .59852 .37256 Mtetra
.014 .445 .868 r
.59852 .37256 .60544 .37918 .61957 .38902 .61256 .37836 Mtetra
.603 .676 .892 r
.61256 .37836 .61957 .38902 .63357 .38942 .62649 .37553 Mtetra
.782 .693 .766 r
.62649 .37553 .63357 .38942 .64713 .37513 .6401 .36176 Mtetra
.806 .709 .758 r
.6401 .36176 .64713 .37513 .6605 .35711 .65363 .34617 Mtetra
.771 .737 .822 r
.65363 .34617 .6605 .35711 .6741 .34477 .66735 .33547 Mtetra
.705 .752 .888 r
.66735 .33547 .6741 .34477 .68796 .33764 .6813 .32888 Mtetra
.667 .752 .914 r
.6813 .32888 .68796 .33764 .70199 .33249 .69538 .3238 Mtetra
.657 .752 .92 r
.69538 .3238 .70199 .33249 .7161 .32774 .70954 .31903 Mtetra
.656 .751 .92 r
.70954 .31903 .7161 .32774 .73029 .32303 .72378 .31427 Mtetra
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Mtetra
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Mtetra
.655 .751 .921 r
.24437 .46427 .25241 .47171 .26444 .46774 .25644 .46025 Mtetra
.648 .749 .923 r
.25644 .46025 .26444 .46774 .27651 .46406 .26855 .45641 Mtetra
.609 .733 .933 r
.26855 .45641 .27651 .46406 .28853 .46189 .28064 .45358 Mtetra
.469 .66 .944 r
.28064 .45358 .28853 .46189 .30033 .46379 .29258 .45375 Mtetra
.238 .489 .893 r
.29258 .45375 .30033 .46379 .31193 .47047 .30433 .45811 Mtetra
.312 .475 .861 r
.30433 .45811 .31193 .47047 .32378 .47517 .31619 .46255 Mtetra
.618 .629 .839 r
.31619 .46255 .32378 .47517 .33638 .4689 .32863 .45946 Mtetra
.786 .741 .811 r
.32863 .45946 .33638 .4689 .34948 .45415 .34158 .44827 Mtetra
.832 .822 .839 r
.34158 .44827 .34948 .45415 .36249 .44073 .3546 .43602 Mtetra
.787 .86 .904 r
.3546 .43602 .36249 .44073 .37526 .43234 .36744 .42717 Mtetra
.71 .842 .945 r
.36744 .42717 .37526 .43234 .38793 .42705 .38019 .42117 Mtetra
.672 .814 .951 r
.38019 .42117 .38793 .42705 .4006 .42283 .39293 .41631 Mtetra
.661 .792 .944 r
.39293 .41631 .4006 .42283 .41332 .41885 .40571 .4118 Mtetra
.654 .775 .938 r
.40571 .4118 .41332 .41885 .42611 .41482 .41855 .4075 Mtetra
.649 .767 .935 r
.41855 .4075 .42611 .41482 .43897 .41065 .43144 .40333 Mtetra
.648 .767 .936 r
.43144 .40333 .43897 .41065 .45188 .4064 .4444 .39919 Mtetra
.649 .772 .938 r
.4444 .39919 .45188 .4064 .46486 .40213 .45742 .39496 Mtetra
.655 .777 .938 r
.45742 .39496 .46486 .40213 .4779 .3979 .47051 .39054 Mtetra
.666 .775 .931 r
.47051 .39054 .4779 .3979 .49101 .39379 .48366 .3858 Mtetra
.676 .762 .916 r
.48366 .3858 .49101 .39379 .50418 .38995 .49688 .3807 Mtetra
.663 .726 .896 r
.49688 .3807 .50418 .38995 .51741 .38617 .51016 .37597 Mtetra
.612 .685 .894 r
.51016 .37597 .51741 .38617 .53072 .38169 .52349 .37292 Mtetra
.587 .711 .929 r
.52349 .37292 .53072 .38169 .54408 .37649 .53691 .37045 Mtetra
.603 .801 .975 r
.53691 .37045 .54408 .37649 .5575 .37134 .5504 .36698 Mtetra
.573 .845 .996 r
.5504 .36698 .5575 .37134 .57101 .36785 .56397 .36344 Mtetra
.375 .752 .99 r
.56397 .36344 .57101 .36785 .58466 .3678 .57766 .3629 Mtetra
.103 .567 .912 r
.57766 .3629 .58466 .3678 .59852 .37256 .59153 .36601 Mtetra
.304 .641 .967 r
.59153 .36601 .59852 .37256 .61256 .37836 .6055 .36783 Mtetra
.693 .718 .868 r
.6055 .36783 .61256 .37836 .62649 .37553 .61936 .36154 Mtetra
.779 .692 .768 r
.61936 .36154 .62649 .37553 .6401 .36176 .63302 .34806 Mtetra
.778 .696 .773 r
.63302 .34806 .6401 .36176 .65363 .34617 .6467 .33491 Mtetra
.74 .722 .835 r
.6467 .33491 .65363 .34617 .66735 .33547 .66055 .32599 Mtetra
.689 .743 .893 r
.66055 .32599 .66735 .33547 .6813 .32888 .67457 .32001 Mtetra
.663 .75 .915 r
.67457 .32001 .6813 .32888 .69538 .3238 .6887 .31503 Mtetra
.657 .751 .92 r
.6887 .31503 .69538 .3238 .70954 .31903 .70292 .31023 Mtetra
.656 .751 .92 r
.70292 .31023 .70954 .31903 .72378 .31427 .71721 .30542 Mtetra
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Mtetra
.655 .751 .92 r
.23627 .45677 .24437 .46427 .25644 .46025 .24837 .45269 Mtetra
.652 .75 .922 r
.24837 .45269 .25644 .46025 .26855 .45641 .26052 .4487 Mtetra
.631 .741 .927 r
.26052 .4487 .26855 .45641 .28064 .45358 .27269 .44528 Mtetra
.553 .698 .936 r
.27269 .44528 .28064 .45358 .29258 .45375 .28477 .4438 Mtetra
.393 .58 .915 r
.28477 .4438 .29258 .45375 .30433 .45811 .29669 .44577 Mtetra
.343 .495 .866 r
.29669 .44577 .30433 .45811 .31619 .46255 .30858 .44957 Mtetra
.529 .582 .852 r
.30858 .44957 .31619 .46255 .32863 .45946 .32085 .4494 Mtetra
.723 .717 .844 r
.32085 .4494 .32863 .45946 .34158 .44827 .33362 .44205 Mtetra
.809 .817 .857 r
.33362 .44205 .34158 .44827 .3546 .43602 .34661 .43132 Mtetra
.796 .862 .898 r
.34661 .43132 .3546 .43602 .36744 .42717 .35954 .42199 Mtetra
.734 .846 .933 r
.35954 .42199 .36744 .42717 .38019 .42117 .37237 .41517 Mtetra
.683 .814 .945 r
.37237 .41517 .38019 .42117 .39293 .41631 .38517 .40998 Mtetra
.659 .799 .95 r
.38517 .40998 .39293 .41631 .40571 .4118 .398 .40545 Mtetra
.653 .798 .952 r
.398 .40545 .40571 .4118 .41855 .4075 .41088 .40108 Mtetra
.652 .797 .952 r
.41088 .40108 .41855 .4075 .43144 .40333 .42383 .3967 Mtetra
.652 .791 .949 r
.42383 .3967 .43144 .40333 .4444 .39919 .43683 .39232 Mtetra
.652 .786 .945 r
.43683 .39232 .4444 .39919 .45742 .39496 .4499 .38794 Mtetra
.649 .781 .944 r
.4499 .38794 .45742 .39496 .47051 .39054 .46303 .38364 Mtetra
.647 .785 .948 r
.46303 .38364 .47051 .39054 .48366 .3858 .47623 .37935 Mtetra
.65 .801 .955 r
.47623 .37935 .48366 .3858 .49688 .3807 .48949 .37489 Mtetra
.696 .834 .949 r
.48949 .37489 .49688 .3807 .51016 .37597 .50282 .36903 Mtetra
.731 .81 .913 r
.50282 .36903 .51016 .37597 .52349 .37292 .51621 .36193 Mtetra
.62 .673 .879 r
.51621 .36193 .52349 .37292 .53691 .37045 .52966 .35855 Mtetra
.523 .609 .88 r
.52966 .35855 .53691 .37045 .5504 .36698 .54319 .35828 Mtetra
.484 .67 .946 r
.54319 .35828 .5504 .36698 .56397 .36344 .55683 .35809 Mtetra
.351 .709 .985 r
.55683 .35809 .56397 .36344 .57766 .3629 .57058 .35843 Mtetra
.273 .693 .968 r
.57058 .35843 .57766 .3629 .59153 .36601 .58446 .35915 Mtetra
.577 .772 .971 r
.58446 .35915 .59153 .36601 .6055 .36783 .59836 .35631 Mtetra
.745 .719 .827 r
.59836 .35631 .6055 .36783 .61936 .36154 .61217 .34692 Mtetra
.764 .679 .769 r
.61217 .34692 .61936 .36154 .63302 .34806 .62591 .33432 Mtetra
.745 .684 .792 r
.62591 .33432 .63302 .34806 .6467 .33491 .63972 .32376 Mtetra
.709 .715 .853 r
.63972 .32376 .6467 .33491 .66055 .32599 .65368 .31652 Mtetra
.674 .74 .9 r
.65368 .31652 .66055 .32599 .67457 .32001 .66778 .31108 Mtetra
.659 .749 .917 r
.66778 .31108 .67457 .32001 .6887 .31503 .68197 .30618 Mtetra
.656 .751 .92 r
.68197 .30618 .6887 .31503 .70292 .31023 .69624 .30134 Mtetra
.69624 .30134 .70292 .31023 .71721 .30542 .71057 .2965 Mtetra
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Mtetra
.2281 .44921 .23627 .45677 .24837 .45269 .24023 .44508 Mtetra
.654 .751 .921 r
.24023 .44508 .24837 .45269 .26052 .4487 .25242 .44099 Mtetra
.645 .746 .923 r
.25242 .44099 .26052 .4487 .27269 .44528 .26465 .43713 Mtetra
.608 .723 .927 r
.26465 .43713 .27269 .44528 .28477 .4438 .27686 .4343 Mtetra
.513 .651 .92 r
.27686 .4343 .28477 .4438 .29669 .44577 .28896 .43387 Mtetra
.414 .545 .879 r
.28896 .43387 .29669 .44577 .30858 .44957 .30096 .43611 Mtetra
.458 .538 .851 r
.30096 .43611 .30858 .44957 .32085 .4494 .3131 .43783 Mtetra
.621 .653 .86 r
.3131 .43783 .32085 .4494 .33362 .44205 .32565 .4346 Mtetra
.756 .785 .877 r
.32565 .4346 .33362 .44205 .34661 .43132 .33854 .42645 Mtetra
.791 .858 .9 r
.33854 .42645 .34661 .43132 .35954 .42199 .35152 .41731 Mtetra
.755 .865 .929 r
.35152 .41731 .35954 .42199 .37237 .41517 .36445 .4097 Mtetra
.711 .837 .942 r
.36445 .4097 .37237 .41517 .38517 .40998 .37734 .40359 Mtetra
.682 .805 .941 r
.37734 .40359 .38517 .40998 .398 .40545 .39024 .39839 Mtetra
.664 .781 .936 r
.39024 .39839 .398 .40545 .41088 .40108 .40318 .39372 Mtetra
.653 .771 .935 r
.40318 .39372 .41088 .40108 .42383 .3967 .41616 .38935 Mtetra
.651 .772 .937 r
.41616 .38935 .42383 .3967 .43683 .39232 .42921 .38502 Mtetra
.653 .775 .938 r
.42921 .38502 .43683 .39232 .4499 .38794 .44232 .38062 Mtetra
.662 .778 .935 r
.44232 .38062 .4499 .38794 .46303 .38364 .4555 .37593 Mtetra
.671 .771 .925 r
.4555 .37593 .46303 .38364 .47623 .37935 .46875 .37093 Mtetra
.625 .737 .928 r
.46875 .37093 .47623 .37935 .48949 .37489 .48204 .36733 Mtetra
.511 .717 .965 r
.48204 .36733 .48949 .37489 .50282 .36903 .49538 .3662 Mtetra
.578 .891 .989 r
.49538 .3662 .50282 .36903 .51621 .36193 .50883 .36176 Mtetra
.596 .946 .916 r
.50883 .36176 .51621 .36193 .52966 .35855 .52235 .35508 Mtetra
.423 .807 .99 r
.52235 .35508 .52966 .35855 .54319 .35828 .53593 .35322 Mtetra
.343 .716 .985 r
.53593 .35322 .54319 .35828 .55683 .35809 .54962 .35344 Mtetra
.379 .749 .991 r
.54962 .35344 .55683 .35809 .57058 .35843 .56342 .35289 Mtetra
.562 .809 .991 r
.56342 .35289 .57058 .35843 .58446 .35915 .57727 .34989 Mtetra
.724 .759 .881 r
.57727 .34989 .58446 .35915 .59836 .35631 .59112 .34249 Mtetra
.747 .684 .79 r
.59112 .34249 .59836 .35631 .61217 .34692 .60493 .33171 Mtetra
.734 .661 .778 r
.60493 .33171 .61217 .34692 .62591 .33432 .61877 .32116 Mtetra
.71 .68 .819 r
.61877 .32116 .62591 .33432 .63972 .32376 .63271 .31316 Mtetra
.683 .718 .876 r
.63271 .31316 .63972 .32376 .65368 .31652 .64677 .30721 Mtetra
.663 .742 .908 r
.64677 .30721 .65368 .31652 .66778 .31108 .66093 .30213 Mtetra
.657 .75 .918 r
.66093 .30213 .66778 .31108 .68197 .30618 .67517 .29725 Mtetra
.656 .751 .92 r
.67517 .29725 .68197 .30618 .69624 .30134 .68949 .29238 Mtetra
.68949 .29238 .69624 .30134 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25761 Mtetra
.13623 .47016 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.21985 .44157 .2281 .44921 .24023 .44508 .23202 .43742 Mtetra
.655 .751 .92 r
.23202 .43742 .24023 .44508 .25242 .44099 .24425 .43324 Mtetra
.652 .749 .921 r
.24425 .43324 .25242 .44099 .26465 .43713 .25653 .42915 Mtetra
.638 .74 .922 r
.25653 .42915 .26465 .43713 .27686 .4343 .26883 .42544 Mtetra
.593 .702 .919 r
.26883 .42544 .27686 .4343 .28896 .43387 .2811 .423 Mtetra
.513 .62 .895 r
.2811 .423 .28896 .43387 .30096 .43611 .29328 .42279 Mtetra
.462 .544 .854 r
.29328 .42279 .30096 .43611 .3131 .43783 .30543 .42432 Mtetra
.516 .569 .848 r
.30543 .42432 .3131 .43783 .32565 .4346 .31777 .42448 Mtetra
.646 .695 .881 r
.31777 .42448 .32565 .4346 .33854 .42645 .33046 .42038 Mtetra
.752 .825 .908 r
.33046 .42038 .33854 .42645 .35152 .41731 .34341 .41274 Mtetra
.766 .87 .925 r
.34341 .41274 .35152 .41731 .36445 .4097 .35642 .40469 Mtetra
.728 .855 .942 r
.35642 .40469 .36445 .4097 .37734 .40359 .36939 .39798 Mtetra
.687 .832 .952 r
.36939 .39798 .37734 .40359 .39024 .39839 .38235 .39251 Mtetra
.67 .82 .956 r
.38235 .39251 .39024 .39839 .40318 .39372 .39535 .38754 Mtetra
.658 .809 .956 r
.39535 .38754 .40318 .39372 .41616 .38935 .40839 .38287 Mtetra
.655 .801 .952 r
.40839 .38287 .41616 .38935 .42921 .38502 .42149 .37829 Mtetra
.643 .791 .953 r
.42149 .37829 .42921 .38502 .44232 .38062 .43464 .37406 Mtetra
.644 .797 .956 r
.43464 .37406 .44232 .38062 .4555 .37593 .44786 .36973 Mtetra
.639 .808 .964 r
.44786 .36973 .4555 .37593 .46875 .37093 .46114 .36545 Mtetra
.623 .827 .979 r
.46114 .36545 .46875 .37093 .48204 .36733 .47449 .36134 Mtetra
.371 .7 .984 r
.47449 .36134 .48204 .36733 .49538 .3662 .48786 .36171 Mtetra
.577 .024 0 r
.48786 .36171 .49538 .3662 .50883 .36176 .50124 .37362 Mtetra
0 0 0 r
.50124 .37362 .50883 .36176 .52235 .35508 .51491 .36312 Mtetra
.51491 .36312 .52235 .35508 .53593 .35322 .5286 .35463 Mtetra
.367 .834 .788 r
.5286 .35463 .53593 .35322 .54962 .35344 .54234 .34938 Mtetra
.672 .893 .977 r
.54234 .34938 .54962 .35344 .56342 .35289 .55613 .34346 Mtetra
.727 .757 .876 r
.55613 .34346 .56342 .35289 .57727 .34989 .56996 .33586 Mtetra
.727 .673 .797 r
.56996 .33586 .57727 .34989 .59112 .34249 .5838 .32641 Mtetra
.711 .64 .777 r
.5838 .32641 .59112 .34249 .60493 .33171 .59768 .31712 Mtetra
.697 .654 .803 r
.59768 .31712 .60493 .33171 .61877 .32116 .61162 .30935 Mtetra
.679 .693 .855 r
.61162 .30935 .61877 .32116 .63271 .31316 .62567 .30329 Mtetra
.666 .73 .898 r
.62567 .30329 .63271 .31316 .64677 .30721 .6398 .29806 Mtetra
.657 .746 .915 r
.6398 .29806 .64677 .30721 .66093 .30213 .65402 .29315 Mtetra
.657 .751 .92 r
.65402 .29315 .66093 .30213 .67517 .29725 .66831 .28824 Mtetra
.655 .751 .92 r
.66831 .28824 .67517 .29725 .68949 .29238 .68268 .28334 Mtetra
.656 .752 .92 r
.68268 .28334 .68949 .29238 .70388 .28749 .69712 .27839 Mtetra
.656 .751 .92 r
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27344 Mtetra
.656 .752 .92 r
.71163 .27344 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.656 .751 .92 r
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.656 .752 .92 r
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.656 .751 .92 r
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25761 .78532 .24824 Mtetra
.656 .752 .92 r
.12769 .46272 .13623 .47016 .14801 .46614 .1395 .45865 Mtetra
.656 .751 .92 r
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43742 .22374 .42968 Mtetra
.22374 .42968 .23202 .43742 .24425 .43324 .236 .42547 Mtetra
.655 .751 .92 r
.236 .42547 .24425 .43324 .25653 .42915 .24832 .42125 Mtetra
.651 .748 .92 r
.24832 .42125 .25653 .42915 .26883 .42544 .26069 .41714 Mtetra
.636 .733 .918 r
.26069 .41714 .26883 .42544 .2811 .423 .27308 .41345 Mtetra
.596 .688 .907 r
.27308 .41345 .2811 .423 .29328 .42279 .28544 .41092 Mtetra
.538 .612 .875 r
.28544 .41092 .29328 .42279 .30543 .42432 .29776 .41019 Mtetra
.502 .552 .84 r
.29776 .41019 .30543 .42432 .31777 .42448 .31007 .41077 Mtetra
.531 .576 .845 r
.31007 .41077 .31777 .42448 .33046 .42038 .32254 .41042 Mtetra
.623 .693 .895 r
.32254 .41042 .33046 .42038 .34341 .41274 .33527 .40706 Mtetra
.719 .835 .936 r
.33527 .40706 .34341 .41274 .35642 .40469 .34824 .40062 Mtetra
.746 .886 .943 r
.34824 .40062 .35642 .40469 .36939 .39798 .36131 .39317 Mtetra
.728 .864 .945 r
.36131 .39317 .36939 .39798 .38235 .39251 .37439 .38635 Mtetra
.69 .818 .944 r
.37439 .38635 .38235 .39251 .39535 .38754 .38746 .38078 Mtetra
.667 .797 .944 r
.38746 .38078 .39535 .38754 .40839 .38287 .40055 .37588 Mtetra
.648 .786 .947 r
.40055 .37588 .40839 .38287 .42149 .37829 .41369 .37151 Mtetra
.651 .793 .95 r
.41369 .37151 .42149 .37829 .43464 .37406 .42689 .367 Mtetra
.633 .781 .952 r
.42689 .367 .43464 .37406 .44786 .36973 .44015 .36299 Mtetra
.597 .779 .967 r
.44015 .36299 .44786 .36973 .46114 .36545 .45346 .35976 Mtetra
.331 .69 .98 r
.45346 .35976 .46114 .36545 .47449 .36134 .46677 .36043 Mtetra
.252 0 0 r
.46677 .36043 .47449 .36134 .48786 .36171 .48015 .36393 Mtetra
.933 .969 .736 r
.48015 .36393 .48786 .36171 .50124 .37362 .49391 .34322 Mtetra
.546 .442 .687 r
.49391 .34322 .50124 .37362 .51491 .36312 .50749 .34256 Mtetra
.601 .536 .754 r
.50749 .34256 .51491 .36312 .5286 .35463 .52117 .33907 Mtetra
.661 .622 .8 r
.52117 .33907 .5286 .35463 .54234 .34938 .53492 .33308 Mtetra
.67 .618 .788 r
.53492 .33308 .54234 .34938 .55613 .34346 .54873 .32636 Mtetra
.68 .614 .775 r
.54873 .32636 .55613 .34346 .56996 .33586 .56257 .31873 Mtetra
.674 .611 .777 r
.56257 .31873 .56996 .33586 .5838 .32641 .57647 .31147 Mtetra
.676 .64 .806 r
.57647 .31147 .5838 .32641 .59768 .31712 .59043 .30481 Mtetra
.668 .679 .851 r
.59043 .30481 .59768 .31712 .61162 .30935 .60447 .29915 Mtetra
.664 .723 .893 r
.60447 .29915 .61162 .30935 .62567 .30329 .61858 .29395 Mtetra
.657 .742 .912 r
.61858 .29395 .62567 .30329 .6398 .29806 .63278 .28902 Mtetra
.657 .751 .919 r
.63278 .28902 .6398 .29806 .65402 .29315 .64705 .28408 Mtetra
.655 .75 .92 r
.64705 .28408 .65402 .29315 .66831 .28824 .66139 .27916 Mtetra
.656 .752 .92 r
.66139 .27916 .66831 .28824 .68268 .28334 .6758 .27419 Mtetra
.655 .751 .92 r
.6758 .27419 .68268 .28334 .69712 .27839 .69029 .26922 Mtetra
.656 .752 .92 r
.69029 .26922 .69712 .27839 .71163 .27344 .70486 .2642 Mtetra
.655 .751 .92 r
.70486 .2642 .71163 .27344 .72622 .26844 .7195 .25917 Mtetra
.656 .752 .92 r
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .2541 Mtetra
.656 .751 .92 r
.73421 .2541 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.656 .752 .92 r
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.656 .751 .92 r
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.21539 .42188 .22374 .42968 .236 .42547 .22768 .41762 Mtetra
.22768 .41762 .236 .42547 .24832 .42125 .24004 .41335 Mtetra
.655 .751 .92 r
.24004 .41335 .24832 .42125 .26069 .41714 .25245 .40908 Mtetra
.652 .746 .919 r
.25245 .40908 .26069 .41714 .27308 .41345 .26491 .4049 Mtetra
.64 .731 .914 r
.26491 .4049 .27308 .41345 .28544 .41092 .2774 .40105 Mtetra
.612 .689 .898 r
.2774 .40105 .28544 .41092 .29776 .41019 .2899 .39802 Mtetra
.572 .624 .865 r
.2899 .39802 .29776 .41019 .31007 .41077 .30238 .39627 Mtetra
.541 .568 .832 r
.30238 .39627 .31007 .41077 .32254 .41042 .31486 .39565 Mtetra
.539 .564 .829 r
.31486 .39565 .32254 .41042 .33527 .40706 .32743 .39509 Mtetra
.577 .633 .87 r
.32743 .39509 .33527 .40706 .34824 .40062 .34017 .39312 Mtetra
.642 .767 .939 r
.34017 .39312 .34824 .40062 .36131 .39317 .35311 .38902 Mtetra
.683 .878 .971 r
.35311 .38902 .36131 .39317 .37439 .38635 .36619 .38329 Mtetra
.688 .911 .972 r
.36619 .38329 .37439 .38635 .38746 .38078 .37935 .37707 Mtetra
.68 .892 .975 r
.37935 .37707 .38746 .38078 .40055 .37588 .39254 .37122 Mtetra
.658 .861 .977 r
.39254 .37122 .40055 .37588 .41369 .37151 .40576 .36612 Mtetra
.627 .831 .979 r
.40576 .36612 .41369 .37151 .42689 .367 .419 .36189 Mtetra
.569 .821 .993 r
.419 .36189 .42689 .367 .44015 .36299 .43229 .3587 Mtetra
.454 .799 .998 r
.43229 .3587 .44015 .36299 .45346 .35976 .44561 .3569 Mtetra
.48 .851 .987 r
.44561 .3569 .45346 .35976 .46677 .36043 .45906 .35387 Mtetra
.812 .836 .868 r
.45906 .35387 .46677 .36043 .48015 .36393 .47271 .34275 Mtetra
.716 .595 .719 r
.47271 .34275 .48015 .36393 .49391 .34322 .4864 .33038 Mtetra
.674 .668 .836 r
.4864 .33038 .49391 .34322 .50749 .34256 .50003 .32441 Mtetra
.617 .569 .778 r
.50003 .32441 .50749 .34256 .52117 .33907 .51371 .32027 Mtetra
.623 .566 .77 r
.51371 .32027 .52117 .33907 .53492 .33308 .52747 .31573 Mtetra
.636 .589 .785 r
.52747 .31573 .53492 .33308 .54873 .32636 .5413 .31067 Mtetra
.648 .616 .804 r
.5413 .31067 .54873 .32636 .56257 .31873 .55519 .3053 Mtetra
.656 .654 .836 r
.55519 .3053 .56257 .31873 .57647 .31147 .56915 .29998 Mtetra
.659 .693 .87 r
.56915 .29998 .57647 .31147 .59043 .30481 .58317 .29481 Mtetra
.658 .726 .899 r
.58317 .29481 .59043 .30481 .60447 .29915 .59727 .2898 Mtetra
.657 .742 .913 r
.59727 .2898 .60447 .29915 .61858 .29395 .61144 .28485 Mtetra
.656 .75 .919 r
.61144 .28485 .61858 .29395 .63278 .28902 .62569 .27992 Mtetra
.656 .751 .92 r
.62569 .27992 .63278 .28902 .64705 .28408 .64001 .27496 Mtetra
.656 .752 .92 r
.64001 .27496 .64705 .28408 .66139 .27916 .6544 .26998 Mtetra
.656 .751 .92 r
.6544 .26998 .66139 .27916 .6758 .27419 .66887 .26498 Mtetra
.656 .752 .92 r
.66887 .26498 .6758 .27419 .69029 .26922 .68341 .25995 Mtetra
.656 .751 .92 r
.68341 .25995 .69029 .26922 .70486 .2642 .69802 .25489 Mtetra
.656 .752 .92 r
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.656 .751 .92 r
.71271 .24981 .7195 .25917 .73421 .2541 .72748 .2447 Mtetra
.72748 .2447 .73421 .2541 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Mtetra
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Mtetra
.23168 .40541 .24004 .41335 .25245 .40908 .24412 .40108 Mtetra
.655 .751 .92 r
.24412 .40108 .25245 .40908 .26491 .4049 .25663 .39674 Mtetra
.653 .747 .919 r
.25663 .39674 .26491 .4049 .2774 .40105 .26919 .39245 Mtetra
.647 .734 .913 r
.26919 .39245 .2774 .40105 .2899 .39802 .2818 .38833 Mtetra
.632 .704 .898 r
.2818 .38833 .2899 .39802 .30238 .39627 .29443 .38465 Mtetra
.608 .653 .869 r
.29443 .38465 .30238 .39627 .31486 .39565 .30709 .38167 Mtetra
.584 .601 .835 r
.30709 .38167 .31486 .39565 .32743 .39509 .31976 .37947 Mtetra
.57 .57 .813 r
.31976 .37947 .32743 .39509 .34017 .39312 .33249 .37778 Mtetra
.572 .575 .818 r
.33249 .37778 .34017 .39312 .35311 .38902 .3453 .37601 Mtetra
.59 .623 .852 r
.3453 .37601 .35311 .38902 .36619 .38329 .35824 .37356 Mtetra
.618 .704 .906 r
.35824 .37356 .36619 .38329 .37935 .37707 .37129 .37016 Mtetra
.638 .788 .954 r
.37129 .37016 .37935 .37707 .39254 .37122 .38446 .36597 Mtetra
.642 .84 .976 r
.38446 .36597 .39254 .37122 .40576 .36612 .39771 .36134 Mtetra
.642 .856 .981 r
.39771 .36134 .40576 .36612 .419 .36189 .41103 .35655 Mtetra
.663 .845 .97 r
.41103 .35655 .419 .36189 .43229 .3587 .42443 .35137 Mtetra
.705 .799 .923 r
.42443 .35137 .43229 .3587 .44561 .3569 .43792 .34507 Mtetra
.728 .705 .829 r
.43792 .34507 .44561 .3569 .45906 .35387 .45151 .33658 Mtetra
.708 .624 .761 r
.45151 .33658 .45906 .35387 .47271 .34275 .46516 .32697 Mtetra
.679 .628 .791 r
.46516 .32697 .47271 .34275 .4864 .33038 .4788 .31991 Mtetra
.67 .714 .882 r
.4788 .31991 .4864 .33038 .50003 .32441 .49246 .31453 Mtetra
.655 .723 .899 r
.49246 .31453 .50003 .32441 .51371 .32027 .50619 .30976 Mtetra
.649 .707 .89 r
.50619 .30976 .51371 .32027 .52747 .31573 .51998 .30514 Mtetra
.652 .708 .888 r
.51998 .30514 .52747 .31573 .5413 .31067 .53385 .30036 Mtetra
.655 .716 .893 r
.53385 .30036 .5413 .31067 .55519 .3053 .54779 .29547 Mtetra
.657 .729 .903 r
.54779 .29547 .55519 .3053 .56915 .29998 .56179 .29054 Mtetra
.656 .74 .911 r
.56179 .29054 .56915 .29998 .58317 .29481 .57587 .28561 Mtetra
.656 .747 .917 r
.57587 .28561 .58317 .29481 .59727 .2898 .59002 .28068 Mtetra
.656 .75 .919 r
.59002 .28068 .59727 .2898 .61144 .28485 .60424 .27573 Mtetra
.656 .751 .92 r
.60424 .27573 .61144 .28485 .62569 .27992 .61853 .27075 Mtetra
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Mtetra
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .2248 Mtetra
.75056 .2248 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24412 .40108 .23573 .39302 Mtetra
.23573 .39302 .24412 .40108 .25663 .39674 .24827 .38863 Mtetra
.24827 .38863 .25663 .39674 .26919 .39245 .26087 .38422 Mtetra
.655 .749 .919 r
.26087 .38422 .26919 .39245 .2818 .38833 .27353 .37982 Mtetra
.652 .742 .915 r
.27353 .37982 .2818 .38833 .29443 .38465 .28625 .37547 Mtetra
.646 .724 .905 r
.28625 .37547 .29443 .38465 .30709 .38167 .29902 .37127 Mtetra
.636 .693 .886 r
.29902 .37127 .30709 .38167 .31976 .37947 .31183 .36734 Mtetra
.624 .653 .859 r
.31183 .36734 .31976 .37947 .33249 .37778 .32469 .36372 Mtetra
.613 .616 .83 r
.32469 .36372 .33249 .37778 .3453 .37601 .3376 .36034 Mtetra
.607 .59 .808 r
.3376 .36034 .3453 .37601 .35824 .37356 .35058 .35704 Mtetra
.608 .58 .797 r
.35058 .35704 .35824 .37356 .37129 .37016 .36365 .35361 Mtetra
.615 .584 .796 r
.36365 .35361 .37129 .37016 .38446 .36597 .3768 .34983 Mtetra
.628 .596 .799 r
.3768 .34983 .38446 .36597 .39771 .36134 .39004 .34546 Mtetra
.643 .608 .799 r
.39004 .34546 .39771 .36134 .41103 .35655 .40339 .34037 Mtetra
.656 .611 .792 r
.40339 .34037 .41103 .35655 .42443 .35137 .41682 .33454 Mtetra
.663 .607 .782 r
.41682 .33454 .42443 .35137 .43792 .34507 .43032 .32809 Mtetra
.662 .605 .781 r
.43032 .32809 .43792 .34507 .45151 .33658 .44387 .32166 Mtetra
.659 .631 .81 r
.44387 .32166 .45151 .33658 .46516 .32697 .45747 .31591 Mtetra
.667 .701 .872 r
.45747 .31591 .46516 .32697 .4788 .31991 .47111 .31055 Mtetra
.658 .738 .909 r
.47111 .31055 .4788 .31991 .49246 .31453 .48482 .30565 Mtetra
.653 .749 .92 r
.48482 .30565 .49246 .31453 .50619 .30976 .49859 .30092 Mtetra
.654 .752 .922 r
.49859 .30092 .50619 .30976 .51998 .30514 .51243 .29613 Mtetra
.656 .749 .919 r
.51243 .29613 .51998 .30514 .53385 .30036 .52634 .29125 Mtetra
.656 .748 .918 r
.52634 .29125 .53385 .30036 .54779 .29547 .54032 .28635 Mtetra
.656 .749 .918 r
.54032 .28635 .54779 .29547 .56179 .29054 .55437 .28144 Mtetra
.656 .75 .92 r
.55437 .28144 .56179 .29054 .57587 .28561 .5685 .27649 Mtetra
.656 .751 .92 r
.5685 .27649 .57587 .28561 .59002 .28068 .5827 .27152 Mtetra
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Mtetra
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .2248 .7438 .2151 Mtetra
.7438 .2151 .75056 .2248 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Mtetra
.23983 .38046 .24827 .38863 .26087 .38422 .25247 .37601 Mtetra
.25247 .37601 .26087 .38422 .27353 .37982 .26517 .37154 Mtetra
.655 .75 .92 r
.26517 .37154 .27353 .37982 .28625 .37547 .27793 .36705 Mtetra
.655 .748 .918 r
.27793 .36705 .28625 .37547 .29902 .37127 .29075 .36256 Mtetra
.654 .741 .913 r
.29075 .36256 .29902 .37127 .31183 .36734 .30364 .35807 Mtetra
.651 .727 .904 r
.30364 .35807 .31183 .36734 .32469 .36372 .31658 .35364 Mtetra
.646 .707 .891 r
.31658 .35364 .32469 .36372 .3376 .36034 .32958 .3493 Mtetra
.642 .686 .876 r
.32958 .3493 .3376 .36034 .35058 .35704 .34264 .34501 Mtetra
.641 .666 .859 r
.34264 .34501 .35058 .35704 .36365 .35361 .35577 .34068 Mtetra
.64 .65 .844 r
.35577 .34068 .36365 .35361 .3768 .34983 .36897 .33623 Mtetra
.642 .641 .834 r
.36897 .33623 .3768 .34983 .39004 .34546 .38225 .33162 Mtetra
.644 .639 .83 r
.38225 .33162 .39004 .34546 .40339 .34037 .3956 .32682 Mtetra
.648 .646 .834 r
.3956 .32682 .40339 .34037 .41682 .33454 .40901 .32187 Mtetra
.653 .664 .848 r
.40901 .32187 .41682 .33454 .43032 .32809 .4225 .31686 Mtetra
.659 .695 .872 r
.4225 .31686 .43032 .32809 .44387 .32166 .43605 .31178 Mtetra
.664 .727 .897 r
.43605 .31178 .44387 .32166 .45747 .31591 .44967 .30665 Mtetra
.658 .741 .912 r
.44967 .30665 .45747 .31591 .47111 .31055 .46335 .30176 Mtetra
.657 .754 .922 r
.46335 .30176 .47111 .31055 .48482 .30565 .4771 .29689 Mtetra
.655 .755 .924 r
.4771 .29689 .48482 .30565 .49859 .30092 .49091 .29205 Mtetra
.656 .754 .922 r
.49091 .29205 .49859 .30092 .51243 .29613 .5048 .28716 Mtetra
.657 .753 .921 r
.5048 .28716 .51243 .29613 .52634 .29125 .51876 .28221 Mtetra
.656 .752 .92 r
.51876 .28221 .52634 .29125 .54032 .28635 .53279 .27726 Mtetra
.53279 .27726 .54032 .28635 .55437 .28144 .54689 .27228 Mtetra
.656 .751 .92 r
.54689 .27228 .55437 .28144 .5685 .27649 .56106 .26729 Mtetra
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Mtetra
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Mtetra
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Mtetra
.25673 .36322 .26517 .37154 .27793 .36705 .26953 .35868 Mtetra
.26953 .35868 .27793 .36705 .29075 .36256 .28239 .35413 Mtetra
.655 .751 .92 r
.28239 .35413 .29075 .36256 .30364 .35807 .29531 .34956 Mtetra
.656 .75 .919 r
.29531 .34956 .30364 .35807 .31658 .35364 .3083 .34496 Mtetra
.656 .747 .916 r
.3083 .34496 .31658 .35364 .32958 .3493 .32136 .34031 Mtetra
.656 .74 .911 r
.32136 .34031 .32958 .3493 .34264 .34501 .33447 .33564 Mtetra
.655 .731 .905 r
.33447 .33564 .34264 .34501 .35577 .34068 .34766 .33098 Mtetra
.654 .724 .9 r
.34766 .33098 .35577 .34068 .36897 .33623 .3609 .32632 Mtetra
.654 .72 .897 r
.3609 .32632 .36897 .33623 .38225 .33162 .37421 .32163 Mtetra
.655 .719 .896 r
.37421 .32163 .38225 .33162 .3956 .32682 .3876 .31687 Mtetra
.656 .722 .897 r
.3876 .31687 .3956 .32682 .40901 .32187 .40105 .31205 Mtetra
.657 .726 .9 r
.40105 .31205 .40901 .32187 .4225 .31686 .41456 .30718 Mtetra
.656 .73 .904 r
.41456 .30718 .4225 .31686 .43605 .31178 .42815 .30235 Mtetra
.653 .736 .911 r
.42815 .30235 .43605 .31178 .44967 .30665 .4418 .29759 Mtetra
.655 .747 .918 r
.4418 .29759 .44967 .30665 .46335 .30176 .45552 .29275 Mtetra
.654 .749 .92 r
.45552 .29275 .46335 .30176 .4771 .29689 .46931 .28793 Mtetra
.657 .753 .921 r
.46931 .28793 .4771 .29689 .49091 .29205 .48317 .28299 Mtetra
.657 .752 .92 r
.48317 .28299 .49091 .29205 .5048 .28716 .4971 .278 Mtetra
.656 .75 .919 r
.4971 .278 .5048 .28716 .51876 .28221 .51111 .27303 Mtetra
.655 .75 .92 r
.51111 .27303 .51876 .28221 .53279 .27726 .52518 .26805 Mtetra
.656 .751 .92 r
.52518 .26805 .53279 .27726 .54689 .27228 .53933 .26304 Mtetra
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Mtetra
.26105 .35025 .26953 .35868 .28239 .35413 .27395 .34565 Mtetra
.27395 .34565 .28239 .35413 .29531 .34956 .28691 .34101 Mtetra
.28691 .34101 .29531 .34956 .3083 .34496 .29994 .33637 Mtetra
.655 .75 .92 r
.29994 .33637 .3083 .34496 .32136 .34031 .31303 .33173 Mtetra
.655 .752 .921 r
.31303 .33173 .32136 .34031 .33447 .33564 .32618 .32708 Mtetra
.655 .753 .922 r
.32618 .32708 .33447 .33564 .34766 .33098 .3394 .32237 Mtetra
.656 .753 .922 r
.3394 .32237 .34766 .33098 .3609 .32632 .35269 .31762 Mtetra
.656 .752 .921 r
.35269 .31762 .3609 .32632 .37421 .32163 .36605 .31284 Mtetra
.656 .751 .92 r
.36605 .31284 .37421 .32163 .3876 .31687 .37947 .30806 Mtetra
.655 .751 .921 r
.37947 .30806 .3876 .31687 .40105 .31205 .39296 .30327 Mtetra
.654 .753 .922 r
.39296 .30327 .40105 .31205 .41456 .30718 .40652 .29848 Mtetra
.655 .757 .924 r
.40652 .29848 .41456 .30718 .42815 .30235 .42014 .29363 Mtetra
.657 .758 .924 r
.42014 .29363 .42815 .30235 .4418 .29759 .43384 .28869 Mtetra
.656 .754 .922 r
.43384 .28869 .4418 .29759 .45552 .29275 .44761 .28377 Mtetra
.658 .754 .921 r
.44761 .28377 .45552 .29275 .46931 .28793 .46145 .27875 Mtetra
.656 .749 .918 r
.46145 .27875 .46931 .28793 .48317 .28299 .47535 .27377 Mtetra
.655 .749 .919 r
.47535 .27377 .48317 .28299 .4971 .278 .48933 .26883 Mtetra
.655 .752 .921 r
.48933 .26883 .4971 .278 .51111 .27303 .50338 .26383 Mtetra
.656 .752 .921 r
.50338 .26383 .51111 .27303 .52518 .26805 .5175 .25879 Mtetra
.656 .752 .92 r
.5175 .25879 .52518 .26805 .53933 .26304 .5317 .25372 Mtetra
.656 .751 .92 r
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Mtetra
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .3371 Mtetra
.26543 .3371 .27395 .34565 .28691 .34101 .27843 .33244 Mtetra
.656 .752 .921 r
.27843 .33244 .28691 .34101 .29994 .33637 .2915 .32775 Mtetra
.657 .752 .92 r
.2915 .32775 .29994 .33637 .31303 .33173 .30463 .32301 Mtetra
.657 .751 .919 r
.30463 .32301 .31303 .33173 .32618 .32708 .31783 .31824 Mtetra
.656 .749 .918 r
.31783 .31824 .32618 .32708 .3394 .32237 .33109 .31347 Mtetra
.655 .748 .918 r
.33109 .31347 .3394 .32237 .35269 .31762 .34442 .3087 Mtetra
.34442 .3087 .35269 .31762 .36605 .31284 .35781 .30391 Mtetra
.656 .749 .919 r
.35781 .30391 .36605 .31284 .37947 .30806 .37128 .29908 Mtetra
.656 .75 .919 r
.37128 .29908 .37947 .30806 .39296 .30327 .38481 .2942 Mtetra
.657 .749 .918 r
.38481 .2942 .39296 .30327 .40652 .29848 .39841 .28929 Mtetra
.656 .746 .916 r
.39841 .28929 .40652 .29848 .42014 .29363 .41208 .28437 Mtetra
.655 .745 .916 r
.41208 .28437 .42014 .29363 .43384 .28869 .42582 .27946 Mtetra
.656 .748 .918 r
.42582 .27946 .43384 .28869 .44761 .28377 .43963 .27451 Mtetra
.654 .747 .919 r
.43963 .27451 .44761 .28377 .46145 .27875 .45351 .2696 Mtetra
.655 .752 .921 r
.45351 .2696 .46145 .27875 .47535 .27377 .46746 .26462 Mtetra
.656 .753 .921 r
.46746 .26462 .47535 .27377 .48933 .26883 .48148 .25957 Mtetra
.656 .752 .92 r
.48148 .25957 .48933 .26883 .50338 .26383 .49558 .25449 Mtetra
.656 .751 .92 r
.49558 .25449 .50338 .26383 .5175 .25879 .50975 .24941 Mtetra
.50975 .24941 .5175 .25879 .5317 .25372 .52399 .2443 Mtetra
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Mtetra
.24386 .33315 .25249 .34174 .26543 .3371 .25683 .32846 Mtetra
.25683 .32846 .26543 .3371 .27843 .33244 .26987 .32375 Mtetra
.26987 .32375 .27843 .33244 .2915 .32775 .28298 .31902 Mtetra
.655 .751 .92 r
.28298 .31902 .2915 .32775 .30463 .32301 .29614 .31428 Mtetra
.655 .752 .921 r
.29614 .31428 .30463 .32301 .31783 .31824 .30938 .30953 Mtetra
.656 .754 .922 r
.30938 .30953 .31783 .31824 .33109 .31347 .32268 .30473 Mtetra
.32268 .30473 .33109 .31347 .34442 .3087 .33605 .2999 Mtetra
.33605 .2999 .34442 .3087 .35781 .30391 .34949 .29503 Mtetra
.656 .753 .921 r
.34949 .29503 .35781 .30391 .37128 .29908 .363 .29015 Mtetra
.655 .753 .921 r
.363 .29015 .37128 .29908 .38481 .2942 .37657 .28526 Mtetra
.655 .753 .922 r
.37657 .28526 .38481 .2942 .39841 .28929 .39021 .28036 Mtetra
.655 .755 .923 r
.39021 .28036 .39841 .28929 .41208 .28437 .40393 .27542 Mtetra
.656 .756 .923 r
.40393 .27542 .41208 .28437 .42582 .27946 .41771 .27043 Mtetra
.656 .755 .923 r
.41771 .27043 .42582 .27946 .43963 .27451 .43157 .26543 Mtetra
.657 .755 .922 r
.43157 .26543 .43963 .27451 .45351 .2696 .4455 .26035 Mtetra
.657 .752 .92 r
.4455 .26035 .45351 .2696 .46746 .26462 .45949 .25526 Mtetra
.655 .75 .919 r
.45949 .25526 .46746 .26462 .48148 .25957 .47356 .25019 Mtetra
.655 .751 .92 r
.47356 .25019 .48148 .25957 .49558 .25449 .48771 .24509 Mtetra
.656 .752 .921 r
.48771 .24509 .49558 .25449 .50975 .24941 .50192 .23996 Mtetra
.656 .752 .92 r
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Mtetra
.656 .751 .92 r
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Mtetra
.23514 .32448 .24386 .33315 .25683 .32846 .24815 .31975 Mtetra
.24815 .31975 .25683 .32846 .26987 .32375 .26123 .31501 Mtetra
.656 .752 .921 r
.26123 .31501 .26987 .32375 .28298 .31902 .27438 .31023 Mtetra
.656 .752 .92 r
.27438 .31023 .28298 .31902 .29614 .31428 .28759 .30541 Mtetra
.657 .751 .919 r
.28759 .30541 .29614 .31428 .30938 .30953 .30087 .30056 Mtetra
.656 .749 .919 r
.30087 .30056 .30938 .30953 .32268 .30473 .31421 .2957 Mtetra
.655 .749 .919 r
.31421 .2957 .32268 .30473 .33605 .2999 .32762 .29084 Mtetra
.32762 .29084 .33605 .2999 .34949 .29503 .3411 .28595 Mtetra
.656 .75 .919 r
.3411 .28595 .34949 .29503 .363 .29015 .35465 .28104 Mtetra
.35465 .28104 .363 .29015 .37657 .28526 .36826 .27608 Mtetra
.36826 .27608 .37657 .28526 .39021 .28036 .38195 .27108 Mtetra
.656 .749 .918 r
.38195 .27108 .39021 .28036 .40393 .27542 .39571 .26607 Mtetra
.655 .748 .918 r
.39571 .26607 .40393 .27542 .41771 .27043 .40954 .26105 Mtetra
.656 .748 .918 r
.40954 .26105 .41771 .27043 .43157 .26543 .42344 .256 Mtetra
.654 .748 .918 r
.42344 .256 .43157 .26543 .4455 .26035 .43741 .25097 Mtetra
.655 .75 .92 r
.43741 .25097 .4455 .26035 .45949 .25526 .45145 .24589 Mtetra
.656 .752 .921 r
.45145 .24589 .45949 .25526 .47356 .25019 .46557 .24076 Mtetra
.656 .752 .92 r
.46557 .24076 .47356 .25019 .48771 .24509 .47976 .23559 Mtetra
.656 .751 .92 r
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .2304 Mtetra
.49402 .2304 .50192 .23996 .51622 .2348 .50836 .2252 Mtetra
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24815 .31975 .2394 .31096 Mtetra
.2394 .31096 .24815 .31975 .26123 .31501 .25252 .30615 Mtetra
.25252 .30615 .26123 .31501 .27438 .31023 .2657 .30134 Mtetra
.655 .751 .92 r
.2657 .30134 .27438 .31023 .28759 .30541 .27895 .29651 Mtetra
.655 .752 .921 r
.27895 .29651 .28759 .30541 .30087 .30056 .29226 .29166 Mtetra
.656 .753 .922 r
.29226 .29166 .30087 .30056 .31421 .2957 .30564 .28678 Mtetra
.656 .754 .922 r
.30564 .28678 .31421 .2957 .32762 .29084 .3191 .28185 Mtetra
.656 .753 .921 r
.3191 .28185 .32762 .29084 .3411 .28595 .33262 .27689 Mtetra
.33262 .27689 .3411 .28595 .35465 .28104 .34621 .27192 Mtetra
.656 .752 .921 r
.34621 .27192 .35465 .28104 .36826 .27608 .35987 .26693 Mtetra
.655 .752 .921 r
.35987 .26693 .36826 .27608 .38195 .27108 .3736 .26193 Mtetra
.655 .754 .922 r
.3736 .26193 .38195 .27108 .39571 .26607 .3874 .25689 Mtetra
.656 .754 .922 r
.3874 .25689 .39571 .26607 .40954 .26105 .40128 .25181 Mtetra
.40128 .25181 .40954 .26105 .42344 .256 .41522 .24672 Mtetra
.657 .755 .922 r
.41522 .24672 .42344 .256 .43741 .25097 .42924 .24155 Mtetra
.657 .752 .921 r
.42924 .24155 .43741 .25097 .45145 .24589 .44333 .23637 Mtetra
.656 .751 .92 r
.44333 .23637 .45145 .24589 .46557 .24076 .45749 .2312 Mtetra
.655 .751 .92 r
.45749 .2312 .46557 .24076 .47976 .23559 .47173 .226 Mtetra
.656 .751 .92 r
.47173 .226 .47976 .23559 .49402 .2304 .48604 .22077 Mtetra
.656 .752 .92 r
.48604 .22077 .49402 .2304 .50836 .2252 .50043 .21551 Mtetra
.656 .751 .92 r
.50043 .21551 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .31169 Mtetra
.20445 .31169 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25252 .30615 .24371 .29725 Mtetra
.656 .752 .921 r
.24371 .29725 .25252 .30615 .2657 .30134 .25694 .29238 Mtetra
.656 .752 .92 r
.25694 .29238 .2657 .30134 .27895 .29651 .27023 .28748 Mtetra
.656 .751 .92 r
.27023 .28748 .27895 .29651 .29226 .29166 .28359 .28254 Mtetra
.656 .75 .919 r
.28359 .28254 .29226 .29166 .30564 .28678 .29701 .27759 Mtetra
.655 .749 .919 r
.29701 .27759 .30564 .28678 .3191 .28185 .31051 .27263 Mtetra
.655 .75 .919 r
.31051 .27263 .3191 .28185 .33262 .27689 .32407 .26766 Mtetra
.656 .75 .92 r
.32407 .26766 .33262 .27689 .34621 .27192 .3377 .26265 Mtetra
.656 .751 .92 r
.3377 .26265 .34621 .27192 .35987 .26693 .3514 .2576 Mtetra
.656 .751 .919 r
.3514 .2576 .35987 .26693 .3736 .26193 .36518 .25251 Mtetra
.656 .75 .919 r
.36518 .25251 .3736 .26193 .3874 .25689 .37902 .24741 Mtetra
.656 .749 .919 r
.37902 .24741 .3874 .25689 .40128 .25181 .39294 .24229 Mtetra
.39294 .24229 .40128 .25181 .41522 .24672 .40693 .23714 Mtetra
.655 .749 .919 r
.40693 .23714 .41522 .24672 .42924 .24155 .42099 .23199 Mtetra
.655 .75 .92 r
.42099 .23199 .42924 .24155 .44333 .23637 .43513 .22681 Mtetra
.656 .752 .921 r
.43513 .22681 .44333 .23637 .45749 .2312 .44934 .22158 Mtetra
.656 .752 .92 r
.44934 .22158 .45749 .2312 .47173 .226 .46363 .21631 Mtetra
.656 .751 .92 r
.46363 .21631 .47173 .226 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .21551 .49243 .20572 Mtetra
.49243 .20572 .50043 .21551 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .31169 .19545 .30283 Mtetra
.19545 .30283 .20445 .31169 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.22164 .29313 .23056 .30209 .24371 .29725 .23483 .28824 Mtetra
.23483 .28824 .24371 .29725 .25694 .29238 .2481 .28332 Mtetra
.655 .751 .92 r
.2481 .28332 .25694 .29238 .27023 .28748 .26142 .2784 Mtetra
.655 .752 .921 r
.26142 .2784 .27023 .28748 .28359 .28254 .27482 .27347 Mtetra
.656 .753 .922 r
.27482 .27347 .28359 .28254 .29701 .27759 .28828 .26849 Mtetra
.656 .754 .922 r
.28828 .26849 .29701 .27759 .31051 .27263 .30182 .26346 Mtetra
.656 .753 .921 r
.30182 .26346 .31051 .27263 .32407 .26766 .31543 .25841 Mtetra
.656 .752 .921 r
.31543 .25841 .32407 .26766 .3377 .26265 .3291 .25334 Mtetra
.3291 .25334 .3377 .26265 .3514 .2576 .34285 .24825 Mtetra
.655 .752 .921 r
.34285 .24825 .3514 .2576 .36518 .25251 .35667 .24315 Mtetra
.656 .753 .921 r
.35667 .24315 .36518 .25251 .37902 .24741 .37056 .23801 Mtetra
.656 .753 .922 r
.37056 .23801 .37902 .24741 .39294 .24229 .38452 .23284 Mtetra
.655 .753 .922 r
.38452 .23284 .39294 .24229 .40693 .23714 .39856 .22766 Mtetra
.657 .754 .922 r
.39856 .22766 .40693 .23714 .42099 .23199 .41267 .2224 Mtetra
.657 .753 .921 r
.41267 .2224 .42099 .23199 .43513 .22681 .42685 .21713 Mtetra
.656 .751 .92 r
.42685 .21713 .43513 .22681 .44934 .22158 .44111 .21184 Mtetra
.44111 .21184 .44934 .22158 .46363 .21631 .45544 .20654 Mtetra
.45544 .20654 .46363 .21631 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0oooo1@2X`>]80:O0j`030000002W`>/0Yl3[00l0Yl3[4@3oool00`000000oooo0?oo
o`0[0?ooo`00<03oool3000004/0oooo1@2X`N`50:S0jdL0Yl3[00<000000:O0j`2W`>/0402W`>/A
0?ooo`030000003oool0oooo02X0oooo000^0?ooo`<00000B`3oool30:O0k0D0Z<7/1@2W_n]60:O0
j`030000002W`>/0Yl3[0100Yl3[4@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0
oooo00<000000?ooo`3oool0AP3oool60:O0k080Z<7/202W_n]50:O0j`030000002W`>/0Yl3[0140
Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo2P2W`>`:0:NojdD0Yl3[
00<000000:O0j`2W`>/04@2W`>/B0?ooo`030000003oool0oooo02P0oooo000V0?ooo`<00000BP3o
ool40:O0j`D0Yl3/2P2W_n/50:S0jd@0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003o
ool0oooo02P0oooo000T0?ooo`800000B`3oool70:O0j`<0Yl3/1`2W_n/50:S1k0D0Z<3[@P2W`>/2
000001D0Yl3[403oool2000002T0oooo000Q0?ooo`<00000B`3oool:0:O0j`L0Yko[0`2W`N`50:S1
k080Z<3[0`2W_n/n0:O0j`<000000P2W`>/00`000000Yl3[0:O0j`0B0:O0ja80oooo00<000000?oo
o`3oool09P3oool001l0oooo0`0000190?ooo`X0Yl3[2@2W_n/60:O1k0@0Z<7/1P2W_n/20:O0j`<0
Yko[=@2W`>/3000000D0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo02H0
oooo000M0?ooo`800000B`3oool<0:O0j`D0Yko[2@2W`N`@0:Nojc40Yl3[0`0000090:O0j`030000
002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo0?ooo`0<0?ooo`800000103oool2000000<0oooo
1000000:0?ooo`005@3oool5000000<0oooo0P0000190?ooo`l0Yl3[2P2W`N`90:Noj`D0Z<3[1@2W
_n/^0:O0j`<000003@2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00/0oooo000G0?ooo`030000003o
ool0oooo00<0oooo0`0000140?oooa@0Yl3[1`2W`N`80:Noj`@0Z<7/1@2X`>/`0:O0j`8000004@2W
`>/00`000000Yl3[0:O0j`0C0:O0ja00oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00X0oooo000G0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000?`3oool50:O1k0D0Yl3[1@2W_n/:0:O0j`@0Yl7/202W_n/30:O1k0@0Z<7/
0P2X`>/_0:O0j`<000004`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0
0`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`090?ooo`00
3`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03/0oooo0P2W`>`50:O1k0X0Yko[2@2W`>/:0:Noj`H0Yl7/0`2X`N`80:O0j`<0Yko[
1@2W`>/50:NojaT0Yl3[0`00000G0:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000002P3oool001L0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0>03oool50:O0k0<0
Yl7/1`2W_n/:0:O0j`T0Yko[2P2W`N`50:Noj`@0Yl3[1P2W_n/20:O0j`P0Yko[5@2W`>/3000001/0
Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`8000002`3oool2000000X0oooo0P00000;0?ooo`00
5P3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?ooo`D0Yl3[
1@2W`>`70:Noj`X0Yl3[202W_n/90:O1k1d0Yko[1`2W`>/30:Noj`D0Yl3[0`2W_n/3000001l0Yl3[
00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0240oooo000L0?ooo`030000003o
ool0oooo00D0oooo0P00000`0?ooo`T0Yl3[2@2W_n/:0:O0j`P0Yko[0`2W`>`40:O1k0D0YkkZ1@2W
_n/50:S1j`@0Yko[1@2X`>/50:Noj`T0Yl3[1P2W_n/20:O0j`80YkoZ0`0000030:Noj`80Yl3[0P2W
_n/50:O0j`D0Yko[4@2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0803o
ool001`0oooo0P0000080?ooo`030000003oool0oooo02/0oooo302W`>/50:Noj`D0Yl7/102W`>/:
0:Noj`H0Yl3/0P2W`N`70:NnjP80Yko[0`2W`N`50:S1j`h0Z<3[1@2W`>/90:Noj`040:NojP000000
000000000080YkoZ2@2W_n/20:O0j`<0Z<3[1@2W_n/A0:O0j`030000002W`>/0Yl3[0180Yl3[4@3o
ool00`000000oooo0?ooo`0P0?ooo`00703oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02P0oooo3`2W`>/50:O0k0D0Yl7/2@2W_n/50:O0j`D0Yl3/2@2W_^X60:O1k080Z<7[0`2W_n/6
0:S0j`<0Yl7/1@2X`>/90:Noj`80YkgY0`0000050:NojPD0Z;gY102W_n/60:S0j`@0Yko[4P2W`>/0
0`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0S0?oooa@0Yl3[1@2W`>`20:O1k0P0Yko[2@2W`>/50:Ro
j`D0YkkZ102X`^`50:O1k0H0Yko[0`2X`>/60:O1k080Z<3[202W_n/20:Rji`<00000102W_NT50:Ri
iPT0Z;gY2P2X`>/B0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0N0?oo
o`006`3oool2000000`0oooo00<000000?ooo`3oool07`3ooolH0:O0j`@0Yl3/202W_n/30:O1k0@0
Yl3[1@2W_n/50:Roj`D0Yl7/102X`^`:0:Noj`T0Yl7/202W_n/20:Ngi08000000`2X^^L20:Nmj@<0
Z;7N1@2X^NH50:Vii0@0Z;gY1@2X_^X50:S0ja40Yl3[00<000000:O0j`2W`>/04`2W`>/@0?ooo`03
0000003oool0oooo01h0oooo000K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
6P3ooolM0:O0j`T0Yko[1P2W`N`20:O0j`L0Yko[0P2X_n/30:O0k0D0Yl7/102W_>T50:Noj`D0Z<7/
102W`N`50:O0k0D0Yko[00@0YkOT00000000000000000P2W]n@30:Rji`H0Z;7N0P2X^NH30:^]f@@0
ZKWT0P2X_NT30:Zji@D0Z;kZ1@2X_n/A0:O0j`030000002W`>/0Yl3[0180Yl3[4@3oool00`000000
oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo
6P2W`>/50:S0j`@0Yko[2P2W`N`90:Noj`H0Yl3/0P2W`N`30:Nji`@0YkcY1@2X_NT50:S1k0D0Yko[
102W`>`20:Jeh`<000001@2W]n@40:NWePD0Z;7N1P2[[MT30:Vii0H0Z[[U0P2X_^X30:Vmj0@0Z;o[
4P2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000O0?ooo`006`3oool2000000l0oooo00<0
00000?ooo`3oool05@3ooolM0:O0j`D0Z<3[2@2W`N`:0:Noj`@0Yl3[1@2W`>`60:Nji`80YkcY0P2Y
^^D50:Rmj@D0Z;cX1@2W_n/20:Jdh`<00000102V]N<20:Ngi0<0YIg=102WYmH20:RagP<0[J?>1@2[
[MT40:fafPD0Z[[U1P2Y_NP20:Roj`80Z;oZ4@2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<0
00000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A
0?ooobH0Yl3[1@2W`N`90:Noj`T0Yl3[1@2X^NH50:Nji`D0ZK[U0P2X_NT30:Zcg`D0Z;cX0P2W_n/0
102W^NH000000000000000030:Jdh`@0Y[GS1@2UWLd40:NWePH0[J?>0P2[[MT30;:Wc@@0[K7J1@2^
]n050:Vmj0D0Z;oZ0P2W`>/30:S0j``0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003o
ool0oooo01/0oooo00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0303oool[0:O0j`80Yl7/1`2W_n/:0:O0j`@0YkSU1@2X^NH5
0:Rag`@0ZK[U1P2Z/ml40:Rlj0<000000`2W^NH30:Jdh`D0XYK81@2UWLd20:NWeP80[9c61@2]Xlh6
0;:Wc@80[K7J0P2e[]450:jgh0D0[;gV102X_nX60:S0j``0Yl3[00<000000:O0j`2W`>/04P2W`>/@
0?ooo`030000003oool0oooo01/0oooo00070?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000`3oool2000001<0oooo00<000000?ooo`3oool02P3oool/0:O0j`P0Yko[0P2W
`>`50:O0j`T0YkSU0`2X^NH20:NYf@D0Z;7O102XXLl50:Zcg`050:^fh@00000000000000002[]^40
1@2W^NH409n@a@@0XYK81@2UWLd40:bLaP@0[J?>0P2fXlH50;:Wc@D0]JkA0P2^]n030;FgfPD0[;gV
102Y_nX50:S0j`d0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01X0oooo
00070?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`03
0000003oool0oooo00L0oooo:`2W`>/40:S0j`D0Yko[1@2W`>`30:O0j`/0YkSU1@2WZMT20:Rag`<0
ZI[7102XXLl20:Zcg`<000001@2[]^4509fAa`<0Wi351@2RU/P20:FMc@<0[Yg6102/W<H20:fScP<0
]Z?6102bYld20;^Ya`@0]JkA1P2e]mX20:bmiP<0/;kT102Y_nX50:S0j``0Yl3[00<000000:O0j`2W
`>/04P2W`>/A0?ooo`030000003oool0oooo01T0oooo00000`3oool000000000000200000080oooo
00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`020?ooob/0Yl3[2@2X`>/:0:O0k0T0YkSU1@2UYMD40:NYf@D0ZI[70`2XXLl3000000@0
[J3:0P2[]^430:b[eP@0WI77102OT<D40::Fb0D0[Yg6102/W<H60;JSaP80/ZO=0`2kZLL30;F^d@80
_Zo:1@2e]mX50;2ni0D0Z/3Y1@2X`>/<0:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`000000
oooo0?ooo`0I0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0
oooo0P00000F0?ooo`030000002W`>/0Yl3[02d0Yl3[1@2X`>/50:O0j`@0Yl3/1@2W^NH40:Nhi@D0
Y:?D1@2UYMD20:NYf@80ZI_81@2YV/L2000000<0]Io2102]X<X50:b[ePD0WI770`2OT<D20::Fb0<0
Zik91@2^WLH20:bLaP80^Zc<1@2fXlH60;^Ya`030;F^d@2n[lX0_Zo:0080_Zo:0P2e]mX30;fhe@<0
/;kT0P2d`><50:[0j@D0Z<3[302W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000J0?ooo`00
203oool2000000X0oooo0`0000030?ooo`030000003oool0oooo0180oooo=02W`>/50:Noj`D0Yl3[
102W^nL50:NiiP@0Y:CE1@2TXm@40:FUe@@0ZI_80P2YV/L3000000D0]Io20`2]X<X20;NH^0D0[:_F
102MTLL309n@a@D0Zik91@2^WLH40;Z/c0@0]Z?60P2o[lX50;^Ya`D0_Zo:1P2m^=D50;C0h`80Z/3Y
0`2[`NT40:S0j`d0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01L0oooo
000I0?ooo`030000003oool0oooo0180oooo=P2W`>/50:Noj`D0YkgY102W^nL20:NiiP<0XjKH0`2T
Y=D50:BSe0D0Yic:0P2YVlP300000080ZI[70P2j]=@50;FO`P030:fPbP2gV;P0]iRh0080]iRh102/
ZmH409fAa`@0ZIo<1@2[W/T20:jMaP<0^/7P102j[<`20;JSaP<0_jo:102kZLL20<>]a0<0_Zo:0P37
//D40;fhe@80aKcB102d`><60:_1j@@0Z<3[302W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<0
00000?ooo`3oool05`3oool001T0oooo0P00000A0?ooocT0Yl3[0`2W_n/20:NojPD0YkgY0`2W^nL5
0:>Vf0@0Y:CE0P2TXm@30:BKc0<0Yic:0`0000020:VKb080ZI[70`2j]=@50;FO`PD0]iRh102/ZmH5
09V9`@<0ZIo<1@2[W/T50;[1h0@0^Zc<1P2o[lX20;^Ya`<0`jg40P2n[lX40<Nba@80_KSE0`35_=82
0;C0h`<0^<?R1@2[`NT50:S0j``0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0
oooo01H0oooo000I0?ooo`030000003oool0oooo00d0oooo?@2W`>/50:NojP@0YkgY102TZ]/50:>V
f0<0Y:CE1@2TVl`300000080Yic:0`2YVlP60;Zde0<0]Io20P3?e]h40;NH^0030>kh_02;LJl0Rg6_
0080Rg6_102IRL440:VOc080Zik90`2/i?X50;[1h080^Zc<0P2i`^450;n_bPD0`jg400<0_Zo:0<Nb
a@37//D00`37//D50<FldPH0^<?R1@2/`^X40:S0j`d0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?oo
o`030000003oool0oooo01D0oooo000I0?ooo`030000003oool0oooo00T0oooo?@2W`>/50:Noj`@0
YkoZ1@2T[n040:BZf`@0XjKH102PV<`01@2TVl`00000000000000000Y9_<00@0Yic:102dc>`50;Zd
e080]Io20`3?e]h30;NH^080k_Rl102;LJl409V9`@@0ZIo<1P2/i?X40;[1h0@0^L;Q102o[lX20;jh
d`@0`jg41@37//D20<je`P<0aKcB0P3<`M030;S3hP<0^lKS102/`^X50:S0j`d0Yl3[00<000000:O0
j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo01D0oooo000I0?ooo`8000001`3ooom10:O0j`D0
Yko[102U]>@50:B_h0<0Y:[K1@2MUL/0102PV<`000000000000000040:BKc080Yic:0`2Yf?P40;C<
k0@0^[CD1@3?e]h30;NH^080k_Rl102;LJl409V9`@H0GMG9102/i?X508o?o@@0^L;Q0P2o[lX30;jh
d`<0`jg40P37/L@30<Nba@@0c[G200<0aKcB0<c1d03<`M000P3<`M060;_6h`@0[<;Z1@2X`>/<0:O0
j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000
oooo0?ooo`030?ooodD0Yl3[1@2V^^L40:Fdi0@0Y:oP102KU<`209fEb`<00000102PV<`30:BKc0H0
ZMSh0`2dc>`507[Io0D0cmKN00@0]iRh0>kh_03^n;`0k_Rl1@2;LJl209V9`@80V?;Z0`1/c_d405Ng
o0@0HKom0`2?cod40;W2h@H0_[SC00<0`jg40<Naa037/L@00P37/L@00`37//D0c[G20<je`P030<je
`PD0c<7@00@0dlO?0;_6h`2ka^<0^lKS0`2lb><40:c2jPD0Z<3[302W`>/00`000000Yl3[0:O0j`0B
0:O0ja00oooo00<000000?ooo`3oool04`3oool001P0oooo00<000000?ooo`3oool00`3ooom30:O0
j`@0YkgY1@2V^^L30:Fdi0D0ViO>0P2KU<`3000000<0WIG;102PV<`50:CKn`H0TM;n0`1dc?l407[I
o0@0cmKN00<0]iRh0>kh_03^n;`00P3^n;`408]a[`0309V9`@2N[>40WZcQ0080WZcQ0`25Vn4407^[
lPD0FKGl0P15/OL409?5n0D0_[SC1@37/L@60<je`P040=Bi_P3<`M00c<7@0<c1d0<0dlO?1@2lb><2
0:c2jP<0Zl;Z102X`>/=0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool2000001D0oooo000H0?oo
o`040000003oool000000?oood<0Yl3[0`2W_n/40:Nmj@@0Y[[W102LWM@409^GcP8000000P2KU<`4
09fEb`H0Y=Oi102Pe?X3097BoP<0X/Oc102HaoL509oCnP@0G[?k0P3^n;`408]a[`030;_?j@2N[>40
WZcQ00<0WZcQ0`25Vn4407^[lPD0Gl3m0P0JTNT409?5n080_[SC0`2a]mh40<Naa0030<Raa03>]L80
c[G20080c[G20`3D^Kh0103<`M00dlO?0=?7c`3Call20=O<cP@0_<SS1P2[`^X40:S0j``0Yl3[00<0
00000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`00603oool0
0`000000Yl3[0:O0j`120:O0j`H0Yko[102W_NT409nWf`<0W9gD00D0ViO>000000000000000009^G
cP0309^Dc0D0XlWd0`2TeoT30:SLnP@0X=Cj1P2Rao<40:?>mPD0Wm?j1022]oL00`3^n;`0Rg6_08]a
[`040;_?j@@0WZcQ0`25Vn4609;HoP<0Gl3m0`0JTNT304fTm`D0/KON0`37/L@20<Raa0<0c[G2103D
^Kh30=?7c`@0elc>0P2lb><20;_8i0H0Zl;Z102X`>/<0:O0j`030000002W`>/0Yl3[0140Yl3[4@3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo000A0?ooo`8000001@3o
ool00`000000oooo0:O0j`0o0:O0j`T0Yko[1@2R/N8409nWf`<00000102KUlh509jdi`@0XlWd1P2X
g?X50:K;l`D0Y<cd102Sc_H509nlk@<0P[Og0`2beO840;_?j@D0U[K]102JcOT609_:n0<0JKOl0P00
NM`304fTm`D0/KON00<0ak740<Raa038/L@00P38/L@00`3>]L80e;Vn0=Bi_P030=Bi_P030=bn^`3C
all0elc>00@0elc>1@2kb>@50:_2jPD0Z<3[302W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0400Yl3[1@2W_n/40:Fii`D0X[7R0`00000309bMe0D0UioJ
1@2N]>L50:kTn@D0YLWb0`2Vbo<20:C:l`D0Y<cd102[aN`509nlk@H0/]Gb102L[n@509Jfk@D0ZmKf
1@2Oc_P306c2oP03001Pb000NM`00g7N0080CJCg102a]mh50<Raa0D0e;Vn0P3L_[/50=O<cP80fLo?
0P2kb>@30;[8i@@0Zl;Z1P2X`>/<0:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0
oooo0P0000020?oood00Yl3[1@2V_NX40:Fii`040::ahP0000000000000000@0TI7@0`2BTm4509NO
fP80W[CW102`jOP40:[<l@D0YLWb1@2Tb_<50:W7k`@0ZlG/1P2VcO@50:Vii@@0W:oT1@2ZfoT30:_F
mP80Y/K`1@2Oc_P306c2oP8006380P03LMh509Z]i0@0b;7400@0b;320=Bi_P3D^Kh0e;Vn0`3L_[/0
103SaKT0elc>0=O<cP3Gc<h30=W?c`H0^/SU102[`NX50:S0j``0Yl3[00<000000:O0j`2W`>/04@2W
`>/A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool00100oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oooc`0Yl3[1@2W_n/40:JmjP0409^W
gP0000000000000000@0UIWE0`2ATM0409:Cd@@0UioJ102`jOP30;3Al@@0Z/ca1P2WcO<40:O6l0D0
ZLO_102Ub?830:K=m0<0[L?Z1@2Y^ND209b_i080XmOj1@2ZfoT50:K6l0D0ZMSh101Y`_h00`00H<P0
03fk00=agP0409Z]i0<0b;740`38/<80103D^Kh0g;jk0=bn^`3L_[/30>?5^@@0fLo?0P3Id=030;[8
i@<0^LSU102[`NX50:S0j``0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`800000103oool20000
00X0oooo000@0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3ooolk0:O0
j`D0Yko[00@0XKCU00000000000000000`2KYmh409FIe@@0TI7@102BTm450:kPn0H0/=7a102Xco@3
0:O=l`<0Y/G_102Wa_050:K7l@@0YLSb1P2]`nX40:Vii@D0XmOj1@2X`nd60:oFm0D0[=ki0`1G^O`0
0`006I`003fk000m^`0409Z]i0030<Raa038/<80b;320080b;32103L_[/30>?5^@030>W;]`3Icll0
fLo?00@0fM3@1@2ib>D50:[1jP@0Z<3[3@2W`>/00`000000Yl3[0:O0j`0A0:O0j`h0oooo0`00000@
0?ooo`004@3oool2000000@0oooo0P0000070?oooc/0Yl3[0P2U^nT3000000@0XKCU0`2KYmh409FI
e@<0TI7@0P2BTm430:C4l0<0[^3h0`2jgO450:_Am0@0Z<od1P2VaNl40:K9l@D0Y/Oa102Za^h50:g3
jPD0Wlgg1@2Za>d30:S3k@80Zm;d0`2_e_@30;?Hl`<0[=ki0P2[g_T303nFlP03000IW000?K/003fk
00<0PIWQ1038/<820<ba_`80g;jk103SaKT20>W;]`@0fM3@0P3Hd=430;W8i@80^<OV1@2Z`NX40:S0
j`d0Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003oool0oooo00h0oooo000G0?ooo`03
0000003oool0oooo00L0oooo>@2W`>/3000000@0YK_Y0`2Q]>D309^WgP@0UIWE0`2ATM060:C4l0@0
^]ga0`2_e?<40:_Am0@0YlG_0`2VaNl30:K:lP@0Y/Wa1@2Wa_040:[6kPH0X/Oc102[b>l50:[4k@D0
Zm;d1P2cf?<50:_Nn@<0?iKb00<001VL000m^`21VN400`21VN420<R``P@0c;6o00@0g;jk0>?5^@3S
aKT0hlFi0`3YbkL00`3/c[H0fM3@0=W@d0040=S@d@D0^<OV1@2Z`NX40:S0j``0Yl3[00<000000:O0
j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00d0oooo000G0?ooo`030000003oool0oooo00P0
oooo=@2W`>/3000000<0Yko[102U^nT409:Og@<0RY7D1029T=@309>RgP<0Y<C`102nh_460:oDl`@0
ZLO_102WaNl60:K:lP@0Y/G`1@2Wa_040:G5l@<0X/Oc0`2Ybo440:_8k`H0Z<kd1@2_d?450;WTm0D0
V[oa00D0;fKF03nFlP0oU_8001VL000m^`03086Ih@030<R``P3</Kl0c;6o00<0c;6o103SaKT20>W;
]`<0k<jf103Hd=420=O@d`80^<OV0`2ganH40:[1jPD0Z<3[302W`>/00`000000Yl3[0:O0j`0A0:O0
ja00oooo00<000000?ooo`3oool0303oool001L0oooo0P0000090?oooc<0Yl3[0P0000020:O0j`@0
Yko[1@2L/>D309:Og@<0RY7D1@29T=@309>RgP@0_^;a102jf_450:k>l0@0ZLO_1P2Vc?<40:G4k`@0
Y/G`1@2Va_040:G5l@H0ZL_a102Vb_830:S>m0<0[<_`0`2_d?430;CQmP@0^=cb1@2J_o4202mVeP03
0002T`000I<0PIWQ0080PIWQ1P3</Kl00`3C][`0hlFi0>?5^@030>W;]`<0k<jf00<0kLng0=S@d@3H
d=400`3Gd=<60;O7iP@0Z/7[1@2X`>/<0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool00`000000
oooo0?ooo`0<0?ooo`005`3oool00`000000oooo0?ooo`0:0?ooobh0Yl3[0`0000050:O0j`@0Xk_Y
1@2L/>D309:Og@<0RY7D1029T=@50;SEk`D0^][a0P2fe_450:k>l0D0Ylcc1@2Va>l40:G4k`@0Y/Sa
1@2Va_050:O:lPD0Y/O`102Vb_860:c;l0<0]>7f0`2gh?@40;SLlP@0V[oa0`0_I]H00`000Y<0006C
0767f@020767f@@0c;6o0`3C][`00`3SaKT0jL^g0>W;]`030>c>]P80kLng103Gd=<20=G@e0<0]lOV
0`2fa^H40:[1j`D0Z<3[302W`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo00<000000?ooo`3oool0
2`3oool001H0oooo00<000000?ooo`3oool0303ooolZ0:O0j`<000001@2W`>/40:Jnj`@0Xk_Y102L
/>D309:Og@<0RY7D1@2O/ND30;SEk`@0a=k/1@2fe_450:S<l`<0Ylcc0P2Wa_050:K4k`@0Y/[c102V
b?460:G9lP@0YlK`1@2Vao050:_;l@D0[Mch1P2gh?@40:FljP@0OHcG0P0_I]H00`000Y<0006C0001
T`020767f@<0c;6o103C][`30>W;]`<0k<jf0P3]ckL00`3/d;L0em3C0=O@d`040=G@e0D0]/KV1@2Z
`N/40:S0j``0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00X0oooo000F
0?ooo`8000003P3ooolV0:O0j`<000002@2W`>/40:Jnj`@0V;3X1029W=l3082=e`<0Qi?H1@2O/ND4
0<CNk0@0`Mg]102^d?450:S<l`D0YlK`1@2Ubo@40:K:l`@0Y<Ka0`2UbO830:O7l0@0YlK`1@2Yc?83
0:_;l@80Z=Gg0`2]g?P30;7MmPD0Ynkh102U_>X307f<e`0502E=a00_I]H0002@0002T`000I<00`1a
QmT00`3</Kl0dkJl0=>f_0030=>f_0030=jo^@3YbkL0k<jf0080k<jf0`3]ckL20>c@]`@0eM3D0P3D
cmD40;K6iPH0Z/7[102X`>/<0:O0j`030000002W`>/0Yl3[0100Yl3[3`3oool2000000`0oooo000F
0?ooo`030000003oool0oooo00h0oooo8P2W`>/3000000d0Yl3[102R^n/409R`j0<0RIcO0`20SML4
08NCf0<0Wk7U0`30dnP40<7Mk@<0^mS^102^d?460:W:l@@0Y<_d1@2Ubo@40:C4l0@0Y<Ka1P2Wao04
0:O<l`D0ZLcb1@2XeOL40;7MmP<0D/Z^102Wk_P30:FljP@0OHcG00D09Dg40000T0000Y<0002B0001
T`020760dPD0dkJl0P3N_kT40>c>]P80kLng0`3/d;L00`3/d;P0eM3D0=G@e0040=C?e@@0]/KW0`2Z
`N/30:W1j`@0Z<3[302W`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo00<000000?ooo`3oool02@3o
ool001H0oooo00<000000?ooo`3oool0403ooolM0:O0j`<000003@2W`>/40:Joj`@0X[_[102H/>P3
08VLg`<0P8gG1027TmP40<3Cj0<0b]_V1P2kf>h50:c@l`T0Y<_d2@2Ta?050:K9lPD0YL_c102Wc?<5
0:O@m@H0[Mgh0`2F__8308Ngm@@0MZkf0`1XY?<304N>k@809Dg400<0002@0000TP000I<00`1aP=83
0=>f_0<0g[ni00<0j<Rf0>c>]P3/c[H00`3]ckL30>c@]`80k=2h103DcmD20=?@eP@0]/KW1@2Y`N/2
0:S0j`h0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00P0oooo000F0?oo
o`8000004P3ooolI0:O0j`<000004@2W`>/40:Joj`<0X[_[1@23W^D207J;fP<0P8gG1P2U/N440<[K
iP80bmcU0`2kf>h30;GGl@<0[=3c0P2VcO@50:C;m0@0YLKa1@2Ta?040:G<m0<0Y/Wb0P2TbO<50:G;
l`D0Y/gd1@2WgoX30:30k`@0U[kb1027]oD307J^mP@0J:Cc0`17S^d0100UCL@0002;0000TP000983
0760dP<0dkJl0`3N_kT20>S8]P<0kLng0`3/d;L30>c@^0030>_@^@3DcmD0e<oE00<0dm3F1@2ea^L4
0:W1ja40Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003oool0oooo00P0oooo000F0?oo
o`030000003oool0oooo0180oooo5@2W`>/3000001D0Yl3[102S_N`309Ncj`@0PikU0`1fRmX308BA
f@@0YK7Q0P31b>020<[KiP@0bmcU1P2eeo450:K=m0D0Y<_d102Ua_450:?=mP@0YLcd1@2TbO<50:G=
m0<0Y/gd0`2Qh?`30:G1kP@0X<3_102HQKd409:8aP<0QI;I1@1GXoH01@17S^d003fo02E=a0000900
002B00@0LH3B00@0dkJl0=jo^@3N_kT0g[ni0`3Xb;H00`3/c;@0kLng0>g?]`030>c@]`80k=2h0P3[
d;T40=?@eP80d]7H1@2ea^L40:W1ja40Yl3[00<000000:O0j`2W`>/0402W`>/?0?ooo`8000002@3o
ool000<0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0503ooolA
0:O0j`<00000502W`>/50:Joj`@0Xkg/0`2G/n/408>Ni@80MX_J1024TMT20:Fah@@0`LSP103;g>D4
0<WLi`D0[mKd102Rd?P50:C;m0D0X<gg0`2ScOH60:;6lP@0Y=3g1@2UcO@30:7Po0030:O2k@2U`Nh0
YL7^0080YL7^1@2LQK/309R5_@D0TXS60`25T]T509j]h@8003fo00<0002;0004U`0009800`20RM<4
0=jo^@<0j<Rf0P3/c;@30>c@]`<0k=2h0P3[d;T00`3/dk/0dm3F0=?@eP040=;Af0D0]<KX102Y`N/A
0:O0j`030000002W`>/0Yl3[0100Yl3[2`3oool3000000030?ooo`000000oooo00P0oooo00020?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0E0?ooo`h0Yl3[0P00000I0:O0j`@0Y[o[0`2S_N`408>Vj`<0JH_Q0`1fRmX308BAf@D0`LSP0`3?
dM/40<WLi`@0amcY102WeoT40:;@n0H0W<gi102Pb_D40:;6lPD0XM?i102Td?L509cNo@@0Yl;]102M
Q[X409b5^`@0V8Fm102BR<H40:j^f0@0WZgQ0P18U_400`00?Kl0002;0004U`040829d`80g[ni0`3X
b;H30>c<]0030>g=/`3/d;L0k=2g0080k=2h0P3[d;T30>cC^`@0d]7H0P3@e=`40;C6j0D0ZL7[402W
`>/00`000000Yl3[0:O0j`0A0:O0j`H0oooo100000040?ooo`030000003oool0oooo00L0oooo0002
0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`X0Yl3[
0`00000L0:O0j`@0YKk/0`2K^Nd408>Vj`<0JH_Q0P1eRMT409jWg0<0`LSP0`3?dM/30=CBePD0amcY
0P34g>/40:OGn@D0Um3k1@2Id?/40:3:m@@0VmOl1@2QdoT509WJo@@0ZL?/102NQ[X309f6^PD0W8Fk
0`2HQKd209:8aP<0/:oG102^[]P40:n/e0<0SJ7Q0P0019L40829d`040=jo^@3Xb;H0j<Rf0>S8]P<0
k<bd0P3]cK<30>c@^080jm2i0`3/dk/00`3]f;d0d]7H0=;Af0040=3Dg0@0//KY102Y`N/A0:O0j`03
0000002W`>/0Yl3[0140Yl3[0P3oool3000000P0oooo00<000000?ooo`3oool01`3oool00080oooo
00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0603oool50:O0j`<0
0000802W`>/40:Fnk0<0VkW]1023Y^/206V;h@<0MHWI102NYm`40<oAf`@0e=;F00@0f=3B0<OLj@37
g>T0amcY1034g>/509gGo0@0RM?o1@2Id?/508oGo`<0VmOl1P2Ge_d30:k5j`D0WhNj0`2NQ[X409f6
^P@0W8Fk0`2HQKd50;2_e`80[ZkH0`2b[M<40:n/e0<0SJ7Q00<000BG0829d`20RM<00P20RM<30>S8
]P<0k<bd0`3]cK<0103^c[80k=2h0>_@^@3[d;T30>cC^`<0kMRm103@e=`20<gFh0@0//KY102Y`N/A
0:O0j`030000002W`>/0Yl3[0100Yl3[0P00000<0?ooo`030000003oool0oooo00H0oooo00020?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I
0?ooo`040:O0j`0000000000000002@0Yl3[102Q_Nd308fbk`<0I9CZ0`1YRn4307F9f@80WZOL102i
]mP40=CBeP<0f=3B1034g>/40<CHj@D0T]Gn0`29dol607oBo`@0Rm;o102Bdoh40;G7j0@0XX^l102O
QkX409j6^P<0WHJj102LQK/40:f]f0@0/:oG1P2b[M<30:n/e0@0XJOJ00<000BG09ZQfP2JXMX00P2J
XMX20>S8]P<0k<bd0P3]cK<20>k>/P<0jm2i0`3/dk/30>gH_@030>gN`P3@e=`0d=CL00<0cMKP1@2`
a^X40:W1ja40Yl3[00<000000:O0j`2W`>/0402W`>/=0?ooo`030000003oool0oooo00H0oooo0003
0?ooo`8000002P3oool3000000<0oooo0P00000H0?ooo`<00000902W`>/40:Jok0@0XKg]0`2=/^l3
06BDjP80EgkM0`1eRMT50;Vgf080bKg?0P3Dd]H30=S@dP<0fL_<1034f>T40<G;g`D0WLKe0`1gc?l6
08C<o`<0Rm;o0`2mb><30;G7j080Z9C10`2RRk`509n7^P<0WXJj0`2MQ[X50:RYe`@0[JgH0P2`[mL2
0;2^ePD0/ZgC102e/mL30:6WfP03000:V`2JXMX0VZ7J00<0VZ7J0`3/c;@30>g=/`80k/jb0P3`dK83
0>cC^`<0kMRm0P3]g/840<gFh080amKU102`a^X50:S1ja00Yl3[00<000000:O0j`2W`>/0402W`>/=
0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo01D0oooo0`0000040?oo
ob@0Yl3[102V_n`30:6mk@<0SK;_101TU>X205Mng@<0QiCJ0`2i]mP40<Vmc`<0f=3B103Ibl`20=W1
``D0aL_O0P36]LX309g6m@80[J_E102A_?@509RhkPH0_LSS102XU<430::;_0D0WhNj0`2NQ[X40:JW
e`D0Z:WG0`2][MP50;2^eP80/ZgC0`2e^M`40;Fce`<0XJOJ00<000ZK09ZQfP2JXMX00`2b^n020>c<
]080kLfc0`3^c[820?3A/P030??H/`3/dk/0k=>k0080kMRm0`3]g/800`3[i<T0cMKP0<gFh0040<OF
i@@0[LG[1@2X`N/@0:O0j`030000002W`>/0Yl3[0100Yl3[303oool00`000000oooo0?ooo`060?oo
o`00503oool00`000000oooo0?ooo`0B0?ooo`<00000203ooolT0:O0j`@0YKo/0`2K^nh307RXl@<0
?7gT0`1GO]d308NDfPD0bKg?0`3A_LH40=W;c0<0fL7300@0ekJh0<G;g`35bml0aL_O1036]LX50:f[
e@@0YZ7A0`2H^>h20<?7g@<0_LSS0`2dZ<d40:RD`@<0XX^l102OQkX80:JWe`@0Z:WG102^/MX40;2^
ePD0]KWL102e/mL40:F/g0H0/[_P0`3]cK<20>k>/P<0l=6b0P3cf;<20>gH_@<0kMk20`3[i<T30<OF
i@<0`=CY102]aN/50:S0ja00Yl3[00<000000:O0j`2W`>/0402W`>/;0?ooo`030000003oool0oooo
00H0oooo000D0?ooo`800000403oool3000000`0oooo902W`>/40:Fok0<0Vk_^0`1hZ?4303ami080
CgWL102NXMH30<Vmc`@0dKg600<0eKRm0=W;c03Ibl`00`3I`L<30=Nf^0D0a[G:0P38ZKX30:f[e@80
^J;2102VXM450<?7g@D0]:S=102XU<430::;_080WhNj0`2UZ=P70:JWe`D0[;?M102^/MX20;2^eP80
/;_R102e^M`50;6ef`<0YJcL00@000fG0;:kh02b^n00/[_P0`2oa^00103]cK<0k/jb0>k>/P3^c[82
0?3A/P<0lmRc00<0mN2f0>gN`P3]g/800P3]g/820>_Tb@80i^SB1@30e>T50:_3k0@0Z<3[4@2W`>/0
0`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?oo
o`3oool0303oool300000140oooo8`2W`>/30:Fok0@0UKW`0`1JVo400`09G]H0?7gT03ami00204mi
g0@0WZ7F00<0bKg?0=6maP3A_LH00P3A_LH30=Fh_@@0fL730`3G][P0103F[[00a[G:0<JebP36]LX4
0<RY^P030:f[e@2iX/80^J;20080^J;20P2VXM420<O5f0<0`lOM0P37c]l50;BXc@<0Z9C10`2RRk`5
0:FXf0@0YZOG102Z]>040:bcg@@0[[7J1@2`^n820;Fig080[[GN102a]M/40:F/g00305J0g`2oa^00
_lKP00<0_lKP0`3^c[830?3A/P80lmRc0P3eh;H00`3dj;X0kMk20>gN`P020>_Tb@80i^SB0P3Mj]`3
0<3Dj@80^<o/1@2[`n`40:S0ja00Yl3[00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0
oooo00H0oooo000D0?ooo`030000003oool0oooo00X0oooo0P00000E0?ooob<0Yl3[0`2T_n`409Fi
l0<0FY_a0P09G]H304mig0<0WZ7F103A_LH40=Fh_@030=Nc]@3I`L<0fL7300@0ekJh0P3F[[000`36
]LX0b:Vj0<RY^P030<RY^PD0^J;21@37aMP50<O>g`@0]:S=102OZ=`30:>Yf`@0YJSH0P2VYmL30:Nc
h@@0Z[CP0`2//md50:bji0@0/;_R1@2^]Mh20;6ef`80[[OO102R[Ml0101TR>40_lKP0;o6h02oa^02
0<K>h080k/jb0P3`dK830??H/`040?GP]P3dj;X0m>Rj0?CX^P80jnC90P3Vj=840=gZg0D0^<o/1@2Y
`^`40:S0ja00Yl3[00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00D0oooo000D
0?ooo`030000003oool0oooo00L0oooo0`00000H0?ooob<0Yl3[0`2T_n`408jglP<0=XW/0P09G]H2
04]hg0@0[jO@0P3A_LH40=Fh_@<0ek>e00@0fL730=Nf^03G][P0ekJh0`3F[[060<RY^P040=2^]`2i
X/80^J;20;VR`P80c/?@0`37aMP30=7bj0<0alkO1@2JY]h409nXg0<0XjWK0`2UZ=P60:Nch@<0Z[CP
102Y^N@40:bji0D0[;GP102^]Mh50:jgg`@0XZgO00<0I8SQ0<K>h036c^000`36c^030?3A/P80lmRc
0P3eh;H30?CX^P030?7]`@3Vj=80i^SB00<0gN[L0`3BinD50;3:k@@0ZL;/5@2W`>/00`000000Yl3[
0:O0j`0?0:O0j`X0oooo00<000000?ooo`3oool01@3oool001<0oooo0`0000050?ooo`<00000703o
oolS0:O0j`<0Xko]102>]o8303J9k004000d^009G]H0BgSL04]hg0@0[jO@103E^;d40=Nc]@@0ekJh
0`3F[[000`3J[j`0b:Vj0<RY^P020<RY^P80d:jg0P2iX/840<k3d0@0dO;X0P2aa^T309f/hP@0VZKN
102OZ=`40:6/gP<0Y;3Q1@2W/n440:Rgi0@0ZKWT102[]^850:beh0@0[[_S102^]ml509b/hP0306R<
hP36c^00a/kP00@0c=oW0`3cf;<0103eh;H0m>Rj0?CX^P3dj;X20?7]`@80k_3800<0jO??0=;Wi@3B
inD00P3BinD20<CNk0D0/<[]102X`N/E0:O0j`030000002W`>/0Yl3[00l0Yl3[2@3oool00`000000
oooo0?ooo`050?ooo`004`3oool00`000000oooo0?ooo`020?ooo`<00000803ooolS0:O0j`<0Xko]
1@29]_<2019ehP03000d^01;N=`0BgSL00<0[jO@0P2kZ/T30=Fh_@@0ek>e00<0f;2_0=Nf^03G][P0
103F[[00103J[j`0b:Vj0<RY^P38ZKX30=2^]`030;VR`P3>`m00c/?@0080c/?@0`3LmMh50;76j@<0
WJcR0`2JY]h509jWg0@0XJcN0`2T/>450:Ngi0@0Z;OT102Z^>@40:^fhPD0ZkcV102^^n<40:RdhP@0
W:cR00<0J8cR0<cOi`3<gnL00`3<gnL20<;al0030??H/`3eh;H0mN2f00<0m>Rj00<0lNg10>k`b03^
l<P00P3Ylll20>?ee`D0a=k/1@2[aN`40:S1ja@0Yl3[00<000000:O0j`2W`>/0402W`>/80?ooo`03
0000003oool0oooo00D0oooo000C0?ooo`030000003oool0000000800000903ooolS0:O0j`@0Xkk]
1029]_<2019ehP04000d^00nLm`0BgSL0:nWd0@0^j[900<0eKRm0=Nc]@3G/kD00P3G/kD30=R`[`04
0=Nf^03F[[00eZj`0=J^/0<0fZn/00<0b:Vj0=2^]`3@[[L00P3@[[L40<k3d0<0g?GN0P3GiN040;76
j@<0WJcR102JXm/409jWg0@0XJcN102W^>D40:Ngi0D0ZKWU102Z^>@40:Vki`@0ZkcV1@2Y]^840:Rd
hP<0W:cR0P1XS>830<cOi`<0`_7`0P3eh;H30?CX^P050?7]`@3^l<P0k_380>k`b03Ylll00P3SmML2
0=Wdh@<0a=k/0P2gd^h40:_5k1T0Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0
oooo00D0oooo000C0?ooo`<000009`3ooolS0:O0j`@0Xkk]1027]_@01000I]P04WGR03icg00nLm`5
0;^Zb@D0ek>e0`3H/:l40=J^/0<0fZn/1@3@[[L00`3K`/00c/?@0<k3d0030=cegP<0enGP1@2JYml3
09JQg0@0VZ?K0`2NYm`50:JhiP@0YkSU102W^NH40:Vii@D0Z;[W102Y^nL40:Rfh`@0ZKKR102X]>84
09BWh`80Ih_R0P32lO030:Wbm@@0W^ci00D0lNg10>k`b03^l<P0k_380>Wcc`020>?ee`@0fOCQ1@2g
d^h40:W2k1T0Yl3[00<000000:O0j`2W`>/03`2W`>/70?ooo`030000003oool0oooo00D0oooo000D
0?ooo`030000003oool0oooo02L0oooo8`2W`>/40:>nk@@0QkKd00@006KH0003QP0nLm`0?W?L0`2k
Z/T20<6/a0<0ek>e103H/:l0103K/:d0eZj`0=J^/03F[[030=Z_[0040>2g[P3@[[L0d:jg0=2^]`<0
fl;00P3LmMh40=OUh080_L;N1@2JYml309JQg0<0VZ?K102S]^L50:JhiP@0Y[OU202W^NH50:Rji`@0
ZKOT102X]^<30:VfhPD0Y;CT102DYn<306N;hP03031Zf@2Nk?T0W^ci00@0ZNWj0`2kjO@00`3Ylll0
hoGG0>?ee`030=Wdh@<0bn_/1@2]b>d40:W2k1P0Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`03
0000003oool0oooo00@0oooo000;0?ooo`D000001@3oool2000002T0oooo8P2W`>/40:>ok@@0R;Kd
00D006;D03icg00nLm`0?W?L0;^Zb@030<6/a0<0ek>e0`3H/:l20=^`[@80eZj`103J[j`20>2g[P03
0=2^]`3K`/00fl;00080fl;00P3Yg<H20>oQ`0D0_L;N102JYml309JQg0@0WK3U102S]^L50:Fdi0@0
Y[OU202W^NH20:Rji`<0ZKWU102Y]n@30:Rfh`@0Z;WV1@2T]>@309BWh`@0Ih_R0P0`J]T200QSf@<0
^nWd0P3;k>`20=Gai@80f?SP103;jn`20;[Il0@0[LS]1@2X`>/H0:O0j`030000002W`>/0Yl3[0100
Yl3[1P3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02L0oooo8P2W`>/40:>ok@@0R;Kd00<006;D01MQe`0GHML01@31[<@00`3G/kD0f;2_
0=R`[`020=R`[`<0fk2]00@0eZj`0=Z_[03J[j`0fZn/0`3P]jh40=_2`080jMc60`3_hL00103XeL<0
_L;N0;g2gP2m`]h20:^^f@@0U:7M0`2FYn4409f`i@@0Y;;R102U]>@50:Nji`L0YkWV1@2Y^ND40:Vg
i0@0Z;_W102X^NH509j_i0<0S:?T0`1YS>43031Zf@80DiC_0`3;k>`20=Gai@80f?SP0`3Dn^850;[I
l0@0ZL;/102X`>/I0:O0j`030000002W`>/0Yl3[0100Yl3[1@3oool00`000000oooo0?ooo`040?oo
o`003@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo8P2W`>/50:>ok@<0
RkOc00<006KG01MQe`0GHML01031[<@40=R`[`@0fk2]103J[j`30>2g[P040>C0/P3K`/00fl;00=_2
`080jMc60P3_hL030>SE``D0ZjkI0`2DXMd409JWh@@0X[3R102T/^840:Nki`@0Yk[W102W^NH40:Rj
iP@0ZKWU1@2W^nP40:Rki`@0Xk?S102N[n@408bSi0<0JHcQ0P1DP^8405>Dk`80eO7U0P3Hn>020=Cj
hP<0bO;/1@2^bNh40:W2k1d0Yl3[00<000000:O0j`2W`>/03`2W`>/50?ooo`030000003oool0oooo
00@0oooo000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3ooolR0:O0j`D0
Xko]0`2;]o<00`00I]L05f7G0<6/a0020<6/a080a:o50`3H/:l40=^`[@040=ng[`3J[j`0fZn/0=Z_
[0<0h;N^0P3T`;800`3K`/00jMc60>WLaP030>oQ`0<0j=G300<0fLK70:^^f@2[[]T00P2[[]T309BQ
g@D0WZgR102R/>840:Jjj0@0Yk_W202W^^L40:RjiP@0Yk[W102W^nP50:Jdh`@0Xk?S0`2N[n@408bS
i0<0JHcQ0`1DP^8408Zim@80f?SP00<0e?[R0<Wbk039l^`00P39l^`20;WKl@@0[/W^1@2X`>/L0:O0
j`030000002W`>/0Yl3[0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000
oooo0?ooo`0:0?ooo`800000:03ooolR0:O0j`D0Y;o]0`2=^?<00`02KM`05f7G0<6/a0030<B_a@80
f;2_103K/:d20=ng[`80fZn/0`3P]jh30>C0/P80jMc60`3_hL030>SE``<0fLK7102WZ]T309ZXg`@0
WZgR1@2S]nL40:Jjj0<0Yk_W102V^>H50:Nji`@0YkWV102W^^L40:Ngi0@0Y[CS1@2R]NH309V[h`@0
QYcQ0P1`S^0405B2hP<0/MWd0P38l^d30<[li0D0^M_a102Y`^`40:S0jad0Yl3[00<000000:O0j`2W
`>/03`2W`>/40?ooo`030000003oool0oooo00@0oooo000<0?ooo`8000003P3oool00`000000oooo
0?ooo`0V0?ooob80Yl3[1@2T_nd308fhl`03000_/`34[lD0a:o500<0a:o500<0f;2_0=^`[@3K/:d0
0P3K/:d30=ng[`040=Z_[03P]jh0h;N^0>2g[P<0i<2b0P3Zb;<20?7A/0<0j=G3103Ia/L00`3=^lT0
Yj[I0:NZf@020:NZf@<0VZSO102P/N@50:>gi`<0Y[[X102V]^D40:JhiPT0YkWV102X^ND40:Ngi0@0
YKWW102R]NH409V[h`<0QYcQ0`1`S^0407NMj@<0b?;]0P3:o>@30<Cck`D0[LS^102Y`^`Q0:O0j`03
0000002W`>/0Yl3[00l0Yl3[0`3oool00`000000oooo0?ooo`040?ooo`007@3oool00`000000oooo
0?ooo`0V0?ooob80Yl3[1@2T_n`308nhlP03000_/`34[lD0a:o50080a:o5103K/:d40=ng[`@0h;N^
0P3T`;820>[8/`<0lM6`0P3cdZh40=W6a`<0cK_90`2WZ]T409n/g`@0X;7T102S]nL40:Jeh`@0Y[KU
102X^^H40:NiiPD0Z;[V102X^ND80:Fii`<0X[GV1@2AX^0208>Hg`@0L8kP1@2M`O800`3:o>@0a??_
0<Cck`020<Cck`80]MOb102]b>h50:S0jb40Yl3[00<000000:O0j`2W`>/03P2W`>/40?ooo`030000
003oool0oooo00<0oooo000N0?ooo`030000003oool0oooo02H0oooo8P2W`>/50:Bok0<0SkSb00<0
02nc0<B_a@34[lD00P32]ll30=^`[@@0gkN_00<0h[jd0>2g[P3P]jh00`3T`;820>[8/`80lM6`0`3c
dZh00`3_c[40fLK70=W6a`040<fkb@@0Zj_H102O[=l40:JchP@0Y[CS102V]N<40:Rki`@0Z;[V102W
^^H40:RjiPD0Y[SV102U^NL40::_h@<0W:[Q1@2AX^0208>Hg`@0Oi[S0P2M`O820;c_l`<0_OcT1@2e
eo840:S1k0@0Z<3[8@2W`>/00`000000Yl3[0:O0j`0@0:O0j`80oooo00<000000?ooo`3oool00`3o
ool001l0oooo0P00000X0?ooob40Yl3[1@2T_n`3096ilPD0`[O?00<0fk2]0=ng[`3O]jl00P3O]jl3
0>:n]0030>2g[P3T`;80i<2b0080j/Rc0`3adK020??B[P<0klja103=^lT20<Rfb@@0Zj_H102V/=l4
0:JchP<0Y[CS2@2X^nL40:Nhi@@0Yk[V102V^>D40:JhiPD0YK?R102R[n4309bZh@@0TJ;P0`23V=l3
07nJh`80_>oc00<0_OcT0;g^l`2mk_<00`2mk_<50:_5k@@0Z<7/9@2W`>/00`000000Yl3[0:O0j`0@
0:O0j`030?ooo`000000oooo00@0oooo000Q0?ooo`030000003oool0oooo02H0oooo8@2W`>/40:Bo
k0@0T[Wb1032]ll40=ng[`@0h[jd0`3T`;820>[8/`80lM6`0`3cdZh30>o>/@030>S9]P3=^lT0cK_9
00@0b;K90P2[ZmP20:n^e`@0Y[3O0`2V/n840:NiiP@0Z;_W1@2W]^@80:Nhi@@0Y[SU102W]^@40:Fc
hP@0XZoQ102HY]l408jKg0<0RIcO0`2J^nl0102bmO80]O[X0;Gjj02en^P40:o>l0@0ZlG]:P2W`>/0
0`000000Yl3[0:O0j`0?0:O0j`030?ooo`000000oooo00@0oooo000R0?ooo`030000003oool0oooo
02H0oooo8@2W`>/40:Fok0@0T[Wb0P32]ll20;BohP<0gkN_103R_[@0103R`kT0i<2b0>[8/`3Zb;<3
0?7A/080lm:^0`3_c[420>S9]PH0b;K91@2_[]L30:J`g`@0Y[CS102W^NH40:NehP@0YkKT1@2X^ND8
0:Nhi@@0YkKT0`2U/n8509n_h`@0V:KO0`2>Vm`408VLg`80/_Gb0`2en^P20;GNm0@0[lk`1@2X`N/Y
0:O0j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002<0oooo00<000000?oo
o`3oool09P3ooolQ0:O0j`@0YKo/0`2D^_450;BohP030=ng[`3R_[@0h[jd0080h[jd0P3R`kT30>[8
/`80lM6`0`3cdZh20>o>/@<0j<Vf00<0h/Fk0<Rfb@38]/T00P38]/T20<JebP@0[jkG102Z/Md40:Jd
h`@0ZKGQ102W]N840:VjiP@0Z;WU2@2W^>D40:Bbh`<0X[;T102O[n<409RVg`<0SY_L1@2Oc?L20;Gj
j0@0]Mkd1@2Y`^`]0:O0j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002@0
oooo0P00000W0?ooob40Yl3[1@2U_n`209Bjl@@0];oR103R_[@30>;3^@80i<Nk0`3adK020??B[P<0
klja0P3XbKH30>;5^`80b;K90`36]LX50;B`e0@0Z[7M102[]=l40:Veh@@0ZK[U102Y^^H40:Nfh`@0
YkSU1@2U/^440:Bbh`<0X[;T0`2O[n<509:Ge@<0TJ?Q0`2Oc?L40;G`m@D0ZlK^<@2W`>/00`000000
Yl3[0:O0j`0;0:O0j`<0oooo00<000000?ooo`3oool00`3oool002H0oooo00<000000?ooo`3oool0
9@3ooolR0:O0j`@0YKo/0P2E^_4409Jom0<0h[jd0P3R`kT30>C7^`80jLnk0P3cdZh30>o>/@<0j<Vf
0`3RaK/40<JebP80a[K:102d/=@50:nbfP@0ZkCO102Z^><40:Vji@@0Z;CQ102W]^<40:Nch@@0YK;Q
102T/^<40:2ReP<0VI[C102BUmD4096Sh@<0XoKW1@2]cO040:S0jc40Yl3[00<000000:O0j`2W`>/0
1P2W`>/80?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo02D0oooo8P2W
`>/40:Fok080UK[a102F_o@0103R_[@0h/>i0>;3^@3R`kT20>C7^`<0jLnk0P3`e[L20?;I]P<0j<Vf
103RaK/00`3L`l40a[G:0<JebP040<JfbP80];3D0P2h/=840:nbfPD0[;?M102Z^><40:VagP@0Z;CQ
102Y]>440:Nch@<0YK;Q1@2TZMX40:2ReP<0VI[C0`2BUmD209S^l`030:?fi`2_eo@0[mOd00<0[mOd
1@2X`N`40:S0jc00Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`030000003oool0oooo0080oooo
000X0?ooo`030000003oool0oooo02H0oooo8@2W`>/40:Fok080Uk_a0`2F_o@30>;3^@<0i<Nk0`3Y
ck/20?3F]`80l]Vf00<0l=Zj0>S9]P3XbKH00`3RaK/30=c3`@D0a[K:1@2h/=820:nbfP80/JoF102/
/md50:b`f`@0ZK7N102[]N440:Vdh@@0YjgL0`2V[M`40:BYfP@0X:;F0`2IV]<409WAn`04087Xc`2_
h_P0[n;h0:oRn0@0ZL?]102X`N`e0:O0j`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0P3oool002T0oooo0P00000W0?ooob40Yl3[102U_n`209Zll0<0NKKi0P3R`kT20>C7^`<0jLnk0P3`
e[L20?;I]P<0l=Zj0`3RaK/40=c3`@040=S5a`36]/X0a[K:0<JfbP80akO;102h/=850;6_eP80[;?M
0P2`[mL40:b`f`D0[;CN102[]N440:NZf@@0YjgL0`2V[M`30:BYfPD0VIoH102G[nP00`21j<l0[n;h
0:oRn0020:oRn080Z/O^102Y`ndf0:O0j`<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`0U0?ooob40Yl3[102U_n`209Zll0<0NKKi0`3T
ak/30>W?^`80l=Jg0P3bfKH30?3J^P80jm[2103L`l430=S5a`030<JfbP37]l/0akO;0080akO;0P2h
/=820;^`c`@0/JoF1@2`[mL20:b`f`80[ZoI102/]=h20:^eh@<0Z:GC0`2WZ]T40:N]g0@0XIW=0`2M
V]0409VOf080IMW41@2XjoT50:[7kSD0Yl3[203oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo000/0?ooo`030000003oool0oooo02D0oooo8@2W`>/40:Fok0<0WKg_0`1T[_T3
0>W?^`80l=Jg0P3bfKH30?3J^P<0jm[200<0i=g>0=c3`@3L`l40103HaLL50<Ngb`D0^k3?102f[]84
0;2_e`D0[ZoI0`2/]=h50:RUd`<0Yj[I1@2TVl`30:6Ic@@0WI[@0P2IWmP409[^m@D0Z/_a1@2W_n/a
0:O0j`/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`00
0000oooo0?ooo`0V0?ooob00Yl3[102V_n`309fmk`<0E:gj0P3Yck/20?3F]`80l]Vf0`3`f[X20>_J
`P<0i=g>103HaLL20=C:d0<0akO;0P38_<l30;^`c`80_[C@102f[]840;6[dP@0[ZoI102ZX/h40:RU
d`@0Z9o=102TVl`40:6Ic@<0WI[@0`24jN/50:W>l`P0Yko[;P2W`>/?0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00@3oool002h0oooo00<000000?ooo`3oool09P3ooolP0:O0j`@0
Y[o/0`2P_^h305B]nP80l=Jg0P3bfKH30?3J^P<0jm[20P3TgLh20=OTg`80f<G7103Db]000`37]l/0
b;c?0<Rlc`020<Rlc`030;^`c`2n]=00_[C@0080_[C@0P2f[]820;R`d@@0/J_B102_YLd40:ZRcP80
Z:GC0P2^Z=830:ROc@@0Y9_<102QVLd00`1Yg><0Q>W[08CYj`050:S?m@@0Z<3[102W_n/40:S1k2T0
Yl3[503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000_0?ooo`800000
9`3ooolP0:O0j`D0Y/3/0`2P_^h206G?n@D0K]We0`3[f/820>CMcP@0enCO1@3Db]050<Rlc`D0_[C@
1@2h/=420;6[dP80^;;D102_YLd30:ZRcP@0[ZSB102XWld30:BKc080Lmo^0P1^gn440:K@mPD0Z<7/
102X`>/40:O1k0@0Z<7/9@2W`>/H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool09@3ooolU0:O0j`@0Xko]0P2@^o<505oCkP80i=g>00<0
=;WN0=OTg`3Gi=l00`2ik?D20=C:d0<0c=WR0P38_<l30<O;g@80_[C@0`32a]d40;R`d@D0^;;D0`2_
YLd40;Fjg@@0[ZSB0`2XWld207GPkP03063Gg@2Td?L0Y=3g00<0Y=3g202X`N`80:O1k0D0Yko[802W
`>/L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<00000
0?ooo`3oool09@3ooolU0:O0j`@0YKo/102L__0307Fdn@03001mfP0j0000^Nce00@0^Nce1@3<fN85
0<O;g@D0`/KM0P2h/=430;kBj@@0^;;D102gf?440;Fjg@<0[ZSB0P1Wfn800`16alH0HmG^0:?>mP03
0:?>mP@0Yl7/102X`N`50:O0k0<0Yl7/1@2W_n/40:O1k1`0Yl3[803oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0040oooo000c0?ooo`030000003oool0oooo02D0oooo9@2W`>/40:Fo
k0@0Xko]102B_?@205N]nPD0Gm?_102RjO/30<O;g@80ZNWj1032a]d50;kBj@80^;;D0`2<jO@30;OH
l@8000000P1ae_/40:;8l`@0X/_e202W`N`50:O0j`@0Z;o[102W_n/80:O1k1P0Yl3[903oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000d0?ooo`8000009P3ooolU0:O0j`@0
Yl3/102S_nd40:2ok`@0Rkcg102;__L30:;Yn`D0ZNWj1@2;j?H30;kBj@D0S>Wd0`2>cOd50:?5l@@0
X/Sc102W`>/40:O1k0T0Yl3[0`2X_n/80:O1k0D0Yko[4`2W`>/Y0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00@3oool003H0oooo00<000000?ooo`3oool09@3ooolT0:O0j`<0Yl3/
1@2V_n`30:2ok`D0Wko_0`2;__L509?0mP<0L;on1@2>`oT409o2l@@0V<Kg102T`^h40:?5l@D0Yko[
402W`>/40:O0k0@0Yl7/202W_n/@0:O0jb`0oooo00<000000?ooo`3oool01`3oool100000040oooo
0@3oool003L0oooo00<000000?ooo`3oool09@3oool/0:O0j`@0YKo/102V`>`40:6ok`@0Y<3]102M
`O440:?0kP@0Wl;a102U`>d40:C2kPD0Yko[202W`N`40:Noj`P0Yl3[102W`>`80:Noj`@0Z<3[302W
`>/`0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo000h0?ooo`030000003oool0
oooo02D0oooo<02W`>/80:K0k0@0Y<3]102V`>`40:?0kPD0Y/3/0`2U`>d50:O0j`P0Yl7/202W_n/8
0:O0j`@0Z;o[102W_n/40:O1k0@0Z<3[102W`>/h0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`40oooo000i0?ooo`8000009P3ooold0:O0j`@0Y/3/1@2W`>/30:K0k140Yl3[102W`N`70:No
j`d0Yl3[0`2X_n/80:O1k0D0Yko[>`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?oo
o`00>`3oool00`000000oooo0?ooo`0T0?oooe00Yl3[202W_n/40:O1k0`0Yl3[1@2W`>`80:Nojcl0
oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool003`0oooo00<000000?ooo`3oool0
903ooom<0:O0j`@0Z<3[102W_n/80:O1k0D0Yko[202W`>/40:Roj`@0Yko[@`3oool00`000000oooo
0?ooo`030?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?ooo`0T0?oood`0Yl3[102X
`>/50:O0k0<0Yl7/1@2W_n/<0:O0j`<0Z;o[B03oool00`000000oooo0?ooo`020?ooo`4000000@3o
ool10?ooo`00?P3oool2000002D0ooooD@2W`>/70:Noj`D0Yl3/2`2W`>];0?ooo`030000003oool0
oooo00<0oooo0@0000010?ooo`00@03oool00`000000oooo0?ooo`0S0?oood`0Yl3[1@2X`>/30:No
j`@0Yl7/102W`>`40:Noj`@0Yl3[C`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool00440
oooo00<000000?ooo`3oool08`3ooom<0:O0j`@0Z<3[102W`>`40:O1k0P0Yko[D`3oool01@000000
oooo0?ooo`3oool000000040oooo00120?ooo`030000003oool0oooo02@0ooooC`2W`>/40:O0k0P0
Yko[E`3oool010000000oooo0?ooo`0000010?ooo`00@`3oool2000002D0ooooC`2W`>/40:Nojeh0
oooo00@000000?ooo`3oool000000@3oool004D0oooo00<000000?ooo`3oool08`3ooom?0:O0jf80
oooo00<000000?ooo`0000000@3oool004H0oooo00<000000?ooo`3oool08`3ooom;0:O0jfH0oooo
0@0000010?ooo`40000000170?ooo`030000003oool0oooo02<0ooooA`2W`>]Z0?ooo`8000000018
0?ooo`8000009@3ooom20:O0jfd0oooo0P00000004X0oooo00<000000?ooo`3oool08`3oooln0:O0
jg00oooo0P00000004/0oooo00<000000?ooo`3oool08P3ooolk0:O0jfl0oooo100000020?ooo`00
C03oool00`000000oooo0?ooo`0S0?oooc<0Yl3[L@3oool4000000H0oooo001=0?ooo`800000903o
ool_0:O0jg00oooo1000000:0?ooo`00C`3oool00`000000oooo0?ooo`0R0?ooob/0Yl3[K`3oool4
000000h0oooo001@0?ooo`030000003oool0oooo02<0oooo9P2W`>]^0?ooo`@000004P3oool00540
oooo00<000000?ooo`3oool08`3ooolR0:O0jfh0oooo0`00000F0?ooo`00DP3oool2000002@0oooo
7P2W`>]]0?ooo`@000006@3oool005@0oooo00<000000?ooo`3oool08P3ooolG0:O0jfl0oooo1000
000M0?ooo`00E@3oool00`000000oooo0?ooo`0Q0?oooa@0Yl3[KP3oool400000240oooo001F0?oo
o`030000003oool0oooo0280oooo3`2W`>]]0?ooo`@000009@3oool005L0oooo0P00000S0?ooo`/0
Yl3[K03oool4000002T0oooo001I0?ooo`030000003oool0oooo0240oooo102W`>]_0?ooo`<00000
;@3oool005X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1Z0?ooo`@00000<03o
ool005/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1V0?ooo`@00000=03oool0
05`0oooo0P00000Q0?ooo`030000003oool0oooo0680oooo1000000h0?ooo`00GP3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo1000000l0?ooo`00G`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05X0oooo100000100?ooo`00H03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05L0oooo0`0000140?ooo`00H@3oool2000001`0oooo00<00000
0?ooo`3oool0D`3oool4000004L0oooo001S0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0C`3oool4000004/0oooo001T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0B`3oool4000004l0oooo001U0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
A`3oool4000005<0oooo001V0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0@`3o
ool4000005L0oooo001W0?ooo`8000005P3oool00`000000oooo0?ooo`100?ooo`<00000F`3oool0
06T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0l0?ooo`@00000GP3oool006X0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0h0?ooo`@00000HP3oool006/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`@00000IP3oool006`0oooo0P00
000@0?ooo`030000003oool0oooo0340oooo1000001Z0?ooo`00KP3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02d0oooo1000001^0?ooo`00K`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo02X0oooo0`00001b0?ooo`00L03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02H0oooo1000001e0?ooo`00L@3oool2000000/0oooo00<000000?ooo`3oool0
8P3oool4000007T0oooo001c0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3o
ool4000007d0oooo001d0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000840oooo001e0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool40000
08D0oooo001f0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`<00000R@3oool007P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`@00000S03oool007T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000T03oool007X0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`@00000U03oool007/0oooo0P0000000`3oool000000?ooo`04
0?ooo`@00000V03oool007d0oooo0P0000000`3oool0000000000002000009`0oooo001n0?ooo`80
0000X03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Mtetra
.656 .752 .92 r
.56155 .64914 .56753 .65509 .57895 .65187 .573 .6459 Mtetra
.656 .751 .92 r
.573 .6459 .57895 .65187 .59042 .64865 .5845 .64263 Mtetra
.5845 .64263 .59042 .64865 .60194 .64541 .59604 .63935 Mtetra
.655 .75 .92 r
.59604 .63935 .60194 .64541 .6135 .64214 .60764 .63608 Mtetra
.655 .751 .921 r
.60764 .63608 .6135 .64214 .62511 .63883 .61928 .63281 Mtetra
.655 .753 .922 r
.61928 .63281 .62511 .63883 .63677 .63552 .63098 .62952 Mtetra
.655 .755 .923 r
.63098 .62952 .63677 .63552 .64848 .63221 .64272 .6262 Mtetra
.64272 .6262 .64848 .63221 .66023 .6289 .65451 .62286 Mtetra
.65451 .62286 .66023 .6289 .67204 .62557 .66635 .6195 Mtetra
.66635 .6195 .67204 .62557 .68389 .62223 .67824 .61614 Mtetra
.67824 .61614 .68389 .62223 .6958 .61886 .69018 .61275 Mtetra
.656 .755 .923 r
.69018 .61275 .6958 .61886 .70775 .61549 .70217 .60935 Mtetra
.70217 .60935 .70775 .61549 .71976 .61211 .71421 .60593 Mtetra
.71421 .60593 .71976 .61211 .73182 .60875 .7263 .60249 Mtetra
.656 .753 .921 r
.7263 .60249 .73182 .60875 .74393 .60538 .73845 .59904 Mtetra
.656 .752 .92 r
.73845 .59904 .74393 .60538 .75609 .60196 .75064 .59557 Mtetra
.656 .751 .92 r
.75064 .59557 .75609 .60196 .7683 .5985 .76289 .5921 Mtetra
.76289 .5921 .7683 .5985 .78057 .59503 .77519 .58861 Mtetra
.656 .752 .92 r
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Mtetra
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .58159 Mtetra
.656 .751 .92 r
.79995 .58159 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Mtetra
.567 .63987 .573 .6459 .5845 .64263 .57853 .63659 Mtetra
.656 .752 .921 r
.57853 .63659 .5845 .64263 .59604 .63935 .59011 .6333 Mtetra
.59011 .6333 .59604 .63935 .60764 .63608 .60173 .62998 Mtetra
.657 .752 .92 r
.60173 .62998 .60764 .63608 .61928 .63281 .61341 .62663 Mtetra
.657 .75 .919 r
.61341 .62663 .61928 .63281 .63098 .62952 .62513 .62327 Mtetra
.656 .748 .918 r
.62513 .62327 .63098 .62952 .64272 .6262 .63691 .6199 Mtetra
.656 .748 .917 r
.63691 .6199 .64272 .6262 .65451 .62286 .64873 .61654 Mtetra
.64873 .61654 .65451 .62286 .66635 .6195 .66061 .61316 Mtetra
.66061 .61316 .66635 .6195 .67824 .61614 .67253 .60976 Mtetra
.67253 .60976 .67824 .61614 .69018 .61275 .6845 .60635 Mtetra
.6845 .60635 .69018 .61275 .70217 .60935 .69653 .60293 Mtetra
.656 .748 .918 r
.69653 .60293 .70217 .60935 .71421 .60593 .70861 .5995 Mtetra
.655 .748 .918 r
.70861 .5995 .71421 .60593 .7263 .60249 .72074 .59608 Mtetra
.655 .75 .919 r
.72074 .59608 .7263 .60249 .73845 .59904 .73292 .59263 Mtetra
.655 .751 .92 r
.73292 .59263 .73845 .59904 .75064 .59557 .74515 .58916 Mtetra
.656 .752 .92 r
.74515 .58916 .75064 .59557 .76289 .5921 .75744 .58565 Mtetra
.656 .751 .92 r
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58213 Mtetra
.76977 .58213 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.78216 .57861 .78754 .58511 .79995 .58159 .79461 .57507 Mtetra
.79461 .57507 .79995 .58159 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Mtetra
.57251 .63049 .57853 .63659 .59011 .6333 .58412 .62716 Mtetra
.655 .751 .92 r
.58412 .62716 .59011 .6333 .60173 .62998 .59578 .62383 Mtetra
.655 .751 .921 r
.59578 .62383 .60173 .62998 .61341 .62663 .60749 .62051 Mtetra
.655 .753 .922 r
.60749 .62051 .61341 .62663 .62513 .62327 .61925 .61717 Mtetra
.655 .755 .923 r
.61925 .61717 .62513 .62327 .63691 .6199 .63106 .61381 Mtetra
.63106 .61381 .63691 .6199 .64873 .61654 .64292 .61041 Mtetra
.656 .756 .923 r
.64292 .61041 .64873 .61654 .66061 .61316 .65483 .607 Mtetra
.655 .755 .923 r
.65483 .607 .66061 .61316 .67253 .60976 .66679 .60358 Mtetra
.66679 .60358 .67253 .60976 .6845 .60635 .6788 .60015 Mtetra
.655 .756 .924 r
.6788 .60015 .6845 .60635 .69653 .60293 .69086 .5967 Mtetra
.656 .756 .923 r
.69086 .5967 .69653 .60293 .70861 .5995 .70297 .59322 Mtetra
.656 .755 .923 r
.70297 .59322 .70861 .5995 .72074 .59608 .71513 .58971 Mtetra
.656 .753 .921 r
.71513 .58971 .72074 .59608 .73292 .59263 .72735 .58619 Mtetra
.656 .752 .92 r
.72735 .58619 .73292 .59263 .74515 .58916 .73962 .58267 Mtetra
.656 .751 .92 r
.73962 .58267 .74515 .58916 .75744 .58565 .75194 .57915 Mtetra
.75194 .57915 .75744 .58565 .76977 .58213 .76431 .57561 Mtetra
.76431 .57561 .76977 .58213 .78216 .57861 .77674 .57206 Mtetra
.656 .752 .92 r
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.656 .751 .92 r
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Mtetra
.655 .752 .921 r
.56645 .62435 .57251 .63049 .58412 .62716 .57809 .62101 Mtetra
.656 .752 .921 r
.57809 .62101 .58412 .62716 .59578 .62383 .58979 .61764 Mtetra
.657 .752 .92 r
.58979 .61764 .59578 .62383 .60749 .62051 .60153 .61423 Mtetra
.657 .75 .919 r
.60153 .61423 .60749 .62051 .61925 .61717 .61332 .61081 Mtetra
.657 .748 .917 r
.61332 .61081 .61925 .61717 .63106 .61381 .62516 .60739 Mtetra
.656 .747 .917 r
.62516 .60739 .63106 .61381 .64292 .61041 .63705 .60397 Mtetra
.63705 .60397 .64292 .61041 .65483 .607 .64899 .60054 Mtetra
.64899 .60054 .65483 .607 .66679 .60358 .66099 .59709 Mtetra
.66099 .59709 .66679 .60358 .6788 .60015 .67303 .59363 Mtetra
.67303 .59363 .6788 .60015 .69086 .5967 .68513 .59015 Mtetra
.68513 .59015 .69086 .5967 .70297 .59322 .69727 .58667 Mtetra
.655 .747 .918 r
.69727 .58667 .70297 .59322 .71513 .58971 .70948 .58319 Mtetra
.655 .749 .919 r
.70948 .58319 .71513 .58971 .72735 .58619 .72173 .57969 Mtetra
.655 .751 .92 r
.72173 .57969 .72735 .58619 .73962 .58267 .73404 .57617 Mtetra
.656 .752 .921 r
.73404 .57617 .73962 .58267 .75194 .57915 .7464 .57261 Mtetra
.656 .752 .92 r
.7464 .57261 .75194 .57915 .76431 .57561 .75881 .56903 Mtetra
.656 .751 .92 r
.75881 .56903 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Mtetra
.56034 .61815 .56645 .62435 .57809 .62101 .57202 .61477 Mtetra
.655 .75 .92 r
.57202 .61477 .57809 .62101 .58979 .61764 .58374 .61139 Mtetra
.655 .751 .921 r
.58374 .61139 .58979 .61764 .60153 .61423 .59552 .60802 Mtetra
.654 .753 .922 r
.59552 .60802 .60153 .61423 .61332 .61081 .60734 .60464 Mtetra
.655 .755 .924 r
.60734 .60464 .61332 .61081 .62516 .60739 .61922 .60123 Mtetra
.655 .757 .924 r
.61922 .60123 .62516 .60739 .63705 .60397 .63115 .59778 Mtetra
.63115 .59778 .63705 .60397 .64899 .60054 .64312 .59432 Mtetra
.655 .756 .924 r
.64312 .59432 .64899 .60054 .66099 .59709 .65515 .59084 Mtetra
.65515 .59084 .66099 .59709 .67303 .59363 .66723 .58736 Mtetra
.655 .757 .924 r
.66723 .58736 .67303 .59363 .68513 .59015 .67936 .58385 Mtetra
.656 .757 .924 r
.67936 .58385 .68513 .59015 .69727 .58667 .69155 .58031 Mtetra
.657 .756 .923 r
.69155 .58031 .69727 .58667 .70948 .58319 .70378 .57673 Mtetra
.657 .754 .921 r
.70378 .57673 .70948 .58319 .72173 .57969 .71607 .57315 Mtetra
.656 .752 .92 r
.71607 .57315 .72173 .57969 .73404 .57617 .72841 .56957 Mtetra
.656 .751 .92 r
.72841 .56957 .73404 .57617 .7464 .57261 .74081 .566 Mtetra
.74081 .566 .7464 .57261 .75881 .56903 .75326 .56241 Mtetra
.75326 .56241 .75881 .56903 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64514 Mtetra
.43976 .64514 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Mtetra
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Mtetra
.655 .751 .92 r
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61192 Mtetra
.655 .752 .921 r
.55418 .61192 .56034 .61815 .57202 .61477 .56589 .60854 Mtetra
.656 .753 .921 r
.56589 .60854 .57202 .61477 .58374 .61139 .57765 .60512 Mtetra
.657 .752 .92 r
.57765 .60512 .58374 .61139 .59552 .60802 .58946 .60166 Mtetra
.657 .75 .919 r
.58946 .60166 .59552 .60802 .60734 .60464 .60132 .59819 Mtetra
.656 .748 .918 r
.60132 .59819 .60734 .60464 .61922 .60123 .61323 .59473 Mtetra
.655 .747 .917 r
.61323 .59473 .61922 .60123 .63115 .59778 .62519 .59128 Mtetra
.655 .748 .918 r
.62519 .59128 .63115 .59778 .64312 .59432 .6372 .58781 Mtetra
.656 .749 .918 r
.6372 .58781 .64312 .59432 .65515 .59084 .64926 .58431 Mtetra
.657 .749 .918 r
.64926 .58431 .65515 .59084 .66723 .58736 .66138 .58077 Mtetra
.657 .748 .918 r
.66138 .58077 .66723 .58736 .67936 .58385 .67354 .57721 Mtetra
.656 .748 .917 r
.67354 .57721 .67936 .58385 .69155 .58031 .68576 .57366 Mtetra
.655 .748 .918 r
.68576 .57366 .69155 .58031 .70378 .57673 .69804 .57013 Mtetra
.655 .75 .92 r
.69804 .57013 .70378 .57673 .71607 .57315 .71036 .56657 Mtetra
.656 .752 .921 r
.71036 .56657 .71607 .57315 .72841 .56957 .72275 .56298 Mtetra
.656 .753 .921 r
.72275 .56298 .72841 .56957 .74081 .566 .73518 .55935 Mtetra
.656 .752 .92 r
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Mtetra
.656 .751 .92 r
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Mtetra
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64514 .43325 .63911 Mtetra
.43325 .63911 .43976 .64514 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Mtetra
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Mtetra
.655 .751 .921 r
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60905 Mtetra
.655 .752 .921 r
.53629 .60905 .54252 .6153 .55418 .61192 .54798 .60566 Mtetra
.654 .752 .922 r
.54798 .60566 .55418 .61192 .56589 .60854 .55972 .60228 Mtetra
.651 .752 .924 r
.55972 .60228 .56589 .60854 .57765 .60512 .57151 .59898 Mtetra
.647 .755 .928 r
.57151 .59898 .57765 .60512 .58946 .60166 .58336 .59576 Mtetra
.643 .763 .936 r
.58336 .59576 .58946 .60166 .60132 .59819 .59526 .59259 Mtetra
.641 .774 .944 r
.59526 .59259 .60132 .59819 .61323 .59473 .60721 .58939 Mtetra
.642 .784 .95 r
.60721 .58939 .61323 .59473 .62519 .59128 .61922 .5861 Mtetra
.644 .792 .953 r
.61922 .5861 .62519 .59128 .6372 .58781 .63127 .5827 Mtetra
.648 .797 .954 r
.63127 .5827 .6372 .58781 .64926 .58431 .64338 .57918 Mtetra
.653 .798 .952 r
.64338 .57918 .64926 .58431 .66138 .58077 .65553 .57551 Mtetra
.657 .796 .949 r
.65553 .57551 .66138 .58077 .67354 .57721 .66773 .57174 Mtetra
.661 .79 .943 r
.66773 .57174 .67354 .57721 .68576 .57366 .67997 .56787 Mtetra
.663 .781 .936 r
.67997 .56787 .68576 .57366 .69804 .57013 .69227 .56398 Mtetra
.662 .769 .929 r
.69227 .56398 .69804 .57013 .71036 .56657 .70462 .56013 Mtetra
.66 .76 .924 r
.70462 .56013 .71036 .56657 .72275 .56298 .71703 .55637 Mtetra
.657 .754 .921 r
.71703 .55637 .72275 .56298 .73518 .55935 .7295 .55267 Mtetra
.656 .753 .921 r
.7295 .55267 .73518 .55935 .74767 .55572 .74203 .549 Mtetra
.656 .752 .921 r
.74203 .549 .74767 .55572 .76021 .55208 .75461 .54532 Mtetra
.656 .752 .92 r
.75461 .54532 .76021 .55208 .77281 .54842 .76725 .54162 Mtetra
.656 .751 .92 r
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Mtetra
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Mtetra
.655 .751 .92 r
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60958 Mtetra
.654 .751 .921 r
.5067 .60958 .51305 .61582 .52464 .61244 .51833 .60621 Mtetra
.651 .752 .923 r
.51833 .60621 .52464 .61244 .53629 .60905 .53 .60291 Mtetra
.644 .753 .929 r
.53 .60291 .53629 .60905 .54798 .60566 .54173 .59979 Mtetra
.631 .76 .94 r
.54173 .59979 .54798 .60566 .55972 .60228 .55351 .59693 Mtetra
.614 .773 .957 r
.55351 .59693 .55972 .60228 .57151 .59898 .56535 .59433 Mtetra
.593 .794 .976 r
.56535 .59433 .57151 .59898 .58336 .59576 .57725 .59191 Mtetra
.568 .817 .992 r
.57725 .59191 .58336 .59576 .59526 .59259 .5892 .58956 Mtetra
.541 .84 .999 r
.5892 .58956 .59526 .59259 .60721 .58939 .60122 .58711 Mtetra
.519 .86 .994 r
.60122 .58711 .60721 .58939 .61922 .5861 .61329 .5844 Mtetra
.51 .876 .981 r
.61329 .5844 .61922 .5861 .63127 .5827 .62541 .58131 Mtetra
.524 .89 .973 r
.62541 .58131 .63127 .5827 .64338 .57918 .63756 .57776 Mtetra
.558 .904 .974 r
.63756 .57776 .64338 .57918 .65553 .57551 .64976 .57375 Mtetra
.603 .911 .98 r
.64976 .57375 .65553 .57551 .66773 .57174 .66199 .56934 Mtetra
.643 .904 .983 r
.66199 .56934 .66773 .57174 .67997 .56787 .67425 .56468 Mtetra
.668 .882 .977 r
.67425 .56468 .67997 .56787 .69227 .56398 .68656 .55991 Mtetra
.679 .852 .965 r
.68656 .55991 .69227 .56398 .70462 .56013 .69892 .55519 Mtetra
.679 .82 .951 r
.69892 .55519 .70462 .56013 .71703 .55637 .71133 .55066 Mtetra
.673 .791 .938 r
.71133 .55066 .71703 .55637 .7295 .55267 .72381 .54639 Mtetra
.665 .77 .928 r
.72381 .54639 .7295 .55267 .74203 .549 .73636 .54238 Mtetra
.66 .758 .923 r
.73636 .54238 .74203 .549 .75461 .54532 .74897 .53854 Mtetra
.657 .753 .921 r
.74897 .53854 .75461 .54532 .76725 .54162 .76164 .53478 Mtetra
.656 .752 .92 r
.76164 .53478 .76725 .54162 .77994 .53792 .77437 .53104 Mtetra
.656 .751 .92 r
.77437 .53104 .77994 .53792 .79269 .5342 .78716 .52728 Mtetra
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Mtetra
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61009 Mtetra
.655 .751 .921 r
.47713 .61009 .4836 .61634 .49513 .61296 .48869 .60671 Mtetra
.651 .751 .923 r
.48869 .60671 .49513 .61296 .5067 .60958 .5003 .60341 Mtetra
.642 .752 .929 r
.5003 .60341 .5067 .60958 .51833 .60621 .51196 .60035 Mtetra
.619 .756 .944 r
.51196 .60035 .51833 .60621 .53 .60291 .52366 .59778 Mtetra
.576 .769 .97 r
.52366 .59778 .53 .60291 .54173 .59979 .53543 .59589 Mtetra
.495 .787 .997 r
.53543 .59589 .54173 .59979 .55351 .59693 .54726 .59466 Mtetra
.358 .782 .974 r
.54726 .59466 .55351 .59693 .56535 .59433 .55917 .59377 Mtetra
.194 .72 .848 r
.55917 .59377 .56535 .59433 .57725 .59191 .57114 .59273 Mtetra
.098 .652 .703 r
.57114 .59273 .57725 .59191 .5892 .58956 .58316 .59108 Mtetra
0 0 0 r
.58316 .59108 .5892 .58956 .60122 .58711 .59524 .58869 Mtetra
.59524 .58869 .60122 .58711 .61329 .5844 .60737 .58568 Mtetra
.233 .746 .731 r
.60737 .58568 .61329 .5844 .62541 .58131 .61954 .58231 Mtetra
.284 .783 .774 r
.61954 .58231 .62541 .58131 .63756 .57776 .63176 .57874 Mtetra
.303 .796 .781 r
.63176 .57874 .63756 .57776 .64976 .57375 .64403 .57498 Mtetra
.309 .797 .763 r
.64403 .57498 .64976 .57375 .66199 .56934 .65634 .57084 Mtetra
.337 .811 .749 r
.65634 .57084 .66199 .56934 .67425 .56468 .66867 .56608 Mtetra
.417 .86 .781 r
.66867 .56608 .67425 .56468 .68656 .55991 .68101 .56056 Mtetra
.543 .928 .864 r
.68101 .56056 .68656 .55991 .69892 .55519 .69337 .55442 Mtetra
.656 .956 .942 r
.69337 .55442 .69892 .55519 .71133 .55066 .70575 .54809 Mtetra
.703 .918 .967 r
.70575 .54809 .71133 .55066 .72381 .54639 .71818 .54211 Mtetra
.7 .854 .956 r
.71818 .54211 .72381 .54639 .73636 .54238 .7307 .53679 Mtetra
.682 .802 .939 r
.7307 .53679 .73636 .54238 .74897 .53854 .74331 .53216 Mtetra
.667 .771 .928 r
.74331 .53216 .74897 .53854 .76164 .53478 .756 .52802 Mtetra
.659 .757 .922 r
.756 .52802 .76164 .53478 .77437 .53104 .76876 .52413 Mtetra
.657 .753 .921 r
.76876 .52413 .77437 .53104 .78716 .52728 .78159 .52032 Mtetra
.656 .752 .92 r
.78159 .52032 .78716 .52728 .80001 .52351 .79448 .51651 Mtetra
.656 .751 .92 r
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Mtetra
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Mtetra
.655 .751 .92 r
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .60721 Mtetra
.654 .751 .921 r
.45908 .60721 .46562 .61348 .47713 .61009 .47062 .60384 Mtetra
.647 .751 .925 r
.47062 .60384 .47713 .61009 .48869 .60671 .48221 .60064 Mtetra
.627 .751 .936 r
.48221 .60064 .48869 .60671 .5003 .60341 .49384 .59793 Mtetra
.575 .756 .963 r
.49384 .59793 .5003 .60341 .51196 .60035 .50552 .59618 Mtetra
.457 .759 .995 r
.50552 .59618 .51196 .60035 .52366 .59778 .51727 .59561 Mtetra
.232 .713 .934 r
.51727 .59561 .52366 .59778 .53543 .59589 .52908 .59577 Mtetra
.051 .618 .746 r
.52908 .59577 .53543 .59589 .54726 .59466 .54097 .59548 Mtetra
.126 .674 .721 r
.54097 .59548 .54726 .59466 .55917 .59377 .55292 .59364 Mtetra
.437 .871 .909 r
.55292 .59364 .55917 .59377 .57114 .59273 .56491 .59 Mtetra
.668 .892 .978 r
.56491 .59 .57114 .59273 .58316 .59108 .57693 .5852 Mtetra
.703 .787 .916 r
.57693 .5852 .58316 .59108 .59524 .58869 .589 .58012 Mtetra
.686 .707 .864 r
.589 .58012 .59524 .58869 .60737 .58568 .60111 .57534 Mtetra
.666 .663 .837 r
.60111 .57534 .60737 .58568 .61954 .58231 .61328 .57113 Mtetra
.649 .641 .828 r
.61328 .57113 .61954 .58231 .63176 .57874 .62553 .56753 Mtetra
.635 .634 .832 r
.62553 .56753 .63176 .57874 .64403 .57498 .63784 .56456 Mtetra
.622 .644 .851 r
.63784 .56456 .64403 .57498 .65634 .57084 .65024 .56214 Mtetra
.61 .678 .89 r
.65024 .56214 .65634 .57084 .66867 .56608 .66271 .56004 Mtetra
.602 .757 .952 r
.66271 .56004 .66867 .56608 .68101 .56056 .67524 .55764 Mtetra
.589 .872 .994 r
.67524 .55764 .68101 .56056 .69337 .55442 .68777 .55407 Mtetra
.564 .931 .924 r
.68777 .55407 .69337 .55442 .70575 .54809 .70027 .54867 Mtetra
.601 .952 .87 r
.70027 .54867 .70575 .54809 .71818 .54211 .71272 .54168 Mtetra
.692 .973 .919 r
.71272 .54168 .71818 .54211 .7307 .53679 .72518 .53422 Mtetra
.729 .926 .957 r
.72518 .53422 .7307 .53679 .74331 .53216 .73771 .52748 Mtetra
.706 .845 .949 r
.73771 .52748 .74331 .53216 .756 .52802 .75036 .52195 Mtetra
.678 .789 .933 r
.75036 .52195 .756 .52802 .76876 .52413 .76312 .5174 Mtetra
.663 .762 .924 r
.76312 .5174 .76876 .52413 .78159 .52032 .77598 .51335 Mtetra
.657 .754 .921 r
.77598 .51335 .78159 .52032 .79448 .51651 .7889 .50946 Mtetra
.656 .752 .92 r
.7889 .50946 .79448 .51651 .80742 .51269 .80189 .5056 Mtetra
.656 .751 .92 r
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Mtetra
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Mtetra
.655 .751 .92 r
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60432 Mtetra
.654 .751 .921 r
.44096 .60432 .44759 .61061 .45908 .60721 .45248 .60095 Mtetra
.644 .75 .926 r
.45248 .60095 .45908 .60721 .47062 .60384 .46405 .59781 Mtetra
.613 .749 .942 r
.46405 .59781 .47062 .60384 .48221 .60064 .47566 .59541 Mtetra
.524 .747 .977 r
.47566 .59541 .48221 .60064 .49384 .59793 .4873 .59443 Mtetra
.306 .712 .977 r
.4873 .59443 .49384 .59793 .50552 .59618 .49901 .59501 Mtetra
.035 .597 .799 r
.49901 .59501 .50552 .59618 .51727 .59561 .51079 .59583 Mtetra
.112 .665 .758 r
.51079 .59583 .51727 .59561 .52908 .59577 .52265 .59473 Mtetra
.555 .908 .968 r
.52265 .59473 .52908 .59577 .54097 .59548 .53458 .59065 Mtetra
.734 .826 .922 r
.53458 .59065 .54097 .59548 .55292 .59364 .54654 .58459 Mtetra
.716 .706 .839 r
.54654 .58459 .55292 .59364 .56491 .59 .55853 .57831 Mtetra
.685 .647 .806 r
.55853 .57831 .56491 .59 .57693 .5852 .57057 .57283 Mtetra
.666 .628 .803 r
.57057 .57283 .57693 .5852 .589 .58012 .58266 .56823 Mtetra
.656 .632 .814 r
.58266 .56823 .589 .58012 .60111 .57534 .5948 .56419 Mtetra
.653 .643 .828 r
.5948 .56419 .60111 .57534 .61328 .57113 .60701 .56042 Mtetra
.651 .651 .837 r
.60701 .56042 .61328 .57113 .62553 .56753 .61927 .55679 Mtetra
.647 .65 .838 r
.61927 .55679 .62553 .56753 .63784 .56456 .63159 .5533 Mtetra
.639 .637 .832 r
.63159 .5533 .63784 .56456 .65024 .56214 .64398 .55009 Mtetra
.625 .618 .823 r
.64398 .55009 .65024 .56214 .66271 .56004 .65644 .54744 Mtetra
.604 .599 .82 r
.65644 .54744 .66271 .56004 .67524 .55764 .66901 .54568 Mtetra
.583 .6 .835 r
.66901 .54568 .67524 .55764 .68777 .55407 .68169 .54473 Mtetra
.58 .653 .886 r
.68169 .54473 .68777 .55407 .70027 .54867 .69443 .54355 Mtetra
.621 .801 .969 r
.69443 .54355 .70027 .54867 .71272 .54168 .70714 .54035 Mtetra
.668 .949 .955 r
.70714 .54035 .71272 .54168 .72518 .53422 .71974 .5341 Mtetra
.709 .982 .899 r
.71974 .5341 .72518 .53422 .73771 .52748 .73226 .52589 Mtetra
.752 .962 .935 r
.73226 .52589 .73771 .52748 .75036 .52195 .74481 .51792 Mtetra
.73 .877 .949 r
.74481 .51792 .75036 .52195 .76312 .5174 .7575 .51152 Mtetra
.688 .801 .935 r
.7575 .51152 .76312 .5174 .77598 .51335 .77033 .50659 Mtetra
.665 .765 .925 r
.77033 .50659 .77598 .51335 .7889 .50946 .78328 .50241 Mtetra
.658 .754 .921 r
.78328 .50241 .7889 .50946 .80189 .5056 .7963 .49846 Mtetra
.656 .752 .92 r
.7963 .49846 .80189 .5056 .81493 .50174 .80939 .49455 Mtetra
.656 .751 .92 r
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Mtetra
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .60141 Mtetra
.654 .751 .921 r
.42277 .60141 .42948 .60773 .44096 .60432 .43428 .59802 Mtetra
.645 .75 .926 r
.43428 .59802 .44096 .60432 .45248 .60095 .44582 .59486 Mtetra
.609 .747 .943 r
.44582 .59486 .45248 .60095 .46405 .59781 .45741 .59254 Mtetra
.496 .735 .979 r
.45741 .59254 .46405 .59781 .47566 .59541 .46902 .592 Mtetra
.207 .658 .947 r
.46902 .592 .47566 .59541 .4873 .59443 .48067 .59338 Mtetra
0 .54 .747 r
.48067 .59338 .4873 .59443 .49901 .59501 .49241 .59465 Mtetra
.269 .771 .869 r
.49241 .59465 .49901 .59501 .51079 .59583 .50426 .59282 Mtetra
.71 .887 .962 r
.50426 .59282 .51079 .59583 .52265 .59473 .51617 .58725 Mtetra
.742 .748 .857 r
.51617 .58725 .52265 .59473 .53458 .59065 .52813 .5802 Mtetra
.706 .676 .818 r
.52813 .5802 .53458 .59065 .54654 .58459 .54011 .57392 Mtetra
.682 .663 .825 r
.54011 .57392 .54654 .58459 .55853 .57831 .55214 .56886 Mtetra
.673 .684 .852 r
.55214 .56886 .55853 .57831 .57057 .57283 .56421 .56447 Mtetra
.67 .709 .877 r
.56421 .56447 .57057 .57283 .58266 .56823 .57634 .56035 Mtetra
.666 .721 .889 r
.57634 .56035 .58266 .56823 .5948 .56419 .58852 .55636 Mtetra
.662 .721 .893 r
.58852 .55636 .5948 .56419 .60701 .56042 .60076 .55252 Mtetra
.656 .718 .894 r
.60076 .55252 .60701 .56042 .61927 .55679 .61305 .54887 Mtetra
.65 .716 .896 r
.61305 .54887 .61927 .55679 .63159 .5533 .62541 .54539 Mtetra
.645 .715 .899 r
.62541 .54539 .63159 .5533 .64398 .55009 .63782 .54207 Mtetra
.64 .712 .899 r
.63782 .54207 .64398 .55009 .65644 .54744 .6503 .53889 Mtetra
.633 .695 .89 r
.6503 .53889 .65644 .54744 .66901 .54568 .66285 .53596 Mtetra
.613 .66 .872 r
.66285 .53596 .66901 .54568 .68169 .54473 .6755 .53372 Mtetra
.581 .618 .854 r
.6755 .53372 .68169 .54473 .69443 .54355 .68827 .53271 Mtetra
.557 .61 .862 r
.68827 .53271 .69443 .54355 .70714 .54035 .70116 .53247 Mtetra
.588 .699 .919 r
.70116 .53247 .70714 .54035 .71974 .5341 .71405 .53073 Mtetra
.692 .892 .97 r
.71405 .53073 .71974 .5341 .73226 .52589 .72679 .52515 Mtetra
.755 .982 .911 r
.72679 .52515 .73226 .52589 .74481 .51792 .73936 .51639 Mtetra
.779 .968 .921 r
.73936 .51639 .74481 .51792 .7575 .51152 .75195 .50752 Mtetra
.744 .884 .944 r
.75195 .50752 .7575 .51152 .77033 .50659 .76471 .50061 Mtetra
.691 .802 .933 r
.76471 .50061 .77033 .50659 .78328 .50241 .77763 .49553 Mtetra
.665 .764 .924 r
.77763 .49553 .78328 .50241 .7963 .49846 .79068 .4913 Mtetra
.657 .754 .921 r
.79068 .4913 .7963 .49846 .80939 .49455 .8038 .48731 Mtetra
.656 .752 .92 r
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Mtetra
.656 .751 .92 r
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Mtetra
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Mtetra
.655 .751 .921 r
.40452 .59849 .41132 .60484 .42277 .60141 .41601 .59507 Mtetra
.648 .75 .924 r
.41601 .59507 .42277 .60141 .43428 .59802 .42754 .5918 Mtetra
.618 .746 .938 r
.42754 .5918 .43428 .59802 .44582 .59486 .4391 .58928 Mtetra
.509 .73 .973 r
.4391 .58928 .44582 .59486 .45741 .59254 .45068 .58865 Mtetra
.193 .634 .946 r
.45068 .58865 .45741 .59254 .46902 .592 .46228 .59049 Mtetra
0 .481 .726 r
.46228 .59049 .46902 .592 .48067 .59338 .47396 .59268 Mtetra
.261 .762 .884 r
.47396 .59268 .48067 .59338 .49241 .59465 .48578 .59124 Mtetra
.734 .875 .946 r
.48578 .59124 .49241 .59465 .50426 .59282 .4977 .5851 Mtetra
.755 .745 .844 r
.4977 .5851 .50426 .59282 .51617 .58725 .50966 .57724 Mtetra
.72 .689 .819 r
.50966 .57724 .51617 .58725 .52813 .5802 .52164 .57035 Mtetra
.697 .684 .834 r
.52164 .57035 .52813 .5802 .54011 .57392 .53365 .56476 Mtetra
.684 .695 .854 r
.53365 .56476 .54011 .57392 .55214 .56886 .54571 .55995 Mtetra
.673 .697 .864 r
.54571 .55995 .55214 .56886 .56421 .56447 .55781 .55561 Mtetra
.664 .696 .869 r
.55781 .55561 .56421 .56447 .57634 .56035 .56997 .55161 Mtetra
.659 .698 .875 r
.56997 .55161 .57634 .56035 .58852 .55636 .58219 .54782 Mtetra
.656 .702 .881 r
.58219 .54782 .58852 .55636 .60076 .55252 .59445 .5441 Mtetra
.655 .706 .884 r
.59445 .5441 .60076 .55252 .61305 .54887 .60678 .54042 Mtetra
.654 .705 .885 r
.60678 .54042 .61305 .54887 .62541 .54539 .61916 .53676 Mtetra
.651 .7 .882 r
.61916 .53676 .62541 .54539 .63782 .54207 .6316 .53319 Mtetra
.645 .693 .88 r
.6316 .53319 .63782 .54207 .6503 .53889 .6441 .52981 Mtetra
.635 .685 .88 r
.6441 .52981 .6503 .53889 .66285 .53596 .65668 .52679 Mtetra
.62 .677 .882 r
.65668 .52679 .66285 .53596 .6755 .53372 .66934 .52424 Mtetra
.597 .66 .882 r
.66934 .52424 .6755 .53372 .68827 .53271 .6821 .52247 Mtetra
.558 .625 .875 r
.6821 .52247 .68827 .53271 .70116 .53247 .695 .52202 Mtetra
.527 .606 .875 r
.695 .52202 .70116 .53247 .71405 .53073 .70804 .52255 Mtetra
.57 .685 .918 r
.70804 .52255 .71405 .53073 .72679 .52515 .72107 .52131 Mtetra
.713 .883 .959 r
.72107 .52131 .72679 .52515 .73936 .51639 .73388 .51526 Mtetra
.798 .979 .902 r
.73388 .51526 .73936 .51639 .75195 .50752 .74649 .50548 Mtetra
.802 .957 .915 r
.74649 .50548 .75195 .50752 .76471 .50061 .75913 .49605 Mtetra
.743 .867 .937 r
.75913 .49605 .76471 .50061 .77763 .49553 .77198 .48916 Mtetra
.686 .79 .929 r
.77198 .48916 .77763 .49553 .79068 .4913 .78501 .48422 Mtetra
.662 .76 .922 r
.78501 .48422 .79068 .4913 .8038 .48731 .79817 .48004 Mtetra
.657 .753 .921 r
.79817 .48004 .8038 .48731 .81699 .48336 .8114 .47602 Mtetra
.656 .751 .92 r
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Mtetra
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Mtetra
.655 .751 .92 r
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .59211 Mtetra
.652 .751 .922 r
.39767 .59211 .40452 .59849 .41601 .59507 .40919 .58872 Mtetra
.633 .748 .93 r
.40919 .58872 .41601 .59507 .42754 .5918 .42074 .58582 Mtetra
.554 .734 .959 r
.42074 .58582 .42754 .5918 .4391 .58928 .4323 .58454 Mtetra
.277 .652 .968 r
.4323 .58454 .4391 .58928 .45068 .58865 .44385 .58621 Mtetra
0 .42 .727 r
.44385 .58621 .45068 .58865 .46228 .59049 .45545 .58965 Mtetra
.041 .606 .783 r
.45545 .58965 .46228 .59049 .47396 .59268 .46721 .59009 Mtetra
.707 .901 .966 r
.46721 .59009 .47396 .59268 .48578 .59124 .47912 .58445 Mtetra
.781 .773 .845 r
.47912 .58445 .48578 .59124 .4977 .5851 .4911 .57548 Mtetra
.744 .704 .814 r
.4911 .57548 .4977 .5851 .50966 .57724 .5031 .56728 Mtetra
.709 .687 .827 r
.5031 .56728 .50966 .57724 .52164 .57035 .51511 .56104 Mtetra
.683 .692 .852 r
.51511 .56104 .52164 .57035 .53365 .56476 .52715 .55621 Mtetra
.668 .705 .875 r
.52715 .55621 .53365 .56476 .54571 .55995 .53924 .55211 Mtetra
.662 .722 .893 r
.53924 .55211 .54571 .55995 .55781 .55561 .55138 .54823 Mtetra
.661 .735 .904 r
.55138 .54823 .55781 .55561 .56997 .55161 .56358 .54438 Mtetra
.661 .74 .909 r
.56358 .54438 .56997 .55161 .58219 .54782 .57582 .54054 Mtetra
.659 .739 .909 r
.57582 .54054 .58219 .54782 .59445 .5441 .58813 .53675 Mtetra
.656 .736 .909 r
.58813 .53675 .59445 .5441 .60678 .54042 .60048 .53303 Mtetra
.653 .735 .91 r
.60048 .53303 .60678 .54042 .61916 .53676 .6129 .5294 Mtetra
.65 .736 .912 r
.6129 .5294 .61916 .53676 .6316 .53319 .62537 .52581 Mtetra
.65 .737 .913 r
.62537 .52581 .6316 .53319 .6441 .52981 .63791 .52224 Mtetra
.649 .731 .909 r
.63791 .52224 .6441 .52981 .65668 .52679 .6505 .51868 Mtetra
.642 .715 .901 r
.6505 .51868 .65668 .52679 .66934 .52424 .66316 .51536 Mtetra
.62 .686 .891 r
.66316 .51536 .66934 .52424 .6821 .52247 .67591 .51276 Mtetra
.577 .648 .884 r
.67591 .51276 .6821 .52247 .695 .52202 .68881 .5116 Mtetra
.514 .601 .878 r
.68881 .5116 .695 .52202 .70804 .52255 .70189 .51243 Mtetra
.482 .592 .887 r
.70189 .51243 .70804 .52255 .72107 .52131 .7151 .51402 Mtetra
.581 .719 .937 r
.7151 .51402 .72107 .52131 .73388 .51526 .72822 .51219 Mtetra
.771 .922 .937 r
.72822 .51219 .73388 .51526 .74649 .50548 .741 .50414 Mtetra
.837 .974 .881 r
.741 .50414 .74649 .50548 .75913 .49605 .7536 .49299 Mtetra
.806 .928 .915 r
.7536 .49299 .75913 .49605 .77198 .48916 .76634 .48366 Mtetra
.725 .832 .931 r
.76634 .48366 .77198 .48916 .78501 .48422 .77933 .47737 Mtetra
.674 .773 .925 r
.77933 .47737 .78501 .48422 .79817 .48004 .79249 .47275 Mtetra
.659 .755 .921 r
.79249 .47275 .79817 .48004 .8114 .47602 .80576 .46863 Mtetra
.656 .752 .92 r
.80576 .46863 .8114 .47602 .82469 .47202 .81909 .46458 Mtetra
.656 .751 .92 r
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44825 Mtetra
.87306 .44825 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Mtetra
.655 .751 .921 r
.37927 .58915 .38621 .59557 .39767 .59211 .39077 .58568 Mtetra
.647 .75 .924 r
.39077 .58568 .39767 .59211 .40919 .58872 .40231 .58243 Mtetra
.604 .742 .942 r
.40231 .58243 .40919 .58872 .42074 .58582 .41387 .58019 Mtetra
.425 .695 .976 r
.41387 .58019 .42074 .58582 .4323 .58454 .4254 .58071 Mtetra
0 .448 .814 r
.4254 .58071 .4323 .58454 .44385 .58621 .43693 .58471 Mtetra
.263 0 0 r
.43693 .58471 .44385 .58621 .45545 .58965 .44856 .58824 Mtetra
.492 .873 .975 r
.44856 .58824 .45545 .58965 .46721 .59009 .46042 .58522 Mtetra
.807 .828 .867 r
.46042 .58522 .46721 .59009 .47912 .58445 .47244 .57573 Mtetra
.78 .731 .807 r
.47244 .57573 .47912 .58445 .4911 .57548 .48447 .56549 Mtetra
.731 .694 .815 r
.48447 .56549 .4911 .57548 .5031 .56728 .49649 .5579 Mtetra
.694 .695 .847 r
.49649 .5579 .5031 .56728 .51511 .56104 .50853 .55256 Mtetra
.676 .71 .874 r
.50853 .55256 .51511 .56104 .52715 .55621 .5206 .54814 Mtetra
.67 .719 .886 r
.5206 .54814 .52715 .55621 .53924 .55211 .53272 .54397 Mtetra
.665 .717 .887 r
.53272 .54397 .53924 .55211 .55138 .54823 .54489 .53997 Mtetra
.66 .712 .887 r
.54489 .53997 .55138 .54823 .56358 .54438 .55712 .53612 Mtetra
.657 .712 .888 r
.55712 .53612 .56358 .54438 .57582 .54054 .5694 .53236 Mtetra
.656 .715 .892 r
.5694 .53236 .57582 .54054 .58813 .53675 .58173 .52864 Mtetra
.656 .717 .894 r
.58173 .52864 .58813 .53675 .60048 .53303 .59413 .52489 Mtetra
.59413 .52489 .60048 .53303 .6129 .5294 .60657 .52113 Mtetra
.654 .714 .892 r
.60657 .52113 .6129 .5294 .62537 .52581 .61907 .51739 Mtetra
.651 .71 .891 r
.61907 .51739 .62537 .52581 .63791 .52224 .63164 .51375 Mtetra
.646 .707 .892 r
.63164 .51375 .63791 .52224 .6505 .51868 .64427 .51028 Mtetra
.641 .708 .896 r
.64427 .51028 .6505 .51868 .66316 .51536 .65696 .50696 Mtetra
.632 .706 .899 r
.65696 .50696 .66316 .51536 .67591 .51276 .66973 .5039 Mtetra
.603 .682 .897 r
.66973 .5039 .67591 .51276 .68881 .5116 .68261 .50177 Mtetra
.531 .625 .89 r
.68261 .50177 .68881 .5116 .70189 .51243 .69567 .50191 Mtetra
.435 .559 .881 r
.69567 .50191 .70189 .51243 .7151 .51402 .70898 .50475 Mtetra
.445 .597 .908 r
.70898 .50475 .7151 .51402 .72822 .51219 .72235 .5068 Mtetra
.668 .819 .956 r
.72235 .5068 .72822 .51219 .741 .50414 .73542 .50222 Mtetra
.845 .96 .883 r
.73542 .50222 .741 .50414 .7536 .49299 .74808 .49089 Mtetra
.856 .955 .875 r
.74808 .49089 .7536 .49299 .76634 .48366 .76072 .47909 Mtetra
.777 .877 .92 r
.76072 .47909 .76634 .48366 .77933 .47737 .77362 .47088 Mtetra
.696 .794 .926 r
.77362 .47088 .77933 .47737 .79249 .47275 .78678 .46551 Mtetra
.664 .76 .922 r
.78678 .46551 .79249 .47275 .80576 .46863 .80007 .46119 Mtetra
.657 .752 .92 r
.80007 .46119 .80576 .46863 .81909 .46458 .81345 .45709 Mtetra
.656 .751 .92 r
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Mtetra
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44825 .8676 .44062 Mtetra
.8676 .44062 .87306 .44825 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Mtetra
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Mtetra
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58269 Mtetra
.653 .751 .921 r
.37228 .58269 .37927 .58915 .39077 .58568 .38381 .57923 Mtetra
.637 .748 .928 r
.38381 .57923 .39077 .58568 .40231 .58243 .39537 .5762 Mtetra
.554 .728 .956 r
.39537 .5762 .40231 .58243 .41387 .58019 .40692 .57493 Mtetra
.204 .593 .946 r
.40692 .57493 .41387 .58019 .4254 .58071 .41842 .57759 Mtetra
.369 0 0 r
.41842 .57759 .4254 .58071 .43693 .58471 .42992 .58354 Mtetra
.163 0 0 r
.42992 .58354 .43693 .58471 .44856 .58824 .44162 .58588 Mtetra
.759 .913 .942 r
.44162 .58588 .44856 .58824 .46042 .58522 .45361 .57874 Mtetra
.829 .783 .809 r
.45361 .57874 .46042 .58522 .47244 .57573 .46572 .56622 Mtetra
.777 .716 .795 r
.46572 .56622 .47244 .57573 .48447 .56549 .4778 .55566 Mtetra
.72 .695 .826 r
.4778 .55566 .48447 .56549 .49649 .5579 .48984 .54883 Mtetra
.682 .699 .859 r
.48984 .54883 .49649 .5579 .50853 .55256 .5019 .54407 Mtetra
.664 .707 .879 r
.5019 .54407 .50853 .55256 .5206 .54814 .514 .54008 Mtetra
.656 .716 .892 r
.514 .54008 .5206 .54814 .53272 .54397 .52616 .53637 Mtetra
.655 .729 .904 r
.52616 .53637 .53272 .54397 .54489 .53997 .53836 .53269 Mtetra
.656 .74 .911 r
.53836 .53269 .54489 .53997 .55712 .53612 .55062 .52895 Mtetra
.657 .744 .914 r
.55062 .52895 .55712 .53612 .5694 .53236 .56294 .52515 Mtetra
.56294 .52515 .5694 .53236 .58173 .52864 .57531 .52135 Mtetra
.655 .742 .913 r
.57531 .52135 .58173 .52864 .59413 .52489 .58774 .51758 Mtetra
.654 .741 .914 r
.58774 .51758 .59413 .52489 .60657 .52113 .60022 .51383 Mtetra
.653 .743 .915 r
.60022 .51383 .60657 .52113 .61907 .51739 .61276 .51008 Mtetra
.655 .744 .915 r
.61276 .51008 .61907 .51739 .63164 .51375 .62536 .50628 Mtetra
.657 .741 .912 r
.62536 .50628 .63164 .51375 .64427 .51028 .63801 .5024 Mtetra
.655 .729 .904 r
.63801 .5024 .64427 .51028 .65696 .50696 .65072 .49856 Mtetra
.646 .713 .896 r
.65072 .49856 .65696 .50696 .66973 .5039 .6635 .495 Mtetra
.623 .691 .893 r
.6635 .495 .66973 .5039 .68261 .50177 .67638 .49223 Mtetra
.556 .646 .894 r
.67638 .49223 .68261 .50177 .69567 .50191 .68943 .49155 Mtetra
.418 .555 .885 r
.68943 .49155 .69567 .50191 .70898 .50475 .70277 .49467 Mtetra
.318 .505 .883 r
.70277 .49467 .70898 .50475 .72235 .5068 .71634 .49976 Mtetra
.511 .7 .955 r
.71634 .49976 .72235 .5068 .73542 .50222 .72971 .49933 Mtetra
.823 .934 .903 r
.72971 .49933 .73542 .50222 .74808 .49089 .74252 .48915 Mtetra
.889 .956 .838 r
.74252 .48915 .74808 .49089 .76072 .47909 .75509 .47525 Mtetra
.83 .907 .892 r
.75509 .47525 .76072 .47909 .77362 .47088 .76789 .46475 Mtetra
.726 .817 .921 r
.76789 .46475 .77362 .47088 .78678 .46551 .78102 .45832 Mtetra
.672 .767 .922 r
.78102 .45832 .78678 .46551 .80007 .46119 .79434 .45371 Mtetra
.658 .754 .921 r
.79434 .45371 .80007 .46119 .81345 .45709 .80776 .44953 Mtetra
.656 .752 .92 r
.80776 .44953 .81345 .45709 .82689 .453 .82125 .4454 Mtetra
.656 .751 .92 r
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Mtetra
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Mtetra
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Mtetra
.655 .751 .92 r
.35373 .5797 .3608 .58619 .37228 .58269 .36524 .57617 Mtetra
.651 .75 .922 r
.36524 .57617 .37228 .58269 .38381 .57923 .37679 .57274 Mtetra
.624 .744 .933 r
.37679 .57274 .38381 .57923 .39537 .5762 .38837 .57001 Mtetra
.483 .703 .966 r
.38837 .57001 .39537 .5762 .40692 .57493 .39991 .5699 Mtetra
0 .41 .821 r
.39991 .5699 .40692 .57493 .41842 .57759 .41135 .57488 Mtetra
.528 0 0 r
.41135 .57488 .41842 .57759 .42992 .58354 .42282 .58244 Mtetra
.071 .626 .813 r
.42282 .58244 .42992 .58354 .44162 .58588 .43462 .58283 Mtetra
.85 .878 .86 r
.43462 .58283 .44162 .58588 .45361 .57874 .44676 .57142 Mtetra
.842 .765 .777 r
.44676 .57142 .45361 .57874 .46572 .56622 .45897 .55639 Mtetra
.773 .711 .793 r
.45897 .55639 .46572 .56622 .4778 .55566 .47108 .54588 Mtetra
.703 .692 .836 r
.47108 .54588 .4778 .55566 .48984 .54883 .48314 .53996 Mtetra
.664 .699 .872 r
.48314 .53996 .48984 .54883 .5019 .54407 .49523 .5359 Mtetra
.657 .714 .89 r
.49523 .5359 .5019 .54407 .514 .54008 .50736 .53214 Mtetra
.659 .722 .896 r
.50736 .53214 .514 .54008 .52616 .53637 .51954 .52831 Mtetra
.659 .719 .894 r
.51954 .52831 .52616 .53637 .53836 .53269 .53178 .52447 Mtetra
.656 .715 .892 r
.53178 .52447 .53836 .53269 .55062 .52895 .54407 .5207 Mtetra
.654 .715 .892 r
.54407 .5207 .55062 .52895 .56294 .52515 .55642 .51696 Mtetra
.654 .717 .894 r
.55642 .51696 .56294 .52515 .57531 .52135 .56882 .51321 Mtetra
.656 .72 .896 r
.56882 .51321 .57531 .52135 .58774 .51758 .58128 .50941 Mtetra
.657 .72 .895 r
.58128 .50941 .58774 .51758 .60022 .51383 .59379 .50555 Mtetra
.657 .718 .894 r
.59379 .50555 .60022 .51383 .61276 .51008 .60637 .50167 Mtetra
.655 .715 .892 r
.60637 .50167 .61276 .51008 .62536 .50628 .619 .49783 Mtetra
.652 .714 .893 r
.619 .49783 .62536 .50628 .63801 .5024 .63169 .49407 Mtetra
.652 .718 .896 r
.63169 .49407 .63801 .5024 .65072 .49856 .64443 .4903 Mtetra
.654 .721 .898 r
.64443 .4903 .65072 .49856 .6635 .495 .65724 .48644 Mtetra
.644 .71 .895 r
.65724 .48644 .6635 .495 .67638 .49223 .67012 .48289 Mtetra
.587 .667 .894 r
.67012 .48289 .67638 .49223 .68943 .49155 .68315 .48123 Mtetra
.418 .558 .888 r
.68315 .48123 .68943 .49155 .70277 .49467 .69651 .48425 Mtetra
.194 .421 .853 r
.69651 .48425 .70277 .49467 .71634 .49976 .71023 .49185 Mtetra
.3 .559 .927 r
.71023 .49185 .71634 .49976 .72971 .49933 .72389 .49573 Mtetra
.775 .91 .933 r
.72389 .49573 .72971 .49933 .74252 .48915 .7369 .48746 Mtetra
.911 .949 .811 r
.7369 .48746 .74252 .48915 .75509 .47525 .74944 .47182 Mtetra
.873 .916 .855 r
.74944 .47182 .75509 .47525 .76789 .46475 .76213 .45887 Mtetra
.759 .834 .91 r
.76213 .45887 .76789 .46475 .78102 .45832 .77522 .45116 Mtetra
.682 .773 .92 r
.77522 .45116 .78102 .45832 .79434 .45371 .78856 .44618 Mtetra
.66 .755 .92 r
.78856 .44618 .79434 .45371 .80776 .44953 .80202 .44191 Mtetra
.656 .752 .92 r
.80202 .44191 .80776 .44953 .82125 .4454 .81555 .43773 Mtetra
.656 .751 .92 r
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Mtetra
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Mtetra
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Mtetra
.655 .751 .921 r
.3466 .57315 .35373 .5797 .36524 .57617 .35814 .5696 Mtetra
.649 .75 .923 r
.35814 .5696 .36524 .57617 .37679 .57274 .36972 .56621 Mtetra
.609 .74 .938 r
.36972 .56621 .37679 .57274 .38837 .57001 .38131 .5638 Mtetra
.393 .663 .967 r
.38131 .5638 .38837 .57001 .39991 .5699 .39283 .56492 Mtetra
0 .196 .632 r
.39283 .56492 .39991 .5699 .41135 .57488 .4042 .57225 Mtetra
.621 .056 0 r
.4042 .57225 .41135 .57488 .42282 .58244 .41565 .58135 Mtetra
.328 .797 .926 r
.41565 .58135 .42282 .58244 .43462 .58283 .42755 .57961 Mtetra
.89 .853 .8 r
.42755 .57961 .43462 .58283 .44676 .57142 .43986 .56388 Mtetra
.856 .76 .756 r
.43986 .56388 .44676 .57142 .45897 .55639 .45218 .54646 Mtetra
.771 .71 .794 r
.45218 .54646 .45897 .55639 .47108 .54588 .46432 .53609 Mtetra
.686 .687 .845 r
.46432 .53609 .47108 .54588 .48314 .53996 .4764 .53098 Mtetra
.65 .692 .876 r
.4764 .53098 .48314 .53996 .49523 .5359 .4885 .52743 Mtetra
.644 .704 .89 r
.4885 .52743 .49523 .5359 .50736 .53214 .50066 .52406 Mtetra
.645 .715 .899 r
.50066 .52406 .50736 .53214 .51954 .52831 .51287 .52066 Mtetra
.647 .728 .908 r
.51287 .52066 .51954 .52831 .53178 .52447 .52514 .51716 Mtetra
.651 .74 .915 r
.52514 .51716 .53178 .52447 .54407 .5207 .53747 .5135 Mtetra
.654 .746 .917 r
.53747 .5135 .54407 .5207 .55642 .51696 .54985 .50972 Mtetra
.655 .746 .916 r
.54985 .50972 .55642 .51696 .56882 .51321 .56229 .5059 Mtetra
.655 .744 .915 r
.56229 .5059 .56882 .51321 .58128 .50941 .57479 .50206 Mtetra
.655 .744 .916 r
.57479 .50206 .58128 .50941 .59379 .50555 .58734 .49822 Mtetra
.656 .746 .916 r
.58734 .49822 .59379 .50555 .60637 .50167 .59995 .49432 Mtetra
.659 .748 .915 r
.59995 .49432 .60637 .50167 .619 .49783 .61261 .49032 Mtetra
.664 .745 .911 r
.61261 .49032 .619 .49783 .63169 .49407 .62533 .48614 Mtetra
.666 .735 .902 r
.62533 .48614 .63169 .49407 .64443 .4903 .6381 .48186 Mtetra
.665 .722 .892 r
.6381 .48186 .64443 .4903 .65724 .48644 .65092 .47756 Mtetra
.66 .71 .885 r
.65092 .47756 .65724 .48644 .67012 .48289 .66381 .47344 Mtetra
.614 .678 .887 r
.66381 .47344 .67012 .48289 .68315 .48123 .67683 .4709 Mtetra
.424 .562 .889 r
.67683 .4709 .68315 .48123 .69651 .48425 .6902 .47372 Mtetra
.059 .331 .811 r
.6902 .47372 .69651 .48425 .71023 .49185 .70407 .48372 Mtetra
.025 .375 .841 r
.70407 .48372 .71023 .49185 .72389 .49573 .71801 .49195 Mtetra
.705 .893 .965 r
.71801 .49195 .72389 .49573 .7369 .48746 .73121 .48578 Mtetra
.927 .94 .788 r
.73121 .48578 .7369 .48746 .74944 .47182 .74373 .46849 Mtetra
.904 .911 .817 r
.74373 .46849 .74944 .47182 .76213 .45887 .75632 .45302 Mtetra
.788 .843 .893 r
.75632 .45302 .76213 .45887 .77522 .45116 .76937 .44398 Mtetra
.692 .778 .917 r
.76937 .44398 .77522 .45116 .78856 .44618 .78273 .43859 Mtetra
.662 .756 .92 r
.78273 .43859 .78856 .44618 .80202 .44191 .79623 .43422 Mtetra
.656 .752 .92 r
.79623 .43422 .80202 .44191 .81555 .43773 .8098 .43 Mtetra
.656 .751 .92 r
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Mtetra
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57013 Mtetra
.32789 .57013 .33511 .5767 .3466 .57315 .33941 .56656 Mtetra
.655 .751 .921 r
.33941 .56656 .3466 .57315 .35814 .5696 .35098 .56298 Mtetra
.647 .749 .924 r
.35098 .56298 .35814 .5696 .36972 .56621 .36259 .55961 Mtetra
.595 .735 .942 r
.36259 .55961 .36972 .56621 .38131 .5638 .3742 .5575 Mtetra
.297 .613 .956 r
.3742 .5575 .38131 .5638 .39283 .56492 .38569 .55977 Mtetra
.528 0 0 r
.38569 .55977 .39283 .56492 .4042 .57225 .39699 .56943 Mtetra
.688 .143 0 r
.39699 .56943 .4042 .57225 .41565 .58135 .40839 .58026 Mtetra
.503 .886 .966 r
.40839 .58026 .41565 .58135 .42755 .57961 .42039 .57677 Mtetra
.916 .842 .756 r
.42039 .57677 .42755 .57961 .43986 .56388 .43289 .55676 Mtetra
.875 .766 .738 r
.43289 .55676 .43986 .56388 .45218 .54646 .44534 .53658 Mtetra
.773 .712 .795 r
.44534 .53658 .45218 .54646 .46432 .53609 .45752 .52607 Mtetra
.664 .675 .851 r
.45752 .52607 .46432 .53609 .4764 .53098 .46961 .52186 Mtetra
.627 .682 .882 r
.46961 .52186 .4764 .53098 .4885 .52743 .48173 .51906 Mtetra
.636 .705 .896 r
.48173 .51906 .4885 .52743 .50066 .52406 .49391 .51593 Mtetra
.648 .717 .898 r
.49391 .51593 .50066 .52406 .51287 .52066 .50616 .5124 Mtetra
.652 .715 .894 r
.50616 .5124 .51287 .52066 .52514 .51716 .51846 .5087 Mtetra
.652 .711 .891 r
.51846 .5087 .52514 .51716 .53747 .5135 .53082 .505 Mtetra
.652 .71 .891 r
.53082 .505 .53747 .5135 .54985 .50972 .54323 .50129 Mtetra
.653 .713 .892 r
.54323 .50129 .54985 .50972 .56229 .5059 .5557 .49752 Mtetra
.655 .717 .893 r
.5557 .49752 .56229 .5059 .57479 .50206 .56823 .49365 Mtetra
.658 .717 .893 r
.56823 .49365 .57479 .50206 .58734 .49822 .58081 .48968 Mtetra
.659 .716 .89 r
.58081 .48968 .58734 .49822 .59995 .49432 .59345 .48566 Mtetra
.658 .713 .888 r
.59345 .48566 .59995 .49432 .61261 .49032 .60615 .48163 Mtetra
.658 .713 .889 r
.60615 .48163 .61261 .49032 .62533 .48614 .61891 .4776 Mtetra
.662 .719 .891 r
.61891 .4776 .62533 .48614 .6381 .48186 .63171 .4734 Mtetra
.673 .727 .89 r
.63171 .4734 .6381 .48186 .65092 .47756 .64457 .46878 Mtetra
.681 .722 .881 r
.64457 .46878 .65092 .47756 .66381 .47344 .65746 .46383 Mtetra
.64 .687 .878 r
.65746 .46383 .66381 .47344 .67683 .4709 .67047 .46033 Mtetra
.422 .557 .885 r
.67047 .46033 .67683 .4709 .6902 .47372 .68385 .46324 Mtetra
0 .214 .738 r
.68385 .46324 .6902 .47372 .70407 .48372 .69787 .47599 Mtetra
0 .147 .669 r
.69787 .47599 .70407 .48372 .71801 .49195 .71208 .48854 Mtetra
.617 .881 .99 r
.71208 .48854 .71801 .49195 .73121 .48578 .72546 .4841 Mtetra
.941 .929 .763 r
.72546 .4841 .73121 .48578 .74373 .46849 .73794 .46492 Mtetra
.923 .895 .783 r
.73794 .46492 .74373 .46849 .75632 .45302 .75045 .44699 Mtetra
.811 .842 .874 r
.75045 .44699 .75632 .45302 .76937 .44398 .76347 .43669 Mtetra
.702 .78 .912 r
.76347 .43669 .76937 .44398 .78273 .43859 .77685 .43092 Mtetra
.663 .756 .919 r
.77685 .43092 .78273 .43859 .79623 .43422 .79039 .42646 Mtetra
.656 .752 .92 r
.79039 .42646 .79623 .43422 .8098 .43 .80401 .42221 Mtetra
.656 .751 .92 r
.80401 .42221 .8098 .43 .82344 .42579 .81769 .41795 Mtetra
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58133 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57013 .32061 .56351 Mtetra
.32061 .56351 .32789 .57013 .33941 .56656 .33216 .55991 Mtetra
.655 .751 .921 r
.33216 .55991 .33941 .56656 .35098 .56298 .34377 .55631 Mtetra
.646 .749 .924 r
.34377 .55631 .35098 .56298 .36259 .55961 .35541 .55295 Mtetra
.584 .731 .944 r
.35541 .55295 .36259 .55961 .3742 .5575 .36703 .55107 Mtetra
.211 .561 .936 r
.36703 .55107 .3742 .5575 .38569 .55977 .37849 .55429 Mtetra
.636 .105 0 r
.37849 .55429 .38569 .55977 .39699 .56943 .38972 .56606 Mtetra
.742 .219 0 r
.38972 .56606 .39699 .56943 .40839 .58026 .40106 .57897 Mtetra
.579 .911 .975 r
.40106 .57897 .40839 .58026 .42039 .57677 .41313 .57467 Mtetra
.935 .839 .725 r
.41313 .57467 .42039 .57677 .43289 .55676 .42584 .55078 Mtetra
.899 .779 .72 r
.42584 .55078 .43289 .55676 .44534 .53658 .43844 .52722 Mtetra
.788 .726 .794 r
.43844 .52722 .44534 .53658 .45752 .52607 .45068 .51587 Mtetra
.649 .667 .854 r
.45068 .51587 .45752 .52607 .46961 .52186 .46278 .5122 Mtetra
.606 .663 .879 r
.46278 .5122 .46961 .52186 .48173 .51906 .47491 .51004 Mtetra
.618 .683 .889 r
.47491 .51004 .48173 .51906 .49391 .51593 .48712 .50748 Mtetra
.629 .702 .899 r
.48712 .50748 .49391 .51593 .50616 .5124 .49938 .50453 Mtetra
.637 .722 .909 r
.49938 .50453 .50616 .5124 .51846 .5087 .51172 .50127 Mtetra
.645 .738 .917 r
.51172 .50127 .51846 .5087 .53082 .505 .52411 .49773 Mtetra
.651 .746 .919 r
.52411 .49773 .53082 .505 .54323 .50129 .53656 .49399 Mtetra
.654 .747 .918 r
.53656 .49399 .54323 .50129 .5557 .49752 .54907 .49015 Mtetra
.655 .746 .917 r
.54907 .49015 .5557 .49752 .56823 .49365 .56163 .48625 Mtetra
.656 .747 .916 r
.56163 .48625 .56823 .49365 .58081 .48968 .57426 .4823 Mtetra
.659 .749 .917 r
.57426 .4823 .58081 .48968 .59345 .48566 .58693 .47825 Mtetra
.665 .751 .915 r
.58693 .47825 .59345 .48566 .60615 .48163 .59967 .47399 Mtetra
.673 .748 .907 r
.59967 .47399 .60615 .48163 .61891 .4776 .61245 .46944 Mtetra
.68 .737 .894 r
.61245 .46944 .61891 .4776 .63171 .4734 .62527 .46458 Mtetra
.687 .724 .878 r
.62527 .46458 .63171 .4734 .64457 .46878 .63814 .45934 Mtetra
.694 .713 .863 r
.63814 .45934 .64457 .46878 .65746 .46383 .65104 .45369 Mtetra
.655 .683 .864 r
.65104 .45369 .65746 .46383 .67047 .46033 .66405 .44957 Mtetra
.388 .535 .881 r
.66405 .44957 .67047 .46033 .68385 .46324 .67749 .45328 Mtetra
0 .052 .608 r
.67749 .45328 .68385 .46324 .69787 .47599 .69169 .46943 Mtetra
.562 .072 0 r
.69169 .46943 .69787 .47599 .71208 .48854 .70613 .48588 Mtetra
.541 .877 .99 r
.70613 .48588 .71208 .48854 .72546 .4841 .71962 .48219 Mtetra
.953 .912 .738 r
.71962 .48219 .72546 .4841 .73794 .46492 .73206 .46079 Mtetra
.933 .874 .756 r
.73206 .46079 .73794 .46492 .75045 .44699 .7445 .4406 Mtetra
.825 .835 .856 r
.7445 .4406 .75045 .44699 .76347 .43669 .7575 .42925 Mtetra
.709 .78 .907 r
.7575 .42925 .76347 .43669 .77685 .43092 .77091 .42318 Mtetra
.665 .756 .919 r
.77091 .42318 .77685 .43092 .79039 .42646 .78449 .41864 Mtetra
.657 .752 .92 r
.78449 .41864 .79039 .42646 .80401 .42221 .79816 .41434 Mtetra
.656 .751 .92 r
.79816 .41434 .80401 .42221 .81769 .41795 .81189 .41005 Mtetra
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58133 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Mtetra
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Mtetra
.655 .751 .921 r
.32486 .5532 .33216 .55991 .34377 .55631 .33649 .54958 Mtetra
.645 .748 .925 r
.33649 .54958 .34377 .55631 .35541 .55295 .34816 .54622 Mtetra
.575 .727 .946 r
.34816 .54622 .35541 .55295 .36703 .55107 .3598 .5445 Mtetra
.145 .518 .916 r
.3598 .5445 .36703 .55107 .37849 .55429 .37125 .54843 Mtetra
.696 .18 0 r
.37125 .54843 .37849 .55429 .38972 .56606 .3824 .56188 Mtetra
.78 .277 0 r
.3824 .56188 .38972 .56606 .40106 .57897 .39367 .57695 Mtetra
.575 .891 .988 r
.39367 .57695 .40106 .57897 .41313 .57467 .40578 .57314 Mtetra
.944 .838 .708 r
.40578 .57314 .41313 .57467 .42584 .55078 .41866 .54666 Mtetra
.926 .798 .7 r
.41866 .54666 .42584 .55078 .43844 .52722 .43145 .51931 Mtetra
.825 .758 .789 r
.43145 .51931 .43844 .52722 .45068 .51587 .44379 .50578 Mtetra
.649 .671 .857 r
.44379 .50578 .45068 .51587 .46278 .5122 .45591 .5021 Mtetra
.58 .642 .877 r
.45591 .5021 .46278 .5122 .47491 .51004 .46805 .50075 Mtetra
.602 .672 .889 r
.46805 .50075 .47491 .51004 .48712 .50748 .48027 .49866 Mtetra
.63 .695 .892 r
.48027 .49866 .48712 .50748 .49938 .50453 .49257 .49563 Mtetra
.643 .699 .886 r
.49257 .49563 .49938 .50453 .51172 .50127 .50493 .49216 Mtetra
.646 .696 .882 r
.50493 .49216 .51172 .50127 .52411 .49773 .51735 .48856 Mtetra
.647 .696 .881 r
.51735 .48856 .52411 .49773 .53656 .49399 .52983 .48491 Mtetra
.65 .7 .882 r
.52983 .48491 .53656 .49399 .54907 .49015 .54237 .48114 Mtetra
.655 .704 .883 r
.54237 .48114 .54907 .49015 .56163 .48625 .55497 .47721 Mtetra
.659 .706 .882 r
.55497 .47721 .56163 .48625 .57426 .4823 .56762 .47311 Mtetra
.661 .704 .879 r
.56762 .47311 .57426 .4823 .58693 .47825 .58033 .4689 Mtetra
.662 .701 .876 r
.58033 .4689 .58693 .47825 .59967 .47399 .59309 .46463 Mtetra
.664 .702 .875 r
.59309 .46463 .59967 .47399 .61245 .46944 .60591 .46025 Mtetra
.676 .712 .875 r
.60591 .46025 .61245 .46944 .62527 .46458 .61877 .45542 Mtetra
.698 .721 .867 r
.61877 .45542 .62527 .46458 .63814 .45934 .63166 .44963 Mtetra
.711 .715 .851 r
.63166 .44963 .63814 .45934 .65104 .45369 .64456 .44309 Mtetra
.654 .674 .857 r
.64456 .44309 .65104 .45369 .66405 .44957 .6576 .43892 Mtetra
.275 .473 .871 r
.6576 .43892 .66405 .44957 .67749 .45328 .67116 .44479 Mtetra
.591 .142 0 r
.67116 .44479 .67749 .45328 .69169 .46943 .68554 .46476 Mtetra
.718 .213 0 r
.68554 .46476 .69169 .46943 .70613 .48588 .70014 .48379 Mtetra
.547 .897 .978 r
.70014 .48379 .70613 .48588 .71962 .48219 .71366 .47951 Mtetra
.958 .886 .718 r
.71366 .47951 .71962 .48219 .73206 .46079 .72606 .45581 Mtetra
.934 .851 .737 r
.72606 .45581 .73206 .46079 .7445 .4406 .73847 .43381 Mtetra
.832 .826 .842 r
.73847 .43381 .7445 .4406 .7575 .42925 .75148 .42166 Mtetra
.714 .779 .904 r
.75148 .42166 .7575 .42925 .77091 .42318 .76493 .41535 Mtetra
.666 .756 .918 r
.76493 .41535 .77091 .42318 .78449 .41864 .77855 .41074 Mtetra
.657 .752 .92 r
.77855 .41074 .78449 .41864 .79816 .41434 .79226 .40641 Mtetra
.656 .751 .92 r
.79226 .40641 .79816 .41434 .81189 .41005 .80604 .40207 Mtetra
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38455 Mtetra
.86182 .38455 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54645 Mtetra
.655 .751 .921 r
.31749 .54645 .32486 .5532 .33649 .54958 .32916 .54279 Mtetra
.644 .748 .925 r
.32916 .54279 .33649 .54958 .34816 .54622 .34086 .53944 Mtetra
.568 .725 .948 r
.34086 .53944 .34816 .54622 .3598 .5445 .35252 .53784 Mtetra
.095 .485 .898 r
.35252 .53784 .3598 .5445 .37125 .54843 .36396 .54227 Mtetra
.727 .222 0 r
.36396 .54227 .37125 .54843 .3824 .56188 .37506 .55684 Mtetra
.801 .312 0 r
.37506 .55684 .3824 .56188 .39367 .57695 .38625 .57357 Mtetra
.527 .833 .999 r
.38625 .57357 .39367 .57695 .40578 .57314 .39835 .57117 Mtetra
.941 .831 .707 r
.39835 .57117 .40578 .57314 .41866 .54666 .41134 .54436 Mtetra
.945 .815 .686 r
.41134 .54436 .41866 .54666 .43145 .51931 .42432 .51424 Mtetra
.881 .814 .778 r
.42432 .51424 .43145 .51931 .44379 .50578 .43682 .49728 Mtetra
.701 .726 .869 r
.43682 .49728 .44379 .50578 .45591 .5021 .44901 .49169 Mtetra
.585 .639 .871 r
.44901 .49169 .45591 .5021 .46805 .50075 .46117 .49017 Mtetra
.577 .633 .87 r
.46117 .49017 .46805 .50075 .48027 .49866 .47339 .48889 Mtetra
.596 .66 .883 r
.47339 .48889 .48027 .49866 .49257 .49563 .4857 .48694 Mtetra
.617 .696 .901 r
.4857 .48694 .49257 .49563 .50493 .49216 .49809 .48427 Mtetra
.636 .726 .913 r
.49809 .48427 .50493 .49216 .51735 .48856 .51054 .48096 Mtetra
.649 .739 .915 r
.51054 .48096 .51735 .48856 .52983 .48491 .52306 .47724 Mtetra
.654 .74 .912 r
.52306 .47724 .52983 .48491 .54237 .48114 .53563 .47333 Mtetra
.655 .737 .91 r
.53563 .47333 .54237 .48114 .55497 .47721 .54826 .46937 Mtetra
.656 .737 .909 r
.54826 .46937 .55497 .47721 .56762 .47311 .56095 .46536 Mtetra
.662 .743 .91 r
.56095 .46536 .56762 .47311 .58033 .4689 .5737 .46115 Mtetra
.673 .748 .907 r
.5737 .46115 .58033 .4689 .59309 .46463 .58649 .45653 Mtetra
.69 .745 .893 r
.58649 .45653 .59309 .46463 .60591 .46025 .59933 .45126 Mtetra
.704 .728 .869 r
.59933 .45126 .60591 .46025 .61877 .45542 .6122 .44526 Mtetra
.711 .706 .844 r
.6122 .44526 .61877 .45542 .63166 .44963 .62509 .4386 Mtetra
.701 .686 .833 r
.62509 .4386 .63166 .44963 .64456 .44309 .63803 .43218 Mtetra
.604 .647 .866 r
.63803 .43218 .64456 .44309 .6576 .43892 .65118 .42989 Mtetra
0 .322 .81 r
.65118 .42989 .6576 .43892 .67116 .44479 .6649 .43919 Mtetra
.768 .289 0 r
.6649 .43919 .67116 .44479 .68554 .46476 .67942 .46192 Mtetra
.765 .258 0 r
.67942 .46192 .68554 .46476 .70014 .48379 .69406 .48122 Mtetra
.652 .922 .976 r
.69406 .48122 .70014 .48379 .71366 .47951 .70756 .47541 Mtetra
.953 .855 .706 r
.70756 .47541 .71366 .47951 .72606 .45581 .71995 .44993 Mtetra
.931 .832 .725 r
.71995 .44993 .72606 .45581 .73847 .43381 .73237 .42669 Mtetra
.837 .819 .832 r
.73237 .42669 .73847 .43381 .75148 .42166 .7454 .41396 Mtetra
.717 .779 .901 r
.7454 .41396 .75148 .42166 .76493 .41535 .75888 .40746 Mtetra
.666 .757 .918 r
.75888 .40746 .76493 .41535 .77855 .41074 .77255 .40278 Mtetra
.657 .752 .92 r
.77255 .40278 .77855 .41074 .79226 .40641 .78631 .3984 Mtetra
.656 .751 .92 r
.78631 .3984 .79226 .40641 .80604 .40207 .80014 .39403 Mtetra
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38523 Mtetra
.82799 .38523 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38455 .85611 .37635 Mtetra
.85611 .37635 .86182 .38455 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.29843 .54333 .30588 .55011 .31749 .54645 .31007 .53963 Mtetra
.655 .751 .921 r
.31007 .53963 .31749 .54645 .32916 .54279 .32176 .53596 Mtetra
.643 .748 .925 r
.32176 .53596 .32916 .54279 .34086 .53944 .33349 .5326 Mtetra
.56 .722 .949 r
.33349 .5326 .34086 .53944 .35252 .53784 .34517 .53112 Mtetra
.052 .457 .881 r
.34517 .53112 .35252 .53784 .36396 .54227 .3566 .53595 Mtetra
.744 .245 0 r
.3566 .53595 .36396 .54227 .37506 .55684 .36766 .55119 Mtetra
.806 .322 0 r
.36766 .55119 .37506 .55684 .38625 .57357 .37881 .56865 Mtetra
.501 .771 .992 r
.37881 .56865 .38625 .57357 .39835 .57117 .39091 .56736 Mtetra
.923 .81 .717 r
.39091 .56736 .39835 .57117 .41134 .54436 .40394 .54215 Mtetra
.945 .818 .687 r
.40394 .54215 .41134 .54436 .42432 .51424 .41703 .51214 Mtetra
.924 .865 .763 r
.41703 .51214 .42432 .51424 .43682 .49728 .42968 .49246 Mtetra
.8 .842 .883 r
.42968 .49246 .43682 .49728 .44901 .49169 .44201 .4833 Mtetra
.654 .716 .893 r
.44201 .4833 .44901 .49169 .46117 .49017 .45424 .47946 Mtetra
.621 .651 .858 r
.45424 .47946 .46117 .49017 .47339 .48889 .46651 .4767 Mtetra
.638 .632 .828 r
.46651 .4767 .47339 .48889 .4857 .48694 .47885 .47314 Mtetra
.65 .614 .8 r
.47885 .47314 .4857 .48694 .49809 .48427 .49127 .46874 Mtetra
.648 .592 .778 r
.49127 .46874 .49809 .48427 .51054 .48096 .50373 .46407 Mtetra
.641 .574 .764 r
.50373 .46407 .51054 .48096 .52306 .47724 .51625 .45953 Mtetra
.634 .563 .757 r
.51625 .45953 .52306 .47724 .53563 .47333 .52882 .45525 Mtetra
.629 .557 .755 r
.52882 .45525 .53563 .47333 .54826 .46937 .54145 .45124 Mtetra
.624 .555 .756 r
.54145 .45124 .54826 .46937 .56095 .46536 .55414 .44751 Mtetra
.62 .555 .76 r
.55414 .44751 .56095 .46536 .5737 .46115 .56689 .44404 Mtetra
.619 .563 .769 r
.56689 .44404 .5737 .46115 .58649 .45653 .57971 .4407 Mtetra
.627 .581 .783 r
.57971 .4407 .58649 .45653 .59933 .45126 .5926 .43712 Mtetra
.648 .613 .801 r
.5926 .43712 .59933 .45126 .6122 .44526 .60552 .43269 Mtetra
.669 .647 .819 r
.60552 .43269 .6122 .44526 .62509 .4386 .61848 .42744 Mtetra
.651 .664 .85 r
.61848 .42744 .62509 .4386 .63803 .43218 .63153 .42331 Mtetra
.45 .623 .926 r
.63153 .42331 .63803 .43218 .65118 .42989 .64484 .42459 Mtetra
.476 0 0 r
.64484 .42459 .65118 .42989 .6649 .43919 .6587 .4366 Mtetra
.814 .331 0 r
.6587 .4366 .6649 .43919 .67942 .46192 .67323 .45914 Mtetra
.737 .218 0 r
.67323 .45914 .67942 .46192 .69406 .48122 .68781 .47673 Mtetra
.731 .883 .95 r
.68781 .47673 .69406 .48122 .70756 .47541 .70131 .46971 Mtetra
.942 .827 .702 r
.70131 .46971 .70756 .47541 .71995 .44993 .71374 .4434 Mtetra
.928 .82 .719 r
.71374 .4434 .71995 .44993 .73237 .42669 .7262 .41941 Mtetra
.841 .817 .826 r
.7262 .41941 .73237 .42669 .7454 .41396 .73927 .40619 Mtetra
.721 .78 .899 r
.73927 .40619 .7454 .41396 .75888 .40746 .75279 .39949 Mtetra
.667 .757 .917 r
.75279 .39949 .75888 .40746 .77255 .40278 .7665 .39475 Mtetra
.657 .752 .92 r
.7665 .39475 .77255 .40278 .78631 .3984 .78031 .39032 Mtetra
.656 .751 .92 r
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Mtetra
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38523 .82213 .37704 Mtetra
.82213 .37704 .82799 .38523 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Mtetra
.654 .751 .921 r
.30259 .53276 .31007 .53963 .32176 .53596 .31431 .52906 Mtetra
.641 .748 .926 r
.31431 .52906 .32176 .53596 .33349 .5326 .32607 .52571 Mtetra
.552 .719 .951 r
.32607 .52571 .33349 .5326 .34517 .53112 .33777 .52436 Mtetra
.007 .427 .862 r
.33777 .52436 .34517 .53112 .3566 .53595 .34919 .52958 Mtetra
.758 .262 0 r
.34919 .52958 .3566 .53595 .36766 .55119 .36021 .54529 Mtetra
.801 .317 0 r
.36021 .54529 .36766 .55119 .37881 .56865 .37136 .56271 Mtetra
.534 .75 .975 r
.37136 .56271 .37881 .56865 .39091 .56736 .38349 .56129 Mtetra
.899 .781 .722 r
.38349 .56129 .39091 .56736 .40394 .54215 .39655 .53744 Mtetra
.922 .792 .7 r
.39655 .53744 .40394 .54215 .41703 .51214 .40966 .50978 Mtetra
.921 .861 .764 r
.40966 .50978 .41703 .51214 .42968 .49246 .42239 .49018 Mtetra
.878 .901 .843 r
.42239 .49018 .42968 .49246 .44201 .4833 .4349 .47682 Mtetra
.803 .797 .847 r
.4349 .47682 .44201 .4833 .45424 .47946 .44732 .46657 Mtetra
.71 .652 .79 r
.44732 .46657 .45424 .47946 .46651 .4767 .4597 .45901 Mtetra
.647 .569 .753 r
.4597 .45901 .46651 .4767 .47885 .47314 .47206 .45395 Mtetra
.617 .54 .745 r
.47206 .45395 .47885 .47314 .49127 .46874 .48445 .45047 Mtetra
.61 .544 .756 r
.48445 .45047 .49127 .46874 .50373 .46407 .4969 .44756 Mtetra
.615 .565 .775 r
.4969 .44756 .50373 .46407 .51625 .45953 .50942 .44452 Mtetra
.627 .589 .792 r
.50942 .44452 .51625 .45953 .52882 .45525 .522 .44104 Mtetra
.64 .606 .8 r
.522 .44104 .52882 .45525 .54145 .45124 .53464 .437 Mtetra
.651 .612 .797 r
.53464 .437 .54145 .45124 .55414 .44751 .54733 .43239 Mtetra
.655 .603 .784 r
.54733 .43239 .55414 .44751 .56689 .44404 .56008 .42733 Mtetra
.651 .584 .767 r
.56008 .42733 .56689 .44404 .57971 .4407 .57287 .42216 Mtetra
.636 .559 .751 r
.57287 .42216 .57971 .4407 .5926 .43712 .58573 .41753 Mtetra
.607 .535 .747 r
.58573 .41753 .5926 .43712 .60552 .43269 .59868 .41452 Mtetra
.562 .522 .768 r
.59868 .41452 .60552 .43269 .61848 .42744 .61177 .41407 Mtetra
.471 .534 .84 r
.61177 .41407 .61848 .42744 .63153 .42331 .62504 .41637 Mtetra
.093 .473 .893 r
.62504 .41637 .63153 .42331 .64484 .42459 .63853 .42186 Mtetra
.605 .045 0 r
.63853 .42186 .64484 .42459 .6587 .4366 .65242 .43371 Mtetra
.781 .281 0 r
.65242 .43371 .6587 .4366 .67323 .45914 .66686 .45377 Mtetra
.62 .104 0 r
.66686 .45377 .67323 .45914 .68781 .47673 .68138 .4699 Mtetra
.73 .81 .914 r
.68138 .4699 .68781 .47673 .70131 .46971 .69494 .46294 Mtetra
.933 .811 .702 r
.69494 .46294 .70131 .46971 .71374 .4434 .70747 .43661 Mtetra
.928 .815 .715 r
.70747 .43661 .71374 .4434 .7262 .41941 .71998 .41206 Mtetra
.846 .817 .821 r
.71998 .41206 .7262 .41941 .73927 .40619 .73308 .39837 Mtetra
.725 .782 .898 r
.73308 .39837 .73927 .40619 .75279 .39949 .74664 .39146 Mtetra
.668 .757 .917 r
.74664 .39146 .75279 .39949 .7665 .39475 .7604 .38664 Mtetra
.657 .752 .92 r
.7604 .38664 .7665 .39475 .78031 .39032 .77425 .38217 Mtetra
.656 .751 .92 r
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Mtetra
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Mtetra
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52584 Mtetra
.654 .751 .921 r
.29504 .52584 .30259 .53276 .31431 .52906 .3068 .52211 Mtetra
.64 .747 .927 r
.3068 .52211 .31431 .52906 .32607 .52571 .31858 .51876 Mtetra
.543 .716 .953 r
.31858 .51876 .32607 .52571 .33777 .52436 .33029 .51758 Mtetra
0 .394 .838 r
.33029 .51758 .33777 .52436 .34919 .52958 .3417 .52322 Mtetra
.77 .278 0 r
.3417 .52322 .34919 .52958 .36021 .54529 .3527 .53935 Mtetra
.792 .304 0 r
.3527 .53935 .36021 .54529 .37136 .56271 .36385 .55634 Mtetra
.603 .762 .955 r
.36385 .55634 .37136 .56271 .38349 .56129 .37606 .55366 Mtetra
.888 .759 .713 r
.37606 .55366 .38349 .56129 .39655 .53744 .38924 .52895 Mtetra
.891 .746 .694 r
.38924 .52895 .39655 .53744 .40966 .50978 .40243 .50133 Mtetra
.86 .753 .743 r
.40243 .50133 .40966 .50978 .42239 .49018 .41521 .48214 Mtetra
.818 .762 .8 r
.41521 .48214 .42239 .49018 .4349 .47682 .42776 .46937 Mtetra
.785 .774 .842 r
.42776 .46937 .4349 .47682 .44732 .46657 .44021 .4597 Mtetra
.748 .785 .883 r
.44021 .4597 .44732 .46657 .4597 .45901 .45263 .45238 Mtetra
.695 .782 .918 r
.45263 .45238 .4597 .45901 .47206 .45395 .46503 .44715 Mtetra
.648 .765 .934 r
.46503 .44715 .47206 .45395 .48445 .45047 .47747 .44336 Mtetra
.625 .749 .936 r
.47747 .44336 .48445 .45047 .4969 .44756 .48995 .44018 Mtetra
.627 .742 .93 r
.48995 .44018 .4969 .44756 .50942 .44452 .5025 .43699 Mtetra
.64 .743 .924 r
.5025 .43699 .50942 .44452 .522 .44104 .51512 .43342 Mtetra
.656 .747 .917 r
.51512 .43342 .522 .44104 .53464 .437 .5278 .42933 Mtetra
.672 .752 .911 r
.5278 .42933 .53464 .437 .54733 .43239 .54053 .42474 Mtetra
.682 .756 .908 r
.54053 .42474 .54733 .43239 .56008 .42733 .55332 .41977 Mtetra
.682 .76 .91 r
.55332 .41977 .56008 .42733 .57287 .42216 .56616 .41478 Mtetra
.662 .76 .923 r
.56616 .41478 .57287 .42216 .58573 .41753 .57906 .41045 Mtetra
.608 .751 .946 r
.57906 .41045 .58573 .41753 .59868 .41452 .59206 .40755 Mtetra
.509 .713 .964 r
.59206 .40755 .59868 .41452 .61177 .41407 .60518 .40678 Mtetra
.381 .639 .957 r
.60518 .40678 .61177 .41407 .62504 .41637 .61846 .4084 Mtetra
.201 .511 .912 r
.61846 .4084 .62504 .41637 .63853 .42186 .63195 .4132 Mtetra
0 .205 .723 r
.63195 .4132 .63853 .42186 .65242 .43371 .64583 .42455 Mtetra
0 0 .416 r
.64583 .42455 .65242 .43371 .66686 .45377 .66026 .44452 Mtetra
0 0 .543 r
.66026 .44452 .66686 .45377 .68138 .4699 .67482 .46146 Mtetra
.692 .755 .9 r
.67482 .46146 .68138 .4699 .69494 .46294 .68849 .45573 Mtetra
.928 .806 .705 r
.68849 .45573 .69494 .46294 .70747 .43661 .70113 .42975 Mtetra
.929 .815 .711 r
.70113 .42975 .70747 .43661 .71998 .41206 .7137 .40471 Mtetra
.852 .819 .816 r
.7137 .40471 .71998 .41206 .73308 .39837 .72684 .39051 Mtetra
.73 .784 .896 r
.72684 .39051 .73308 .39837 .74664 .39146 .74044 .38337 Mtetra
.67 .758 .917 r
.74044 .38337 .74664 .39146 .7604 .38664 .75424 .37846 Mtetra
.657 .752 .92 r
.75424 .37846 .7604 .38664 .77425 .38217 .76814 .37395 Mtetra
.656 .751 .92 r
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Mtetra
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Mtetra
.27569 .52264 .28333 .52959 .29504 .52584 .28743 .51886 Mtetra
.654 .751 .921 r
.28743 .51886 .29504 .52584 .3068 .52211 .29922 .5151 Mtetra
.638 .747 .927 r
.29922 .5151 .3068 .52211 .31858 .51876 .31103 .51177 Mtetra
.532 .712 .954 r
.31103 .51177 .31858 .51876 .33029 .51758 .32276 .51076 Mtetra
0 .357 .811 r
.32276 .51076 .33029 .51758 .3417 .52322 .33415 .51685 Mtetra
.779 .289 0 r
.33415 .51685 .3417 .52322 .3527 .53935 .34512 .53331 Mtetra
.77 .273 0 r
.34512 .53331 .3527 .53935 .36385 .55634 .3563 .54938 Mtetra
.696 .771 .909 r
.3563 .54938 .36385 .55634 .37606 .55366 .36867 .54409 Mtetra
.882 .734 .693 r
.36867 .54409 .37606 .55366 .38924 .52895 .38204 .51636 Mtetra
.865 .703 .679 r
.38204 .51636 .38924 .52895 .40243 .50133 .39536 .4871 Mtetra
.801 .672 .721 r
.39536 .4871 .40243 .50133 .41521 .48214 .40814 .46944 Mtetra
.711 .657 .794 r
.40814 .46944 .41521 .48214 .42776 .46937 .42055 .46186 Mtetra
.627 .736 .926 r
.42055 .46186 .42776 .46937 .44021 .4597 .43287 .45871 Mtetra
.4 .841 .937 r
.43287 .45871 .44021 .4597 .45263 .45238 .44524 .45595 Mtetra
0 0 0 r
.44524 .45595 .45263 .45238 .46503 .44715 .4577 .45208 Mtetra
.4577 .45208 .46503 .44715 .47747 .44336 .47023 .44731 Mtetra
.47023 .44731 .47747 .44336 .48995 .44018 .48282 .4423 Mtetra
.31 .792 .727 r
.48282 .4423 .48995 .44018 .5025 .43699 .49546 .4375 Mtetra
.421 .867 .865 r
.49546 .4375 .5025 .43699 .51512 .43342 .50815 .43304 Mtetra
.456 .88 .917 r
.50815 .43304 .51512 .43342 .5278 .42933 .52089 .42895 Mtetra
.421 .862 .908 r
.52089 .42895 .5278 .42933 .54053 .42474 .5337 .42522 Mtetra
.307 .8 .825 r
.5337 .42522 .54053 .42474 .55332 .41977 .54657 .42183 Mtetra
0 0 0 r
.54657 .42183 .55332 .41977 .56616 .41478 .55951 .41866 Mtetra
.004 0 0 r
.55951 .41866 .56616 .41478 .57906 .41045 .57251 .41519 Mtetra
0 0 0 r
.57251 .41519 .57906 .41045 .59206 .40755 .58557 .41083 Mtetra
.58557 .41083 .59206 .40755 .60518 .40678 .59866 .40539 Mtetra
.571 .92 .961 r
.59866 .40539 .60518 .40678 .61846 .4084 .61182 .40034 Mtetra
.514 .685 .944 r
.61182 .40034 .61846 .4084 .63195 .4132 .62517 .39978 Mtetra
.156 .346 .802 r
.62517 .39978 .63195 .4132 .64583 .42455 .63898 .40948 Mtetra
0 0 .567 r
.63898 .40948 .64583 .42455 .66026 .44452 .65344 .43104 Mtetra
0 .008 .582 r
.65344 .43104 .66026 .44452 .67482 .46146 .66812 .451 Mtetra
.618 .678 .885 r
.66812 .451 .67482 .46146 .68849 .45573 .68196 .44789 Mtetra
.919 .799 .712 r
.68196 .44789 .68849 .45573 .70113 .42975 .69473 .4228 Mtetra
.93 .814 .709 r
.69473 .4228 .70113 .42975 .7137 .40471 .70737 .39734 Mtetra
.858 .82 .811 r
.70737 .39734 .7137 .40471 .72684 .39051 .72055 .3826 Mtetra
.735 .786 .894 r
.72055 .3826 .72684 .39051 .74044 .38337 .73418 .37521 Mtetra
.671 .759 .916 r
.73418 .37521 .74044 .38337 .75424 .37846 .74803 .37021 Mtetra
.657 .752 .92 r
.74803 .37021 .75424 .37846 .76814 .37395 .76197 .36566 Mtetra
.656 .751 .92 r
.76197 .36566 .76814 .37395 .78211 .36946 .77599 .36113 Mtetra
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .3428 Mtetra
.83275 .3428 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Mtetra
.26799 .51563 .27569 .52264 .28743 .51886 .27976 .51182 Mtetra
.654 .751 .921 r
.27976 .51182 .28743 .51886 .29922 .5151 .29158 .50804 Mtetra
.636 .746 .928 r
.29158 .50804 .29922 .5151 .31103 .51177 .30342 .50473 Mtetra
.52 .707 .956 r
.30342 .50473 .31103 .51177 .32276 .51076 .31516 .5039 Mtetra
0 .324 .784 r
.31516 .5039 .32276 .51076 .33415 .51685 .32654 .5104 Mtetra
.776 .286 0 r
.32654 .5104 .33415 .51685 .34512 .53331 .33749 .5268 Mtetra
.693 .182 0 r
.33749 .5268 .34512 .53331 .3563 .54938 .34876 .54082 Mtetra
.767 .746 .834 r
.34876 .54082 .3563 .54938 .36867 .54409 .36136 .53161 Mtetra
.868 .705 .677 r
.36136 .53161 .36867 .54409 .38204 .51636 .37492 .50142 Mtetra
.844 .681 .679 r
.37492 .50142 .38204 .51636 .39536 .4871 .38823 .47382 Mtetra
.775 .674 .752 r
.38823 .47382 .39536 .4871 .40814 .46944 .40089 .46055 Mtetra
.652 .709 .889 r
.40089 .46055 .40814 .46944 .42055 .46186 .41321 .45663 Mtetra
.511 .77 .99 r
.41321 .45663 .42055 .46186 .43287 .45871 .42552 .45516 Mtetra
.464 .808 .999 r
.42552 .45516 .43287 .45871 .44524 .45595 .43791 .45344 Mtetra
.459 .838 .988 r
.43791 .45344 .44524 .45595 .4577 .45208 .45039 .4511 Mtetra
.411 .848 .937 r
.45039 .4511 .4577 .45208 .47023 .44731 .46295 .44813 Mtetra
.309 .801 .813 r
.46295 .44813 .47023 .44731 .48282 .4423 .47558 .44459 Mtetra
0 0 0 r
.47558 .44459 .48282 .4423 .49546 .4375 .48829 .44066 Mtetra
.48829 .44066 .49546 .4375 .50815 .43304 .50106 .43656 Mtetra
.50106 .43656 .50815 .43304 .52089 .42895 .51388 .43243 Mtetra
.51388 .43243 .52089 .42895 .5337 .42522 .52677 .42827 Mtetra
.52677 .42827 .5337 .42522 .54657 .42183 .53972 .42396 Mtetra
.275 .768 .704 r
.53972 .42396 .54657 .42183 .55951 .41866 .55272 .41924 Mtetra
.459 .888 .862 r
.55272 .41924 .55951 .41866 .57251 .41519 .56578 .414 Mtetra
.62 .94 .955 r
.56578 .414 .57251 .41519 .58557 .41083 .57888 .40807 Mtetra
.703 .925 .966 r
.57888 .40807 .58557 .41083 .59866 .40539 .59201 .40146 Mtetra
.728 .895 .955 r
.59201 .40146 .59866 .40539 .61182 .40034 .60518 .39459 Mtetra
.649 .816 .964 r
.60518 .39459 .61182 .40034 .62517 .39978 .61847 .39021 Mtetra
.245 .495 .896 r
.61847 .39021 .62517 .39978 .63898 .40948 .63214 .39537 Mtetra
0 .015 .589 r
.63214 .39537 .63898 .40948 .65344 .43104 .6465 .41513 Mtetra
0 0 .568 r
.6465 .41513 .65344 .43104 .66812 .451 .66124 .43753 Mtetra
.51 .566 .849 r
.66124 .43753 .66812 .451 .68196 .44789 .67529 .43838 Mtetra
.894 .775 .723 r
.67529 .43838 .68196 .44789 .69473 .4228 .68824 .41534 Mtetra
.926 .807 .709 r
.68824 .41534 .69473 .4228 .70737 .39734 .70097 .38987 Mtetra
.862 .82 .806 r
.70097 .38987 .70737 .39734 .72055 .3826 .71419 .37464 Mtetra
.74 .788 .892 r
.71419 .37464 .72055 .3826 .73418 .37521 .72787 .36698 Mtetra
.673 .76 .916 r
.72787 .36698 .73418 .37521 .74803 .37021 .74176 .36189 Mtetra
.658 .752 .92 r
.74176 .36189 .74803 .37021 .76197 .36566 .75575 .35729 Mtetra
.656 .751 .92 r
.75575 .35729 .76197 .36566 .77599 .36113 .76982 .35272 Mtetra
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .3428 .82677 .33423 Mtetra
.82677 .33423 .83275 .3428 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Mtetra
.26022 .50856 .26799 .51563 .27976 .51182 .27202 .50472 Mtetra
.653 .751 .921 r
.27202 .50472 .27976 .51182 .29158 .50804 .28387 .50091 Mtetra
.634 .746 .929 r
.28387 .50091 .29158 .50804 .30342 .50473 .29574 .49763 Mtetra
.51 .703 .958 r
.29574 .49763 .30342 .50473 .31516 .5039 .30749 .49696 Mtetra
0 .31 .774 r
.30749 .49696 .31516 .5039 .32654 .5104 .31887 .50362 Mtetra
.745 .249 0 r
.31887 .50362 .32654 .5104 .33749 .5268 .32985 .51915 Mtetra
0 .038 .54 r
.32985 .51915 .33749 .5268 .34876 .54082 .34129 .52998 Mtetra
.789 .711 .778 r
.34129 .52998 .34876 .54082 .36136 .53161 .3541 .51732 Mtetra
.855 .689 .676 r
.3541 .51732 .36136 .53161 .37492 .50142 .36769 .48779 Mtetra
.836 .689 .701 r
.36769 .48779 .37492 .50142 .38823 .47382 .38088 .4647 Mtetra
.765 .736 .826 r
.38088 .4647 .38823 .47382 .40089 .46055 .39342 .45538 Mtetra
.572 .796 .984 r
.39342 .45538 .40089 .46055 .41321 .45663 .40574 .45283 Mtetra
.477 .807 1 r
.40574 .45283 .41321 .45663 .42552 .45516 .4181 .45107 Mtetra
.551 .827 .997 r
.4181 .45107 .42552 .45516 .43791 .45344 .43056 .44838 Mtetra
.614 .816 .978 r
.43056 .44838 .43791 .45344 .45039 .4511 .44311 .44492 Mtetra
.638 .788 .954 r
.44311 .44492 .45039 .4511 .46295 .44813 .45573 .44115 Mtetra
.643 .766 .937 r
.45573 .44115 .46295 .44813 .47558 .44459 .46841 .43734 Mtetra
.644 .759 .932 r
.46841 .43734 .47558 .44459 .48829 .44066 .48115 .4335 Mtetra
.647 .763 .934 r
.48115 .4335 .48829 .44066 .50106 .43656 .49395 .42957 Mtetra
.651 .771 .936 r
.49395 .42957 .50106 .43656 .51388 .43243 .50682 .42546 Mtetra
.657 .774 .935 r
.50682 .42546 .51388 .43243 .52677 .42827 .51975 .42115 Mtetra
.662 .772 .931 r
.51975 .42115 .52677 .42827 .53972 .42396 .53274 .41669 Mtetra
.663 .77 .929 r
.53274 .41669 .53972 .42396 .55272 .41924 .54579 .41218 Mtetra
.667 .778 .932 r
.54579 .41218 .55272 .41924 .56578 .414 .5589 .40753 Mtetra
.674 .799 .942 r
.5589 .40753 .56578 .414 .57888 .40807 .57207 .40261 Mtetra
.695 .838 .952 r
.57207 .40261 .57888 .40807 .59201 .40146 .58527 .39695 Mtetra
.721 .876 .954 r
.58527 .39695 .59201 .40146 .60518 .39459 .59851 .39034 Mtetra
.69 .88 .969 r
.59851 .39034 .60518 .39459 .61847 .39021 .61182 .38449 Mtetra
.344 .681 .979 r
.61182 .38449 .61847 .39021 .63214 .39537 .62539 .3855 Mtetra
0 .068 .617 r
.62539 .3855 .63214 .39537 .6465 .41513 .63958 .40056 Mtetra
0 0 .555 r
.63958 .40056 .6465 .41513 .66124 .43753 .65426 .42218 Mtetra
.416 .483 .821 r
.65426 .42218 .66124 .43753 .67529 .43838 .66846 .4265 Mtetra
.852 .737 .736 r
.66846 .4265 .67529 .43838 .68824 .41534 .68164 .40667 Mtetra
.911 .79 .714 r
.68164 .40667 .68824 .41534 .70097 .38987 .6945 .38205 Mtetra
.861 .813 .801 r
.6945 .38205 .70097 .38987 .71419 .37464 .70778 .36657 Mtetra
.744 .789 .889 r
.70778 .36657 .71419 .37464 .72787 .36698 .7215 .35868 Mtetra
.674 .76 .916 r
.7215 .35868 .72787 .36698 .74176 .36189 .73544 .3535 Mtetra
.658 .752 .92 r
.73544 .3535 .74176 .36189 .75575 .35729 .74947 .34884 Mtetra
.656 .751 .92 r
.74947 .34884 .75575 .35729 .76982 .35272 .76359 .34423 Mtetra
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Mtetra
.25239 .50144 .26022 .50856 .27202 .50472 .26422 .49756 Mtetra
.653 .751 .921 r
.26422 .49756 .27202 .50472 .28387 .50091 .2761 .49373 Mtetra
.633 .745 .929 r
.2761 .49373 .28387 .50091 .29574 .49763 .288 .49045 Mtetra
.506 .701 .958 r
.288 .49045 .29574 .49763 .30749 .49696 .29977 .48982 Mtetra
0 .338 .799 r
.29977 .48982 .30749 .49696 .31887 .50362 .31117 .49618 Mtetra
.657 .154 0 r
.31117 .49618 .31887 .50362 .32985 .51915 .32225 .50993 Mtetra
0 .318 .805 r
.32225 .50993 .32985 .51915 .34129 .52998 .33387 .51746 Mtetra
.786 .688 .756 r
.33387 .51746 .34129 .52998 .3541 .51732 .34677 .50351 Mtetra
.847 .691 .689 r
.34677 .50351 .3541 .51732 .36769 .48779 .36028 .4773 Mtetra
.839 .725 .738 r
.36028 .4773 .36769 .48779 .38088 .4647 .37332 .45867 Mtetra
.754 .812 .899 r
.37332 .45867 .38088 .4647 .39342 .45538 .38584 .45121 Mtetra
.572 .831 .994 r
.38584 .45121 .39342 .45538 .40574 .45283 .39822 .44823 Mtetra
.564 .815 .992 r
.39822 .44823 .40574 .45283 .4181 .45107 .41065 .44554 Mtetra
.602 .797 .974 r
.41065 .44554 .4181 .45107 .43056 .44838 .42316 .44245 Mtetra
.616 .79 .965 r
.42316 .44245 .43056 .44838 .44311 .44492 .43575 .43914 Mtetra
.624 .798 .966 r
.43575 .43914 .44311 .44492 .45573 .44115 .4484 .43559 Mtetra
.632 .809 .968 r
.4484 .43559 .45573 .44115 .46841 .43734 .46113 .43178 Mtetra
.639 .812 .966 r
.46113 .43178 .46841 .43734 .48115 .4335 .47392 .42776 Mtetra
.645 .809 .962 r
.47392 .42776 .48115 .4335 .49395 .42957 .48677 .42363 Mtetra
.648 .805 .958 r
.48677 .42363 .49395 .42957 .50682 .42546 .49969 .41943 Mtetra
.648 .803 .957 r
.49969 .41943 .50682 .42546 .51975 .42115 .51266 .41521 Mtetra
.649 .807 .959 r
.51266 .41521 .51975 .42115 .53274 .41669 .5257 .41092 Mtetra
.654 .815 .961 r
.5257 .41092 .53274 .41669 .54579 .41218 .5388 .40645 Mtetra
.661 .82 .96 r
.5388 .40645 .54579 .41218 .5589 .40753 .55196 .40177 Mtetra
.674 .824 .955 r
.55196 .40177 .5589 .40753 .57207 .40261 .56518 .39671 Mtetra
.688 .825 .948 r
.56518 .39671 .57207 .40261 .58527 .39695 .57844 .39123 Mtetra
.702 .835 .946 r
.57844 .39123 .58527 .39695 .59851 .39034 .59176 .38531 Mtetra
.685 .854 .964 r
.59176 .38531 .59851 .39034 .61182 .38449 .60513 .37974 Mtetra
.435 .766 .997 r
.60513 .37974 .61182 .38449 .62539 .3855 .61869 .37879 Mtetra
0 .188 .677 r
.61869 .37879 .62539 .3855 .63958 .40056 .63273 .3892 Mtetra
0 0 .565 r
.63273 .3892 .63958 .40056 .65426 .42218 .64726 .40732 Mtetra
.364 .461 .826 r
.64726 .40732 .65426 .42218 .66846 .4265 .66152 .41286 Mtetra
.81 .704 .748 r
.66152 .41286 .66846 .4265 .68164 .40667 .67491 .39636 Mtetra
.887 .766 .722 r
.67491 .39636 .68164 .40667 .6945 .38205 .68794 .37351 Mtetra
.851 .798 .799 r
.68794 .37351 .6945 .38205 .70778 .36657 .7013 .3583 Mtetra
.745 .785 .886 r
.7013 .3583 .70778 .36657 .7215 .35868 .71507 .35029 Mtetra
.675 .76 .915 r
.71507 .35029 .7215 .35868 .73544 .3535 .72905 .34502 Mtetra
.658 .753 .92 r
.72905 .34502 .73544 .3535 .74947 .34884 .74314 .34032 Mtetra
.656 .751 .92 r
.74314 .34032 .74947 .34884 .76359 .34423 .7573 .33566 Mtetra
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Mtetra
.24449 .49425 .25239 .50144 .26422 .49756 .25636 .49034 Mtetra
.653 .751 .921 r
.25636 .49034 .26422 .49756 .2761 .49373 .26827 .48648 Mtetra
.633 .745 .929 r
.26827 .48648 .2761 .49373 .288 .49045 .2802 .48317 Mtetra
.515 .704 .956 r
.2802 .48317 .288 .49045 .29977 .48982 .292 .48237 Mtetra
0 .409 .853 r
.292 .48237 .29977 .48982 .31117 .49618 .30347 .48786 Mtetra
0 .008 .522 r
.30347 .48786 .31117 .49618 .32225 .50993 .31467 .49931 Mtetra
.22 .458 .875 r
.31467 .49931 .32225 .50993 .33387 .51746 .32643 .50446 Mtetra
.774 .679 .759 r
.32643 .50446 .33387 .51746 .34677 .50351 .33931 .49149 Mtetra
.844 .708 .713 r
.33931 .49149 .34677 .50351 .36028 .4773 .35267 .46938 Mtetra
.844 .768 .779 r
.35267 .46938 .36028 .4773 .37332 .45867 .36564 .45375 Mtetra
.748 .847 .925 r
.36564 .45375 .37332 .45867 .38584 .45121 .37819 .44667 Mtetra
.613 .834 .984 r
.37819 .44667 .38584 .45121 .39822 .44823 .39064 .44306 Mtetra
.604 .811 .979 r
.39064 .44306 .39822 .44823 .41065 .44554 .40313 .4398 Mtetra
.627 .8 .966 r
.40313 .4398 .41065 .44554 .42316 .44245 .41571 .43617 Mtetra
.644 .789 .952 r
.41571 .43617 .42316 .44245 .43575 .43914 .42835 .43222 Mtetra
.649 .772 .938 r
.42835 .43222 .43575 .43914 .4484 .43559 .44106 .42818 Mtetra
.648 .758 .929 r
.44106 .42818 .4484 .43559 .46113 .43178 .45382 .42417 Mtetra
.648 .753 .926 r
.45382 .42417 .46113 .43178 .47392 .42776 .46665 .42017 Mtetra
.649 .755 .927 r
.46665 .42017 .47392 .42776 .48677 .42363 .47954 .41611 Mtetra
.653 .76 .928 r
.47954 .41611 .48677 .42363 .49969 .41943 .4925 .41191 Mtetra
.658 .762 .927 r
.4925 .41191 .49969 .41943 .51266 .41521 .50552 .40752 Mtetra
.663 .76 .922 r
.50552 .40752 .51266 .41521 .5257 .41092 .5186 .40298 Mtetra
.663 .754 .918 r
.5186 .40298 .5257 .41092 .5388 .40645 .53174 .39842 Mtetra
.662 .753 .917 r
.53174 .39842 .5388 .40645 .55196 .40177 .54494 .39387 Mtetra
.655 .755 .923 r
.54494 .39387 .55196 .40177 .56518 .39671 .55821 .3895 Mtetra
.658 .777 .937 r
.55821 .3895 .56518 .39671 .57844 .39123 .57154 .38499 Mtetra
.673 .813 .95 r
.57154 .38499 .57844 .39123 .59176 .38531 .58492 .37992 Mtetra
.665 .839 .967 r
.58492 .37992 .59176 .38531 .60513 .37974 .59836 .3749 Mtetra
.478 .785 .998 r
.59836 .3749 .60513 .37974 .61869 .37879 .61196 .3733 Mtetra
0 .335 .77 r
.61196 .3733 .61869 .37879 .63273 .3892 .62593 .38047 Mtetra
0 .092 .624 r
.62593 .38047 .63273 .3892 .64726 .40732 .6403 .39426 Mtetra
.371 .499 .858 r
.6403 .39426 .64726 .40732 .66152 .41286 .65452 .39868 Mtetra
.783 .689 .76 r
.65452 .39868 .66152 .41286 .67491 .39636 .66806 .38456 Mtetra
.859 .743 .733 r
.66806 .38456 .67491 .39636 .68794 .37351 .68128 .36403 Mtetra
.832 .778 .801 r
.68128 .36403 .68794 .37351 .7013 .3583 .69475 .34967 Mtetra
.739 .777 .883 r
.69475 .34967 .7013 .3583 .71507 .35029 .70858 .34177 Mtetra
.675 .759 .914 r
.70858 .34177 .71507 .35029 .72905 .34502 .72261 .33647 Mtetra
.658 .752 .92 r
.72261 .33647 .72905 .34502 .74314 .34032 .73674 .33172 Mtetra
.656 .751 .92 r
.73674 .33172 .74314 .34032 .7573 .33566 .75096 .32702 Mtetra
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Mtetra
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .48701 Mtetra
.23653 .48701 .24449 .49425 .25636 .49034 .24842 .48306 Mtetra
.653 .751 .921 r
.24842 .48306 .25636 .49034 .26827 .48648 .26037 .47916 Mtetra
.635 .746 .928 r
.26037 .47916 .26827 .48648 .2802 .48317 .27233 .47575 Mtetra
.537 .71 .951 r
.27233 .47575 .2802 .48317 .292 .48237 .28419 .47454 Mtetra
.153 .5 .908 r
.28419 .47454 .292 .48237 .30347 .48786 .29575 .47867 Mtetra
0 .197 .712 r
.29575 .47867 .30347 .48786 .31467 .49931 .3071 .48779 Mtetra
.323 .497 .875 r
.3071 .48779 .31467 .49931 .32643 .50446 .31892 .49179 Mtetra
.752 .677 .779 r
.31892 .49179 .32643 .50446 .33931 .49149 .33171 .48118 Mtetra
.839 .729 .743 r
.33171 .48118 .33931 .49149 .35267 .46938 .34493 .46287 Mtetra
.843 .8 .809 r
.34493 .46287 .35267 .46938 .36564 .45375 .35787 .44902 Mtetra
.754 .854 .925 r
.35787 .44902 .36564 .45375 .37819 .44667 .37049 .44169 Mtetra
.656 .832 .968 r
.37049 .44169 .37819 .44667 .39064 .44306 .38301 .43724 Mtetra
.638 .802 .962 r
.38301 .43724 .39064 .44306 .40313 .4398 .39557 .43337 Mtetra
.637 .783 .951 r
.39557 .43337 .40313 .4398 .41571 .43617 .40819 .42958 Mtetra
.636 .779 .95 r
.40819 .42958 .41571 .43617 .42835 .43222 .42086 .42583 Mtetra
.637 .786 .953 r
.42086 .42583 .42835 .43222 .44106 .42818 .43361 .42199 Mtetra
.64 .795 .957 r
.43361 .42199 .44106 .42818 .45382 .42417 .44642 .41802 Mtetra
.644 .798 .957 r
.44642 .41802 .45382 .42417 .46665 .42017 .45929 .41392 Mtetra
.646 .797 .955 r
.45929 .41392 .46665 .42017 .47954 .41611 .47223 .40976 Mtetra
.645 .795 .954 r
.47223 .40976 .47954 .41611 .4925 .41191 .48523 .4056 Mtetra
.641 .796 .957 r
.48523 .4056 .4925 .41191 .50552 .40752 .49829 .40152 Mtetra
.637 .805 .964 r
.49829 .40152 .50552 .40752 .5186 .40298 .51142 .39746 Mtetra
.641 .823 .97 r
.51142 .39746 .5186 .40298 .53174 .39842 .52461 .39316 Mtetra
.652 .836 .971 r
.52461 .39316 .53174 .39842 .54494 .39387 .53787 .3885 Mtetra
.677 .841 .962 r
.53787 .3885 .54494 .39387 .55821 .3895 .55118 .38319 Mtetra
.683 .814 .945 r
.55118 .38319 .55821 .3895 .57154 .38499 .56455 .37782 Mtetra
.664 .783 .937 r
.56455 .37782 .57154 .38499 .58492 .37992 .57799 .37305 Mtetra
.629 .782 .955 r
.57799 .37305 .58492 .37992 .59836 .3749 .59151 .3692 Mtetra
.475 .756 .992 r
.59151 .3692 .59836 .3749 .61196 .3733 .60516 .36805 Mtetra
0 .451 .848 r
.60516 .36805 .61196 .3733 .62593 .38047 .61911 .37326 Mtetra
0 .247 .733 r
.61911 .37326 .62593 .38047 .6403 .39426 .63335 .38295 Mtetra
.443 .579 .895 r
.63335 .38295 .6403 .39426 .65452 .39868 .64749 .38478 Mtetra
.774 .69 .771 r
.64749 .38478 .65452 .39868 .66806 .38456 .66113 .37177 Mtetra
.833 .725 .745 r
.66113 .37177 .66806 .38456 .68128 .36403 .67451 .35363 Mtetra
.807 .757 .806 r
.67451 .35363 .68128 .36403 .69475 .34967 .68812 .34063 Mtetra
.728 .765 .882 r
.68812 .34063 .69475 .34967 .70858 .34177 .70202 .3331 Mtetra
.673 .756 .913 r
.70202 .3331 .70858 .34177 .72261 .33647 .71611 .32782 Mtetra
.658 .752 .919 r
.71611 .32782 .72261 .33647 .73674 .33172 .73029 .32303 Mtetra
.656 .751 .92 r
.73029 .32303 .73674 .33172 .75096 .32702 .74455 .31829 Mtetra
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .48701 .2285 .4797 Mtetra
.2285 .4797 .23653 .48701 .24842 .48306 .24043 .47572 Mtetra
.654 .751 .921 r
.24043 .47572 .24842 .48306 .26037 .47916 .2524 .47177 Mtetra
.64 .747 .926 r
.2524 .47177 .26037 .47916 .27233 .47575 .26441 .4682 Mtetra
.567 .719 .944 r
.26441 .4682 .27233 .47575 .28419 .47454 .27634 .46637 Mtetra
.308 .582 .938 r
.27634 .46637 .28419 .47454 .29575 .47867 .28802 .46887 Mtetra
.014 .353 .828 r
.28802 .46887 .29575 .47867 .3071 .48779 .29951 .47579 Mtetra
.345 .5 .87 r
.29951 .47579 .3071 .48779 .31892 .49179 .31134 .47955 Mtetra
.713 .671 .808 r
.31134 .47955 .31892 .49179 .33171 .48118 .32398 .47194 Mtetra
.826 .746 .776 r
.32398 .47194 .33171 .48118 .34493 .46287 .33707 .45695 Mtetra
.838 .817 .829 r
.33707 .45695 .34493 .46287 .35787 .44902 .35002 .44416 Mtetra
.765 .852 .916 r
.35002 .44416 .35787 .44902 .37049 .44169 .36271 .43633 Mtetra
.68 .827 .954 r
.36271 .43633 .37049 .44169 .38301 .43724 .37531 .43129 Mtetra
.65 .802 .956 r
.37531 .43129 .38301 .43724 .39557 .43337 .38792 .42708 Mtetra
.649 .793 .951 r
.38792 .42708 .39557 .43337 .40819 .42958 .4006 .42292 Mtetra
.653 .784 .944 r
.4006 .42292 .40819 .42958 .42086 .42583 .41333 .41868 Mtetra
.653 .77 .935 r
.41333 .41868 .42086 .42583 .43361 .42199 .42612 .41445 Mtetra
.652 .759 .928 r
.42612 .41445 .43361 .42199 .44642 .41802 .43898 .41026 Mtetra
.651 .754 .925 r
.43898 .41026 .44642 .41802 .45929 .41392 .45189 .40608 Mtetra
.653 .754 .923 r
.45189 .40608 .45929 .41392 .47223 .40976 .46487 .40182 Mtetra
.657 .753 .921 r
.46487 .40182 .47223 .40976 .48523 .4056 .47791 .39741 Mtetra
.664 .749 .914 r
.47791 .39741 .48523 .4056 .49829 .40152 .49102 .39278 Mtetra
.663 .736 .904 r
.49102 .39278 .49829 .40152 .51142 .39746 .50419 .38813 Mtetra
.648 .717 .898 r
.50419 .38813 .51142 .39746 .52461 .39316 .51742 .38396 Mtetra
.629 .713 .907 r
.51742 .38396 .52461 .39316 .53787 .3885 .53071 .38039 Mtetra
.612 .737 .935 r
.53071 .38039 .53787 .3885 .55118 .38319 .54408 .37722 Mtetra
.634 .812 .968 r
.54408 .37722 .55118 .38319 .56455 .37782 .55752 .37305 Mtetra
.666 .861 .974 r
.55752 .37305 .56455 .37782 .57799 .37305 .57101 .36778 Mtetra
.632 .836 .979 r
.57101 .36778 .57799 .37305 .59151 .3692 .58457 .36341 Mtetra
.463 .75 .991 r
.58457 .36341 .59151 .3692 .60516 .36805 .59829 .36246 Mtetra
.075 .522 .901 r
.59829 .36246 .60516 .36805 .61911 .37326 .61224 .36658 Mtetra
0 .431 .86 r
.61224 .36658 .61911 .37326 .63335 .38295 .6264 .3727 Mtetra
.555 .664 .909 r
.6264 .3727 .63335 .38295 .64749 .38478 .64044 .37126 Mtetra
.775 .697 .777 r
.64044 .37126 .64749 .38478 .66113 .37177 .65413 .35843 Mtetra
.809 .711 .757 r
.65413 .35843 .66113 .37177 .67451 .35363 .66767 .34255 Mtetra
.779 .738 .815 r
.66767 .34255 .67451 .35363 .68812 .34063 .68141 .33122 Mtetra
.713 .753 .884 r
.68141 .33122 .68812 .34063 .70202 .3331 .6954 .32428 Mtetra
.669 .753 .913 r
.6954 .32428 .70202 .3331 .71611 .32782 .70954 .31909 Mtetra
.658 .752 .919 r
.70954 .31909 .71611 .32782 .73029 .32303 .72378 .31427 Mtetra
.656 .751 .92 r
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Mtetra
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.2204 .47233 .2285 .4797 .24043 .47572 .23236 .46831 Mtetra
.655 .751 .921 r
.23236 .46831 .24043 .47572 .2524 .47177 .24437 .46431 Mtetra
.645 .748 .924 r
.24437 .46431 .2524 .47177 .26441 .4682 .25642 .46056 Mtetra
.598 .729 .936 r
.25642 .46056 .26441 .4682 .27634 .46637 .26843 .45802 Mtetra
.435 .642 .944 r
.26843 .45802 .27634 .46637 .28802 .46887 .28026 .45877 Mtetra
.205 .467 .885 r
.28026 .45877 .28802 .46887 .29951 .47579 .29189 .46357 Mtetra
.34 .494 .866 r
.29189 .46357 .29951 .47579 .31134 .47955 .3037 .46744 Mtetra
.652 .651 .837 r
.3037 .46744 .31134 .47955 .32398 .47194 .31616 .46302 Mtetra
.799 .751 .809 r
.31616 .46302 .32398 .47194 .33707 .45695 .32912 .45117 Mtetra
.829 .823 .843 r
.32912 .45117 .33707 .45695 .35002 .44416 .34209 .43924 Mtetra
.777 .852 .908 r
.34209 .43924 .35002 .44416 .36271 .43633 .35486 .43087 Mtetra
.705 .831 .942 r
.35486 .43087 .36271 .43633 .37531 .43129 .36754 .42508 Mtetra
.669 .801 .946 r
.36754 .42508 .37531 .43129 .38792 .42708 .38022 .42036 Mtetra
.654 .783 .943 r
.38022 .42036 .38792 .42708 .4006 .42292 .39294 .41609 Mtetra
.646 .778 .944 r
.39294 .41609 .4006 .42292 .41333 .41868 .40571 .41201 Mtetra
.645 .784 .948 r
.40571 .41201 .41333 .41868 .42612 .41445 .41854 .40792 Mtetra
.646 .79 .951 r
.41854 .40792 .42612 .41445 .43898 .41026 .43143 .40376 Mtetra
.649 .792 .951 r
.43143 .40376 .43898 .41026 .45189 .40608 .44439 .39949 Mtetra
.65 .791 .95 r
.44439 .39949 .45189 .40608 .46487 .40182 .45742 .39518 Mtetra
.652 .791 .949 r
.45742 .39518 .46487 .40182 .47791 .39741 .4705 .39081 Mtetra
.653 .794 .95 r
.4705 .39081 .47791 .39741 .49102 .39278 .48366 .38638 Mtetra
.666 .805 .949 r
.48366 .38638 .49102 .39278 .50419 .38813 .49687 .38154 Mtetra
.698 .809 .934 r
.49687 .38154 .50419 .38813 .51742 .38396 .51016 .3757 Mtetra
.697 .763 .903 r
.51016 .3757 .51742 .38396 .53071 .38039 .52349 .36981 Mtetra
.649 .692 .876 r
.52349 .36981 .53071 .38039 .54408 .37722 .53689 .36544 Mtetra
.586 .64 .871 r
.53689 .36544 .54408 .37722 .55752 .37305 .55037 .36329 Mtetra
.579 .683 .912 r
.55037 .36329 .55752 .37305 .57101 .36778 .56394 .36115 Mtetra
.581 .775 .972 r
.56394 .36115 .57101 .36778 .58457 .36341 .57758 .35828 Mtetra
.434 .759 .996 r
.57758 .35828 .58457 .36341 .59829 .36246 .59135 .35736 Mtetra
.152 .594 .932 r
.59135 .35736 .59829 .36246 .61224 .36658 .6053 .36009 Mtetra
.25 .611 .955 r
.6053 .36009 .61224 .36658 .6264 .3727 .61939 .36263 Mtetra
.661 .717 .89 r
.61939 .36263 .6264 .3727 .64044 .37126 .63335 .35771 Mtetra
.777 .698 .777 r
.63335 .35771 .64044 .37126 .65413 .35843 .64708 .34477 Mtetra
.784 .7 .771 r
.64708 .34477 .65413 .35843 .66767 .34255 .66077 .33113 Mtetra
.749 .724 .829 r
.66077 .33113 .66767 .34255 .68141 .33122 .67465 .32161 Mtetra
.695 .744 .889 r
.67465 .32161 .68141 .33122 .6954 .32428 .68872 .31534 Mtetra
.665 .75 .914 r
.68872 .31534 .6954 .32428 .70954 .31909 .70292 .31026 Mtetra
.657 .751 .919 r
.70292 .31026 .70954 .31909 .72378 .31427 .71721 .30543 Mtetra
.656 .751 .92 r
.71721 .30543 .72378 .31427 .73809 .30949 .73157 .3006 Mtetra
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Mtetra
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Mtetra
.655 .751 .92 r
.22422 .46084 .23236 .46831 .24437 .46431 .23627 .45679 Mtetra
.65 .749 .922 r
.23627 .45679 .24437 .46431 .25642 .46056 .24836 .45286 Mtetra
.623 .738 .929 r
.24836 .45286 .25642 .46056 .26843 .45802 .26045 .44966 Mtetra
.529 .685 .938 r
.26045 .44966 .26843 .45802 .28026 .45877 .27242 .44871 Mtetra
.357 .557 .91 r
.27242 .44871 .28026 .45877 .29189 .46357 .28422 .4513 Mtetra
.347 .498 .867 r
.28422 .4513 .29189 .46357 .3037 .46744 .29604 .45499 Mtetra
.567 .609 .855 r
.29604 .45499 .3037 .46744 .31616 .46302 .30831 .45364 Mtetra
.748 .736 .841 r
.30831 .45364 .31616 .46302 .32912 .45117 .32111 .44518 Mtetra
.813 .821 .856 r
.32111 .44518 .32912 .45117 .34209 .43924 .33407 .43431 Mtetra
.787 .853 .901 r
.33407 .43431 .34209 .43924 .35486 .43087 .34693 .42542 Mtetra
.723 .835 .934 r
.34693 .42542 .35486 .43087 .36754 .42508 .35969 .41901 Mtetra
.68 .81 .945 r
.35969 .41901 .36754 .42508 .38022 .42036 .37243 .41393 Mtetra
.666 .797 .945 r
.37243 .41393 .38022 .42036 .39294 .41609 .3852 .40926 Mtetra
.662 .785 .94 r
.3852 .40926 .39294 .41609 .40571 .41201 .39803 .40471 Mtetra
.658 .771 .933 r
.39803 .40471 .40571 .41201 .41854 .40792 .41091 .40028 Mtetra
.656 .762 .928 r
.41091 .40028 .41854 .40792 .43143 .40376 .42385 .3959 Mtetra
.656 .757 .924 r
.42385 .3959 .43143 .40376 .44439 .39949 .43686 .39151 Mtetra
.659 .755 .921 r
.43686 .39151 .44439 .39949 .45742 .39518 .44992 .38701 Mtetra
.666 .754 .916 r
.44992 .38701 .45742 .39518 .4705 .39081 .46306 .38225 Mtetra
.665 .744 .909 r
.46306 .38225 .4705 .39081 .48366 .38638 .47625 .37747 Mtetra
.641 .728 .911 r
.47625 .37747 .48366 .38638 .49687 .38154 .4895 .37346 Mtetra
.604 .738 .939 r
.4895 .37346 .49687 .38154 .51016 .3757 .50281 .37042 Mtetra
.655 .841 .972 r
.50281 .37042 .51016 .3757 .52349 .36981 .5162 .36555 Mtetra
.719 .89 .958 r
.5162 .36555 .52349 .36981 .53689 .36544 .52966 .35874 Mtetra
.653 .798 .953 r
.52966 .35874 .53689 .36544 .55037 .36329 .54317 .35415 Mtetra
.551 .689 .931 r
.54317 .35415 .55037 .36329 .56394 .36115 .55678 .35258 Mtetra
.507 .685 .947 r
.55678 .35258 .56394 .36115 .57758 .35828 .57049 .35187 Mtetra
.403 .702 .982 r
.57049 .35187 .57758 .35828 .59135 .35736 .58432 .35209 Mtetra
.279 .671 .971 r
.58432 .35209 .59135 .35736 .6053 .36009 .59829 .35332 Mtetra
.51 .746 .98 r
.59829 .35332 .6053 .36009 .61939 .36263 .61231 .35182 Mtetra
.73 .728 .849 r
.61231 .35182 .61939 .36263 .63335 .35771 .62621 .34361 Mtetra
.768 .689 .775 r
.62621 .34361 .63335 .35771 .64708 .34477 .63998 .33102 Mtetra
.755 .689 .788 r
.63998 .33102 .64708 .34477 .66077 .33113 .65382 .31978 Mtetra
.718 .715 .847 r
.65382 .31978 .66077 .33113 .67465 .32161 .66782 .31199 Mtetra
.679 .739 .896 r
.66782 .31199 .67465 .32161 .68872 .31534 .68198 .30634 Mtetra
.66 .749 .916 r
.68198 .30634 .68872 .31534 .70292 .31026 .69624 .30136 Mtetra
.656 .751 .92 r
.69624 .30136 .70292 .31026 .71721 .30543 .71057 .2965 Mtetra
.71057 .2965 .71721 .30543 .73157 .3006 .72498 .29163 Mtetra
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Mtetra
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Mtetra
.21602 .45331 .22422 .46084 .23627 .45679 .2281 .44921 Mtetra
.653 .75 .921 r
.2281 .44921 .23627 .45679 .24836 .45286 .24023 .44516 Mtetra
.641 .744 .924 r
.24023 .44516 .24836 .45286 .26045 .44966 .25239 .44144 Mtetra
.592 .715 .93 r
.25239 .44144 .26045 .44966 .27242 .44871 .2645 .43903 Mtetra
.48 .631 .919 r
.2645 .43903 .27242 .44871 .28422 .4513 .27648 .43931 Mtetra
.393 .532 .876 r
.27648 .43931 .28422 .4513 .29604 .45499 .28837 .44197 Mtetra
.483 .559 .857 r
.28837 .44197 .29604 .45499 .30831 .45364 .30049 .44297 Mtetra
.661 .686 .863 r
.30049 .44297 .30831 .45364 .32111 .44518 .31307 .43834 Mtetra
.775 .801 .874 r
.31307 .43834 .32111 .44518 .33407 .43431 .32597 .42938 Mtetra
.79 .855 .899 r
.32597 .42938 .33407 .43431 .34693 .42542 .3389 .42031 Mtetra
.747 .85 .927 r
.3389 .42031 .34693 .42542 .35969 .41901 .35175 .413 Mtetra
.701 .818 .937 r
.35175 .413 .35969 .41901 .37243 .41393 .36457 .40725 Mtetra
.671 .792 .939 r
.36457 .40725 .37243 .41393 .3852 .40926 .3774 .4024 Mtetra
.655 .784 .943 r
.3774 .4024 .3852 .40926 .39803 .40471 .39026 .39799 Mtetra
.652 .788 .947 r
.39026 .39799 .39803 .40471 .41091 .40028 .40318 .39364 Mtetra
.651 .792 .949 r
.40318 .39364 .41091 .40028 .42385 .3959 .41616 .38926 Mtetra
.654 .793 .949 r
.41616 .38926 .42385 .3959 .43686 .39151 .42921 .3848 Mtetra
.655 .793 .948 r
.42921 .3848 .43686 .39151 .44992 .38701 .44233 .3803 Mtetra
.664 .797 .946 r
.44233 .3803 .44992 .38701 .46306 .38225 .45551 .37551 Mtetra
.645 .791 .952 r
.45551 .37551 .46306 .38225 .47625 .37747 .46874 .37121 Mtetra
.656 .81 .958 r
.46874 .37121 .47625 .37747 .4895 .37346 .48205 .36654 Mtetra
.62 .78 .958 r
.48205 .36654 .4895 .37346 .50281 .37042 .49541 .36288 Mtetra
.343 .633 .96 r
.49541 .36288 .50281 .37042 .5162 .36555 .50881 .36456 Mtetra
.601 .938 .946 r
.50881 .36456 .5162 .36555 .52966 .35874 .52234 .35846 Mtetra
.647 .963 .917 r
.52234 .35846 .52966 .35874 .54317 .35415 .53592 .35093 Mtetra
.506 .854 .993 r
.53592 .35093 .54317 .35415 .55678 .35258 .54958 .34774 Mtetra
.417 .763 .995 r
.54958 .34774 .55678 .35258 .57049 .35187 .56334 .3468 Mtetra
.377 .735 .99 r
.56334 .3468 .57049 .35187 .58432 .35209 .57722 .34654 Mtetra
.485 .775 .996 r
.57722 .34654 .58432 .35209 .59829 .35332 .59118 .3449 Mtetra
.687 .77 .915 r
.59118 .3449 .59829 .35332 .61231 .35182 .60512 .3391 Mtetra
.75 .702 .807 r
.60512 .3391 .61231 .35182 .62621 .34361 .619 .32878 Mtetra
.744 .671 .779 r
.619 .32878 .62621 .34361 .63998 .33102 .63286 .31765 Mtetra
.721 .682 .812 r
.63286 .31765 .63998 .33102 .65382 .31978 .64684 .30888 Mtetra
.69 .716 .868 r
.64684 .30888 .65382 .31978 .66782 .31199 .66095 .30254 Mtetra
.667 .741 .905 r
.66095 .30254 .66782 .31199 .68198 .30634 .67518 .29731 Mtetra
.657 .749 .918 r
.67518 .29731 .68198 .30634 .69624 .30136 .68949 .29239 Mtetra
.656 .751 .92 r
.68949 .29239 .69624 .30136 .71057 .2965 .70388 .28749 Mtetra
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25761 Mtetra
.13623 .47016 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Mtetra
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Mtetra
.655 .751 .92 r
.21985 .44157 .2281 .44921 .24023 .44516 .23202 .43744 Mtetra
.651 .749 .921 r
.23202 .43744 .24023 .44516 .25239 .44144 .24424 .43341 Mtetra
.63 .735 .923 r
.24424 .43341 .25239 .44144 .2645 .43903 .25646 .42997 Mtetra
.571 .688 .92 r
.25646 .42997 .2645 .43903 .27648 .43931 .26862 .42812 Mtetra
.48 .596 .892 r
.26862 .42812 .27648 .43931 .28837 .44197 .28067 .42874 Mtetra
.454 .541 .856 r
.28067 .42874 .28837 .44197 .30049 .44297 .29273 .43042 Mtetra
.55 .603 .859 r
.29273 .43042 .30049 .44297 .31307 .43834 .30508 .42948 Mtetra
.693 .738 .886 r
.30508 .42948 .31307 .43834 .32597 .42938 .31782 .42379 Mtetra
.769 .837 .904 r
.31782 .42379 .32597 .42938 .3389 .42031 .33075 .41552 Mtetra
.76 .861 .924 r
.33075 .41552 .3389 .42031 .35175 .413 .34369 .40769 Mtetra
.719 .843 .941 r
.34369 .40769 .35175 .413 .36457 .40725 .3566 .40129 Mtetra
.693 .821 .944 r
.3566 .40129 .36457 .40725 .3774 .4024 .3695 .39571 Mtetra
.675 .796 .94 r
.3695 .39571 .3774 .4024 .39026 .39799 .38243 .39069 Mtetra
.666 .777 .932 r
.38243 .39069 .39026 .39799 .40318 .39364 .39541 .38592 Mtetra
.655 .764 .929 r
.39541 .38592 .40318 .39364 .41616 .38926 .40844 .38148 Mtetra
.658 .764 .928 r
.40844 .38148 .41616 .38926 .42921 .3848 .42153 .37693 Mtetra
.656 .762 .928 r
.42153 .37693 .42921 .3848 .44233 .3803 .43468 .37243 Mtetra
.667 .766 .924 r
.43468 .37243 .44233 .3803 .45551 .37551 .44791 .36754 Mtetra
.615 .747 .94 r
.44791 .36754 .45551 .37551 .46874 .37121 .46117 .36416 Mtetra
.645 .785 .949 r
.46117 .36416 .46874 .37121 .48205 .36654 .47451 .35984 Mtetra
.822 .829 .854 r
.47451 .35984 .48205 .36654 .49541 .36288 .48801 .34807 Mtetra
.115 .312 .784 r
.48801 .34807 .49541 .36288 .50881 .36456 .50136 .35792 Mtetra
.618 .792 .965 r
.50136 .35792 .50881 .36456 .52234 .35846 .51494 .35412 Mtetra
.68 .883 .974 r
.51494 .35412 .52234 .35846 .53592 .35093 .52859 .3482 Mtetra
.488 .86 .985 r
.52859 .3482 .53592 .35093 .54958 .34774 .54231 .34489 Mtetra
.443 .836 .982 r
.54231 .34489 .54958 .34774 .56334 .3468 .55612 .34224 Mtetra
.552 .838 .998 r
.55612 .34224 .56334 .3468 .57722 .34654 .57001 .33892 Mtetra
.694 .794 .927 r
.57001 .33892 .57722 .34654 .59118 .3449 .58393 .3329 Mtetra
.733 .709 .828 r
.58393 .3329 .59118 .3449 .60512 .3391 .59784 .32404 Mtetra
.728 .661 .784 r
.59784 .32404 .60512 .3391 .619 .32878 .61175 .31401 Mtetra
.709 .658 .797 r
.61175 .31401 .619 .32878 .63286 .31765 .62574 .30538 Mtetra
.69 .69 .844 r
.62574 .30538 .63286 .31765 .64684 .30888 .63983 .29869 Mtetra
.669 .725 .891 r
.63983 .29869 .64684 .30888 .66095 .30254 .65403 .29328 Mtetra
.66 .745 .913 r
.65403 .29328 .66095 .30254 .67518 .29731 .66831 .28825 Mtetra
.656 .75 .919 r
.66831 .28825 .67518 .29731 .68949 .29239 .68268 .28334 Mtetra
.656 .752 .92 r
.68268 .28334 .68949 .29239 .70388 .28749 .69712 .27839 Mtetra
.655 .751 .92 r
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27344 Mtetra
.656 .752 .92 r
.71163 .27344 .71834 .28257 .73287 .27763 .72622 .26844 Mtetra
.656 .751 .92 r
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.656 .752 .92 r
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.656 .751 .92 r
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25761 .78532 .24824 Mtetra
.656 .752 .92 r
.12769 .46272 .13623 .47016 .14801 .46614 .1395 .45865 Mtetra
.656 .751 .92 r
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Mtetra
.21154 .43388 .21985 .44157 .23202 .43744 .22374 .42968 Mtetra
.654 .75 .92 r
.22374 .42968 .23202 .43744 .24424 .43341 .236 .42551 Mtetra
.648 .746 .921 r
.236 .42551 .24424 .43341 .25646 .42997 .2483 .4215 Mtetra
.624 .724 .919 r
.2483 .4215 .25646 .42997 .26862 .42812 .2606 .41819 Mtetra
.571 .668 .904 r
.2606 .41819 .26862 .42812 .28067 .42874 .27285 .41639 Mtetra
.505 .586 .87 r
.27285 .41639 .28067 .42874 .29273 .43042 .28503 .41658 Mtetra
.495 .554 .845 r
.28503 .41658 .29273 .43042 .30508 .42948 .29726 .41729 Mtetra
.566 .62 .865 r
.29726 .41729 .30508 .42948 .31782 .42379 .30974 .41577 Mtetra
.685 .76 .908 r
.30974 .41577 .31782 .42379 .33075 .41552 .32254 .41043 Mtetra
.75 .854 .927 r
.32254 .41043 .33075 .41552 .34369 .40769 .33551 .40293 Mtetra
.746 .865 .935 r
.33551 .40293 .34369 .40769 .3566 .40129 .34852 .39557 Mtetra
.704 .832 .943 r
.34852 .39557 .3566 .40129 .3695 .39571 .3615 .38958 Mtetra
.678 .815 .949 r
.3615 .38958 .3695 .39571 .38243 .39069 .37448 .38438 Mtetra
.658 .806 .954 r
.37448 .38438 .38243 .39069 .39541 .38592 .3875 .37972 Mtetra
.661 .811 .955 r
.3875 .37972 .39541 .38592 .40844 .38148 .40059 .37493 Mtetra
.645 .797 .956 r
.40059 .37493 .40844 .38148 .42153 .37693 .41372 .3706 Mtetra
.655 .808 .957 r
.41372 .3706 .42153 .37693 .43468 .37243 .42692 .36596 Mtetra
.621 .794 .965 r
.42692 .36596 .43468 .37243 .44791 .36754 .44017 .36215 Mtetra
.697 .85 .956 r
.44017 .36215 .44791 .36754 .46117 .36416 .45354 .35617 Mtetra
.647 .761 .932 r
.45354 .35617 .46117 .36416 .47451 .35984 .46693 .35181 Mtetra
.618 .128 0 r
.46693 .35181 .47451 .35984 .48801 .34807 .48009 .36825 Mtetra
0 0 .005 r
.48009 .36825 .48801 .34807 .50136 .35792 .49384 .34994 Mtetra
.53 .719 .96 r
.49384 .34994 .50136 .35792 .51494 .35412 .50745 .34841 Mtetra
.658 .837 .969 r
.50745 .34841 .51494 .35412 .52859 .3482 .52116 .34333 Mtetra
.678 .87 .971 r
.52116 .34333 .52859 .3482 .54231 .34489 .53493 .33752 Mtetra
.678 .796 .937 r
.53493 .33752 .54231 .34489 .55612 .34224 .54877 .33201 Mtetra
.709 .735 .871 r
.54877 .33201 .55612 .34224 .57001 .33892 .56265 .32498 Mtetra
.703 .666 .811 r
.56265 .32498 .57001 .33892 .58393 .3329 .57656 .31709 Mtetra
.702 .641 .785 r
.57656 .31709 .58393 .3329 .59784 .32404 .59051 .30853 Mtetra
.687 .638 .795 r
.59051 .30853 .59784 .32404 .61175 .31401 .60451 .30099 Mtetra
.68 .673 .836 r
.60451 .30099 .61175 .31401 .62574 .30538 .6186 .29458 Mtetra
.666 .711 .881 r
.6186 .29458 .62574 .30538 .63983 .29869 .63279 .28919 Mtetra
.661 .74 .909 r
.63279 .28919 .63983 .29869 .65403 .29328 .64705 .2841 Mtetra
.655 .748 .918 r
.64705 .2841 .65403 .29328 .66831 .28825 .66139 .27917 Mtetra
.657 .752 .92 r
.66139 .27917 .66831 .28825 .68268 .28334 .6758 .27418 Mtetra
.655 .751 .92 r
.6758 .27418 .68268 .28334 .69712 .27839 .69029 .26922 Mtetra
.656 .752 .92 r
.69029 .26922 .69712 .27839 .71163 .27344 .70486 .2642 Mtetra
.655 .751 .92 r
.70486 .2642 .71163 .27344 .72622 .26844 .7195 .25918 Mtetra
.656 .752 .92 r
.7195 .25918 .72622 .26844 .74088 .26343 .73421 .2541 Mtetra
.655 .751 .92 r
.73421 .2541 .74088 .26343 .75562 .25839 .749 .24903 Mtetra
.656 .752 .92 r
.749 .24903 .75562 .25839 .77043 .25333 .76387 .2439 Mtetra
.656 .751 .92 r
.76387 .2439 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Mtetra
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Mtetra
.655 .751 .92 r
.21539 .42188 .22374 .42968 .236 .42551 .22768 .41763 Mtetra
.654 .75 .92 r
.22768 .41763 .236 .42551 .2483 .4215 .24003 .41341 Mtetra
.647 .743 .919 r
.24003 .41341 .2483 .4215 .2606 .41819 .25242 .40936 Mtetra
.628 .719 .912 r
.25242 .40936 .2606 .41819 .27285 .41639 .26483 .40589 Mtetra
.587 .664 .892 r
.26483 .40589 .27285 .41639 .28503 .41658 .2772 .40365 Mtetra
.54 .594 .857 r
.2772 .40365 .28503 .41658 .29726 .41729 .28954 .40292 Mtetra
.521 .56 .836 r
.28954 .40292 .29726 .41729 .30974 .41577 .30192 .4029 Mtetra
.556 .605 .857 r
.30192 .4029 .30974 .41577 .32254 .41043 .31447 .40167 Mtetra
.637 .729 .915 r
.31447 .40167 .32254 .41043 .33551 .40293 .32726 .39781 Mtetra
.711 .851 .949 r
.32726 .39781 .33551 .40293 .34852 .39557 .34026 .39157 Mtetra
.731 .888 .952 r
.34026 .39157 .34852 .39557 .3615 .38958 .35335 .38456 Mtetra
.718 .858 .948 r
.35335 .38456 .3615 .38958 .37448 .38438 .36645 .37803 Mtetra
.689 .815 .943 r
.36645 .37803 .37448 .38438 .3875 .37972 .37956 .37246 Mtetra
.668 .784 .936 r
.37956 .37246 .3875 .37972 .40059 .37493 .39269 .36752 Mtetra
.653 .776 .939 r
.39269 .36752 .40059 .37493 .41372 .3706 .40587 .36301 Mtetra
.65 .772 .938 r
.40587 .36301 .41372 .3706 .42692 .36596 .41911 .35859 Mtetra
.626 .771 .95 r
.41911 .35859 .42692 .36596 .44017 .36215 .4324 .35475 Mtetra
.603 .763 .956 r
.4324 .35475 .44017 .36215 .45354 .35617 .44575 .35147 Mtetra
.406 .763 .994 r
.44575 .35147 .45354 .35617 .46693 .35181 .45913 .35054 Mtetra
.242 .748 .885 r
.45913 .35054 .46693 .35181 .48009 .36825 .47261 .34909 Mtetra
.739 .622 .729 r
.47261 .34909 .48009 .36825 .49384 .34994 .48633 .33565 Mtetra
.689 .652 .808 r
.48633 .33565 .49384 .34994 .50745 .34841 .5 .32849 Mtetra
.604 .545 .761 r
.5 .32849 .50745 .34841 .52116 .34333 .5137 .32482 Mtetra
.624 .57 .773 r
.5137 .32482 .52116 .34333 .53493 .33752 .52748 .32023 Mtetra
.644 .594 .784 r
.52748 .32023 .53493 .33752 .54877 .33201 .54132 .31476 Mtetra
.658 .603 .781 r
.54132 .31476 .54877 .33201 .56265 .32498 .55522 .30845 Mtetra
.663 .614 .789 r
.55522 .30845 .56265 .32498 .57656 .31709 .56918 .30202 Mtetra
.666 .635 .809 r
.56918 .30202 .57656 .31709 .59051 .30853 .58319 .29583 Mtetra
.665 .673 .848 r
.58319 .29583 .59051 .30853 .60451 .30099 .59728 .29021 Mtetra
.662 .711 .884 r
.59728 .29021 .60451 .30099 .6186 .29458 .61145 .28496 Mtetra
.658 .737 .908 r
.61145 .28496 .6186 .29458 .63279 .28919 .62569 .27995 Mtetra
.657 .748 .917 r
.62569 .27995 .63279 .28919 .64705 .2841 .64001 .27496 Mtetra
.656 .751 .92 r
.64001 .27496 .64705 .2841 .66139 .27917 .6544 .26999 Mtetra
.6544 .26999 .66139 .27917 .6758 .27418 .66887 .26497 Mtetra
.656 .752 .921 r
.66887 .26497 .6758 .27418 .69029 .26922 .68341 .25995 Mtetra
.656 .751 .92 r
.68341 .25995 .69029 .26922 .70486 .2642 .69802 .25489 Mtetra
.656 .752 .92 r
.69802 .25489 .70486 .2642 .7195 .25918 .71271 .24981 Mtetra
.656 .751 .92 r
.71271 .24981 .7195 .25918 .73421 .2541 .72748 .24469 Mtetra
.72748 .24469 .73421 .2541 .749 .24903 .74232 .23956 Mtetra
.74232 .23956 .749 .24903 .76387 .2439 .75724 .2344 Mtetra
.75724 .2344 .76387 .2439 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Mtetra
.20696 .41401 .21539 .42188 .22768 .41763 .21929 .40972 Mtetra
.21929 .40972 .22768 .41763 .24003 .41341 .23168 .40541 Mtetra
.654 .75 .92 r
.23168 .40541 .24003 .41341 .25242 .40936 .24412 .40112 Mtetra
.65 .743 .918 r
.24412 .40112 .25242 .40936 .26483 .40589 .25661 .39695 Mtetra
.637 .722 .909 r
.25661 .39695 .26483 .40589 .2772 .40365 .26913 .39315 Mtetra
.611 .677 .888 r
.26913 .39315 .2772 .40365 .28954 .40292 .28166 .39013 Mtetra
.578 .617 .855 r
.28166 .39013 .28954 .40292 .30192 .4029 .29418 .38818 Mtetra
.554 .574 .828 r
.29418 .38818 .30192 .4029 .31447 .40167 .30672 .38706 Mtetra
.554 .576 .831 r
.30672 .38706 .31447 .40167 .32726 .39781 .31935 .38593 Mtetra
.583 .64 .872 r
.31935 .38593 .32726 .39781 .34026 .39157 .33213 .38372 Mtetra
.632 .756 .937 r
.33213 .38372 .34026 .39157 .35335 .38456 .34509 .37987 Mtetra
.664 .859 .974 r
.34509 .37987 .35335 .38456 .36645 .37803 .35818 .3747 Mtetra
.668 .9 .978 r
.35818 .3747 .36645 .37803 .37956 .37246 .37135 .36896 Mtetra
.663 .896 .98 r
.37135 .36896 .37956 .37246 .39269 .36752 .38458 .36336 Mtetra
.648 .874 .983 r
.38458 .36336 .39269 .36752 .40587 .36301 .39783 .35828 Mtetra
.626 .852 .985 r
.39783 .35828 .40587 .36301 .41911 .35859 .41113 .35382 Mtetra
.592 .841 .992 r
.41113 .35382 .41911 .35859 .4324 .35475 .42447 .35002 Mtetra
.568 .835 .996 r
.42447 .35002 .4324 .35475 .44575 .35147 .43788 .34662 Mtetra
.646 .858 .98 r
.43788 .34662 .44575 .35147 .45913 .35054 .45139 .34166 Mtetra
.759 .775 .866 r
.45139 .34166 .45913 .35054 .47261 .34909 .46505 .33262 Mtetra
.721 .639 .766 r
.46505 .33262 .47261 .34909 .48633 .33565 .47876 .32239 Mtetra
.695 .671 .823 r
.47876 .32239 .48633 .33565 .5 .32849 .49246 .31523 Mtetra
.65 .653 .84 r
.49246 .31523 .5 .32849 .5137 .32482 .50619 .31026 Mtetra
.636 .627 .824 r
.50619 .31026 .5137 .32482 .52748 .32023 .51998 .30569 Mtetra
.639 .629 .824 r
.51998 .30569 .52748 .32023 .54132 .31476 .53385 .30096 Mtetra
.647 .645 .834 r
.53385 .30096 .54132 .31476 .55522 .30845 .54779 .29596 Mtetra
.654 .672 .855 r
.54779 .29596 .55522 .30845 .56918 .30202 .5618 .29085 Mtetra
.657 .7 .878 r
.5618 .29085 .56918 .30202 .58319 .29583 .57587 .28575 Mtetra
.658 .726 .9 r
.57587 .28575 .58319 .29583 .59728 .29021 .59002 .28072 Mtetra
.657 .741 .912 r
.59002 .28072 .59728 .29021 .61145 .28496 .60424 .27574 Mtetra
.656 .749 .918 r
.60424 .27574 .61145 .28496 .62569 .27995 .61853 .27075 Mtetra
.656 .751 .92 r
.61853 .27075 .62569 .27995 .64001 .27496 .6329 .26575 Mtetra
.6329 .26575 .64001 .27496 .6544 .26999 .64734 .26072 Mtetra
.64734 .26072 .6544 .26999 .66887 .26497 .66186 .25567 Mtetra
.66186 .25567 .66887 .26497 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .24469 .72068 .23519 Mtetra
.72068 .23519 .72748 .24469 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .2248 Mtetra
.75056 .2248 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Mtetra
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Mtetra
.22325 .39739 .23168 .40541 .24412 .40112 .23573 .39302 Mtetra
.655 .75 .92 r
.23573 .39302 .24412 .40112 .25661 .39695 .24827 .38866 Mtetra
.653 .745 .918 r
.24827 .38866 .25661 .39695 .26913 .39315 .26086 .38433 Mtetra
.646 .731 .91 r
.26086 .38433 .26913 .39315 .28166 .39013 .2735 .38018 Mtetra
.633 .7 .894 r
.2735 .38018 .28166 .39013 .29418 .38818 .28618 .3764 Mtetra
.615 .655 .866 r
.28618 .3764 .29418 .38818 .30672 .38706 .29888 .37316 Mtetra
.596 .609 .835 r
.29888 .37316 .30672 .38706 .31935 .38593 .31162 .37049 Mtetra
.584 .581 .815 r
.31162 .37049 .31935 .38593 .33213 .38372 .32441 .3682 Mtetra
.584 .58 .815 r
.32441 .3682 .33213 .38372 .34509 .37987 .33727 .36592 Mtetra
.596 .611 .837 r
.33727 .36592 .34509 .37987 .35818 .3747 .35025 .3632 Mtetra
.617 .666 .875 r
.35025 .3632 .35818 .3747 .37135 .36896 .36333 .3598 Mtetra
.639 .729 .913 r
.36333 .3598 .37135 .36896 .38458 .36336 .37652 .35571 Mtetra
.654 .774 .937 r
.37652 .35571 .38458 .36336 .39783 .35828 .3898 .35109 Mtetra
.667 .792 .942 r
.3898 .35109 .39783 .35828 .41113 .35382 .40317 .34604 Mtetra
.685 .782 .925 r
.40317 .34604 .41113 .35382 .42447 .35002 .41661 .34042 Mtetra
.704 .743 .882 r
.41661 .34042 .42447 .35002 .43788 .34662 .43015 .33384 Mtetra
.707 .683 .825 r
.43015 .33384 .43788 .34662 .45139 .34166 .44376 .32617 Mtetra
.692 .639 .791 r
.44376 .32617 .45139 .34166 .46505 .33262 .45742 .31837 Mtetra
.684 .652 .812 r
.45742 .31837 .46505 .33262 .47876 .32239 .4711 .31146 Mtetra
.671 .706 .874 r
.4711 .31146 .47876 .32239 .49246 .31523 .48481 .30595 Mtetra
.66 .742 .91 r
.48481 .30595 .49246 .31523 .50619 .31026 .49859 .30096 Mtetra
.655 .74 .913 r
.49859 .30096 .50619 .31026 .51998 .30569 .51243 .29614 Mtetra
.654 .735 .909 r
.51243 .29614 .51998 .30569 .53385 .30096 .52634 .29133 Mtetra
.656 .735 .908 r
.52634 .29133 .53385 .30096 .54779 .29596 .54032 .28641 Mtetra
.656 .738 .91 r
.54032 .28641 .54779 .29596 .5618 .29085 .55437 .28146 Mtetra
.656 .743 .914 r
.55437 .28146 .5618 .29085 .57587 .28575 .5685 .2765 Mtetra
.656 .748 .918 r
.5685 .2765 .57587 .28575 .59002 .28072 .5827 .27152 Mtetra
.656 .75 .919 r
.5827 .27152 .59002 .28072 .60424 .27574 .59697 .26652 Mtetra
.656 .751 .92 r
.59697 .26652 .60424 .27574 .61853 .27075 .61131 .2615 Mtetra
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .2248 .7438 .2151 Mtetra
.7438 .2151 .75056 .2248 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Mtetra
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Mtetra
.22725 .3849 .23573 .39302 .24827 .38866 .23983 .38047 Mtetra
.23983 .38047 .24827 .38866 .26086 .38433 .25247 .37602 Mtetra
.655 .748 .919 r
.25247 .37602 .26086 .38433 .2735 .38018 .26517 .37158 Mtetra
.653 .741 .914 r
.26517 .37158 .2735 .38018 .28618 .3764 .27792 .36717 Mtetra
.648 .725 .905 r
.27792 .36717 .28618 .3764 .29888 .37316 .29073 .36287 Mtetra
.64 .699 .888 r
.29073 .36287 .29888 .37316 .31162 .37049 .30359 .35877 Mtetra
.631 .666 .865 r
.30359 .35877 .31162 .37049 .32441 .3682 .3165 .35487 Mtetra
.624 .634 .84 r
.3165 .35487 .32441 .3682 .33727 .36592 .32947 .35109 Mtetra
.619 .609 .819 r
.32947 .35109 .33727 .36592 .35025 .3632 .34251 .34733 Mtetra
.618 .595 .805 r
.34251 .34733 .35025 .3632 .36333 .3598 .35562 .34347 Mtetra
.622 .592 .798 r
.35562 .34347 .36333 .3598 .37652 .35571 .36882 .33934 Mtetra
.63 .596 .797 r
.36882 .33934 .37652 .35571 .3898 .35109 .3821 .33479 Mtetra
.64 .602 .795 r
.3821 .33479 .3898 .35109 .40317 .34604 .39548 .32973 Mtetra
.649 .607 .794 r
.39548 .32973 .40317 .34604 .41661 .34042 .40893 .3242 Mtetra
.654 .611 .794 r
.40893 .3242 .41661 .34042 .43015 .33384 .42245 .31838 Mtetra
.657 .623 .804 r
.42245 .31838 .43015 .33384 .44376 .32617 .43603 .31257 Mtetra
.661 .653 .831 r
.43603 .31257 .44376 .32617 .45742 .31837 .44966 .30698 Mtetra
.658 .693 .871 r
.44966 .30698 .45742 .31837 .4711 .31146 .46335 .30188 Mtetra
.661 .736 .905 r
.46335 .30188 .4711 .31146 .48481 .30595 .4771 .29683 Mtetra
.658 .747 .916 r
.4771 .29683 .48481 .30595 .49859 .30096 .49092 .2919 Mtetra
.654 .748 .919 r
.49092 .2919 .49859 .30096 .51243 .29614 .5048 .28708 Mtetra
.655 .75 .92 r
.5048 .28708 .51243 .29614 .52634 .29133 .51876 .2822 Mtetra
.656 .749 .919 r
.51876 .2822 .52634 .29133 .54032 .28641 .53279 .27725 Mtetra
.656 .75 .919 r
.53279 .27725 .54032 .28641 .55437 .28146 .54689 .27229 Mtetra
.656 .751 .92 r
.54689 .27229 .55437 .28146 .5685 .2765 .56106 .26729 Mtetra
.56106 .26729 .5685 .2765 .5827 .27152 .5753 .26227 Mtetra
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Mtetra
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Mtetra
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .38047 .23132 .37223 Mtetra
.23132 .37223 .23983 .38047 .25247 .37602 .24399 .36773 Mtetra
.24399 .36773 .25247 .37602 .26517 .37158 .25673 .36322 Mtetra
.655 .75 .92 r
.25673 .36322 .26517 .37158 .27792 .36717 .26953 .35869 Mtetra
.655 .748 .918 r
.26953 .35869 .27792 .36717 .29073 .36287 .28239 .35415 Mtetra
.655 .743 .914 r
.28239 .35415 .29073 .36287 .30359 .35877 .29531 .34959 Mtetra
.653 .732 .907 r
.29531 .34959 .30359 .35877 .3165 .35487 .30829 .34506 Mtetra
.649 .717 .897 r
.30829 .34506 .3165 .35487 .32947 .35109 .32134 .34059 Mtetra
.646 .701 .886 r
.32134 .34059 .32947 .35109 .34251 .34733 .33444 .33616 Mtetra
.645 .687 .875 r
.33444 .33616 .34251 .34733 .35562 .34347 .34762 .3317 Mtetra
.645 .676 .865 r
.34762 .3317 .35562 .34347 .36882 .33934 .36086 .32715 Mtetra
.647 .669 .858 r
.36086 .32715 .36882 .33934 .3821 .33479 .37417 .32249 Mtetra
.649 .669 .856 r
.37417 .32249 .3821 .33479 .39548 .32973 .38756 .3177 Mtetra
.652 .676 .86 r
.38756 .3177 .39548 .32973 .40893 .3242 .40102 .31281 Mtetra
.656 .692 .871 r
.40102 .31281 .40893 .3242 .42245 .31838 .41454 .30783 Mtetra
.659 .711 .886 r
.41454 .30783 .42245 .31838 .43603 .31257 .42813 .3028 Mtetra
.659 .73 .902 r
.42813 .3028 .43603 .31257 .44966 .30698 .44179 .29781 Mtetra
.662 .747 .913 r
.44179 .29781 .44966 .30698 .46335 .30188 .45552 .29274 Mtetra
.656 .747 .917 r
.45552 .29274 .46335 .30188 .4771 .29683 .46931 .28784 Mtetra
.653 .751 .922 r
.46931 .28784 .4771 .29683 .49092 .2919 .48317 .28302 Mtetra
.655 .756 .924 r
.48317 .28302 .49092 .2919 .5048 .28708 .4971 .27809 Mtetra
.657 .755 .922 r
.4971 .27809 .5048 .28708 .51876 .2822 .51111 .27308 Mtetra
.657 .752 .92 r
.51111 .27308 .51876 .2822 .53279 .27725 .52518 .26806 Mtetra
.656 .751 .92 r
.52518 .26806 .53279 .27725 .54689 .27229 .53933 .26304 Mtetra
.53933 .26304 .54689 .27229 .56106 .26729 .55355 .258 Mtetra
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19003 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Mtetra
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Mtetra
.24821 .35483 .25673 .36322 .26953 .35869 .26105 .35024 Mtetra
.26105 .35024 .26953 .35869 .28239 .35415 .27395 .34565 Mtetra
.655 .751 .92 r
.27395 .34565 .28239 .35415 .29531 .34959 .28691 .34105 Mtetra
.28691 .34105 .29531 .34959 .30829 .34506 .29994 .33641 Mtetra
.656 .749 .918 r
.29994 .33641 .30829 .34506 .32134 .34059 .31303 .33172 Mtetra
.657 .745 .915 r
.31303 .33172 .32134 .34059 .33444 .33616 .32619 .32699 Mtetra
.656 .738 .91 r
.32619 .32699 .33444 .33616 .34762 .3317 .33941 .32224 Mtetra
.655 .732 .906 r
.33941 .32224 .34762 .3317 .36086 .32715 .3527 .3175 Mtetra
.655 .728 .903 r
.3527 .3175 .36086 .32715 .37417 .32249 .36606 .31273 Mtetra
.655 .727 .902 r
.36606 .31273 .37417 .32249 .38756 .3177 .37948 .30793 Mtetra
.656 .728 .902 r
.37948 .30793 .38756 .3177 .40102 .31281 .39297 .30309 Mtetra
.655 .73 .904 r
.39297 .30309 .40102 .31281 .41454 .30783 .40653 .29825 Mtetra
.655 .734 .908 r
.40653 .29825 .41454 .30783 .42813 .3028 .42015 .29341 Mtetra
.655 .74 .912 r
.42015 .29341 .42813 .3028 .44179 .29781 .43385 .28854 Mtetra
.652 .743 .917 r
.43385 .28854 .44179 .29781 .45552 .29274 .44761 .28376 Mtetra
.655 .753 .922 r
.44761 .28376 .45552 .29274 .46931 .28784 .46144 .27886 Mtetra
.658 .755 .922 r
.46144 .27886 .46931 .28784 .48317 .28302 .47535 .27384 Mtetra
.658 .751 .919 r
.47535 .27384 .48317 .28302 .4971 .27809 .48933 .2688 Mtetra
.656 .749 .918 r
.48933 .2688 .4971 .27809 .51111 .27308 .50338 .26379 Mtetra
.655 .75 .919 r
.50338 .26379 .51111 .27308 .52518 .26806 .5175 .25878 Mtetra
.656 .751 .92 r
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Mtetra
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Mtetra
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19003 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Mtetra
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35024 .25249 .34174 Mtetra
.656 .752 .92 r
.25249 .34174 .26105 .35024 .27395 .34565 .26543 .33709 Mtetra
.656 .751 .92 r
.26543 .33709 .27395 .34565 .28691 .34105 .27843 .33241 Mtetra
.656 .75 .92 r
.27843 .33241 .28691 .34105 .29994 .33641 .2915 .32772 Mtetra
.655 .75 .92 r
.2915 .32772 .29994 .33641 .31303 .33172 .30463 .32303 Mtetra
.654 .751 .921 r
.30463 .32303 .31303 .33172 .32619 .32699 .31782 .31834 Mtetra
.655 .753 .922 r
.31782 .31834 .32619 .32699 .33941 .32224 .33108 .31361 Mtetra
.655 .755 .923 r
.33108 .31361 .33941 .32224 .3527 .3175 .34441 .30885 Mtetra
.656 .755 .923 r
.34441 .30885 .3527 .3175 .36606 .31273 .35781 .30404 Mtetra
.656 .756 .923 r
.35781 .30404 .36606 .31273 .37948 .30793 .37127 .29922 Mtetra
.655 .756 .924 r
.37127 .29922 .37948 .30793 .39297 .30309 .3848 .29438 Mtetra
.656 .757 .925 r
.3848 .29438 .39297 .30309 .40653 .29825 .3984 .2895 Mtetra
.656 .758 .925 r
.3984 .2895 .40653 .29825 .42015 .29341 .41207 .28458 Mtetra
.656 .757 .924 r
.41207 .28458 .42015 .29341 .43385 .28854 .42581 .27964 Mtetra
.659 .757 .922 r
.42581 .27964 .43385 .28854 .44761 .28376 .43963 .27458 Mtetra
.657 .751 .919 r
.43963 .27458 .44761 .28376 .46144 .27886 .45351 .26954 Mtetra
.655 .748 .918 r
.45351 .26954 .46144 .27886 .47535 .27384 .46746 .26455 Mtetra
.654 .749 .92 r
.46746 .26455 .47535 .27384 .48933 .2688 .48148 .25956 Mtetra
.655 .752 .921 r
.48148 .25956 .48933 .2688 .50338 .26379 .49558 .25452 Mtetra
.656 .753 .921 r
.49558 .25452 .50338 .26379 .5175 .25878 .50975 .24942 Mtetra
.656 .752 .92 r
.50975 .24942 .5175 .25878 .5317 .25372 .52399 .2443 Mtetra
.656 .751 .92 r
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Mtetra
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33314 Mtetra
.24386 .33314 .25249 .34174 .26543 .33709 .25683 .32846 Mtetra
.655 .751 .92 r
.25683 .32846 .26543 .33709 .27843 .33241 .26987 .32377 Mtetra
.656 .752 .921 r
.26987 .32377 .27843 .33241 .2915 .32772 .28297 .31904 Mtetra
.657 .753 .921 r
.28297 .31904 .2915 .32772 .30463 .32303 .29615 .31426 Mtetra
.657 .751 .92 r
.29615 .31426 .30463 .32303 .31782 .31834 .30939 .30944 Mtetra
.657 .749 .918 r
.30939 .30944 .31782 .31834 .33108 .31361 .32269 .30461 Mtetra
.656 .748 .917 r
.32269 .30461 .33108 .31361 .34441 .30885 .33606 .29977 Mtetra
.656 .747 .917 r
.33606 .29977 .34441 .30885 .35781 .30404 .3495 .29492 Mtetra
.3495 .29492 .35781 .30404 .37127 .29922 .363 .29003 Mtetra
.656 .746 .916 r
.363 .29003 .37127 .29922 .3848 .29438 .37658 .28512 Mtetra
.37658 .28512 .3848 .29438 .3984 .2895 .39022 .28019 Mtetra
.655 .745 .916 r
.39022 .28019 .3984 .2895 .41207 .28458 .40393 .27524 Mtetra
.656 .746 .916 r
.40393 .27524 .41207 .28458 .42581 .27964 .41772 .27027 Mtetra
.653 .745 .917 r
.41772 .27027 .42581 .27964 .43963 .27458 .43157 .26534 Mtetra
.654 .75 .921 r
.43157 .26534 .43963 .27458 .45351 .26954 .44549 .26037 Mtetra
.656 .754 .922 r
.44549 .26037 .45351 .26954 .46746 .26455 .45949 .25531 Mtetra
.657 .754 .921 r
.45949 .25531 .46746 .26455 .48148 .25956 .47356 .2502 Mtetra
.656 .752 .92 r
.47356 .2502 .48148 .25956 .49558 .25452 .48771 .24507 Mtetra
.656 .75 .92 r
.48771 .24507 .49558 .25452 .50975 .24942 .50192 .23995 Mtetra
.656 .751 .92 r
.50192 .23995 .50975 .24942 .52399 .2443 .51622 .2348 Mtetra
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32919 Mtetra
.22219 .32919 .23095 .33781 .24386 .33314 .23514 .32448 Mtetra
.656 .752 .92 r
.23514 .32448 .24386 .33314 .25683 .32846 .24816 .31975 Mtetra
.24816 .31975 .25683 .32846 .26987 .32377 .26123 .31499 Mtetra
.656 .751 .92 r
.26123 .31499 .26987 .32377 .28297 .31904 .27438 .31021 Mtetra
.655 .75 .92 r
.27438 .31021 .28297 .31904 .29615 .31426 .28759 .30543 Mtetra
.655 .751 .921 r
.28759 .30543 .29615 .31426 .30939 .30944 .30086 .30064 Mtetra
.655 .753 .922 r
.30086 .30064 .30939 .30944 .32269 .30461 .3142 .29581 Mtetra
.656 .755 .923 r
.3142 .29581 .32269 .30461 .33606 .29977 .32761 .29095 Mtetra
.32761 .29095 .33606 .29977 .3495 .29492 .34109 .28605 Mtetra
.34109 .28605 .3495 .29492 .363 .29003 .35464 .28113 Mtetra
.656 .756 .923 r
.35464 .28113 .363 .29003 .37658 .28512 .36826 .27619 Mtetra
.656 .756 .924 r
.36826 .27619 .37658 .28512 .39022 .28019 .38195 .27122 Mtetra
.38195 .27122 .39022 .28019 .40393 .27524 .3957 .26622 Mtetra
.3957 .26622 .40393 .27524 .41772 .27027 .40953 .2612 Mtetra
.658 .757 .923 r
.40953 .2612 .41772 .27027 .43157 .26534 .42343 .25608 Mtetra
.657 .753 .921 r
.42343 .25608 .43157 .26534 .44549 .26037 .43741 .25096 Mtetra
.656 .75 .919 r
.43741 .25096 .44549 .26037 .45949 .25531 .45145 .24585 Mtetra
.655 .75 .919 r
.45145 .24585 .45949 .25531 .47356 .2502 .46557 .24074 Mtetra
.655 .751 .92 r
.46557 .24074 .47356 .2502 .48771 .24507 .47976 .2356 Mtetra
.656 .752 .921 r
.47976 .2356 .48771 .24507 .50192 .23995 .49402 .23041 Mtetra
.656 .752 .92 r
.49402 .23041 .50192 .23995 .51622 .2348 .50836 .2252 Mtetra
.656 .751 .92 r
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33459 Mtetra
.17479 .33459 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32919 .21336 .32048 Mtetra
.21336 .32048 .22219 .32919 .23514 .32448 .22635 .31573 Mtetra
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Mtetra
.655 .751 .92 r
.2394 .31096 .24816 .31975 .26123 .31499 .25251 .30617 Mtetra
.656 .752 .921 r
.25251 .30617 .26123 .31499 .27438 .31021 .2657 .30136 Mtetra
.2657 .30136 .27438 .31021 .28759 .30543 .27895 .2965 Mtetra
.657 .752 .92 r
.27895 .2965 .28759 .30543 .30086 .30064 .29227 .29159 Mtetra
.657 .75 .919 r
.29227 .29159 .30086 .30064 .3142 .29581 .30565 .28667 Mtetra
.656 .748 .918 r
.30565 .28667 .3142 .29581 .32761 .29095 .3191 .28175 Mtetra
.3191 .28175 .32761 .29095 .34109 .28605 .33263 .2768 Mtetra
.33263 .2768 .34109 .28605 .35464 .28113 .34622 .27183 Mtetra
.34622 .27183 .35464 .28113 .36826 .27619 .35988 .26683 Mtetra
.656 .747 .917 r
.35988 .26683 .36826 .27619 .38195 .27122 .37361 .2618 Mtetra
.37361 .2618 .38195 .27122 .3957 .26622 .38741 .25676 Mtetra
.38741 .25676 .3957 .26622 .40953 .2612 .40128 .25168 Mtetra
.654 .747 .918 r
.40128 .25168 .40953 .2612 .42343 .25608 .41522 .24664 Mtetra
.654 .75 .92 r
.41522 .24664 .42343 .25608 .43741 .25096 .42924 .24155 Mtetra
.656 .752 .921 r
.42924 .24155 .43741 .25096 .45145 .24585 .44333 .23641 Mtetra
.656 .753 .921 r
.44333 .23641 .45145 .24585 .46557 .24074 .45749 .23121 Mtetra
.656 .752 .92 r
.45749 .23121 .46557 .24074 .47976 .2356 .47173 .22599 Mtetra
.656 .751 .92 r
.47173 .22599 .47976 .2356 .49402 .23041 .48604 .22076 Mtetra
.48604 .22076 .49402 .23041 .50836 .2252 .50043 .2155 Mtetra
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Mtetra
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33459 .16576 .32593 Mtetra
.16576 .32593 .17479 .33459 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Mtetra
.656 .752 .92 r
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Mtetra
.23056 .30209 .2394 .31096 .25251 .30617 .24372 .29723 Mtetra
.656 .751 .92 r
.24372 .29723 .25251 .30617 .2657 .30136 .25694 .29236 Mtetra
.655 .75 .92 r
.25694 .29236 .2657 .30136 .27895 .2965 .27023 .28749 Mtetra
.655 .751 .921 r
.27023 .28749 .27895 .2965 .29227 .29159 .28358 .28261 Mtetra
.655 .753 .922 r
.28358 .28261 .29227 .29159 .30565 .28667 .297 .27769 Mtetra
.656 .754 .922 r
.297 .27769 .30565 .28667 .3191 .28175 .3105 .27273 Mtetra
.656 .755 .923 r
.3105 .27273 .3191 .28175 .33263 .2768 .32406 .26774 Mtetra
.32406 .26774 .33263 .2768 .34622 .27183 .3377 .26272 Mtetra
.3377 .26272 .34622 .27183 .35988 .26683 .3514 .25768 Mtetra
.3514 .25768 .35988 .26683 .37361 .2618 .36517 .25262 Mtetra
.36517 .25262 .37361 .2618 .38741 .25676 .37902 .24752 Mtetra
.37902 .24752 .38741 .25676 .40128 .25168 .39294 .2424 Mtetra
.657 .756 .923 r
.39294 .2424 .40128 .25168 .41522 .24664 .40693 .23721 Mtetra
.657 .753 .921 r
.40693 .23721 .41522 .24664 .42924 .24155 .42099 .232 Mtetra
.656 .751 .92 r
.42099 .232 .42924 .24155 .44333 .23641 .43513 .22679 Mtetra
.656 .75 .92 r
.43513 .22679 .44333 .23641 .45749 .23121 .44934 .22157 Mtetra
.655 .751 .92 r
.44934 .22157 .45749 .23121 .47173 .22599 .46363 .21632 Mtetra
.656 .752 .92 r
.46363 .21632 .47173 .22599 .48604 .22076 .47799 .21103 Mtetra
.47799 .21103 .48604 .22076 .50043 .2155 .49243 .20572 Mtetra
.656 .751 .92 r
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Mtetra
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17872 Mtetra
.56578 .17872 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .34989 Mtetra
.06836 .34989 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Mtetra
.655 .751 .92 r
.22164 .29313 .23056 .30209 .24372 .29723 .23483 .28825 Mtetra
.656 .752 .921 r
.23483 .28825 .24372 .29723 .25694 .29236 .24809 .28335 Mtetra
.24809 .28335 .25694 .29236 .27023 .28749 .26142 .27839 Mtetra
.657 .752 .92 r
.26142 .27839 .27023 .28749 .28358 .28261 .27482 .2734 Mtetra
.657 .75 .919 r
.27482 .2734 .28358 .28261 .297 .27769 .28829 .26839 Mtetra
.656 .749 .918 r
.28829 .26839 .297 .27769 .3105 .27273 .30183 .26337 Mtetra
.656 .748 .918 r
.30183 .26337 .3105 .27273 .32406 .26774 .31543 .25833 Mtetra
.31543 .25833 .32406 .26774 .3377 .26272 .32911 .25327 Mtetra
.32911 .25327 .3377 .26272 .3514 .25768 .34286 .24817 Mtetra
.34286 .24817 .3514 .25768 .36517 .25262 .35667 .24305 Mtetra
.35667 .24305 .36517 .25262 .37902 .24752 .37056 .2379 Mtetra
.37056 .2379 .37902 .24752 .39294 .2424 .38453 .23273 Mtetra
.654 .747 .918 r
.38453 .23273 .39294 .2424 .40693 .23721 .39856 .22758 Mtetra
.654 .749 .92 r
.39856 .22758 .40693 .23721 .42099 .232 .41267 .2224 Mtetra
.656 .752 .921 r
.41267 .2224 .42099 .232 .43513 .22679 .42685 .21716 Mtetra
.656 .753 .921 r
.42685 .21716 .43513 .22679 .44934 .22157 .44111 .21186 Mtetra
.656 .752 .92 r
.44111 .21186 .44934 .22157 .46363 .21632 .45544 .20653 Mtetra
.656 .751 .92 r
.45544 .20653 .46363 .21632 .47799 .21103 .46985 .2012 Mtetra
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17872 .55795 .16857 Mtetra
.55795 .16857 .56578 .17872 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03ooom80:O0j`030000002W`>/0Yl3[00d0Yl3[4@3oool2000002h0oooo000e0?ooo`<00000
C@3ooom:0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0ooooC@2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<000000?ooo`3oool0:`3o
ool00300oooo0`00001;0?ooo`D0Yko[1@2W`>/40:Nojd<0Yl3[00<000000:O0j`2W`>/0402W`>/A
0?ooo`030000003oool0oooo02X0oooo000^0?ooo`<00000B`3oool80:Noj`D0Yl3[102W_n]20:O0
j`030000002W`>/0Yl3[0100Yl3[4@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0
oooo00<000000?ooo`3oool0AP3oool80:Noj`<0Z<3[1@2W`>/20:Nojd<0Yl3[00<000000:O0j`2W
`>/04@2W`>/A0?ooo`030000003oool0oooo02T0oooo000Y0?ooo`800000B`3oool:0:Noj`H0Z<3[
B@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?ooo`T0Yko[1@2X`N`50:S0jdT0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003o
ool0oooo02P0oooo000T0?ooo`800000B`3oool:0:Noj`80Yl7/1@2X`N`50:Noj`D0Yl3[1@2W_n/5
0:O0j`@0Yko[=02W`>/2000001D0Yl3[403oool2000002T0oooo000Q0?ooo`<00000B`3oool:0:No
j`D0Yl7/0P2X`N`80:Noj`80Yl3[202W_n/50:O0j`@0Yko[<02W`>/300000080Yl3[00<000000:O0
j`2W`>/04P2W`>/B0?ooo`030000003oool0oooo02H0oooo000O0?ooo`<00000B@3oool:0:Noj`T0
Yl7/4P2W_n/30:S1j`D0Yl3[0P2W_n/^0:O0j`<000001@2W`>/00`000000Yl3[0:O0j`0C0:O0ja40
oooo00<000000?ooo`3oool09P3oool001d0oooo0P00001;0?ooo`L0Yko[2P2W`N`50:NojP@0Yko[
1@2X`>/50:Noj`H0Z<7[<@2W`>/3000000T0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000
003oool0oooo00`0oooo0P0000040?ooo`8000000`3oool4000000X0oooo000E0?ooo`D000000`3o
ool2000004T0oooo1`2W_n/80:O1k0X0YkoZ1@2X`N`40:S0j`D0Yl7/1@2X`N/^0:O0j`<000003@2W
`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`00
00140?ooo`T0Yko[202W`N`:0:NojP<0Yl7/1@2X`N`40:Noj`D0Yl7/1@2W_n/50:O0j`D0Yko[8@2W
`>/200000140Yl3[00<000000:O0j`2W`>/04`2W`>/@0?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0:0?ooo`005`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000003l0oooo2P2W_n/90:O1k0X0YkoZ1P2W`N`20:S1k0<0YkkZ
102W_n/20:O1k180Yko[7@2W`>/3000001<0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000
003oool0oooo00<0oooo100000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool02@3oool000l0oooo100000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0k0?ooo`80Z;o[1@2W_n/:0:O1k0D0Yko[102W_nX:0:O1k0H0YkkZ
2`2W_n/30:S0j`D0Yko[1@2X`>/>0:O0j`D0Yko[1P2W`>/3000001L0Yl3[00<000000:O0j`2W`>/0
4`2W`>/A0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000:0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`0h0?ooo`D0Z;o[0`2W_n/70:O1k0X0Yko[2@2W`N`:0:NnjPD0Z<3[102W_n/60:S0j`80
Yko[0`2X`N`50:S0j`80Yl3[0P2W_n/50:O0j``0Yko[0`00000K0:O0j`030000002W`>/0Yl3[0180
Yl3[403oool2000000/0oooo0P00000:0?ooo`8000002`3oool001H0oooo0P0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool50:S0j`D0Z;o[1`2W`N`:0:Noj`P0Yl7/
2@2W_^X50:S1k0D0Z<3[102X`N`50:S0j`H0Z<7/102X`>/50:Noj`80Yl3[0`2W_^T70:Noj`040:Rm
j@0000000000000000<0Yko[1@2X_nX50:O0j`D0Z<3[3@2W`>/00`000000Yl3[0:O0j`0B0:O0ja40
oooo00<000000?ooo`3oool08@3oool001`0oooo00<000000?ooo`3oool01@3oool200000300oooo
102W`>/50:S0j`D0Yl3/102W`N`:0:Noj`P0Yl7/2@2W_^X30:O1k0D0Z<7/1@2W`>`40:S1k0D0Yl7/
1@2X`N`90:Noj`H0YkkY102W_n/3000000<0Z;gY0P2W_n/20:Rlj0D0Z;oZ1@2W_n/50:S0j``0Yl3[
00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`800000203o
ool00`000000oooo0?ooo`0[0?ooo``0Yl3[1@2W`>`90:Noj`X0Yl7/2@2W_^X60:O1k080Z<7/0`2V
_^X90:O0k0D0Yl7/2P2W_n/40:Nlj0D0YkkY00D0Z;WV00000000000000000:RiiP050:Rmj@D0Z;cX
0P2X_nX30:Vmj0D0Yko[0P2X`>/30:Noj``0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000
003oool0oooo0200oooo000L0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:03o
ool80:O0j`80Yko[1@2W`>/50:Roj`D0Yko[2@2W`N`:0:NnjPD0Yl;/102W`N`60:JnjP80Yl3/0`2W
_nX40:O0k0X0Yko[2@2W_>P20:Rch0<000001@2X^NH50:VfhP@0Z;cX1P2Y_NP:0:Noj``0Yl3[00<0
00000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01l0oooo000K0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08`3oool:0:O0j`D0Yko[0`2W`>/20:S0j`D0Z;o[0P2W_n/8
0:O1k0@0YkoZ1@2W_^X50:O1k0D0Yl;/102W_NT50:JnjPH0YkoZ0P2W`>`20:RojPL0Yko[2P2W_>P3
000000@0Z;?P0P2X^NH30:Z/f@D0ZKKR102Z]^450:Vmj0D0Z;kY1@2W_n/=0:O0j`030000002W`>/0
Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<000000?oo
o`3oool07`3oool>0:O0j`D0Yko[1@2X`>/40:Roj`P0Yl7/1`2W_nX:0:O1k0D0Yk_X102W_NT50:Vo
j@D0YkoZ1@2X_nX40:Noj`X0YkcX0P0000030:N/fP@0Z;?P1P2Z[=T20:VfhP<0[ZcF102Z]^450:^i
i0D0Z;kY1@2X_n/<0:O0j`030000002W`>/0Yl3[01<0Yl3[403oool00`000000oooo0?ooo`0N0?oo
o`006`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo602W`>/50:S0j`@0
Yl3/1@2W`N`80:NojPL0Yl7/1@2W^^L50:Nkj0@0Z;[V1@2Y_nT50:Vli`@0Z;oZ1@2W_NT50:Nlj005
0:FUe@00000000000000002UYMD0102W[=X50:ZRc`D0ZZcI1@2^[=H20:Zfh@<0/;3H1@2[^N@50:Zm
i`@0Z;o[3@2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool07@3oool001/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?oooal0Yl3[102W`>`:0:NojPP0
Yl7/0P2W^^H50:Nji`80Yk_X0`2X]^840:RjiP80ZKoY0`2X/Mh50:Vli`D0Z;gX102W_NT20:>QdP<0
00001@2UYMD20:N/fP80ZIg91@2ZX/l20:Z/f@<0[j?;102^[=H60;2`f080ZkWT0`2`]mh40:Zmi`D0
Z;oZ3@2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000O0?ooo`006`3oool2000000l0oooo
00<000000?ooo`3oool05@3ooolI0:O0j`@0Yko[1@2W`>/50:Roj`@0YkoZ2P2W`N`50:NjiP@0Yk[W
1P2X]^830:RjiPH0Z;7N0P2Y_>L30:^dg`D0Z;gX0P2RX=83000000<0Xj7B1@2UYMD40:VMb@D0ZZ;?
1P2_Xl/20:j/eP80]JS<1@2`/=P60;2ggP80Z[gW0P2]_ND50:RojPD0Z<3[1`2W`>/00`000000Yl3[
0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0A0?oooad0Yl3[102W_n/50:S0j`D0Z;o[2@2W`N`90:NjiPD0Yk7N1@2X
]^840:VWe0D0Z;7N1P2[]=l20:Rmj0040:JWe`000000000000000080XZ3B1@2SXM820:FUe@<0Z9[7
102YWLT20:ZRc`<0/jC81@2_Xl/50;FXc080/;3H0`2h[/l50;2ggPD0[KgU0P2X_nX30:Zoj@D0Z<3[
1`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P00
00040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0<0?ooob80Yl3[0P2W_n/70:S0j`80Z;o[0`2W`>`40:O1k0D0Yk[W1@2W^^H40:J]g0D0Yk7N0P2X
]^830:ROc@@0ZJOD0P2X/Mh30:nVc`D0ZkCO0`0000020:JWe`@0XZ3B102SXM850:RJa`@0ZIg91@2c
Y<P40:nSb`80^ZW8102eZ<`60;R^c`80/;ON0`2g]mP40:fmi@H0Z[oY1@2X`>/70:O0j`030000002W
`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0K0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo0P00000C0?ooo`030000003oool0oooo00X0oooo
8`2W`>/90:S0j`H0Yl3/0P2W`N`20:Nki`D0Yk[W0P2W^^H30:J[f`@0YZgL102W/Mh50:ROc@@0ZJOD
1P2_Y/l01@2[]=l00000000000000000/J_B00D0YZOG0`2RX=850:BHb0D0Z9[70P2YWLT20;>Zc`D0
/jC80P2_Xl/30;ZYb0<0]JS<0P2nZlL50;R^c`H0]kOH102a_^<50:Zoj@D0Z<3[202W`>/00`000000
Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool06P3oool000L0oooo00@000000?ooo`3oool0
00002`3oool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool01`3ooolV0:O0
j`D0Z<3[102W`>/50:O0k0D0Yk_W102W^^L50:J[f`D0YZgL102WW</50:ROc@80ZJOD0P2aXlX30:nV
c`<000001@2aZm840:JWe`@0Wi75102TV<P50:RJa`@0/j[?1@2cY<P60;ZYb0040;FXc02nZlL0_Z_7
0;j[a`@0^:k?0P31/<T40;Ngf080_kWD102a_^<50:_0j@@0Z<3[202W`>/00`000000Yl3[0:O0j`0B
0:O0ja40oooo00<000000?ooo`3oool06@3oool000030?ooo`0000000000008000000P3oool01000
0000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0080oooo:`2W`>/50:Noj`@0Yl3[1@2W_>P50:Nki`@0YJ_K1@2VZm/20:J]g0<0YY_;0`2WW</5
0:ROc@@0/J?:0`0000000`2_Y/l0^:?40;RSa0050;6[dPD0VX_20`2OTLD50:BHb080Z9[70`2e_=h4
0;>Zc`80/jC80`2k]M<50;ZYb0D0_Z_70P2h[/l40<6`b@80]kOH0`2o^M@20;6nh`<0]/3R1@2[`>T4
0:S0j`P0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01T0oooo00070?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool2000001H0oooo00<00000
0:O0j`2W`>/0:@2W`>/90:Noj`D0Z;kZ102W_>P50:F]g@@0YJ_K102VZm/50:JKb`@0Yic;0P2XWld3
0;B^d`030;6SbP00000000000080/J?:1@2hXl@20;6[dP<0/:K>102JRl8409nAa@@0Y9S81@2e_=h4
0;>Zc`D0^kGC102jZLP20;nccP@0_Z_71P31/<T50;nie0H0]/3R0P2[`>T30:c1j@@0Z<3[202W`>/0
0`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000J0?ooo`00203oool2000000X0oooo0`0000030?oo
o`030000003oool0oooo0180oooo<02W`>/90:Noj`D0Z;kZ102U[ml50:F]g@<0YJ_K1@2SV//50:JK
b`<0Yic;0`2d[]<3000000<0/J?:0P32a]d40;RSa0D0/:K>1@2JRl8309nAa@80Y9S80`2]bnl50;Fl
gP80/j[?0P2abnd50;^ed`80^ZW80`2o/lh30;j[a`80a;361031/<T20<Rca@<0_kWD0P37_=050;K0
hPD0[<7Y1@2X`>/80:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0G0?oo
o`006@3oool00`000000oooo0?ooo`0B0?oooc80Yl3[0P2W_n/20:O0j`D0Yko[0P2X_^X30:FchP@0
YJoO102U[Md40:6Hc0@0Xi[;1@2VVl/30;Bnh@<000000`2d[]<20;6SbP<0`/KM102hXl@00`2mWkX0
/:K>0;2VcP020;2VcPD0VX_20`2OTLD60:g;k`@0]KcN102abnd50;^ed`H0_k?>00@0_Z_70<B`aP34
/<H0a;360`31/<T40<Rca@030;nie037_=00akc@0080akc@0P2f`>830;[3h@<0[<7Y0P2/`^T50:S0
j`L0Yl3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01L0oooo000I0?ooo`80
00004@3oooli0:O0j`@0Yko[1P2U/n830:F_g`D0WiO<0`2QV<`50:>Jb`80YY_;0P2_b>`300000080
];kQ102d[]<60<;6g@80^:?40P2mWkX50;2VcP@0VX_2102]g_P50:g;k`D0SMKo102abnd20;^ed`<0
[lGZ1@2o/lh50<B`aP030<6`b@38/lD0b;?500<0b;?51@37_=060;[3h@D0[<;Y1@2X`>/70:O0j`03
0000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0F0?ooo`006@3oool00`000000oooo
0?ooo`0=0?ooocd0Yl3[102V]nD50:FchP@0WYS>102OUl`40:6Hc0@0Xi[;00@0[lS/000000000000
00000P2_b>`30;Bnh@D0YM_j1@32a]d00`2hXl@0_Inj0;fO^P020;fO^P@0/:K>0P2JRl830:SFn0@0
[Mkh1P1ae_/308gFo`@0/L_]1@2_aNX40;nccP80^[[I1034/<H50<Rca@80ckK10`37_=020<k1cP<0
^/?Q0`2ma^840:c2j@H0Z<3[1`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3o
ool05@3oool001T0oooo00<000000?ooo`3oool02@3ooolm0:O0j`D0Yk_X102V]nD509jKd@<0WYS>
1@2OUl`30:6Hc080Z/[a0`0000050:o8k0D0TMGn102UfoX40<;6g@D0_Inj102`Y/h50:SFn080O=cl
1@21f_h406[3oP<0H;cm101la_h50:o5jP80_k?>0`2j^]T30<B`aP80a[;60`38/lD30<nf`@80akc@
103>`Lh50;g6hPD0[<;Z1@2X`>/80:O0j`030000002W`>/0Yl3[0140Yl3[403oool00`000000oooo
0?ooo`0E0?ooo`006@3oool2000000L0oooo?@2W`>/40:Nnj@D0Yk_X102OX]L409jKd@@0WYS>102O
Ul`20:6Hc0<00000102Zb_4609OGo@@0V/?d1@1W`oh303fohP@0_Inj00<07Do808Nhm@27^?D00`27
^?D40:kRn@<0YOKZ1021f_h406[3oP<0H;cm101la_h40:o5jPD0^[[I0P34/<H40<JbaP030<Rca@3?
]/40ckK10080ckK11@3>`Lh20=C7c@<0_LKR0P2nb>850:c2jPD0Z<3[1`2W`>/00`000000Yl3[0:O0
j`0B0:O0ja00oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00`3oooll
0:O0j`D0Yko[102W_^T50:6Zg@<0Wj;G1@2NVm4309jHcP<0WiO<0`0000040:O6k`D0X=[l1@2PaO<4
09[3m0D0YL;^0P0m_n830;fO^P80d]CJ00<07Do809k:m`2Nb_L0102Nb_L20:GfjP@0Ylcc102=/>h5
086_lP<0Ik?k0`17ZoP408:nnP@0^[[I1P36//H50<nf`@040=Fi_P3>`Lh0c/7>0<k1cP@0e<O=1@2n
b>850:c2jP@0Z<3[202W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool04`3o
ool001P0oooo00<000000?ooo`3oool00`3oooll0:O0j`L0Yko[102S/^<40:6Zg@@0Wj;G102NVm43
09jHcP<000000P2S^^T30:O6k`<0YMok0`2Pf_`20:K5l0D0X<Gc102bfO@50:G2kP80?KoR0P2mWkX2
0=;DfP807Do80`2Nb_L209W`lP<0^>?e102Wc?<408f`kPD0U<Kh101_`_h202JHkP@0P[kj102Y]n<6
0<JbaP<0ckK10`3E^Kh00`3>`Lh0e<O=0=C7c@020=C7c@80fLc<0P2nb>830;k9h`@0[<;Z1@2X`>/8
0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool2000001D0oooo000H0?ooo`040000003oool00000
0?oooc`0Yl3[1`2W_n/30:Fii`<0Xk;S1@2QZ]d309nRe`@0WY_A00@0WJ[O000000000000WJ[O1@2S
^^T60:GOn`D0Y/G`1@2NboL40;;Im0D0YLSb00<0?KoR0;fO^P2NaoD00`2NaoD205NRm@80VO3b1P2h
hoD30:O<l`D0U:kY102Da_P507Joo@<04hGV0`0oW?@30:Vgh`H0a[;60`3?]/430=Fi_P@0e<O=0`3I
c<`60;k9h`@0[<;Z1@2X`>/70:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?oo
o`060?ooo`8000002P3oool001P0oooo00<000000:O0j`2W`>/0?P2W`>/40:Noj`H0YKWW0`2S/^<4
0:6Zg@@0UIC@00@0V9cF0000000000000000102MZ]l60:WUnPD0YlK`0`2VaO020:O>m0D0W/_g102M
_o030:G8lP<0Yloe1@2NaoD50:OGn0D0Y[7P0`2FXmh509B^j@D0XMKj101f_od301>5iP03001^g00o
W?@0?icd00<0ZKOS1P36//H00`3?]/40eKVn0=Fi_P020=Fi_P030=^n^`3Dald0e<O=00@0fLc<00<0
g=3=0;k9h`2nbN<00`2nbN<50:c2jPD0Z<3[1`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`004@3oool2000000D0oooo00<0
00000?ooo`2W`>/0?`2W`>/50:Nmj@@0YKWW0`2S/^<609FDd0<00000102HW=H209fZg`@0ZnKj102[
b>l50:O6l0D0Ylkd1@2Za>`409fol0H0Yloe1@2J_?030:OGn080//?W1@2V/N0309JSgPH0Z]ci102Q
b?@507W1o@8007?I0P00K]`30:Vgh`H0a[;6103E^Kh30=^n^`@0fLc<0`3Ld<d20;k9h`<0_LWT0P2/
`^X30:_2jPD0Z<3[1`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo03`0Yl3[102W_n/50:Nmj@@0WJOM0`2HVmD209FDd0<000000`2EU=0409RLeP@0ZnKj
0`2`d?440:_8k`H0YLcd102W`nd50:[4k0H0YL[c102T^^T509Zll0D0//?W102V/N050:;?m`D0ZLS_
102Qb?@507[8o`04001Ea@00LmT006kL001^g0<0SZWX1036//H20<J`a@<0eKVn0`3K_[/0103Sa;P0
fLc<0=W<c03Ic<`30=c@c@D0_LWT1P2[`^X50:S0j`L0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002@3oool00100oooo00@000000?oo
o`3oool00000103oool200000080oooo?02W`>/40:Noj`D0X[?T0`2MYmd209RKe@<000001P2EU=06
0:WKn@H0/=3a1@2Yco@50:S3k@@0Yl?]1@2Yc?830:G:l`<0Z[kX102T^^T50;;?k`@0//?W1@2L_>l3
0:;?m`80[]3a1@2Yb>l50:[Fm`@0N/So0P00ELD00`00K]`0SZWX08jYj00208jYj080a[;61036/<D0
103E^Kh0fkjk0=^n^`3K_[/30>?4^0030=W<c03Ld<d0g=3=0080g=3=00@0g=7>0;g9i02mbN@0_LWT
0P2lbN@50:_2jPD0Z<3[1`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo?02W`>/40:Fkj0D0X[?T00@0WJOM00000000000000000`2HVmD309FD
d0H0XL7_1@2gfo850:S>m0<0ZLod0P2W`nd50:S3k@@0Yl_b1@2Yc?850:Znj080Y;[Y0`2Zc_850;;?
k`@0XKKX1@2L_>l50:k@l@D0[=3c1P2_f_H306o4o`8005G5102>ZNP60<J`a@@0fkjk0`3Sa;P40=c@
c@<0g=7>1@2lbN@50:_2jP@0Z<3[202W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P0000040?oo
o`8000002P3oool00100oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?oo
ocL0Yl3[102W_^/40:Fkj080X[?T0`00000209fWg@@0V9_E102EXml30:71k`<0^n?c0`2gfo820:g@
lPD0Z<kd1@2W`nd20:S3k@L0Yl_b1@2Z`NX40:Znj0H0Z/kb1@2U]nD40:6fj0D0[MOf0P2^d?430:S6
k`<0[=3c0P2ceO830:oJmP<0/>7h0P1H[_X00`00<:d005G5000GW`04076Di@@0a[350P38/<820=^n
^`@0hlBh00<0jLZf0=c@c@3Ld<d00`3LdLh20=_Ac`80_<WT0`2jb>D40:_2jPD0Z<3[202W`>/00`00
0000Yl3[0:O0j`0A0:O0j`h0oooo0`00000@0?ooo`004@3oool2000000@0oooo0P0000070?oooc@0
Yl3[0`2W_n/40:Nnj`80YK_X0`00000309>MfP<0SI;C102=Tm@409FSg`H0^n?c1@2]d?850:[6kP@0
Yl?]1P2Wbo840:S1j`D0Z/7Z1@2Wbo<50:Vli`@0YKOU0P2Q]^P30:KFn0@0[MOf1P2Xa^l50;?ElPH0
/>7h0P1H[_X00`00<:d001NO000GW`03076Di@<0a[351038/<80103K_[/0hlBh0>?4^03Sa;P30>W:
]P<0g=7>0`3KdLl60;[8i@@0Zl7Z1@2X`>/80:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool00`00
0000oooo0?ooo`0>0?ooo`005`3oool00`000000oooo0?ooo`070?oooc40Yl3[1P2W_n/20:Nnj`<0
00000P2L[N<409>MfP<0SI;C1@2=Tm@209FSg`<0]]Wb1P2de?450:c;l0@0Z/K^1@2Vb_850:O1k0@0
Z<7[1@2Vb_830:O;l`80ZKoY1@2Y_>L30:Fgi@H0Y]Kh102W`N`30:S6k`<0/=?b0`2ceO830;SPm0D0
Y]3f0P0nO^D00`00<:d001NO076Di@03076Di@030<J`a@38/<80b;3200<0b;320`3Sa;P40>W:]P03
0>g>]@3LdLh0fm7?00<0fm7?00@0f]7@0;[8i@2jb>D0^/SU0`2ib>D40:_1jPD0Z<3[1`2W`>/00`00
0000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?ooo`3o
ool0203ooola0:O0j`@0Yko[0`0000020:>hj0@0W:gS102CWMX308fBd`@0SI?D102ffO830;kMk`<0
]=Ca0P2ad_450:c;l0D0Y/Wb1@2W`nd40:O1k0@0Y/[c1@2Vb_850:Voj@@0ZKcW1@2Td_P50:W0jP@0
Yl7/1P2`do830;SPm0@0^^Gd0`2Vd?H303ini@03000`[@005il0GWoK0080GWoK1P38/<800`3?];l0
hlBh0>?4^0030>W:]P80kLje103KdLl30=[Ad0D0^LSU1@2Z`NX40:S0j`P0Yl3[00<000000:O0j`2W
`>/04@2W`>/@0?ooo`030000003oool0oooo00`0oooo000G0?ooo`8000002@3ooolb0:O0j`030:Jn
j`00000000000080Y[k[102S^>P409b]h`<0TigJ0`2=T]<60:>jjPH0_]g_1@2ad_450:O8l@<0Y/Wb
0P2XaNh50:O3k@P0Y/[c1@2X`>/40:Voj@H0Xlkf102Y`N/50:W0jPD0[=;d1@2ae_<40;[Um0<0T^_f
0`23[o401@0WF<d0?WkU0003UP00090001NO00<0GWoK1038/<820<nd_`040>?4^03Yb[H0jLZf0>W:
]P<0kLje00<0k]2e0=_Ac`3KdLl0103JdM00103HdM80^LSU0;W8i@2ib>D20;S7iPD0Z/7Z102X`>/8
0:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`0<0?ooo`005`3oool00`00
0000oooo0?ooo`0:0?ooobd0Yl3[00D0Yko[00000000000000000:Noj`040:Jnj`@0UZWT102:V=/3
08F?eP<0SY[K0`2S^^X40;oJk@H0^=O`102[b_050:O8l@D0Z<G^0P2W`nd30:G:l`@0Y/[c102W`N`5
0:S0j`D0Y<_d1@2Y`^`40:W1j`H0ZM7e102/c?430;7Fl`<0/ncg1P2BjoH208>_l@809eS=00<0?WkU
0003UP0009000`1NOm/30<R``P<0ckBo103Yb[H20>g>]@<0k]2e103JdM030=SAdPD0^<OV1@2Z`N/4
0:S0j`P0Yl3[00<000000:O0j`2W`>/0402W`>/@0?ooo`030000003oool0oooo00/0oooo000F0?oo
o`030000003oool0oooo00`0oooo:P2W`>/3000000D0Yko[102P^>T309JYi0@0RYSK0`25SmH408jJ
f`D0_m[]0P32g>`30;SGl0<0/m7_102[b_050:W8l0@0Z<G^1P2Ub_<40:K1k0@0Yl7/1@2Ubo@30:C;
m080Z<?]1@2Y`^`40:O@mP<0ZM7e0`2Zanh40:c<l@80/ncg0P2K`?8408:fmP<0HJ?d0`23[o4202MH
c@8000>F00D0002@05efd`1NOm/0GWoK0<R``P040<nd_`030=Zl_03Yb[H0jLZf00<0kLje0`3^d;D0
0`3]d;H0f]7@0=[Ad0030=SAdP80em7C0P2hanH30;O7iP@0Z/7[1@2X`>/70:O0j`030000002W`>/0
Yl3[0140Yl3[403oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000h0oooo9P2W`>/30000
00@0Yl3[1@2U_^/40:2hj@<0UZWT102:V=/308F?eP80SY[K0`2_`^P20;oJk@@0`]c/1P2cdNl40:[<
l@D0ZLS`1@2Ub?850:K2k@@0Y/7/102Uc?@50:G;m0D0Z<?]1@2Vc_D40:O@mPD0Z/O^0P2Nl?@30:W2
k0@0Vl3b1022]_H3066Sm080<h;Y0`0WF<d00`000iH0002>05efd`0205efd`@0ckBo0`3J_;`30>g>
]@<0k]2e0`3]d;H30=SAdP<0em7C1P2ganH40:[1j`D0Z<3[1`2W`>/00`000000Yl3[0:O0j`0@0:O0
j`l0oooo0P00000<0?ooo`005P3oool00`000000oooo0?ooo`0>0?ooob80Yl3[0`0000040:O0j`D0
Yko[102U_^/30:2hj@<0UZWT102:V=/308F?ePH0[l;X1032g>`30;oIk@D0[/oa102Zc?460:G7l@@0
YlG_1@2V`^d40:C<m0@0YLcd1@2W`^d30:S3k@80YLgd1@2Vc_D40:W5k@<0Z/O^0`2^`^P40:W2k0@0
VhRo102?QL@207R8e`<0<h;Y00D003Bi02MHc@00094000>F0000SP0305efd`<0ckBo0`3J_;`00`3T
a[T0kLje0>g>]@030>k@]@<0kM2f00<0kM2g0=SAdP3GdM<00`3GdM<0103FdM@0]lOV0;O7iP2ganH3
0;K7i`@0Z/7[1@2X`>/70:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?ooo`09
0?ooo`005P3oool00`000000oooo0?ooo`0@0?oooad0Yl3[0`0000080:O0j`D0Yko[102O^N/309:[
i`<0PIKN101nSMP3092Ng@<0[l;X1034e^L40;oIk@80^MG_1@2^co440:O8l@<0YLOa0`2Wb?440:O5
k`D0Xl_d102Tc?@40:K1k@D0Yl;]1@2UcO@50:W5kP@0ZLG]1@2^`^P50::?`0<0VhRo102?QL@307R8
e`<05gWT00@003Bi02MHc@000iH0002A101MM]<00`3?];l0f[bl0=Zl_0020=Zl_080i<Ji0`3^d;D3
0>g@]P80kM2g103GdM<30=KAe0D0]/OW1@2Z`N/40:S0j`L0Yl3[00<000000:O0j`2W`>/04@2W`>/@
0?ooo`030000003oool0oooo00P0oooo000F0?ooo`8000004P3ooolI0:O0j`<00000302W`>/50:Fn
j`@0WkW[0`2BZnL2086FgPD0OXgH0`2@W]d40<CFi`@0b][V1@2ieNl50:_=lPX0YlSa102SbO<50:?;
m0@0YL3]102V`Nd60:G>m@@0Z<K_102YaNh00`1>c=<0[/7X0:k1j0020:k1j0<0[/;X0P2VUL@40::?
`0@0VhRo102?QL@307R8e`@05gWT00<0002A0003UP0008h00`1ZNm840=Zl_0<0i<Ji00<0jlbf0>k@
]@3^d;D00P3]d;H30>g@]`030>gA^03GdM<0em7C00<0e]7D0P3DdmL40;K7i`D0Z/7[302W`>/00`00
0000Yl3[0:O0j`0A0:O0j`l0oooo00<000000?ooo`3oool0203oool001H0oooo00<000000?ooo`3o
ool04P3ooolE0:O0j`<00000302W`>/40:Noj`D0YKk[0`2O^N/309:[i`<0PIKN101nSMP50;6lhPD0
b][V0P39f^H30;WEk`<0]=Ca102[cO850:K;l`D0X/Oc102SbO<50:G2k@@0YL3]1@2UcoH50:K5k`@0
Z<K_1@2/`>T40:k1j0@0YYG41@2RSl0309^8_`@0ShG4102VZMT407>Ok@80002A101ZNm830=Zl_080
i<Ji0`3[c;H30>g@]P80kM2g0`3]dKP30=KAe0@0e=?G102eanP30:[1j`80ZL7[302W`>/00`000000
Yl3[0:O0j`0@0:O0j`l0oooo0P0000090?ooo`000`3oool2000000@0oooo0P0000040?ooo`800000
103oool00`000000oooo0?ooo`0D0?oooa40Yl3[0`00000@0:O0j`@0Yko[1@2Q_>`309:`j`<0NYST
0P1dR]/508bJf`<0/KcR0P36cMl30<[JiP@0bM[V1P2de?450:K=m0@0XlSc1@2Rao<40:K5l0@0YL;]
1P2ScoL40:G3k`D0Y/G_102W_nX50:c0j@@0Yi[8102VUL@40::?`0<0VhRo1@2[YM440:JYf@@0VZGM
0P00094306YkdP80f[bl0`3Ta[T30>_<]P030>g>]03]d;H0kM2g0080kM2g0`3]dKP20>kD^@@0e=?G
0P3CeM/40;G7j0D0ZL7[302W`>/00`000000Yl3[0:O0j`0@0:O0j`/0oooo0`0000000`3oool00000
0?ooo`080?ooo`000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool05@3oool>0:O0j`800000502W`>/50:Joj`@0XKc/0`2B/>/207ZHi0<0
M8[K1@2<V]/00`2a_>80a/gO0<K=g`020<K=g`D0bM[V0`36f^P60:kCm0@0Xlgf102Sb?<50:C9l`@0
Y/G`1@2QcoL50:C2kP@0YL?_00<0JmgM0:>nk02S_^`00P2S_^`40:NojPD0YYc<0`2WV/P40:JEa0@0
XXo0102UW<d40:^Ud@80YZWI0`2c[mD409ZUg@030000T@1ZNm80JW_B0080JW_B00<0f[bl0>C6^@3T
a[T00`3[c;H20>g>]0<0kM2g0`3]dKP30>kD^@030>oI_03DdmL0e=?G00<0dmGK1@2canT40:W1j``0
Yl3[00<000000:O0j`2W`>/04@2W`>/60?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`00
0P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`8000005`3oool:0:O0
j`<000005`2W`>/50:Joj`<0XKc/0`2B/>/307ZHi0<0M8[K102<V]/40<K=g`@0d=;K1036f^P20<?J
jP<0[]?d0`2We?L40:?=mP@0X<cg1@2TbO<509o<m`@0Y<C_1@2T`^h50:2mkP@0Xkk/102SVl`40:JL
c0@0Yi[80`2VUL@50:2Db0@0YIc=0`2[YM450;>_e@@0VZGM00<0001Z0000T@22T=T00P22T=T30>C6
^@<0jlbf0P3]c[@00`3^ck<0kM2g0>g@]`030>gA^080k]Bi0P3_fK`40=?Ef`80cmOO102canT50:W1
j``0Yl3[00<000000:O0j`2W`>/04@2W`>/20?ooo`<00000203oool00`000000oooo0?ooo`070?oo
o`000P3oool010000000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0H0?oo
o`D0Yl3[0`00000K0:O0j`D0Y;k/0`2G]nh307ZQj`80I8SP101dR]/50:V_g0D0d=;K0`3Dd]L50<?J
jPH0YmCg102JcoX40:3<m`H0WL[g102SbO@40:C4k`8000000`2O_nl40:2mkPD0X9K:0`2SVl`40:JL
c0@0Yi[8102NT<@40:2Db0@0YIc=102f]=P40;>_e@D0YjcK00<000:D08:@f@22T=T00P22T=T0103T
a[T0jlbf0>_<]P3[c;H30>g>]080k/nc0`3]dKP20>kD^@<0kmVl00<0k]o10=?Ef`3CeM/0103?eml4
0;77jPD0ZL7[302W`>/00`000000Yl3[0:O0j`0@0:O0j`800000303oool00`000000oooo0?ooo`06
0?ooo`000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool06@3oool0102W`>/0000000000000000M0:O0j`80Yko[1@2T_^`309NgkP<0NZ7[0P1T
R>0407^?f`<0ZJoL0P2o_=L30=3Bf`<0e=;G0`3FdM@50<7Jk0H0W=Gk0`2JcoX509[<n@D0WM3j102S
bO@204o=d0<0YL?_102O_nl409f@aP@0X9K:102SVl`30:JLc0D0WXk20`2NT<@40:2Db080YIc=0`2d
^]h40;Jdf080/joE0P2f]mT40:N/f`030000JP000Y@0PY3I0080PY3I103[c;H20>g>]0<0k/nc00<0
lM>c0>gA^03]dKP00P3^e;T20>oI_0<0k]o1103?eml20<WGi0@0/LOZ1@2X`N/<0:O0j`030000002W
`>/0Yl3[0100Yl3[3@3oool00`000000oooo0?ooo`060?ooo`000`3oool2000000X0oooo0`000003
0?ooo`800000603oool3000001h0Yl3[1@2W_n/40:Bnk0@0Qjo`0P1KS^P306B8h0@0NhoK00<0ZJoL
0;nle`2o_=L00P2o_=L40=CBe`<0e]7D0P3Gc<l30<7Jk0<0_mS/1@2Be?h4093@o@@0SM?o1@2Md?X2
06WIk`<0/LS[102U`nl409b;`@<0WI361@2PU/X30:>Kc0@0Whk1102NS/8409j@a0<0X9C81P2d^]h3
0;Jdf0D0][OI102W[=/00`0008/0WZgR09j]hP0209j]hP80jlbf0`3]c[@30>k?/`80lM>c0P3^e;T3
0>oI_0<0k]o100<0k>G80<oGg`3?eml00`39en@50:k5j`@0Z<7[302W`>/00`000000Yl3[0:O0j`0@
0:O0j`d0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool05@3oool30000
00@0oooo7P2W`>/50:Noj`@0Wkc]1027[o0205^>j080F7oM101kSm/40;nle`80c<3?0P3Dd]L30=KA
e0@0elc?102of>`30<7?iP@0T]Cn1@1jc_l308gCo`80MMKl00<0I]O_0;o8hP2ob>80102ab>/509f:
_P<0W8_1102MT<H40:2FbP@0XHk10`2OS/4509j>`P<0WY34102`_^@50;BjgP@0/[SM102f]mT40:N^
g@80002;102N[N830>g>]0<0k/nc0`3adk<0103cf[@0kmVl0>oI_03_fK`30>kO`@80k>G81039en@2
0<;Ej0D0[/G[102X`N/<0:O0j`030000002W`>/0Yl3[0100Yl3[303oool00`000000oooo0?ooo`06
0?ooo`00503oool00`000000oooo0?ooo`0B0?ooo`<00000203ooolN0:O0j`D0Y[o/102O_>d308N_
l0<0FhkX0P1HOmd4096KfP80_kcG103<`<l30=KAe0@0elc?0`3Ha<L40<7?iP80`kcC1@2Bbo/508;5
o@80I]O_1@2ob>840:FA`0@0WHZn102LRl4309f@aPD0XY310`2QS/4409n>`@@0WXk20P2NT<@20:bo
j0@0/;kT1@2]]]l40;:hg@@0/KKL102W[]d20000R`80WZgR0P2a`NH20>g>]0<0k/nc0P3adk<20??J
]0030?GR]`3_fK`0kmVl0080k]o10`3/iLP20>OYd@D0`]GX1@2/a>`40:S1j``0Yl3[00<000000:O0
j`2W`>/0402W`>/;0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000403oool3000000`0
oooo7`2W`>/40:Jok0@0VK[_0`1_Y?4203AghP<0F7oM102AVmX50<c0c`80dkk6103Gc<l40=S4a`03
0=Ji_031cnH0`LoV00@0`kcC1P2V]N<40:2lk@80b<KG0`2ob>820;FVbP<0YI701@2MR[h309b;`@80
WI360P2TT/<40::@`@@0XHk10`2OS/4409j>`PD0[;oX0P2`_^@20:Vcg`@0[KKO0P2b^=d30:nih0@0
/KKL0`2W[]d00`1SR>40002;0;71iP040;71iP<0k/nc0`3adk<20??J]080mN:g0P3^gl430>cUb0<0
inWA00<0gn[J0<;Ej032eNP00`2idN/40:c4k0D0Z<3[302W`>/00`000000Yl3[0:O0j`0@0:O0j`X0
oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool0303oool300000140oooo
7P2W`>/40:Fok0@0VK[_0`1_Y?4203AghP80EgkM1@2VY]H30<c0c`<0dkk600<0e[Zn0=O<c`3Gc<l0
103Ha<L30=Ji_0@0`kcC0P36[<030:Jeh`<0]ZS;0P2P_>d40<S6e`@0]JK:102UTL0409f:_P<0W8_1
102TT/<40::@`@@0XHk10`2OS/450:Vnj0@0[;oX1@2Y/ml30:ffg`D0[kWP0P2a]]`30:jhh@<0XjoP
00@0K8kR0000R`2a`NH0/L7V0`2jcnT20>k?/`80lM>c0P3cf[@30?GR]`040??Y_03/iLP0k>G80>cU
b0<0inWA0P3Oj]X60;WAj`@0ZL;/102X`>/<0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool00`00
0000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`8000005@3ooolN0:O0j`@0
YKo/102A^?4204jDl080=7OR0`1GO]d50:JVeP040<c0c`3C_/H0dkk60=>naP<0e[Zn1@3Ha<L30=Ji
_0030=J`/`33_=<0`kcC00@0aZc01P2fZ</40<S6e`80cLcH102eY/X30:FA`0@0WHZn102UUlL40:BB
``<0XY31102QS/440:Nlj0@0ZKkX1@2Y/n040:Vcg`@0[[cT102_^N060:jhh@<0XjoP00<0K8kR0;[?
j@2jcnT0102jcnT30?7C/`80lmZd0P3eh[L20??Y_080l>g30`3WjM420=oZfP<0e>ST1@2bbnd40:W2
k100Yl3[00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00D0oooo000D0?ooo`03
0000003oool0oooo00L0oooo0`00000H0?oooah0Yl3[102S_nd4096hl@80CYC`00@00e[C03AghP1G
O]d0EgkM1@2VY]H40=>naP<0e[Zn0P3H]KH20=S4a`<0e[Vl0`3F/;<50<J/`0030<f/^02fZ</0]ZS;
0080]ZS;0P3A`l`20<S6e`<0cLcH102eY/X30:FA`0D0YYg<0`2UUlL40:BB``<0XY312@2W_>P40:Vd
h@@0ZK?P1@2/_nP40:jli0@0[;[S1@2^^>4409f]h`0406b?h`2jcnT0^/oY0;[?j@<0^n;c00<0lM>c
0??J]03cf[@00`3eh[L0103cjK`0l>g30?3]``3`kL<20>g`b@80gn[J0`3Dj>@20<KPj`@0//_]1@2X
`N/@0:O0j`030000002W`>/0Yl3[00l0Yl3[2P3oool00`000000oooo0?ooo`050?ooo`004`3oool3
000000D0oooo0`00000L0?oooah0Yl3[102S_nd408Vel`809goX00@00e[C05Mng@1GO]d0EgkM0P2V
Y]H30;J[cP80dkk60`3F^[h40=Re]P<0e[Vl103F/;<0103H[Zd0aZc00<J/`036[<030<f/^080]ZS;
0`3A`l`60<g<f0<0]JK:102SXM<40:JMc0@0YIO70`2TT/<40:Nmj@D0YkcX102X]>440:Vdh@@0Z/3Z
1@2/_nP40:Vhi0@0[;[S1@2X]N8409f]h`0306b?h`2kh_<0^n;c00<0^n;c0`3cf[@20?GR]`80lnVl
0P3`kL<20>g`b@80jO;?0`3Dj>@40<KPj`@0[<G/102X`N/A0:O0j`030000002W`>/0Yl3[00l0Yl3[
2@3oool00`000000oooo0?ooo`050?ooo`004`3oool00`000000oooo0?ooo`020?ooo`<00000803o
oolN0:O0j`@0X[k]1029]O<202Moj00300=Jd`1HOmh0F7oN00H0]Z_>103F^[h40=Re]P030=R`/03F
^K`0e[Vl00<0e[2c0P3H[Zd30<J/`0<0cJbh103A`l`20>3Ve`D0cLcH102NY]/30:>Qd`@0YYg<102U
UlL40:JmjP@0YkgY1@2W]>840:Rdh@@0Z;oZ102Z`>X50:Rfh`@0ZKST102Z^>@40:RehP@0WJgS0`1/
Sn<50:K/n@80mN:g0P3cjK`20?3]``80kO390P3Yl/l30>?deP<0a^3[0`2ie>h40:c5k0@0Z<3[402W
`>/00`000000Yl3[0:O0j`0@0:O0j`P0oooo00<000000?ooo`3oool01@3oool001<0oooo00<00000
0?ooo`0000000P00000T0?oooah0Yl3[102R_^d408>dm003001XfP0WOnP00e[C0080F7oN102fZlh2
0<2]a`80e[Zn103H]KH20=R`/0030=Ji_03F/;<0e[2c0080e[2c0`3H[Zd00`36[<00cJbh0<f/^002
0<f/^0030=c0_P3A`l`0dL?<00@0h>KG1@2W]n@409jVf`<0Xj7C0`2VWL`50::ij@@0Y[gZ102V/n44
0:NdhPD0YkoZ102X_nX80:Rfh`D0Z[cV102Z^>@30:RehPD0UZ[T0P1[S^<00`0?E<l0S>Gj08cUnP05
08[Po@80l>g30P3]l<T20>Wbc`<0hoCF0P3Km=l50;WDkPD0ZL;/102X`>/@0:O0j`030000002W`>/0
Yl3[0100Yl3[1`3oool00`000000oooo0?ooo`050?ooo`004`3oool3000002L0oooo7P2W`>/40::n
k@@0PkCd00<006SJ000b]P1HOmh00P1HOmh20;J[cP@0`:g700<0e[Zn0=Re]P3H]KH00P3H]KH20=R`
/0@0e[2c103H[Zd40<f/^0<0g<2n103Pi]L20<cGhP@0YkOT102NY]/30:>Qd`@0WK;V102R^NT50:Fb
h@@0Y[?Q102W_^X40:NojPD0Z;OS1P2X]^<20:Vnj@@0Z[cV0P2Z^>@30:Nhi@<0Y;GU102FZ^@306^>
h`04035[fP0?E<l01UoG000UZ`<0WN7m0`2di?L20>Wbc`<0hoCF0P3Km=l30<k]jP@0[l[]102Y`^`E
0:O0j`030000002W`>/0Yl3[00l0Yl3[1`3oool00`000000oooo0?ooo`050?ooo`00503oool00`00
0000oooo0?ooo`0W0?oooal0Yl3[0`2R_^d4086cm@04001Fc000<[H0DWoO059og`H0`:g7103H]KH3
0=R`/0040=Z`[@3F/;<0e[2c0=J`/`@0f:j]00@0gK>]0<f/^03=[;P0cJbh0`3L`;h20>_L``D0c=OR
102EXmh409>RgP<0V:SR102M/^H90:Fbh@80Y[?Q0P2W_n/40:NnjP@0Z;OT1@2X]n<30:Rfh`D0ZKkY
0`2Z_>H60:Nhi@<0Y;GU0`2FZ^@406^>h`80<F_J0P06GmL40;CTm`80a^S^0P3BknL20=_dg`<0c^gZ
0`2ngNl40:o:k@@0Z<7[502W`>/00`000000Yl3[0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool0
103oool000/0oooo1@0000050?ooo`800000:@3ooolN0:O0j`@0X[k]0`21/oD01000E/`003:f059o
g`1BOml40<2]a`80aZg20`3H]KH30=R`/080f[2]00<0e[2c0=R^[@3H[Zd00P3H[Zd30=fc[@040<f/
^03L`;h0g<2n0=c0_P<0jmc30P3/gL<40;>igP@0UJ?N102CX]h309RXhP@0Y;;R202U/^450:Noj`@0
YkOT102X]n@40:Rgh`@0Z;oZ102Y_^T40:Jgi@D0YkSU102O/>@308jUi0<0JhkR0`0aJmX304b?k@<0
a^S^0P3BknL20=SehP80e_WQ1@2ngNl50:[3k0@0Z<7[502W`>/00`000000Yl3[0:O0j`0@0:O0j`H0
oooo00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0W0?oooah0Yl3[102R_^d308:cm@04001?aP1BOml0DWoO059og`80`:g71036[L80103H]KH0
f;2`0=R`/03H/;030=Z`[@D0f:j]0`3M/jd40=c0_P80jmc30`3/gL<00`3Qd<L0/kWN0;>igP020;>i
gP<0UJ?N102CX]h40:6ai0@0Y;;R0`2U/^450:Jnj`D0YkKT102W]n@30:Rgi0D0YkkZ102X_nX40:Jf
i0@0Y[OU1@2U]^D409n`i0<0SZGT0`1[S^830561hP<0C8o]0`3BknL20=SehP80e_WQ0`3=m>X40;3=
kP@0Z/?/6@2W`>/00`000000Yl3[0:O0j`0@0:O0j`D0oooo00<000000?ooo`3oool0103oool000d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?oooah0Yl3[102R_^d308:cm@03
001?aP0hMMl0>7GO00H0aZg2103H/;030=Z`[@040=jd[@3H[Zd0f:j]0=R^[@@0gK>]00<0i;ja0=c0
_P3L`;h00`3[g<<20>cM``<0hM370`2c^Mh409BTh0@0VZcS102Q/N@40:>hj0@0YKcZ102V]N@40:Nf
i0@0YkOT202W_^X50:Ngi0@0Y[KT102W^^L40:Ffi@@0Wk3T0`2>YN@406^>hP<0DH7R1022/o@0103H
mN80e_WQ0=Kih@3FnN420<gdjP<0_^;a102`cNh40:S1jaT0Yl3[00<000000:O0j`2W`>/03`2W`>/5
0?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool09`3ooolN0:O0j`@0X[k]0`25]?@00`00D/P0>7GO03Qeg`040<J]`P80bK310`3H/;030=Z`
[@040=jd[@3H[Zd0f:j]0=R^[@<0gK>]0`3T_[400`3L`;h0jmc30>_L``030>cM``<0hM37102VZm/4
09BTh0<0VZcS1@2Q/nH40:>hj0@0Y[KT102V]N@30:Nfi0T0YkkZ102X]n@40:Ngi0D0Z;gY102W^^L4
0:6diP@0VZkU0`27Wn<406n?h@80LISX102[dO@30<G/k`030<gdjP2nh_40_^;a00<0_^;a1@2Z`n`4
0:S1jaP0Yl3[00<000000:O0j`2W`>/0402W`>/40?ooo`030000003oool0oooo00@0oooo000=0?oo
o`030000003oool0oooo00X0oooo0P00000X0?oooah0Yl3[102R_^d308Fdm080>7GO0`36[L830<V`
`@80f;2`0`3J/:d30=jd[@030=R^[@3M/jd0gK>]0080gK>]0`3T_[420>_L``<0k=g30`3Qd<L20=?2
b@@0YZ_K0`2DY>0409j^h`@0XK?V1@2V]n@40:Jfi0<0Y[GT2@2W_^X40:Rhi@@0Z;OT102W_^X40:Rm
j@D0Y;GU102Q]>H309Z^i@@0QioS0`1_Sn44076Hj0<0aNc_0P3<n^H30<Ogj`@0/<g_102Z`n`M0:O0
j`030000002W`>/0Yl3[00l0Yl3[103oool00`000000oooo0?ooo`040?ooo`00303oool2000000h0
oooo00<000000?ooo`3oool09P3ooolN0:O0j`@0Xko]0`28]_@00`00DLh0>7GO0<J]`P050<V``@04
0=R`/03J/:d0f[2]0=Z`[@<0g[B]103M/jd40>Bn/@80k<Zc0P3adJl30>7@a`@0dl;9102VZ]X309^Y
h@@0WZkS102U]nD50:Jgi0<0Y[KT202W_^X50:Nhi@@0Z;SU202W_^X40:Fdi0@0Y;GU102Q]>H409>U
hP@0PiWP0P1kUn<509Bhk`80c?[V0`37mn/30;[PlP@0/<g_102X`N/M0:O0j`030000002W`>/0Yl3[
00l0Yl3[0`3oool00`000000oooo0?ooo`040?ooo`007@3oool00`000000oooo0?ooo`0V0?oooah0
Yl3[102S_nd308Rfm003001AcP39/<40bK3100@0bK31103J/:d30=jd[@040>6k/@3M/jd0gK>]0=fc
[@<0i;ja0P3/b[<30?7A[`80lM2_103C`/T20<Vib`@0YZ[J0`2KZN440::di@@0YKOU102V]n@40:Jm
jP@0YkkZ102W]n@40:Nhi@D0YkgY102W_^X40:Jei0@0YKCT102T]nH409j_i0@0TjGR0`23VN0307^G
h`<0U;S_0P2fh_D20<7kj@D0^^3b1@2Y`n`40:S1jad0Yl3[00<000000:O0j`2W`>/03P2W`>/40?oo
o`030000003oool0oooo00<0oooo000N0?ooo`030000003oool0oooo02H0oooo7P2W`>/40:>ok@<0
RkOc00<0057>0<V``@39/<400P39/<420<Vfa`80f[2]103N]:d00`3Q^k40gK>]0=fc[@040>Bn/@80
k<Zc0P3adJl30?7@[`030>g</`3C`/T0dl;900<0bKW;102VZ]X40:2^h@@0X[CU0`2U]nD50:Fjj0@0
Y[gZ202W]n@80:Nmj@D0YkKT102V]N@40:Jkj0@0Y;OV102N[n@309>UhP<0PiWP101kUn<30;KRm@80
`O_Y0`30m^l40:g9kP@0ZL?/8@2W`>/00`000000Yl3[0:O0j`0@0:O0j`80oooo00<000000?ooo`3o
ool00`3oool001l0oooo0P00000X0?oooad0Yl3[102S_nd308^gl`03001AcP39/<40bK3100<0bKK7
0P3J/:d30=jd[@<0hK^a00@0gK>]0>Bn/@3T_[40i;ja0P3/b[<30?7A[`80lM2_0P3]c;<50<Vib`D0
ZJcI102P[^430::di@@0YKOV102U^^P90:Ngi0@0Z;kY102W_NT40:Ngi0@0YkKT1@2V_>T40:Jkj0<0
Y;OV1@2HZ>4308jOg`<0QY_O102A[n/20<7kj@030<3fk`2df?80]=Sb00<0]=Sb102]bNh50:S0jb00
Yl3[00<000000:O0j`2W`>/0402W`>/00`3oool000000?ooo`040?ooo`008@3oool00`000000oooo
0?ooo`0V0?oooad0Yl3[102T_nd308fhl`H0bKK700@0f[2]0=jd[@3N]:d0g[B]0`3Q^k440>Bn/@80
k<Zc0P3adJl30?7@[`80kLbc00@0i/Nh0<Vib`39^L/0bKW;0P35]//50:V/f@@0Y[7P0`2T]><40:Fg
iP@0Z;ST102W]n@90:Rnj@P0YkOT202V_>T50::_h@<0WZgQ102HZ>4408jOg`<0QY_O102ai?P00`2e
nnH0^^gd0;[]m0040;CHlPD0Z<7/9@2W`>/00`000000Yl3[0:O0j`0?0:O0j`030?ooo`000000oooo
00@0oooo000R0?ooo`030000003oool0oooo02H0oooo7@2W`>/40:Bok@<0SkSb1@39]/L40=jd[@<0
hK^a00<0hl:f0>Bn/@3T_[400P3/b[<30?7A[`80lM2_0`3]c;<20>K7^0030<Vib`35]//0aKK;0080
aKK;0P2Y[=T30:n_f0@0Y[7P0`2T]><40:Rhi@@0Z;ST102W_NT40:Rnj@T0YkOT102W_>P40:Jlj@@0
YK7Q102R[n4409j]h@<0V:SQ102>Wml509Jbj`030;GkiP2jkO@0^^gd00<0^^gd1@2ZaNdY0:O0j`03
0000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002<0oooo00<000000?ooo`3oool0
9P3ooolM0:O0j`@0Y;o/0`2?^?820<Vfa`<0a;kE0P3N]:d30>6k/@<0hl:f0`3/b[<20?7A[`<0lM2_
0P3]c;<30>K7^0D0aKK;1@2_[mP40:Jah0@0Z;KS102X^>D40:Nji`@0YkgY102X]^<40:Ngi0T0YkcX
102V/n440:Fah@<0XZoQ1@2LZ=l309BNfP@0SYcL0P2F/^/20:_bm0<0/OW[102^cO050:S0jbP0Yl3[
00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2000002L0oooo7@2W
`>/40:Bok080TKWb1P34_]D0103N]:d0hK^a0>6k/@3Q^k430>?2]P80i/Nh0`3adJl20?7@[`<0kLbc
0`3VakP0103Oa;`0aKK;0<Ffb`35]//20<Feb`@0[joH1@2Y/]l40:Rfh`@0YkOT102W^^L80:Rfh`@0
Z;gX102W_>P50:NdhP@0Y[?Q0`2U/N440::ah`@0W:SO102DW]X308jLg080Zo;d00<0/OW[0;?Jm02c
f_@00`2cf_@40:S2k0@0Z<3[:@2W`>/00`000000Yl3[0:O0j`0;0:O0j`<0oooo00<000000?ooo`3o
ool00`3oool002H0oooo00<000000?ooo`3oool09@3ooolM0:O0j`D0Y;o/00<0TKWb0<Bne@34_]D0
0`34_]D30>6k/@@0hl:f0P3VakP20>c?]`<0lM2_0P3]c;<30>K7^0<0glBl00<0aKK;0<Feb`35]L/0
0P35]L/40;>aeP@0ZK;O1@2Y]>440:Ngi0@0Z[OS102X]^<40:Vmj0@0Z;gX202W]>850:FgiP<0XkKV
102R/N<309bXg`@0U9kJ0`2NcOP209WcgP80/n_g0`2cf_@20:[5k@@0Z<;/;@2W`>/00`000000Yl3[
0:O0j`060:O0j`P0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool09@3o
oolN0:O0j`@0YKo/00<0Tk[b0;;5j02baNP00`2baNP20>6k/@<0hl:f0`3VakP20>c?]`80l=Bd0`3]
c;<30>K7^0<0glBl1035]L/20<Ffb`@0/k7F102^/]/40:Vdh@D0ZkSR102Z]n<40:Vli`@0ZKgX102W
/n440:NdhP@0Y[OU102U]nH40:>fiP@0VYWA0`2EVMD409BWhP80VO?N1@2cjoL50:[5kC00Yl3[00<0
00000:O0j`2W`>/00`2W`>/;0?ooo`030000003oool0oooo0080oooo000X0?ooo`030000003oool0
oooo02H0oooo7@2W`>/40:Fok00309>jlP2baNP0//GX00<0//GX103S`[H20>K7^0<0k<ng0P3`e;@2
0?7F]@<0i/Nh103Oa;`00`3K`/40aKG;0<Feb`040<Ffb`80/k7F0P2h/M<40:jbf`@0[KGO102[^>85
0:Vhi0@0ZKcW102X/]l40:Nch@@0YkOT102V]nD30:FgiPD0WikB0`2JVM4409FIe@80U:OR0P2@k^`2
0:Odl@D0[<[`=@2W`>/00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo000Y0?oo
o`8000009`3ooolM0:O0j`@0YKo/00<0UK_a09[3m02J`o@00`2J`o@20>?2]P<0i/Nh0P3/ckL30?3D
]080lMJe0P3_e[T40=o4_0<0fl;11@35]//50;Rad`80[[;K0P2a/MP40:feg`@0ZkCO102Y^>@50:Vb
gP@0Z;;O102Y^>@40:Ngi0@0YJKF0`2SXm@409nNdP@0VYWA0`2EVMD2093^k0030:Odl@2]dO<0[M7c
00<0[M7c102X`N/b0:O0j`<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`00:`3oool00`000000oooo0?ooo`0U0?oooad0Yl3[102U_n`00`2H_?40V/?d09[3m00309[3m003
0>?2]P3VakP0i/Nh00<0k<ng0P3`e;@20?7F]@<0kmJi00<0j]O10=o4_03Oa;`0103K`/40103G`lH0
aKK;0<Ffb`35]//20<Jgb`@0^;7C1@2a/MP40:jafP@0ZkCO102//]d40:VbgPD0Z[SS0`2Y^>@50:JV
eP@0YJKF0`2SXm@309nNdP@0VYWA00<0U]on08_]g@2;kMd01@2]f_L40:S2k0@0Z<7[;@2W`>/80?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3o
ool09@3ooolM0:O0j`@0YKo/00<0V;ca09[3m02J`o@00P2J`o@30>K7^080k<ng0`3`e;@20?7F]@80
kmJi0`3Zel440=_2`@<0el?600<0aKK;0<Jgb`36]l/00P36]l/20;Rad`80^k7@0`2a/MP20;F_d`@0
[[7J102_/MX40:bbg@@0ZkGP102Z^><40:NTd`@0YZKF102UY]H30:>Se0@0W:gS0`2J`O<40:_QnPD0
ZLC]0`2X`^`^0:O0j`/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00
;@3oool00`000000oooo0?ooo`0V0?oooa`0Yl3[102U_n`209^ml0@0R;oi0`3/ckL20?3D]080lMJe
0`3_e[T20>[G`@80hm[<0P3K`/440=O3aPD0a[O;1@2k/M050;F_d`80[[7J0P2b[mD40:nafP80[;;M
0P2/[mX40:^eh0@0Yj7@102WY=<30:JVePD0XZ;D0`2OY=T409b]h`<0Y>Ok102Yanl40:W4kBh0Yl3[
3`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000^0?ooo`030000003o
ool0oooo02H0oooo702W`>/40:Jok080Vkg`1@20aOd30?3D]080lMJe0P3_e[T20>[G`@@0hm[<103G
`lH20=C8c`80a[O;0`37^lh20;^ad0<0_[C@102e[m<50;:_e@<0[k7J1@2/[mX20:^eh080ZZ3=102W
XM030:NTd`@0YZCC102RX]@409nTf@0305K?_`2Tio/0Y>Ok00@0ZL[a102Yanl40:NojbT0Yl3[503o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000_0?ooo`8000009`3ooolM
0:O0j`<0Y[o/0P2O_^h608KEo`80lMJe0`3_e[T00`3Zel40hm[<0>?Jc0020>?Jc080fN3L0P3G`lH3
0=C8c`D0ak_>1@2n]=020;F_d`<0^;3A102b[mD40:jYd`@0[:oJ102ZX<d40:NQd0@0ZZWF102VY=<3
0::Re080Clc300<0V^Wj0:S;lP2Xbo800`2Xbo840:W:l@P0Yko[9@2W`>/H0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool09@3ooolM0:O0
j`@0Y[o/0P2S_nd209?To0H0U>Wi00<0j]O10>?Jc03Sf/`00P3Sf/`30=WPg0@0e<S?0P3>dmd30<Nk
cP80alGH102n]=050;R`d@80/ZoE0`2d[M430:jYd`D0[jG>102ZX<d20:NQd080[kCM102ZZMH30:JT
d`80CL_700<0S^Oi0:O<l`2Wc?<00P2Wc?<40:S;lPD0YkoZ0`2W_n/50:S1jb00Yl3[703oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000b0?ooo`030000003oool0oooo02D0
oooo8@2W`>/40:>ok@0308fjm020h_L0P>;g00D0Dlc]103Ih=`20<;Yl@80e<S?103>dmd00`37^lh0
alGH0<O5f0020<O5f080_[C@0P31_]P40;R`d@D0]:gA0P2^ZM<20;NdeP@0[jG>102ZX<d50:ndg@<0
ZZWF00<0B<S608KSn@26hoT0102Uc?@40:O<l`@0Z;o[102W_nX50:S1k0@0Yko[702W`>/P0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool003<0oooo00<000000?ooo`3oool0
9@3ooolQ0:O0j`@0YKo/102J_O4306ban@03001bd00Y0000`^Wa00@0`^Wa1@3>dmd50<O5f0D0`KkH
102m_m/40;B]d@D0]kCF0`2_YLh50;?9jP@0[kCM00<0>kjk08;Pn`22h?/0102Tb_<40:G<m0P0Z;o[
1@2W`N`80:NojaP0Yl3[903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo
000d0?ooo`8000009P3ooolQ0:O0j`@0YKo/102R_nh408fkm@80AZKg1@1mgoT40;CVm`<0alGH0P2k
go830<6nf080]N?f102m_m/40;_Ck0@0]kCF1@2[i?X30;?9jP@0R]Oo102Tb?<40:C:l`@0Yko[202W
`N`50:NojP<0Yko[602W`>/Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3o
ool003H0oooo00<000000?ooo`3oool09@3ooolO0:O0j`D0Y/3/0`2R_nh509jnl0<0P[[i100aX_80
1000NkT0]>Kg0;CVm`2di_L50;_OlPD0]N?f102>j?L40;_Ck0D0KmkX00<06JJc036hf@2AdOd00`2A
dOd50:C6l@<0Y<Sc1@2W_n/80:O1k0P0YkoZ102W`N`D0:O0jb`0oooo00<000000?ooo`3oool01`3o
ool100000040oooo0@3oool003L0oooo00<000000?ooo`3oool09@3ooolP0:O0j`<0Y/3/1@2U_n`4
0:Fok@@0Vkoa0`1n_?X508JonP80C[Kj0`14aMh501bZ`P<0S^Sg0`1nbOl409g5m0@0Ul_i1@2T`nl4
0:Noj`@0YkoZ202W`N`80:NojPP0Yl7/102W_n/<0:O0jc00oooo00<000000?ooo`3oool01P3oool1
00000040oooo0@3oool003P0oooo00<000000?ooo`3oool09@3ooolX0:O0j`@0YKo]102T_nd409bo
l@@0X<3_102C`OH409k1l@@0TlCh1@2Q`_0309g5m0D0YL7]102X_n/40:Noj`P0Yl7/202W_nX80:O1
k0P0Yko[102W`>/h0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo000i0?ooo`80
00009P3oool/0:O0j`@0Y;o]102U`>`40:30k`@0Y<3]102N`O450:C0k@@0Yl3/102V`>`40:S0j`@0
Z;o[1`2W`N`80:NojPP0Yl7/202W_n/50:O0jc/0oooo00<000000?ooo`3oool01@3oool100000040
oooo0@3oool003/0oooo00<000000?ooo`3oool0903oool`0:O0j`@0YL3/1@2V`>`30:C0k@D0Y/3/
102W`>/30:O0k0D0Yl3[0`2X`>/50:O0k0<0Yl7/202W_nX80:O1k0D0YkoZ202W`N`o0?ooo`030000
003oool0oooo00@0oooo0@0000010?ooo`40oooo000l0?ooo`030000003oool0oooo02@0ooooD02W
`>/40:O0k0@0Z;oZ102W_nX50:O1k0P0YkoZ202W`Na30?ooo`030000003oool0oooo00<0oooo0@00
00010?ooo`40oooo000m0?ooo`030000003oool0oooo02@0ooooB02W`>/40:Noj`@0Yl3[1@2X_n/3
0:RojPD0Yl7/1`2W_nX80:O1k4P0oooo00<000000?ooo`3oool00P3oool100000040oooo0@3oool0
03h0oooo0P00000U0?ooodT0Yl3[0`2W_n/50:S0j`@0Yl3/0`2W`N`80:NojPP0Yl7/B`3oool00`00
0000oooo0?ooo`030?ooo`4000000@3oool00400oooo00<000000?ooo`3oool08`3ooomA0:O0j`<0
Yl3/102W_n/40:NojPP0Yl7/C`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool00440oooo
00<000000?ooo`3oool08`3ooom@0:O0j`@0Z;o[102W_n/80:O1k5<0oooo00D000000?ooo`3oool0
oooo000000010?ooo`00@P3oool00`000000oooo0?ooo`0T0?oood/0Yl3[102X`>/40:Roj`P0Yl7/
E`3oool010000000oooo0?ooo`0000010?ooo`00@`3oool2000002D0ooooC02W`>/30:S0j`@0Yl3/
GP3oool010000000oooo0?ooo`0000010?ooo`00A@3oool00`000000oooo0?ooo`0S0?ooodP0Yl3[
102W_n/30:O0jf80oooo00<000000?ooo`0000000@3oool004H0oooo00<000000?ooo`3oool08`3o
oom80:O0j`<0Yko[IP3oool100000040oooo0@00000004L0oooo00<000000?ooo`3oool08`3ooom7
0:O0jfX0oooo0P00000004P0oooo0P00000U0?oood80Yl3[K@3oool200000000BP3oool00`000000
oooo0?ooo`0S0?oooch0Yl3[L03oool200000000B`3oool00`000000oooo0?ooo`0R0?oooc/0Yl3[
K`3oool400000080oooo001<0?ooo`030000003oool0oooo02<0oooo<`2W`>]a0?ooo`@000001P3o
ool004d0oooo0P00000T0?ooobl0Yl3[L03oool4000000X0oooo001?0?ooo`030000003oool0oooo
0280oooo:`2W`>]_0?ooo`@000003P3oool00500oooo00<000000?ooo`3oool08`3ooolV0:O0jfh0
oooo1000000B0?ooo`00D@3oool00`000000oooo0?ooo`0S0?ooob80Yl3[KP3oool3000001H0oooo
001B0?ooo`800000903ooolN0:O0jfd0oooo1000000I0?ooo`00E03oool00`000000oooo0?ooo`0R
0?oooaL0Yl3[K`3oool4000001d0oooo001E0?ooo`030000003oool0oooo0240oooo502W`>]^0?oo
o`@000008@3oool005H0oooo00<000000?ooo`3oool08P3oool?0:O0jfd0oooo1000000U0?ooo`00
E`3oool2000002<0oooo2`2W`>]/0?ooo`@00000:@3oool005T0oooo00<000000?ooo`3oool08@3o
ool40:O0jfl0oooo0`00000]0?ooo`00FP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo06X0oooo1000000`0?ooo`00F`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
06H0oooo1000000d0?ooo`00G03oool200000240oooo00<000000?ooo`3oool0HP3oool4000003P0
oooo001N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool4000003`0oooo
001O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool400000400oooo001P
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool3000004@0oooo001Q0?oo
o`800000703oool00`000000oooo0?ooo`1C0?ooo`@00000A`3oool006<0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000B`3oool006@0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1;0?ooo`@00000C`3oool006D0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`170?ooo`@00000D`3oool006H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`130?ooo`@00000E`3oool006L0oooo0P00000F0?ooo`030000003oool0oooo
0400oooo0`00001K0?ooo`00J@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03`0
oooo1000001N0?ooo`00JP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03P0oooo
1000001R0?ooo`00J`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0oooo1000
001V0?ooo`00K03oool200000100oooo00<000000?ooo`3oool0<@3oool4000006X0oooo001^0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;@3oool4000006h0oooo001_0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3oool300000780oooo001`0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool4000007D0oooo001a0?ooo`8000002`3o
ool00`000000oooo0?ooo`0R0?ooo`@00000N@3oool007<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0N0?ooo`@00000O@3oool007@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0J0?ooo`@00000P@3oool007D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0F0?ooo`@00000Q@3oool007H0oooo0P0000060?ooo`030000003oool0oooo01<0oooo
0`0000290?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo1000
002<0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000002@
0?ooo`00NP3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002D0?ooo`00N`3oool20000
00030?ooo`000000oooo00@0oooo1000002H0?ooo`00O@3oool2000000030?ooo`00000000000080
0000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .66149 .53878 .65559 Mtetra
.53878 .65559 .54483 .66149 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .6551 .56155 .64914 Mtetra
.56155 .64914 .56753 .6551 .57895 .65188 .573 .64589 Mtetra
.655 .751 .92 r
.573 .64589 .57895 .65188 .59042 .64863 .5845 .64265 Mtetra
.655 .752 .921 r
.5845 .64265 .59042 .64863 .60194 .64537 .59604 .63939 Mtetra
.656 .753 .921 r
.59604 .63939 .60194 .64537 .6135 .64212 .60764 .6361 Mtetra
.657 .753 .921 r
.60764 .6361 .6135 .64212 .62511 .63887 .61928 .63277 Mtetra
.657 .751 .919 r
.61928 .63277 .62511 .63887 .63677 .63562 .63097 .62943 Mtetra
.657 .749 .918 r
.63097 .62943 .63677 .63562 .64848 .63234 .64271 .62607 Mtetra
.657 .747 .917 r
.64271 .62607 .64848 .63234 .66024 .62904 .6545 .62272 Mtetra
.657 .746 .916 r
.6545 .62272 .66024 .62904 .67204 .62571 .66634 .61936 Mtetra
.656 .746 .916 r
.66634 .61936 .67204 .62571 .6839 .62237 .67823 .61599 Mtetra
.67823 .61599 .6839 .62237 .69581 .619 .69017 .61261 Mtetra
.655 .746 .916 r
.69017 .61261 .69581 .619 .70776 .61561 .70216 .60924 Mtetra
.655 .747 .918 r
.70216 .60924 .70776 .61561 .71977 .61218 .71421 .60585 Mtetra
.654 .749 .92 r
.71421 .60585 .71977 .61218 .73182 .60876 .7263 .60247 Mtetra
.654 .752 .921 r
.7263 .60247 .73182 .60876 .74393 .60533 .73845 .59907 Mtetra
.656 .754 .922 r
.73845 .59907 .74393 .60533 .75609 .60192 .75064 .5956 Mtetra
.656 .753 .921 r
.75064 .5956 .75609 .60192 .7683 .5985 .76289 .59211 Mtetra
.656 .752 .92 r
.76289 .59211 .7683 .5985 .78057 .59505 .77519 .58861 Mtetra
.656 .751 .92 r
.77519 .58861 .78057 .59505 .79288 .59157 .78754 .58511 Mtetra
.78754 .58511 .79288 .59157 .80525 .58807 .79995 .58159 Mtetra
.79995 .58159 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66881 Mtetra
.46533 .66881 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66247 Mtetra
.4876 .66247 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.656 .752 .92 r
.55551 .64314 .56155 .64914 .573 .64589 .567 .63987 Mtetra
.567 .63987 .573 .64589 .5845 .64265 .57853 .63658 Mtetra
.656 .751 .92 r
.57853 .63658 .5845 .64265 .59604 .63939 .59011 .63327 Mtetra
.656 .75 .919 r
.59011 .63327 .59604 .63939 .60764 .6361 .60173 .62996 Mtetra
.655 .75 .92 r
.60173 .62996 .60764 .6361 .61928 .63277 .61341 .62667 Mtetra
.655 .752 .921 r
.61341 .62667 .61928 .63277 .63097 .62943 .62514 .62336 Mtetra
.654 .754 .923 r
.62514 .62336 .63097 .62943 .64271 .62607 .63691 .62004 Mtetra
.655 .756 .924 r
.63691 .62004 .64271 .62607 .6545 .62272 .64874 .61669 Mtetra
.655 .757 .925 r
.64874 .61669 .6545 .62272 .66634 .61936 .66061 .61331 Mtetra
.66061 .61331 .66634 .61936 .67823 .61599 .67254 .60991 Mtetra
.67254 .60991 .67823 .61599 .69017 .61261 .68451 .6065 Mtetra
.656 .757 .924 r
.68451 .6065 .69017 .61261 .70216 .60924 .69654 .60305 Mtetra
.656 .756 .923 r
.69654 .60305 .70216 .60924 .71421 .60585 .70861 .59958 Mtetra
.657 .754 .922 r
.70861 .59958 .71421 .60585 .7263 .60247 .72074 .59609 Mtetra
.657 .751 .92 r
.72074 .59609 .7263 .60247 .73845 .59907 .73292 .5926 Mtetra
.655 .749 .919 r
.73292 .5926 .73845 .59907 .75064 .5956 .74515 .58914 Mtetra
.656 .75 .919 r
.74515 .58914 .75064 .5956 .76289 .59211 .75744 .58565 Mtetra
.656 .751 .92 r
.75744 .58565 .76289 .59211 .77519 .58861 .76977 .58214 Mtetra
.656 .752 .92 r
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Mtetra
.656 .751 .92 r
.78216 .57861 .78754 .58511 .79995 .58159 .79461 .57507 Mtetra
.79461 .57507 .79995 .58159 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66881 .45901 .66296 Mtetra
.45901 .66296 .46533 .66881 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66247 .48134 .65658 Mtetra
.48134 .65658 .4876 .66247 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Mtetra
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Mtetra
.655 .751 .92 r
.56095 .6338 .567 .63987 .57853 .63658 .57251 .6305 Mtetra
.655 .752 .921 r
.57251 .6305 .57853 .63658 .59011 .63327 .58412 .62719 Mtetra
.656 .753 .921 r
.58412 .62719 .59011 .63327 .60173 .62996 .59578 .62385 Mtetra
.657 .753 .921 r
.59578 .62385 .60173 .62996 .61341 .62667 .60749 .62047 Mtetra
.657 .751 .919 r
.60749 .62047 .61341 .62667 .62514 .62336 .61925 .61707 Mtetra
.657 .749 .918 r
.61925 .61707 .62514 .62336 .63691 .62004 .63106 .61366 Mtetra
.657 .747 .916 r
.63106 .61366 .63691 .62004 .64874 .61669 .64291 .61025 Mtetra
.657 .746 .916 r
.64291 .61025 .64874 .61669 .66061 .61331 .65482 .60684 Mtetra
.656 .745 .915 r
.65482 .60684 .66061 .61331 .67254 .60991 .66678 .60342 Mtetra
.656 .745 .916 r
.66678 .60342 .67254 .60991 .68451 .6065 .67879 .59998 Mtetra
.655 .745 .916 r
.67879 .59998 .68451 .6065 .69654 .60305 .69085 .59656 Mtetra
.655 .747 .917 r
.69085 .59656 .69654 .60305 .70861 .59958 .70296 .59313 Mtetra
.654 .749 .919 r
.70296 .59313 .70861 .59958 .72074 .59609 .71513 .58969 Mtetra
.655 .751 .921 r
.71513 .58969 .72074 .59609 .73292 .5926 .72735 .58623 Mtetra
.656 .754 .922 r
.72735 .58623 .73292 .5926 .74515 .58914 .73962 .5827 Mtetra
.656 .753 .921 r
.73962 .5827 .74515 .58914 .75744 .58565 .75194 .57916 Mtetra
.656 .752 .92 r
.75194 .57916 .75744 .58565 .76977 .58214 .76431 .57561 Mtetra
.656 .751 .92 r
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57205 Mtetra
.77674 .57205 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Mtetra
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Mtetra
.656 .752 .92 r
.55486 .62768 .56095 .6338 .57251 .6305 .56645 .62434 Mtetra
.656 .751 .92 r
.56645 .62434 .57251 .6305 .58412 .62719 .57809 .62098 Mtetra
.656 .75 .919 r
.57809 .62098 .58412 .62719 .59578 .62385 .58979 .61761 Mtetra
.655 .75 .92 r
.58979 .61761 .59578 .62385 .60749 .62047 .60153 .61427 Mtetra
.654 .752 .921 r
.60153 .61427 .60749 .62047 .61925 .61707 .61332 .61092 Mtetra
.654 .754 .923 r
.61332 .61092 .61925 .61707 .63106 .61366 .62516 .60756 Mtetra
.655 .757 .925 r
.62516 .60756 .63106 .61366 .64291 .61025 .63706 .60416 Mtetra
.655 .758 .926 r
.63706 .60416 .64291 .61025 .65482 .60684 .649 .60073 Mtetra
.649 .60073 .65482 .60684 .66678 .60342 .66099 .59728 Mtetra
.66099 .59728 .66678 .60342 .67879 .59998 .67304 .59381 Mtetra
.656 .758 .925 r
.67304 .59381 .67879 .59998 .69085 .59656 .68513 .59031 Mtetra
.657 .757 .924 r
.68513 .59031 .69085 .59656 .70296 .59313 .69728 .58678 Mtetra
.657 .755 .922 r
.69728 .58678 .70296 .59313 .71513 .58969 .70948 .58322 Mtetra
.657 .752 .92 r
.70948 .58322 .71513 .58969 .72735 .58623 .72173 .57966 Mtetra
.656 .749 .919 r
.72173 .57966 .72735 .58623 .73962 .5827 .73404 .57613 Mtetra
.655 .75 .919 r
.73404 .57613 .73962 .5827 .75194 .57916 .7464 .5726 Mtetra
.655 .751 .92 r
.7464 .5726 .75194 .57916 .76431 .57561 .75881 .56904 Mtetra
.656 .752 .92 r
.75881 .56904 .76431 .57561 .77674 .57205 .77128 .56545 Mtetra
.77128 .56545 .77674 .57205 .78922 .56848 .7838 .56185 Mtetra
.656 .751 .92 r
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Mtetra
.655 .751 .92 r
.54871 .62151 .55486 .62768 .56645 .62434 .56034 .61816 Mtetra
.655 .752 .921 r
.56034 .61816 .56645 .62434 .57809 .62098 .57202 .61481 Mtetra
.655 .753 .922 r
.57202 .61481 .57809 .62098 .58979 .61761 .58374 .61143 Mtetra
.657 .754 .921 r
.58374 .61143 .58979 .61761 .60153 .61427 .59552 .60799 Mtetra
.657 .752 .92 r
.59552 .60799 .60153 .61427 .61332 .61092 .60734 .60453 Mtetra
.657 .749 .918 r
.60734 .60453 .61332 .61092 .62516 .60756 .61922 .60107 Mtetra
.657 .746 .916 r
.61922 .60107 .62516 .60756 .63706 .60416 .63114 .59761 Mtetra
.656 .745 .915 r
.63114 .59761 .63706 .60416 .649 .60073 .64312 .59415 Mtetra
.64312 .59415 .649 .60073 .66099 .59728 .65515 .59067 Mtetra
.65515 .59067 .66099 .59728 .67304 .59381 .66722 .58718 Mtetra
.656 .745 .916 r
.66722 .58718 .67304 .59381 .68513 .59031 .67936 .5837 Mtetra
.655 .746 .917 r
.67936 .5837 .68513 .59031 .69728 .58678 .69154 .58021 Mtetra
.654 .748 .919 r
.69154 .58021 .69728 .58678 .70948 .58322 .70378 .57672 Mtetra
.655 .751 .921 r
.70378 .57672 .70948 .58322 .72173 .57966 .71607 .5732 Mtetra
.656 .754 .922 r
.71607 .5732 .72173 .57966 .73404 .57613 .72841 .56961 Mtetra
.656 .753 .921 r
.72841 .56961 .73404 .57613 .7464 .5726 .74081 .56601 Mtetra
.656 .752 .92 r
.74081 .56601 .7464 .5726 .75881 .56904 .75326 .5624 Mtetra
.656 .751 .92 r
.75326 .5624 .75881 .56904 .77128 .56545 .76577 .55879 Mtetra
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54785 Mtetra
.80361 .54785 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64514 Mtetra
.43976 .64514 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Mtetra
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Mtetra
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61868 Mtetra
.655 .751 .921 r
.53091 .61868 .53714 .62486 .54871 .62151 .54252 .61531 Mtetra
.655 .752 .921 r
.54252 .61531 .54871 .62151 .56034 .61816 .55418 .61193 Mtetra
.55418 .61193 .56034 .61816 .57202 .61481 .56589 .60855 Mtetra
.653 .751 .921 r
.56589 .60855 .57202 .61481 .58374 .61143 .57765 .60521 Mtetra
.65 .752 .924 r
.57765 .60521 .58374 .61143 .59552 .60799 .58946 .60193 Mtetra
.647 .757 .929 r
.58946 .60193 .59552 .60799 .60734 .60453 .60133 .5987 Mtetra
.646 .766 .936 r
.60133 .5987 .60734 .60453 .61922 .60107 .61324 .59545 Mtetra
.647 .774 .941 r
.61324 .59545 .61922 .60107 .63114 .59761 .62521 .59214 Mtetra
.648 .781 .944 r
.62521 .59214 .63114 .59761 .64312 .59415 .63723 .58873 Mtetra
.651 .785 .945 r
.63723 .58873 .64312 .59415 .65515 .59067 .6493 .58523 Mtetra
.654 .786 .944 r
.6493 .58523 .65515 .59067 .66722 .58718 .66141 .58163 Mtetra
.658 .784 .941 r
.66141 .58163 .66722 .58718 .67936 .5837 .67357 .57793 Mtetra
.66 .778 .936 r
.67357 .57793 .67936 .5837 .69154 .58021 .68579 .57418 Mtetra
.661 .77 .93 r
.68579 .57418 .69154 .58021 .70378 .57672 .69805 .5704 Mtetra
.66 .761 .925 r
.69805 .5704 .70378 .57672 .71607 .5732 .71037 .56666 Mtetra
.658 .754 .921 r
.71037 .56666 .71607 .5732 .72841 .56961 .72275 .563 Mtetra
.656 .752 .92 r
.72275 .563 .72841 .56961 .74081 .56601 .73518 .55937 Mtetra
.656 .752 .921 r
.73518 .55937 .74081 .56601 .75326 .5624 .74767 .55574 Mtetra
.74767 .55574 .75326 .5624 .76577 .55879 .76021 .55208 Mtetra
.656 .752 .92 r
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Mtetra
.656 .751 .92 r
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Mtetra
.78546 .54474 .79094 .55152 .80361 .54785 .79817 .54105 Mtetra
.79817 .54105 .80361 .54785 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64514 .43325 .63911 Mtetra
.43325 .63911 .43976 .64514 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Mtetra
.655 .751 .92 r
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61583 Mtetra
.655 .751 .921 r
.51305 .61583 .51935 .62203 .53091 .61868 .52464 .61248 Mtetra
.652 .752 .923 r
.52464 .61248 .53091 .61868 .54252 .61531 .53629 .60918 Mtetra
.647 .753 .926 r
.53629 .60918 .54252 .61531 .55418 .61193 .54798 .606 Mtetra
.638 .758 .935 r
.54798 .606 .55418 .61193 .56589 .60855 .55973 .60301 Mtetra
.627 .769 .948 r
.55973 .60301 .56589 .60855 .57765 .60521 .57153 .6002 Mtetra
.615 .786 .963 r
.57153 .6002 .57765 .60521 .58946 .60193 .58339 .59749 Mtetra
.603 .804 .977 r
.58339 .59749 .58946 .60193 .60133 .5987 .59531 .59481 Mtetra
.593 .824 .987 r
.59531 .59481 .60133 .5987 .61324 .59545 .60728 .59207 Mtetra
.586 .843 .993 r
.60728 .59207 .61324 .59545 .62521 .59214 .6193 .58915 Mtetra
.588 .859 .995 r
.6193 .58915 .62521 .59214 .63723 .58873 .63137 .58595 Mtetra
.598 .872 .993 r
.63137 .58595 .63723 .58873 .6493 .58523 .64349 .58243 Mtetra
.617 .878 .99 r
.64349 .58243 .6493 .58523 .66141 .58163 .65565 .57857 Mtetra
.638 .875 .985 r
.65565 .57857 .66141 .58163 .67357 .57793 .66784 .57444 Mtetra
.657 .865 .978 r
.66784 .57444 .67357 .57793 .68579 .57418 .68008 .57012 Mtetra
.668 .847 .968 r
.68008 .57012 .68579 .57418 .69805 .5704 .69236 .56573 Mtetra
.672 .826 .957 r
.69236 .56573 .69805 .5704 .71037 .56666 .70469 .56137 Mtetra
.673 .804 .945 r
.70469 .56137 .71037 .56666 .72275 .563 .71708 .55711 Mtetra
.668 .782 .934 r
.71708 .55711 .72275 .563 .73518 .55937 .72952 .55302 Mtetra
.663 .766 .926 r
.72952 .55302 .73518 .55937 .74767 .55574 .74204 .54912 Mtetra
.659 .756 .922 r
.74204 .54912 .74767 .55574 .76021 .55208 .75461 .54536 Mtetra
.657 .753 .921 r
.75461 .54536 .76021 .55208 .77281 .54842 .76725 .54163 Mtetra
.656 .752 .92 r
.76725 .54163 .77281 .54842 .78546 .54474 .77994 .53792 Mtetra
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Mtetra
.656 .751 .92 r
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Mtetra
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61635 Mtetra
.655 .751 .921 r
.4836 .61635 .49001 .62255 .50151 .61919 .49512 .613 Mtetra
.652 .751 .923 r
.49512 .613 .50151 .61919 .51305 .61583 .5067 .60971 Mtetra
.643 .752 .928 r
.5067 .60971 .51305 .61583 .52464 .61248 .51833 .60664 Mtetra
.626 .757 .941 r
.51833 .60664 .52464 .61248 .53629 .60918 .53 .60395 Mtetra
.594 .77 .963 r
.53 .60395 .53629 .60918 .54798 .606 .54174 .60177 Mtetra
.54 .79 .99 r
.54174 .60177 .54798 .606 .55973 .60301 .55353 .60011 Mtetra
.453 .806 .997 r
.55353 .60011 .55973 .60301 .57153 .6002 .5654 .59876 Mtetra
.331 .79 .942 r
.5654 .59876 .57153 .6002 .58339 .59749 .57733 .59741 Mtetra
.215 .738 .827 r
.57733 .59741 .58339 .59749 .59531 .59481 .58932 .59571 Mtetra
.155 .695 .726 r
.58932 .59571 .59531 .59481 .60728 .59207 .60136 .59347 Mtetra
0 0 0 r
.60136 .59347 .60728 .59207 .6193 .58915 .61345 .5907 Mtetra
.61345 .5907 .6193 .58915 .63137 .58595 .62559 .5875 Mtetra
.214 .73 .698 r
.62559 .5875 .63137 .58595 .64349 .58243 .63777 .58395 Mtetra
.25 .754 .714 r
.63777 .58395 .64349 .58243 .65565 .57857 .64999 .58007 Mtetra
.295 .785 .733 r
.64999 .58007 .65565 .57857 .66784 .57444 .66225 .57575 Mtetra
.369 .833 .774 r
.66225 .57575 .66784 .57444 .68008 .57012 .67453 .57089 Mtetra
.478 .897 .845 r
.67453 .57089 .68008 .57012 .69236 .56573 .68683 .56547 Mtetra
.595 .944 .923 r
.68683 .56547 .69236 .56573 .70469 .56137 .69915 .55968 Mtetra
.671 .937 .966 r
.69915 .55968 .70469 .56137 .71708 .55711 .71151 .55389 Mtetra
.696 .892 .969 r
.71151 .55389 .71708 .55711 .72952 .55302 .72393 .54841 Mtetra
.691 .838 .954 r
.72393 .54841 .72952 .55302 .74204 .54912 .73642 .54344 Mtetra
.677 .796 .938 r
.73642 .54344 .74204 .54912 .75461 .54536 .749 .53898 Mtetra
.666 .769 .927 r
.749 .53898 .75461 .54536 .76725 .54163 .76165 .53493 Mtetra
.659 .757 .922 r
.76165 .53493 .76725 .54163 .77994 .53792 .77438 .53107 Mtetra
.657 .753 .921 r
.77438 .53107 .77994 .53792 .79269 .5342 .78716 .52729 Mtetra
.656 .752 .92 r
.78716 .52729 .79269 .5342 .8055 .53046 .80001 .52351 Mtetra
.656 .751 .92 r
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Mtetra
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Mtetra
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Mtetra
.655 .751 .92 r
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61349 Mtetra
.653 .751 .921 r
.46562 .61349 .47212 .61971 .4836 .61635 .47713 .61016 Mtetra
.646 .751 .926 r
.47713 .61016 .4836 .61635 .49512 .613 .48869 .60701 Mtetra
.627 .753 .938 r
.48869 .60701 .49512 .613 .5067 .60971 .50029 .60433 Mtetra
.581 .759 .963 r
.50029 .60433 .5067 .60971 .51833 .60664 .51195 .60247 Mtetra
.483 .77 .995 r
.51195 .60247 .51833 .60664 .53 .60395 .52366 .60158 Mtetra
.303 .748 .962 r
.52366 .60158 .53 .60395 .54174 .60177 .53545 .60131 Mtetra
.12 .669 .807 r
.53545 .60131 .54174 .60177 .55353 .60011 .5473 .6008 Mtetra
.116 .666 .724 r
.5473 .6008 .55353 .60011 .5654 .59876 .55922 .59917 Mtetra
.316 .805 .837 r
.55922 .59917 .5654 .59876 .57733 .59741 .57118 .59612 Mtetra
.568 .909 .974 r
.57118 .59612 .57733 .59741 .58932 .59571 .58318 .59202 Mtetra
.673 .857 .97 r
.58318 .59202 .58932 .59571 .60136 .59347 .59522 .58749 Mtetra
.683 .778 .922 r
.59522 .58749 .60136 .59347 .61345 .5907 .60731 .58306 Mtetra
.67 .725 .89 r
.60731 .58306 .61345 .5907 .62559 .5875 .61945 .579 Mtetra
.655 .698 .878 r
.61945 .579 .62559 .5875 .63777 .58395 .63166 .57544 Mtetra
.641 .693 .882 r
.63166 .57544 .63777 .58395 .64999 .58007 .64394 .57235 Mtetra
.628 .71 .905 r
.64394 .57235 .64999 .58007 .66225 .57575 .65629 .56966 Mtetra
.614 .757 .947 r
.65629 .56966 .66225 .57575 .67453 .57089 .66871 .56705 Mtetra
.593 .835 .99 r
.66871 .56705 .67453 .57089 .68683 .56547 .68117 .56402 Mtetra
.553 .904 .972 r
.68117 .56402 .68683 .56547 .69915 .55968 .69364 .55991 Mtetra
.531 .922 .888 r
.69364 .55991 .69915 .55968 .71151 .55389 .70608 .55434 Mtetra
.593 .949 .877 r
.70608 .55434 .71151 .55389 .72393 .54841 .7185 .54764 Mtetra
.685 .966 .934 r
.7185 .54764 .72393 .54841 .73642 .54344 .73094 .54068 Mtetra
.719 .917 .961 r
.73094 .54068 .73642 .54344 .749 .53898 .74345 .53432 Mtetra
.702 .843 .95 r
.74345 .53432 .749 .53898 .76165 .53493 .75606 .52896 Mtetra
.678 .79 .934 r
.75606 .52896 .76165 .53493 .77438 .53107 .76879 .52444 Mtetra
.664 .764 .925 r
.76879 .52444 .77438 .53107 .78716 .52729 .7816 .52039 Mtetra
.658 .754 .921 r
.7816 .52039 .78716 .52729 .80001 .52351 .79448 .51653 Mtetra
.656 .752 .92 r
.79448 .51653 .80001 .52351 .81291 .51973 .80742 .5127 Mtetra
.656 .751 .92 r
.80742 .5127 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Mtetra
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Mtetra
.655 .751 .921 r
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61063 Mtetra
.652 .751 .922 r
.44759 .61063 .45416 .61686 .46562 .61349 .45908 .60732 Mtetra
.641 .75 .928 r
.45908 .60732 .46562 .61349 .47713 .61016 .47061 .6043 Mtetra
.605 .751 .947 r
.47061 .6043 .47713 .61016 .48869 .60701 .48219 .60206 Mtetra
.515 .752 .982 r
.48219 .60206 .48869 .60701 .50029 .60433 .49381 .60114 Mtetra
.312 .726 .976 r
.49381 .60114 .50029 .60433 .51195 .60247 .50549 .60144 Mtetra
.081 .634 .818 r
.50549 .60144 .51195 .60247 .52366 .60158 .51725 .60177 Mtetra
.149 .692 .779 r
.51725 .60177 .52366 .60158 .53545 .60131 .52909 .6004 Mtetra
.529 .901 .962 r
.52909 .6004 .53545 .60131 .5473 .6008 .54097 .59656 Mtetra
.719 .843 .941 r
.54097 .59656 .5473 .6008 .55922 .59917 .5529 .59099 Mtetra
.714 .723 .857 r
.5529 .59099 .55922 .59917 .57118 .59612 .56485 .58508 Mtetra
.687 .657 .815 r
.56485 .58508 .57118 .59612 .58318 .59202 .57685 .57971 Mtetra
.667 .629 .802 r
.57685 .57971 .58318 .59202 .59522 .58749 .5889 .57506 Mtetra
.656 .623 .804 r
.5889 .57506 .59522 .58749 .60731 .58306 .60101 .57095 Mtetra
.651 .626 .811 r
.60101 .57095 .60731 .58306 .61945 .579 .61318 .56716 Mtetra
.648 .629 .817 r
.61318 .56716 .61945 .579 .63166 .57544 .62541 .56356 Mtetra
.643 .627 .819 r
.62541 .56356 .63166 .57544 .64394 .57235 .63769 .56016 Mtetra
.635 .619 .816 r
.63769 .56016 .64394 .57235 .65629 .56966 .65005 .55707 Mtetra
.623 .607 .814 r
.65005 .55707 .65629 .56966 .66871 .56705 .66248 .55453 Mtetra
.606 .6 .819 r
.66248 .55453 .66871 .56705 .68117 .56402 .67502 .55271 Mtetra
.591 .614 .843 r
.67502 .55271 .68117 .56402 .69364 .55991 .68764 .55144 Mtetra
.592 .678 .901 r
.68764 .55144 .69364 .55991 .70608 .55434 .70033 .54982 Mtetra
.62 .822 .978 r
.70033 .54982 .70608 .55434 .7185 .54764 .71299 .54644 Mtetra
.645 .946 .955 r
.71299 .54644 .7185 .54764 .73094 .54068 .72556 .54054 Mtetra
.682 .975 .904 r
.72556 .54054 .73094 .54068 .74345 .53432 .73805 .53289 Mtetra
.736 .963 .939 r
.73805 .53289 .74345 .53432 .75606 .52896 .75058 .52525 Mtetra
.728 .888 .953 r
.75058 .52525 .75606 .52896 .76879 .52444 .76323 .51886 Mtetra
.692 .811 .939 r
.76323 .51886 .76879 .52444 .7816 .52039 .77601 .51382 Mtetra
.668 .77 .927 r
.77601 .51382 .7816 .52039 .79448 .51653 .78891 .50957 Mtetra
.659 .756 .922 r
.78891 .50957 .79448 .51653 .80742 .5127 .80189 .50562 Mtetra
.656 .752 .921 r
.80189 .50562 .80742 .5127 .82043 .50886 .81493 .50174 Mtetra
.656 .751 .92 r
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Mtetra
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Mtetra
.655 .751 .921 r
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60774 Mtetra
.652 .751 .922 r
.42948 .60774 .43614 .614 .44759 .61063 .44096 .60443 Mtetra
.638 .75 .929 r
.44096 .60443 .44759 .61063 .45908 .60732 .45247 .60147 Mtetra
.59 .747 .952 r
.45247 .60147 .45908 .60732 .47061 .6043 .46402 .59953 Mtetra
.456 .736 .988 r
.46402 .59953 .47061 .6043 .48219 .60206 .4756 .59932 Mtetra
.17 .657 .924 r
.4756 .59932 .48219 .60206 .49381 .60114 .48724 .60047 Mtetra
.031 .599 .769 r
.48724 .60047 .49381 .60114 .50549 .60144 .49896 .60085 Mtetra
.39 .84 .924 r
.49896 .60085 .50549 .60144 .51725 .60177 .51078 .5982 Mtetra
.719 .867 .951 r
.51078 .5982 .51725 .60177 .52909 .6004 .52266 .59256 Mtetra
.73 .735 .855 r
.52266 .59256 .52909 .6004 .54097 .59656 .53457 .58599 Mtetra
.697 .669 .818 r
.53457 .58599 .54097 .59656 .5529 .59099 .54651 .58019 Mtetra
.676 .657 .824 r
.54651 .58019 .5529 .59099 .56485 .58508 .5585 .57543 Mtetra
.667 .676 .849 r
.5585 .57543 .56485 .58508 .57685 .57971 .57054 .57127 Mtetra
.665 .703 .876 r
.57054 .57127 .57685 .57971 .5889 .57506 .58264 .56733 Mtetra
.663 .722 .893 r
.58264 .56733 .5889 .57506 .60101 .57095 .59479 .56349 Mtetra
.66 .729 .901 r
.59479 .56349 .60101 .57095 .61318 .56716 .60699 .55975 Mtetra
.656 .73 .904 r
.60699 .55975 .61318 .56716 .62541 .56356 .61925 .55612 Mtetra
.652 .729 .906 r
.61925 .55612 .62541 .56356 .63769 .56016 .63157 .55261 Mtetra
.648 .725 .905 r
.63157 .55261 .63769 .56016 .65005 .55707 .64395 .5492 Mtetra
.645 .716 .899 r
.64395 .5492 .65005 .55707 .66248 .55453 .65638 .54588 Mtetra
.639 .694 .885 r
.65638 .54588 .66248 .55453 .67502 .55271 .66889 .54279 Mtetra
.622 .657 .864 r
.66889 .54279 .67502 .55271 .68764 .55144 .68148 .5403 Mtetra
.594 .621 .848 r
.68148 .5403 .68764 .55144 .70033 .54982 .6942 .53886 Mtetra
.571 .614 .856 r
.6942 .53886 .70033 .54982 .71299 .54644 .70703 .53821 Mtetra
.588 .686 .91 r
.70703 .53821 .71299 .54644 .72556 .54054 .71989 .53659 Mtetra
.665 .862 .975 r
.71989 .53659 .72556 .54054 .73805 .53289 .73263 .53191 Mtetra
.724 .972 .929 r
.73263 .53191 .73805 .53289 .75058 .52525 .74522 .52413 Mtetra
.76 .976 .92 r
.74522 .52413 .75058 .52525 .76323 .51886 .75778 .51556 Mtetra
.75 .909 .947 r
.75778 .51556 .76323 .51886 .77601 .51382 .77047 .50836 Mtetra
.702 .821 .939 r
.77047 .50836 .77601 .51382 .78891 .50957 .78332 .50295 Mtetra
.67 .773 .927 r
.78332 .50295 .78891 .50957 .80189 .50562 .79631 .49857 Mtetra
.659 .756 .922 r
.79631 .49857 .80189 .50562 .81493 .50174 .80939 .49457 Mtetra
.656 .752 .92 r
.80939 .49457 .81493 .50174 .82803 .49785 .82254 .49064 Mtetra
.656 .751 .92 r
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Mtetra
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Mtetra
.655 .751 .92 r
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60485 Mtetra
.653 .751 .922 r
.41132 .60485 .41806 .61113 .42948 .60774 .42277 .60149 Mtetra
.64 .749 .928 r
.42277 .60149 .42948 .60774 .44096 .60443 .43426 .59847 Mtetra
.591 .745 .95 r
.43426 .59847 .44096 .60443 .45247 .60147 .44579 .59652 Mtetra
.437 .722 .985 r
.44579 .59652 .45247 .60147 .46402 .59953 .45733 .59663 Mtetra
.1 .606 .896 r
.45733 .59663 .46402 .59953 .4756 .59932 .46891 .59845 Mtetra
.003 .576 .763 r
.46891 .59845 .4756 .59932 .48724 .60047 .4806 .59922 Mtetra
.497 .878 .971 r
.4806 .59922 .48724 .60047 .49896 .60085 .4924 .59607 Mtetra
.747 .827 .913 r
.4924 .59607 .49896 .60085 .51078 .5982 .50428 .58954 Mtetra
.733 .717 .836 r
.50428 .58954 .51078 .5982 .52266 .59256 .51619 .58247 Mtetra
.703 .68 .825 r
.51619 .58247 .52266 .59256 .53457 .58599 .52812 .5765 Mtetra
.688 .687 .844 r
.52812 .5765 .53457 .58599 .54651 .58019 .5401 .57147 Mtetra
.68 .702 .863 r
.5401 .57147 .54651 .58019 .5585 .57543 .55212 .56689 Mtetra
.673 .705 .871 r
.55212 .56689 .5585 .57543 .57054 .57127 .56419 .56261 Mtetra
.666 .7 .872 r
.56419 .56261 .57054 .57127 .58264 .56733 .57632 .55859 Mtetra
.661 .697 .873 r
.57632 .55859 .58264 .56733 .59479 .56349 .58849 .55476 Mtetra
.657 .696 .875 r
.58849 .55476 .59479 .56349 .60699 .55975 .60073 .55104 Mtetra
.655 .697 .877 r
.60073 .55104 .60699 .55975 .61925 .55612 .61301 .54738 Mtetra
.653 .696 .877 r
.61301 .54738 .61925 .55612 .63157 .55261 .62536 .54379 Mtetra
.649 .694 .878 r
.62536 .54379 .63157 .55261 .64395 .5492 .63776 .54031 Mtetra
.643 .69 .879 r
.63776 .54031 .64395 .5492 .65638 .54588 .65023 .53702 Mtetra
.636 .689 .882 r
.65023 .53702 .65638 .54588 .66889 .54279 .66277 .53399 Mtetra
.627 .687 .887 r
.66277 .53399 .66889 .54279 .68148 .5403 .67539 .53126 Mtetra
.612 .676 .886 r
.67539 .53126 .68148 .5403 .6942 .53886 .68809 .52899 Mtetra
.586 .645 .876 r
.68809 .52899 .6942 .53886 .70703 .53821 .70091 .52767 Mtetra
.554 .616 .869 r
.70091 .52767 .70703 .53821 .71989 .53659 .71387 .52745 Mtetra
.562 .653 .897 r
.71387 .52745 .71989 .53659 .73263 .53191 .72688 .52668 Mtetra
.66 .815 .958 r
.72688 .52668 .73263 .53191 .74522 .52413 .73975 .52244 Mtetra
.761 .962 .932 r
.73975 .52244 .74522 .52413 .75778 .51556 .75241 .51418 Mtetra
.79 .974 .911 r
.75241 .51418 .75778 .51556 .77047 .50836 .76501 .50483 Mtetra
.762 .906 .94 r
.76501 .50483 .77047 .50836 .78332 .50295 .77776 .49724 Mtetra
.702 .816 .935 r
.77776 .49724 .78332 .50295 .79631 .49857 .79071 .49177 Mtetra
.669 .769 .925 r
.79071 .49177 .79631 .49857 .80939 .49457 .80381 .4874 Mtetra
.658 .755 .921 r
.80381 .4874 .80939 .49457 .82254 .49064 .81699 .48337 Mtetra
.656 .752 .92 r
.81699 .48337 .82254 .49064 .83574 .4867 .83024 .47939 Mtetra
.656 .751 .92 r
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Mtetra
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60194 Mtetra
.654 .751 .921 r
.39308 .60194 .39991 .60825 .41132 .60485 .40452 .59854 Mtetra
.646 .75 .925 r
.40452 .59854 .41132 .60485 .42277 .60149 .416 .59535 Mtetra
.607 .745 .942 r
.416 .59535 .42277 .60149 .43426 .59847 .4275 .59308 Mtetra
.469 .72 .979 r
.4275 .59308 .43426 .59847 .44579 .59652 .43901 .59296 Mtetra
.105 .588 .908 r
.43901 .59296 .44579 .59652 .45733 .59663 .45053 .59527 Mtetra
0 .495 .729 r
.45053 .59527 .45733 .59663 .46891 .59845 .46216 .59719 Mtetra
.433 .849 .962 r
.46216 .59719 .46891 .59845 .4806 .59922 .47393 .59471 Mtetra
.759 .837 .911 r
.47393 .59471 .4806 .59922 .4924 .59607 .48582 .58774 Mtetra
.752 .73 .832 r
.48582 .58774 .4924 .59607 .50428 .58954 .49774 .57973 Mtetra
.719 .692 .823 r
.49774 .57973 .50428 .58954 .51619 .58247 .50968 .57297 Mtetra
.696 .69 .841 r
.50968 .57297 .51619 .58247 .52812 .5765 .52164 .56756 Mtetra
.678 .697 .86 r
.52164 .56756 .52812 .5765 .5401 .57147 .53365 .56305 Mtetra
.666 .706 .877 r
.53365 .56305 .5401 .57147 .55212 .56689 .5457 .55906 Mtetra
.66 .72 .893 r
.5457 .55906 .55212 .56689 .56419 .56261 .55781 .55528 Mtetra
.659 .734 .905 r
.55781 .55528 .56419 .56261 .57632 .55859 .56997 .55155 Mtetra
.658 .743 .913 r
.56997 .55155 .57632 .55859 .58849 .55476 .58219 .54781 Mtetra
.657 .746 .916 r
.58219 .54781 .58849 .55476 .60073 .55104 .59445 .54408 Mtetra
.655 .747 .917 r
.59445 .54408 .60073 .55104 .61301 .54738 .60678 .5404 Mtetra
.653 .746 .918 r
.60678 .5404 .61301 .54738 .62536 .54379 .61916 .53675 Mtetra
.652 .745 .918 r
.61916 .53675 .62536 .54379 .63776 .54031 .63159 .53313 Mtetra
.652 .742 .915 r
.63159 .53313 .63776 .54031 .65023 .53702 .64409 .52949 Mtetra
.651 .732 .908 r
.64409 .52949 .65023 .53702 .66277 .53399 .65664 .52589 Mtetra
.644 .714 .898 r
.65664 .52589 .66277 .53399 .67539 .53126 .66926 .52251 Mtetra
.629 .692 .89 r
.66926 .52251 .67539 .53126 .68809 .52899 .68197 .51966 Mtetra
.602 .666 .885 r
.68197 .51966 .68809 .52899 .70091 .52767 .69478 .51772 Mtetra
.56 .633 .881 r
.69478 .51772 .70091 .52767 .71387 .52745 .70775 .51714 Mtetra
.52 .606 .879 r
.70775 .51714 .71387 .52745 .72688 .52668 .72087 .51783 Mtetra
.544 .654 .907 r
.72087 .51783 .72688 .52668 .73975 .52244 .73402 .51744 Mtetra
.684 .834 .955 r
.73402 .51744 .73975 .52244 .75241 .51418 .74695 .51243 Mtetra
.8 .965 .912 r
.74695 .51243 .75241 .51418 .76501 .50483 .75961 .5029 Mtetra
.813 .962 .906 r
.75961 .5029 .76501 .50483 .77776 .49724 .77226 .49297 Mtetra
.758 .881 .935 r
.77226 .49297 .77776 .49724 .79071 .49177 .78512 .48554 Mtetra
.693 .798 .93 r
.78512 .48554 .79071 .49177 .80381 .4874 .79819 .48034 Mtetra
.664 .762 .923 r
.79819 .48034 .80381 .4874 .81699 .48337 .8114 .47607 Mtetra
.657 .753 .921 r
.8114 .47607 .81699 .48337 .83024 .47939 .82469 .47202 Mtetra
.656 .752 .92 r
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Mtetra
.656 .751 .92 r
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Mtetra
.655 .751 .92 r
.37479 .59902 .38169 .60536 .39308 .60194 .3862 .59558 Mtetra
.651 .751 .922 r
.3862 .59558 .39308 .60194 .40452 .59854 .39767 .59224 Mtetra
.628 .747 .933 r
.39767 .59224 .40452 .59854 .416 .59535 .40916 .58947 Mtetra
.533 .729 .964 r
.40916 .58947 .416 .59535 .4275 .59308 .42065 .58854 Mtetra
.21 .621 .951 r
.42065 .58854 .4275 .59308 .43901 .59296 .43213 .59069 Mtetra
0 .398 .699 r
.43213 .59069 .43901 .59296 .45053 .59527 .44366 .59419 Mtetra
.16 .69 .859 r
.44366 .59419 .45053 .59527 .46216 .59719 .45537 .59391 Mtetra
.746 .879 .94 r
.45537 .59391 .46216 .59719 .47393 .59471 .46725 .5874 Mtetra
.78 .758 .833 r
.46725 .5874 .47393 .59471 .48582 .58774 .47921 .57814 Mtetra
.741 .703 .815 r
.47921 .57814 .48582 .58774 .49774 .57973 .49116 .57012 Mtetra
.705 .692 .835 r
.49116 .57012 .49774 .57973 .50968 .57297 .50312 .56419 Mtetra
.681 .702 .863 r
.50312 .56419 .50968 .57297 .52164 .56756 .51511 .55956 Mtetra
.672 .719 .884 r
.51511 .55956 .52164 .56756 .53365 .56305 .52715 .55537 Mtetra
.669 .728 .893 r
.52715 .55537 .53365 .56305 .5457 .55906 .53923 .55128 Mtetra
.667 .725 .893 r
.53923 .55128 .5457 .55906 .55781 .55528 .55137 .54726 Mtetra
.662 .718 .89 r
.55137 .54726 .55781 .55528 .56997 .55155 .56356 .54337 Mtetra
.659 .713 .888 r
.56356 .54337 .56997 .55155 .58219 .54781 .57581 .53957 Mtetra
.657 .712 .888 r
.57581 .53957 .58219 .54781 .59445 .54408 .58811 .53583 Mtetra
.656 .712 .889 r
.58811 .53583 .59445 .54408 .60678 .5404 .60046 .53212 Mtetra
.654 .711 .89 r
.60046 .53212 .60678 .5404 .61916 .53675 .61287 .52843 Mtetra
.652 .71 .89 r
.61287 .52843 .61916 .53675 .63159 .53313 .62534 .52479 Mtetra
.649 .71 .892 r
.62534 .52479 .63159 .53313 .64409 .52949 .63787 .52127 Mtetra
.645 .712 .896 r
.63787 .52127 .64409 .52949 .65664 .52589 .65047 .51786 Mtetra
.642 .717 .902 r
.65047 .51786 .65664 .52589 .66926 .52251 .66312 .51452 Mtetra
.638 .717 .905 r
.66312 .51452 .66926 .52251 .68197 .51966 .67585 .51128 Mtetra
.624 .702 .901 r
.67585 .51128 .68197 .51966 .69478 .51772 .68865 .50849 Mtetra
.585 .664 .893 r
.68865 .50849 .69478 .51772 .70775 .51714 .7016 .50701 Mtetra
.518 .61 .884 r
.7016 .50701 .70775 .51714 .72087 .51783 .71474 .50766 Mtetra
.471 .585 .887 r
.71474 .50766 .72087 .51783 .73402 .51744 .72806 .50955 Mtetra
.552 .688 .93 r
.72806 .50955 .73402 .51744 .74695 .51243 .74129 .50861 Mtetra
.753 .896 .942 r
.74129 .50861 .74695 .51243 .75961 .5029 .75417 .50127 Mtetra
.841 .969 .882 r
.75417 .50127 .75961 .5029 .77226 .49297 .7668 .49003 Mtetra
.817 .934 .908 r
.7668 .49003 .77226 .49297 .78512 .48554 .77954 .48019 Mtetra
.735 .842 .93 r
.77954 .48019 .78512 .48554 .79819 .48034 .79256 .47353 Mtetra
.678 .777 .925 r
.79256 .47353 .79819 .48034 .8114 .47607 .80577 .46877 Mtetra
.66 .756 .921 r
.80577 .46877 .8114 .47607 .82469 .47202 .8191 .4646 Mtetra
.656 .752 .92 r
.8191 .4646 .82469 .47202 .83804 .468 .83249 .46053 Mtetra
.656 .751 .92 r
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Mtetra
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44825 Mtetra
.87306 .44825 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Mtetra
.654 .751 .921 r
.36782 .59263 .37479 .59902 .3862 .59558 .37927 .58919 Mtetra
.645 .749 .925 r
.37927 .58919 .3862 .59558 .39767 .59224 .39076 .58599 Mtetra
.595 .74 .945 r
.39076 .58599 .39767 .59224 .40916 .58947 .40225 .58395 Mtetra
.39 .682 .976 r
.40225 .58395 .40916 .58947 .42065 .58854 .41371 .58485 Mtetra
0 .407 .774 r
.41371 .58485 .42065 .58854 .43213 .59069 .42516 .58917 Mtetra
.233 0 0 r
.42516 .58917 .43213 .59069 .44366 .59419 .43673 .59241 Mtetra
.582 .897 .986 r
.43673 .59241 .44366 .59419 .45537 .59391 .44855 .58857 Mtetra
.81 .812 .852 r
.44855 .58857 .45537 .59391 .46725 .5874 .46055 .57858 Mtetra
.778 .727 .805 r
.46055 .57858 .46725 .5874 .47921 .57814 .47255 .56841 Mtetra
.73 .698 .82 r
.47255 .56841 .47921 .57814 .49116 .57012 .48453 .56106 Mtetra
.694 .701 .852 r
.48453 .56106 .49116 .57012 .50312 .56419 .49651 .55581 Mtetra
.676 .711 .875 r
.49651 .55581 .50312 .56419 .51511 .55956 .50853 .55144 Mtetra
.665 .715 .886 r
.50853 .55144 .51511 .55956 .52715 .55537 .5206 .54745 Mtetra
.658 .719 .894 r
.5206 .54745 .52715 .55537 .53923 .55128 .53272 .54371 Mtetra
.655 .728 .903 r
.53272 .54371 .53923 .55128 .55137 .54726 .54489 .54006 Mtetra
.655 .74 .912 r
.54489 .54006 .55137 .54726 .56356 .54337 .55712 .53638 Mtetra
.656 .747 .917 r
.55712 .53638 .56356 .54337 .57581 .53957 .5694 .53266 Mtetra
.656 .751 .92 r
.5694 .53266 .57581 .53957 .58811 .53583 .58174 .52892 Mtetra
.655 .751 .921 r
.58174 .52892 .58811 .53583 .60046 .53212 .59413 .52517 Mtetra
.654 .751 .921 r
.59413 .52517 .60046 .53212 .61287 .52843 .60658 .52143 Mtetra
.655 .75 .92 r
.60658 .52143 .61287 .52843 .62534 .52479 .61908 .51767 Mtetra
.656 .748 .917 r
.61908 .51767 .62534 .52479 .63787 .52127 .63164 .51385 Mtetra
.656 .74 .911 r
.63164 .51385 .63787 .52127 .65047 .51786 .64426 .51001 Mtetra
.653 .728 .904 r
.64426 .51001 .65047 .51786 .66312 .51452 .65693 .50627 Mtetra
.646 .715 .898 r
.65693 .50627 .66312 .51452 .67585 .51128 .66968 .50276 Mtetra
.633 .704 .897 r
.66968 .50276 .67585 .51128 .68865 .50849 .68251 .49966 Mtetra
.606 .685 .898 r
.68251 .49966 .68865 .50849 .7016 .50701 .69544 .49743 Mtetra
.537 .635 .895 r
.69544 .49743 .7016 .50701 .71474 .50766 .70857 .49734 Mtetra
.435 .564 .886 r
.70857 .49734 .71474 .50766 .72806 .50955 .72196 .50012 Mtetra
.426 .582 .904 r
.72196 .50012 .72806 .50955 .74129 .50861 .73545 .50269 Mtetra
.641 .792 .955 r
.73545 .50269 .74129 .50861 .75417 .50127 .74862 .49892 Mtetra
.841 .95 .889 r
.74862 .49892 .75417 .50127 .7668 .49003 .76134 .48787 Mtetra
.862 .954 .869 r
.76134 .48787 .7668 .49003 .77954 .48019 .77398 .47571 Mtetra
.787 .883 .916 r
.77398 .47571 .77954 .48019 .79256 .47353 .7869 .46709 Mtetra
.701 .799 .925 r
.7869 .46709 .79256 .47353 .80577 .46877 .8001 .46151 Mtetra
.665 .761 .922 r
.8001 .46151 .80577 .46877 .8191 .4646 .81346 .45713 Mtetra
.657 .753 .921 r
.81346 .45713 .8191 .4646 .83249 .46053 .82689 .453 Mtetra
.656 .751 .92 r
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Mtetra
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.85397 .44476 .85948 .45237 .87306 .44825 .8676 .44062 Mtetra
.8676 .44062 .87306 .44825 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58969 Mtetra
.34937 .58969 .35642 .5961 .36782 .59263 .3608 .5862 Mtetra
.653 .751 .922 r
.3608 .5862 .36782 .59263 .37927 .58919 .37228 .58277 Mtetra
.634 .747 .929 r
.37228 .58277 .37927 .58919 .39076 .58599 .38379 .57982 Mtetra
.542 .725 .959 r
.38379 .57982 .39076 .58599 .40225 .58395 .39527 .57878 Mtetra
.154 .566 .93 r
.39527 .57878 .40225 .58395 .41371 .58485 .40668 .58182 Mtetra
.393 0 0 r
.40668 .58182 .41371 .58485 .42516 .58917 .4181 .58789 Mtetra
0 .498 .723 r
.4181 .58789 .42516 .58917 .43673 .59241 .42974 .58968 Mtetra
.783 .899 .924 r
.42974 .58968 .43673 .59241 .44855 .58857 .44172 .58182 Mtetra
.827 .775 .803 r
.44172 .58182 .44855 .58857 .46055 .57858 .45381 .56913 Mtetra
.775 .716 .797 r
.45381 .56913 .46055 .57858 .47255 .56841 .46585 .5588 Mtetra
.717 .697 .83 r
.46585 .5588 .47255 .56841 .48453 .56106 .47785 .55221 Mtetra
.679 .702 .865 r
.47785 .55221 .48453 .56106 .49651 .55581 .48986 .54764 Mtetra
.662 .714 .886 r
.48986 .54764 .49651 .55581 .50853 .55144 .5019 .54374 Mtetra
.66 .726 .898 r
.5019 .54374 .50853 .55144 .5206 .54745 .514 .53993 Mtetra
.662 .733 .902 r
.514 .53993 .5206 .54745 .53272 .54371 .52616 .53604 Mtetra
.662 .729 .9 r
.52616 .53604 .53272 .54371 .54489 .54006 .53836 .53213 Mtetra
.66 .722 .895 r
.53836 .53213 .54489 .54006 .55712 .53638 .55062 .52827 Mtetra
.657 .718 .893 r
.55062 .52827 .55712 .53638 .5694 .53266 .56293 .52447 Mtetra
.656 .716 .892 r
.56293 .52447 .5694 .53266 .58174 .52892 .5753 .5207 Mtetra
.656 .716 .893 r
.5753 .5207 .58174 .52892 .59413 .52517 .58772 .51693 Mtetra
.655 .716 .893 r
.58772 .51693 .59413 .52517 .60658 .52143 .6002 .51315 Mtetra
.654 .716 .893 r
.6002 .51315 .60658 .52143 .61908 .51767 .61274 .5094 Mtetra
.651 .716 .895 r
.61274 .5094 .61908 .51767 .63164 .51385 .62534 .50572 Mtetra
.65 .72 .9 r
.62534 .50572 .63164 .51385 .64426 .51001 .638 .50208 Mtetra
.65 .726 .905 r
.638 .50208 .64426 .51001 .65693 .50627 .65071 .49842 Mtetra
.651 .73 .907 r
.65071 .49842 .65693 .50627 .66968 .50276 .66349 .49468 Mtetra
.648 .723 .903 r
.66349 .49468 .66968 .50276 .68251 .49966 .67632 .49103 Mtetra
.628 .701 .898 r
.67632 .49103 .68251 .49966 .69544 .49743 .68926 .48806 Mtetra
.563 .654 .897 r
.68926 .48806 .69544 .49743 .70857 .49734 .70237 .48714 Mtetra
.425 .563 .889 r
.70237 .48714 .70857 .49734 .72196 .50012 .71578 .49004 Mtetra
.311 .5 .882 r
.71578 .49004 .72196 .50012 .73545 .50269 .72946 .49532 Mtetra
.483 .676 .95 r
.72946 .49532 .73545 .50269 .74862 .49892 .74295 .49561 Mtetra
.811 .923 .911 r
.74295 .49561 .74862 .49892 .76134 .48787 .75584 .48596 Mtetra
.891 .954 .837 r
.75584 .48596 .76134 .48787 .77398 .47571 .76842 .47191 Mtetra
.837 .91 .886 r
.76842 .47191 .77398 .47571 .7869 .46709 .78123 .461 Mtetra
.732 .821 .92 r
.78123 .461 .7869 .46709 .8001 .46151 .79439 .45432 Mtetra
.674 .768 .922 r
.79439 .45432 .8001 .46151 .81346 .45713 .80777 .44962 Mtetra
.658 .754 .921 r
.80777 .44962 .81346 .45713 .82689 .453 .82125 .44541 Mtetra
.656 .752 .92 r
.82125 .44541 .82689 .453 .8404 .44889 .8348 .44126 Mtetra
.656 .751 .92 r
.8348 .44126 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.33086 .58673 .33799 .59317 .34937 .58969 .34227 .58322 Mtetra
.655 .751 .92 r
.34227 .58322 .34937 .58969 .3608 .5862 .35373 .57971 Mtetra
.651 .75 .922 r
.35373 .57971 .3608 .5862 .37228 .58277 .36523 .57631 Mtetra
.62 .743 .935 r
.36523 .57631 .37228 .58277 .38379 .57982 .37675 .57369 Mtetra
.464 .696 .968 r
.37675 .57369 .38379 .57982 .39527 .57878 .38822 .57385 Mtetra
0 .372 .788 r
.38822 .57385 .39527 .57878 .40668 .58182 .39957 .57916 Mtetra
.531 0 0 r
.39957 .57916 .40668 .58182 .4181 .58789 .41096 .58663 Mtetra
.18 .701 .875 r
.41096 .58663 .4181 .58789 .42974 .58968 .42271 .5863 Mtetra
.854 .863 .847 r
.42271 .5863 .42974 .58968 .44172 .58182 .43484 .57433 Mtetra
.839 .76 .776 r
.43484 .57433 .44172 .58182 .45381 .56913 .44704 .55943 Mtetra
.77 .711 .797 r
.44704 .55943 .45381 .56913 .46585 .5588 .45911 .54928 Mtetra
.701 .695 .842 r
.45911 .54928 .46585 .5588 .47785 .55221 .47112 .54355 Mtetra
.665 .703 .875 r
.47112 .54355 .47785 .55221 .48986 .54764 .48315 .53949 Mtetra
.658 .714 .89 r
.48315 .53949 .48986 .54764 .5019 .54374 .49523 .53572 Mtetra
.655 .717 .894 r
.49523 .53572 .5019 .54374 .514 .53993 .50736 .53204 Mtetra
.651 .721 .899 r
.50736 .53204 .514 .53993 .52616 .53604 .51954 .52847 Mtetra
.65 .73 .907 r
.51954 .52847 .52616 .53604 .53836 .53213 .53178 .52491 Mtetra
.651 .741 .916 r
.53178 .52491 .53836 .53213 .55062 .52827 .54407 .52128 Mtetra
.653 .75 .921 r
.54407 .52128 .55062 .52827 .56293 .52447 .55642 .51756 Mtetra
.654 .753 .923 r
.55642 .51756 .56293 .52447 .5753 .5207 .56883 .51379 Mtetra
.655 .754 .923 r
.56883 .51379 .5753 .5207 .58772 .51693 .58129 .50998 Mtetra
.655 .755 .923 r
.58129 .50998 .58772 .51693 .6002 .51315 .59381 .50615 Mtetra
.657 .754 .922 r
.59381 .50615 .6002 .51315 .61274 .5094 .60638 .50225 Mtetra
.659 .752 .919 r
.60638 .50225 .61274 .5094 .62534 .50572 .61901 .49827 Mtetra
.661 .744 .912 r
.61901 .49827 .62534 .50572 .638 .50208 .63169 .49422 Mtetra
.66 .733 .904 r
.63169 .49422 .638 .50208 .65071 .49842 .64443 .49019 Mtetra
.656 .723 .898 r
.64443 .49019 .65071 .49842 .66349 .49468 .65723 .48625 Mtetra
.653 .717 .895 r
.65723 .48625 .66349 .49468 .67632 .49103 .6701 .48242 Mtetra
.644 .71 .895 r
.6701 .48242 .67632 .49103 .68926 .48806 .68304 .47887 Mtetra
.592 .674 .897 r
.68304 .47887 .68926 .48806 .70237 .48714 .69613 .47702 Mtetra
.431 .57 .892 r
.69613 .47702 .70237 .48714 .71578 .49004 .70955 .47967 Mtetra
.201 .427 .856 r
.70955 .47967 .71578 .49004 .72946 .49532 .72338 .48717 Mtetra
.277 .538 .918 r
.72338 .48717 .72946 .49532 .74295 .49561 .73717 .49163 Mtetra
.755 .896 .941 r
.73717 .49163 .74295 .49561 .75584 .48596 .75027 .48407 Mtetra
.91 .947 .813 r
.75027 .48407 .75584 .48596 .76842 .47191 .76283 .46849 Mtetra
.878 .918 .849 r
.76283 .46849 .76842 .47191 .78123 .461 .77553 .45516 Mtetra
.765 .839 .908 r
.77553 .45516 .78123 .461 .79439 .45432 .78864 .44716 Mtetra
.684 .775 .92 r
.78864 .44716 .79439 .45432 .80777 .44962 .80203 .44206 Mtetra
.66 .755 .92 r
.80203 .44206 .80777 .44962 .82125 .44541 .81555 .43775 Mtetra
.656 .752 .92 r
.81555 .43775 .82125 .44541 .8348 .44126 .82914 .43356 Mtetra
.656 .751 .92 r
.82914 .43356 .8348 .44126 .84841 .43709 .8428 .42936 Mtetra
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .57671 Mtetra
.655 .751 .921 r
.33511 .57671 .34227 .58322 .35373 .57971 .3466 .57317 Mtetra
.648 .75 .923 r
.3466 .57317 .35373 .57971 .36523 .57631 .35813 .56981 Mtetra
.604 .739 .94 r
.35813 .56981 .36523 .57631 .37675 .57369 .36966 .56754 Mtetra
.365 .651 .966 r
.36966 .56754 .37675 .57369 .38822 .57385 .3811 .56897 Mtetra
0 .158 .591 r
.3811 .56897 .38822 .57385 .39957 .57916 .39237 .57661 Mtetra
.612 .045 0 r
.39237 .57661 .39957 .57916 .41096 .58663 .40374 .58538 Mtetra
.442 .854 .962 r
.40374 .58538 .41096 .58663 .42271 .5863 .4156 .58273 Mtetra
.888 .841 .792 r
.4156 .58273 .42271 .5863 .43484 .57433 .42792 .56661 Mtetra
.851 .756 .757 r
.42792 .56661 .43484 .57433 .44704 .55943 .44022 .54962 Mtetra
.766 .71 .799 r
.44022 .54962 .44704 .55943 .45911 .54928 .45232 .5397 Mtetra
.683 .689 .85 r
.45232 .5397 .45911 .54928 .47112 .54355 .46435 .53478 Mtetra
.647 .696 .881 r
.46435 .53478 .47112 .54355 .48315 .53949 .47639 .53133 Mtetra
.644 .711 .896 r
.47639 .53133 .48315 .53949 .49523 .53572 .4885 .528 Mtetra
.649 .725 .904 r
.4885 .528 .49523 .53572 .50736 .53204 .50066 .52446 Mtetra
.656 .732 .906 r
.50066 .52446 .50736 .53204 .51954 .52847 .51287 .52071 Mtetra
.658 .729 .902 r
.51287 .52071 .51954 .52847 .53178 .52491 .52514 .51685 Mtetra
.657 .722 .896 r
.52514 .51685 .53178 .52491 .54407 .52128 .53747 .513 Mtetra
.656 .716 .893 r
.53747 .513 .54407 .52128 .55642 .51756 .54985 .50919 Mtetra
.655 .714 .892 r
.54985 .50919 .55642 .51756 .56883 .51379 .56229 .50538 Mtetra
.655 .714 .891 r
.56229 .50538 .56883 .51379 .58129 .50998 .57478 .50154 Mtetra
.57478 .50154 .58129 .50998 .59381 .50615 .58733 .49768 Mtetra
.655 .714 .892 r
.58733 .49768 .59381 .50615 .60638 .50225 .59994 .49383 Mtetra
.653 .716 .894 r
.59994 .49383 .60638 .50225 .61901 .49827 .61261 .49001 Mtetra
.653 .721 .898 r
.61261 .49001 .61901 .49827 .63169 .49422 .62533 .4862 Mtetra
.656 .729 .903 r
.62533 .4862 .63169 .49422 .64443 .49019 .63811 .48228 Mtetra
.662 .735 .904 r
.63811 .48228 .64443 .49019 .65723 .48625 .65095 .47813 Mtetra
.667 .732 .899 r
.65095 .47813 .65723 .48625 .6701 .48242 .66383 .47378 Mtetra
.662 .718 .89 r
.66383 .47378 .6701 .48242 .68304 .47887 .67677 .46955 Mtetra
.618 .684 .889 r
.67677 .46955 .68304 .47887 .69613 .47702 .68985 .46683 Mtetra
.441 .576 .892 r
.68985 .46683 .69613 .47702 .70955 .47967 .70328 .4692 Mtetra
.085 .349 .821 r
.70328 .4692 .70955 .47967 .72338 .48717 .71724 .47879 Mtetra
.02 .363 .834 r
.71724 .47879 .72338 .48717 .73717 .49163 .73132 .48743 Mtetra
.673 .871 .974 r
.73132 .48743 .73717 .49163 .75027 .48407 .74464 .48219 Mtetra
.924 .939 .792 r
.74464 .48219 .75027 .48407 .76283 .46849 .75718 .46517 Mtetra
.908 .912 .812 r
.75718 .46517 .76283 .46849 .77553 .45516 .76977 .44936 Mtetra
.795 .847 .89 r
.76977 .44936 .77553 .45516 .78864 .44716 .78284 .43997 Mtetra
.696 .78 .916 r
.78284 .43997 .78864 .44716 .80203 .44206 .79625 .43444 Mtetra
.662 .756 .92 r
.79625 .43444 .80203 .44206 .81555 .43775 .80981 .43003 Mtetra
.656 .752 .92 r
.80981 .43003 .81555 .43775 .82914 .43356 .82344 .42579 Mtetra
.656 .751 .92 r
.82344 .42579 .82914 .43356 .8428 .42936 .83715 .42155 Mtetra
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.31642 .5737 .32366 .58024 .33511 .57671 .32789 .57014 Mtetra
.655 .751 .921 r
.32789 .57014 .33511 .57671 .3466 .57317 .33941 .56658 Mtetra
.646 .749 .924 r
.33941 .56658 .3466 .57317 .35813 .56981 .35097 .56326 Mtetra
.588 .733 .944 r
.35097 .56326 .35813 .56981 .36966 .56754 .36251 .56131 Mtetra
.257 .593 .949 r
.36251 .56131 .36966 .56754 .3811 .56897 .37391 .56395 Mtetra
.563 .016 0 r
.37391 .56395 .3811 .56897 .39237 .57661 .38511 .57389 Mtetra
.674 .124 0 r
.38511 .57389 .39237 .57661 .40374 .58538 .39643 .58415 Mtetra
.608 .921 .974 r
.39643 .58415 .40374 .58538 .4156 .58273 .40842 .57947 Mtetra
.912 .831 .752 r
.40842 .57947 .4156 .58273 .42792 .56661 .42093 .55919 Mtetra
.868 .76 .742 r
.42093 .55919 .42792 .56661 .44022 .54962 .43335 .53981 Mtetra
.766 .711 .801 r
.43335 .53981 .44022 .54962 .45232 .5397 .44549 .52997 Mtetra
.662 .68 .857 r
.44549 .52997 .45232 .5397 .46435 .53478 .45753 .52589 Mtetra
.631 .688 .886 r
.45753 .52589 .46435 .53478 .47639 .53133 .46959 .52297 Mtetra
.639 .705 .895 r
.46959 .52297 .47639 .53133 .4885 .528 .48172 .51977 Mtetra
.644 .711 .897 r
.48172 .51977 .4885 .528 .50066 .52446 .49391 .5164 Mtetra
.643 .716 .901 r
.49391 .5164 .50066 .52446 .51287 .52071 .50615 .51301 Mtetra
.644 .728 .91 r
.50615 .51301 .51287 .52071 .52514 .51685 .51846 .50958 Mtetra
.647 .742 .919 r
.51846 .50958 .52514 .51685 .53747 .513 .53082 .50602 Mtetra
.65 .752 .924 r
.53082 .50602 .53747 .513 .54985 .50919 .54324 .50232 Mtetra
.653 .758 .927 r
.54324 .50232 .54985 .50919 .56229 .50538 .55571 .49852 Mtetra
.654 .76 .927 r
.55571 .49852 .56229 .50538 .57478 .50154 .56824 .49466 Mtetra
.656 .76 .926 r
.56824 .49466 .57478 .50154 .58733 .49768 .58083 .49072 Mtetra
.659 .76 .924 r
.58083 .49072 .58733 .49768 .59994 .49383 .59348 .48668 Mtetra
.663 .757 .92 r
.59348 .48668 .59994 .49383 .61261 .49001 .60617 .4825 Mtetra
.667 .748 .911 r
.60617 .4825 .61261 .49001 .62533 .4862 .61892 .47819 Mtetra
.667 .735 .901 r
.61892 .47819 .62533 .4862 .63811 .48228 .63173 .47385 Mtetra
.666 .725 .893 r
.63173 .47385 .63811 .48228 .65095 .47813 .64459 .46949 Mtetra
.67 .722 .888 r
.64459 .46949 .65095 .47813 .66383 .47378 .6575 .46495 Mtetra
.677 .72 .882 r
.6575 .46495 .66383 .47378 .67677 .46955 .67046 .46013 Mtetra
.644 .694 .881 r
.67046 .46013 .67677 .46955 .68985 .46683 .68353 .45648 Mtetra
.447 .576 .891 r
.68353 .45648 .68985 .46683 .70328 .4692 .69697 .45872 Mtetra
0 .251 .764 r
.69697 .45872 .70328 .4692 .71724 .47879 .71107 .4707 Mtetra
0 .153 .679 r
.71107 .4707 .71724 .47879 .73132 .48743 .72542 .48355 Mtetra
.565 .846 .997 r
.72542 .48355 .73132 .48743 .74464 .48219 .73894 .48031 Mtetra
.937 .931 .771 r
.73894 .48031 .74464 .48219 .75718 .46517 .75146 .46167 Mtetra
.927 .898 .779 r
.75146 .46167 .75718 .46517 .76977 .44936 .76396 .4434 Mtetra
.818 .847 .87 r
.76396 .4434 .76977 .44936 .78284 .43997 .77698 .43269 Mtetra
.706 .783 .911 r
.77698 .43269 .78284 .43997 .79625 .43444 .79041 .42675 Mtetra
.664 .757 .919 r
.79041 .42675 .79625 .43444 .80981 .43003 .80401 .42223 Mtetra
.657 .752 .92 r
.80401 .42223 .80981 .43003 .82344 .42579 .81769 .41795 Mtetra
.656 .751 .92 r
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Mtetra
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56352 Mtetra
.655 .751 .921 r
.32061 .56352 .32789 .57014 .33941 .56658 .33216 .55994 Mtetra
.644 .748 .925 r
.33216 .55994 .33941 .56658 .35097 .56326 .34375 .55663 Mtetra
.574 .728 .947 r
.34375 .55663 .35097 .56326 .36251 .56131 .3553 .55495 Mtetra
.157 .532 .922 r
.3553 .55495 .36251 .56131 .37391 .56395 .36667 .55863 Mtetra
.665 .136 0 r
.36667 .55863 .37391 .56395 .38511 .57389 .37778 .57072 Mtetra
.726 .196 0 r
.37778 .57072 .38511 .57389 .39643 .58415 .38905 .5828 Mtetra
.686 .936 .966 r
.38905 .5828 .39643 .58415 .40842 .57947 .40113 .57688 Mtetra
.93 .828 .723 r
.40113 .57688 .40842 .57947 .42093 .55919 .41386 .5527 Mtetra
.889 .772 .726 r
.41386 .5527 .42093 .55919 .43335 .53981 .42644 .53035 Mtetra
.775 .72 .801 r
.42644 .53035 .43335 .53981 .44549 .52997 .43863 .51997 Mtetra
.643 .669 .859 r
.43863 .51997 .44549 .52997 .45753 .52589 .45067 .51656 Mtetra
.605 .669 .885 r
.45067 .51656 .45753 .52589 .46959 .52297 .46274 .51441 Mtetra
.618 .694 .898 r
.46274 .51441 .46959 .52297 .48172 .51977 .47489 .51181 Mtetra
.636 .717 .906 r
.47489 .51181 .48172 .51977 .49391 .5164 .4871 .50862 Mtetra
.65 .728 .906 r
.4871 .50862 .49391 .5164 .50615 .51301 .49938 .505 Mtetra
.656 .725 .9 r
.49938 .505 .50615 .51301 .51846 .50958 .51172 .50116 Mtetra
.656 .715 .892 r
.51172 .50116 .51846 .50958 .53082 .50602 .52411 .49729 Mtetra
.654 .707 .886 r
.52411 .49729 .53082 .50602 .54324 .50232 .53656 .49344 Mtetra
.654 .704 .884 r
.53656 .49344 .54324 .50232 .55571 .49852 .54907 .48958 Mtetra
.655 .704 .883 r
.54907 .48958 .55571 .49852 .56824 .49466 .56163 .48568 Mtetra
.56163 .48568 .56824 .49466 .58083 .49072 .57425 .48175 Mtetra
.655 .705 .884 r
.57425 .48175 .58083 .49072 .59348 .48668 .58693 .4778 Mtetra
.654 .708 .887 r
.58693 .4778 .59348 .48668 .60617 .4825 .59966 .47388 Mtetra
.655 .716 .893 r
.59966 .47388 .60617 .4825 .61892 .47819 .61246 .46992 Mtetra
.661 .728 .899 r
.61246 .46992 .61892 .47819 .63173 .47385 .62531 .46574 Mtetra
.673 .737 .899 r
.62531 .46574 .63173 .47385 .64459 .46949 .6382 .46112 Mtetra
.688 .736 .888 r
.6382 .46112 .64459 .46949 .6575 .46495 .65112 .4559 Mtetra
.696 .724 .871 r
.65112 .4559 .6575 .46495 .67046 .46013 .66408 .45023 Mtetra
.661 .692 .868 r
.66408 .45023 .67046 .46013 .68353 .45648 .67715 .44586 Mtetra
.428 .561 .886 r
.67715 .44586 .68353 .45648 .69697 .45872 .69063 .44859 Mtetra
0 .115 .663 r
.69063 .44859 .69697 .45872 .71107 .4707 .70491 .46355 Mtetra
0 0 .468 r
.70491 .46355 .71107 .4707 .72542 .48355 .71951 .48034 Mtetra
.456 .821 .994 r
.71951 .48034 .72542 .48355 .73894 .48031 .73316 .47829 Mtetra
.949 .917 .747 r
.73316 .47829 .73894 .48031 .75146 .46167 .74565 .45768 Mtetra
.937 .878 .752 r
.74565 .45768 .75146 .46167 .76396 .4434 .75807 .43711 Mtetra
.833 .84 .852 r
.75807 .43711 .76396 .4434 .77698 .43269 .77107 .42526 Mtetra
.714 .783 .906 r
.77107 .42526 .77698 .43269 .79041 .42675 .78452 .41898 Mtetra
.666 .757 .918 r
.78452 .41898 .79041 .42675 .80401 .42223 .79816 .41437 Mtetra
.657 .752 .92 r
.79816 .41437 .80401 .42223 .81769 .41795 .81189 .41005 Mtetra
.656 .751 .92 r
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Mtetra
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.30174 .56046 .30911 .56711 .32061 .56352 .31328 .55684 Mtetra
.655 .751 .921 r
.31328 .55684 .32061 .56352 .33216 .55994 .32486 .55324 Mtetra
.643 .748 .925 r
.32486 .55324 .33216 .55994 .34375 .55663 .33647 .54995 Mtetra
.563 .724 .949 r
.33647 .54995 .34375 .55663 .3553 .55495 .34804 .54846 Mtetra
.077 .478 .892 r
.34804 .54846 .3553 .55495 .36667 .55863 .35939 .55295 Mtetra
.724 .211 0 r
.35939 .55295 .36667 .55863 .37778 .57072 .37041 .56682 Mtetra
.766 .256 0 r
.37041 .56682 .37778 .57072 .38905 .5828 .3816 .5809 Mtetra
.699 .924 .967 r
.3816 .5809 .38905 .5828 .40113 .57688 .39374 .57494 Mtetra
.941 .827 .704 r
.39374 .57494 .40113 .57688 .41386 .5527 .40667 .54781 Mtetra
.915 .789 .708 r
.40667 .54781 .41386 .5527 .42644 .53035 .41943 .52195 Mtetra
.804 .746 .799 r
.41943 .52195 .42644 .53035 .43863 .51997 .43171 .51 Mtetra
.637 .668 .863 r
.43171 .51 .43863 .51997 .45067 .51656 .44377 .5068 Mtetra
.586 .652 .882 r
.44377 .5068 .45067 .51656 .46274 .51441 .45585 .50525 Mtetra
.609 .677 .889 r
.45585 .50525 .46274 .51441 .47489 .51181 .46802 .50293 Mtetra
.626 .692 .891 r
.46802 .50293 .47489 .51181 .4871 .50862 .48025 .50005 Mtetra
.631 .702 .897 r
.48025 .50005 .4871 .50862 .49938 .505 .49256 .49701 Mtetra
.634 .72 .909 r
.49256 .49701 .49938 .505 .51172 .50116 .50492 .49383 Mtetra
.64 .741 .922 r
.50492 .49383 .51172 .50116 .52411 .49729 .51735 .49041 Mtetra
.646 .758 .93 r
.51735 .49041 .52411 .49729 .53656 .49344 .52984 .48675 Mtetra
.651 .766 .934 r
.52984 .48675 .53656 .49344 .54907 .48958 .54238 .48292 Mtetra
.653 .769 .934 r
.54238 .48292 .54907 .48958 .56163 .48568 .55498 .479 Mtetra
.657 .77 .933 r
.55498 .479 .56163 .48568 .57425 .48175 .56764 .47496 Mtetra
.662 .77 .93 r
.56764 .47496 .57425 .48175 .58693 .4778 .58036 .47075 Mtetra
.67 .765 .922 r
.58036 .47075 .58693 .4778 .59966 .47388 .59313 .46629 Mtetra
.676 .752 .909 r
.59313 .46629 .59966 .47388 .61246 .46992 .60594 .46161 Mtetra
.678 .734 .893 r
.60594 .46161 .61246 .46992 .62531 .46574 .61881 .45679 Mtetra
.68 .72 .88 r
.61881 .45679 .62531 .46574 .6382 .46112 .63173 .45181 Mtetra
.692 .717 .868 r
.63173 .45181 .6382 .46112 .65112 .4559 .64468 .44625 Mtetra
.707 .715 .855 r
.64468 .44625 .65112 .4559 .66408 .45023 .65764 .43992 Mtetra
.666 .686 .859 r
.65764 .43992 .66408 .45023 .67715 .44586 .67073 .43526 Mtetra
.355 .521 .884 r
.67073 .43526 .67715 .44586 .69063 .44859 .68431 .43954 Mtetra
0 0 .489 r
.68431 .43954 .69063 .44859 .70491 .46355 .69878 .45803 Mtetra
.698 .202 0 r
.69878 .45803 .70491 .46355 .71951 .48034 .71357 .47777 Mtetra
.417 .822 .979 r
.71357 .47777 .71951 .48034 .73316 .47829 .72728 .47568 Mtetra
.956 .895 .727 r
.72728 .47568 .73316 .47829 .74565 .45768 .73972 .45293 Mtetra
.94 .857 .732 r
.73972 .45293 .74565 .45768 .75807 .43711 .7521 .43044 Mtetra
.842 .832 .837 r
.7521 .43044 .75807 .43711 .77107 .42526 .7651 .41769 Mtetra
.72 .783 .902 r
.7651 .41769 .77107 .42526 .78452 .41898 .77858 .41112 Mtetra
.667 .757 .918 r
.77858 .41112 .78452 .41898 .79816 .41437 .79227 .40644 Mtetra
.657 .752 .92 r
.79227 .40644 .79816 .41437 .81189 .41005 .80604 .40208 Mtetra
.656 .751 .92 r
.80604 .40208 .81189 .41005 .82569 .40574 .81989 .39773 Mtetra
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Mtetra
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Mtetra
.654 .751 .921 r
.30588 .55011 .31328 .55684 .32486 .55324 .31749 .54649 Mtetra
.642 .748 .926 r
.31749 .54649 .32486 .55324 .33647 .54995 .32913 .5432 Mtetra
.554 .72 .951 r
.32913 .5432 .33647 .54995 .34804 .54846 .34072 .54188 Mtetra
.015 .435 .866 r
.34072 .54188 .34804 .54846 .35939 .55295 .35205 .54695 Mtetra
.755 .255 0 r
.35205 .54695 .35939 .55295 .37041 .56682 .36301 .56209 Mtetra
.79 .294 0 r
.36301 .56209 .37041 .56682 .3816 .5809 .37412 .57783 Mtetra
.672 .884 .977 r
.37412 .57783 .3816 .5809 .39374 .57494 .38627 .57289 Mtetra
.941 .822 .699 r
.38627 .57289 .39374 .57494 .40667 .54781 .39934 .54474 Mtetra
.936 .807 .693 r
.39934 .54474 .40667 .54781 .41943 .52195 .4123 .51583 Mtetra
.855 .794 .791 r
.4123 .51583 .41943 .52195 .43171 .51 .42472 .50088 Mtetra
.668 .7 .87 r
.42472 .50088 .43171 .51 .44377 .5068 .43684 .49654 Mtetra
.572 .637 .876 r
.43684 .49654 .44377 .5068 .45585 .50525 .44893 .49539 Mtetra
.585 .652 .882 r
.44893 .49539 .45585 .50525 .46802 .50293 .4611 .4938 Mtetra
.627 .687 .887 r
.4611 .4938 .46802 .50293 .48025 .50005 .47336 .49088 Mtetra
.661 .7 .875 r
.47336 .49088 .48025 .50005 .49256 .49701 .48571 .48673 Mtetra
.674 .681 .849 r
.48571 .48673 .49256 .49701 .50492 .49383 .49811 .48189 Mtetra
.669 .65 .822 r
.49811 .48189 .50492 .49383 .51735 .49041 .51056 .47692 Mtetra
.658 .622 .802 r
.51056 .47692 .51735 .49041 .52984 .48675 .52306 .47217 Mtetra
.647 .603 .79 r
.52306 .47217 .52984 .48675 .54238 .48292 .53561 .4678 Mtetra
.637 .592 .786 r
.53561 .4678 .54238 .48292 .55498 .479 .54822 .46382 Mtetra
.629 .588 .788 r
.54822 .46382 .55498 .479 .56764 .47496 .5609 .46027 Mtetra
.623 .591 .797 r
.5609 .46027 .56764 .47496 .58036 .47075 .57364 .45708 Mtetra
.62 .604 .813 r
.57364 .45708 .58036 .47075 .59313 .46629 .58645 .45414 Mtetra
.625 .631 .836 r
.58645 .45414 .59313 .46629 .60594 .46161 .59933 .45106 Mtetra
.645 .671 .86 r
.59933 .45106 .60594 .46161 .61881 .45679 .61225 .44727 Mtetra
.678 .707 .87 r
.61225 .44727 .61881 .45679 .63173 .45181 .6252 .44225 Mtetra
.708 .718 .857 r
.6252 .44225 .63173 .45181 .64468 .44625 .63816 .43588 Mtetra
.712 .703 .841 r
.63816 .43588 .64468 .44625 .65764 .43992 .65114 .42908 Mtetra
.637 .664 .86 r
.65114 .42908 .65764 .43992 .67073 .43526 .66431 .42553 Mtetra
.154 .422 .862 r
.66431 .42553 .67073 .43526 .68431 .43954 .67805 .43281 Mtetra
.704 .229 0 r
.67805 .43281 .68431 .43954 .69878 .45803 .69268 .45436 Mtetra
.766 .267 0 r
.69268 .45436 .69878 .45803 .71357 .47777 .70754 .47508 Mtetra
.503 .862 .989 r
.70754 .47508 .71357 .47777 .72728 .47568 .72126 .47185 Mtetra
.954 .866 .713 r
.72126 .47185 .72728 .47568 .73972 .45293 .73368 .4473 Mtetra
.937 .837 .72 r
.73368 .4473 .73972 .45293 .7521 .43044 .74605 .42343 Mtetra
.847 .825 .826 r
.74605 .42343 .7521 .43044 .7651 .41769 .75907 .41 Mtetra
.724 .783 .899 r
.75907 .41 .7651 .41769 .77858 .41112 .77259 .4032 Mtetra
.668 .757 .917 r
.77259 .4032 .77858 .41112 .79227 .40644 .78632 .39844 Mtetra
.657 .752 .92 r
.78632 .39844 .79227 .40644 .80604 .40208 .80014 .39403 Mtetra
.656 .751 .92 r
.80014 .39403 .80604 .40208 .81989 .39773 .81403 .38964 Mtetra
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Mtetra
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Mtetra
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Mtetra
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Mtetra
.654 .751 .921 r
.29843 .54333 .30588 .55011 .31749 .54649 .31007 .53968 Mtetra
.64 .747 .926 r
.31007 .53968 .31749 .54649 .32913 .5432 .32174 .5364 Mtetra
.545 .717 .952 r
.32174 .5364 .32913 .5432 .34072 .54188 .33334 .53523 Mtetra
0 .398 .841 r
.33334 .53523 .34072 .54188 .35205 .54695 .34465 .54078 Mtetra
.773 .28 0 r
.34465 .54078 .35205 .54695 .36301 .56209 .35556 .5567 Mtetra
.798 .308 0 r
.35556 .5567 .36301 .56209 .37412 .57783 .36663 .5733 Mtetra
.64 .829 .973 r
.36663 .5733 .37412 .57783 .38627 .57289 .37878 .56945 Mtetra
.928 .807 .706 r
.37878 .56945 .38627 .57289 .39934 .54474 .3919 .54237 Mtetra
.942 .814 .689 r
.3919 .54237 .39934 .54474 .4123 .51583 .405 .51258 Mtetra
.906 .846 .774 r
.405 .51258 .4123 .51583 .42472 .50088 .4176 .49434 Mtetra
.765 .789 .873 r
.4176 .49434 .42472 .50088 .43684 .49654 .42985 .48636 Mtetra
.654 .674 .856 r
.42985 .48636 .43684 .49654 .44893 .49539 .44203 .4824 Mtetra
.644 .621 .812 r
.44203 .4824 .44893 .49539 .4611 .4938 .45426 .47847 Mtetra
.649 .593 .778 r
.45426 .47847 .4611 .4938 .47336 .49088 .46656 .47386 Mtetra
.643 .573 .761 r
.46656 .47386 .47336 .49088 .48571 .48673 .47891 .46922 Mtetra
.635 .564 .758 r
.47891 .46922 .48571 .48673 .49811 .48189 .4913 .46497 Mtetra
.63 .568 .766 r
.4913 .46497 .49811 .48189 .51056 .47692 .50375 .46107 Mtetra
.631 .58 .778 r
.50375 .46107 .51056 .47692 .52306 .47217 .51626 .45731 Mtetra
.635 .594 .791 r
.51626 .45731 .52306 .47217 .53561 .4678 .52882 .45348 Mtetra
.64 .604 .797 r
.52882 .45348 .53561 .4678 .54822 .46382 .54144 .44947 Mtetra
.643 .606 .797 r
.54144 .44947 .54822 .46382 .5609 .46027 .55412 .44528 Mtetra
.642 .598 .789 r
.55412 .44528 .5609 .46027 .57364 .45708 .56686 .44101 Mtetra
.636 .582 .777 r
.56686 .44101 .57364 .45708 .58645 .45414 .57965 .43687 Mtetra
.626 .565 .766 r
.57965 .43687 .58645 .45414 .59933 .45106 .59251 .4331 Mtetra
.617 .554 .761 r
.59251 .4331 .59933 .45106 .61225 .44727 .60545 .42976 Mtetra
.618 .56 .766 r
.60545 .42976 .61225 .44727 .6252 .44225 .61845 .42639 Mtetra
.634 .586 .782 r
.61845 .42639 .6252 .44225 .63816 .43588 .6315 .42234 Mtetra
.641 .62 .814 r
.6315 .42234 .63816 .43588 .65114 .42908 .64461 .41833 Mtetra
.525 .615 .884 r
.64461 .41833 .65114 .42908 .66431 .42553 .65795 .41842 Mtetra
0 .207 .708 r
.65795 .41842 .66431 .42553 .67805 .43281 .67187 .42899 Mtetra
.793 .305 0 r
.67187 .42899 .67805 .43281 .69268 .45436 .68655 .45136 Mtetra
.761 .253 0 r
.68655 .45136 .69268 .45436 .70754 .47508 .70138 .47091 Mtetra
.623 .864 .988 r
.70138 .47091 .70754 .47508 .72126 .47185 .71508 .46649 Mtetra
.944 .837 .708 r
.71508 .46649 .72126 .47185 .73368 .4473 .72754 .44098 Mtetra
.934 .824 .712 r
.72754 .44098 .73368 .4473 .74605 .42343 .73994 .41623 Mtetra
.852 .822 .818 r
.73994 .41623 .74605 .42343 .75907 .41 .75298 .40223 Mtetra
.729 .784 .897 r
.75298 .40223 .75907 .41 .77259 .4032 .76654 .39521 Mtetra
.669 .758 .917 r
.76654 .39521 .77259 .4032 .78632 .39844 .78031 .39037 Mtetra
.657 .752 .92 r
.78031 .39037 .78632 .39844 .80014 .39403 .79418 .38592 Mtetra
.656 .751 .92 r
.79418 .38592 .80014 .39403 .81403 .38964 .80812 .38149 Mtetra
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Mtetra
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Mtetra
.654 .751 .921 r
.29091 .53649 .29843 .54333 .31007 .53968 .30258 .53281 Mtetra
.638 .747 .927 r
.30258 .53281 .31007 .53968 .32174 .5364 .31428 .52955 Mtetra
.534 .713 .954 r
.31428 .52955 .32174 .5364 .33334 .53523 .3259 .52855 Mtetra
0 .361 .813 r
.3259 .52855 .33334 .53523 .34465 .54078 .3372 .53456 Mtetra
.785 .297 0 r
.3372 .53456 .34465 .54078 .35556 .5567 .34807 .55099 Mtetra
.792 .302 0 r
.34807 .55099 .35556 .5567 .36663 .5733 .35913 .56758 Mtetra
.647 .793 .952 r
.35913 .56758 .36663 .5733 .37878 .56945 .37131 .56379 Mtetra
.907 .781 .711 r
.37131 .56379 .37878 .56945 .3919 .54237 .38446 .53811 Mtetra
.926 .794 .696 r
.38446 .53811 .3919 .54237 .405 .51258 .39762 .50956 Mtetra
.918 .841 .754 r
.39762 .50956 .405 .51258 .4176 .49434 .41037 .48904 Mtetra
.854 .819 .814 r
.41037 .48904 .4176 .49434 .42985 .48636 .42285 .47533 Mtetra
.744 .691 .8 r
.42285 .47533 .42985 .48636 .44203 .4824 .43519 .46637 Mtetra
.653 .587 .769 r
.43519 .46637 .44203 .4824 .45426 .47847 .44745 .46133 Mtetra
.604 .551 .768 r
.44745 .46133 .45426 .47847 .46656 .47386 .4597 .45884 Mtetra
.587 .566 .798 r
.4597 .45884 .46656 .47386 .47891 .46922 .47201 .45728 Mtetra
.59 .616 .846 r
.47201 .45728 .47891 .46922 .4913 .46497 .48439 .45558 Mtetra
.602 .676 .893 r
.48439 .45558 .4913 .46497 .50375 .46107 .49685 .45331 Mtetra
.618 .727 .923 r
.49685 .45331 .50375 .46107 .51626 .45731 .50939 .45042 Mtetra
.636 .759 .937 r
.50939 .45042 .51626 .45731 .52882 .45348 .52199 .44693 Mtetra
.654 .777 .939 r
.52199 .44693 .52882 .45348 .54144 .44947 .53465 .44288 Mtetra
.672 .782 .932 r
.53465 .44288 .54144 .44947 .55412 .44528 .54737 .43828 Mtetra
.69 .776 .917 r
.54737 .43828 .55412 .44528 .56686 .44101 .56014 .43309 Mtetra
.704 .755 .892 r
.56014 .43309 .56686 .44101 .57965 .43687 .57295 .42728 Mtetra
.709 .718 .856 r
.57295 .42728 .57965 .43687 .59251 .4331 .58579 .42088 Mtetra
.696 .664 .815 r
.58579 .42088 .59251 .4331 .60545 .42976 .59868 .41433 Mtetra
.663 .605 .78 r
.59868 .41433 .60545 .42976 .61845 .42639 .61163 .4087 Mtetra
.611 .554 .767 r
.61163 .4087 .61845 .42639 .6315 .42234 .62471 .40569 Mtetra
.528 .519 .79 r
.62471 .40569 .6315 .42234 .64461 .41833 .638 .40669 Mtetra
.295 .466 .86 r
.638 .40669 .64461 .41833 .65795 .41842 .65159 .41254 Mtetra
0 .039 .526 r
.65159 .41254 .65795 .41842 .67187 .42899 .66563 .42537 Mtetra
.778 .282 0 r
.66563 .42537 .67187 .42899 .68655 .45136 .68026 .4464 Mtetra
.68 .169 0 r
.68026 .4464 .68655 .45136 .70138 .47091 .69502 .46444 Mtetra
.656 .799 .951 r
.69502 .46444 .70138 .47091 .71508 .46649 .70877 .45989 Mtetra
.933 .818 .708 r
.70877 .45989 .71508 .46649 .72754 .44098 .72132 .43431 Mtetra
.934 .818 .708 r
.72132 .43431 .72754 .44098 .73994 .41623 .73377 .40896 Mtetra
.857 .822 .813 r
.73377 .40896 .73994 .41623 .75298 .40223 .74685 .39442 Mtetra
.733 .786 .895 r
.74685 .39442 .75298 .40223 .76654 .39521 .76044 .38715 Mtetra
.671 .759 .917 r
.76044 .38715 .76654 .39521 .78031 .39037 .77426 .38223 Mtetra
.657 .752 .92 r
.77426 .38223 .78031 .39037 .79418 .38592 .78817 .37773 Mtetra
.656 .751 .92 r
.78817 .37773 .79418 .38592 .80812 .38149 .80216 .37326 Mtetra
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Mtetra
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .5296 Mtetra
.654 .751 .921 r
.28333 .5296 .29091 .53649 .30258 .53281 .29504 .5259 Mtetra
.637 .746 .928 r
.29504 .5259 .30258 .53281 .31428 .52955 .30676 .52265 Mtetra
.522 .709 .956 r
.30676 .52265 .31428 .52955 .3259 .52855 .31839 .52184 Mtetra
0 .32 .781 r
.31839 .52184 .3259 .52855 .3372 .53456 .32967 .52833 Mtetra
.795 .31 0 r
.32967 .52833 .3372 .53456 .34807 .55099 .3405 .54517 Mtetra
.778 .282 0 r
.3405 .54517 .34807 .55099 .35913 .56758 .35158 .56118 Mtetra
.698 .785 .918 r
.35158 .56118 .35913 .56758 .37131 .56379 .36387 .55592 Mtetra
.891 .752 .702 r
.36387 .55592 .37131 .56379 .38446 .53811 .37714 .52931 Mtetra
.89 .74 .69 r
.37714 .52931 .38446 .53811 .39762 .50956 .39037 .50091 Mtetra
.861 .748 .737 r
.39037 .50091 .39762 .50956 .41037 .48904 .40317 .48113 Mtetra
.819 .763 .8 r
.40317 .48113 .41037 .48904 .42285 .47533 .41567 .46834 Mtetra
.769 .782 .863 r
.41567 .46834 .42285 .47533 .43519 .46637 .42804 .45992 Mtetra
.694 .785 .92 r
.42804 .45992 .43519 .46637 .44745 .46133 .44034 .45478 Mtetra
.613 .76 .949 r
.44034 .45478 .44745 .46133 .4597 .45884 .45264 .45189 Mtetra
.572 .733 .951 r
.45264 .45189 .4597 .45884 .47201 .45728 .46498 .44999 Mtetra
.574 .723 .944 r
.46498 .44999 .47201 .45728 .48439 .45558 .4774 .44811 Mtetra
.594 .727 .937 r
.4774 .44811 .48439 .45558 .49685 .45331 .48989 .44579 Mtetra
.616 .734 .93 r
.48989 .44579 .49685 .45331 .50939 .45042 .50246 .44287 Mtetra
.637 .742 .924 r
.50246 .44287 .50939 .45042 .52199 .44693 .5151 .43937 Mtetra
.656 .749 .919 r
.5151 .43937 .52199 .44693 .53465 .44288 .5278 .4353 Mtetra
.673 .755 .912 r
.5278 .4353 .53465 .44288 .54737 .43828 .54056 .43065 Mtetra
.69 .76 .905 r
.54056 .43065 .54737 .43828 .56014 .43309 .55337 .4254 Mtetra
.706 .764 .897 r
.55337 .4254 .56014 .43309 .57295 .42728 .56622 .41953 Mtetra
.716 .766 .892 r
.56622 .41953 .57295 .42728 .58579 .42088 .57911 .41322 Mtetra
.715 .769 .895 r
.57911 .41322 .58579 .42088 .59868 .41433 .59205 .40696 Mtetra
.688 .771 .915 r
.59205 .40696 .59868 .41433 .61163 .4087 .60505 .40172 Mtetra
.608 .756 .949 r
.60505 .40172 .61163 .4087 .62471 .40569 .61818 .39876 Mtetra
.444 .685 .967 r
.61818 .39876 .62471 .40569 .638 .40669 .63149 .39913 Mtetra
.18 .511 .913 r
.63149 .39913 .638 .40669 .65159 .41254 .64506 .40396 Mtetra
0 .178 .701 r
.64506 .40396 .65159 .41254 .66563 .42537 .65907 .41594 Mtetra
0 0 .411 r
.65907 .41594 .66563 .42537 .68026 .4464 .67369 .43675 Mtetra
0 0 .498 r
.67369 .43675 .68026 .4464 .69502 .46444 .68849 .45567 Mtetra
.615 .717 .918 r
.68849 .45567 .69502 .46444 .70877 .45989 .70237 .45257 Mtetra
.925 .808 .712 r
.70237 .45257 .70877 .45989 .72132 .43431 .71504 .42753 Mtetra
.935 .817 .705 r
.71504 .42753 .72132 .43431 .73377 .40896 .72754 .40168 Mtetra
.863 .823 .807 r
.72754 .40168 .73377 .40896 .74685 .39442 .74066 .38657 Mtetra
.739 .788 .893 r
.74066 .38657 .74685 .39442 .76044 .38715 .75428 .37903 Mtetra
.672 .76 .916 r
.75428 .37903 .76044 .38715 .77426 .38223 .76815 .37401 Mtetra
.658 .752 .92 r
.76815 .37401 .77426 .38223 .78817 .37773 .78211 .36947 Mtetra
.656 .751 .92 r
.78211 .36947 .78817 .37773 .80216 .37326 .79614 .36496 Mtetra
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Mtetra
.26401 .52641 .27168 .53333 .28333 .5296 .27569 .52265 Mtetra
.653 .751 .921 r
.27569 .52265 .28333 .5296 .29504 .5259 .28743 .51892 Mtetra
.634 .746 .929 r
.28743 .51892 .29504 .5259 .30676 .52265 .29918 .5157 Mtetra
.508 .703 .958 r
.29918 .5157 .30676 .52265 .31839 .52184 .31082 .51511 Mtetra
0 .276 .744 r
.31082 .51511 .31839 .52184 .32967 .52833 .32207 .52211 Mtetra
.801 .317 0 r
.32207 .52211 .32967 .52833 .3405 .54517 .33288 .53918 Mtetra
.737 .23 0 r
.33288 .53918 .3405 .54517 .35158 .56118 .34402 .55384 Mtetra
.764 .771 .859 r
.34402 .55384 .35158 .56118 .36387 .55592 .35649 .54543 Mtetra
.879 .722 .683 r
.35649 .54543 .36387 .55592 .37714 .52931 .36997 .51594 Mtetra
.856 .694 .68 r
.36997 .51594 .37714 .52931 .39037 .50091 .38328 .48749 Mtetra
.793 .677 .736 r
.38328 .48749 .39037 .50091 .40317 .48113 .39596 .47181 Mtetra
.709 .715 .853 r
.39596 .47181 .40317 .48113 .41567 .46834 .40828 .46558 Mtetra
.565 .871 .995 r
.40828 .46558 .41567 .46834 .42804 .45992 .42054 .46214 Mtetra
.257 .757 .705 r
.42054 .46214 .42804 .45992 .44034 .45478 .43289 .45798 Mtetra
0 0 0 r
.43289 .45798 .44034 .45478 .45264 .45189 .44532 .45284 Mtetra
.47 .893 .86 r
.44532 .45284 .45264 .45189 .46498 .44999 .45779 .44765 Mtetra
.621 .905 .985 r
.45779 .44765 .46498 .44999 .4774 .44811 .47031 .44295 Mtetra
.651 .822 .965 r
.47031 .44295 .4774 .44811 .48989 .44579 .48287 .43875 Mtetra
.651 .763 .931 r
.48287 .43875 .48989 .44579 .50246 .44287 .49548 .43479 Mtetra
.652 .734 .909 r
.49548 .43479 .50246 .44287 .5151 .43937 .50816 .43081 Mtetra
.656 .724 .899 r
.50816 .43081 .5151 .43937 .5278 .4353 .52089 .4267 Mtetra
.659 .725 .898 r
.52089 .4267 .5278 .4353 .54056 .43065 .53369 .42247 Mtetra
.658 .736 .907 r
.53369 .42247 .54056 .43065 .55337 .4254 .54654 .41824 Mtetra
.648 .763 .933 r
.54654 .41824 .55337 .4254 .56622 .41953 .55946 .41428 Mtetra
.612 .814 .978 r
.55946 .41428 .56622 .41953 .57911 .41322 .57245 .41079 Mtetra
.49 .859 .986 r
.57245 .41079 .57911 .41322 .59205 .40696 .58551 .40777 Mtetra
.234 .751 .77 r
.58551 .40777 .59205 .40696 .60505 .40172 .59865 .40467 Mtetra
0 0 0 r
.59865 .40467 .60505 .40172 .61818 .39876 .61183 .4006 Mtetra
.285 .776 .715 r
.61183 .4006 .61818 .39876 .63149 .39913 .62505 .39581 Mtetra
.447 .815 .994 r
.62505 .39581 .63149 .39913 .64506 .40396 .63843 .39389 Mtetra
.122 .4 .852 r
.63843 .39389 .64506 .40396 .65907 .41594 .65228 .40161 Mtetra
0 .002 .578 r
.65228 .40161 .65907 .41594 .67369 .43675 .66686 .42237 Mtetra
0 0 .561 r
.66686 .42237 .67369 .43675 .68849 .45567 .68178 .44419 Mtetra
.523 .61 .881 r
.68178 .44419 .68849 .45567 .70237 .45257 .69585 .44427 Mtetra
.91 .795 .721 r
.69585 .44427 .70237 .45257 .71504 .42753 .70868 .42056 Mtetra
.934 .814 .703 r
.70868 .42056 .71504 .42753 .72754 .40168 .72127 .39439 Mtetra
.869 .824 .801 r
.72127 .39439 .72754 .40168 .74066 .38657 .73441 .37868 Mtetra
.744 .791 .89 r
.73441 .37868 .74066 .38657 .75428 .37903 .74807 .37084 Mtetra
.674 .76 .916 r
.74807 .37084 .75428 .37903 .76815 .37401 .76198 .36573 Mtetra
.658 .752 .92 r
.76198 .36573 .76815 .37401 .78211 .36947 .77599 .36113 Mtetra
.656 .751 .92 r
.77599 .36113 .78211 .36947 .79614 .36496 .79008 .35658 Mtetra
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Mtetra
.25627 .51944 .26401 .52641 .27569 .52265 .26799 .51564 Mtetra
.653 .751 .921 r
.26799 .51564 .27569 .52265 .28743 .51892 .27975 .51189 Mtetra
.632 .745 .929 r
.27975 .51189 .28743 .51892 .29918 .5157 .29153 .50871 Mtetra
.493 .697 .96 r
.29153 .50871 .29918 .5157 .31082 .51511 .30318 .50834 Mtetra
0 .24 .713 r
.30318 .50834 .31082 .51511 .32207 .52211 .31441 .51575 Mtetra
.793 .307 0 r
.31441 .51575 .32207 .52211 .33288 .53918 .32522 .53254 Mtetra
.607 .086 0 r
.32522 .53254 .33288 .53918 .34402 .55384 .33649 .54464 Mtetra
.8 .737 .794 r
.33649 .54464 .34402 .55384 .35649 .54543 .34921 .53222 Mtetra
.864 .697 .673 r
.34921 .53222 .35649 .54543 .36997 .51594 .36283 .50131 Mtetra
.838 .68 .688 r
.36283 .50131 .36997 .51594 .38328 .48749 .37607 .47587 Mtetra
.765 .691 .781 r
.37607 .47587 .38328 .48749 .39596 .47181 .3886 .46486 Mtetra
.614 .749 .942 r
.3886 .46486 .39596 .47181 .40828 .46558 .40083 .46196 Mtetra
.438 .793 .997 r
.40083 .46196 .40828 .46558 .42054 .46214 .41307 .46065 Mtetra
.373 .818 .948 r
.41307 .46065 .42054 .46214 .43289 .45798 .42541 .45854 Mtetra
.325 .811 .837 r
.42541 .45854 .43289 .45798 .44532 .45284 .43786 .45518 Mtetra
.27 .765 .703 r
.43786 .45518 .44532 .45284 .45779 .44765 .45039 .4507 Mtetra
0 0 0 r
.45039 .4507 .45779 .44765 .47031 .44295 .463 .44556 Mtetra
.311 .788 .699 r
.463 .44556 .47031 .44295 .48287 .43875 .47565 .44032 Mtetra
.378 .84 .79 r
.47565 .44032 .48287 .43875 .49548 .43479 .48835 .43535 Mtetra
.424 .869 .863 r
.48835 .43535 .49548 .43479 .50816 .43081 .5011 .43079 Mtetra
.427 .868 .893 r
.5011 .43079 .50816 .43081 .52089 .4267 .5139 .42668 Mtetra
.383 .844 .88 r
.5139 .42668 .52089 .4267 .53369 .42247 .52677 .42301 Mtetra
.291 .79 .816 r
.52677 .42301 .53369 .42247 .54654 .41824 .5397 .41972 Mtetra
.176 .706 .704 r
.5397 .41972 .54654 .41824 .55946 .41428 .5527 .41665 Mtetra
0 0 0 r
.5527 .41665 .55946 .41428 .57245 .41079 .56577 .4135 Mtetra
.56577 .4135 .57245 .41079 .58551 .40777 .57891 .40974 Mtetra
.29 .779 .714 r
.57891 .40974 .58551 .40777 .59865 .40467 .59208 .40487 Mtetra
.546 .929 .891 r
.59208 .40487 .59865 .40467 .61183 .4006 .60529 .3987 Mtetra
.696 .949 .956 r
.60529 .3987 .61183 .4006 .62505 .39581 .61851 .39168 Mtetra
.672 .879 .975 r
.61851 .39168 .62505 .39581 .63843 .39389 .63183 .38624 Mtetra
.311 .593 .945 r
.63183 .38624 .63843 .39389 .65228 .40161 .64552 .38909 Mtetra
0 .055 .62 r
.64552 .38909 .65228 .40161 .66686 .42237 .65995 .40669 Mtetra
0 0 .552 r
.65995 .40669 .66686 .42237 .68178 .44419 .6749 .42988 Mtetra
.412 .497 .836 r
.6749 .42988 .68178 .44419 .69585 .44427 .68919 .43402 Mtetra
.877 .765 .735 r
.68919 .43402 .69585 .44427 .70868 .42056 .70224 .41289 Mtetra
.927 .805 .705 r
.70224 .41289 .70868 .42056 .72127 .39439 .71492 .38694 Mtetra
.873 .822 .796 r
.71492 .38694 .72127 .39439 .73441 .37868 .72811 .37073 Mtetra
.75 .793 .888 r
.72811 .37073 .73441 .37868 .74807 .37084 .74181 .36259 Mtetra
.676 .761 .915 r
.74181 .36259 .74807 .37084 .76198 .36573 .75576 .35737 Mtetra
.658 .753 .92 r
.75576 .35737 .76198 .36573 .77599 .36113 .76982 .35272 Mtetra
.656 .751 .92 r
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Mtetra
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Mtetra
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Mtetra
.24847 .5124 .25627 .51944 .26799 .51564 .26022 .50857 Mtetra
.653 .751 .922 r
.26022 .50857 .26799 .51564 .27975 .51189 .27202 .5048 Mtetra
.629 .744 .93 r
.27202 .5048 .27975 .51189 .29153 .50871 .28382 .50166 Mtetra
.48 .692 .961 r
.28382 .50166 .29153 .50871 .30318 .50834 .29547 .50146 Mtetra
0 .232 .707 r
.29547 .50146 .30318 .50834 .31441 .51575 .3067 .50899 Mtetra
.755 .26 0 r
.3067 .50899 .31441 .51575 .32522 .53254 .31757 .52462 Mtetra
0 .199 .698 r
.31757 .52462 .32522 .53254 .33649 .54464 .32903 .53328 Mtetra
.807 .706 .754 r
.32903 .53328 .33649 .54464 .34921 .53222 .34195 .51798 Mtetra
.853 .688 .677 r
.34195 .51798 .34921 .53222 .36283 .50131 .35556 .48879 Mtetra
.832 .698 .715 r
.35556 .48879 .36283 .50131 .37607 .47587 .36863 .46804 Mtetra
.75 .761 .862 r
.36863 .46804 .37607 .47587 .3886 .46486 .38107 .46025 Mtetra
.549 .806 .993 r
.38107 .46025 .3886 .46486 .40083 .46196 .39332 .45791 Mtetra
.514 .813 .999 r
.39332 .45791 .40083 .46196 .41307 .46065 .40563 .45581 Mtetra
.584 .813 .986 r
.40563 .45581 .41307 .46065 .42541 .45854 .41804 .4529 Mtetra
.613 .796 .969 r
.41804 .4529 .42541 .45854 .43786 .45518 .43052 .44963 Mtetra
.613 .8 .971 r
.43052 .44963 .43786 .45518 .45039 .4507 .44307 .44634 Mtetra
.596 .835 .99 r
.44307 .44634 .45039 .4507 .463 .44556 .45569 .44295 Mtetra
.552 .877 .992 r
.45569 .44295 .463 .44556 .47565 .44032 .46837 .43935 Mtetra
.479 .883 .947 r
.46837 .43935 .47565 .44032 .48835 .43535 .48112 .43551 Mtetra
.406 .858 .88 r
.48112 .43551 .48835 .43535 .5011 .43079 .49394 .43148 Mtetra
.367 .836 .837 r
.49394 .43148 .5011 .43079 .5139 .42668 .50681 .42735 Mtetra
.373 .84 .839 r
.50681 .42735 .5139 .42668 .52677 .42301 .51975 .42312 Mtetra
.428 .87 .884 r
.51975 .42312 .52677 .42301 .5397 .41972 .53275 .41876 Mtetra
.52 .904 .947 r
.53275 .41876 .5397 .41972 .5527 .41665 .54581 .41418 Mtetra
.61 .907 .984 r
.54581 .41418 .5527 .41665 .56577 .4135 .55892 .40931 Mtetra
.662 .871 .978 r
.55892 .40931 .56577 .4135 .57891 .40974 .57209 .40422 Mtetra
.68 .833 .957 r
.57209 .40422 .57891 .40974 .59208 .40487 .58531 .39898 Mtetra
.693 .825 .946 r
.58531 .39898 .59208 .40487 .60529 .3987 .59858 .39338 Mtetra
.715 .851 .947 r
.59858 .39338 .60529 .3987 .61851 .39168 .61189 .38705 Mtetra
.7 .871 .962 r
.61189 .38705 .61851 .39168 .63183 .38624 .62525 .38098 Mtetra
.43 .744 .993 r
.62525 .38098 .63183 .38624 .64552 .38909 .63886 .38046 Mtetra
0 .143 .67 r
.63886 .38046 .64552 .38909 .65995 .40669 .6531 .39316 Mtetra
0 0 .545 r
.6531 .39316 .65995 .40669 .6749 .42988 .66793 .41448 Mtetra
.324 .427 .813 r
.66793 .41448 .6749 .42988 .68919 .43402 .68236 .42151 Mtetra
.83 .725 .748 r
.68236 .42151 .68919 .43402 .70224 .41289 .69566 .40386 Mtetra
.91 .786 .712 r
.69566 .40386 .70224 .41289 .71492 .38694 .7085 .37907 Mtetra
.87 .814 .792 r
.7085 .37907 .71492 .38694 .72811 .37073 .72174 .36267 Mtetra
.755 .793 .884 r
.72174 .36267 .72811 .37073 .74181 .36259 .73549 .35427 Mtetra
.678 .762 .915 r
.73549 .35427 .74181 .36259 .75576 .35737 .74948 .34893 Mtetra
.658 .753 .92 r
.74948 .34893 .75576 .35737 .76982 .35272 .76359 .34423 Mtetra
.656 .752 .92 r
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Mtetra
.656 .751 .92 r
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Mtetra
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Mtetra
.24061 .50531 .24847 .5124 .26022 .50857 .25239 .50145 Mtetra
.652 .751 .922 r
.25239 .50145 .26022 .50857 .27202 .5048 .26421 .49766 Mtetra
.628 .744 .931 r
.26421 .49766 .27202 .5048 .28382 .50166 .27604 .49452 Mtetra
.477 .69 .961 r
.27604 .49452 .28382 .50166 .29547 .50146 .28772 .49437 Mtetra
0 .271 .743 r
.28772 .49437 .29547 .50146 .3067 .50899 .29898 .5015 Mtetra
.658 .156 0 r
.29898 .5015 .3067 .50899 .31757 .52462 .30995 .51515 Mtetra
.141 .441 .876 r
.30995 .51515 .31757 .52462 .32903 .53328 .3216 .52063 Mtetra
.8 .689 .743 r
.3216 .52063 .32903 .53328 .34195 .51798 .33459 .50476 Mtetra
.848 .695 .693 r
.33459 .50476 .34195 .51798 .35556 .48879 .34807 .47928 Mtetra
.836 .738 .756 r
.34807 .47928 .35556 .48879 .36863 .46804 .36102 .46248 Mtetra
.735 .823 .919 r
.36102 .46248 .36863 .46804 .38107 .46025 .37345 .45587 Mtetra
.574 .824 .992 r
.37345 .45587 .38107 .46025 .39332 .45791 .38577 .45297 Mtetra
.574 .806 .987 r
.38577 .45297 .39332 .45791 .40563 .45581 .39814 .45027 Mtetra
.605 .797 .973 r
.39814 .45027 .40563 .45581 .41804 .4529 .4106 .44713 Mtetra
.627 .798 .964 r
.4106 .44713 .41804 .4529 .43052 .44963 .42313 .44355 Mtetra
.644 .793 .954 r
.42313 .44355 .43052 .44963 .44307 .44634 .43574 .43959 Mtetra
.653 .777 .939 r
.43574 .43959 .44307 .44634 .45569 .44295 .44841 .43546 Mtetra
.654 .756 .924 r
.44841 .43546 .45569 .44295 .46837 .43935 .46114 .43132 Mtetra
.653 .741 .914 r
.46114 .43132 .46837 .43935 .48112 .43551 .47393 .4272 Mtetra
.653 .735 .909 r
.47393 .4272 .48112 .43551 .49394 .43148 .48678 .42306 Mtetra
.655 .734 .907 r
.48678 .42306 .49394 .43148 .50681 .42735 .49969 .41885 Mtetra
.658 .733 .906 r
.49969 .41885 .50681 .42735 .51975 .42312 .51267 .41453 Mtetra
.659 .733 .904 r
.51267 .41453 .51975 .42312 .53275 .41876 .5257 .41015 Mtetra
.658 .733 .905 r
.5257 .41015 .53275 .41876 .54581 .41418 .5388 .40578 Mtetra
.654 .738 .911 r
.5388 .40578 .54581 .41418 .55892 .40931 .55196 .40153 Mtetra
.651 .755 .925 r
.55196 .40153 .55892 .40931 .57209 .40422 .56519 .39732 Mtetra
.659 .784 .941 r
.56519 .39732 .57209 .40422 .58531 .39898 .57847 .39281 Mtetra
.677 .814 .949 r
.57847 .39281 .58531 .39898 .59858 .39338 .59181 .38765 Mtetra
.699 .835 .948 r
.59181 .38765 .59858 .39338 .61189 .38705 .60518 .38179 Mtetra
.692 .85 .959 r
.60518 .38179 .61189 .38705 .62525 .38098 .61861 .37604 Mtetra
.502 .792 .997 r
.61861 .37604 .62525 .38098 .63886 .38046 .63223 .37415 Mtetra
0 .286 .751 r
.63223 .37415 .63886 .38046 .6531 .39316 .64633 .3827 Mtetra
0 .007 .566 r
.64633 .3827 .6531 .39316 .66793 .41448 .66098 .40011 Mtetra
.279 .417 .823 r
.66098 .40011 .66793 .41448 .68236 .42151 .67544 .40764 Mtetra
.789 .695 .761 r
.67544 .40764 .68236 .42151 .69566 .40386 .68894 .3932 Mtetra
.885 .762 .722 r
.68894 .3932 .69566 .40386 .7085 .37907 .70197 .3704 Mtetra
.858 .798 .791 r
.70197 .3704 .7085 .37907 .72174 .36267 .71531 .35436 Mtetra
.755 .789 .881 r
.71531 .35436 .72174 .36267 .73549 .35427 .7291 .34584 Mtetra
.679 .762 .914 r
.7291 .34584 .73549 .35427 .74948 .34893 .74315 .34042 Mtetra
.659 .753 .92 r
.74315 .34042 .74948 .34893 .76359 .34423 .7573 .33567 Mtetra
.656 .752 .92 r
.7573 .33567 .76359 .34423 .77777 .3396 .77153 .33099 Mtetra
.656 .751 .92 r
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Mtetra
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Mtetra
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Mtetra
.655 .751 .92 r
.23268 .49815 .24061 .50531 .25239 .50145 .24449 .49426 Mtetra
.652 .751 .922 r
.24449 .49426 .25239 .50145 .26421 .49766 .25635 .49044 Mtetra
.628 .744 .931 r
.25635 .49044 .26421 .49766 .27604 .49452 .26821 .48727 Mtetra
.488 .693 .959 r
.26821 .48727 .27604 .49452 .28772 .49437 .27992 .48693 Mtetra
0 .355 .815 r
.27992 .48693 .28772 .49437 .29898 .5015 .29125 .49309 Mtetra
0 .011 .527 r
.29125 .49309 .29898 .5015 .30995 .51515 .30236 .50442 Mtetra
.34 .524 .891 r
.30236 .50442 .30995 .51515 .3216 .52063 .31413 .50783 Mtetra
.788 .685 .751 r
.31413 .50783 .3216 .52063 .33459 .50476 .32709 .49339 Mtetra
.845 .714 .718 r
.32709 .49339 .33459 .50476 .34807 .47928 .34041 .4719 Mtetra
.838 .778 .795 r
.34041 .4719 .34807 .47928 .36102 .46248 .35329 .45759 Mtetra
.731 .845 .934 r
.35329 .45759 .36102 .46248 .37345 .45587 .36577 .45112 Mtetra
.617 .827 .981 r
.36577 .45112 .37345 .45587 .38577 .45297 .37816 .44752 Mtetra
.617 .804 .972 r
.37816 .44752 .38577 .45297 .39814 .45027 .3906 .4441 Mtetra
.635 .788 .955 r
.3906 .4441 .39814 .45027 .4106 .44713 .40311 .44039 Mtetra
.639 .772 .944 r
.40311 .44039 .4106 .44713 .42313 .44355 .41569 .43664 Mtetra
.636 .768 .942 r
.41569 .43664 .42313 .44355 .43574 .43959 .42833 .43296 Mtetra
.635 .776 .949 r
.42833 .43296 .43574 .43959 .44841 .43546 .44103 .42927 Mtetra
.635 .791 .957 r
.44103 .42927 .44841 .43546 .46114 .43132 .45379 .42545 Mtetra
.637 .804 .963 r
.45379 .42545 .46114 .43132 .47393 .4272 .46663 .4215 Mtetra
.639 .811 .965 r
.46663 .4215 .47393 .4272 .48678 .42306 .47952 .41745 Mtetra
.64 .815 .967 r
.47952 .41745 .48678 .42306 .49969 .41885 .49248 .41334 Mtetra
.639 .819 .969 r
.49248 .41334 .49969 .41885 .51267 .41453 .50551 .40919 Mtetra
.639 .826 .972 r
.50551 .40919 .51267 .41453 .5257 .41015 .51859 .40497 Mtetra
.646 .834 .973 r
.51859 .40497 .5257 .41015 .5388 .40578 .53174 .40051 Mtetra
.664 .837 .966 r
.53174 .40051 .5388 .40578 .55196 .40153 .54495 .3956 Mtetra
.681 .822 .951 r
.54495 .3956 .55196 .40153 .56519 .39732 .55822 .39032 Mtetra
.68 .79 .933 r
.55822 .39032 .56519 .39732 .57847 .39281 .57154 .38514 Mtetra
.667 .767 .925 r
.57154 .38514 .57847 .39281 .59181 .38765 .58493 .38036 Mtetra
.665 .779 .934 r
.58493 .38036 .59181 .38765 .60518 .38179 .59838 .3756 Mtetra
.661 .813 .956 r
.59838 .3756 .60518 .38179 .61861 .37604 .61189 .37081 Mtetra
.523 .793 .995 r
.61189 .37081 .61861 .37604 .63223 .37415 .62555 .36866 Mtetra
0 .425 .837 r
.62555 .36866 .63223 .37415 .64633 .3827 .63959 .37446 Mtetra
0 .113 .637 r
.63959 .37446 .64633 .3827 .66098 .40011 .65408 .38763 Mtetra
.294 .465 .858 r
.65408 .38763 .66098 .40011 .67544 .40764 .66846 .39357 Mtetra
.765 .685 .774 r
.66846 .39357 .67544 .40764 .68894 .3932 .68212 .38119 Mtetra
.858 .741 .733 r
.68212 .38119 .68894 .3932 .70197 .3704 .69534 .36075 Mtetra
.839 .778 .793 r
.69534 .36075 .70197 .3704 .71531 .35436 .7088 .34566 Mtetra
.749 .779 .878 r
.7088 .34566 .71531 .35436 .7291 .34584 .72266 .33728 Mtetra
.679 .76 .913 r
.72266 .33728 .7291 .34584 .74315 .34042 .73675 .33182 Mtetra
.659 .753 .919 r
.73675 .33182 .74315 .34042 .7573 .33567 .75096 .32703 Mtetra
.656 .752 .92 r
.75096 .32703 .7573 .33567 .77153 .33099 .76524 .3223 Mtetra
.656 .751 .92 r
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Mtetra
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Mtetra
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Mtetra
.22469 .49094 .23268 .49815 .24449 .49426 .23653 .48701 Mtetra
.653 .751 .922 r
.23653 .48701 .24449 .49426 .25635 .49044 .24842 .48316 Mtetra
.631 .744 .93 r
.24842 .48316 .25635 .49044 .26821 .48727 .26031 .47988 Mtetra
.515 .701 .954 r
.26031 .47988 .26821 .48727 .27992 .48693 .27208 .47908 Mtetra
.089 .46 .887 r
.27208 .47908 .27992 .48693 .29125 .49309 .28351 .48385 Mtetra
0 .196 .712 r
.28351 .48385 .29125 .49309 .30236 .50442 .29476 .49292 Mtetra
.401 .54 .881 r
.29476 .49292 .30236 .50442 .31413 .50783 .30659 .49552 Mtetra
.769 .687 .772 r
.30659 .49552 .31413 .50783 .32709 .49339 .31943 .48364 Mtetra
.841 .736 .748 r
.31943 .48364 .32709 .49339 .34041 .4719 .33262 .46563 Mtetra
.835 .805 .821 r
.33262 .46563 .34041 .4719 .35329 .45759 .34548 .45272 Mtetra
.741 .847 .929 r
.34548 .45272 .35329 .45759 .36577 .45112 .35803 .44585 Mtetra
.653 .821 .964 r
.35803 .44585 .36577 .45112 .37816 .44752 .37049 .44154 Mtetra
.636 .795 .959 r
.37049 .44154 .37816 .44752 .3906 .4441 .38299 .43777 Mtetra
.636 .785 .953 r
.38299 .43777 .3906 .4441 .40311 .44039 .39554 .43401 Mtetra
.643 .786 .95 r
.39554 .43401 .40311 .44039 .41569 .43664 .40817 .43007 Mtetra
.65 .783 .945 r
.40817 .43007 .41569 .43664 .42833 .43296 .42086 .42595 Mtetra
.654 .773 .936 r
.42086 .42595 .42833 .43296 .44103 .42927 .43361 .42173 Mtetra
.655 .758 .926 r
.43361 .42173 .44103 .42927 .45379 .42545 .44643 .4175 Mtetra
.654 .748 .919 r
.44643 .4175 .45379 .42545 .46663 .4215 .4593 .41327 Mtetra
.655 .741 .913 r
.4593 .41327 .46663 .4215 .47952 .41745 .47224 .40901 Mtetra
.657 .737 .909 r
.47224 .40901 .47952 .41745 .49248 .41334 .48524 .40465 Mtetra
.659 .733 .904 r
.48524 .40465 .49248 .41334 .50551 .40919 .4983 .40022 Mtetra
.657 .726 .9 r
.4983 .40022 .50551 .40919 .51859 .40497 .51143 .39582 Mtetra
.647 .719 .901 r
.51143 .39582 .51859 .40497 .53174 .40051 .52461 .39172 Mtetra
.631 .723 .914 r
.52461 .39172 .53174 .40051 .54495 .3956 .53787 .38811 Mtetra
.624 .758 .942 r
.53787 .38811 .54495 .3956 .55822 .39032 .55119 .38456 Mtetra
.646 .821 .967 r
.55119 .38456 .55822 .39032 .57154 .38514 .56458 .38011 Mtetra
.681 .856 .966 r
.56458 .38011 .57154 .38514 .58493 .38036 .57801 .37456 Mtetra
.685 .833 .954 r
.57801 .37456 .58493 .38036 .59838 .3756 .5915 .36902 Mtetra
.646 .798 .955 r
.5915 .36902 .59838 .3756 .61189 .37081 .60508 .36464 Mtetra
.513 .759 .985 r
.60508 .36464 .61189 .37081 .62555 .36866 .61881 .36304 Mtetra
.067 .513 .897 r
.61881 .36304 .62555 .36866 .63959 .37446 .63283 .36738 Mtetra
0 .263 .745 r
.63283 .36738 .63959 .37446 .65408 .38763 .64719 .3768 Mtetra
.377 .554 .901 r
.64719 .3768 .65408 .38763 .66846 .39357 .66148 .37995 Mtetra
.76 .69 .784 r
.66148 .37995 .66846 .39357 .68212 .38119 .67521 .36834 Mtetra
.833 .725 .745 r
.67521 .36834 .68212 .38119 .69534 .36075 .68861 .3502 Mtetra
.814 .757 .799 r
.68861 .3502 .69534 .36075 .7088 .34566 .70221 .33652 Mtetra
.737 .767 .877 r
.70221 .33652 .7088 .34566 .72266 .33728 .71615 .32856 Mtetra
.676 .757 .912 r
.71615 .32856 .72266 .33728 .73675 .33182 .7303 .32313 Mtetra
.659 .752 .919 r
.7303 .32313 .73675 .33182 .75096 .32703 .74455 .3183 Mtetra
.656 .751 .92 r
.74455 .3183 .75096 .32703 .76524 .3223 .75888 .31353 Mtetra
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Mtetra
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Mtetra
.21662 .48366 .22469 .49094 .23653 .48701 .2285 .4797 Mtetra
.653 .751 .921 r
.2285 .4797 .23653 .48701 .24842 .48316 .24042 .47579 Mtetra
.636 .745 .927 r
.24042 .47579 .24842 .48316 .26031 .47988 .25236 .47235 Mtetra
.55 .713 .948 r
.25236 .47235 .26031 .47988 .27208 .47908 .26419 .47089 Mtetra
.258 .553 .929 r
.26419 .47089 .27208 .47908 .28351 .48385 .27576 .474 Mtetra
0 .343 .822 r
.27576 .474 .28351 .48385 .29476 .49292 .28715 .48105 Mtetra
.4 .533 .875 r
.28715 .48105 .29476 .49292 .30659 .49552 .29897 .48373 Mtetra
.736 .685 .802 r
.29897 .48373 .30659 .49552 .31943 .48364 .31164 .47485 Mtetra
.83 .753 .778 r
.31164 .47485 .31943 .48364 .33262 .46563 .32472 .4598 Mtetra
.831 .818 .837 r
.32472 .4598 .33262 .46563 .34548 .45272 .3376 .44767 Mtetra
.753 .845 .92 r
.3376 .44767 .34548 .45272 .35803 .44585 .35022 .44033 Mtetra
.677 .82 .952 r
.35022 .44033 .35803 .44585 .37049 .44154 .36276 .43543 Mtetra
.654 .797 .951 r
.36276 .43543 .37049 .44154 .38299 .43777 .37532 .43117 Mtetra
.652 .783 .944 r
.37532 .43117 .38299 .43777 .39554 .43401 .38793 .427 Mtetra
.648 .771 .938 r
.38793 .427 .39554 .43401 .40817 .43007 .40059 .42295 Mtetra
.644 .767 .938 r
.40059 .42295 .40817 .43007 .42086 .42595 .41332 .41899 Mtetra
.642 .773 .942 r
.41332 .41899 .42086 .42595 .43361 .42173 .4261 .41505 Mtetra
.644 .782 .948 r
.4261 .41505 .43361 .42173 .44643 .4175 .43896 .41101 Mtetra
.646 .79 .951 r
.43896 .41101 .44643 .4175 .4593 .41327 .45187 .40687 Mtetra
.649 .795 .953 r
.45187 .40687 .4593 .41327 .47224 .40901 .46485 .40262 Mtetra
.652 .797 .952 r
.46485 .40262 .47224 .40901 .48524 .40465 .4779 .39825 Mtetra
.657 .8 .951 r
.4779 .39825 .48524 .40465 .4983 .40022 .49101 .39372 Mtetra
.668 .801 .946 r
.49101 .39372 .4983 .40022 .51143 .39582 .50418 .38887 Mtetra
.683 .793 .932 r
.50418 .38887 .51143 .39582 .52461 .39172 .51742 .38356 Mtetra
.687 .761 .908 r
.51742 .38356 .52461 .39172 .53787 .38811 .53071 .37806 Mtetra
.657 .705 .882 r
.53071 .37806 .53787 .38811 .55119 .38456 .54406 .37349 Mtetra
.611 .664 .877 r
.54406 .37349 .55119 .38456 .56458 .38011 .55749 .37052 Mtetra
.603 .696 .909 r
.55749 .37052 .56458 .38011 .57801 .37456 .57101 .36773 Mtetra
.641 .789 .953 r
.57101 .36773 .57801 .37456 .5915 .36902 .58458 .36351 Mtetra
.639 .832 .975 r
.58458 .36351 .5915 .36902 .60508 .36464 .59821 .35902 Mtetra
.502 .775 .993 r
.59821 .35902 .60508 .36464 .61881 .36304 .61198 .3573 Mtetra
.148 .568 .929 r
.61198 .3573 .61881 .36304 .63283 .36738 .62601 .36068 Mtetra
0 .428 .858 r
.62601 .36068 .63283 .36738 .64719 .3768 .64029 .36691 Mtetra
.501 .647 .922 r
.64029 .36691 .64719 .3768 .66148 .37995 .65447 .36679 Mtetra
.766 .7 .789 r
.65447 .36679 .66148 .37995 .67521 .36834 .66824 .35503 Mtetra
.811 .714 .757 r
.66824 .35503 .67521 .36834 .68861 .3502 .6818 .33898 Mtetra
.787 .739 .809 r
.6818 .33898 .68861 .3502 .70221 .33652 .69555 .327 Mtetra
.72 .754 .879 r
.69555 .327 .70221 .33652 .71615 .32856 .70958 .31967 Mtetra
.672 .753 .912 r
.70958 .31967 .71615 .32856 .7303 .32313 .72378 .31435 Mtetra
.658 .752 .919 r
.72378 .31435 .7303 .32313 .74455 .3183 .73809 .30949 Mtetra
.656 .751 .92 r
.73809 .30949 .74455 .3183 .75888 .31353 .75247 .30468 Mtetra
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Mtetra
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Mtetra
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Mtetra
.654 .751 .921 r
.2204 .47233 .2285 .4797 .24042 .47579 .23235 .46836 Mtetra
.642 .747 .925 r
.23235 .46836 .24042 .47579 .25236 .47235 .24434 .46471 Mtetra
.585 .724 .939 r
.24434 .46471 .25236 .47235 .26419 .47089 .25626 .46249 Mtetra
.397 .622 .943 r
.25626 .46249 .26419 .47089 .27576 .474 .26797 .46384 Mtetra
.177 .449 .877 r
.26797 .46384 .27576 .474 .28715 .48105 .27949 .46898 Mtetra
.377 .518 .871 r
.27949 .46898 .28715 .48105 .29897 .48373 .29128 .47211 Mtetra
.683 .671 .832 r
.29128 .47211 .29897 .48373 .31164 .47485 .30378 .46639 Mtetra
.808 .76 .808 r
.30378 .46639 .31164 .47485 .32472 .4598 .31673 .45408 Mtetra
.824 .824 .848 r
.31673 .45408 .32472 .4598 .3376 .44767 .32964 .44255 Mtetra
.766 .845 .911 r
.32964 .44255 .3376 .44767 .35022 .44033 .34235 .43462 Mtetra
.697 .82 .941 r
.34235 .43462 .35022 .44033 .36276 .43543 .35496 .4291 Mtetra
.664 .795 .945 r
.35496 .4291 .36276 .43543 .37532 .43117 .36757 .42456 Mtetra
.652 .785 .945 r
.36757 .42456 .37532 .43117 .38793 .427 .38022 .42034 Mtetra
.653 .784 .944 r
.38022 .42034 .38793 .427 .40059 .42295 .39294 .4161 Mtetra
.655 .781 .94 r
.39294 .4161 .40059 .42295 .41332 .41899 .40571 .41178 Mtetra
.657 .771 .934 r
.40571 .41178 .41332 .41899 .4261 .41505 .41855 .4074 Mtetra
.657 .76 .926 r
.41855 .4074 .4261 .41505 .43896 .41101 .43145 .40301 Mtetra
.658 .752 .919 r
.43145 .40301 .43896 .41101 .45187 .40687 .44441 .39858 Mtetra
.661 .746 .913 r
.44441 .39858 .45187 .40687 .46485 .40262 .45744 .39404 Mtetra
.664 .74 .907 r
.45744 .39404 .46485 .40262 .4779 .39825 .47053 .38937 Mtetra
.662 .733 .902 r
.47053 .38937 .4779 .39825 .49101 .39372 .48368 .38475 Mtetra
.653 .729 .905 r
.48368 .38475 .49101 .39372 .50418 .38887 .49688 .3804 Mtetra
.644 .739 .918 r
.49688 .3804 .50418 .38887 .51742 .38356 .51015 .37632 Mtetra
.66 .78 .938 r
.51015 .37632 .51742 .38356 .53071 .37806 .52349 .37167 Mtetra
.699 .818 .939 r
.52349 .37167 .53071 .37806 .54406 .37349 .53689 .36577 Mtetra
.684 .776 .921 r
.53689 .36577 .54406 .37349 .55749 .37052 .55035 .36033 Mtetra
.611 .687 .896 r
.55035 .36033 .55749 .37052 .57101 .36773 .56389 .35727 Mtetra
.576 .666 .9 r
.56389 .35727 .57101 .36773 .58458 .36351 .57753 .3553 Mtetra
.577 .726 .944 r
.57753 .3553 .58458 .36351 .59821 .35902 .59125 .35289 Mtetra
.476 .747 .988 r
.59125 .35289 .59821 .35902 .61198 .3573 .60509 .35181 Mtetra
.208 .617 .95 r
.60509 .35181 .61198 .3573 .62601 .36068 .61914 .35418 Mtetra
.214 .588 .945 r
.61914 .35418 .62601 .36068 .64029 .36691 .63334 .35725 Mtetra
.622 .711 .91 r
.63334 .35725 .64029 .36691 .65447 .36679 .64742 .35368 Mtetra
.772 .704 .787 r
.64742 .35368 .65447 .36679 .66824 .35503 .66121 .34144 Mtetra
.789 .704 .77 r
.66121 .34144 .66824 .35503 .6818 .33898 .67492 .32741 Mtetra
.757 .725 .823 r
.67492 .32741 .6818 .33898 .69555 .327 .68882 .31726 Mtetra
.702 .744 .884 r
.68882 .31726 .69555 .327 .70958 .31967 .70294 .31066 Mtetra
.667 .75 .913 r
.70294 .31066 .70958 .31967 .72378 .31435 .71721 .30548 Mtetra
.657 .751 .919 r
.71721 .30548 .72378 .31435 .73809 .30949 .73157 .3006 Mtetra
.656 .751 .92 r
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Mtetra
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Mtetra
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28105 Mtetra
.78974 .28105 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .4649 Mtetra
.655 .751 .921 r
.21223 .4649 .2204 .47233 .23235 .46836 .22422 .46087 Mtetra
.648 .749 .923 r
.22422 .46087 .23235 .46836 .24434 .46471 .23625 .45702 Mtetra
.614 .734 .931 r
.23625 .45702 .24434 .46471 .25626 .46249 .24826 .45407 Mtetra
.501 .671 .94 r
.24826 .45407 .25626 .46249 .26797 .46384 .26012 .45367 Mtetra
.322 .535 .905 r
.26012 .45367 .26797 .46384 .27949 .46898 .2718 .45682 Mtetra
.361 .508 .87 r
.2718 .45682 .27949 .46898 .29128 .47211 .28356 .46019 Mtetra
.605 .636 .855 r
.28356 .46019 .29128 .47211 .30378 .46639 .29586 .4576 Mtetra
.767 .75 .838 r
.29586 .4576 .30378 .46639 .31673 .45408 .30867 .44823 Mtetra
.813 .823 .858 r
.30867 .44823 .31673 .45408 .32964 .44255 .32159 .43742 Mtetra
.777 .846 .904 r
.32159 .43742 .32964 .44255 .34235 .43462 .33438 .42898 Mtetra
.716 .827 .934 r
.33438 .42898 .34235 .43462 .35496 .4291 .34707 .42284 Mtetra
.68 .803 .941 r
.34707 .42284 .35496 .4291 .36757 .42456 .35975 .4178 Mtetra
.666 .786 .938 r
.35975 .4178 .36757 .42456 .38022 .42034 .37247 .41318 Mtetra
.656 .772 .935 r
.37247 .41318 .38022 .42034 .39294 .4161 .38522 .40884 Mtetra
.65 .769 .936 r
.38522 .40884 .39294 .4161 .40571 .41178 .39803 .40465 Mtetra
.649 .773 .939 r
.39803 .40465 .40571 .41178 .41855 .4074 .41091 .40046 Mtetra
.651 .78 .943 r
.41091 .40046 .41855 .4074 .43145 .40301 .42385 .39617 Mtetra
.654 .786 .944 r
.42385 .39617 .43145 .40301 .44441 .39858 .43685 .39175 Mtetra
.662 .789 .943 r
.43685 .39175 .44441 .39858 .45744 .39404 .44992 .38711 Mtetra
.66 .787 .942 r
.44992 .38711 .45744 .39404 .47053 .38937 .46305 .38249 Mtetra
.652 .787 .946 r
.46305 .38249 .47053 .38937 .48368 .38475 .47625 .37806 Mtetra
.648 .792 .952 r
.47625 .37806 .48368 .38475 .49688 .3804 .4895 .3737 Mtetra
.605 .779 .964 r
.4895 .3737 .49688 .3804 .51015 .37632 .50281 .37039 Mtetra
.525 .773 .988 r
.50281 .37039 .51015 .37632 .52349 .37167 .5162 .36844 Mtetra
.581 .882 .992 r
.5162 .36844 .52349 .37167 .53689 .36577 .52966 .3642 Mtetra
.696 .957 .949 r
.52966 .3642 .53689 .36577 .55035 .36033 .54318 .35673 Mtetra
.679 .903 .975 r
.54318 .35673 .55035 .36033 .56389 .35727 .55676 .35064 Mtetra
.584 .778 .972 r
.55676 .35064 .56389 .35727 .57753 .3553 .57043 .34767 Mtetra
.528 .724 .963 r
.57043 .34767 .57753 .3553 .59125 .35289 .58421 .34618 Mtetra
.436 .71 .981 r
.58421 .34618 .59125 .35289 .60509 .35181 .59812 .34601 Mtetra
.293 .662 .972 r
.59812 .34601 .60509 .35181 .61914 .35418 .61219 .34742 Mtetra
.448 .717 .982 r
.61219 .34742 .61914 .35418 .63334 .35725 .62632 .34704 Mtetra
.708 .734 .871 r
.62632 .34704 .63334 .35725 .64742 .35368 .64031 .34008 Mtetra
.77 .697 .782 r
.64031 .34008 .64742 .35368 .66121 .34144 .65414 .32771 Mtetra
.763 .693 .785 r
.65414 .32771 .66121 .34144 .67492 .32741 .668 .31585 Mtetra
.727 .716 .84 r
.668 .31585 .67492 .32741 .68882 .31726 .68204 .30749 Mtetra
.684 .739 .892 r
.68204 .30749 .68882 .31726 .70294 .31066 .69625 .30158 Mtetra
.662 .749 .915 r
.69625 .30158 .70294 .31066 .71721 .30548 .71057 .29653 Mtetra
.657 .751 .92 r
.71057 .29653 .71721 .30548 .73157 .3006 .72498 .29163 Mtetra
.656 .751 .92 r
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Mtetra
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28105 .78336 .2719 Mtetra
.78336 .2719 .78974 .28105 .80447 .27611 .79815 .2669 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.19202 .46147 .20029 .46893 .21223 .4649 .20399 .4574 Mtetra
.655 .751 .92 r
.20399 .4574 .21223 .4649 .22422 .46087 .21602 .45332 Mtetra
.652 .75 .921 r
.21602 .45332 .22422 .46087 .23625 .45702 .22809 .44932 Mtetra
.635 .742 .925 r
.22809 .44932 .23625 .45702 .24826 .45407 .24017 .44578 Mtetra
.573 .706 .932 r
.24017 .44578 .24826 .45407 .26012 .45367 .25219 .44382 Mtetra
.445 .609 .917 r
.25219 .44382 .26012 .45367 .2718 .45682 .26404 .4448 Mtetra
.382 .525 .875 r
.26404 .4448 .2718 .45682 .28356 .46019 .27584 .44766 Mtetra
.515 .584 .862 r
.27584 .44766 .28356 .46019 .29586 .4576 .28795 .44775 Mtetra
.696 .713 .862 r
.28795 .44775 .29586 .4576 .30867 .44823 .30057 .44181 Mtetra
.787 .811 .871 r
.30057 .44181 .30867 .44823 .32159 .43742 .31346 .43235 Mtetra
.785 .849 .899 r
.31346 .43235 .32159 .43742 .33438 .42898 .32633 .4235 Mtetra
.736 .836 .926 r
.32633 .4235 .33438 .42898 .34707 .42284 .33911 .41661 Mtetra
.691 .808 .937 r
.33911 .41661 .34707 .42284 .35975 .4178 .35185 .41119 Mtetra
.668 .793 .941 r
.35185 .41119 .35975 .4178 .37247 .41318 .36461 .40646 Mtetra
.662 .789 .942 r
.36461 .40646 .37247 .41318 .38522 .40884 .37742 .40187 Mtetra
.662 .783 .938 r
.37742 .40187 .38522 .40884 .39803 .40465 .39029 .39728 Mtetra
.661 .772 .932 r
.39029 .39728 .39803 .40465 .41091 .40046 .40321 .39271 Mtetra
.659 .762 .926 r
.40321 .39271 .41091 .40046 .42385 .39617 .4162 .38818 Mtetra
.663 .757 .92 r
.4162 .38818 .42385 .39617 .43685 .39175 .42925 .38351 Mtetra
.666 .752 .915 r
.42925 .38351 .43685 .39175 .44992 .38711 .44237 .37874 Mtetra
.647 .744 .92 r
.44237 .37874 .44992 .38711 .46305 .38249 .45553 .37453 Mtetra
.635 .752 .933 r
.45553 .37453 .46305 .38249 .47625 .37806 .46875 .37065 Mtetra
.671 .781 .932 r
.46875 .37065 .47625 .37806 .4895 .3737 .48206 .36562 Mtetra
.68 .766 .916 r
.48206 .36562 .4895 .3737 .50281 .37039 .49543 .36028 Mtetra
.564 .67 .909 r
.49543 .36028 .50281 .37039 .5162 .36844 .50884 .35854 Mtetra
.522 .656 .92 r
.50884 .35854 .5162 .36844 .52966 .3642 .52234 .35782 Mtetra
.699 .824 .942 r
.52234 .35782 .52966 .3642 .54318 .35673 .53593 .35179 Mtetra
.706 .871 .959 r
.53593 .35179 .54318 .35673 .55676 .35064 .54956 .34534 Mtetra
.583 .823 .99 r
.54956 .34534 .55676 .35064 .57043 .34767 .56328 .34188 Mtetra
.479 .763 .993 r
.56328 .34188 .57043 .34767 .58421 .34618 .57712 .3405 Mtetra
.4 .728 .99 r
.57712 .3405 .58421 .34618 .59812 .34601 .59108 .34026 Mtetra
.43 .742 .992 r
.59108 .34026 .59812 .34601 .61219 .34742 .60514 .3396 Mtetra
.64 .771 .943 r
.60514 .3396 .61219 .34742 .62632 .34704 .61919 .33526 Mtetra
.746 .718 .826 r
.61919 .33526 .62632 .34704 .64031 .34008 .63314 .3257 Mtetra
.753 .681 .782 r
.63314 .3257 .64031 .34008 .65414 .32771 .64704 .31418 Mtetra
.732 .685 .806 r
.64704 .31418 .65414 .32771 .668 .31585 .66104 .30468 Mtetra
.698 .714 .861 r
.66104 .30468 .668 .31585 .68204 .30749 .6752 .29787 Mtetra
.67 .739 .902 r
.6752 .29787 .68204 .30749 .69625 .30158 .68949 .29248 Mtetra
.658 .749 .917 r
.68949 .29248 .69625 .30158 .71057 .29653 .70388 .2875 Mtetra
.656 .751 .92 r
.70388 .2875 .71057 .29653 .72498 .29163 .71834 .28257 Mtetra
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Mtetra
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Mtetra
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26768 Mtetra
.76217 .26768 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Mtetra
.19568 .44984 .20399 .4574 .21602 .45332 .20774 .44572 Mtetra
.655 .751 .921 r
.20774 .44572 .21602 .45332 .22809 .44932 .21985 .44161 Mtetra
.648 .747 .922 r
.21985 .44161 .22809 .44932 .24017 .44578 .232 .43769 Mtetra
.619 .729 .925 r
.232 .43769 .24017 .44578 .25219 .44382 .24414 .43455 Mtetra
.544 .671 .92 r
.24414 .43455 .25219 .44382 .26404 .4448 .25618 .43337 Mtetra
.45 .575 .888 r
.25618 .43337 .26404 .4448 .27584 .44766 .2681 .43466 Mtetra
.46 .548 .859 r
.2681 .43466 .27584 .44766 .28795 .44775 .28011 .43616 Mtetra
.591 .64 .868 r
.28011 .43616 .28795 .44775 .30057 .44181 .29249 .43391 Mtetra
.727 .768 .885 r
.29249 .43391 .30057 .44181 .31346 .43235 .30525 .42698 Mtetra
.776 .842 .902 r
.30525 .42698 .31346 .43235 .32633 .4235 .31816 .41844 Mtetra
.754 .852 .923 r
.31816 .41844 .32633 .4235 .33911 .41661 .33103 .41087 Mtetra
.715 .829 .935 r
.33103 .41087 .33911 .41661 .35185 .41119 .34387 .40464 Mtetra
.687 .801 .935 r
.34387 .40464 .35185 .41119 .36461 .40646 .3567 .3993 Mtetra
.666 .779 .934 r
.3567 .3993 .36461 .40646 .37742 .40187 .36955 .39459 Mtetra
.656 .774 .936 r
.36955 .39459 .37742 .40187 .39029 .39728 .38246 .39014 Mtetra
.652 .778 .941 r
.38246 .39014 .39029 .39728 .40321 .39271 .39542 .38579 Mtetra
.655 .786 .944 r
.39542 .38579 .40321 .39271 .4162 .38818 .40844 .38129 Mtetra
.658 .789 .944 r
.40844 .38129 .4162 .38818 .42925 .38351 .42154 .37669 Mtetra
.66 .793 .946 r
.42154 .37669 .42925 .38351 .44237 .37874 .4347 .372 Mtetra
.643 .791 .953 r
.4347 .372 .44237 .37874 .45553 .37453 .4479 .36774 Mtetra
.677 .801 .941 r
.4479 .36774 .45553 .37453 .46875 .37065 .4612 .3625 Mtetra
.749 .783 .881 r
.4612 .3625 .46875 .37065 .48206 .36562 .4746 .35435 Mtetra
.746 .716 .824 r
.4746 .35435 .48206 .36562 .49543 .36028 .48805 .34507 Mtetra
.675 .629 .795 r
.48805 .34507 .49543 .36028 .50884 .35854 .5015 .33849 Mtetra
.401 .42 .765 r
.5015 .33849 .50884 .35854 .52234 .35782 .51497 .34383 Mtetra
.551 .588 .844 r
.51497 .34383 .52234 .35782 .53593 .35179 .52858 .34283 Mtetra
.617 .727 .924 r
.52858 .34283 .53593 .35179 .54956 .34534 .54228 .33936 Mtetra
.536 .784 .989 r
.54228 .33936 .54956 .34534 .56328 .34188 .55607 .337 Mtetra
.464 .788 .999 r
.55607 .337 .56328 .34188 .57712 .3405 .56996 .33532 Mtetra
.486 .789 .998 r
.56996 .33532 .57712 .3405 .59108 .34026 .58394 .33342 Mtetra
.631 .798 .963 r
.58394 .33342 .59108 .34026 .60514 .3396 .59796 .32915 Mtetra
.726 .738 .861 r
.59796 .32915 .60514 .3396 .61919 .33526 .61195 .32124 Mtetra
.739 .681 .795 r
.61195 .32124 .61919 .33526 .63314 .3257 .62592 .31098 Mtetra
.722 .665 .793 r
.62592 .31098 .63314 .3257 .64704 .31418 .63993 .3015 Mtetra
.7 .687 .835 r
.63993 .3015 .64704 .31418 .66104 .30468 .65407 .29418 Mtetra
.676 .722 .884 r
.65407 .29418 .66104 .30468 .6752 .29787 .66832 .28847 Mtetra
.661 .743 .911 r
.66832 .28847 .6752 .29787 .68949 .29248 .68268 .28336 Mtetra
.656 .75 .919 r
.68268 .28336 .68949 .29248 .70388 .2875 .69712 .2784 Mtetra
.656 .751 .92 r
.69712 .2784 .70388 .2875 .71834 .28257 .71163 .27343 Mtetra
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26845 Mtetra
.72622 .26845 .73287 .27763 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26768 .75562 .25839 Mtetra
.75562 .25839 .76217 .26768 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Mtetra
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Mtetra
.655 .751 .92 r
.19939 .43805 .20774 .44572 .21985 .44161 .21154 .43389 Mtetra
.653 .75 .921 r
.21154 .43389 .21985 .44161 .232 .43769 .22374 .42976 Mtetra
.643 .743 .921 r
.22374 .42976 .232 .43769 .24414 .43455 .23596 .42592 Mtetra
.609 .714 .919 r
.23596 .42592 .24414 .43455 .25618 .43337 .24817 .42303 Mtetra
.54 .645 .902 r
.24817 .42303 .25618 .43337 .2681 .43466 .26029 .42205 Mtetra
.481 .568 .866 r
.26029 .42205 .2681 .43466 .28011 .43616 .27234 .42289 Mtetra
.505 .568 .854 r
.27234 .42289 .28011 .43616 .29249 .43391 .28453 .42324 Mtetra
.616 .672 .881 r
.28453 .42324 .29249 .43391 .30525 .42698 .29706 .42014 Mtetra
.726 .799 .909 r
.29706 .42014 .30525 .42698 .31816 .41844 .30989 .41342 Mtetra
.759 .855 .921 r
.30989 .41342 .31816 .41844 .33103 .41087 .32284 .40562 Mtetra
.732 .847 .935 r
.32284 .40562 .33103 .41087 .34387 .40464 .33576 .3988 Mtetra
.699 .826 .943 r
.33576 .3988 .34387 .40464 .3567 .3993 .34866 .39303 Mtetra
.681 .81 .945 r
.34866 .39303 .3567 .3993 .36955 .39459 .36159 .38779 Mtetra
.674 .795 .939 r
.36159 .38779 .36955 .39459 .38246 .39014 .37456 .38277 Mtetra
.665 .777 .933 r
.37456 .38277 .38246 .39014 .39542 .38579 .38758 .378 Mtetra
.661 .765 .927 r
.38758 .378 .39542 .38579 .40844 .38129 .40065 .37333 Mtetra
.654 .759 .927 r
.40065 .37333 .40844 .38129 .42154 .37669 .41378 .36887 Mtetra
.658 .766 .929 r
.41378 .36887 .42154 .37669 .4347 .372 .42698 .36424 Mtetra
.665 .771 .929 r
.42698 .36424 .4347 .372 .4479 .36774 .44024 .35939 Mtetra
.689 .763 .908 r
.44024 .35939 .4479 .36774 .4612 .3625 .45359 .35368 Mtetra
.549 .7 .939 r
.45359 .35368 .4612 .3625 .4746 .35435 .46692 .35202 Mtetra
.596 .025 0 r
.46692 .35202 .4746 .35435 .48805 .34507 .48017 .36241 Mtetra
.339 0 .149 r
.48017 .36241 .48805 .34507 .5015 .33849 .49377 .35797 Mtetra
.255 0 .144 r
.49377 .35797 .5015 .33849 .51497 .34383 .50745 .34966 Mtetra
0 0 0 r
.50745 .34966 .51497 .34383 .52858 .34283 .52116 .34172 Mtetra
.557 .921 .946 r
.52116 .34172 .52858 .34283 .54228 .33936 .53493 .3362 Mtetra
.549 .877 .991 r
.53493 .3362 .54228 .33936 .55607 .337 .54877 .33217 Mtetra
.603 .85 .991 r
.54877 .33217 .55607 .337 .56996 .33532 .56268 .32795 Mtetra
.675 .798 .941 r
.56268 .32795 .56996 .33532 .58394 .33342 .57665 .32251 Mtetra
.717 .725 .857 r
.57665 .32251 .58394 .33342 .59796 .32915 .59064 .31488 Mtetra
.718 .669 .801 r
.59064 .31488 .59796 .32915 .61195 .32124 .60464 .30593 Mtetra
.706 .65 .792 r
.60464 .30593 .61195 .32124 .62592 .31098 .61868 .2973 Mtetra
.69 .667 .823 r
.61868 .2973 .62592 .31098 .63993 .3015 .63282 .29021 Mtetra
.675 .705 .87 r
.63282 .29021 .63993 .3015 .65407 .29418 .64706 .28439 Mtetra
.662 .735 .904 r
.64706 .28439 .65407 .29418 .66832 .28847 .66139 .27921 Mtetra
.657 .748 .917 r
.66139 .27921 .66832 .28847 .68268 .28336 .6758 .2742 Mtetra
.656 .751 .92 r
.6758 .2742 .68268 .28336 .69712 .2784 .69029 .26922 Mtetra
.69029 .26922 .69712 .2784 .71163 .27343 .70486 .2642 Mtetra
.70486 .2642 .71163 .27343 .72622 .26845 .7195 .25917 Mtetra
.7195 .25917 .72622 .26845 .74088 .26343 .73421 .25411 Mtetra
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Mtetra
.19097 .43033 .19939 .43805 .21154 .43389 .20315 .42611 Mtetra
.655 .751 .92 r
.20315 .42611 .21154 .43389 .22374 .42976 .21539 .42189 Mtetra
.653 .749 .92 r
.21539 .42189 .22374 .42976 .23596 .42592 .22767 .41774 Mtetra
.641 .738 .919 r
.22767 .41774 .23596 .42592 .24817 .42303 .23999 .41389 Mtetra
.61 .704 .911 r
.23999 .41389 .24817 .42303 .26029 .42205 .25229 .41094 Mtetra
.557 .637 .886 r
.25229 .41094 .26029 .42205 .27234 .42289 .26453 .40957 Mtetra
.513 .573 .853 r
.26453 .40957 .27234 .42289 .28453 .42324 .27674 .40965 Mtetra
.524 .575 .848 r
.27674 .40965 .28453 .42324 .29706 .42014 .28907 .40944 Mtetra
.602 .668 .886 r
.28907 .40944 .29706 .42014 .30989 .41342 .30165 .40672 Mtetra
.7 .801 .928 r
.30165 .40672 .30989 .41342 .32284 .40562 .31452 .40091 Mtetra
.743 .866 .937 r
.31452 .40091 .32284 .40562 .33576 .3988 .32752 .39366 Mtetra
.73 .853 .939 r
.32752 .39366 .33576 .3988 .34866 .39303 .34053 .38682 Mtetra
.695 .818 .941 r
.34053 .38682 .34866 .39303 .36159 .38779 .35353 .38111 Mtetra
.671 .799 .943 r
.35353 .38111 .36159 .38779 .37456 .38277 .36655 .37611 Mtetra
.658 .798 .949 r
.36655 .37611 .37456 .38277 .38758 .378 .3796 .37145 Mtetra
.656 .801 .953 r
.3796 .37145 .38758 .378 .40065 .37333 .39272 .36681 Mtetra
.65 .802 .956 r
.39272 .36681 .40065 .37333 .41378 .36887 .4059 .3623 Mtetra
.647 .8 .957 r
.4059 .3623 .41378 .36887 .42698 .36424 .41914 .35786 Mtetra
.653 .809 .958 r
.41914 .35786 .42698 .36424 .44024 .35939 .43245 .35318 Mtetra
.682 .823 .951 r
.43245 .35318 .44024 .35939 .45359 .35368 .44584 .34767 Mtetra
.56 .791 .986 r
.44584 .34767 .45359 .35368 .46692 .35202 .45924 .34493 Mtetra
.188 .562 .935 r
.45924 .34493 .46692 .35202 .48017 .36241 .47262 .34822 Mtetra
.642 .632 .825 r
.47262 .34822 .48017 .36241 .49377 .35797 .48624 .34348 Mtetra
.701 .655 .801 r
.48624 .34348 .49377 .35797 .50745 .34966 .49994 .33553 Mtetra
.655 .64 .823 r
.49994 .33553 .50745 .34966 .52116 .34172 .51368 .33019 Mtetra
.653 .686 .868 r
.51368 .33019 .52116 .34172 .53493 .3362 .52748 .32533 Mtetra
.665 .706 .877 r
.52748 .32533 .53493 .3362 .54877 .33217 .54135 .32004 Mtetra
.679 .687 .851 r
.54135 .32004 .54877 .33217 .56268 .32795 .55527 .31392 Mtetra
.687 .659 .817 r
.55527 .31392 .56268 .32795 .57665 .32251 .56924 .30687 Mtetra
.687 .637 .795 r
.56924 .30687 .57665 .32251 .59064 .31488 .58326 .29932 Mtetra
.681 .636 .798 r
.58326 .29932 .59064 .31488 .60464 .30593 .59733 .29212 Mtetra
.675 .659 .827 r
.59733 .29212 .60464 .30593 .61868 .2973 .61147 .28576 Mtetra
.668 .698 .869 r
.61147 .28576 .61868 .2973 .63282 .29021 .6257 .28019 Mtetra
.661 .73 .901 r
.6257 .28019 .63282 .29021 .64706 .28439 .64001 .27502 Mtetra
.657 .746 .915 r
.64001 .27502 .64706 .28439 .66139 .27921 .6544 .26999 Mtetra
.656 .75 .919 r
.6544 .26999 .66139 .27921 .6758 .2742 .66887 .26498 Mtetra
.656 .751 .92 r
.66887 .26498 .6758 .2742 .69029 .26922 .68341 .25995 Mtetra
.68341 .25995 .69029 .26922 .70486 .2642 .69802 .25489 Mtetra
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Mtetra
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Mtetra
.19469 .41828 .20315 .42611 .21539 .42189 .20696 .41401 Mtetra
.655 .751 .92 r
.20696 .41401 .21539 .42189 .22767 .41774 .21929 .40974 Mtetra
.653 .748 .92 r
.21929 .40974 .22767 .41774 .23999 .41389 .23167 .40551 Mtetra
.644 .737 .916 r
.23167 .40551 .23999 .41389 .25229 .41094 .24408 .40154 Mtetra
.621 .704 .905 r
.24408 .40154 .25229 .41094 .26453 .40957 .25651 .39823 Mtetra
.583 .646 .878 r
.25651 .39823 .26453 .40957 .27674 .40965 .2689 .39607 Mtetra
.547 .588 .846 r
.2689 .39607 .27674 .40965 .28907 .40944 .28128 .39513 Mtetra
.538 .572 .836 r
.28128 .39513 .28907 .40944 .30165 .40672 .29372 .39451 Mtetra
.571 .626 .868 r
.29372 .39451 .30165 .40672 .31452 .40091 .30634 .39272 Mtetra
.64 .747 .926 r
.30634 .39272 .31452 .40091 .32752 .39366 .31917 .38872 Mtetra
.698 .856 .958 r
.31917 .38872 .32752 .39366 .34053 .38682 .33219 .3828 Mtetra
.717 .887 .959 r
.33219 .3828 .34053 .38682 .35353 .38111 .34529 .37616 Mtetra
.71 .86 .954 r
.34529 .37616 .35353 .38111 .36655 .37611 .35843 .36983 Mtetra
.69 .818 .944 r
.35843 .36983 .36655 .37611 .3796 .37145 .37158 .36419 Mtetra
.67 .787 .936 r
.37158 .36419 .3796 .37145 .39272 .36681 .38476 .35915 Mtetra
.658 .773 .934 r
.38476 .35915 .39272 .36681 .4059 .3623 .39799 .35446 Mtetra
.647 .766 .935 r
.39799 .35446 .4059 .3623 .41914 .35786 .41126 .3501 Mtetra
.632 .764 .942 r
.41126 .3501 .41914 .35786 .43245 .35318 .4246 .34611 Mtetra
.611 .778 .961 r
.4246 .34611 .43245 .35318 .44584 .34767 .43799 .34252 Mtetra
.533 .809 .997 r
.43799 .34252 .44584 .34767 .45924 .34493 .45143 .33988 Mtetra
.581 .832 .992 r
.45143 .33988 .45924 .34493 .47262 .34822 .46498 .3363 Mtetra
.724 .705 .831 r
.46498 .3363 .47262 .34822 .48624 .34348 .47868 .32796 Mtetra
.707 .645 .785 r
.47868 .32796 .48624 .34348 .49994 .33553 .49241 .31917 Mtetra
.652 .609 .793 r
.49241 .31917 .49994 .33553 .51368 .33019 .50617 .31345 Mtetra
.631 .595 .795 r
.50617 .31345 .51368 .33019 .52748 .32533 .51998 .30877 Mtetra
.639 .601 .796 r
.51998 .30877 .52748 .32533 .54135 .32004 .53386 .3037 Mtetra
.648 .609 .797 r
.53386 .3037 .54135 .32004 .55527 .31392 .54781 .29816 Mtetra
.655 .621 .803 r
.54781 .29816 .55527 .31392 .56924 .30687 .56181 .29236 Mtetra
.659 .641 .821 r
.56181 .29236 .56924 .30687 .58326 .29932 .57589 .28661 Mtetra
.661 .673 .85 r
.57589 .28661 .58326 .29932 .59733 .29212 .59003 .28111 Mtetra
.661 .707 .882 r
.59003 .28111 .59733 .29212 .61147 .28576 .60424 .27587 Mtetra
.658 .733 .905 r
.60424 .27587 .61147 .28576 .6257 .28019 .61853 .27078 Mtetra
.657 .746 .916 r
.61853 .27078 .6257 .28019 .64001 .27502 .6329 .26575 Mtetra
.656 .75 .919 r
.6329 .26575 .64001 .27502 .6544 .26999 .64734 .26072 Mtetra
.656 .751 .92 r
.64734 .26072 .6544 .26999 .66887 .26498 .66186 .25567 Mtetra
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Mtetra
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Mtetra
.19846 .40607 .20696 .41401 .21929 .40974 .21082 .40174 Mtetra
.655 .751 .92 r
.21082 .40174 .21929 .40974 .23167 .40551 .22324 .3974 Mtetra
.654 .748 .919 r
.22324 .3974 .23167 .40551 .24408 .40154 .23572 .39309 Mtetra
.649 .739 .915 r
.23572 .39309 .24408 .40154 .25651 .39823 .24824 .38892 Mtetra
.635 .714 .904 r
.24824 .38892 .25651 .39823 .2689 .39607 .2608 .38512 Mtetra
.612 .669 .88 r
.2608 .38512 .2689 .39607 .28128 .39513 .27336 .38201 Mtetra
.585 .616 .849 r
.27336 .38201 .28128 .39513 .29372 .39451 .28593 .37975 Mtetra
.567 .581 .827 r
.28593 .37975 .29372 .39451 .30634 .39272 .29853 .37813 Mtetra
.566 .584 .831 r
.29853 .37813 .30634 .39272 .31917 .38872 .31121 .37654 Mtetra
.587 .637 .868 r
.31121 .37654 .31917 .38872 .33219 .3828 .32403 .37417 Mtetra
.623 .734 .926 r
.32403 .37417 .33219 .3828 .34529 .37616 .337 .37057 Mtetra
.651 .83 .969 r
.337 .37057 .34529 .37616 .35843 .36983 .3501 .36586 Mtetra
.657 .881 .981 r
.3501 .36586 .35843 .36983 .37158 .36419 .36329 .36056 Mtetra
.652 .89 .983 r
.36329 .36056 .37158 .36419 .38476 .35915 .37655 .35521 Mtetra
.642 .88 .985 r
.37655 .35521 .38476 .35915 .39799 .35446 .38985 .35013 Mtetra
.63 .867 .987 r
.38985 .35013 .39799 .35446 .41126 .3501 .40319 .3454 Mtetra
.617 .853 .988 r
.40319 .3454 .41126 .3501 .4246 .34611 .41659 .34103 Mtetra
.625 .845 .984 r
.41659 .34103 .4246 .34611 .43799 .34252 .43006 .33659 Mtetra
.673 .835 .961 r
.43006 .33659 .43799 .34252 .45143 .33988 .44363 .33115 Mtetra
.728 .773 .889 r
.44363 .33115 .45143 .33988 .46498 .3363 .4573 .32368 Mtetra
.727 .695 .82 r
.4573 .32368 .46498 .3363 .47868 .32796 .47104 .31489 Mtetra
.704 .68 .824 r
.47104 .31489 .47868 .32796 .49241 .31917 .4848 .30724 Mtetra
.673 .689 .856 r
.4848 .30724 .49241 .31917 .50617 .31345 .49858 .30142 Mtetra
.654 .68 .862 r
.49858 .30142 .50617 .31345 .51998 .30877 .51243 .2964 Mtetra
.648 .672 .859 r
.51243 .2964 .51998 .30877 .53386 .3037 .52634 .29156 Mtetra
.649 .677 .863 r
.52634 .29156 .53386 .3037 .54781 .29816 .54032 .28668 Mtetra
.654 .694 .874 r
.54032 .28668 .54781 .29816 .56181 .29236 .55438 .28166 Mtetra
.657 .712 .889 r
.55438 .28166 .56181 .29236 .57589 .28661 .5685 .2766 Mtetra
.657 .73 .903 r
.5685 .2766 .57589 .28661 .59003 .28111 .5827 .27156 Mtetra
.657 .742 .913 r
.5827 .27156 .59003 .28111 .60424 .27587 .59697 .26653 Mtetra
.656 .748 .918 r
.59697 .26653 .60424 .27587 .61853 .27078 .61131 .2615 Mtetra
.656 .751 .92 r
.61131 .2615 .61853 .27078 .6329 .26575 .62573 .25645 Mtetra
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Mtetra
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Mtetra
.20228 .39369 .21082 .40174 .22324 .3974 .21474 .38931 Mtetra
.21474 .38931 .22324 .3974 .23572 .39309 .22725 .3849 Mtetra
.655 .749 .919 r
.22725 .3849 .23572 .39309 .24824 .38892 .23983 .3805 Mtetra
.653 .744 .917 r
.23983 .3805 .24824 .38892 .2608 .38512 .25246 .37614 Mtetra
.647 .729 .908 r
.25246 .37614 .2608 .38512 .27336 .38201 .26514 .37192 Mtetra
.636 .7 .892 r
.26514 .37192 .27336 .38201 .28593 .37975 .27786 .36801 Mtetra
.621 .66 .866 r
.27786 .36801 .28593 .37975 .29853 .37813 .29061 .3645 Mtetra
.607 .62 .839 r
.29061 .3645 .29853 .37813 .31121 .37654 .30341 .36139 Mtetra
.597 .593 .818 r
.30341 .36139 .31121 .37654 .32403 .37417 .31625 .35857 Mtetra
.594 .586 .813 r
.31625 .35857 .32403 .37417 .337 .37057 .32918 .35579 Mtetra
.601 .602 .824 r
.32918 .35579 .337 .37057 .3501 .36586 .34219 .35276 Mtetra
.617 .637 .848 r
.34219 .35276 .3501 .36586 .36329 .36056 .35531 .34923 Mtetra
.635 .68 .875 r
.35531 .34923 .36329 .36056 .37655 .35521 .36853 .34512 Mtetra
.653 .714 .893 r
.36853 .34512 .37655 .35521 .38985 .35013 .38185 .34048 Mtetra
.667 .73 .897 r
.38185 .34048 .38985 .35013 .40319 .3454 .39525 .33533 Mtetra
.681 .726 .884 r
.39525 .33533 .40319 .3454 .41659 .34103 .40873 .32959 Mtetra
.69 .702 .856 r
.40873 .32959 .41659 .34103 .43006 .33659 .4223 .32316 Mtetra
.692 .668 .822 r
.4223 .32316 .43006 .33659 .44363 .33115 .43593 .31608 Mtetra
.684 .642 .801 r
.43593 .31608 .44363 .33115 .4573 .32368 .44962 .30891 Mtetra
.672 .641 .811 r
.44962 .30891 .4573 .32368 .47104 .31489 .46334 .30249 Mtetra
.663 .676 .853 r
.46334 .30249 .47104 .31489 .4848 .30724 .4771 .29704 Mtetra
.659 .721 .895 r
.4771 .29704 .4848 .30724 .49858 .30142 .49091 .29202 Mtetra
.657 .741 .912 r
.49091 .29202 .49858 .30142 .51243 .2964 .5048 .28708 Mtetra
.654 .743 .915 r
.5048 .28708 .51243 .2964 .52634 .29156 .51876 .28221 Mtetra
.655 .744 .915 r
.51876 .28221 .52634 .29156 .54032 .28668 .53279 .27729 Mtetra
.656 .744 .915 r
.53279 .27729 .54032 .28668 .55438 .28166 .54689 .2723 Mtetra
.656 .746 .916 r
.54689 .2723 .55438 .28166 .5685 .2766 .56106 .2673 Mtetra
.656 .749 .918 r
.56106 .2673 .5685 .2766 .5827 .27156 .5753 .26227 Mtetra
.656 .75 .92 r
.5753 .26227 .5827 .27156 .59697 .26653 .58962 .25723 Mtetra
.656 .751 .92 r
.58962 .25723 .59697 .26653 .61131 .2615 .60402 .25215 Mtetra
.60402 .25215 .61131 .2615 .62573 .25645 .61848 .24706 Mtetra
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Mtetra
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Mtetra
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Mtetra
.21871 .3767 .22725 .3849 .23983 .3805 .23132 .37223 Mtetra
.655 .75 .92 r
.23132 .37223 .23983 .3805 .25246 .37614 .24399 .36775 Mtetra
.655 .748 .918 r
.24399 .36775 .25246 .37614 .26514 .37192 .25673 .36325 Mtetra
.654 .742 .914 r
.25673 .36325 .26514 .37192 .27786 .36801 .26952 .35878 Mtetra
.65 .728 .906 r
.26952 .35878 .27786 .36801 .29061 .3645 .28237 .35439 Mtetra
.644 .706 .892 r
.28237 .35439 .29061 .3645 .30341 .36139 .29527 .35013 Mtetra
.637 .679 .873 r
.29527 .35013 .30341 .36139 .31625 .35857 .30823 .34601 Mtetra
.632 .653 .853 r
.30823 .34601 .31625 .35857 .32918 .35579 .32125 .34194 Mtetra
.629 .63 .833 r
.32125 .34194 .32918 .35579 .34219 .35276 .33434 .33785 Mtetra
.627 .614 .818 r
.33434 .33785 .34219 .35276 .35531 .34923 .3475 .33366 Mtetra
.629 .606 .809 r
.3475 .33366 .35531 .34923 .36853 .34512 .36075 .32928 Mtetra
.634 .606 .804 r
.36075 .32928 .36853 .34512 .38185 .34048 .37407 .32461 Mtetra
.64 .609 .803 r
.37407 .32461 .38185 .34048 .39525 .33533 .38748 .31962 Mtetra
.646 .615 .804 r
.38748 .31962 .39525 .33533 .40873 .32959 .40096 .31434 Mtetra
.651 .624 .81 r
.40096 .31434 .40873 .32959 .4223 .32316 .4145 .3089 Mtetra
.653 .64 .824 r
.4145 .3089 .4223 .32316 .43593 .31608 .42811 .30352 Mtetra
.656 .671 .852 r
.42811 .30352 .43593 .31608 .44962 .30891 .44178 .29831 Mtetra
.661 .713 .887 r
.44178 .29831 .44962 .30891 .46334 .30249 .45551 .29316 Mtetra
.664 .745 .91 r
.45551 .29316 .46334 .30249 .4771 .29704 .46931 .28799 Mtetra
.661 .752 .918 r
.46931 .28799 .4771 .29704 .49091 .29202 .48317 .2829 Mtetra
.656 .75 .919 r
.48317 .2829 .49091 .29202 .5048 .28708 .4971 .27797 Mtetra
.654 .75 .921 r
.4971 .27797 .5048 .28708 .51876 .28221 .51111 .27307 Mtetra
.656 .752 .92 r
.51111 .27307 .51876 .28221 .53279 .27729 .52518 .26808 Mtetra
.656 .751 .92 r
.52518 .26808 .53279 .27729 .54689 .2723 .53933 .26305 Mtetra
.53933 .26305 .54689 .2723 .56106 .2673 .55355 .25801 Mtetra
.55355 .25801 .56106 .2673 .5753 .26227 .56784 .25294 Mtetra
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Mtetra
.58221 .24784 .58962 .25723 .60402 .25215 .59665 .24272 Mtetra
.59665 .24272 .60402 .25215 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Mtetra
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Mtetra
.22273 .36392 .23132 .37223 .24399 .36775 .23544 .35938 Mtetra
.23544 .35938 .24399 .36775 .25673 .36325 .24821 .35483 Mtetra
.655 .75 .92 r
.24821 .35483 .25673 .36325 .26952 .35878 .26105 .35026 Mtetra
.655 .749 .919 r
.26105 .35026 .26952 .35878 .28237 .35439 .27395 .34567 Mtetra
.656 .745 .916 r
.27395 .34567 .28237 .35439 .29527 .35013 .28691 .34104 Mtetra
.655 .737 .91 r
.28691 .34104 .29527 .35013 .30823 .34601 .29993 .33642 Mtetra
.652 .725 .902 r
.29993 .33642 .30823 .34601 .32125 .34194 .31302 .33185 Mtetra
.649 .713 .894 r
.31302 .33185 .32125 .34194 .33434 .33785 .32617 .3273 Mtetra
.649 .704 .887 r
.32617 .3273 .33434 .33785 .3475 .33366 .33938 .32274 Mtetra
.649 .696 .881 r
.33938 .32274 .3475 .33366 .36075 .32928 .35267 .31811 Mtetra
.65 .693 .877 r
.35267 .31811 .36075 .32928 .37407 .32461 .36602 .3134 Mtetra
.652 .693 .876 r
.36602 .3134 .37407 .32461 .38748 .31962 .37945 .3086 Mtetra
.654 .699 .879 r
.37945 .3086 .38748 .31962 .40096 .31434 .39294 .3037 Mtetra
.657 .71 .887 r
.39294 .3037 .40096 .31434 .4145 .3089 .40651 .29873 Mtetra
.66 .722 .895 r
.40651 .29873 .4145 .3089 .42811 .30352 .42014 .29367 Mtetra
.661 .731 .901 r
.42014 .29367 .42811 .30352 .44178 .29831 .43385 .28857 Mtetra
.658 .734 .906 r
.43385 .28857 .44178 .29831 .45551 .29316 .44761 .28356 Mtetra
.654 .737 .911 r
.44761 .28356 .45551 .29316 .46931 .28799 .46145 .27868 Mtetra
.652 .744 .918 r
.46145 .27868 .46931 .28799 .48317 .2829 .47535 .27385 Mtetra
.654 .753 .922 r
.47535 .27385 .48317 .2829 .4971 .27797 .48933 .26891 Mtetra
.657 .755 .922 r
.48933 .26891 .4971 .27797 .51111 .27307 .50338 .26385 Mtetra
.657 .752 .92 r
.50338 .26385 .51111 .27307 .52518 .26808 .5175 .25877 Mtetra
.656 .751 .92 r
.5175 .25877 .52518 .26808 .53933 .26305 .5317 .25371 Mtetra
.5317 .25371 .53933 .26305 .55355 .25801 .54597 .24863 Mtetra
.54597 .24863 .55355 .25801 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Mtetra
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35096 Mtetra
.22681 .35096 .23544 .35938 .24821 .35483 .23962 .34636 Mtetra
.23962 .34636 .24821 .35483 .26105 .35026 .25249 .34173 Mtetra
.25249 .34173 .26105 .35026 .27395 .34567 .26543 .33709 Mtetra
.655 .75 .92 r
.26543 .33709 .27395 .34567 .28691 .34104 .27843 .33245 Mtetra
.655 .751 .921 r
.27843 .33245 .28691 .34104 .29993 .33642 .29149 .32778 Mtetra
.656 .751 .92 r
.29149 .32778 .29993 .33642 .31302 .33185 .30462 .32306 Mtetra
.657 .749 .918 r
.30462 .32306 .31302 .33185 .32617 .3273 .31782 .31828 Mtetra
.657 .744 .914 r
.31782 .31828 .32617 .3273 .33938 .32274 .33109 .31348 Mtetra
.656 .739 .911 r
.33109 .31348 .33938 .32274 .35267 .31811 .34442 .30866 Mtetra
.656 .736 .908 r
.34442 .30866 .35267 .31811 .36602 .3134 .35782 .30384 Mtetra
.656 .734 .907 r
.35782 .30384 .36602 .3134 .37945 .3086 .37128 .29899 Mtetra
.655 .734 .907 r
.37128 .29899 .37945 .3086 .39294 .3037 .38481 .29413 Mtetra
.655 .735 .909 r
.38481 .29413 .39294 .3037 .40651 .29873 .39841 .28928 Mtetra
.653 .739 .913 r
.39841 .28928 .40651 .29873 .42014 .29367 .41208 .28444 Mtetra
.652 .745 .918 r
.41208 .28444 .42014 .29367 .43385 .28857 .42581 .27962 Mtetra
.654 .754 .924 r
.42581 .27962 .43385 .28857 .44761 .28356 .43962 .27474 Mtetra
.657 .76 .926 r
.43962 .27474 .44761 .28356 .46145 .27868 .45351 .26973 Mtetra
.659 .758 .923 r
.45351 .26973 .46145 .27868 .47535 .27385 .46746 .26463 Mtetra
.658 .753 .92 r
.46746 .26463 .47535 .27385 .48933 .26891 .48149 .25952 Mtetra
.656 .748 .918 r
.48149 .25952 .48933 .26891 .50338 .26385 .49558 .25446 Mtetra
.655 .749 .919 r
.49558 .25446 .50338 .26385 .5175 .25877 .50975 .24941 Mtetra
.655 .751 .921 r
.50975 .24941 .5175 .25877 .5317 .25371 .52399 .24431 Mtetra
.656 .752 .92 r
.52399 .24431 .5317 .25371 .54597 .24863 .53831 .23916 Mtetra
.656 .751 .92 r
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35096 .2181 .34245 Mtetra
.2181 .34245 .22681 .35096 .23962 .34636 .23095 .33781 Mtetra
.23095 .33781 .23962 .34636 .25249 .34173 .24386 .33315 Mtetra
.656 .752 .92 r
.24386 .33315 .25249 .34173 .26543 .33709 .25683 .32847 Mtetra
.657 .752 .92 r
.25683 .32847 .26543 .33709 .27843 .33245 .26987 .32374 Mtetra
.656 .75 .919 r
.26987 .32374 .27843 .33245 .29149 .32778 .28298 .31899 Mtetra
.655 .749 .919 r
.28298 .31899 .29149 .32778 .30462 .32306 .29615 .31424 Mtetra
.654 .75 .92 r
.29615 .31424 .30462 .32306 .31782 .31828 .30938 .30951 Mtetra
.654 .752 .921 r
.30938 .30951 .31782 .31828 .33109 .31348 .32268 .30475 Mtetra
.655 .754 .923 r
.32268 .30475 .33109 .31348 .34442 .30866 .33605 .29995 Mtetra
.655 .756 .924 r
.33605 .29995 .34442 .30866 .35782 .30384 .34949 .29511 Mtetra
.655 .757 .924 r
.34949 .29511 .35782 .30384 .37128 .29899 .36299 .29025 Mtetra
.656 .758 .925 r
.36299 .29025 .37128 .29899 .38481 .29413 .37657 .28535 Mtetra
.656 .758 .924 r
.37657 .28535 .38481 .29413 .39841 .28928 .39021 .2804 Mtetra
.658 .757 .923 r
.39021 .2804 .39841 .28928 .41208 .28444 .40393 .27539 Mtetra
.659 .754 .921 r
.40393 .27539 .41208 .28444 .42581 .27962 .41772 .27032 Mtetra
.658 .749 .917 r
.41772 .27032 .42581 .27962 .43962 .27474 .43157 .26526 Mtetra
.656 .745 .915 r
.43157 .26526 .43962 .27474 .45351 .26973 .4455 .26022 Mtetra
.654 .745 .916 r
.4455 .26022 .45351 .26973 .46746 .26463 .45949 .25522 Mtetra
.654 .748 .919 r
.45949 .25522 .46746 .26463 .48149 .25952 .47356 .25021 Mtetra
.655 .752 .921 r
.47356 .25021 .48149 .25952 .49558 .25446 .48771 .24512 Mtetra
.656 .753 .921 r
.48771 .24512 .49558 .25446 .50975 .24941 .50192 .23996 Mtetra
.656 .752 .92 r
.50192 .23996 .50975 .24941 .52399 .24431 .51622 .23479 Mtetra
.656 .751 .92 r
.51622 .23479 .52399 .24431 .53831 .23916 .53058 .22961 Mtetra
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Mtetra
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32447 Mtetra
.23514 .32447 .24386 .33315 .25683 .32847 .24816 .31975 Mtetra
.655 .751 .92 r
.24816 .31975 .25683 .32847 .26987 .32374 .26123 .31502 Mtetra
.655 .752 .921 r
.26123 .31502 .26987 .32374 .28298 .31899 .27437 .31025 Mtetra
.656 .753 .921 r
.27437 .31025 .28298 .31899 .29615 .31424 .28758 .30544 Mtetra
.657 .753 .921 r
.28758 .30544 .29615 .31424 .30938 .30951 .30086 .30058 Mtetra
.657 .751 .919 r
.30086 .30058 .30938 .30951 .32268 .30475 .31421 .29569 Mtetra
.657 .749 .918 r
.31421 .29569 .32268 .30475 .33605 .29995 .32762 .29079 Mtetra
.656 .747 .917 r
.32762 .29079 .33605 .29995 .34949 .29511 .3411 .28588 Mtetra
.656 .746 .916 r
.3411 .28588 .34949 .29511 .36299 .29025 .35465 .28095 Mtetra
.35465 .28095 .36299 .29025 .37657 .28535 .36827 .276 Mtetra
.655 .745 .916 r
.36827 .276 .37657 .28535 .39021 .2804 .38195 .27104 Mtetra
.654 .746 .917 r
.38195 .27104 .39021 .2804 .40393 .27539 .39571 .26608 Mtetra
.654 .748 .919 r
.39571 .26608 .40393 .27539 .41772 .27032 .40953 .26112 Mtetra
.654 .752 .922 r
.40953 .26112 .41772 .27032 .43157 .26526 .42343 .25613 Mtetra
.655 .756 .924 r
.42343 .25613 .43157 .26526 .4455 .26022 .4374 .25106 Mtetra
.657 .756 .923 r
.4374 .25106 .4455 .26022 .45949 .25522 .45145 .24593 Mtetra
.657 .755 .922 r
.45145 .24593 .45949 .25522 .47356 .25021 .46557 .24075 Mtetra
.656 .751 .92 r
.46557 .24075 .47356 .25021 .48771 .24512 .47976 .23557 Mtetra
.655 .75 .919 r
.47976 .23557 .48771 .24512 .50192 .23996 .49402 .2304 Mtetra
.655 .751 .92 r
.49402 .2304 .50192 .23996 .51622 .23479 .50836 .2252 Mtetra
.656 .752 .92 r
.50836 .2252 .51622 .23479 .53058 .22961 .52278 .21996 Mtetra
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.656 .751 .92 r
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33459 Mtetra
.17479 .33459 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .3252 Mtetra
.20044 .3252 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.21336 .32048 .22219 .32918 .23514 .32447 .22635 .31574 Mtetra
.656 .752 .92 r
.22635 .31574 .23514 .32447 .24816 .31975 .2394 .31096 Mtetra
.2394 .31096 .24816 .31975 .26123 .31502 .25252 .30615 Mtetra
.656 .751 .92 r
.25252 .30615 .26123 .31502 .27437 .31025 .2657 .30131 Mtetra
.655 .75 .919 r
.2657 .30131 .27437 .31025 .28758 .30544 .27895 .29648 Mtetra
.655 .75 .92 r
.27895 .29648 .28758 .30544 .30086 .30058 .29226 .29164 Mtetra
.655 .752 .921 r
.29226 .29164 .30086 .30058 .31421 .29569 .30564 .28679 Mtetra
.655 .754 .923 r
.30564 .28679 .31421 .29569 .32762 .29079 .3191 .28189 Mtetra
.655 .756 .923 r
.3191 .28189 .32762 .29079 .3411 .28588 .33262 .27696 Mtetra
.656 .756 .924 r
.33262 .27696 .3411 .28588 .35465 .28095 .34621 .272 Mtetra
.656 .757 .924 r
.34621 .272 .35465 .28095 .36827 .276 .35987 .26701 Mtetra
.35987 .26701 .36827 .276 .38195 .27104 .3736 .26197 Mtetra
.657 .756 .923 r
.3736 .26197 .38195 .27104 .39571 .26608 .3874 .2569 Mtetra
.658 .755 .922 r
.3874 .2569 .39571 .26608 .40953 .26112 .40128 .25177 Mtetra
.657 .752 .92 r
.40128 .25177 .40953 .26112 .42343 .25613 .41522 .24662 Mtetra
.656 .749 .918 r
.41522 .24662 .42343 .25613 .4374 .25106 .42924 .24148 Mtetra
.655 .748 .918 r
.42924 .24148 .4374 .25106 .45145 .24593 .44333 .23635 Mtetra
.655 .749 .919 r
.44333 .23635 .45145 .24593 .46557 .24075 .45749 .2312 Mtetra
.655 .751 .92 r
.45749 .2312 .46557 .24075 .47976 .23557 .47173 .22601 Mtetra
.656 .752 .921 r
.47173 .22601 .47976 .23557 .49402 .2304 .48604 .22077 Mtetra
.656 .752 .92 r
.48604 .22077 .49402 .2304 .50836 .2252 .50043 .2155 Mtetra
.656 .751 .92 r
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21021 Mtetra
.5149 .21021 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33459 .16576 .32593 Mtetra
.16576 .32593 .17479 .33459 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .3252 .19149 .31646 Mtetra
.19149 .31646 .20044 .3252 .21336 .32048 .20445 .3117 Mtetra
.20445 .3117 .21336 .32048 .22635 .31574 .21747 .3069 Mtetra
.21747 .3069 .22635 .31574 .2394 .31096 .23056 .30208 Mtetra
.655 .751 .92 r
.23056 .30208 .2394 .31096 .25252 .30615 .24371 .29726 Mtetra
.655 .752 .921 r
.24371 .29726 .25252 .30615 .2657 .30131 .25693 .29241 Mtetra
.656 .753 .921 r
.25693 .29241 .2657 .30131 .27895 .29648 .27022 .28751 Mtetra
.657 .753 .921 r
.27022 .28751 .27895 .29648 .29226 .29164 .28358 .28256 Mtetra
.657 .751 .919 r
.28358 .28256 .29226 .29164 .30564 .28679 .29701 .27758 Mtetra
.657 .749 .918 r
.29701 .27758 .30564 .28679 .3191 .28189 .31051 .27259 Mtetra
.656 .748 .917 r
.31051 .27259 .3191 .28189 .33262 .27696 .32407 .26759 Mtetra
.656 .747 .917 r
.32407 .26759 .33262 .27696 .34621 .272 .3377 .26256 Mtetra
.3377 .26256 .34621 .272 .35987 .26701 .35141 .25752 Mtetra
.655 .746 .917 r
.35141 .25752 .35987 .26701 .3736 .26197 .36518 .25246 Mtetra
.655 .747 .917 r
.36518 .25246 .3736 .26197 .3874 .2569 .37903 .24739 Mtetra
.654 .748 .919 r
.37903 .24739 .3874 .2569 .40128 .25177 .39294 .24232 Mtetra
.654 .751 .92 r
.39294 .24232 .40128 .25177 .41522 .24662 .40693 .23721 Mtetra
.655 .753 .922 r
.40693 .23721 .41522 .24662 .42924 .24148 .42099 .23206 Mtetra
.656 .754 .922 r
.42099 .23206 .42924 .24148 .44333 .23635 .43513 .22685 Mtetra
.657 .754 .921 r
.43513 .22685 .44333 .23635 .45749 .2312 .44934 .22159 Mtetra
.656 .752 .92 r
.44934 .22159 .45749 .2312 .47173 .22601 .46363 .21631 Mtetra
.656 .751 .92 r
.46363 .21631 .47173 .22601 .48604 .22077 .47799 .21103 Mtetra
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Mtetra
.49243 .20572 .50043 .2155 .5149 .21021 .50694 .20038 Mtetra
.50694 .20038 .5149 .21021 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17872 Mtetra
.56578 .17872 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .1397 Mtetra
.67184 .1397 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35448 Mtetra
.056 .35448 .06538 .36287 .07772 .35833 .06836 .34989 Mtetra
.06836 .34989 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Mtetra
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Mtetra
.656 .752 .92 r
.20851 .29799 .21747 .3069 .23056 .30208 .22164 .29313 Mtetra
.22164 .29313 .23056 .30208 .24371 .29726 .23483 .28823 Mtetra
.656 .751 .92 r
.23483 .28823 .24371 .29726 .25693 .29241 .2481 .2833 Mtetra
.656 .75 .919 r
.2481 .2833 .25693 .29241 .27022 .28751 .26143 .27837 Mtetra
.655 .75 .92 r
.26143 .27837 .27022 .28751 .28358 .28256 .27482 .27344 Mtetra
.655 .752 .921 r
.27482 .27344 .28358 .28256 .29701 .27758 .28828 .26849 Mtetra
.655 .754 .922 r
.28828 .26849 .29701 .27758 .31051 .27259 .30182 .26351 Mtetra
.656 .755 .923 r
.30182 .26351 .31051 .27259 .32407 .26759 .31542 .25848 Mtetra
.656 .756 .923 r
.31542 .25848 .32407 .26759 .3377 .26256 .3291 .25342 Mtetra
.656 .756 .924 r
.3291 .25342 .3377 .26256 .35141 .25752 .34285 .24833 Mtetra
.656 .756 .923 r
.34285 .24833 .35141 .25752 .36518 .25246 .35667 .2432 Mtetra
.657 .756 .923 r
.35667 .2432 .36518 .25246 .37903 .24739 .37056 .23803 Mtetra
.657 .755 .922 r
.37056 .23803 .37903 .24739 .39294 .24232 .38452 .23281 Mtetra
.657 .752 .92 r
.38452 .23281 .39294 .24232 .40693 .23721 .39856 .22758 Mtetra
.656 .75 .919 r
.39856 .22758 .40693 .23721 .42099 .23206 .41267 .22235 Mtetra
.655 .749 .919 r
.41267 .22235 .42099 .23206 .43513 .22685 .42685 .21711 Mtetra
.42685 .21711 .43513 .22685 .44934 .22159 .44111 .21185 Mtetra
.656 .751 .92 r
.44111 .21185 .44934 .22159 .46363 .21631 .45544 .20655 Mtetra
.656 .752 .921 r
.45544 .20655 .46363 .21631 .47799 .21103 .46985 .20121 Mtetra
.656 .752 .92 r
.46985 .20121 .47799 .21103 .49243 .20572 .48434 .19583 Mtetra
.656 .751 .92 r
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17872 .55795 .16857 Mtetra
.55795 .16857 .56578 .17872 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .1397 .66439 .12915 Mtetra
.66439 .12915 .67184 .1397 .68732 .134 .67994 .1234 Mtetra
.67994 .1234 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03oool30:NojdD0Yl3[00<000000:O0j`2W`>/03@2W`>/A0?ooo`800000;P3oool003D0oooo
0`00001=0?ooo`H0Yko[A02W`>/00`000000Yl3[0:O0j`0>0:O0ja40oooo00<000000?ooo`3oool0
;03oool003<0oooo0P00001=0?ooo`T0Yko[A02W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<0
00000?ooo`3oool0:`3oool00300oooo0`00001;0?ooo`X0Yko[102X`N]30:O0j`030000002W`>/0
Yl3[0100Yl3[4@3oool00`000000oooo0?ooo`0Z0?ooo`00;P3oool3000004/0oooo0`2X`>/50:No
j`D0Yl7/102X`N]20:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool3000000<0oooo00<000000?ooo`3oool0AP3oool60:S0j`80Yko[0`2W`>`50:O1k080
Z<7[0P2W_n/50:O0j`D0Yko[=`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3o
ool0:@3oool002T0oooo0P00001;0?ooo`D0Z<7/1@2X`>/60:O0k0@0Yl7/1@2W_n/50:O0j`D0Yko[
=P2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?ooo`T0Z<7/1@2W`>/50:O0k0X0Yko[1@2W`>/40:NojcH0Yl3[00<000000:O0j`2W`>/04P2W
`>/A0?ooo`030000003oool0oooo02P0oooo000T0?ooo`800000B`3oool30:O1k0L0Z<7/0P2W_n/5
0:O0j`X0Yko[1@2X`N`m0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?oo
o`H0Yl7/102X`N`50:Noj`80Yl3[0`2X`>/70:Noj`P0Z<7/>@2W`>/300000080Yl3[00<000000:O0
j`2W`>/04P2W`>/B0?ooo`030000003oool0oooo02H0oooo000O0?ooo`<00000B@3oool:0:O1k0D0
YkoZ102W_n/60:S0j`@0Yko[202X`N`30:Noj`D0Yl3[102W_n//0:O0j`<000001@2W`>/00`000000
Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool09P3oool001d0oooo0P00001;0?ooo`L0Yl7/
1@2W_^X50:NojPD0Z<7/102X`>/50:O1k0D0Z<7/1P2W_n/20:O0j`L0Yko[:02W`>/3000000T0Yl3[
00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`800000
0`3oool4000000X0oooo000E0?ooo`D000000`3oool2000004T0oooo1`2W`N`30:NojPD0YkkZ2P2X
`N`50:O0k0@0Yl7/1@2W_^X?0:Noja40Yl3[0`2W_n/@0:O0j`<000003@2W`>/00`000000Yl3[0:O0
j`0C0:O0ja40oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`0000140?ooo`T0Yl7/1P2W
_nX20:NnjP<0Yl7/1`2X`N`30:Noj`D0Yl3/2@2W_^X50:S0j`D0Yko[1@2X`>/>0:O0j`H0Yko[0P2W
`>/30:Noj`H0Yl3[0P2W_n/200000140Yl3[00<000000:O0j`2W`>/04`2W`>/@0?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0:0?ooo`005`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000003l0oooo2P2W`N`90:NojPH0Yl7/
102X`N`60:Noj`80Yl3/0`2X_nX60:NnjP<0Z<;/1@2X`>/50:S1k0D0Z<3[2@2W`>/@0:Noj`<0Yl3[
00@0Yko[00000000000000000P2W_n/20:O0j`<0Yko[302W`>/00`000000Yl3[0:O0j`0C0:O0ja40
oooo00<000000?ooo`3oool00`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`090?ooo`003`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo0P2W`>/50:O1k0X0YkoZ2@2W`N`50:NnjPD0
Yko[1P2X_nX30:NnjPH0Z<;/0P2X`>/30:O0k0D0Z<7/2@2W`>/50:NnjPD0Yko[1@2X_NT50:Noj`04
0:RnjP0000000000000000/0Yko[302W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000X0oooo000G
0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo03P0oooo1@2W`>/3
0:O1k080Z;o[1@2W_nX:0:O1k0T0YkkZ1@2X`N/50:RojPD0Z<;]102X`^`60:O0k080Z<7/0`2W_n/7
0:O0j`L0YkkZ1@2X^^L50:Rmj@80Z;_W0`0000090:RnjPD0Yko[3@2W`>/00`000000Yl3[0:O0j`0B
0:O0ja00oooo0P00000;0?ooo`8000002P3oool2000000/0oooo000F0?ooo`800000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03<0oooo1@2W_n/50:O0j`D0Z;o[0P2W_nX:0:O1
k0P0YkkZ102X`N`50:S1j`D0Yl7/1@2X`^d40:Jnj`D0Yl3/1P2W_n/40:O0j`L0YkkZ0`2X]^<50:Rj
i`80Z;gY00@0ZKCQ00000000000000000`2X^nL50:VjiPD0Z;kZ1@2X_nX=0:O0j`030000002W`>/0
Yl3[0180Yl3[4@3oool00`000000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?oo
o`800000<03oool90:Noj`D0Z<3[102X_n/:0:O1k0P0YkkZ0`2W`^`40:S1k0D0Y[k[1@2W`N`50:Nl
j@@0Y[k[2P2W_n/90:NnjPH0Z;KS102X^^L3000000<0ZKCQ0P2X^nL20:^bgPD0ZK[V1@2Y_>L50:Ro
jPD0Yko[1`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool0803oool001`0
oooo0P0000080?ooo`030000003oool0oooo02/0oooo0`2W`>/40:Noj`X0Z<3[2@2W`N`:0:NnjPH0
Yl;/0P2X`N`20:Nmj@D0Y[k[0P2W`N`30:Rki`D0YkcY102Y`>/50:Noj`X0YkkZ102W/Ml50:Rfh`05
0:V/f@00000000000000002Y[=T01@2Y]>450:^bgP80ZK[V0`2/]=h50:Vli`80Z;oZ0`2Y_^T40:No
j`P0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0:03oool60:O0j`80Yko[0P2W`>/50:S0j`D0
Yl3[1@2W`N`50:NojP@0YkkZ2P2W`^`50:Nmj@@0Y[k[1P2X^nL20:Nlj@<0ZKkX102Y`>/20:Noj`<0
Z;gY1@2W_^X50:J]g0@0Yk7O0P2X]^<3000000D0ZJcI0P2Y]>430:bXd`@0Zk;N1P2/]=h40:Vli`H0
ZKkY0P2W_n/20:RojPP0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01l0
oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool?0:O0j`<0Z<3[
0P2W_n/50:O0j`80Yl7/0`2X_n/50:NojP@0Yl7/1@2W`^`50:Nlj0D0YkgY102Y^nH50:Rki`H0ZKkX
0`2Y`>/60:Rmj@80YkkZ0`2U[=/50:J]g080Yk7O0`0000040:RTdP@0ZJcI1P2/Z=<20:^bgP80/:[B
1@2/]=h50:fhhPD0ZKkY1@2X_nX20:O0j`<0Z<3[0`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo
00<000000?ooo`3oool07P3oool001/0oooo0P00000<0?ooo`030000003oool0oooo01l0oooo4`2W
`>/50:Noj`@0Yl3[1P2X_n/20:NojPL0Yl7/1@2W^nP50:Nlj0D0Z;SU102Y^nH50:Vfh`D0ZKkX102X
^>D50:Rmj@D0YJcK1@2V[M`200000080Yik=1@2XY=850:jRc0D0[:SC1@2`Z]820:bdgP<0/joE1@2]
^>850:^miP@0Z;oZ1P2X`>/20:O0j`030000002W`>/0Yl3[01<0Yl3[403oool00`000000oooo0?oo
o`0N0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo4`2W`>/:
0:Noj`@0Z<3[1@2X_n/80:O1k0L0Yk_X0P2W_>P30:Reh`D0Z;SU0P2Y^nH20:N[fPD0ZKKS1@2Y[MX4
0:Rhi@D0YjkL1@2U[=/01@2V[M`00000000000000000YI_<00@0Yik=0P2XY=830:nSb`D0[Z;<0P2/
Z=<30;BVbP@0/:[B1P2c[mD20:fhhP<0/[KL102[_NH50:VojPD0Z<3[0`2W`>/00`000000Yl3[0:O0
j`0B0:O0ja40oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0H0?oooaH0Yl3[102W_n/90:S0j`X0Yl7/2@2W^nP60:Reh`@0Z;SU1@2WZmX2
0:Vfh`<0[:C?1@2Y[MX20:Rhi@80[;3K1@2W[]`20:F/f`<00000102UVl`40:NNc@D0[j?;1@2^X/`5
0;BVbP<0/:[B0P2hZ//50;>_e@H0/[KL0P2[_NH20:nmi0D0ZKoZ1@2X`>/30:O0j`030000002W`>/0
Yl3[0140Yl3[403oool2000001l0oooo000K0?ooo`8000003`3oool00`000000oooo0?ooo`0E0?oo
oad0Yl3[1@2X`>/50:O0j`@0Yl7/1@2W_>P50:Nkj0@0Yk;Q1@2X]N<50:NSdP@0Yj_J1@2/Y<l50:V]
fPD0[;3K0`2W[]`3000000<0XiW;1@2UVl`20:NNc@80[jSA1@2_Xl/30:jRc080]j_=1@2dY/X00`2`
Z]80^:[;0;RZb`020;RZb`80/joE0`2k[lh50;:fg0D0[kgT0P2Y_nX30:Zoj@@0Z<3[0`2W`>/00`00
0000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0A0?ooob40Yl3[1@2W_n/50:O0j`@0YkgY1@2W_>P50:Jah0@0
Yk;Q1@2VWll50:NSdP80Yj_J0P2_Y<d50:bTc`80ZJgJ0`2d[]840:b`f`<000000P2QV</40:>Ib`D0
YI_<102_Z=450:nSb`80[Z;<0`2gZld50;BVbPD0^:[;1P2k[lh20;:fg0<0^[OG102__N@60:Zoj@@0
Z<3[0`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo
0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0<0?ooob@0Yl3[1`2W_n/20:O0j`<0Z;kY102W_NT:0:Jah080Yk;Q0P2UWLd40:JOc`D0Yj?B
102_Y<d50:bTc`H0]:kB0`0000000`2VVl/0XIS;0:6Hb`020:6Hb`D0XiW;0P2UVl`30:f_f@@0[jSA
102_Xl/60;N[c@80]:K:0`2m[//30;RZb`80`:k81@2k[lh50;Zge`D0/kkR0`2Z_nT30:c0j@@0Z<3[
0`2W`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool06`3oool000L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`8000004`3oool00`000000
oooo0?ooo`0:0?ooob<0Yl3[2@2W_n/60:Rnj@80YkgY0P2V/^490:Jah0@0YIg=1@2VWll20:NSdP<0
/J_B102_Y<d20:bTc`<0^[7A0P2d[]83000000D0YY_;102QV</40:>Ib`D0[JoI102_Z=420:nSb`<0
]kWK1@2gZld50;f^b`80^:[;0`30[/P40;^_cP80`k780`2j]mL20<6idPD0/kkR1@2/`>T40:S0j`@0
Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01X0oooo00070?ooo`040000
003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo
00L0oooo8@2W`>/:0:Noj`@0Z;o[1@2X_^T50:Jbh@@0Y[7P1@2SVld40:FMc@@0YYo?1@2aZm840:nT
c@@0^[7A0`000000102d[]80]:G80;BUb02dYLP40:JKb`@0XIS;1@2Z]>050:f_f@<0[jSA1P2g^M/2
0;N[c@<0^KcL102m[//00`2hZ//0`:k80<2^b0030<2^b080^jo>1033/LP00`2j]mL0`KWB0<6idP02
0<6idP80/kkR0`2h`N440:c0j@D0Z<3[0`2W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<00000
0?ooo`3oool06@3oool000030?ooo`0000000000008000000P3oool010000000oooo0?ooo`000009
0?ooo`800000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo8P2W`>/5
0:S0j`@0Yko[1@2W`>/40:Roj`D0Y[CS1@2V/^440::Kc@@0Xi_=102UWLd20:JOc`<0/;?K1@2aZm82
0:nTc@80^/GS0`0000020;Zad@D0]:G81@2VVl/20:6Hb`80YjoN1@2Z]>040:f_f@@0[<c`1@2g^M/5
0;Vlg0@0_Jk;1P30[/P60<>ab0D0`KWB1P2h`N440:g1j@D0Z<3[0`2W`>/00`000000Yl3[0:O0j`0B
0:O0ja00oooo00<000000?ooo`3oool06@3oool000L0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`030?ooo`8000005P3oool00`000000Yl3[0:O0j`0T0:O0j`D0Z<3[2@2W`>/4
0:Jfi0D0Y[CS0P2V/^430:6Kc`<0XY_=1@2SVld30:FMc@H0/;?K102aZm820;[5h`80000000<0^/GS
0;Zad@2j/M400`2i]=@50;BUb0@0YY_;1@2W[mh40:Zdh0D0V]Wm102/c?020;Nif`<0XLcf1@2i_=`2
0;f^b`80_[OC1030[/P20<Fbb0@0`k780P39]<D30<6idP80bKg?0`2h`N430;c4h0@0[L7Y1@2X`>/3
0:O0j`030000002W`>/0Yl3[0140Yl3[403oool2000001X0oooo00080?ooo`8000002P3oool30000
00<0oooo00<000000?ooo`3oool04P3oool[0:O0j`80Z<3[0`2W_n/40:O0j`D0Y[WV102V]^@40:Jd
h`D0XI_?102RVld40:>Kc@@0[[WR1@2`/m/30:cEmP<000000`2jaN<50;Vde0D0]:G81@2WXm840:N_
gPD0S>3m1@2JfOd30:c<l0H0XLcf102i_=`50;jgd`80`:k80`35//P30<>ab0<0bKC50P31^M840<Vm
c`D0_<CP0P2]`NT30:g2j@D0Z<3[0`2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?oo
o`3oool05`3oool001T0oooo00<000000?ooo`3oool04P3oool/0:O0j`H0Yko[0P2W`>/20:Nlj0D0
Y[WV102V]^@40:2Md@D0XI_?0`2RVld50:Zji@@0[[WR0`2`/m/0102Of?/000000000000000030:cE
mP@0U=Cm1@2i]=@20;BUb0<0/jO=1@2WXm820:N_gP<0S^_b102<h?d507K9o`@0O<Wo102Qc?H50:?5
l@@0_[OC1P35//P00`33/LP0bKC50<Vda@020<Vda@D0bKg?0P3@`L`40;c4h0H0[L;Y1@2X`>/20:O0
j`030000002W`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0G0?ooo`006@3oool200000140
oooo;`2W`>/50:Noj`D0YkcX102V^NH50:6Qe@<0X9gA1@2QVll20::Kc@80YkKT1@2Z^^D40:jihP<0
00000P2Of?/508S?o`@0U=Cm102i]=@50;>Wc@D0Yj?B00<0S^_b09fjk02M^^`00`2M^^`508W8o@@0
N/?n101V^_d406jmo@D0XlGa0P2n]m<20;FkgPD0aK;81@39]<D0103?]/40bKg?0<Vmc`39_Ll40=31
c080_<CP0P2oan030:g2j@<0[L?Y102X`>/30:O0j`030000002W`>/0Yl3[0180Yl3[403oool00`00
0000oooo0?ooo`0F0?ooo`006@3oool00`000000oooo0?ooo`0=0?oooc<0Yl3[1@2W_^X50:Nlj0@0
XJOJ102QXMD40:2Md@@0XI_?1@2W]^@40:Zji@0409gJo0000000000000000080WM[l1@2LaoH408S?
o`@0U=Cm0P2i]=@20:BQd`D0/jO=0P2WXm80101VJl<0SIKH08fFf02=U]P509fjk0H0UM;m0`1j`oh4
06Jjo@@0K[gm102SaO440;FkgP@0aK;80P35]<T30<Vda@<0ckK100<0bKg?0=31c03@`L`00`3@`L`5
0;o7h0H0[L?Y102X`>/30:O0j`030000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0E
0?ooo`006@3oool00`000000oooo0?ooo`090?oooc@0Yl3[1@2W_n/40:NnjPD0XjgO0`2QYmX50:6Q
e@<0X9gA1@2R[]l40:Nfi080XMgl0`0000000`2QgO`0XL?a0:73l@030:73l@<0W<Of0P2^d_<408o:
o0<0<8o_102TXM<50;>Wc@<0IV_3102=U]P209fjk0@0]=ke1@2EaoP308NimP@0KkGk101;ZOP407:g
n`@0]K_N0P35//P40<Fdb@030<Vda@3?]/40ckK10080ckK11@3@`L`20=K7b`80_lOP0`31bN450:g3
j@D0Z<3[0`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool05@3oool001T0
oooo0P0000070?oooc@0Yl3[2@2W_n/40:Bdi0D0XjgO0`2QYmX40:6Qe@@0WJ?I1@2R[]l20:CQo0<0
000000<0Y>7l0:G4k`2Ua>l00P2Ua>l50:73l@D0[];c102?b_`3032?k`@0Y:7C0P2cYld20:bQb`@0
IV_30`2=U]P40;CNm@<0[NOi1@2EaoP308NimP@0KkGk101;ZOP307:gn`@0]K_N1P35]<T50<nf`@04
0=Fi_P3@`L`0d<7<0=31c0<0e/O;1P31bN450:g3jP@0Z<3[0`2W`>/00`000000Yl3[0:O0j`0B0:O0
ja00oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00`3ooolh0:O0j`@0
Yko[1@2V^^L40:Bdi0@0XjgO0`2QYmX509VJdP@0WJ?I0P2R[]l0102Vho/000000000000000050:S5
k`@0YLC_1@2WcoD30:kBl`80/<?X0`2</o020;o8h@80<8o_0`2TXM<0102n]m80[:7;0:bQb`2/XL/4
06I[``D0/];a1P2]ioT509>ZiP@0TkWa101i_o`303FMl`80=YKa1@2O]^P40<Fdb@80a;?90`3?]/43
0=Fi_P030=31c03Fal/0e/O;0080e/O;00@0flc:0<79h@31bN40`LWQ0`31bn840:g3jPD0Z<3[0`2W
`>/00`000000Yl3[0:O0j`0B0:O0ja00oooo00<000000?ooo`3oool04`3oool001P0oooo00<00000
0?ooo`3oool00`3ooolj0:O0j`80Yko[0P2W_NT50:Jji`<0Y;CT1@2HUm4309RFd0D0VI[B0`2MXmT3
00000080Y^?k0P2[bNl50:S5k`@0YLcd1@2WcoD50;33j0H0_lSQ102n]m84092[j0@0QJO[0`2bd_43
0;;dlPD0W:oU102CZ^H209>il@<0XmCi1020a_h302FAk@80=YKa102O]^P30<Fdb@<0a;?90`3?]/43
0=Fi_P@0e/O;0`3Kc<X50<7;hPD0[L;Z1@2X`>/30:O0j`030000002W`>/0Yl3[0140Yl3[3`3oool2
000001D0oooo000H0?ooo`040000003oool000000?oooc`0Yl3[1@2W_NT40:Jji`@0VikF102HUm43
09RFd0D0VI[B00<0Z>7k0000000000000`2XhO/50:_9k`80Z<G_0`2VcO@40:G<m0D0Z/G]0`2``nP2
0:g=l0D0_lSQ1@2^a>X4092[j0@0QJO[0P2bm?840:o6j`D0W:oU0`2CZ^H60:?Dn@@0P<Kn0`0UTNd0
0`00KM/0=YKa09nfj00309nfj0030<Fdb@34/lT0a;?900<0a;?900<0ckK10=Fi_P3E^Kh00P3E^Kh0
0`3K_K/0e/O;0=K7b`040=_<bP040=k@bP31bn80`L_R0<7;hP80_l_S1@2]`^X50:S0j`80Yl3[00<0
00000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`00603oool0
0`000000Yl3[0:O0j`0i0:O0j`D0Yko[102W_NT509jXg@<0VikF1@2HUm4309RFd080VI[B0`000000
0`2Ve?P0/=7a0;3Al@030;3Al@@0ZlW_1P2VcO@40:S4k@D0Z/G]1@2]cO020;o8h@<0ZlO^1@2^a>X3
092[j0@0U>7m0`2bdO040:o6j`@0W:oU1@2TbO<50:G<m0@0Pl;l0P0APnD2001]f`@0WkKX1P34/lT4
0=Fi_P<0fkfk103Kc<X30=k@bP030<7;hP2obn<0_l_S0080_l_S0P2]`^X30:c2jP@0Z<3[0`2W`>/0
0`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
00090?ooo`004@3oool2000000D0oooo00<000000?ooo`2W`>/0=P2W`>/90:Noj`@0X[?T102NZ=d4
09^NeP@0V9OA0P2HU]0300000080Y]Ch0`2eg?@50;3Al@D0Ylgc1@2W`^d40:S4k@D0Y<[c102]cO06
0:_7kPD0V/Of1026aO`60;;Al0<0[lK[1@2J/^P30:C9l`80[mGd1@2Uc?@508G;oP030163i@00@kh0
06gK00@0P:G/1034/lT20<:`b0<0eKVn0`3K_K/0103R`kP0flc:0=_<bP3Kc<X30=k@bPD0_l_S1P2/
`^X40:S0j`<0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0g0:O0j`D0Yko[102U^^P40::ci0@0WZSM0`2KW]H309JSgP<000000`2O^nd60;GLm0D0Z<cb
0`2WcO<20:W3k@D0Yl;]102Xbo850:C:l`D0X/3^0`2[anh20:G:l`D0V/Of102Xao030;;Al0<0Z;CQ
0`2LZN0509Zbj0D0[mGd1P2Yd?@4083:o`030019`000@kh004>n00@0P:G/0P34/lT40<:`b0040=Fi
_P3K_K/0fkfk0=^m^`<0h/>h00@0flc:0=k@bP3Nd<X0g]3:0P3Od//30;o;h`80_/[S1P2/`^X40:S0
j`<0Yl3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool200000080oooo=`2W`>/5
0:NnjP@0YK[X102R/n@309jXg@<0T9GD0`00000309JSgP80Wk_]102ghoD40:_<l@D0Z<cb1@2Y`nd5
0:S9l@@0Z<_b1@2U_^/50:;0kPD0YL[c1@2T_N/40:S7l0H0Z;CQ0`2LZN060:kKm`@0Z/O_0`2Yd?@3
0;7Im@@0P<[o00<004W0000LX`00@kh00`1PSNH60<:`b0@0fkfk0`3R`kP30=k@bP@0gm;;1@2nb^<5
0:c2jPD0Z<3[0P2W`>/00`000000Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo<`2W`>/50:Noj`@0YkkZ0`2U^^P509FMf@80TICC0`000002092Ee0@0UZ?N102g
hoD30;7Al0@0Zlca1@2Za^h30:W3k@80YlWa1@2XbO440:[0jPD0YKk[1@2VbO850:Nji`D0Y;g[102_
`^P50:Rdh@D0YM;g1@2Za>`40:[7k`@0/MWe0P2cg_H406jnoP030019`0007:<004>n00<0H8gV1032
/<P20<>_aP80fkfk103R`kP00`3XbKH0g]3:0=oBb`030=oBb`80g];=0P2nb^<30;g9i0@0[<;Z1@2X
`>/30:O0j`030000002W`>/0Yl3[0140Yl3[403oool2000000@0oooo0P00000:0?ooo`00403oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo<P2W`>/50:Noj`@0X[KW0`2L
Zn4309FMf@<000000P2AU=<4092Ee0D0/]_e1P2adO040:c;l0D0Z/K^1@2WbO450:W1j`@0Z/3Z1@2X
bO430:K9lP80ZK_V1@2W^^L50:k;kP@0[l;X1@2O`_420:GBm`<0[/[^102Za>`60;;ElPD0/mkf101^
__h00`00BL0001bS062=iP02062=iP<0`[380`33[lH20=^m^`<0h/>h0P3XbKH40=oBb`<0g];=1@2m
bN@50:_2jP@0Z<3[102W`>/00`000000Yl3[0:O0j`0A0:O0j`h0oooo0`00000@0?ooo`004@3oool2
000000@0oooo0P0000070?oooc80Yl3[0P2W_n/30:JmjP@0X[KW0P2LZn4300000080UIgI0`2AU=<5
0:>ok@<0/]_e0P2jf_030;7Al0<0[/oa102/bo060:K7l0@0Z<?]1@2Y`N/40:W9l@D0Z<Wa1@2Y^nH2
0:Nji`<0Zlgb102^bnh50:6ij@@0Wl;a1P2^b^h40:g@lP<0/]Gb102gfO840:cQn@@0CiOa00<004W0
000LX`1;Mm/00P1PSNH00`32/<P0`jo60<>_aP020<>_aP040=^m^`3R`kP0h/>h0>;3^0<0j<Vf00<0
kLjd0=oBb`3Od//0103Nd/d0103Ld/h0_LWT0;g9i02mbN@20;_9i@D0Zl;Z102X`>/40:O0j`030000
002W`>/0Yl3[0140Yl3[3`3oool00`000000oooo0?ooo`0>0?ooo`005`3oool00`000000oooo0?oo
o`070?oooc40Yl3[1P2V_NX20::fi`<0000000<0W:_Q09FMf@2EWMT00P2EWMT409:PgPD0Xko]1@2j
f_060:k?l@D0YlK_0`2Vao020:W5kP@0Z<?]1@2WbO440:W9l@D0ZKgX102Y^nH60:_=lP@0YKSV1@2Q
^NT40:kBl`<0[/[^0`2Xb?040:g@lP@0]mWb0`2bl_@40:cQn@<0CiOa00<000jN0001T0007:<00P1;
Mm/50<>_aP@0h/>h0`3XbKH20>g>]0@0g];=0`3Ld/h50;_9i@D0Zl;Z102X`>/30:O0j`030000002W
`>/0Yl3[0140Yl3[403oool00`000000oooo0?ooo`0=0?ooo`005`3oool00`000000oooo0?ooo`08
0?ooobd0Yl3[102W_n/40:JmjP<000000P2EYN0308bFf0@0RI;F102BX=h20:>ok@@0_]g_1P2bdo44
0:[7k`D0YlK_1@2YaNh20:S3k@<0Y/Oa102WbO440:Vnj@D0ZKgX1@2Xc?<50:RiiP@0YKSV0P2Q^NT3
0:WFm`@0[];c1P2Xb?050;7ClP@0/_;d0`18a[L307;@oP0501mVfP1?Uo40CiOa000>WP000I000`1;
Mm/30<>_aP80bK720P3R`kP30>S9]P<0kLjd00<0km2c0=kBc@3Nd/d00`3Ld/h20=_Bd080^lWU0`2j
b>D40:_2jPD0Z<3[0`2W`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0303o
ool001L0oooo0P0000090?ooobh0Yl3[102W_n/00`2N]>L000000000000209jdi`<0UJGP0`2<U]P5
08VBeP<0TZ3N102ngNl30;_Hk`<0/]?a0`2_cNl40:[7k`D0ZLS`102YaNh60:K7l@@0Z<3[102Y_^T5
0:K<l`<0Z<cc0P2X^nL50:RiiP<0YKSV1P2Ye_L40:K1k0<0Z<S`0`2^eO@20;7ClP@0RngT0P2K`O84
076_m`<0;X;Y0P0OI]X2000>WP050001T017J]80BgOK04]gf`33[lH01039/L840>S9]P<0kLjd0P3_
d;<30=cBcP<0fm;@1P2jb>D40:_1jPD0Z<3[0`2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo00<0
00000?ooo`3oool0303oool001L0oooo00<000000?ooo`3oool02P3oool]0:O0j`050:BljP000000
00000000002T_>X0102N]>L309FUh0<0S9KH1029T]H50;?=k@H0^mS_1P2_cNl40:W9l@D0ZLS`1@2V
aO050:S2k@@0Z<3[102Vbo<50:K<l`D0Z;_W102X^NH50:GEn@D0YkcY102V`N`50:kEm080RngT0`2`
aNX409_1lP@0LJog0`0^P^T201mVfP03000>WP0008/0Af[B0080Af[B1@39/L800`3D^Kl0j<Vf0>S9
]P030>g>]0<0km2c00<0km6d0=cBcP3Kd]000`3Kd]00103Jd]40^/SU0;[8i@2jb>D30;W8iP@0Zl7Z
1@2X`>/30:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?ooo`0;0?ooo`005P3o
ool00`000000oooo0?ooo`0<0?ooobT0Yl3[00@0Yko[00000000000000001@2T_>X309jdi`<0UJGP
0`2<U]P509Z[hP<0/lg]1032f^/50;ODk`D0Zl_`102YbO450:K4k`<0Y/G`0P2XaNl50:S2k@@0YL[c
102Vbo<50:Rlj0@0Z;_W1P2SdoP40:Rki`D0YkcY1@2Yg_X207gKo080]lCU1@2`aNX409b=a0@0QhC:
00L0BgOL02j2j@00;K<07fKJ0000T`003Yh0002;00<0Af[B0`39/L830=Bi_`040>S9]P3]c[@0kLjd
0>g>]080km2c0P3_dK@40=_Bd0<0f];A1@2ib>H50:[1j`@0Z<3[0`2W`>/00`000000Yl3[0:O0j`0A
0:O0ja00oooo00<000000?ooo`3oool02P3oool001H0oooo0P00000>0?ooobH0Yl3[0`0000040:No
j`D0W;CY0`2>Xn8308>BfP<0QY?I1@2JZn840<;Jj`<0`M[/0`2ge>l20;3>k`D0Zl_`102WaNl50:K4
k`D0Z<G_1@2Tb?840:G:l`@0YkgY1@2X_>P50:?An0T0Z;_W1@2Lj?/409c@nPD0]lCU1@2YV/L309b=
a0D0QhC:00H0BgOL000]/`00;K<0002C000>WP0008d304MZdP<0bK720`3D^Kl30>g>]0<0km2c0P3_
dK@00`3_dKD0fm;@0=_Bd0040=[Bd@040=SCd`2ib>H0^LSV0;W8iP80^<SV1@2Z`N/40:S0j`<0Yl3[
00<000000:O0j`2W`>/0402W`>/?0?ooo`800000303oool001H0oooo00<000000?ooo`3oool03P3o
oolR0:O0j`<00000102W`>/40:Blj`D0W;CY0P2>Xn8308>BfP@0QY?I0`2JZn830;W<j0H0`M[/1@2`
c^l50:[9l0@0YlG_1P2Wao040:C5l@D0Y<Sb102W_n/40:Nmj@H0Xm3g2@2X^nL508GWlP<0YL?^0`2L
d?X20;O4i0<0]lCU0P2bZM040:VJa`@0W8g41027Q<X304]gg080002C00<0002=0000R`1BKM000P17
J]800`39/L80e;Vo0=Bi_`020=Bi_`030>33_03]c[@0kLjd0080km2c0`3_dK@20>oA]@@0f];A0`3H
dm<50;S8iPD0Z/7[102X`>/30:O0j`030000002W`>/0Yl3[0100Yl3[403oool00`000000oooo0?oo
o`090?ooo`005P3oool00`000000oooo0?ooo`0@0?oooad0Yl3[0`0000040:O0j`@0Yko[102T_>/4
09bdj@<0SZ?R0`23T]X408JCf@@0^LcX0P36enH30<7Jk0@0_=K]102^cO050:[9l0@0YlSa0`2Wao03
0:C4l0@0Y<Ga1@2W`^d40:Noj`@0Xlog0`2Sd?L30:Nkj0H0Z;_W0`1]g^830:Rlj0D0YL?^1@2ga>@4
0;:Yd0D0ZI[70`2LSL@50:BNd0<0QYgR00<0002C0000S@0008d00`1BKM040=Bi_`<0h<>l0`3_d;<2
0>oA]0<0km6e00<0km:f0=[Bd@3Jd]400`3Hdm<20=ODeP80^<SV0`2fb>L40:[1j`D0Z<3[0P2W`>/0
0`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0203oool001H0oooo0P00000B0?oo
oaT0Yl3[0`0000080:O0j`@0Yko[102T_>/408ZUiP80Ni7M0`23T]X509f/h@80^LcX1036enH50;cF
k@80]m?_102^cO050:K8l@@0YlSa1P2Ta?040:O5k`@0Yl;]1@2ScOH40:??m`H0Yk_X0`2X^nL206gN
hP<0Z;WU102X_>P50;C3i@80]lCT0`2e]m/40;:Yd0@0ZI[7102RU/P40:BNd0@0QYgR00<0002C0000
S@0008d00`1BKM020=Bi_`@0h<>l00<0j<^h0>o@/`3_dK@00P3_dK@20>oA]@<0km:f0`3Hdm<30=OD
ePD0]/SW0P2Z`N/30:W1j`@0Z<3[0`2W`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo00<000000?oo
o`3oool0203oool001H0oooo00<000000?ooo`3oool04P3ooolE0:O0j`<00000302W`>/40:Bnj`@0
VkK[0`2:YNH307^Ag@<0PI7J1@2M[>440<KGiP@0b=WV1@2gdnl50:W;l@@0Y/Sa1@2UaO050:K8l@@0
YlG_102Rb_@50:?=mP@0YkcX1@2W^nP205oGeP0306;Hh@2X^ND0Z;WU00@0Z;WU0P2X_>P20;32i`@0
]<?U1P2e]m/30;:Yd0D0WXo40`2RU/P40:BNd0D0XjWL00<0002?0000S@1BKM000P1BKM000`3D^Kl0
h<>l0>33_0020>33_080j<^h0`3_dK@30>oA]@<0km:f00<0kmJh0=SCd`3Ge=H00P3Ge=H20=GGfP@0
]/SW1P2Y`N/70:O0j`030000002W`>/0Yl3[0100Yl3[3`3oool2000000T0oooo00030?ooo`800000
103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo01@0oooo4@2W`>/3000000`0Yl3[
102W_n/40:Bnj`@0VkK[0`2:YNH307^Ag@<0PI7J1P2ja>840<SIiP<0a]SW0`2gdnl20;;Al0D0ZL_a
1@2Vb?440:C9l`D0Y/Sa102Ra_840:;:m0D0YkgY102W_>P205gFeP80KMkT102W^NH50:Rii@D0/<;W
102d`N@50;Fgf`@0WHg2102NSl@40::Fb080Y9k@0P2f/mL40:>Yg00302M/g00008d0002=0080JGoF
103P`k`30>S;^0030>c>]P3_dK@0km6d0080km6e0`3_d[H20>oF^0<0emCF103EemX40;C8j@H0ZL7[
1`2W`>/00`000000Yl3[0:O0j`0@0:O0j`/0oooo0`0000000`3oool000000?ooo`080?ooo`000P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool05@3oool>0:O0j`800000402W`>/40:Noj`<0Y;k[1@2;Zn/207>Ch`<0Ni7M102GXmh40;[4hP<0
bLoN1P36f>L50;;Al0H0Ylcc102Rb?<40:C9l`D0X/Ca102Ra_840:O1k0D0YkgY0P1Wfn4206cNg0@0
Y[_X102W^NH50:c1j@<0/<;W0P2`a^X40;C1i0D0X9340`2MSL8409j?a0@0XYK81@2f/mL30:>Yg003
02M/g00008l0002=00<0JGoF0`3P`k`20>S;^0<0k<jf0`3_dKD20>oB]P<0kmJh0P3`fk/40=GGfP80
dMSN102db>T50:W1j`L0Yl3[00<000000:O0j`2W`>/04@2W`>/60?ooo`@00000103oool00`000000
oooo0?ooo`070?ooo`000P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?oo
o`8000005`3oool:0:O0j`<000004`2W`>/20:Noj`80YKo/102N^^`408^[j`80Li?S0`1eS=/409NS
gP80^/CR0`39cmh20=3Bf`<0a]SW1034f>T50:gAl`D0X/_e102Rb?<40:?5l@D0X/Ca102Wa_040:O1
k080N^;b0P1PelX50:K3kP@0Y[_X102W_n/50:c1j@D0/<KZ102RU<H40:2@a0@0WHg20`2NSl@20::F
b0<0]KOK102f/mL40:Z_f`0305Z5hP0008l0JGoF00<0JGoF00@0h<>l0>S;^03XbkP0j<^h0`3/c[H2
0>kA]@<0km:f0P3_e[P30?3K^`030>oP`03EemX0eMOJ00<0dMSN1@2banX30:W1j`80Z<7[1`2W`>/0
0`000000Yl3[0:O0j`0A0:O0j`80oooo0`0000080?ooo`030000003oool0oooo00L0oooo00020?oo
o`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01P0oooo1@2W`>/3
000001H0Yl3[1@2U_n`409jjk0<0Rj_[0`1cTn<307F<f`@0Uj?N0`39cmh40=3Bf`@0a=SY0`30f>/3
0:gAl`80Ym;f1@2RboD40:;9m0@0XlGa1@2Tbo@40:O6l0@0SN3m102Vd_L50:K3kP@0Xkg/102W_n/5
0:c8kPD0Y9W90`2RU<H40:2@a0@0WHg20`2NSl@60;Fgf`80][?G0P2d]mX40:Z_f`0305Z5hP1YOmH0
JGoF0080JGoF0`3XbkP30>c>]P<0k]6e00<0lMJe0>oB]P3_e[P00P3_e[P20?3K^`80kn30103Af=h2
0<_Hh`D0//OZ1@2X`N/70:O0j`030000002W`>/0Yl3[0100Yl3[0P00000<0?ooo`030000003oool0
oooo00H0oooo00020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0I0?ooo`040:O0j`0000000000000001X0Yl3[102U_n`509:dkP<0LI_Z0P1Q
Q]l307F<f`H0/[KL103@d]/30=;Bf@H0`=S[1@2Wd_H509g=n0@0X/Wd102Pc?H50:C;m0D0V=Gm102N
io`30:KBm`D0WK_^102S_N`40:O6l0<0[<S^0P2TVl`40:BIb@@0XYC60`2PT<@409f=`P@0[KCN1@2e
]m/50;BgfP<0ZZoK00<0FXGR0000O`25W>400`25W>420>S;^0<0k<jf0P3^dKD20?7F]@<0kmJh0`3`
fk/20>oP`0030>gUa`3Af=h0dMSN00@0bmSS1@2_a^/40:S1j`P0Yl3[00<000000:O0j`2W`>/0402W
`>/=0?ooo`030000003oool0oooo00H0oooo00030?ooo`8000002P3oool3000000<0oooo0P00000H
0?ooo`<000007P2W`>/50::mk0@0T[C^0P1aVnX30666g`<0PiGL102b]]`20<BoeP80d=;K0`3Bd]T4
0=CAePD0_MS]102Mdo/509g=n0@0V/ci102Pc?H609c<n0<0N>CL1@2B^O4309Rjk`@0WK_^1@2R`^l4
0:O6l0@0Y9_<1@2TVLT30::DaP<0X9341@2UZm`40:fdgPD0/KON102d]mX40:VagP0306f?hP0007l0
QIcQ00<0QIcQ0`3/c[H30>kA]@80lMJe00<0m=ff0>oF^03_e[P00P3`fk/20>oP`0<0kNG70`3;f><3
0<?Fj0@0[lK[1@2X`N/70:O0j`030000002W`>/0Yl3[0100Yl3[3@3oool00`000000oooo0?ooo`06
0?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`<00000103ooolJ0:O0j`@0Y[o[1@2R_N`309:d
kP<0LI_Z0`1QQ]l308>Eg080/[KL1034_mH30=;Bf@@0e=7F0P3Ec]830;gHk@<0^mS_0`2Mdo/609;>
o0<0V/ci1@2LboP204G3/`<0W<;b0`2B^o<509:il@<0V;[_102N^^`50:;2k`@0Xi[<102TVl`40:BI
b@<0XYC6102OXMH50:F[g080[KCN0P2^^>440;6ggPD0/[WN102Y/Mh00`1]Sn80WKO[09fgj`0309fg
j`80k<jf0P3^dKD30?7F]@80m=ff0`3`fk/20>oP`0<0kNG700<0j>W?0<?Fj033e^P01033e^P40:c4
k0@0Z<7[202W`>/00`000000Yl3[0:O0j`0@0:O0j``0oooo00<000000?ooo`3oool01P3oool001@0
oooo00<000000?ooo`3oool04P3oool3000000P0oooo6P2W`>/40:Joj`D0WK_^0`20Zo0205:8i`<0
HHKO0`23UM`50<BoeP<0c/;>103DdMH40=G>dP@0^mS_0`2ld^/309;Bo@D0Pm3o102Ed?`205??eP<0
/LS[102L`_8309:kl`D0UigH0`2J[N@409jjk0D0XYS:102SV/`30:BKc0@0Y9W9102NV]0409nQeP@0
YJ_L1@2^^>420;6ggP80/;cS102b^Mh50:Bah@0307:Ci02M]n/0WKO[00<0WKO[0`3^dKD20?7F]@<0
m=ff0P3diKX20>oP`0<0kNG70P3XjLl0103PjmT0`mKX0<?Fj033e^P30;_Bj`@0[<C/102X`>/80:O0
j`030000002W`>/0Yl3[0100Yl3[2`3oool00`000000oooo0?ooo`060?ooo`00503oool200000100
oooo0`00000<0?oooaX0Yl3[1@2U_n`409fkkP<0P:_`0P1BR>L305b2gP<0VZ;J0`34_mH30<k2cP80
e<370P3DdMH40=G>dP<0e/O;102ld^/20;o2g0@0S<kn1023d?l205oAlP03093NoP34b=`0a<SL00@0
/LS[102JSL@309J@c0D0UigH0`2J[N@40:6Da`@0XYS:102SV/`40:6Fb@@0WiO<102NV]0309nQePD0
[K_T102^^>450;2lh`80/[WN0P2]^>450:Bah@0307:Ci02M]n/0WKO[00<0Ylcc00@0k]6e0?7F]@3a
e[D0lMJe0P3dgKH30?CU^P040?;Z_`3]iLL0kNG70>gUa`80j>W?0`3PjmT50;_Bj`D0Z/;/102X`>/8
0:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`00
0000oooo0?ooo`0<0?ooo`<000004@3ooolI0:O0j`D0YKo/102E^O0306FOl@0402ebh01BR>L0G8;N
05b2gP@0VZ;J103>`/h40=C0a`@0eLkB103Fal/00`3F_<40_=;[0;cBj`040;o2g0D0WKoa102@g_h4
0<C8g0@0YiK40`2JSL@409J@c0@0UigH102QTL@30:6Da`@0XYS:0P2SV/`30:>Gb@<0XIK9102OUl`4
09jJd0@0[L3X102]^n@50:bliP@0/;cS1@2]^>440:Bah@0307:Ci02Wc?<0Ylcc00<0Ylcc0`3ae[D3
0?CM]P80m>Fj0P3bj[l20>o^a@80j>W?0`3PjmT30=KXhP@0/lc/102Z`^`<0:O0j`030000002W`>/0
Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0:0?oo
o`8000005@3ooolI0:O0j`D0Y;o/102E^O0306FOl@0402ebh01LP]h0G8;N05b2gP80VZ;J0P2^Zm@2
0<k2cPD0e<3700<0ekbo0=G>dP3Ec]80103Fal/30=Jl`@@0_l;L0P33/<L309fol@<0]KOJ1@34b=`2
0;j`c0<0YiK4102JSL@309J@c0D0XY320`2QTL@40:6Da`<0XYS:1@2SUlT40:6Fb@<0WiO<1@2[`n`4
0:g0j0@0ZK[V102/_>H50:^hh`@0[KSQ1@2N[n<2072Ci0@0Wmgl0P3ae[D20?CM]P80m>Fj0P3bj[l2
0>o^a@80k?3:0`3PjmT30=KXhP80bN;Z102cc>`40:S1j``0Yl3[00<000000:O0j`2W`>/0402W`>/:
0?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003oool0oooo00L0oooo0`00000H0?oo
oaT0Yl3[1@2T_n`408bflP80@Xg]0P0]L^020624gPD0[Z_D1@3D`<L30=Nl_`@0e/O;103F_<400`3D
/[L0_l;L0;o2g0040<>`a`@0]KOJ0P3A`l`30<C8g0<0_[3<102WU/@309Z=a0@0Y9;2102RT<840:6A
a0<0XIC7102UV/X50:>Gb@<0XIK9102YaNh40:_3k0D0YkOT102Y^^H40:Zii0D0ZkSS102Y]n<409j_
h`<0L9?T102OgO`30?CM]P050?CU^P3bj[l0l^Zo0?;Z_`3_k/D00`3/l<X20>Sbd0<0e^SR0`39h^X5
0:g6k0@0Z<7[302W`>/00`000000Yl3[0:O0j`0?0:O0j`X0oooo00<000000?ooo`3oool01@3oool0
01<0oooo0`0000050?ooo`<00000703ooolI0:O0j`D0X[k]102<]_8204:=k@04001GdP0]L^00H8CN
0624gP<0[Z_D0P2l[ld40=C0a`<0ekbo00<0f;Jg0=K7b`3Fal/0103F_<430=Bb]`D0`k3700<0bjfl
0;FgfP2e]mX0103A`l`50;j`c0@0YiK4102VUlL30:BB`P@0XY32102QTL@40:ROc@<0YI[:1@2SUlT2
0:6Fb@80Z<G^102YaNh40:Neh`D0YkOT102Z_>H40:Zii0D0Z[_V102Y]n<309j_h`@0L9?T00<05EWB
083Lo@20g?d00P20g?d01@3diKX0l^Zo0?;Z_`3bj[l0knk500<0k?3:0P3Xl]020>CdeP@0bN;Z0P2l
enh40:g6k0D0Z<3[302W`>/00`000000Yl3[0:O0j`0?0:O0j`T0oooo00<000000?ooo`3oool01@3o
ool001<0oooo00<000000?ooo`3oool00P3oool300000200oooo6P2W`>/40::nk@<0S;Kb0`12SNd0
1@00Em80H8CN0624gP1PQ=h0[Z_D00@0_:o=0P3D`<L30=Nl_`<0f;Jg103F_<440=Bb]`040=J^/033
/<L0`k370<>`a`<0bjfl103A`l`20=[Ad0@0_[3<1@2TW/l30:JGa`@0Y9;20`2RT<850:^VdP<0Z9o=
102UV/X40:>Gb@D0Z<G^102W]>840:Neh`D0Z[oY102Z_>H40:Vli`@0Z[_V1@2T]ND309N/i@<0KY7T
0`0EFM8507CBoP040>o^a@3/l<X0k?3:0>c`bP80j?;@0P3Tm=H30=cdgPD0_=O^102Y`n`40:S0j``0
Yl3[00<000000:O0j`2W`>/0402W`>/80?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000
003oool0000000800000903ooolJ0:O0j`@0XKk^0`23/o@201Ieh`8005OB0P1VR=l60;b_c@@0ekbo
0`3H][L00`3I/K40e[c10=Jl`@040=Bb]`<0eZj`00<0`k370<^]_03;[K`00P3;[K`00`3L_k`0dL?<
0=73c0040=[Ad0@0YjcK102TW/l40:JGa`<0Y9;20P2RT<820:b^f@@0ZjKB102XWld30:FJbPD0YlC_
2@2W]>820:Neh`80ZL7[102Z_nT50:Nji`@0ZKcW102W]nD40:Bei@@0UjcU0`1^TN@00`0cKM/05EWB
01EIdP04093Ho`<0[=ki00@0j?;@0>CdeP3Tm=H0i?CF0P3Lm=h30=7_j0D0/Lc^102Y`n`@0:O0j`03
0000002W`>/0Yl3[0100Yl3[1`3oool00`000000oooo0?ooo`050?ooo`004`3oool3000002L0oooo
5@2W`>/50:O0k0@0XKk^0`23/o@201Ieh`04000b]P00Em80IXSO06J8g`@0_:o=0P34[lD20=Nl_`<0
f;Jg0`3I/K440=Bb]`@0eZj`103;[K`30=bo_0@0f]7@0P33bMl30:N/f`@0Y9k?102VUlL30:BB`PD0
[:kI0`2[Y]840:ROc@D0Y/C_302W]>850:W1j`@0YkSU102W^^L50:Nii@@0YkOU0`2T]ND409N/i@@0
KY7T0P0cKM/200ELe@<0[=ki0P31iO030<o/j@030=cdgP3AknP0dNoX0080dNoX0P32hNl40;7<kPD0
Z<7[402W`>/00`000000Yl3[0:O0j`0?0:O0j`L0oooo00<000000?ooo`3oool01@3oool001@0oooo
00<000000?ooo`3oool09`3ooolF0:O0j`@0Yl3/102P_^h307bam@8005[@00@003:f06J8g`1VR=l0
IXSO0P2l[ld40<B_a@@0f;Jg0`3I/K40103J/:d0e;:g0=Bb]`3D/[L40=J^/0040=^a[P3;[K`0bjfl
0<^]_0<0g;nl00<0jmO10=[Ad03JdM001033bMl30:N/f`<0Y9k?102VUlL40:Vcg`@0[:kI0`2[Y]86
0:G2kP/0YkCR1P2X`^`40:Ngi0@0YkSU0P2W^^L20:Rki`D0YkWU0`2W]nD40:2ci@@0T:OU101/T><0
101?On40<fgK04J9j`16RN/30<7Ul0<0cncY00@0eo?S0=Ohh@3Gn>40eoSQ1@32hNl40:_4k0@0Z<7[
402W`>/00`000000Yl3[0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool0103oool000/0oooo1@00
00050?ooo`800000:@3ooolE0:O0j`D0Y/3/0`2P_^h307bam@8005[@00<003:f06J:h@1VR^401@34
[lD20<V_`080f;Jg103I/K420=Z`[@030=Bb]`3F[[00eZj`0080eZj`0`3K/Jh0103;[K`0g;nl0=bo
_03L_k`30>_G`@D0`lWO0`2W[=/409FVh@@0X:oS102Y/ml40::hj0@0Xkg/302W]>850:O2k@D0YkKT
102W]n@30:Nhi@D0Z;_W102W^ND40:Fii`@0X;?U102@YnD306b@h`80CgoQ1016RN/30<o/j@040=Oc
h`3Gn>40eoSQ0=Ohh@80d?KW1@2cd>l40:_4k1@0Yl3[00<000000:O0j`2W`>/0402W`>/60?ooo`03
0000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
9`3ooolE0:O0j`D0Y/3/0`2P_^h307Z`mP030015_P00F]0003:f0080IX[Q0`34[lD40<V_`0040=Rf
]`3I/K40fK6a0=Va/@<0f[2]1@3F[[030=^a[P<0g;nl0`3[el430>OHaP@0Zk?N0`2BXn0409FVh@@0
X:oS102Q/nD40::hj0@0YkOT202W]>870:O2k@H0YkKT102W]n@40:Vnj@@0Z;_W1@2V^^P40:Fii`@0
VjoU1029X^D206n@hP<0CgoQ101k[O<20=Och`<0eoSQ0P3@m^L20<?Wl0@0/m3_1@2X`N`D0:O0j`03
0000002W`>/0Yl3[0100Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02L0oooo5@2W`>/50:K0k0<0X;k^0`1j/?H00`00AKh000:6
06J:h@0206J:h@030<B_a@39[l00bJo000<0bJo0103I/K430=Z`[@040=fb[03F[[00eZj`0=J^/0@0
fk6^00<0hkf`0=bo_03L_k`00P3[el430>OHaP80f/_:102[/mh309:Sh0<0UJKQ1@2P/N@40:6ci@@0
YkWV102W]n@30:NdhPT0Yl;]202W]^@50:S0j`@0ZKkY102V^NL40:Jjj0D0X[CU102K[nD308VRi@<0
Ki3R0`1]U>L30:C:m0<0`>Ga0P3@m^L50<?Wl0@0ZlG]102X`N`E0:O0j`030000002W`>/0Yl3[00l0
Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02L0oooo5P2W`>/40:O0k0@0XKk^0`1j/OH00`000XH0EhKT05N6i0060<V_`0040<b`
_P3I/K40fK6a0=Va/@<0f[2]00@0gK:/0=J^/03F[[00eZj`0`3K/Jh20>>m/0030=bo_03[el40jmO1
00<0imS6103JblX30:^cgP<0TZ?P102K[N<40:2ai0D0Y[[W102W^NH30:Ngi0@0Y/3/102W`^d90:Nf
i0@0Z<7/102X`>/50:JhiP@0Y[WW102U]nD40::di@@0VjoU0`29X^D406n@hP<0KICW1030iO420<cg
j@80b_WY1@2cd_040:_5kAP0Yl3[00<000000:O0j`2W`>/0402W`>/40?ooo`030000003oool0oooo
00@0oooo000=0?ooo`030000003oool0oooo00X0oooo0P00000X0?oooaH0Yl3[102W`>`40:6nk@<0
O[;e00<000:605N6i01GQ^@01039[l020<b`_P80fK6a0`3J/:d30=fb[0030=J^/03K/Jh0fk6^0080
fk6^0P3S_K020>_G`@<0imS61@3JblX40:>[g0<0UZKQ102K[N<40::gi`@0Y[[W102W^NH40:Fmj`@0
Y/3/2@2W]^@40:O1k0@0Z<7/102V]nD40:JhiPD0Yk[W102U]nD409nciP@0UJWT0`24W>8307REh`D0
SK3^0`3<mnT20<[ij@80_nSb102cd_050:S1k1P0Yl3[00<000000:O0j`2W`>/03`2W`>/40?ooo`03
0000003oool0oooo00@0oooo000<0?ooo`8000003P3oool00`000000oooo0?ooo`0V0?oooaX0Yl3[
102Q_^d307jbm@80EhKT0`39[l040<b`_P040=Va/@3J/:d0f[2]0=Z`[@<0gK:/103K/Jh30>>m/080
kL^b0P3ad;050=[;bP80cKk<102SZm`309JVh@@0W[7U102R]nL30:Jji`D0Y;[X102U_N/40:Ngi0@0
YkKT2@2W`N`40:Ngi0@0Y[OU102W_NT40:Nji`D0XkOW102O/nH309FYi0@0Q9cR0`1hUN<208f`kP<0
[mGd0P3:nNT50;oXlP@0ZlG]102X`N`I0:O0j`030000002W`>/0Yl3[00l0Yl3[0`3oool00`000000
oooo0?ooo`040?ooo`007@3oool00`000000oooo0?ooo`0V0?oooaX0Yl3[102R_^d308:cm@0302A`
h01GQ^@0bJo000D0c;2n103J/:d30=fb[0040>6h[P3K/Jh0fk6^0=^a[P<0hkf`0P3]bk820?7@/004
0>o>/@3JblX0f/_:0=[;bP<0cKk<102SZm`409Z[hP@0W[7U0`2R]nL40:BgiPD0Y;[X102X^>D40:Ng
i0@0Yl3/102W`N`90:Ngi0@0YkoZ102W_NT40:BgiP@0XkOW102O/nH309FYi0@0Q9cR0`1hUN<40:oE
m080`_K^0P32nN/50;7?l0@0ZlG]7@2W`>/00`000000Yl3[0:O0j`0>0:O0j`@0oooo00<000000?oo
o`3oool00`3oool001h0oooo00<000000?ooo`3oool09P3ooolJ0:O0j`@0X[k]0`22/oD00`0TL>00
c;2n0<b`_P030<b`_P80c[C10P3J/:d30=fb[080hKR^0P3K/Jh30>>m/080kL^b0`3ad;020>o>/@@0
cKk<0P36^<d40:B[f`@0VZ_R102S]>D30:Bfi@@0Y;OV1@2X^^H40:Rhi@@0Yko[102W`>`80:Ngi0D0
Yko[102W_nX40:Ffi@@0Y;OV102Q/N<409ZZhP<0Sj;Q1025Vn4408^Wj0<0`_K^0P32nN/20;[Sl`@0
/Lo`1@2X`N/L0:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?ooo`00
7`3oool2000002P0oooo6@2W`>/40:>nk@80QKGd0P0TL>030<b`_P<0c[C10P3J/:d30=fb[0<0hKR^
00@0fk6^0>>m/03S_K00hkf`0P3]bk820?7@/0<0klja00<0j/Ve0<fnc03=_/`01036^<d30:B[f`D0
XK3R102S]>D30:Bfi@@0Yk_W102X^^H50:JmjP@0Yko[202W]n@40:O0j`@0Yko[1@2V]N@40:Ffi@@0
Y;KU102Q/N<409ZZhP<0Sj;Q0`25Vn450:S@m@80`_W[1@2jho<50:W3k200Yl3[00<000000:O0j`2W
`>/0402W`>/00`3oool000000?ooo`040?ooo`008@3oool00`000000oooo0?ooo`0V0?oooaT0Yl3[
102S_^d208Fem003000b/P0TL>00c;2n00D0c[C100<0f[2]0=fb[03M/Z`0103Q^:h30>>m/0<0kL^b
0P3ad;030>o>/@80j/Ve1@36^<d40:V^f`D0XK3R0`2S]>D40:Jii`@0Yk_W102V^^P40:JmjPD0Z;OT
102W]n@80:O0j`@0Y[GS102V]N@50:Jkj0@0Y;KU0`2Q/N<409ZZhP@0SIgN0`2?YnD30:S@m@040;Wh
k@2lm_00_?K`0;cfl0D0[L[_1@2X`>/P0:O0j`030000002W`>/0Yl3[00l0Yl3[00<0oooo0000003o
ool0103oool00280oooo00<000000?ooo`3oool09P3ooolI0:O0j`@0Xko]0P28]_@00`00<[80c[C1
0<jd`@040<jd`@<0gK:/103Q^:h00`3T`;<0hkf`0>>m/0020>g;/P<0lM2`0P3_c[430>[9]@040>?5
^@36^<d0a[S=0<Jhc@80a;K=102Y[]/50:Fbh@<0Y;KU102V^NL40:JhiP@0Y[[X102X^>D40:Rgi0T0
Yl3[102W]^<40:Jeh`@0Y[gZ102V^nP50:2_h`<0W:gR102FYN0408fMgP<0SjOU00<0^OS]0;cfl02l
m_001@2ceo<40:S1k0@0Z<3[8@2W`>/00`000000Yl3[0:O0j`0?0:O0j`030000003oool0oooo00<0
oooo000S0?ooo`030000003oool0oooo02H0oooo6@2W`>/40:>ok@80R;Kd00<003:b0<jd`@3>]<40
0P3>]<420<blb`030=fb[03Q^:h0hKR^0080hKR^0`3T`;<30>g;/P80lM2`0`3_c[420>[9]@<0hlFi
00<0a[S=0<Bfc@34]/d00P34]/d20:V^f`80[[3I102U/^440:Bfi@@0YkOT102V^>H40:VjiP@0Z;SU
102W_nX40:O0j`T0YkKS102V_^/40:JmjP@0X[3Q102P[n<409b]hP<0UZGP102=WMh30:[Ln@80[_WW
0P2hj_H20;?Gl`<0Z/C]102X`N`T0:O0j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool0
0`3oool002@0oooo0P00000W0?oooaT0Yl3[102S_nd208^gl`03000b/P3>]<40c[C100<0c;c;00<0
gK:/0>6h[P3Q^:h00P3Q^:h30>C0/`80j<Nf0`3ad;020>o>/@<0j/Ve0`3SaKT50<Bfc@D0[[3I0`2U
/^450:Rfh`@0YkOT102Y^nH40:VjiP@0YkgY102W_nX40:Rfh`@0YkKS1@2W_^/40:Jnj`@0Y;3Q102R
/>430:2_h`@0W:gR102BWM/409J_j080[_WW102hj_H50:[4kBT0Yl3[00<000000:O0j`2W`>/02`2W
`>/30?ooo`030000003oool0oooo00<0oooo000V0?ooo`030000003oool0oooo02D0oooo6@2W`>/4
0:>ok@80SKSc1@3<_</40>6h[P<0i<2c0`3XakH20>g>]0<0klja0P3ZbKD40>?5^@040=k2_@34]/d0
a;K=0<Bfc@80a;G<102^/=T40:Zcg`@0Z;KS1@2X^ND40:VkiP@0Yk[W102W_NT80:Rfh`@0YkoZ102W
_^/50:Jah0@0Y;3Q0`2R/>4409nXg@@0V9kI102BWM/209J_j0040:Gbm02_mnl0[oO_0:ogk`D0[L_`
102X`>/Y0:O0j`030000002W`>/0Yl3[00H0Yl3[203oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`0U0?oooaT0Yl3[1@2T_nd0102=^?<0c;c;0<blb`3<_</20<?5f`<0hKR^
0`3T`;<20>S7]P<0kLjd0P3`d[830>[9]@<0hlFi0`3N`[d50<Bec0@0/k7G102Z/ml40:VfhP@0Z;WU
1@2X^>@40:Nji`@0ZKOS102X]^<40:RnjP@0YkoZ102W/^040:Jah0D0YKOV0`2S/N8409nXg@<0V9kI
102BWM/00`2Ul_@0[oO_0:ogk`050;3Fm0@0Z<7/102X`>/X0:O0j`030000002W`>/0Yl3[00<0Yl3[
2`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`0V0?oooaT0Yl3[102T
_n`00`2@^O80c;c;0<?5f`030<?5f`040>6h[P3T`;<0i<2c0>C0/`<0j<Nf0P3]c[@30?3B/P80l=>d
103SaKT30=k2_@040=W1`@34]L`0a;G<0<Bec080aKK<102c/ML40:fcg@@0ZKKR102Z]n840:Rhi0D0
Z[WT102Y]n<40:Rnj@@0Z;kZ202W/^040:Fii`@0YKOV102S/N8309nXg@@0UjgV0`2Nd_X0102Gl^00
/^Ch0;;Tn02bi?P50:W4k@<0Z<7/;@2W`>/00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0080oooo000Y0?ooo`8000009`3ooolI0:O0j`@0Y;o/1@33aM/40>C0/`80j<Nf0`3]c[@20?3B/P<0
l=>d00<0k]>i0>?5^@3SaKT00`3N`[d30=W1`@030<Bec035]/`0aKK<0080aKK<0P2c/ML20;Nbe0@0
[K?M102]]]l40:ZghP@0Zk[T102Z^N@50:Rki`@0Z;kY102X/]l40:Nbh0@0Y[[W102U^NL30:FgiPD0
ViWA0`2GWML409N]iP0309Obh02bi?P0/^Ch00@0ZlS_102Ya>d^0:O0j`<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`0U0?oooaT0Yl3[
102T_n`00`2B^_80//S[0;;8j`020;;8j`80i<2c0`3XakH20>g>]0<0l=:b0P3`dk@30>kC^@@0g/:m
0`3I`L450<Ffc0D0]k;D102a/mX40:ffg`@0[;SR102[^^@40:Rhi0@0Z;_W1@2Y/]l30:Rbg`D0Yk[W
102V^^L40::Nd0<0Wi_@102KVM4409NMe`0308O/h`2[koL0Znog0080Znog0P2/cO440:_8kbd0Yl3[
203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003o
ool0oooo02D0oooo6@2W`>/40:Bok00309:jlP2bb>/0//S[0080//S[0`3XakH30>g>]080l=:b0`3`
dk@30>kC^@030>WD`03N`[d0g/:m00<0fL710P3F`/H30<Ffc080a[O<0`2g/]@20;Zbd@@0/K?J102^
/m`40:bhhP@0Z[CP102X^>@40:Zcg`@0ZK;O102X^^H40:Nji`D0Y:3A0`2RW]0409nKd0<0ViWA102=
ioP309Sak0@0[<ga;P2W`>/;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool002d0oooo00<000000?ooo`3oool09P3ooolH0:O0j`@0YKo/00<0U[_a0:G;l`2Ubo<00P2Ubo<2
0>S7]P80kLjd0`3`d[820?3C]0<0k]>i0`3Ye<030=W1`@@0e/;600<0aKK<0<Jgc036]l`00P36]l`4
0;Zbd@80/K?J0`2d/MD40:jcg0@0[K;L102Z]>040:bdgP@0Z[?O102Y^>@40:RjiP@0YJ7A102TX=44
0::Nd0<0Wi_@1@2GeOd00`2HlN`0[=?d0:cCm0030:cCm0@0Z<7[:P2W`>/?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00@3oool002h0oooo00<000000?ooo`3oool09P3ooolH0:O0
j`@0YKo/00<0V[g`0:G;l`2Ubo<00P2Ubo<30>g>]080l=:b0`3`dk@20>kC^@<0jMC00P3SelX00`3I
`L40e/;60=K2aP030=K2aP@0a[O<0P37^/h30;Zbd@D0];7E0P2^/m`30;:`e`@0[K;L102^/m`40:bd
gP@0Z[?P102Y^>@40:JPc`@0YJ7A0`2TX=440::Nd0D0WL7b00<0N^GH0:_Hm`2[f?L00`2[f?L40:S2
k0@0Z<7[9@2W`>/D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool002l0
oooo0P00000W0?oooaP0Yl3[102U_n`00`2J_O00XmCi0:?Dn@030:?Dn@80l=:b0`3`dk@20>kC^@<0
jMC00`3SelX50=K2aP80dlK=0P36]l`30<NjcP80^[;A0P2m/m040;Bae@D0/[3G0P2]/]`30;2_f0<0
[[?L1@2Z[MT40:Zch0@0Yio=102VX<l30:FQd@@0Y;7Q102P]NL205kEaPD0Z=gj102YaNh40:S2k0@0
Yl7/8@2W`>/H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool09@3ooolI0:O0j`<0YKo/0P2N_^l40:cRnP<0/^cg0P3^dkT30>WD`0<0hmO:
0P3Jg=P30=K2aP<0dlK=1@37^/h50;fcd0@0^;7B102b/=L50;2_f080[[?L0P2]Z=840:Z]f@D0ZZ7=
102WWld30:JPc`@0Yk;P102T/N420:2ei`@0Xmol1@2Xanl30:W5kPD0Yl3[202W_n/H0:O0ja`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<P3oool00`000000oooo0?oo
o`0U0?oooaT0Yl3[102V_n`20::ok@80/^cg102_koL309_[n@<0hmO:103Jg=P40=?6c@80cloJ0`37
^/h20<O2e@<0_K?@0P30^]@40;RadP@0/jkC102`[mP50:fXdP80ZZgI0P2_Z=040:ZQc@@0Yio=102[
^N<40:Nbh0<0Y;7Q0`2Mh?d50:S8l0<0Z<O_1@2W_n/40:S0j`@0Yko[602W`>/P0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00@3oool003<0oooo00<000000?ooo`3oool09@3ooolI
0:O0j`@0Yl3/102R_nd00`2:^OD0Vn_i09_[n@05077JmP@0f]cH0P38i^`20=?6c@@0cloJ1@37`]D0
0`2m/m00`;[D0<2je0020<2je080^;7B0P2k]mH40;>^d`@0/Z_A102]Z=840:nXd0@0ZZ7=0P2WWld3
0:k7k0<0ZkWS102W/^0309WOoPD0YlWa202W_^X40:S1k0@0Z<3[102W`N`D0:O0jb@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`00=03oool2000002H0oooo6@2W`>/40:O0
k0@0YKo/102H_O4206>^n@<0;[?O1@38i^`40<o?fP80_^7`1037`]D50<2je0D0^kOF0P2c[]<20;Zl
fP@0/Z_A102f^M/40:nXd0<0ZZ7=1@2^an`30:^ih`@0U]_n102Vb?480:NnjPP0Z<7/1@2W`>/30:O1
k0D0Yko[2`2W`>/Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool003H0
oooo00<000000?ooo`3oool09@3ooolL0:O0j`<0YKo/1@2P_nh308RjmP<0=Ikc1@2DiO`50;kQl0@0
`]KY0`30^]@20;oCj@@0^kOF1@2j_=X20;:[d@80^=O`102f^M/30:nXd0D0[=_h0P00000409KGoPD0
YLOa202W_^X40:O2k0@0Z<7/102W_n/40:O0j`P0Yko[202W`>//0?ooo`030000003oool0oooo00L0
oooo0@0000010?ooo`40oooo000g0?ooo`030000003oool0oooo02D0oooo6`2W`>/50:K0k0<0X;o^
1@2K__4307RhnP806YKX0`0X/=/406kImP@0`]KY1@2odnT40;SMl`@0^[cJ1@2heo030;Jif`D0TNSi
0P2JcOX409OBo0D0YLK`202W_^X40:O2k@@0Yl;/102W_nX40:Noj`@0Z<3[102W_n/80:O0jc00oooo
00<000000?ooo`3oool01P3oool100000040oooo0@3oool003P0oooo00<000000?ooo`3oool09@3o
oolP0:O0j`@0YKo/102S_nd409Nnl`<0KkSl0`0IVnD2002C``D0On3h101Sen`40;SMl`@0QnKf102h
eo000`1@c]H07JZi05C:l@0509g9mP<0V/gj1@2Ua>l40:RnjP@0YkkZ202W`^d40:NnjP@0YkoZ102X
`N`40:S0j`@0Yl7/>03oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>@3oool2
000002H0oooo802W`>/40:O0k0P0Xko]102G_o<409[0lP@0Pl3k0`1?^OT507_5oPD0V<Gf0`2:b_d5
0:34lP@0Y/3/102U`Nd40:Roj`<0Z;kZ202W`^d80:NnjPD0Yl7/0`2X`N`50:O0jc/0oooo00<00000
0?ooo`3oool01@3oool100000040oooo0@3oool003/0oooo00<000000?ooo`3oool0903ooolP0:O0
j`@0Yl3/102V`>`40:>ok@@0Y;o]102J`?850:30l0<0U<;f1@2P`O040:G0k@<0Xl;_1@2W`>/30:K0
k0D0Z<3[0`2X_n/40:O1k0@0Yl;]202W_^X50:O1k0P0Yko[?`3oool00`000000oooo0?ooo`040?oo
o`4000000@3oool10?ooo`00?03oool00`000000oooo0?ooo`0T0?ooob@0Yl3[2@2V`>`30:Bok@D0
YL3]102V`>`30:C0k@D0Y/3/0`2U`>d80:O0j`@0Z<7[102X`>/80:O1k0D0Z;kZ202W`N`40:NnjP@0
Yko[@`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo
0?ooo`0T0?ooocD0Yl3[0`2V`>`40:O0j`@0Y/3/202W`>/40:O0k0@0Z<7[1@2W`>/30:O1k0D0Z;oZ
1`2W`N`80:NnjTP0oooo00<000000?ooo`3oool00P3oool100000040oooo0@3oool003h0oooo0P00
000U0?ooodT0Yl3[0`2W`>`50:Noj`@0Z<3[0`2X_n/80:O1k0P0YkkZB`3oool00`000000oooo0?oo
o`030?ooo`4000000@3oool00400oooo00<000000?ooo`3oool08`3ooom90:O0j`<0Yko[202X`>/8
0:O1k0@0Z;kZ102W_^Y?0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`00@@3oool00`00
0000oooo0?ooo`0S0?oood`0Yl3[102X`>/40:O0j`@0Yl7/102X_nX40:RnjU<0oooo00D000000?oo
o`3oool0oooo000000010?ooo`00@P3oool00`000000oooo0?ooo`0T0?oood/0Yl3[102W_n/40:O0
j`D0Z;o[0`2X_nYG0?ooo`040000003oool0oooo00000040oooo00130?ooo`8000009@3ooom70:O0
j`P0Yko[102X`>]N0?ooo`040000003oool0oooo00000040oooo00150?ooo`030000003oool0oooo
02<0ooooC02W`>/30:S0jf80oooo00<000000?ooo`0000000@3oool004H0oooo00<000000?ooo`3o
ool08`3ooom;0:O0jfH0oooo0@0000010?ooo`40000000170?ooo`030000003oool0oooo02<0oooo
A`2W`>]Z0?ooo`80000000180?ooo`8000009@3ooom20:O0jfd0oooo0P00000004X0oooo00<00000
0?ooo`3oool08`3oooln0:O0jg00oooo0P00000004/0oooo00<000000?ooo`3oool08P3ooolk0:O0
jfl0oooo100000020?ooo`00C03oool00`000000oooo0?ooo`0S0?oooc<0Yl3[L@3oool4000000H0
oooo001=0?ooo`800000903oool_0:O0jg00oooo1000000:0?ooo`00C`3oool00`000000oooo0?oo
o`0R0?ooob/0Yl3[K`3oool4000000h0oooo001@0?ooo`030000003oool0oooo02<0oooo9P2W`>]^
0?ooo`@000004P3oool00540oooo00<000000?ooo`3oool08`3ooolR0:O0jfh0oooo0`00000F0?oo
o`00DP3oool2000002@0oooo7P2W`>]]0?ooo`@000006@3oool005@0oooo00<000000?ooo`3oool0
8P3ooolG0:O0jfl0oooo1000000M0?ooo`00E@3oool00`000000oooo0?ooo`0Q0?oooa@0Yl3[KP3o
ool400000240oooo001F0?ooo`030000003oool0oooo0280oooo3`2W`>]]0?ooo`@000009@3oool0
05L0oooo0P00000S0?ooo`/0Yl3[K03oool4000002T0oooo001I0?ooo`030000003oool0oooo0240
oooo102W`>]_0?ooo`<00000;@3oool005X0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1Z0?ooo`@00000<03oool005/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`1V0?ooo`@00000=03oool005`0oooo0P00000Q0?ooo`030000003oool0oooo0680oooo1000000h
0?ooo`00GP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo1000000l0?oo
o`00G`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo100000100?ooo`00
H03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo0`0000140?ooo`00H@3o
ool2000001`0oooo00<000000?ooo`3oool0D`3oool4000004L0oooo001S0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0C`3oool4000004/0oooo001T0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0B`3oool4000004l0oooo001U0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0A`3oool4000005<0oooo001V0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0@`3oool4000005L0oooo001W0?ooo`8000005P3oool00`000000oooo0?oo
o`100?ooo`<00000F`3oool006T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0l
0?ooo`@00000GP3oool006X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0h0?oo
o`@00000HP3oool006/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`@0
0000IP3oool006`0oooo0P00000@0?ooo`030000003oool0oooo0340oooo1000001Z0?ooo`00KP3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo1000001^0?ooo`00K`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo0`00001b0?ooo`00L03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo1000001e0?ooo`00L@3oool2000000/0
oooo00<000000?ooo`3oool08P3oool4000007T0oooo001c0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool07P3oool4000007d0oooo001d0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool06P3oool400000840oooo001e0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05P3oool4000008D0oooo001f0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?oo
o`<00000R@3oool007P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`@0
0000S03oool007T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000
T03oool007X0oooo00D000000?ooo`3oool0oooo000000090?ooo`@00000U03oool007/0oooo0P00
00000`3oool000000?ooo`040?ooo`@00000V03oool007d0oooo0P0000000`3oool0000000000002
000009`0oooo001n0?ooo`800000X03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68706 Mtetra
.42772 .68706 .43406 .69273 .44494 .68966 .43863 .68396 Mtetra
.43863 .68396 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68038 .47161 .67462 Mtetra
.47161 .67462 .47783 .68038 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .66149 .53878 .65559 Mtetra
.53878 .65559 .54483 .66149 .55616 .6583 .55014 .65237 Mtetra
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64915 Mtetra
.656 .752 .921 r
.56155 .64915 .56753 .65509 .57895 .65187 .573 .6459 Mtetra
.573 .6459 .57895 .65187 .59042 .64864 .5845 .64263 Mtetra
.657 .751 .92 r
.5845 .64263 .59042 .64864 .60194 .64543 .59604 .63934 Mtetra
.656 .75 .919 r
.59604 .63934 .60194 .64543 .6135 .64217 .60764 .63605 Mtetra
.655 .749 .919 r
.60764 .63605 .6135 .64217 .62511 .63888 .61928 .63276 Mtetra
.655 .75 .92 r
.61928 .63276 .62511 .63888 .63677 .63556 .63098 .62948 Mtetra
.655 .752 .921 r
.63098 .62948 .63677 .63556 .64848 .63223 .64272 .62619 Mtetra
.655 .754 .923 r
.64272 .62619 .64848 .63223 .66023 .62889 .65451 .62287 Mtetra
.655 .756 .924 r
.65451 .62287 .66023 .62889 .67204 .62555 .66635 .61952 Mtetra
.655 .757 .924 r
.66635 .61952 .67204 .62555 .68389 .62221 .67824 .61615 Mtetra
.656 .757 .924 r
.67824 .61615 .68389 .62221 .6958 .61887 .69018 .61276 Mtetra
.656 .756 .923 r
.69018 .61276 .6958 .61887 .70776 .61552 .70217 .60934 Mtetra
.657 .754 .922 r
.70217 .60934 .70776 .61552 .71976 .61217 .71421 .60588 Mtetra
.656 .752 .92 r
.71421 .60588 .71976 .61217 .73182 .60879 .7263 .60244 Mtetra
.656 .75 .919 r
.7263 .60244 .73182 .60879 .74393 .60541 .73844 .59899 Mtetra
.656 .749 .918 r
.73844 .59899 .74393 .60541 .75609 .60197 .75064 .59554 Mtetra
.655 .749 .919 r
.75064 .59554 .75609 .60197 .7683 .59849 .76289 .59211 Mtetra
.655 .751 .921 r
.76289 .59211 .7683 .59849 .78057 .59503 .77519 .58863 Mtetra
.656 .752 .921 r
.77519 .58863 .78057 .59503 .79288 .59156 .78755 .58512 Mtetra
.656 .752 .92 r
.78755 .58512 .79288 .59156 .80525 .58808 .79995 .58159 Mtetra
.656 .751 .92 r
.79995 .58159 .80525 .58808 .81767 .58457 .81241 .57806 Mtetra
.81241 .57806 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68706 .42134 .68134 Mtetra
.42134 .68134 .42772 .68706 .43863 .68396 .43227 .67823 Mtetra
.43227 .67823 .43863 .68396 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66881 Mtetra
.46533 .66881 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66247 Mtetra
.4876 .66247 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.656 .752 .92 r
.54408 .6464 .55014 .65237 .56155 .64915 .55551 .64314 Mtetra
.656 .751 .92 r
.55551 .64314 .56155 .64915 .573 .6459 .567 .63986 Mtetra
.567 .63986 .573 .6459 .5845 .64263 .57853 .63659 Mtetra
.655 .751 .921 r
.57853 .63659 .5845 .64263 .59604 .63934 .59011 .63332 Mtetra
.655 .753 .922 r
.59011 .63332 .59604 .63934 .60764 .63605 .60173 .63002 Mtetra
.656 .754 .922 r
.60173 .63002 .60764 .63605 .61928 .63276 .61341 .62668 Mtetra
.657 .753 .921 r
.61341 .62668 .61928 .63276 .63098 .62948 .62513 .6233 Mtetra
.657 .751 .919 r
.62513 .6233 .63098 .62948 .64272 .62619 .63691 .61991 Mtetra
.657 .749 .917 r
.63691 .61991 .64272 .62619 .65451 .62287 .64873 .61652 Mtetra
.657 .747 .916 r
.64873 .61652 .65451 .62287 .66635 .61952 .6606 .61313 Mtetra
.656 .746 .916 r
.6606 .61313 .66635 .61952 .67824 .61615 .67253 .60973 Mtetra
.67253 .60973 .67824 .61615 .69018 .61276 .6845 .60634 Mtetra
.655 .747 .917 r
.6845 .60634 .69018 .61276 .70217 .60934 .69653 .60294 Mtetra
.655 .748 .918 r
.69653 .60294 .70217 .60934 .71421 .60588 .70861 .59954 Mtetra
.655 .751 .921 r
.70861 .59954 .71421 .60588 .7263 .60244 .72074 .59612 Mtetra
.655 .753 .922 r
.72074 .59612 .7263 .60244 .73844 .59899 .73292 .59267 Mtetra
.656 .754 .922 r
.73292 .59267 .73844 .59899 .75064 .59554 .74515 .58918 Mtetra
.656 .753 .921 r
.74515 .58918 .75064 .59554 .76289 .59211 .75744 .58566 Mtetra
.656 .751 .92 r
.75744 .58566 .76289 .59211 .77519 .58863 .76977 .58214 Mtetra
.76977 .58214 .77519 .58863 .78755 .58512 .78216 .57861 Mtetra
.78216 .57861 .78755 .58512 .79995 .58159 .79461 .57507 Mtetra
.79461 .57507 .79995 .58159 .81241 .57806 .80711 .57151 Mtetra
.80711 .57151 .81241 .57806 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66881 .45901 .66296 Mtetra
.45901 .66296 .46533 .66881 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66247 .48134 .65658 Mtetra
.48134 .65658 .4876 .66247 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .6371 Mtetra
.656 .752 .92 r
.54943 .6371 .55551 .64314 .567 .63986 .56095 .63381 Mtetra
.56095 .63381 .567 .63986 .57853 .63659 .57251 .63049 Mtetra
.657 .752 .92 r
.57251 .63049 .57853 .63659 .59011 .63332 .58412 .62714 Mtetra
.656 .75 .919 r
.58412 .62714 .59011 .63332 .60173 .63002 .59578 .62379 Mtetra
.655 .749 .918 r
.59578 .62379 .60173 .63002 .61341 .62668 .60749 .62046 Mtetra
.655 .749 .92 r
.60749 .62046 .61341 .62668 .62513 .6233 .61925 .61713 Mtetra
.654 .752 .922 r
.61925 .61713 .62513 .6233 .63691 .61991 .63106 .6138 Mtetra
.654 .755 .923 r
.63106 .6138 .63691 .61991 .64873 .61652 .64292 .61043 Mtetra
.655 .757 .925 r
.64292 .61043 .64873 .61652 .6606 .61313 .65483 .60704 Mtetra
.65483 .60704 .6606 .61313 .67253 .60973 .66679 .60362 Mtetra
.656 .758 .925 r
.66679 .60362 .67253 .60973 .6845 .60634 .6788 .60016 Mtetra
.656 .757 .924 r
.6788 .60016 .6845 .60634 .69653 .60294 .69086 .59668 Mtetra
.657 .755 .922 r
.69086 .59668 .69653 .60294 .70861 .59954 .70297 .59317 Mtetra
.657 .752 .92 r
.70297 .59317 .70861 .59954 .72074 .59612 .71513 .58966 Mtetra
.656 .75 .919 r
.71513 .58966 .72074 .59612 .73292 .59267 .72734 .58616 Mtetra
.655 .749 .919 r
.72734 .58616 .73292 .59267 .74515 .58918 .73961 .58266 Mtetra
.655 .75 .919 r
.73961 .58266 .74515 .58918 .75744 .58566 .75194 .57916 Mtetra
.656 .751 .92 r
.75194 .57916 .75744 .58566 .76977 .58214 .76431 .57562 Mtetra
.656 .752 .92 r
.76431 .57562 .76977 .58214 .78216 .57861 .77674 .57206 Mtetra
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Mtetra
.656 .751 .92 r
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .6474 Mtetra
.48629 .6474 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Mtetra
.53181 .63431 .53797 .64037 .54943 .6371 .54331 .631 Mtetra
.54331 .631 .54943 .6371 .56095 .63381 .55486 .62767 Mtetra
.55486 .62767 .56095 .63381 .57251 .63049 .56645 .62435 Mtetra
.655 .751 .921 r
.56645 .62435 .57251 .63049 .58412 .62714 .57809 .62103 Mtetra
.655 .753 .922 r
.57809 .62103 .58412 .62714 .59578 .62379 .58979 .61769 Mtetra
.656 .754 .922 r
.58979 .61769 .59578 .62379 .60749 .62046 .60153 .6143 Mtetra
.657 .754 .921 r
.60153 .6143 .60749 .62046 .61925 .61713 .61332 .61086 Mtetra
.657 .751 .919 r
.61332 .61086 .61925 .61713 .63106 .6138 .62516 .60742 Mtetra
.657 .748 .917 r
.62516 .60742 .63106 .6138 .64292 .61043 .63705 .60397 Mtetra
.657 .746 .916 r
.63705 .60397 .64292 .61043 .65483 .60704 .64899 .60052 Mtetra
.656 .745 .916 r
.64899 .60052 .65483 .60704 .66679 .60362 .66098 .59707 Mtetra
.66098 .59707 .66679 .60362 .6788 .60016 .67303 .59363 Mtetra
.655 .746 .917 r
.67303 .59363 .6788 .60016 .69086 .59668 .68513 .59017 Mtetra
.654 .748 .918 r
.68513 .59017 .69086 .59668 .70297 .59317 .69728 .58673 Mtetra
.655 .751 .921 r
.69728 .58673 .70297 .59317 .71513 .58966 .70948 .58326 Mtetra
.655 .753 .922 r
.70948 .58326 .71513 .58966 .72734 .58616 .72173 .57975 Mtetra
.656 .754 .922 r
.72173 .57975 .72734 .58616 .73961 .58266 .73404 .57619 Mtetra
.657 .753 .921 r
.73404 .57619 .73961 .58266 .75194 .57916 .7464 .5726 Mtetra
.656 .751 .92 r
.7464 .5726 .75194 .57916 .76431 .57562 .75881 .56903 Mtetra
.75881 .56903 .76431 .57562 .77674 .57206 .77128 .56545 Mtetra
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Mtetra
.656 .752 .92 r
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Mtetra
.656 .751 .92 r
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .6474 .47997 .64138 Mtetra
.47997 .64138 .48629 .6474 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Mtetra
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Mtetra
.655 .752 .921 r
.53714 .62486 .54331 .631 .55486 .62767 .54871 .62153 Mtetra
.656 .752 .921 r
.54871 .62153 .55486 .62767 .56645 .62435 .56034 .61817 Mtetra
.56034 .61817 .56645 .62435 .57809 .62103 .57202 .61479 Mtetra
.655 .75 .92 r
.57202 .61479 .57809 .62103 .58979 .61769 .58374 .61142 Mtetra
.653 .75 .921 r
.58374 .61142 .58979 .61769 .60153 .6143 .59552 .6081 Mtetra
.651 .752 .924 r
.59552 .6081 .60153 .6143 .61332 .61086 .60735 .60483 Mtetra
.65 .758 .929 r
.60735 .60483 .61332 .61086 .62516 .60742 .61923 .60154 Mtetra
.65 .765 .933 r
.61923 .60154 .62516 .60742 .63705 .60397 .63116 .59821 Mtetra
.651 .77 .936 r
.63116 .59821 .63705 .60397 .64899 .60052 .64314 .59482 Mtetra
.653 .773 .937 r
.64314 .59482 .64899 .60052 .66098 .59707 .65517 .59134 Mtetra
.655 .774 .936 r
.65517 .59134 .66098 .59707 .67303 .59363 .66725 .58779 Mtetra
.658 .772 .934 r
.66725 .58779 .67303 .59363 .68513 .59017 .67938 .58417 Mtetra
.66 .768 .93 r
.67938 .58417 .68513 .59017 .69728 .58673 .69156 .58049 Mtetra
.66 .761 .925 r
.69156 .58049 .69728 .58673 .70948 .58326 .70379 .57682 Mtetra
.658 .755 .921 r
.70379 .57682 .70948 .58326 .72173 .57975 .71607 .57318 Mtetra
.657 .751 .92 r
.71607 .57318 .72173 .57975 .73404 .57619 .72841 .56959 Mtetra
.656 .751 .92 r
.72841 .56959 .73404 .57619 .7464 .5726 .74081 .56602 Mtetra
.656 .752 .921 r
.74081 .56602 .7464 .5726 .75881 .56903 .75326 .56242 Mtetra
.75326 .56242 .75881 .56903 .77128 .56545 .76577 .5588 Mtetra
.656 .752 .92 r
.76577 .5588 .77128 .56545 .7838 .56185 .77832 .55516 Mtetra
.656 .751 .92 r
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64514 Mtetra
.43976 .64514 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Mtetra
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62538 Mtetra
.655 .751 .92 r
.50784 .62538 .51412 .63151 .52561 .62819 .51935 .62204 Mtetra
.655 .752 .921 r
.51935 .62204 .52561 .62819 .53714 .62486 .53091 .6187 Mtetra
.653 .752 .922 r
.53091 .6187 .53714 .62486 .54871 .62153 .54253 .6154 Mtetra
.65 .752 .924 r
.54253 .6154 .54871 .62153 .56034 .61817 .55419 .61217 Mtetra
.643 .756 .931 r
.55419 .61217 .56034 .61817 .57202 .61479 .5659 .60909 Mtetra
.636 .765 .941 r
.5659 .60909 .57202 .61479 .58374 .61142 .57767 .60613 Mtetra
.629 .778 .952 r
.57767 .60613 .58374 .61142 .59552 .6081 .58949 .60323 Mtetra
.623 .793 .963 r
.58949 .60323 .59552 .6081 .60735 .60483 .60136 .60033 Mtetra
.619 .807 .972 r
.60136 .60033 .60735 .60483 .61923 .60154 .61329 .59736 Mtetra
.618 .82 .978 r
.61329 .59736 .61923 .60154 .63116 .59821 .62527 .59428 Mtetra
.621 .832 .981 r
.62527 .59428 .63116 .59821 .64314 .59482 .6373 .59101 Mtetra
.629 .84 .981 r
.6373 .59101 .64314 .59482 .65517 .59134 .64938 .58751 Mtetra
.639 .843 .978 r
.64938 .58751 .65517 .59134 .66725 .58779 .6615 .58378 Mtetra
.65 .841 .973 r
.6615 .58378 .66725 .58779 .67938 .58417 .67366 .57986 Mtetra
.659 .832 .966 r
.67366 .57986 .67938 .58417 .69156 .58049 .68587 .57582 Mtetra
.665 .821 .958 r
.68587 .57582 .69156 .58049 .70379 .57682 .69812 .57171 Mtetra
.668 .806 .949 r
.69812 .57171 .70379 .57682 .71607 .57318 .71042 .5676 Mtetra
.668 .79 .939 r
.71042 .5676 .71607 .57318 .72841 .56959 .72278 .56355 Mtetra
.665 .774 .931 r
.72278 .56355 .72841 .56959 .74081 .56602 .73519 .55961 Mtetra
.661 .761 .924 r
.73519 .55961 .74081 .56602 .75326 .56242 .74767 .55582 Mtetra
.658 .755 .922 r
.74767 .55582 .75326 .56242 .76577 .5588 .76021 .55211 Mtetra
.656 .753 .921 r
.76021 .55211 .76577 .5588 .77832 .55516 .77281 .54843 Mtetra
.656 .752 .92 r
.77281 .54843 .77832 .55516 .79094 .55152 .78546 .54475 Mtetra
.656 .751 .92 r
.78546 .54475 .79094 .55152 .80361 .54786 .79817 .54105 Mtetra
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64514 .43325 .63911 Mtetra
.43325 .63911 .43976 .64514 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Mtetra
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Mtetra
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Mtetra
.655 .751 .921 r
.49001 .62255 .49638 .6287 .50784 .62538 .50151 .61923 Mtetra
.652 .751 .922 r
.50151 .61923 .50784 .62538 .51935 .62204 .51305 .61596 Mtetra
.645 .752 .927 r
.51305 .61596 .51935 .62204 .53091 .6187 .52464 .61285 Mtetra
.632 .757 .938 r
.52464 .61285 .53091 .6187 .54253 .6154 .53629 .61004 Mtetra
.609 .768 .956 r
.53629 .61004 .54253 .6154 .55419 .61217 .54799 .60762 Mtetra
.575 .788 .98 r
.54799 .60762 .55419 .61217 .5659 .60909 .55975 .60557 Mtetra
.522 .811 .998 r
.55975 .60557 .5659 .60909 .57767 .60613 .57158 .6038 Mtetra
.446 .824 .991 r
.57158 .6038 .57767 .60613 .58949 .60323 .58347 .60209 Mtetra
.357 .812 .937 r
.58347 .60209 .58949 .60323 .60136 .60033 .59542 .60022 Mtetra
.281 .782 .855 r
.59542 .60022 .60136 .60033 .61329 .59736 .60742 .59798 Mtetra
.241 .757 .787 r
.60742 .59798 .61329 .59736 .62527 .59428 .61947 .59529 Mtetra
.237 .752 .753 r
.61947 .59529 .62527 .59428 .6373 .59101 .63157 .59217 Mtetra
.259 .765 .748 r
.63157 .59217 .6373 .59101 .64938 .58751 .64371 .58866 Mtetra
.301 .792 .766 r
.64371 .58866 .64938 .58751 .6615 .58378 .65588 .58474 Mtetra
.365 .834 .803 r
.65588 .58474 .6615 .58378 .67366 .57986 .66809 .58038 Mtetra
.454 .885 .859 r
.66809 .58038 .67366 .57986 .68587 .57582 .68033 .57557 Mtetra
.555 .928 .922 r
.68033 .57557 .68587 .57582 .69812 .57171 .69259 .57039 Mtetra
.635 .936 .964 r
.69259 .57039 .69812 .57171 .71042 .5676 .70488 .56502 Mtetra
.678 .909 .975 r
.70488 .56502 .71042 .5676 .72278 .56355 .71722 .55971 Mtetra
.688 .864 .965 r
.71722 .55971 .72278 .56355 .73519 .55961 .72962 .55467 Mtetra
.683 .822 .95 r
.72962 .55467 .73519 .55961 .74767 .55582 .74209 .55001 Mtetra
.673 .788 .936 r
.74209 .55001 .74767 .55582 .76021 .55211 .75464 .54573 Mtetra
.664 .767 .927 r
.75464 .54573 .76021 .55211 .77281 .54843 .76726 .54176 Mtetra
.659 .757 .922 r
.76726 .54176 .77281 .54843 .78546 .54475 .77994 .53795 Mtetra
.657 .753 .921 r
.77994 .53795 .78546 .54475 .79817 .54105 .79269 .5342 Mtetra
.656 .752 .92 r
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Mtetra
.656 .751 .92 r
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Mtetra
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Mtetra
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Mtetra
.655 .751 .921 r
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61973 Mtetra
.653 .751 .922 r
.47212 .61973 .47856 .62589 .49001 .62255 .4836 .61643 Mtetra
.646 .751 .926 r
.4836 .61643 .49001 .62255 .50151 .61923 .49512 .61331 Mtetra
.628 .754 .937 r
.49512 .61331 .50151 .61923 .51305 .61596 .5067 .6106 Mtetra
.59 .762 .961 r
.5067 .6106 .51305 .61596 .52464 .61285 .51832 .60858 Mtetra
.514 .777 .992 r
.51832 .60858 .52464 .61285 .53629 .61004 .53001 .60736 Mtetra
.376 .777 .985 r
.53001 .60736 .53629 .61004 .54799 .60762 .54176 .60669 Mtetra
.205 .722 .874 r
.54176 .60669 .54799 .60762 .55975 .60557 .55358 .60596 Mtetra
.133 .681 .755 r
.55358 .60596 .55975 .60557 .57158 .6038 .56547 .60449 Mtetra
.222 .744 .776 r
.56547 .60449 .57158 .6038 .58347 .60209 .5774 .60195 Mtetra
.42 .863 .904 r
.5774 .60195 .58347 .60209 .59542 .60022 .58937 .59848 Mtetra
.584 .902 .984 r
.58937 .59848 .59542 .60022 .60742 .59798 .60139 .59451 Mtetra
.648 .86 .98 r
.60139 .59451 .60742 .59798 .61947 .59529 .61345 .59046 Mtetra
.658 .811 .957 r
.61345 .59046 .61947 .59529 .63157 .59217 .62556 .5866 Mtetra
.65 .783 .945 r
.62556 .5866 .63157 .59217 .64371 .58866 .63774 .58306 Mtetra
.637 .779 .949 r
.63774 .58306 .64371 .58866 .65588 .58474 .64998 .57984 Mtetra
.62 .8 .969 r
.64998 .57984 .65588 .58474 .66809 .58038 .66229 .57682 Mtetra
.593 .844 .992 r
.66229 .57682 .66809 .58038 .68033 .57557 .67465 .57371 Mtetra
.548 .89 .984 r
.67465 .57371 .68033 .57557 .69259 .57039 .68705 .57009 Mtetra
.503 .905 .918 r
.68705 .57009 .69259 .57039 .70488 .56502 .69945 .56552 Mtetra
.515 .915 .867 r
.69945 .56552 .70488 .56502 .71722 .55971 .71184 .55985 Mtetra
.6 .95 .896 r
.71184 .55985 .71722 .55971 .72962 .55467 .72422 .55343 Mtetra
.685 .955 .951 r
.72422 .55343 .72962 .55467 .74209 .55001 .73664 .54693 Mtetra
.71 .903 .964 r
.73664 .54693 .74209 .55001 .75464 .54573 .74913 .54098 Mtetra
.696 .837 .95 r
.74913 .54098 .75464 .54573 .76726 .54176 .76172 .53583 Mtetra
.676 .789 .934 r
.76172 .53583 .76726 .54176 .77994 .53795 .7744 .53139 Mtetra
.664 .765 .925 r
.7744 .53139 .77994 .53795 .79269 .5342 .78717 .52738 Mtetra
.658 .755 .922 r
.78717 .52738 .79269 .5342 .8055 .53046 .80001 .52353 Mtetra
.656 .752 .921 r
.80001 .52353 .8055 .53046 .81836 .5267 .81291 .51973 Mtetra
.656 .752 .92 r
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Mtetra
.656 .751 .92 r
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62358 Mtetra
.43138 .62358 .43797 .62973 .44931 .6264 .44275 .62023 Mtetra
.655 .751 .921 r
.44275 .62023 .44931 .6264 .46069 .62306 .45416 .61689 Mtetra
.651 .751 .923 r
.45416 .61689 .46069 .62306 .47212 .61973 .46562 .61364 Mtetra
.638 .751 .93 r
.46562 .61364 .47212 .61973 .4836 .61643 .47713 .61071 Mtetra
.602 .753 .95 r
.47713 .61071 .4836 .61643 .49512 .61331 .48867 .60855 Mtetra
.516 .759 .984 r
.48867 .60855 .49512 .61331 .5067 .6106 .50027 .60755 Mtetra
.337 .743 .981 r
.50027 .60755 .5067 .6106 .51832 .60858 .51193 .60754 Mtetra
.132 .67 .846 r
.51193 .60754 .51832 .60858 .53001 .60736 .52366 .6075 Mtetra
.162 .702 .79 r
.52366 .6075 .53001 .60736 .54176 .60669 .53546 .60607 Mtetra
.474 .882 .943 r
.53546 .60607 .54176 .60669 .55358 .60596 .54732 .6026 Mtetra
.694 .871 .965 r
.54732 .6026 .55358 .60596 .56547 .60449 .5592 .59757 Mtetra
.713 .754 .884 r
.5592 .59757 .56547 .60449 .5774 .60195 .57113 .59204 Mtetra
.691 .677 .832 r
.57113 .59204 .5774 .60195 .58937 .59848 .58309 .58679 Mtetra
.671 .639 .809 r
.58309 .58679 .58937 .59848 .60139 .59451 .59511 .5821 Mtetra
.658 .623 .803 r
.59511 .5821 .60139 .59451 .61345 .59046 .60718 .5779 Mtetra
.651 .618 .803 r
.60718 .5779 .61345 .59046 .62556 .5866 .61931 .57407 Mtetra
.646 .616 .806 r
.61931 .57407 .62556 .5866 .63774 .58306 .6315 .5705 Mtetra
.64 .614 .807 r
.6315 .5705 .63774 .58306 .64998 .57984 .64376 .56719 Mtetra
.632 .609 .809 r
.64376 .56719 .64998 .57984 .66229 .57682 .65608 .56425 Mtetra
.621 .606 .813 r
.65608 .56425 .66229 .57682 .67465 .57371 .66849 .5618 Mtetra
.609 .61 .827 r
.66849 .5618 .67465 .57371 .68705 .57009 .68098 .55992 Mtetra
.599 .639 .862 r
.68098 .55992 .68705 .57009 .69945 .56552 .69356 .55833 Mtetra
.602 .718 .926 r
.69356 .55833 .69945 .56552 .71184 .55985 .70618 .55622 Mtetra
.618 .855 .988 r
.70618 .55622 .71184 .55985 .72422 .55343 .71878 .55253 Mtetra
.623 .945 .947 r
.71878 .55253 .72422 .55343 .73664 .54693 .73131 .54674 Mtetra
.663 .969 .909 r
.73131 .54674 .73664 .54693 .74913 .54098 .74379 .53953 Mtetra
.722 .96 .944 r
.74379 .53953 .74913 .54098 .76172 .53583 .75629 .53227 Mtetra
.723 .891 .956 r
.75629 .53227 .76172 .53583 .7744 .53139 .7689 .52602 Mtetra
.693 .817 .941 r
.7689 .52602 .7744 .53139 .78717 .52738 .78164 .52096 Mtetra
.67 .774 .928 r
.78164 .52096 .78717 .52738 .80001 .52353 .79449 .51668 Mtetra
.66 .757 .922 r
.79449 .51668 .80001 .52353 .81291 .51973 .80742 .51272 Mtetra
.657 .753 .921 r
.80742 .51272 .81291 .51973 .82587 .51592 .82043 .50886 Mtetra
.656 .752 .92 r
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Mtetra
.656 .751 .92 r
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Mtetra
.4134 .62074 .42007 .62691 .43138 .62358 .42475 .61738 Mtetra
.655 .751 .921 r
.42475 .61738 .43138 .62358 .44275 .62023 .43614 .61403 Mtetra
.65 .751 .923 r
.43614 .61403 .44275 .62023 .45416 .61689 .44758 .61081 Mtetra
.631 .75 .933 r
.44758 .61081 .45416 .61689 .46562 .61364 .45906 .60804 Mtetra
.575 .749 .96 r
.45906 .60804 .46562 .61364 .47713 .61071 .47058 .60638 Mtetra
.43 .74 .992 r
.47058 .60638 .47713 .61071 .48867 .60855 .48214 .60626 Mtetra
.169 .669 .913 r
.48214 .60626 .48867 .60855 .50027 .60755 .49376 .60705 Mtetra
.095 .65 .796 r
.49376 .60705 .50027 .60755 .51193 .60754 .50546 .60677 Mtetra
.446 .866 .945 r
.50546 .60677 .51193 .60754 .52366 .6075 .51725 .60376 Mtetra
.715 .859 .95 r
.51725 .60376 .52366 .6075 .53546 .60607 .52908 .59829 Mtetra
.723 .733 .859 r
.52908 .59829 .53546 .60607 .54732 .6026 .54095 .59209 Mtetra
.693 .667 .82 r
.54095 .59209 .54732 .6026 .5592 .59757 .55286 .58655 Mtetra
.673 .65 .82 r
.55286 .58655 .5592 .59757 .57113 .59204 .56481 .58193 Mtetra
.664 .664 .84 r
.56481 .58193 .57113 .59204 .58309 .58679 .57682 .57789 Mtetra
.661 .69 .866 r
.57682 .57789 .58309 .58679 .59511 .5821 .58889 .57409 Mtetra
.66 .712 .886 r
.58889 .57409 .59511 .5821 .60718 .5779 .601 .57037 Mtetra
.658 .725 .898 r
.601 .57037 .60718 .5779 .61931 .57407 .61317 .56671 Mtetra
.656 .73 .904 r
.61317 .56671 .61931 .57407 .6315 .5705 .62539 .56311 Mtetra
.654 .729 .905 r
.62539 .56311 .6315 .5705 .64376 .56719 .63767 .55958 Mtetra
.652 .723 .901 r
.63767 .55958 .64376 .56719 .65608 .56425 .65001 .5561 Mtetra
.649 .708 .891 r
.65001 .5561 .65608 .56425 .66849 .5618 .66241 .5527 Mtetra
.641 .682 .873 r
.66241 .5527 .66849 .5618 .68098 .55992 .67488 .54955 Mtetra
.625 .648 .853 r
.67488 .54955 .68098 .55992 .69356 .55833 .68743 .54697 Mtetra
.601 .618 .841 r
.68743 .54697 .69356 .55833 .70618 .55622 .7001 .54533 Mtetra
.582 .619 .854 r
.7001 .54533 .70618 .55622 .71878 .55253 .71287 .54435 Mtetra
.593 .688 .908 r
.71287 .54435 .71878 .55253 .73131 .54674 .72568 .54263 Mtetra
.65 .85 .977 r
.72568 .54263 .73131 .54674 .74379 .53953 .7384 .53838 Mtetra
.698 .963 .941 r
.7384 .53838 .74379 .53953 .75629 .53227 .75099 .53134 Mtetra
.737 .976 .922 r
.75099 .53134 .75629 .53227 .7689 .52602 .76354 .52319 Mtetra
.747 .925 .949 r
.76354 .52319 .7689 .52602 .78164 .52096 .77617 .51596 Mtetra
.709 .838 .944 r
.77617 .51596 .78164 .52096 .79449 .51668 .78897 .51032 Mtetra
.675 .781 .93 r
.78897 .51032 .79449 .51668 .80742 .51272 .8019 .50581 Mtetra
.661 .759 .923 r
.8019 .50581 .80742 .51272 .82043 .50886 .81493 .50177 Mtetra
.657 .753 .921 r
.81493 .50177 .82043 .50886 .83349 .50501 .82803 .49786 Mtetra
.656 .752 .92 r
.82803 .49786 .83349 .50501 .84661 .50114 .8412 .49395 Mtetra
.656 .751 .92 r
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Mtetra
.655 .751 .921 r
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61116 Mtetra
.65 .751 .923 r
.41806 .61116 .42475 .61738 .43614 .61403 .42948 .60791 Mtetra
.629 .749 .933 r
.42948 .60791 .43614 .61403 .44758 .61081 .44094 .60518 Mtetra
.561 .744 .962 r
.44094 .60518 .44758 .61081 .45906 .60804 .45242 .60375 Mtetra
.372 .715 .987 r
.45242 .60375 .45906 .60804 .47058 .60638 .46393 .60424 Mtetra
.074 .607 .862 r
.46393 .60424 .47058 .60638 .48214 .60626 .47551 .60561 Mtetra
.138 .68 .827 r
.47551 .60561 .48214 .60626 .49376 .60705 .48719 .60514 Mtetra
.61 .901 .986 r
.48719 .60514 .49376 .60705 .50546 .60677 .49896 .60105 Mtetra
.742 .794 .894 r
.49896 .60105 .50546 .60677 .51725 .60376 .5108 .5946 Mtetra
.718 .701 .833 r
.5108 .5946 .51725 .60376 .52908 .59829 .52266 .58818 Mtetra
.692 .674 .828 r
.52266 .58818 .52908 .59829 .54095 .59209 .53456 .58281 Mtetra
.681 .687 .85 r
.53456 .58281 .54095 .59209 .55286 .58655 .5465 .57816 Mtetra
.677 .707 .87 r
.5465 .57816 .55286 .58655 .56481 .58193 .55849 .5738 Mtetra
.673 .713 .878 r
.55849 .5738 .56481 .58193 .57682 .57789 .57052 .5696 Mtetra
.668 .708 .878 r
.57052 .5696 .57682 .57789 .58889 .57409 .58261 .56558 Mtetra
.662 .702 .876 r
.58261 .56558 .58889 .57409 .601 .57037 .59475 .56173 Mtetra
.658 .697 .875 r
.59475 .56173 .601 .57037 .61317 .56671 .60695 .558 Mtetra
.655 .695 .875 r
.60695 .558 .61317 .56671 .62539 .56311 .6192 .55438 Mtetra
.652 .694 .876 r
.6192 .55438 .62539 .56311 .63767 .55958 .63151 .55085 Mtetra
.648 .694 .879 r
.63151 .55085 .63767 .55958 .65001 .5561 .64388 .54745 Mtetra
.643 .695 .883 r
.64388 .54745 .65001 .5561 .66241 .5527 .65632 .54421 Mtetra
.637 .697 .889 r
.65632 .54421 .66241 .5527 .67488 .54955 .66882 .54116 Mtetra
.632 .698 .893 r
.66882 .54116 .67488 .54955 .68743 .54697 .68139 .53827 Mtetra
.623 .687 .889 r
.68139 .53827 .68743 .54697 .7001 .54533 .69404 .53567 Mtetra
.603 .656 .875 r
.69404 .53567 .7001 .54533 .71287 .54435 .70679 .5338 Mtetra
.574 .624 .864 r
.70679 .5338 .71287 .54435 .72568 .54263 .71968 .53298 Mtetra
.568 .642 .883 r
.71968 .53298 .72568 .54263 .7384 .53838 .73265 .5322 Mtetra
.63 .769 .947 r
.73265 .5322 .7384 .53838 .75099 .53134 .74554 .52899 Mtetra
.726 .937 .956 r
.74554 .52899 .75099 .53134 .76354 .52319 .75823 .52206 Mtetra
.767 .978 .916 r
.75823 .52206 .76354 .52319 .77617 .51596 .77082 .51323 Mtetra
.766 .933 .939 r
.77082 .51323 .77617 .51596 .78897 .51032 .78351 .50531 Mtetra
.717 .843 .942 r
.78351 .50531 .78897 .51032 .8019 .50581 .79638 .49935 Mtetra
.677 .781 .929 r
.79638 .49935 .8019 .50581 .81493 .50177 .80941 .49474 Mtetra
.661 .758 .922 r
.80941 .49474 .81493 .50177 .82803 .49786 .82254 .49066 Mtetra
.657 .752 .921 r
.82254 .49066 .82803 .49786 .8412 .49395 .83574 .4867 Mtetra
.656 .752 .92 r
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Mtetra
.656 .751 .92 r
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Mtetra
.655 .751 .92 r
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60827 Mtetra
.652 .751 .922 r
.39991 .60827 .40668 .61452 .41806 .61116 .41131 .60496 Mtetra
.634 .749 .93 r
.41131 .60496 .41806 .61116 .42948 .60791 .42275 .60209 Mtetra
.57 .741 .957 r
.42275 .60209 .42948 .60791 .44094 .60518 .43421 .60055 Mtetra
.369 .702 .984 r
.43421 .60055 .44094 .60518 .45242 .60375 .44568 .60125 Mtetra
.023 .562 .846 r
.44568 .60125 .45242 .60375 .46393 .60424 .45719 .60331 Mtetra
.101 .65 .823 r
.45719 .60331 .46393 .60424 .47551 .60561 .46883 .60337 Mtetra
.636 .896 .985 r
.46883 .60337 .47551 .60561 .48719 .60514 .4806 .59907 Mtetra
.754 .785 .878 r
.4806 .59907 .48719 .60514 .49896 .60105 .49244 .59196 Mtetra
.729 .706 .829 r
.49244 .59196 .49896 .60105 .5108 .5946 .50431 .58495 Mtetra
.704 .688 .832 r
.50431 .58495 .5108 .5946 .52266 .58818 .51619 .57911 Mtetra
.688 .695 .851 r
.51619 .57911 .52266 .58818 .53456 .58281 .52812 .57415 Mtetra
.676 .701 .866 r
.52812 .57415 .53456 .58281 .5465 .57816 .54009 .56979 Mtetra
.666 .705 .877 r
.54009 .56979 .5465 .57816 .55849 .5738 .55211 .56584 Mtetra
.66 .714 .889 r
.55211 .56584 .55849 .5738 .57052 .5696 .56419 .56211 Mtetra
.657 .727 .901 r
.56419 .56211 .57052 .5696 .58261 .56558 .57631 .55846 Mtetra
.657 .738 .91 r
.57631 .55846 .58261 .56558 .59475 .56173 .58849 .5548 Mtetra
.656 .745 .915 r
.58849 .5548 .59475 .56173 .60695 .558 .60073 .55114 Mtetra
.655 .748 .918 r
.60073 .55114 .60695 .558 .6192 .55438 .61302 .54749 Mtetra
.61302 .54749 .6192 .55438 .63151 .55085 .62536 .54384 Mtetra
.654 .745 .916 r
.62536 .54384 .63151 .55085 .64388 .54745 .63776 .54018 Mtetra
.654 .738 .911 r
.63776 .54018 .64388 .54745 .65632 .54421 .65021 .53652 Mtetra
.652 .726 .903 r
.65021 .53652 .65632 .54421 .66882 .54116 .66273 .53294 Mtetra
.645 .71 .894 r
.66273 .53294 .66882 .54116 .68139 .53827 .67531 .52957 Mtetra
.632 .693 .888 r
.67531 .52957 .68139 .53827 .69404 .53567 .68797 .52663 Mtetra
.614 .677 .886 r
.68797 .52663 .69404 .53567 .70679 .5338 .70073 .52428 Mtetra
.588 .655 .883 r
.70073 .52428 .70679 .5338 .71968 .53298 .71361 .52284 Mtetra
.553 .624 .877 r
.71361 .52284 .71968 .53298 .73265 .5322 .72663 .52256 Mtetra
.546 .633 .889 r
.72663 .52256 .73265 .5322 .74554 .52899 .73975 .52239 Mtetra
.625 .756 .941 r
.73975 .52239 .74554 .52899 .75823 .52206 .75276 .51932 Mtetra
.753 .931 .946 r
.75276 .51932 .75823 .52206 .77082 .51323 .76551 .51176 Mtetra
.798 .974 .908 r
.76551 .51176 .77082 .51323 .78351 .50531 .77814 .50215 Mtetra
.777 .923 .933 r
.77814 .50215 .78351 .50531 .79638 .49935 .79089 .49393 Mtetra
.714 .83 .937 r
.79089 .49393 .79638 .49935 .80941 .49474 .80386 .48802 Mtetra
.673 .774 .926 r
.80386 .48802 .80941 .49474 .82254 .49066 .817 .48349 Mtetra
.659 .756 .922 r
.817 .48349 .82254 .49066 .83574 .4867 .83024 .47941 Mtetra
.656 .752 .92 r
.83024 .47941 .83574 .4867 .84901 .48275 .84355 .47541 Mtetra
.656 .751 .92 r
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60537 Mtetra
.654 .751 .921 r
.38169 .60537 .38855 .61165 .39991 .60827 .39308 .60199 Mtetra
.643 .749 .926 r
.39308 .60199 .39991 .60827 .41131 .60496 .40451 .5989 Mtetra
.595 .743 .947 r
.40451 .5989 .41131 .60496 .42275 .60209 .41595 .5969 Mtetra
.424 .707 .982 r
.41595 .5969 .42275 .60209 .43421 .60055 .42738 .59727 Mtetra
.028 .544 .867 r
.42738 .59727 .43421 .60055 .44568 .60125 .43883 .59993 Mtetra
0 .532 .756 r
.43883 .59993 .44568 .60125 .45719 .60331 .4504 .60145 Mtetra
.561 .886 .989 r
.4504 .60145 .45719 .60331 .46883 .60337 .46214 .59801 Mtetra
.769 .808 .884 r
.46214 .59801 .46883 .60337 .4806 .59907 .474 .5904 Mtetra
.75 .721 .825 r
.474 .5904 .4806 .59907 .49244 .59196 .48588 .58234 Mtetra
.717 .693 .827 r
.48588 .58234 .49244 .59196 .50431 .58495 .49777 .57581 Mtetra
.691 .695 .849 r
.49777 .57581 .50431 .58495 .51619 .57911 .50969 .5707 Mtetra
.674 .707 .872 r
.50969 .5707 .51619 .57911 .52812 .57415 .52164 .56641 Mtetra
.668 .723 .89 r
.52164 .56641 .52812 .57415 .54009 .56979 .53364 .56241 Mtetra
.667 .734 .899 r
.53364 .56241 .54009 .56979 .55211 .56584 .5457 .55843 Mtetra
.666 .733 .9 r
.5457 .55843 .55211 .56584 .56419 .56211 .5578 .55446 Mtetra
.664 .726 .896 r
.5578 .55446 .56419 .56211 .57631 .55846 .56996 .55056 Mtetra
.661 .72 .892 r
.56996 .55056 .57631 .55846 .58849 .5548 .58217 .54675 Mtetra
.658 .715 .891 r
.58217 .54675 .58849 .5548 .60073 .55114 .59443 .543 Mtetra
.656 .713 .89 r
.59443 .543 .60073 .55114 .61302 .54749 .60675 .53932 Mtetra
.654 .713 .891 r
.60675 .53932 .61302 .54749 .62536 .54384 .61913 .53569 Mtetra
.651 .713 .893 r
.61913 .53569 .62536 .54384 .63776 .54018 .63156 .53214 Mtetra
.648 .715 .897 r
.63156 .53214 .63776 .54018 .65021 .53652 .64406 .52867 Mtetra
.645 .72 .903 r
.64406 .52867 .65021 .53652 .66273 .53294 .65662 .52526 Mtetra
.644 .726 .908 r
.65662 .52526 .66273 .53294 .67531 .52957 .66923 .52188 Mtetra
.643 .726 .909 r
.66923 .52188 .67531 .52957 .68797 .52663 .68191 .51851 Mtetra
.634 .711 .903 r
.68191 .51851 .68797 .52663 .70073 .52428 .69467 .51543 Mtetra
.609 .682 .894 r
.69467 .51543 .70073 .52428 .71361 .52284 .70753 .51318 Mtetra
.566 .643 .886 r
.70753 .51318 .71361 .52284 .72663 .52256 .72055 .51238 Mtetra
.517 .607 .882 r
.72055 .51238 .72663 .52256 .73975 .52239 .73375 .51311 Mtetra
.524 .634 .901 r
.73375 .51311 .73975 .52239 .75276 .51932 .74701 .51338 Mtetra
.654 .792 .949 r
.74701 .51338 .75276 .51932 .76551 .51176 .76007 .50936 Mtetra
.796 .948 .921 r
.76007 .50936 .76551 .51176 .77814 .50215 .7728 .50021 Mtetra
.822 .964 .899 r
.7728 .50021 .77814 .50215 .79089 .49393 .78546 .48989 Mtetra
.771 .894 .93 r
.78546 .48989 .79089 .49393 .80386 .48802 .79833 .48194 Mtetra
.701 .807 .931 r
.79833 .48194 .80386 .48802 .817 .48349 .81144 .47645 Mtetra
.667 .765 .923 r
.81144 .47645 .817 .48349 .83024 .47941 .8247 .47208 Mtetra
.657 .753 .921 r
.8247 .47208 .83024 .47941 .84355 .47541 .83805 .46801 Mtetra
.656 .752 .92 r
.83805 .46801 .84355 .47541 .85692 .4714 .85146 .46396 Mtetra
.656 .751 .92 r
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Mtetra
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Mtetra
.655 .751 .921 r
.36341 .60246 .37035 .60878 .38169 .60537 .37478 .59904 Mtetra
.65 .75 .923 r
.37478 .59904 .38169 .60537 .39308 .60199 .3862 .59574 Mtetra
.623 .746 .935 r
.3862 .59574 .39308 .60199 .40451 .5989 .39764 .59312 Mtetra
.51 .723 .969 r
.39764 .59312 .40451 .5989 .41595 .5969 .40906 .59254 Mtetra
.142 .586 .928 r
.40906 .59254 .41595 .5969 .42738 .59727 .42045 .59512 Mtetra
0 .389 .683 r
.42045 .59512 .42738 .59727 .43883 .59993 .43191 .5986 Mtetra
.28 .763 .922 r
.43191 .5986 .43883 .59993 .4504 .60145 .44358 .59758 Mtetra
.769 .857 .916 r
.44358 .59758 .4504 .60145 .46214 .59801 .45544 .59032 Mtetra
.779 .748 .825 r
.45544 .59032 .46214 .59801 .474 .5904 .46736 .58089 Mtetra
.739 .703 .817 r
.46736 .58089 .474 .5904 .48588 .58234 .47927 .5731 Mtetra
.703 .698 .842 r
.47927 .5731 .48588 .58234 .49777 .57581 .49118 .56739 Mtetra
.682 .71 .869 r
.49118 .56739 .49777 .57581 .50969 .5707 .50313 .56277 Mtetra
.673 .72 .884 r
.50313 .56277 .50969 .5707 .52164 .56641 .51511 .55855 Mtetra
.667 .721 .889 r
.51511 .55855 .52164 .56641 .53364 .56241 .52715 .55456 Mtetra
.66 .72 .893 r
.52715 .55456 .53364 .56241 .5457 .55843 .53923 .55079 Mtetra
.656 .725 .9 r
.53923 .55079 .5457 .55843 .5578 .55446 .55137 .54714 Mtetra
.655 .735 .908 r
.55137 .54714 .5578 .55446 .56996 .55056 .56357 .54351 Mtetra
.655 .743 .915 r
.56357 .54351 .56996 .55056 .58217 .54675 .57581 .53985 Mtetra
.655 .749 .919 r
.57581 .53985 .58217 .54675 .59443 .543 .58811 .53616 Mtetra
.655 .752 .921 r
.58811 .53616 .59443 .543 .60675 .53932 .60047 .53245 Mtetra
.60047 .53245 .60675 .53932 .61913 .53569 .61288 .52871 Mtetra
.656 .75 .919 r
.61288 .52871 .61913 .53569 .63156 .53214 .62535 .52494 Mtetra
.656 .744 .914 r
.62535 .52494 .63156 .53214 .64406 .52867 .63787 .52114 Mtetra
.656 .735 .908 r
.63787 .52114 .64406 .52867 .65662 .52526 .65045 .51736 Mtetra
.652 .724 .902 r
.65045 .51736 .65662 .52526 .66923 .52188 .66309 .5137 Mtetra
.645 .715 .899 r
.66309 .5137 .66923 .52188 .68191 .51851 .6758 .51026 Mtetra
.637 .711 .9 r
.6758 .51026 .68191 .51851 .69467 .51543 .68858 .50706 Mtetra
.624 .703 .902 r
.68858 .50706 .69467 .51543 .70753 .51318 .70145 .50425 Mtetra
.59 .674 .899 r
.70145 .50425 .70753 .51318 .72055 .51238 .71445 .50255 Mtetra
.522 .62 .89 r
.71445 .50255 .72055 .51238 .73375 .51311 .72766 .50298 Mtetra
.463 .583 .888 r
.72766 .50298 .73375 .51311 .74701 .51338 .74106 .50505 Mtetra
.526 .663 .923 r
.74106 .50505 .74701 .51338 .76007 .50936 .75442 .50488 Mtetra
.732 .87 .945 r
.75442 .50488 .76007 .50936 .7728 .50021 .76741 .49827 Mtetra
.843 .963 .884 r
.76741 .49827 .7728 .50021 .78546 .48989 .78007 .48703 Mtetra
.827 .939 .901 r
.78007 .48703 .78546 .48989 .79833 .48194 .79282 .47672 Mtetra
.745 .85 .928 r
.79282 .47672 .79833 .48194 .81144 .47645 .80585 .46968 Mtetra
.682 .781 .926 r
.80585 .46968 .81144 .47645 .8247 .47208 .81911 .46477 Mtetra
.661 .757 .921 r
.81911 .46477 .8247 .47208 .83805 .46801 .83249 .46055 Mtetra
.656 .752 .92 r
.83249 .46055 .83805 .46801 .85146 .46396 .84595 .45646 Mtetra
.656 .751 .92 r
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Mtetra
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44825 Mtetra
.87306 .44825 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Mtetra
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Mtetra
.654 .751 .921 r
.35642 .5961 .36341 .60246 .37478 .59904 .36782 .59268 Mtetra
.643 .749 .926 r
.36782 .59268 .37478 .59904 .3862 .59574 .37925 .58955 Mtetra
.586 .738 .948 r
.37925 .58955 .3862 .59574 .39764 .59312 .39069 .5877 Mtetra
.351 .666 .974 r
.39069 .5877 .39764 .59312 .40906 .59254 .40207 .58899 Mtetra
0 .368 .734 r
.40207 .58899 .40906 .59254 .42045 .59512 .41343 .59357 Mtetra
.193 0 0 r
.41343 .59357 .42045 .59512 .43191 .5986 .42494 .59646 Mtetra
.649 .903 .982 r
.42494 .59646 .43191 .5986 .44358 .59758 .43674 .59184 Mtetra
.812 .799 .84 r
.43674 .59184 .44358 .59758 .45544 .59032 .44871 .58144 Mtetra
.776 .724 .804 r
.44871 .58144 .45544 .59032 .46736 .58089 .46068 .57138 Mtetra
.728 .701 .825 r
.46068 .57138 .46736 .58089 .47927 .5731 .47262 .56425 Mtetra
.692 .704 .857 r
.47262 .56425 .47927 .5731 .49118 .56739 .48455 .55915 Mtetra
.672 .713 .879 r
.48455 .55915 .49118 .56739 .50313 .56277 .49652 .55494 Mtetra
.662 .721 .893 r
.49652 .55494 .50313 .56277 .51511 .55855 .50853 .5511 Mtetra
.66 .732 .903 r
.50853 .5511 .51511 .55855 .52715 .55456 .5206 .54733 Mtetra
.661 .739 .908 r
.5206 .54733 .52715 .55456 .53923 .55079 .53272 .54348 Mtetra
.662 .738 .906 r
.53272 .54348 .53923 .55079 .55137 .54714 .54489 .53959 Mtetra
.661 .732 .902 r
.54489 .53959 .55137 .54714 .56357 .54351 .55711 .53571 Mtetra
.659 .725 .898 r
.55711 .53571 .56357 .54351 .57581 .53985 .56939 .53189 Mtetra
.657 .721 .896 r
.56939 .53189 .57581 .53985 .58811 .53616 .58173 .52811 Mtetra
.656 .719 .895 r
.58173 .52811 .58811 .53616 .60047 .53245 .59411 .52437 Mtetra
.654 .718 .896 r
.59411 .52437 .60047 .53245 .61288 .52871 .60656 .52066 Mtetra
.652 .719 .898 r
.60656 .52066 .61288 .52871 .62535 .52494 .61906 .517 Mtetra
.65 .722 .901 r
.61906 .517 .62535 .52494 .63787 .52114 .63163 .51338 Mtetra
.649 .728 .906 r
.63163 .51338 .63787 .52114 .65045 .51736 .64425 .50979 Mtetra
.65 .734 .911 r
.64425 .50979 .65045 .51736 .66309 .5137 .65693 .50614 Mtetra
.652 .736 .912 r
.65693 .50614 .66309 .5137 .6758 .51026 .66966 .50242 Mtetra
.649 .728 .907 r
.66966 .50242 .6758 .51026 .68858 .50706 .68246 .49878 Mtetra
.638 .713 .901 r
.68246 .49878 .68858 .50706 .70145 .50425 .69534 .49549 Mtetra
.61 .689 .899 r
.69534 .49549 .70145 .50425 .71445 .50255 .70834 .49312 Mtetra
.543 .642 .898 r
.70834 .49312 .71445 .50255 .72766 .50298 .72152 .49282 Mtetra
.437 .569 .889 r
.72152 .49282 .72766 .50298 .74106 .50505 .73499 .49549 Mtetra
.41 .57 .901 r
.73499 .49549 .74106 .50505 .75442 .50488 .74859 .49849 Mtetra
.613 .767 .953 r
.74859 .49849 .75442 .50488 .76741 .49827 .76189 .49552 Mtetra
.834 .941 .895 r
.76189 .49552 .76741 .49827 .78007 .48703 .77467 .4848 Mtetra
.867 .953 .864 r
.77467 .4848 .78007 .48703 .79282 .47672 .78732 .47234 Mtetra
.797 .889 .911 r
.78732 .47234 .79282 .47672 .80585 .46968 .80025 .46329 Mtetra
.707 .803 .925 r
.80025 .46329 .80585 .46968 .81911 .46477 .81349 .4575 Mtetra
.667 .763 .922 r
.81349 .4575 .81911 .46477 .83249 .46055 .8269 .45305 Mtetra
.657 .753 .921 r
.8269 .45305 .83249 .46055 .84595 .45646 .8404 .44889 Mtetra
.656 .752 .92 r
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Mtetra
.656 .751 .92 r
.85397 .44476 .85948 .45237 .87306 .44825 .8676 .44062 Mtetra
.8676 .44062 .87306 .44825 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Mtetra
.655 .751 .92 r
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58969 Mtetra
.652 .751 .922 r
.34937 .58969 .35642 .5961 .36782 .59268 .3608 .58629 Mtetra
.631 .746 .931 r
.3608 .58629 .36782 .59268 .37925 .58955 .37225 .58343 Mtetra
.527 .721 .962 r
.37225 .58343 .37925 .58955 .39069 .5877 .38367 .58264 Mtetra
.1 .536 .911 r
.38367 .58264 .39069 .5877 .40207 .58899 .395 .58605 Mtetra
.412 0 0 r
.395 .58605 .40207 .58899 .41343 .59357 .40632 .59219 Mtetra
0 .565 .783 r
.40632 .59219 .41343 .59357 .42494 .59646 .41792 .5934 Mtetra
.8 .884 .906 r
.41792 .5934 .42494 .59646 .43674 .59184 .42988 .58486 Mtetra
.826 .769 .799 r
.42988 .58486 .43674 .59184 .44871 .58144 .44195 .57206 Mtetra
.772 .715 .799 r
.44195 .57206 .44871 .58144 .46068 .57138 .45396 .56198 Mtetra
.714 .7 .835 r
.45396 .56198 .46068 .57138 .47262 .56425 .46591 .55564 Mtetra
.677 .706 .87 r
.46591 .55564 .47262 .56425 .48455 .55915 .47786 .55118 Mtetra
.664 .719 .889 r
.47786 .55118 .48455 .55915 .49652 .55494 .48986 .54723 Mtetra
.663 .726 .896 r
.48986 .54723 .49652 .55494 .50853 .5511 .50191 .54335 Mtetra
.66 .725 .897 r
.50191 .54335 .50853 .5511 .5206 .54733 .514 .53954 Mtetra
.655 .723 .899 r
.514 .53954 .5206 .54733 .53272 .54348 .52616 .53586 Mtetra
.652 .728 .904 r
.52616 .53586 .53272 .54348 .54489 .53959 .53836 .53226 Mtetra
.652 .737 .912 r
.53836 .53226 .54489 .53959 .55711 .53571 .55062 .52865 Mtetra
.653 .746 .918 r
.55062 .52865 .55711 .53571 .56939 .53189 .56294 .52498 Mtetra
.654 .752 .922 r
.56294 .52498 .56939 .53189 .58173 .52811 .57531 .52126 Mtetra
.655 .755 .923 r
.57531 .52126 .58173 .52811 .59411 .52437 .58773 .51749 Mtetra
.656 .755 .923 r
.58773 .51749 .59411 .52437 .60656 .52066 .60021 .51366 Mtetra
.657 .753 .92 r
.60021 .51366 .60656 .52066 .61906 .517 .61275 .50978 Mtetra
.659 .748 .916 r
.61275 .50978 .61906 .517 .63163 .51338 .62534 .50584 Mtetra
.659 .739 .909 r
.62534 .50584 .63163 .51338 .64425 .50979 .63799 .50189 Mtetra
.656 .729 .903 r
.63799 .50189 .64425 .50979 .65693 .50614 .6507 .49802 Mtetra
.652 .722 .9 r
.6507 .49802 .65693 .50614 .66966 .50242 .66347 .49428 Mtetra
.649 .721 .902 r
.66347 .49428 .66966 .50242 .68246 .49878 .6763 .49062 Mtetra
.647 .721 .903 r
.6763 .49062 .68246 .49878 .69534 .49549 .6892 .48701 Mtetra
.63 .707 .901 r
.6892 .48701 .69534 .49549 .70834 .49312 .70219 .48393 Mtetra
.57 .663 .9 r
.70219 .48393 .70834 .49312 .72152 .49282 .71536 .48276 Mtetra
.433 .571 .892 r
.71536 .48276 .72152 .49282 .73499 .49549 .72885 .48541 Mtetra
.306 .497 .881 r
.72885 .48541 .73499 .49549 .74859 .49849 .74263 .49083 Mtetra
.456 .653 .944 r
.74263 .49083 .74859 .49849 .76189 .49552 .75625 .49182 Mtetra
.797 .911 .918 r
.75625 .49182 .76189 .49552 .77467 .4848 .76922 .48273 Mtetra
.893 .951 .835 r
.76922 .48273 .77467 .4848 .78732 .47234 .78182 .46857 Mtetra
.845 .913 .881 r
.78182 .46857 .78732 .47234 .80025 .46329 .79463 .45726 Mtetra
.739 .826 .919 r
.79463 .45726 .80025 .46329 .81349 .4575 .80783 .45031 Mtetra
.676 .77 .922 r
.80783 .45031 .81349 .4575 .8269 .45305 .82126 .44551 Mtetra
.659 .754 .921 r
.82126 .44551 .8269 .45305 .8404 .44889 .8348 .44126 Mtetra
.656 .752 .92 r
.8348 .44126 .8404 .44889 .85397 .44476 .84841 .43709 Mtetra
.656 .751 .92 r
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Mtetra
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42025 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Mtetra
.655 .751 .92 r
.33086 .58673 .33799 .59317 .34937 .58969 .34227 .58324 Mtetra
.65 .75 .923 r
.34227 .58324 .34937 .58969 .3608 .58629 .35372 .57987 Mtetra
.616 .742 .936 r
.35372 .57987 .3608 .58629 .37225 .58343 .36518 .57736 Mtetra
.442 .689 .97 r
.36518 .57736 .37225 .58343 .38367 .58264 .37657 .57781 Mtetra
0 .332 .751 r
.37657 .57781 .38367 .58264 .395 .58605 .38783 .58345 Mtetra
.531 0 0 r
.38783 .58345 .395 .58605 .40632 .59219 .39914 .59078 Mtetra
.287 .767 .925 r
.39914 .59078 .40632 .59219 .41792 .5934 .41085 .58971 Mtetra
.857 .85 .836 r
.41085 .58971 .41792 .5934 .42988 .58486 .42298 .57721 Mtetra
.835 .755 .775 r
.42298 .57721 .42988 .58486 .44195 .57206 .43516 .56246 Mtetra
.766 .711 .8 r
.43516 .56246 .44195 .57206 .45396 .56198 .44719 .55267 Mtetra
.699 .698 .846 r
.44719 .55267 .45396 .56198 .46591 .55564 .45915 .54711 Mtetra
.664 .705 .878 r
.45915 .54711 .46591 .55564 .47786 .55118 .47113 .54311 Mtetra
.655 .715 .892 r
.47113 .54311 .47786 .55118 .48986 .54723 .48315 .53947 Mtetra
.651 .722 .901 r
.48315 .53947 .48986 .54723 .50191 .54335 .49523 .53592 Mtetra
.653 .733 .908 r
.49523 .53592 .50191 .54335 .514 .53954 .50735 .5323 Mtetra
.657 .741 .912 r
.50735 .5323 .514 .53954 .52616 .53586 .51954 .52853 Mtetra
.66 .74 .909 r
.51954 .52853 .52616 .53586 .53836 .53226 .53178 .52466 Mtetra
.66 .733 .904 r
.53178 .52466 .53836 .53226 .55062 .52865 .54407 .52077 Mtetra
.658 .726 .899 r
.54407 .52077 .55062 .52865 .56294 .52498 .55642 .51692 Mtetra
.657 .721 .896 r
.55642 .51692 .56294 .52498 .57531 .52126 .56882 .51309 Mtetra
.656 .719 .895 r
.56882 .51309 .57531 .52126 .58773 .51749 .58128 .50929 Mtetra
.654 .719 .896 r
.58128 .50929 .58773 .51749 .60021 .51366 .59379 .5055 Mtetra
.653 .72 .898 r
.59379 .5055 .60021 .51366 .61275 .50978 .60637 .50175 Mtetra
.652 .724 .902 r
.60637 .50175 .61275 .50978 .62534 .50584 .619 .49803 Mtetra
.652 .731 .907 r
.619 .49803 .62534 .50584 .63799 .50189 .63169 .49428 Mtetra
.654 .738 .912 r
.63169 .49428 .63799 .50189 .6507 .49802 .64444 .49044 Mtetra
.658 .742 .912 r
.64444 .49044 .6507 .49802 .66347 .49428 .65724 .48645 Mtetra
.66 .736 .906 r
.65724 .48645 .66347 .49428 .6763 .49062 .6701 .48239 Mtetra
.656 .725 .899 r
.6701 .48239 .6763 .49062 .6892 .48701 .68302 .47842 Mtetra
.645 .712 .896 r
.68302 .47842 .6892 .48701 .70219 .48393 .69602 .47481 Mtetra
.597 .678 .898 r
.69602 .47481 .70219 .48393 .71536 .48276 .70917 .47279 Mtetra
.443 .58 .896 r
.70917 .47279 .71536 .48276 .72885 .48541 .72266 .47509 Mtetra
.21 .434 .859 r
.72266 .47509 .72885 .48541 .74263 .49083 .73658 .48245 Mtetra
.257 .519 .909 r
.73658 .48245 .74263 .49083 .75625 .49182 .7505 .48746 Mtetra
.732 .88 .949 r
.7505 .48746 .75625 .49182 .76922 .48273 .76371 .48065 Mtetra
.909 .945 .815 r
.76371 .48065 .76922 .48273 .78182 .46857 .77629 .46516 Mtetra
.883 .919 .844 r
.77629 .46516 .78182 .46857 .79463 .45726 .78899 .45145 Mtetra
.772 .843 .905 r
.78899 .45145 .79463 .45726 .80783 .45031 .80212 .44315 Mtetra
.687 .778 .92 r
.80212 .44315 .80783 .45031 .82126 .44551 .81557 .43792 Mtetra
.661 .756 .92 r
.81557 .43792 .82126 .44551 .8348 .44126 .82915 .43357 Mtetra
.656 .752 .92 r
.82915 .43357 .8348 .44126 .84841 .43709 .8428 .42936 Mtetra
.656 .751 .92 r
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Mtetra
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42025 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Mtetra
.655 .751 .921 r
.32366 .58024 .33086 .58673 .34227 .58324 .3351 .57673 Mtetra
.647 .749 .924 r
.3351 .57673 .34227 .58324 .35372 .57987 .34658 .57341 Mtetra
.598 .737 .942 r
.34658 .57341 .35372 .57987 .36518 .57736 .35806 .57128 Mtetra
.333 .637 .964 r
.35806 .57128 .36518 .57736 .37657 .57781 .36941 .57304 Mtetra
.434 0 0 r
.36941 .57304 .37657 .57781 .38783 .58345 .38059 .58096 Mtetra
.601 .03 0 r
.38059 .58096 .38783 .58345 .39914 .59078 .39187 .58937 Mtetra
.538 .891 .979 r
.39187 .58937 .39914 .59078 .41085 .58971 .40372 .58581 Mtetra
.886 .83 .786 r
.40372 .58581 .41085 .58971 .42298 .57721 .41603 .56934 Mtetra
.846 .752 .759 r
.41603 .56934 .42298 .57721 .43516 .56246 .42831 .55276 Mtetra
.761 .709 .803 r
.42831 .55276 .43516 .56246 .44719 .55267 .44038 .54329 Mtetra
.68 .692 .854 r
.44038 .54329 .44719 .55267 .45915 .54711 .45235 .53856 Mtetra
.647 .7 .885 r
.45235 .53856 .45915 .54711 .47113 .54311 .46434 .53514 Mtetra
.648 .716 .898 r
.46434 .53514 .47113 .54311 .48315 .53947 .47639 .5317 Mtetra
.653 .724 .901 r
.47639 .5317 .48315 .53947 .49523 .53592 .4885 .52805 Mtetra
.654 .723 .9 r
.4885 .52805 .49523 .53592 .50735 .5323 .50066 .52438 Mtetra
.651 .721 .9 r
.50066 .52438 .50735 .5323 .51954 .52853 .51287 .52079 Mtetra
.648 .726 .906 r
.51287 .52079 .51954 .52853 .53178 .52466 .52514 .51726 Mtetra
.649 .737 .914 r
.52514 .51726 .53178 .52466 .54407 .52077 .53747 .51368 Mtetra
.65 .748 .921 r
.53747 .51368 .54407 .52077 .55642 .51692 .54986 .51002 Mtetra
.652 .755 .925 r
.54986 .51002 .55642 .51692 .56882 .51309 .5623 .50627 Mtetra
.654 .759 .927 r
.5623 .50627 .56882 .51309 .58128 .50929 .57479 .50244 Mtetra
.657 .76 .926 r
.57479 .50244 .58128 .50929 .59379 .5055 .58735 .49852 Mtetra
.659 .758 .923 r
.58735 .49852 .59379 .5055 .60637 .50175 .59995 .4945 Mtetra
.662 .751 .917 r
.59995 .4945 .60637 .50175 .619 .49803 .61262 .4904 Mtetra
.662 .742 .909 r
.61262 .4904 .619 .49803 .63169 .49428 .62533 .48627 Mtetra
.66 .731 .902 r
.62533 .48627 .63169 .49428 .64444 .49044 .63811 .48218 Mtetra
.657 .724 .898 r
.63811 .48218 .64444 .49044 .65724 .48645 .65095 .47819 Mtetra
.658 .725 .899 r
.65095 .47819 .65724 .48645 .6701 .48239 .66384 .47415 Mtetra
.663 .729 .898 r
.66384 .47415 .6701 .48239 .68302 .47842 .67679 .46991 Mtetra
.663 .723 .893 r
.67679 .46991 .68302 .47842 .69602 .47481 .68979 .46566 Mtetra
.624 .691 .892 r
.68979 .46566 .69602 .47481 .70917 .47279 .70293 .46274 Mtetra
.458 .589 .896 r
.70293 .46274 .70917 .47279 .72266 .47509 .71642 .46466 Mtetra
.11 .367 .83 r
.71642 .46466 .72266 .47509 .73658 .48245 .73047 .47384 Mtetra
.017 .353 .829 r
.73047 .47384 .73658 .48245 .7505 .48746 .74468 .48288 Mtetra
.638 .847 .98 r
.74468 .48288 .7505 .48746 .76371 .48065 .75813 .47855 Mtetra
.921 .939 .798 r
.75813 .47855 .76371 .48065 .77629 .46516 .77071 .46185 Mtetra
.911 .914 .807 r
.77071 .46185 .77629 .46516 .78899 .45145 .78329 .4457 Mtetra
.803 .852 .887 r
.78329 .4457 .78899 .45145 .80212 .44315 .79637 .43596 Mtetra
.7 .783 .916 r
.79637 .43596 .80212 .44315 .81557 .43792 .80983 .43027 Mtetra
.663 .757 .92 r
.80983 .43027 .81557 .43792 .82915 .43357 .82345 .42581 Mtetra
.656 .752 .92 r
.82345 .42581 .82915 .43357 .8428 .42936 .83715 .42155 Mtetra
.656 .751 .92 r
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Mtetra
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Mtetra
.655 .751 .921 r
.31642 .5737 .32366 .58024 .3351 .57673 .32789 .57017 Mtetra
.645 .749 .925 r
.32789 .57017 .3351 .57673 .34658 .57341 .33939 .56689 Mtetra
.58 .731 .946 r
.33939 .56689 .34658 .57341 .35806 .57128 .35087 .56512 Mtetra
.212 .57 .939 r
.35087 .56512 .35806 .57128 .36941 .57304 .36218 .56815 Mtetra
.594 .047 0 r
.36218 .56815 .36941 .57304 .38059 .58096 .37327 .57835 Mtetra
.656 .1 0 r
.37327 .57835 .38059 .58096 .39187 .58937 .38453 .588 Mtetra
.687 .934 .966 r
.38453 .588 .39187 .58937 .40372 .58581 .39651 .58216 Mtetra
.908 .82 .749 r
.39651 .58216 .40372 .58581 .41603 .56934 .40903 .56166 Mtetra
.86 .755 .745 r
.40903 .56166 .41603 .56934 .42831 .55276 .42143 .54304 Mtetra
.758 .709 .806 r
.42143 .54304 .42831 .55276 .44038 .54329 .43352 .53379 Mtetra
.66 .683 .861 r
.43352 .53379 .44038 .54329 .45235 .53856 .4455 .52982 Mtetra
.632 .692 .888 r
.4455 .52982 .45235 .53856 .46434 .53514 .45751 .52689 Mtetra
.636 .706 .898 r
.45751 .52689 .46434 .53514 .47639 .5317 .46958 .52379 Mtetra
.64 .718 .904 r
.46958 .52379 .47639 .5317 .4885 .52805 .48171 .52054 Mtetra
.645 .732 .912 r
.48171 .52054 .4885 .52805 .50066 .52438 .4939 .51709 Mtetra
.653 .741 .915 r
.4939 .51709 .50066 .52438 .51287 .52079 .50615 .51338 Mtetra
.658 .741 .911 r
.50615 .51338 .51287 .52079 .52514 .51726 .51846 .50949 Mtetra
.659 .732 .903 r
.51846 .50949 .52514 .51726 .53747 .51368 .53082 .50555 Mtetra
.658 .722 .896 r
.53082 .50555 .53747 .51368 .54986 .51002 .54323 .50163 Mtetra
.656 .716 .892 r
.54323 .50163 .54986 .51002 .5623 .50627 .5557 .49774 Mtetra
.655 .713 .89 r
.5557 .49774 .5623 .50627 .57479 .50244 .56823 .49387 Mtetra
.654 .712 .891 r
.56823 .49387 .57479 .50244 .58735 .49852 .58082 .49003 Mtetra
.653 .715 .893 r
.58082 .49003 .58735 .49852 .59995 .4945 .59347 .48622 Mtetra
.652 .72 .899 r
.59347 .48622 .59995 .4945 .61262 .4904 .60617 .48242 Mtetra
.653 .73 .906 r
.60617 .48242 .61262 .4904 .62533 .48627 .61893 .47857 Mtetra
.657 .741 .911 r
.61893 .47857 .62533 .48627 .63811 .48218 .63175 .47455 Mtetra
.665 .746 .911 r
.63175 .47455 .63811 .48218 .65095 .47819 .64462 .47026 Mtetra
.67 .741 .903 r
.64462 .47026 .65095 .47819 .66384 .47415 .65754 .46577 Mtetra
.673 .73 .893 r
.65754 .46577 .66384 .47415 .67679 .46991 .6705 .46112 Mtetra
.676 .722 .884 r
.6705 .46112 .67679 .46991 .68979 .46566 .68352 .45632 Mtetra
.647 .698 .883 r
.68352 .45632 .68979 .46566 .70293 .46274 .69664 .45255 Mtetra
.469 .593 .894 r
.69664 .45255 .70293 .46274 .71642 .46466 .71014 .45419 Mtetra
0 .286 .785 r
.71014 .45419 .71642 .46466 .73047 .47384 .72433 .46543 Mtetra
0 .159 .688 r
.72433 .46543 .73047 .47384 .74468 .48288 .73882 .47853 Mtetra
.512 .807 .999 r
.73882 .47853 .74468 .48288 .75813 .47855 .75248 .47647 Mtetra
.932 .933 .779 r
.75248 .47647 .75813 .47855 .77071 .46185 .76506 .45841 Mtetra
.93 .9 .775 r
.76506 .45841 .77071 .46185 .78329 .4457 .77754 .43982 Mtetra
.826 .852 .866 r
.77754 .43982 .78329 .4457 .79637 .43596 .79057 .42869 Mtetra
.711 .786 .911 r
.79057 .42869 .79637 .43596 .80983 .43027 .80404 .42256 Mtetra
.665 .758 .919 r
.80404 .42256 .80983 .43027 .82345 .42581 .8177 .41799 Mtetra
.657 .752 .92 r
.8177 .41799 .82345 .42581 .83715 .42155 .83145 .41368 Mtetra
.656 .751 .92 r
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Mtetra
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58133 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Mtetra
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Mtetra
.654 .751 .921 r
.30911 .56711 .31642 .5737 .32789 .57017 .32061 .56355 Mtetra
.643 .748 .926 r
.32061 .56355 .32789 .57017 .33939 .56689 .33214 .56031 Mtetra
.564 .725 .949 r
.33214 .56031 .33939 .56689 .35087 .56512 .34363 .55884 Mtetra
.098 .497 .902 r
.34363 .55884 .35087 .56512 .36218 .56815 .3549 .563 Mtetra
.691 .164 0 r
.3549 .563 .36218 .56815 .37327 .57835 .36589 .57536 Mtetra
.706 .167 0 r
.36589 .57536 .37327 .57835 .38453 .588 .37709 .58656 Mtetra
.757 .94 .943 r
.37709 .58656 .38453 .588 .39651 .58216 .3892 .57911 Mtetra
.925 .817 .721 r
.3892 .57911 .39651 .58216 .40903 .56166 .40194 .55474 Mtetra
.88 .765 .731 r
.40194 .55474 .40903 .56166 .42143 .54304 .41449 .53352 Mtetra
.764 .715 .807 r
.41449 .53352 .42143 .54304 .43352 .53379 .42662 .52402 Mtetra
.638 .671 .865 r
.42662 .52402 .43352 .53379 .4455 .52982 .4386 .52082 Mtetra
.608 .678 .89 r
.4386 .52082 .4455 .52982 .45751 .52689 .45062 .51858 Mtetra
.626 .703 .901 r
.45062 .51858 .45751 .52689 .46958 .52379 .46272 .51574 Mtetra
.643 .717 .901 r
.46272 .51574 .46958 .52379 .48171 .52054 .47488 .51236 Mtetra
.648 .715 .898 r
.47488 .51236 .48171 .52054 .4939 .51709 .4871 .50882 Mtetra
.645 .713 .897 r
.4871 .50882 .4939 .51709 .50615 .51338 .49938 .50536 Mtetra
.642 .72 .904 r
.49938 .50536 .50615 .51338 .51846 .50949 .51171 .50196 Mtetra
.643 .735 .916 r
.51171 .50196 .51846 .50949 .53082 .50555 .52411 .49849 Mtetra
.646 .751 .926 r
.52411 .49849 .53082 .50555 .54323 .50163 .53656 .49489 Mtetra
.65 .763 .932 r
.53656 .49489 .54323 .50163 .5557 .49774 .54908 .49113 Mtetra
.653 .769 .934 r
.54908 .49113 .5557 .49774 .56823 .49387 .56165 .48723 Mtetra
.658 .77 .932 r
.56165 .48723 .56823 .49387 .58082 .49003 .57427 .48319 Mtetra
.663 .767 .927 r
.57427 .48319 .58082 .49003 .59347 .48622 .58695 .47899 Mtetra
.667 .757 .918 r
.58695 .47899 .59347 .48622 .60617 .48242 .59968 .47466 Mtetra
.668 .743 .907 r
.59968 .47466 .60617 .48242 .61893 .47857 .61247 .47027 Mtetra
.666 .729 .896 r
.61247 .47027 .61893 .47857 .63175 .47455 .62531 .46592 Mtetra
.662 .72 .892 r
.62531 .46592 .63175 .47455 .64462 .47026 .63822 .46166 Mtetra
.666 .723 .891 r
.63822 .46166 .64462 .47026 .65754 .46577 .65118 .45724 Mtetra
.681 .731 .888 r
.65118 .45724 .65754 .46577 .6705 .46112 .66417 .45227 Mtetra
.695 .729 .877 r
.66417 .45227 .6705 .46112 .68352 .45632 .67719 .44669 Mtetra
.667 .701 .872 r
.67719 .44669 .68352 .45632 .69664 .45255 .6903 .44209 Mtetra
.462 .584 .89 r
.6903 .44209 .69664 .45255 .71014 .45419 .70383 .44394 Mtetra
0 .172 .708 r
.70383 .44394 .71014 .45419 .72433 .46543 .71818 .45778 Mtetra
0 0 .498 r
.71818 .45778 .72433 .46543 .73882 .47853 .73294 .4748 Mtetra
.371 .758 .988 r
.73294 .4748 .73882 .47853 .75248 .47647 .74677 .47432 Mtetra
.944 .922 .758 r
.74677 .47432 .75248 .47647 .76506 .45841 .75931 .45455 Mtetra
.941 .882 .747 r
.75931 .45455 .76506 .45841 .77754 .43982 .77171 .43364 Mtetra
.842 .846 .847 r
.77171 .43364 .77754 .43982 .79057 .42869 .78471 .42128 Mtetra
.719 .787 .905 r
.78471 .42128 .79057 .42869 .80404 .42256 .7982 .41476 Mtetra
.667 .758 .918 r
.7982 .41476 .80404 .42256 .8177 .41799 .8119 .41009 Mtetra
.657 .752 .92 r
.8119 .41009 .8177 .41799 .83145 .41368 .82569 .40574 Mtetra
.656 .751 .92 r
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Mtetra
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58133 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Mtetra
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Mtetra
.654 .751 .921 r
.30174 .56046 .30911 .56711 .32061 .56355 .31327 .55689 Mtetra
.641 .748 .926 r
.31327 .55689 .32061 .56355 .33214 .56031 .32483 .55366 Mtetra
.55 .72 .952 r
.32483 .55366 .33214 .56031 .34363 .55884 .33633 .55244 Mtetra
.003 .432 .862 r
.33633 .55244 .34363 .55884 .3549 .563 .34757 .55749 Mtetra
.747 .239 0 r
.34757 .55749 .3549 .563 .36589 .57536 .35847 .57172 Mtetra
.747 .227 0 r
.35847 .57172 .36589 .57536 .37709 .58656 .3696 .58472 Mtetra
.778 .928 .933 r
.3696 .58472 .37709 .58656 .3892 .57911 .38178 .57673 Mtetra
.936 .817 .702 r
.38178 .57673 .3892 .57911 .40194 .55474 .39474 .54917 Mtetra
.904 .781 .716 r
.39474 .54917 .40194 .55474 .41449 .53352 .40747 .52479 Mtetra
.785 .736 .807 r
.40747 .52479 .41449 .53352 .42662 .52402 .41968 .51416 Mtetra
.628 .666 .868 r
.41968 .51416 .42662 .52402 .4386 .52082 .43167 .5113 Mtetra
.588 .658 .886 r
.43167 .5113 .4386 .52082 .45062 .51858 .4437 .50965 Mtetra
.608 .682 .894 r
.4437 .50965 .45062 .51858 .46272 .51574 .45581 .50736 Mtetra
.625 .703 .902 r
.45581 .50736 .46272 .51574 .47488 .51236 .46799 .50451 Mtetra
.643 .725 .908 r
.46799 .50451 .47488 .51236 .4871 .50882 .48024 .50107 Mtetra
.663 .735 .903 r
.48024 .50107 .4871 .50882 .49938 .50536 .49256 .49698 Mtetra
.675 .723 .886 r
.49256 .49698 .49938 .50536 .51171 .50196 .50493 .49241 Mtetra
.675 .696 .862 r
.50493 .49241 .51171 .50196 .52411 .49849 .51736 .48769 Mtetra
.666 .668 .842 r
.51736 .48769 .52411 .49849 .53656 .49489 .52983 .4831 Mtetra
.656 .647 .829 r
.52983 .4831 .53656 .49489 .54908 .49113 .54236 .4788 Mtetra
.646 .634 .824 r
.54236 .4788 .54908 .49113 .56165 .48723 .55495 .47487 Mtetra
.638 .63 .826 r
.55495 .47487 .56165 .48723 .57427 .48319 .5676 .4713 Mtetra
.632 .636 .836 r
.5676 .4713 .57427 .48319 .58695 .47899 .58031 .46803 Mtetra
.629 .653 .854 r
.58031 .46803 .58695 .47899 .59968 .47466 .5931 .46489 Mtetra
.634 .681 .877 r
.5931 .46489 .59968 .47466 .61247 .47027 .60594 .46159 Mtetra
.648 .714 .896 r
.60594 .46159 .61247 .47027 .62531 .46592 .61884 .45782 Mtetra
.667 .737 .903 r
.61884 .45782 .62531 .46592 .63822 .46166 .63178 .45339 Mtetra
.682 .739 .894 r
.63178 .45339 .63822 .46166 .65118 .45724 .64475 .44837 Mtetra
.694 .729 .877 r
.64475 .44837 .65118 .45724 .66417 .45227 .65776 .44278 Mtetra
.706 .719 .86 r
.65776 .44278 .66417 .45227 .67719 .44669 .67079 .43654 Mtetra
.674 .694 .86 r
.67079 .43654 .67719 .44669 .6903 .44209 .68392 .43154 Mtetra
.415 .558 .889 r
.68392 .43154 .6903 .44209 .70383 .44394 .69753 .43449 Mtetra
0 .014 .569 r
.69753 .43449 .70383 .44394 .71818 .45778 .71206 .45151 Mtetra
.672 .186 0 r
.71206 .45151 .71818 .45778 .73294 .4748 .72704 .47173 Mtetra
.283 .73 .961 r
.72704 .47173 .73294 .4748 .74677 .47432 .74096 .47172 Mtetra
.952 .903 .738 r
.74096 .47172 .74677 .47432 .75931 .45455 .75346 .45001 Mtetra
.945 .862 .727 r
.75346 .45001 .75931 .45455 .77171 .43364 .7658 .42709 Mtetra
.852 .837 .831 r
.7658 .42709 .77171 .43364 .78471 .42128 .77878 .41372 Mtetra
.726 .787 .9 r
.77878 .41372 .78471 .42128 .7982 .41476 .7923 .40688 Mtetra
.669 .758 .917 r
.7923 .40688 .7982 .41476 .8119 .41009 .80605 .40212 Mtetra
.657 .752 .92 r
.80605 .40212 .8119 .41009 .82569 .40574 .81989 .39773 Mtetra
.656 .751 .92 r
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Mtetra
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38455 Mtetra
.86182 .38455 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55377 Mtetra
.654 .751 .921 r
.29432 .55377 .30174 .56046 .31327 .55689 .30588 .55016 Mtetra
.639 .747 .927 r
.30588 .55016 .31327 .55689 .32483 .55366 .31746 .54695 Mtetra
.538 .715 .954 r
.31746 .54695 .32483 .55366 .33633 .55244 .32898 .54593 Mtetra
0 .378 .824 r
.32898 .54593 .33633 .55244 .34757 .55749 .34019 .55168 Mtetra
.778 .284 0 r
.34019 .55168 .34757 .55749 .35847 .57172 .35101 .56729 Mtetra
.774 .269 0 r
.35101 .56729 .35847 .57172 .3696 .58472 .36206 .5819 Mtetra
.765 .899 .936 r
.36206 .5819 .3696 .58472 .38178 .57673 .37427 .57449 Mtetra
.94 .814 .694 r
.37427 .57449 .38178 .57673 .39474 .54917 .3874 .54535 Mtetra
.926 .799 .701 r
.3874 .54535 .39474 .54917 .40747 .52479 .40034 .51783 Mtetra
.83 .777 .802 r
.40034 .51783 .40747 .52479 .41968 .51416 .41268 .50472 Mtetra
.647 .684 .871 r
.41268 .50472 .41968 .51416 .43167 .5113 .42471 .50118 Mtetra
.585 .645 .876 r
.42471 .50118 .43167 .5113 .4437 .50965 .43675 .49964 Mtetra
.628 .666 .868 r
.43675 .49964 .4437 .50965 .45581 .50736 .4489 .49672 Mtetra
.67 .67 .841 r
.4489 .49672 .45581 .50736 .46799 .50451 .46113 .49204 Mtetra
.679 .643 .807 r
.46113 .49204 .46799 .50451 .48024 .50107 .47343 .48648 Mtetra
.667 .61 .782 r
.47343 .48648 .48024 .50107 .49256 .49698 .48577 .48097 Mtetra
.653 .588 .769 r
.48577 .48097 .49256 .49698 .50493 .49241 .49815 .47597 Mtetra
.643 .578 .767 r
.49815 .47597 .50493 .49241 .51736 .48769 .51058 .47149 Mtetra
.638 .579 .772 r
.51058 .47149 .51736 .48769 .52983 .4831 .52306 .46733 Mtetra
.636 .583 .778 r
.52306 .46733 .52983 .4831 .54236 .4788 .5356 .46332 Mtetra
.636 .587 .782 r
.5356 .46332 .54236 .4788 .55495 .47487 .54819 .45934 Mtetra
.635 .586 .782 r
.54819 .45934 .55495 .47487 .5676 .4713 .56084 .4554 Mtetra
.632 .581 .779 r
.56084 .4554 .5676 .4713 .58031 .46803 .57356 .4516 Mtetra
.624 .571 .775 r
.57356 .4516 .58031 .46803 .5931 .46489 .58634 .44813 Mtetra
.613 .563 .774 r
.58634 .44813 .5931 .46489 .60594 .46159 .59919 .4452 Mtetra
.604 .562 .78 r
.59919 .4452 .60594 .46159 .61884 .45782 .61213 .44278 Mtetra
.604 .579 .798 r
.61213 .44278 .61884 .45782 .63178 .45339 .62515 .44044 Mtetra
.626 .62 .825 r
.62515 .44044 .63178 .45339 .64475 .44837 .63821 .4372 Mtetra
.671 .672 .843 r
.63821 .4372 .64475 .44837 .65776 .44278 .65127 .43219 Mtetra
.703 .697 .842 r
.65127 .43219 .65776 .44278 .67079 .43654 .66432 .42577 Mtetra
.657 .675 .856 r
.66432 .42577 .67079 .43654 .68392 .43154 .67751 .42141 Mtetra
.28 .491 .884 r
.67751 .42141 .68392 .43154 .69753 .43449 .69127 .42683 Mtetra
.622 .157 0 r
.69127 .42683 .69753 .43449 .71206 .45151 .70599 .44701 Mtetra
.758 .266 0 r
.70599 .44701 .71206 .45151 .72704 .47173 .72107 .46879 Mtetra
.326 .761 .969 r
.72107 .46879 .72704 .47173 .74096 .47172 .73501 .4681 Mtetra
.953 .877 .723 r
.73501 .4681 .74096 .47172 .75346 .45001 .74749 .44464 Mtetra
.943 .843 .714 r
.74749 .44464 .75346 .45001 .7658 .42709 .75981 .42021 Mtetra
.858 .83 .819 r
.75981 .42021 .7658 .42709 .77878 .41372 .77281 .40605 Mtetra
.731 .787 .897 r
.77281 .40605 .77878 .41372 .7923 .40688 .78635 .39893 Mtetra
.67 .759 .917 r
.78635 .39893 .7923 .40688 .80605 .40212 .80014 .39409 Mtetra
.657 .752 .92 r
.80014 .39409 .80605 .40212 .81989 .39773 .81403 .38965 Mtetra
.656 .751 .92 r
.81403 .38965 .81989 .39773 .8338 .39336 .82799 .38523 Mtetra
.82799 .38523 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38455 .85611 .37635 Mtetra
.85611 .37635 .86182 .38455 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55795 Mtetra
.25235 .55795 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Mtetra
.27529 .55067 .2828 .5574 .29432 .55377 .28683 .54701 Mtetra
.654 .751 .921 r
.28683 .54701 .29432 .55377 .30588 .55016 .29842 .54339 Mtetra
.637 .747 .928 r
.29842 .54339 .30588 .55016 .31746 .54695 .31003 .5402 Mtetra
.526 .711 .956 r
.31003 .5402 .31746 .54695 .32898 .54593 .32156 .53936 Mtetra
0 .331 .789 r
.32156 .53936 .32898 .54593 .34019 .55168 .33275 .54567 Mtetra
.796 .309 0 r
.33275 .54567 .34019 .55168 .35101 .56729 .34351 .56218 Mtetra
.784 .286 0 r
.34351 .56218 .35101 .56729 .36206 .5819 .35451 .57771 Mtetra
.737 .855 .935 r
.35451 .57771 .36206 .5819 .37427 .57449 .36673 .57126 Mtetra
.931 .804 .697 r
.36673 .57126 .37427 .57449 .3874 .54535 .37994 .54257 Mtetra
.937 .809 .692 r
.37994 .54257 .3874 .54535 .40034 .51783 .39305 .5133 Mtetra
.885 .822 .781 r
.39305 .5133 .40034 .51783 .41268 .50472 .40559 .49634 Mtetra
.742 .738 .848 r
.40559 .49634 .41268 .50472 .42471 .50118 .41778 .48884 Mtetra
.659 .636 .816 r
.41778 .48884 .42471 .50118 .43675 .49964 .42991 .48433 Mtetra
.645 .59 .778 r
.42991 .48433 .43675 .49964 .4489 .49672 .44209 .47995 Mtetra
.635 .57 .764 r
.44209 .47995 .4489 .49672 .46113 .49204 .45432 .47584 Mtetra
.625 .571 .774 r
.45432 .47584 .46113 .49204 .47343 .48648 .46659 .47243 Mtetra
.619 .594 .804 r
.46659 .47243 .47343 .48648 .48577 .48097 .4789 .46953 Mtetra
.62 .638 .846 r
.4789 .46953 .48577 .48097 .49815 .47597 .49129 .46674 Mtetra
.626 .688 .888 r
.49129 .46674 .49815 .47597 .51058 .47149 .50373 .46377 Mtetra
.633 .732 .919 r
.50373 .46377 .51058 .47149 .52306 .46733 .51625 .46049 Mtetra
.643 .761 .935 r
.51625 .46049 .52306 .46733 .5356 .46332 .52882 .45684 Mtetra
.654 .777 .939 r
.52882 .45684 .5356 .46332 .54819 .45934 .54146 .45283 Mtetra
.666 .781 .935 r
.54146 .45283 .54819 .45934 .56084 .4554 .55415 .44846 Mtetra
.677 .772 .922 r
.55415 .44846 .56084 .4554 .57356 .4516 .56689 .44372 Mtetra
.685 .749 .9 r
.56689 .44372 .57356 .4516 .58634 .44813 .57968 .43867 Mtetra
.684 .71 .868 r
.57968 .43867 .58634 .44813 .59919 .4452 .59252 .43341 Mtetra
.671 .659 .83 r
.59252 .43341 .59919 .4452 .61213 .44278 .60541 .42829 Mtetra
.649 .609 .796 r
.60541 .42829 .61213 .44278 .62515 .44044 .61837 .42368 Mtetra
.629 .573 .773 r
.61837 .42368 .62515 .44044 .63821 .4372 .63141 .41979 Mtetra
.622 .563 .767 r
.63141 .41979 .63821 .4372 .65127 .43219 .64453 .41619 Mtetra
.623 .579 .784 r
.64453 .41619 .65127 .43219 .66432 .42577 .65772 .41274 Mtetra
.553 .585 .84 r
.65772 .41274 .66432 .42577 .67751 .42141 .67112 .41235 Mtetra
0 .329 .814 r
.67112 .41235 .67751 .42141 .69127 .42683 .68509 .42164 Mtetra
.752 .264 0 r
.68509 .42164 .69127 .42683 .70599 .44701 .69991 .44355 Mtetra
.771 .273 0 r
.69991 .44355 .70599 .44701 .72107 .46879 .71498 .46479 Mtetra
.465 .803 .999 r
.71498 .46479 .72107 .46879 .73501 .4681 .72891 .46303 Mtetra
.945 .848 .716 r
.72891 .46303 .73501 .4681 .74749 .44464 .74142 .43854 Mtetra
.94 .829 .706 r
.74142 .43854 .74749 .44464 .75981 .42021 .75375 .41311 Mtetra
.863 .826 .811 r
.75375 .41311 .75981 .42021 .77281 .40605 .76677 .39829 Mtetra
.737 .788 .894 r
.76677 .39829 .77281 .40605 .78635 .39893 .78036 .39091 Mtetra
.671 .759 .916 r
.78036 .39091 .78635 .39893 .80014 .39409 .79419 .38598 Mtetra
.657 .752 .92 r
.79419 .38598 .80014 .39409 .81403 .38965 .80812 .38149 Mtetra
.656 .751 .92 r
.80812 .38149 .81403 .38965 .82799 .38523 .82213 .37704 Mtetra
.82213 .37704 .82799 .38523 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55795 .24472 .55124 Mtetra
.24472 .55124 .25235 .55795 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Mtetra
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Mtetra
.654 .751 .921 r
.27929 .5402 .28683 .54701 .29842 .54339 .29091 .53656 Mtetra
.635 .746 .928 r
.29091 .53656 .29842 .54339 .31003 .5402 .30254 .53339 Mtetra
.513 .706 .958 r
.30254 .53339 .31003 .5402 .32156 .53936 .31408 .53276 Mtetra
0 .286 .751 r
.31408 .53276 .32156 .53936 .33275 .54567 .32524 .53959 Mtetra
.807 .325 0 r
.32524 .53959 .33275 .54567 .34351 .56218 .33596 .55666 Mtetra
.777 .279 0 r
.33596 .55666 .34351 .56218 .35451 .57771 .34695 .57222 Mtetra
.731 .815 .916 r
.34695 .57222 .35451 .57771 .36673 .57126 .35921 .56591 Mtetra
.912 .779 .701 r
.35921 .56591 .36673 .57126 .37994 .54257 .37246 .53827 Mtetra
.926 .79 .691 r
.37246 .53827 .37994 .54257 .39305 .5133 .38568 .50879 Mtetra
.904 .811 .746 r
.38568 .50879 .39305 .5133 .40559 .49634 .39844 .48794 Mtetra
.813 .75 .794 r
.39844 .48794 .40559 .49634 .41778 .48884 .41085 .4752 Mtetra
.69 .632 .786 r
.41085 .4752 .41778 .48884 .42991 .48433 .42306 .46863 Mtetra
.606 .566 .784 r
.42306 .46863 .42991 .48433 .44209 .47995 .43519 .46622 Mtetra
.565 .572 .819 r
.43519 .46622 .44209 .47995 .45432 .47584 .44735 .46553 Mtetra
.553 .631 .882 r
.44735 .46553 .45432 .47584 .46659 .47243 .45958 .46481 Mtetra
.56 .706 .939 r
.45958 .46481 .46659 .47243 .4789 .46953 .47191 .46339 Mtetra
.576 .76 .966 r
.47191 .46339 .4789 .46953 .49129 .46674 .48432 .4612 Mtetra
.596 .789 .973 r
.48432 .4612 .49129 .46674 .50373 .46377 .49681 .45839 Mtetra
.615 .802 .971 r
.49681 .45839 .50373 .46377 .51625 .46049 .50937 .45511 Mtetra
.632 .808 .967 r
.50937 .45511 .51625 .46049 .52882 .45684 .52199 .45143 Mtetra
.646 .812 .963 r
.52199 .45143 .52882 .45684 .54146 .45283 .53467 .44738 Mtetra
.66 .816 .958 r
.53467 .44738 .54146 .45283 .55415 .44846 .5474 .44298 Mtetra
.675 .82 .953 r
.5474 .44298 .55415 .44846 .56689 .44372 .56019 .43817 Mtetra
.691 .823 .946 r
.56019 .43817 .56689 .44372 .57968 .43867 .57303 .43288 Mtetra
.711 .822 .934 r
.57303 .43288 .57968 .43867 .59252 .43341 .58591 .42697 Mtetra
.731 .807 .911 r
.58591 .42697 .59252 .43341 .60541 .42829 .59881 .42028 Mtetra
.739 .767 .875 r
.59881 .42028 .60541 .42829 .61837 .42368 .61174 .41289 Mtetra
.72 .7 .83 r
.61174 .41289 .61837 .42368 .63141 .41979 .6247 .40547 Mtetra
.668 .623 .795 r
.6247 .40547 .63141 .41979 .64453 .41619 .63776 .39979 Mtetra
.582 .553 .788 r
.63776 .39979 .64453 .41619 .65772 .41274 .65103 .39836 Mtetra
.396 .475 .824 r
.65103 .39836 .65772 .41274 .67112 .41235 .66467 .40324 Mtetra
0 .145 .68 r
.66467 .40324 .67112 .41235 .68509 .42164 .67884 .41645 Mtetra
.754 .267 0 r
.67884 .41645 .68509 .42164 .69991 .44355 .69368 .43849 Mtetra
.714 .214 0 r
.69368 .43849 .69991 .44355 .71498 .46479 .7087 .45857 Mtetra
.544 .764 .979 r
.7087 .45857 .71498 .46479 .72891 .46303 .72266 .4566 Mtetra
.933 .825 .716 r
.72266 .4566 .72891 .46303 .74142 .43854 .73526 .43201 Mtetra
.939 .821 .702 r
.73526 .43201 .74142 .43854 .75375 .41311 .74764 .40593 Mtetra
.868 .826 .804 r
.74764 .40593 .75375 .41311 .76677 .39829 .76068 .39049 Mtetra
.742 .79 .892 r
.76068 .39049 .76677 .39829 .78036 .39091 .7743 .38283 Mtetra
.673 .76 .916 r
.7743 .38283 .78036 .39091 .79419 .38598 .78818 .3778 Mtetra
.658 .752 .92 r
.78818 .3778 .79419 .38598 .80812 .38149 .80216 .37327 Mtetra
.656 .751 .92 r
.80216 .37327 .80812 .38149 .82213 .37704 .81622 .36877 Mtetra
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Mtetra
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53334 Mtetra
.653 .751 .921 r
.27168 .53334 .27929 .5402 .29091 .53656 .28333 .52967 Mtetra
.633 .745 .929 r
.28333 .52967 .29091 .53656 .30254 .53339 .29499 .52654 Mtetra
.498 .7 .96 r
.29499 .52654 .30254 .53339 .31408 .53276 .30653 .52614 Mtetra
0 .237 .709 r
.30653 .52614 .31408 .53276 .32524 .53959 .31767 .53352 Mtetra
.814 .336 0 r
.31767 .53352 .32524 .53959 .33596 .55666 .32835 .55097 Mtetra
.753 .247 0 r
.32835 .55097 .33596 .55666 .34695 .57222 .33938 .56574 Mtetra
.764 .79 .875 r
.33938 .56574 .34695 .57222 .35921 .56591 .35176 .55772 Mtetra
.892 .745 .692 r
.35176 .55772 .35921 .56591 .37246 .53827 .36514 .52916 Mtetra
.888 .735 .686 r
.36514 .52916 .37246 .53827 .38568 .50879 .37843 .5001 Mtetra
.859 .746 .737 r
.37843 .5001 .38568 .50879 .39844 .48794 .3912 .4804 Mtetra
.81 .769 .814 r
.3912 .4804 .39844 .48794 .41085 .4752 .40363 .46871 Mtetra
.728 .788 .9 r
.40363 .46871 .41085 .4752 .42306 .46863 .41587 .46238 Mtetra
.609 .766 .955 r
.41587 .46238 .42306 .46863 .43519 .46622 .42805 .45955 Mtetra
.532 .725 .962 r
.42805 .45955 .43519 .46622 .44735 .46553 .44024 .4584 Mtetra
.528 .709 .954 r
.44024 .4584 .44735 .46553 .45958 .46481 .45251 .45745 Mtetra
.558 .715 .945 r
.45251 .45745 .45958 .46481 .47191 .46339 .46487 .45595 Mtetra
.589 .726 .938 r
.46487 .45595 .47191 .46339 .48432 .4612 .47732 .45375 Mtetra
.613 .735 .932 r
.47732 .45375 .48432 .4612 .49681 .45839 .48984 .45093 Mtetra
.631 .742 .928 r
.48984 .45093 .49681 .45839 .50937 .45511 .50243 .44762 Mtetra
.644 .746 .924 r
.50243 .44762 .50937 .45511 .52199 .45143 .51509 .44391 Mtetra
.655 .75 .92 r
.51509 .44391 .52199 .45143 .53467 .44738 .52781 .43984 Mtetra
.666 .754 .916 r
.52781 .43984 .53467 .44738 .5474 .44298 .54058 .43541 Mtetra
.678 .758 .912 r
.54058 .43541 .5474 .44298 .56019 .43817 .55341 .43059 Mtetra
.691 .763 .906 r
.55341 .43059 .56019 .43817 .57303 .43288 .56629 .42526 Mtetra
.708 .768 .899 r
.56629 .42526 .57303 .43288 .58591 .42697 .57921 .41929 Mtetra
.725 .772 .89 r
.57921 .41929 .58591 .42697 .59881 .42028 .59216 .41262 Mtetra
.738 .777 .884 r
.59216 .41262 .59881 .42028 .61174 .41289 .60514 .40535 Mtetra
.734 .78 .89 r
.60514 .40535 .61174 .41289 .6247 .40547 .61816 .3983 Mtetra
.689 .779 .92 r
.61816 .3983 .6247 .40547 .63776 .39979 .63128 .39298 Mtetra
.551 .74 .964 r
.63128 .39298 .63776 .39979 .65103 .39836 .64459 .39124 Mtetra
.235 .56 .935 r
.64459 .39124 .65103 .39836 .66467 .40324 .6582 .39498 Mtetra
0 .176 .697 r
.6582 .39498 .66467 .40324 .67884 .41645 .67233 .40691 Mtetra
0 0 .404 r
.67233 .40691 .67884 .41645 .69368 .43849 .68713 .42844 Mtetra
0 0 .457 r
.68713 .42844 .69368 .43849 .7087 .45857 .70219 .44941 Mtetra
.515 .661 .927 r
.70219 .44941 .7087 .45857 .72266 .4566 .7163 .44913 Mtetra
.92 .81 .722 r
.7163 .44913 .72266 .4566 .73526 .43201 .72903 .42529 Mtetra
.939 .818 .699 r
.72903 .42529 .73526 .43201 .74764 .40593 .74147 .39873 Mtetra
.874 .827 .798 r
.74147 .39873 .74764 .40593 .76068 .39049 .75454 .38266 Mtetra
.748 .793 .889 r
.75454 .38266 .76068 .39049 .7743 .38283 .7682 .37468 Mtetra
.675 .761 .916 r
.7682 .37468 .7743 .38283 .78818 .3778 .78211 .36955 Mtetra
.658 .753 .92 r
.78211 .36955 .78818 .3778 .80216 .37327 .79615 .36496 Mtetra
.656 .751 .92 r
.79615 .36496 .80216 .37327 .81622 .36877 .81025 .36043 Mtetra
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Mtetra
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Mtetra
.25237 .53017 .26007 .53706 .27168 .53334 .26401 .52642 Mtetra
.653 .751 .921 r
.26401 .52642 .27168 .53334 .28333 .52967 .27569 .52273 Mtetra
.63 .745 .93 r
.27569 .52273 .28333 .52967 .29499 .52654 .28737 .51964 Mtetra
.48 .692 .961 r
.28737 .51964 .29499 .52654 .30653 .52614 .29892 .5195 Mtetra
0 .189 .664 r
.29892 .5195 .30653 .52614 .31767 .53352 .31003 .52743 Mtetra
.816 .339 0 r
.31003 .52743 .31767 .53352 .32835 .55097 .32068 .54497 Mtetra
.682 .16 0 r
.32068 .54497 .32835 .55097 .33938 .56574 .33181 .55792 Mtetra
.803 .762 .815 r
.33181 .55792 .33938 .56574 .35176 .55772 .34441 .54639 Mtetra
.875 .713 .677 r
.34441 .54639 .35176 .55772 .36514 .52916 .35799 .51559 Mtetra
.85 .69 .684 r
.35799 .51559 .36514 .52916 .37843 .5001 .37125 .4884 Mtetra
.792 .696 .758 r
.37125 .4884 .37843 .5001 .3912 .4804 .38383 .47451 Mtetra
.713 .804 .921 r
.38383 .47451 .3912 .4804 .40363 .46871 .39608 .46877 Mtetra
.472 .89 .912 r
.39608 .46877 .40363 .46871 .41587 .46238 .40832 .46451 Mtetra
.353 .821 .755 r
.40832 .46451 .41587 .46238 .42805 .45955 .42063 .45957 Mtetra
.523 .914 .921 r
.42063 .45957 .42805 .45955 .44024 .4584 .43298 .45469 Mtetra
.627 .861 .987 r
.43298 .45469 .44024 .4584 .45251 .45745 .44537 .45064 Mtetra
.628 .759 .941 r
.44537 .45064 .45251 .45745 .46487 .45595 .4578 .44735 Mtetra
.622 .707 .906 r
.4578 .44735 .46487 .45595 .47732 .45375 .47028 .44437 Mtetra
.625 .689 .89 r
.47028 .44437 .47732 .45375 .48984 .45093 .48283 .44131 Mtetra
.633 .688 .883 r
.48283 .44131 .48984 .45093 .50243 .44762 .49545 .43796 Mtetra
.643 .692 .88 r
.49545 .43796 .50243 .44762 .51509 .44391 .50814 .43425 Mtetra
.654 .696 .877 r
.50814 .43425 .51509 .44391 .52781 .43984 .52089 .43015 Mtetra
.664 .7 .874 r
.52089 .43015 .52781 .43984 .54058 .43541 .5337 .42565 Mtetra
.673 .703 .87 r
.5337 .42565 .54058 .43541 .55341 .43059 .54656 .42077 Mtetra
.679 .705 .867 r
.54656 .42077 .55341 .43059 .56629 .42526 .55948 .4156 Mtetra
.681 .71 .87 r
.55948 .4156 .56629 .42526 .57921 .41929 .57244 .41036 Mtetra
.675 .726 .888 r
.57244 .41036 .57921 .41929 .59216 .41262 .58547 .40543 Mtetra
.651 .767 .934 r
.58547 .40543 .59216 .41262 .60514 .40535 .59857 .40131 Mtetra
.571 .844 .996 r
.59857 .40131 .60514 .40535 .61816 .3983 .61176 .39801 Mtetra
.346 .822 .875 r
.61176 .39801 .61816 .3983 .63128 .39298 .62501 .39473 Mtetra
.213 .727 .69 r
.62501 .39473 .63128 .39298 .64459 .39124 .63832 .39077 Mtetra
.278 .779 .861 r
.63832 .39077 .64459 .39124 .6582 .39498 .65175 .38833 Mtetra
.043 .451 .877 r
.65175 .38833 .6582 .39498 .67233 .40691 .66563 .39424 Mtetra
0 .006 .579 r
.66563 .39424 .67233 .40691 .68713 .42844 .68032 .41376 Mtetra
0 0 .541 r
.68032 .41376 .68713 .42844 .70219 .44941 .69547 .43697 Mtetra
.42 .534 .867 r
.69547 .43697 .70219 .44941 .7163 .44913 .7098 .44025 Mtetra
.897 .789 .733 r
.7098 .44025 .7163 .44913 .72903 .42529 .72272 .41823 Mtetra
.937 .814 .698 r
.72272 .41823 .72903 .42529 .74147 .39873 .73525 .39151 Mtetra
.88 .828 .791 r
.73525 .39151 .74147 .39873 .75454 .38266 .74835 .3748 Mtetra
.755 .796 .886 r
.74835 .3748 .75454 .38266 .7682 .37468 .76204 .36647 Mtetra
.677 .762 .915 r
.76204 .36647 .7682 .37468 .78211 .36955 .776 .36122 Mtetra
.658 .753 .92 r
.776 .36122 .78211 .36955 .79615 .36496 .79008 .35659 Mtetra
.656 .751 .92 r
.79008 .35659 .79615 .36496 .81025 .36043 .80423 .35201 Mtetra
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Mtetra
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Mtetra
.24461 .52322 .25237 .53017 .26401 .52642 .25627 .51944 Mtetra
.652 .751 .922 r
.25627 .51944 .26401 .52642 .27569 .52273 .26798 .51573 Mtetra
.627 .744 .931 r
.26798 .51573 .27569 .52273 .28737 .51964 .27969 .51269 Mtetra
.46 .685 .963 r
.27969 .51269 .28737 .51964 .29892 .5195 .29124 .51282 Mtetra
0 .155 .631 r
.29124 .51282 .29892 .5195 .31003 .52743 .30232 .52115 Mtetra
.803 .32 0 r
.30232 .52115 .31003 .52743 .32068 .54497 .313 .53814 Mtetra
0 .056 .536 r
.313 .53814 .32068 .54497 .33181 .55792 .32429 .54807 Mtetra
.82 .727 .763 r
.32429 .54807 .33181 .55792 .34441 .54639 .33716 .5327 Mtetra
.861 .692 .672 r
.33716 .5327 .34441 .54639 .35799 .51559 .35082 .50164 Mtetra
.832 .683 .698 r
.35082 .50164 .35799 .51559 .37125 .4884 .36395 .47847 Mtetra
.754 .715 .815 r
.36395 .47847 .37125 .4884 .38383 .47451 .37636 .4694 Mtetra
.566 .793 .984 r
.37636 .4694 .38383 .47451 .39608 .46877 .38851 .46704 Mtetra
.373 .813 .956 r
.38851 .46704 .39608 .46877 .40832 .46451 .40071 .46516 Mtetra
.339 .82 .84 r
.40071 .46516 .40832 .46451 .42063 .45957 .41304 .46166 Mtetra
.372 .834 .765 r
.41304 .46166 .42063 .45957 .43298 .45469 .42548 .45651 Mtetra
.471 .891 .814 r
.42548 .45651 .43298 .45469 .44537 .45064 .43798 .45053 Mtetra
.6 .943 .931 r
.43798 .45053 .44537 .45064 .4578 .44735 .45053 .44463 Mtetra
.665 .906 .979 r
.45053 .44463 .4578 .44735 .47028 .44437 .46311 .43929 Mtetra
.671 .831 .961 r
.46311 .43929 .47028 .44437 .48283 .44131 .47574 .43454 Mtetra
.663 .776 .934 r
.47574 .43454 .48283 .44131 .49545 .43796 .48841 .43018 Mtetra
.657 .746 .915 r
.48841 .43018 .49545 .43796 .50814 .43425 .50113 .42601 Mtetra
.654 .733 .908 r
.50113 .42601 .50814 .43425 .52089 .43015 .51392 .42191 Mtetra
.652 .733 .909 r
.51392 .42191 .52089 .43015 .5337 .42565 .52676 .41788 Mtetra
.644 .745 .922 r
.52676 .41788 .5337 .42565 .54656 .42077 .53967 .41405 Mtetra
.625 .771 .95 r
.53967 .41405 .54656 .42077 .55948 .4156 .55265 .41059 Mtetra
.577 .812 .988 r
.55265 .41059 .55948 .4156 .57244 .41036 .5657 .40767 Mtetra
.453 .835 .987 r
.5657 .40767 .57244 .41036 .58547 .40543 .57883 .40528 Mtetra
.253 .764 .838 r
.57883 .40528 .58547 .40543 .59857 .40131 .59204 .4029 Mtetra
0 0 0 r
.59204 .4029 .59857 .40131 .61176 .39801 .60531 .39971 Mtetra
.3 .788 .733 r
.60531 .39971 .61176 .39801 .62501 .39473 .61861 .3949 Mtetra
.558 .934 .889 r
.61861 .3949 .62501 .39473 .63832 .39077 .63191 .38847 Mtetra
.652 .93 .972 r
.63191 .38847 .63832 .39077 .65175 .38833 .64527 .3825 Mtetra
.363 .686 .98 r
.64527 .3825 .65175 .38833 .66563 .39424 .65898 .38337 Mtetra
0 .105 .656 r
.65898 .38337 .66563 .39424 .68032 .41376 .67346 .39868 Mtetra
0 0 .542 r
.67346 .39868 .68032 .41376 .69547 .43697 .68858 .42207 Mtetra
.315 .428 .818 r
.68858 .42207 .69547 .43697 .7098 .44025 .70313 .42925 Mtetra
.856 .752 .748 r
.70313 .42925 .7098 .44025 .72272 .41823 .7163 .4103 Mtetra
.927 .802 .702 r
.7163 .4103 .72272 .41823 .73525 .39151 .72896 .38408 Mtetra
.882 .824 .786 r
.72896 .38408 .73525 .39151 .74835 .3748 .7421 .36688 Mtetra
.761 .798 .883 r
.7421 .36688 .74835 .3748 .76204 .36647 .75582 .3582 Mtetra
.68 .764 .915 r
.75582 .3582 .76204 .36647 .776 .36122 .76982 .35282 Mtetra
.659 .753 .92 r
.76982 .35282 .776 .36122 .79008 .35659 .78395 .34814 Mtetra
.656 .752 .92 r
.78395 .34814 .79008 .35659 .80423 .35201 .79815 .34352 Mtetra
.656 .751 .92 r
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Mtetra
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Mtetra
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Mtetra
.655 .751 .92 r
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .51241 Mtetra
.652 .75 .922 r
.24847 .51241 .25627 .51944 .26798 .51573 .26021 .50868 Mtetra
.624 .743 .932 r
.26021 .50868 .26798 .51573 .27969 .51269 .27195 .50569 Mtetra
.445 .678 .963 r
.27195 .50569 .27969 .51269 .29124 .51282 .2835 .50602 Mtetra
0 .154 .632 r
.2835 .50602 .29124 .51282 .30232 .52115 .29458 .51439 Mtetra
.758 .263 0 r
.29458 .51439 .30232 .52115 .313 .53814 .30533 .52993 Mtetra
0 .372 .835 r
.30533 .52993 .313 .53814 .32429 .54807 .31684 .53628 Mtetra
.818 .702 .737 r
.31684 .53628 .32429 .54807 .33716 .5327 .32988 .51869 Mtetra
.851 .688 .679 r
.32988 .51869 .33716 .5327 .35082 .50164 .34347 .4902 Mtetra
.829 .708 .732 r
.34347 .4902 .35082 .50164 .36395 .47847 .35643 .47163 Mtetra
.732 .782 .893 r
.35643 .47163 .36395 .47847 .37636 .4694 .36877 .46501 Mtetra
.54 .81 .996 r
.36877 .46501 .37636 .4694 .38851 .46704 .38096 .46274 Mtetra
.535 .812 .997 r
.38096 .46274 .38851 .46704 .40071 .46516 .39322 .46046 Mtetra
.58 .815 .988 r
.39322 .46046 .40071 .46516 .41304 .46166 .40557 .45761 Mtetra
.584 .839 .993 r
.40557 .45761 .41304 .46166 .42548 .45651 .41799 .45439 Mtetra
.546 .885 .986 r
.41799 .45439 .42548 .45651 .43798 .45053 .43049 .45067 Mtetra
.454 .883 .899 r
.43049 .45067 .43798 .45053 .45053 .44463 .44307 .44632 Mtetra
.364 .831 .783 r
.44307 .44632 .45053 .44463 .46311 .43929 .45572 .44147 Mtetra
.33 .805 .737 r
.45572 .44147 .46311 .43929 .47574 .43454 .46842 .43646 Mtetra
.336 .812 .754 r
.46842 .43646 .47574 .43454 .48841 .43018 .48117 .43158 Mtetra
.35 .824 .79 r
.48117 .43158 .48841 .43018 .50113 .42601 .49398 .427 Mtetra
.346 .823 .812 r
.49398 .427 .50113 .42601 .51392 .42191 .50684 .4228 Mtetra
.314 .804 .805 r
.50684 .4228 .51392 .42191 .52676 .41788 .51976 .41898 Mtetra
.26 .768 .769 r
.51976 .41898 .52676 .41788 .53967 .41405 .53274 .41547 Mtetra
.206 .728 .723 r
.53274 .41547 .53967 .41405 .55265 .41059 .54579 .41215 Mtetra
.193 .718 .707 r
.54579 .41215 .55265 .41059 .5657 .40767 .55891 .4088 Mtetra
.272 .775 .767 r
.55891 .4088 .5657 .40767 .57883 .40528 .5721 .405 Mtetra
.447 .878 .902 r
.5721 .405 .57883 .40528 .59204 .4029 .58534 .40059 Mtetra
.608 .913 .98 r
.58534 .40059 .59204 .4029 .60531 .39971 .59863 .39552 Mtetra
.681 .879 .972 r
.59863 .39552 .60531 .39971 .61861 .3949 .61197 .38987 Mtetra
.711 .86 .953 r
.61197 .38987 .61861 .3949 .63191 .38847 .62533 .38358 Mtetra
.706 .865 .958 r
.62533 .38358 .63191 .38847 .64527 .3825 .63875 .37738 Mtetra
.499 .783 .996 r
.63875 .37738 .64527 .3825 .65898 .38337 .6524 .37566 Mtetra
0 .23 .732 r
.6524 .37566 .65898 .38337 .67346 .39868 .66668 .38616 Mtetra
0 0 .543 r
.66668 .38616 .67346 .39868 .68858 .42207 .68165 .40682 Mtetra
.234 .373 .799 r
.68165 .40682 .68858 .42207 .70313 .42925 .69631 .41621 Mtetra
.805 .711 .761 r
.69631 .41621 .70313 .42925 .7163 .4103 .70975 .40089 Mtetra
.908 .782 .711 r
.70975 .40089 .7163 .4103 .72896 .38408 .72258 .37612 Mtetra
.878 .814 .782 r
.72258 .37612 .72896 .38408 .7421 .36688 .73579 .35881 Mtetra
.766 .798 .879 r
.73579 .35881 .7421 .36688 .75582 .3582 .74955 .34986 Mtetra
.682 .764 .914 r
.74955 .34986 .75582 .3582 .76982 .35282 .7636 .34435 Mtetra
.659 .753 .92 r
.7636 .34435 .76982 .35282 .78395 .34814 .77777 .33961 Mtetra
.656 .752 .92 r
.77777 .33961 .78395 .34814 .79815 .34352 .79202 .33494 Mtetra
.656 .751 .92 r
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Mtetra
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Mtetra
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Mtetra
.655 .751 .92 r
.22888 .50916 .23678 .51622 .24847 .51241 .24061 .50532 Mtetra
.652 .75 .922 r
.24061 .50532 .24847 .51241 .26021 .50868 .25238 .50157 Mtetra
.622 .742 .933 r
.25238 .50157 .26021 .50868 .27195 .50569 .26414 .4986 Mtetra
.442 .676 .963 r
.26414 .4986 .27195 .50569 .2835 .50602 .27571 .49896 Mtetra
0 .203 .683 r
.27571 .49896 .2835 .50602 .29458 .51439 .28683 .50683 Mtetra
.65 .148 0 r
.28683 .50683 .29458 .51439 .30533 .52993 .29771 .52022 Mtetra
.315 .535 .907 r
.29771 .52022 .30533 .52993 .31684 .53628 .30941 .52358 Mtetra
.811 .691 .732 r
.30941 .52358 .31684 .53628 .32988 .51869 .32248 .50608 Mtetra
.848 .7 .698 r
.32248 .50608 .32988 .51869 .34347 .4902 .33592 .48151 Mtetra
.831 .75 .774 r
.33592 .48151 .34347 .4902 .35643 .47163 .34876 .46636 Mtetra
.716 .828 .934 r
.34876 .46636 .35643 .47163 .36877 .46501 .36112 .46046 Mtetra
.576 .818 .99 r
.36112 .46046 .36877 .46501 .38096 .46274 .37337 .45761 Mtetra
.587 .803 .982 r
.37337 .45761 .38096 .46274 .39322 .46046 .38569 .45476 Mtetra
.62 .796 .966 r
.38569 .45476 .39322 .46046 .40557 .45761 .3981 .45137 Mtetra
.64 .785 .951 r
.3981 .45137 .40557 .45761 .41799 .45439 .41058 .44758 Mtetra
.644 .77 .94 r
.41058 .44758 .41799 .45439 .43049 .45067 .42312 .44375 Mtetra
.639 .766 .94 r
.42312 .44375 .43049 .45067 .44307 .44632 .43572 .44004 Mtetra
.63 .784 .955 r
.43572 .44004 .44307 .44632 .45572 .44147 .44838 .43643 Mtetra
.618 .822 .979 r
.44838 .43643 .45572 .44147 .46842 .43646 .46111 .43278 Mtetra
.596 .861 .993 r
.46111 .43278 .46842 .43646 .48117 .43158 .4739 .42899 Mtetra
.567 .885 .99 r
.4739 .42899 .48117 .43158 .49398 .427 .48676 .42505 Mtetra
.547 .894 .98 r
.48676 .42505 .49398 .427 .50684 .4228 .49968 .42096 Mtetra
.55 .899 .976 r
.49968 .42096 .50684 .4228 .51976 .41898 .51266 .4167 Mtetra
.581 .901 .984 r
.51266 .4167 .51976 .41898 .53274 .41547 .5257 .41223 Mtetra
.627 .89 .988 r
.5257 .41223 .53274 .41547 .54579 .41215 .53881 .40749 Mtetra
.665 .856 .973 r
.53881 .40749 .54579 .41215 .55891 .4088 .55197 .40246 Mtetra
.675 .806 .945 r
.55197 .40246 .55891 .4088 .5721 .405 .56519 .39746 Mtetra
.669 .769 .925 r
.56519 .39746 .5721 .405 .58534 .40059 .57847 .39267 Mtetra
.659 .756 .921 r
.57847 .39267 .58534 .40059 .59863 .39552 .59182 .38817 Mtetra
.664 .775 .932 r
.59182 .38817 .59863 .39552 .61197 .38987 .60522 .38347 Mtetra
.686 .812 .943 r
.60522 .38347 .61197 .38987 .62533 .38358 .61867 .37802 Mtetra
.692 .842 .955 r
.61867 .37802 .62533 .38358 .63875 .37738 .63217 .37227 Mtetra
.55 .808 .993 r
.63217 .37227 .63875 .37738 .6524 .37566 .64583 .3696 Mtetra
0 .383 .82 r
.64583 .3696 .6524 .37566 .66668 .38616 .65998 .37645 Mtetra
0 .027 .578 r
.65998 .37645 .66668 .38616 .68165 .40682 .67475 .39298 Mtetra
.195 .373 .814 r
.67475 .39298 .68165 .40682 .69631 .41621 .6894 .40218 Mtetra
.764 .685 .774 r
.6894 .40218 .69631 .41621 .70975 .40089 .70305 .38989 Mtetra
.881 .759 .722 r
.70305 .38989 .70975 .40089 .72258 .37612 .71609 .36731 Mtetra
.865 .797 .782 r
.71609 .36731 .72258 .37612 .73579 .35881 .7294 .35046 Mtetra
.765 .792 .875 r
.7294 .35046 .73579 .35881 .74955 .34986 .74321 .3414 Mtetra
.683 .764 .913 r
.74321 .3414 .74955 .34986 .7636 .34435 .75731 .3358 Mtetra
.66 .753 .919 r
.75731 .3358 .7636 .34435 .77777 .33961 .77153 .331 Mtetra
.656 .752 .92 r
.77153 .331 .77777 .33961 .79202 .33494 .78584 .32629 Mtetra
.656 .751 .92 r
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Mtetra
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50204 Mtetra
.655 .751 .92 r
.22092 .50204 .22888 .50916 .24061 .50532 .23268 .49816 Mtetra
.651 .75 .922 r
.23268 .49816 .24061 .50532 .25238 .50157 .24448 .49439 Mtetra
.622 .742 .933 r
.24448 .49439 .25238 .50157 .26414 .4986 .25627 .49139 Mtetra
.457 .68 .961 r
.25627 .49139 .26414 .4986 .27571 .49896 .26788 .49153 Mtetra
0 .3 .772 r
.26788 .49153 .27571 .49896 .28683 .50683 .27907 .49835 Mtetra
0 .026 .543 r
.27907 .49835 .28683 .50683 .29771 .52022 .2901 .50939 Mtetra
.443 .576 .892 r
.2901 .50939 .29771 .52022 .30941 .52358 .30192 .51101 Mtetra
.799 .69 .744 r
.30192 .51101 .30941 .52358 .32248 .50608 .31493 .49533 Mtetra
.846 .72 .725 r
.31493 .49533 .32248 .50608 .33592 .48151 .32821 .47456 Mtetra
.83 .787 .81 r
.32821 .47456 .33592 .48151 .34876 .46636 .341 .46145 Mtetra
.717 .841 .941 r
.341 .46145 .34876 .46636 .36112 .46046 .3534 .45547 Mtetra
.622 .819 .976 r
.3534 .45547 .36112 .46046 .37337 .45761 .36573 .45187 Mtetra
.623 .796 .965 r
.36573 .45187 .37337 .45761 .38569 .45476 .37812 .44841 Mtetra
.631 .78 .952 r
.37812 .44841 .38569 .45476 .3981 .45137 .39057 .44484 Mtetra
.633 .776 .949 r
.39057 .44484 .3981 .45137 .41058 .44758 .40308 .44123 Mtetra
.638 .784 .952 r
.40308 .44123 .41058 .44758 .42312 .44375 .41566 .43746 Mtetra
.646 .789 .951 r
.41566 .43746 .42312 .44375 .43572 .44004 .42831 .43344 Mtetra
.654 .783 .943 r
.42831 .43344 .43572 .44004 .44838 .43643 .44103 .42924 Mtetra
.657 .767 .931 r
.44103 .42924 .44838 .43643 .46111 .43278 .45381 .42497 Mtetra
.657 .751 .919 r
.45381 .42497 .46111 .43278 .4739 .42899 .46664 .42069 Mtetra
.656 .738 .91 r
.46664 .42069 .4739 .42899 .48676 .42505 .47954 .41642 Mtetra
.655 .73 .904 r
.47954 .41642 .48676 .42505 .49968 .42096 .4925 .41215 Mtetra
.653 .726 .902 r
.4925 .41215 .49968 .42096 .51266 .4167 .50551 .40792 Mtetra
.649 .726 .905 r
.50551 .40792 .51266 .4167 .5257 .41223 .5186 .40383 Mtetra
.641 .734 .916 r
.5186 .40383 .5257 .41223 .53881 .40749 .53174 .39997 Mtetra
.631 .756 .938 r
.53174 .39997 .53881 .40749 .55197 .40246 .54496 .39632 Mtetra
.635 .802 .963 r
.54496 .39632 .55197 .40246 .56519 .39746 .55824 .3923 Mtetra
.656 .841 .971 r
.55824 .3923 .56519 .39746 .57847 .39267 .57157 .3875 Mtetra
.686 .85 .962 r
.57157 .3875 .57847 .39267 .59182 .38817 .58496 .38192 Mtetra
.69 .818 .944 r
.58496 .38192 .59182 .38817 .60522 .38347 .5984 .37633 Mtetra
.675 .788 .934 r
.5984 .37633 .60522 .38347 .61867 .37802 .6119 .37123 Mtetra
.661 .795 .947 r
.6119 .37123 .61867 .37802 .63217 .37227 .62549 .3665 Mtetra
.554 .789 .986 r
.62549 .3665 .63217 .37227 .64583 .3696 .63921 .36398 Mtetra
.054 .502 .891 r
.63921 .36398 .64583 .3696 .65998 .37645 .65331 .36859 Mtetra
0 .142 .658 r
.65331 .36859 .65998 .37645 .67475 .39298 .6679 .38104 Mtetra
.219 .429 .853 r
.6679 .38104 .67475 .39298 .6894 .40218 .68246 .38826 Mtetra
.744 .679 .788 r
.68246 .38826 .6894 .40218 .70305 .38989 .69625 .37769 Mtetra
.855 .739 .734 r
.69625 .37769 .70305 .38989 .71609 .36731 .70949 .35749 Mtetra
.845 .777 .786 r
.70949 .35749 .71609 .36731 .7294 .35046 .72294 .3417 Mtetra
.758 .782 .872 r
.72294 .3417 .7294 .35046 .74321 .3414 .73682 .3328 Mtetra
.683 .762 .911 r
.73682 .3328 .74321 .3414 .75731 .3358 .75097 .32716 Mtetra
.66 .753 .919 r
.75097 .32716 .75731 .3358 .77153 .331 .76524 .32231 Mtetra
.656 .752 .92 r
.76524 .32231 .77153 .331 .78584 .32629 .77959 .31756 Mtetra
.656 .751 .92 r
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Mtetra
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.20116 .49875 .20922 .5059 .22092 .50204 .2129 .49485 Mtetra
.655 .751 .92 r
.2129 .49485 .22092 .50204 .23268 .49816 .22469 .49095 Mtetra
.652 .75 .922 r
.22469 .49095 .23268 .49816 .24448 .49439 .23652 .48713 Mtetra
.625 .743 .931 r
.23652 .48713 .24448 .49439 .25627 .49139 .24834 .48402 Mtetra
.489 .691 .957 r
.24834 .48402 .25627 .49139 .26788 .49153 .26001 .48367 Mtetra
.023 .416 .861 r
.26001 .48367 .26788 .49153 .27907 .49835 .27131 .48905 Mtetra
0 .205 .72 r
.27131 .48905 .27907 .49835 .2901 .50939 .28248 .49794 Mtetra
.472 .578 .88 r
.28248 .49794 .2901 .50939 .30192 .51101 .29434 .49908 Mtetra
.783 .695 .767 r
.29434 .49908 .30192 .51101 .31493 .49533 .30722 .48606 Mtetra
.842 .742 .753 r
.30722 .48606 .31493 .49533 .32821 .47456 .32037 .46847 Mtetra
.827 .809 .833 r
.32037 .46847 .32821 .47456 .341 .46145 .33315 .45643 Mtetra
.729 .84 .933 r
.33315 .45643 .341 .46145 .3534 .45547 .34563 .45002 Mtetra
.651 .814 .962 r
.34563 .45002 .3534 .45547 .36573 .45187 .35803 .44583 Mtetra
.638 .793 .957 r
.35803 .44583 .36573 .45187 .37812 .44841 .37047 .44204 Mtetra
.643 .785 .949 r
.37047 .44204 .37812 .44841 .39057 .44484 .38297 .43813 Mtetra
.649 .777 .941 r
.38297 .43813 .39057 .44484 .40308 .44123 .39554 .43408 Mtetra
.649 .765 .934 r
.39554 .43408 .40308 .44123 .41566 .43746 .40817 .43006 Mtetra
.646 .758 .93 r
.40817 .43006 .41566 .43746 .42831 .43344 .42085 .42612 Mtetra
.643 .76 .934 r
.42085 .42612 .42831 .43344 .44103 .42924 .4336 .42223 Mtetra
.643 .77 .941 r
.4336 .42223 .44103 .42924 .45381 .42497 .44641 .4183 Mtetra
.644 .782 .947 r
.44641 .4183 .45381 .42497 .46664 .42069 .45928 .41426 Mtetra
.648 .792 .951 r
.45928 .41426 .46664 .42069 .47954 .41642 .47222 .41008 Mtetra
.653 .797 .952 r
.47222 .41008 .47954 .41642 .4925 .41215 .48523 .40573 Mtetra
.661 .798 .948 r
.48523 .40573 .4925 .41215 .50551 .40792 .49829 .40113 Mtetra
.673 .791 .938 r
.49829 .40113 .50551 .40792 .5186 .40383 .51142 .39621 Mtetra
.682 .771 .919 r
.51142 .39621 .5186 .40383 .53174 .39997 .52461 .39099 Mtetra
.678 .735 .893 r
.52461 .39099 .53174 .39997 .54496 .39632 .53786 .38579 Mtetra
.648 .689 .874 r
.53786 .38579 .54496 .39632 .55824 .3923 .55117 .38155 Mtetra
.618 .672 .88 r
.55117 .38155 .55824 .3923 .57157 .3875 .56456 .37837 Mtetra
.614 .71 .914 r
.56456 .37837 .57157 .3875 .58496 .38192 .57802 .37525 Mtetra
.651 .796 .952 r
.57802 .37525 .58496 .38192 .5984 .37633 .59154 .37077 Mtetra
.683 .842 .959 r
.59154 .37077 .5984 .37633 .6119 .37123 .60509 .36521 Mtetra
.662 .822 .96 r
.60509 .36521 .6119 .37123 .62549 .3665 .61872 .36029 Mtetra
.545 .772 .982 r
.61872 .36029 .62549 .3665 .63921 .36398 .63251 .35807 Mtetra
.157 .566 .931 r
.63251 .35807 .63921 .36398 .65331 .36859 .64661 .36157 Mtetra
0 .287 .763 r
.64661 .36157 .65331 .36859 .6679 .38104 .66108 .37062 Mtetra
.311 .525 .901 r
.66108 .37062 .6679 .38104 .68246 .38826 .67552 .37493 Mtetra
.742 .688 .799 r
.67552 .37493 .68246 .38826 .69625 .37769 .68936 .36479 Mtetra
.833 .725 .746 r
.68936 .36479 .69625 .37769 .70949 .35749 .70279 .34679 Mtetra
.82 .757 .793 r
.70279 .34679 .70949 .35749 .72294 .3417 .71639 .33246 Mtetra
.746 .769 .872 r
.71639 .33246 .72294 .3417 .73682 .3328 .73036 .32402 Mtetra
.68 .758 .91 r
.73036 .32402 .73682 .3328 .75097 .32716 .74456 .31843 Mtetra
.659 .753 .919 r
.74456 .31843 .75097 .32716 .76524 .32231 .75889 .31354 Mtetra
.656 .752 .92 r
.75889 .31354 .76524 .32231 .77959 .31756 .77329 .30875 Mtetra
.656 .751 .92 r
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Mtetra
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Mtetra
.2048 .48761 .2129 .49485 .22469 .49095 .21662 .48367 Mtetra
.652 .75 .922 r
.21662 .48367 .22469 .49095 .23652 .48713 .22849 .4798 Mtetra
.631 .744 .929 r
.22849 .4798 .23652 .48713 .24834 .48402 .24036 .4765 Mtetra
.529 .704 .951 r
.24036 .4765 .24834 .48402 .26001 .48367 .2521 .47545 Mtetra
.204 .521 .917 r
.2521 .47545 .26001 .48367 .27131 .48905 .26354 .47916 Mtetra
0 .34 .82 r
.26354 .47916 .27131 .48905 .28248 .49794 .27484 .48621 Mtetra
.456 .565 .876 r
.27484 .48621 .28248 .49794 .29434 .49908 .28667 .48771 Mtetra
.755 .696 .796 r
.28667 .48771 .29434 .49908 .30722 .48606 .29938 .47768 Mtetra
.832 .759 .781 r
.29938 .47768 .30722 .48606 .32037 .46847 .31243 .46269 Mtetra
.823 .819 .845 r
.31243 .46269 .32037 .46847 .33315 .45643 .32524 .45124 Mtetra
.742 .838 .924 r
.32524 .45124 .33315 .45643 .34563 .45002 .33779 .44432 Mtetra
.674 .813 .95 r
.33779 .44432 .34563 .45002 .35803 .44583 .35027 .43953 Mtetra
.654 .791 .947 r
.35027 .43953 .35803 .44583 .37047 .44204 .36276 .43532 Mtetra
.648 .777 .942 r
.36276 .43532 .37047 .44204 .38297 .43813 .37531 .4313 Mtetra
.644 .774 .942 r
.37531 .4313 .38297 .43813 .39554 .43408 .38791 .42736 Mtetra
.646 .779 .944 r
.38791 .42736 .39554 .43408 .40817 .43006 .40058 .42333 Mtetra
.651 .781 .943 r
.40058 .42333 .40817 .43006 .42085 .42612 .41331 .41915 Mtetra
.656 .776 .937 r
.41331 .41915 .42085 .42612 .4336 .42223 .42611 .41484 Mtetra
.658 .766 .929 r
.42611 .41484 .4336 .42223 .44641 .4183 .43897 .41046 Mtetra
.66 .755 .92 r
.43897 .41046 .44641 .4183 .45928 .41426 .45189 .40602 Mtetra
.661 .745 .912 r
.45189 .40602 .45928 .41426 .47222 .41008 .46487 .4015 Mtetra
.662 .738 .906 r
.46487 .4015 .47222 .41008 .48523 .40573 .47792 .39694 Mtetra
.659 .732 .904 r
.47792 .39694 .48523 .40573 .49829 .40113 .49102 .39245 Mtetra
.652 .734 .909 r
.49102 .39245 .49829 .40113 .51142 .39621 .50419 .38817 Mtetra
.648 .751 .924 r
.50419 .38817 .51142 .39621 .52461 .39099 .51742 .384 Mtetra
.658 .785 .942 r
.51742 .384 .52461 .39099 .53786 .38579 .53071 .37944 Mtetra
.694 .816 .94 r
.53071 .37944 .53786 .38579 .55117 .38155 .54406 .37371 Mtetra
.691 .773 .914 r
.54406 .37371 .55117 .38155 .56456 .37837 .55747 .36806 Mtetra
.637 .693 .885 r
.55747 .36806 .56456 .37837 .57802 .37525 .57096 .36417 Mtetra
.595 .659 .882 r
.57096 .36417 .57802 .37525 .59154 .37077 .58454 .36169 Mtetra
.613 .715 .918 r
.58454 .36169 .59154 .37077 .60509 .36521 .5982 .35849 Mtetra
.633 .792 .959 r
.5982 .35849 .60509 .36521 .61872 .36029 .6119 .35441 Mtetra
.534 .781 .989 r
.6119 .35441 .61872 .36029 .63251 .35807 .62574 .35222 Mtetra
.215 .608 .95 r
.62574 .35222 .63251 .35807 .64661 .36157 .63985 .35485 Mtetra
.004 .433 .862 r
.63985 .35485 .64661 .36157 .66108 .37062 .65424 .36105 Mtetra
.444 .626 .93 r
.65424 .36105 .66108 .37062 .67552 .37493 .66856 .36212 Mtetra
.753 .701 .803 r
.66856 .36212 .67552 .37493 .68936 .36479 .68242 .35153 Mtetra
.813 .716 .758 r
.68242 .35153 .68936 .36479 .70279 .34679 .69601 .33544 Mtetra
.794 .74 .803 r
.69601 .33544 .70279 .34679 .71639 .33246 .70976 .32282 Mtetra
.729 .756 .874 r
.70976 .32282 .71639 .33246 .73036 .32402 .72383 .31506 Mtetra
.676 .754 .91 r
.72383 .31506 .73036 .32402 .74456 .31843 .7381 .3096 Mtetra
.659 .752 .919 r
.7381 .3096 .74456 .31843 .75889 .31354 .75247 .30469 Mtetra
.656 .751 .92 r
.75247 .30469 .75889 .31354 .77329 .30875 .76693 .29986 Mtetra
.76693 .29986 .77329 .30875 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Mtetra
.19664 .48031 .2048 .48761 .21662 .48367 .20849 .47633 Mtetra
.654 .751 .921 r
.20849 .47633 .21662 .48367 .22849 .4798 .22039 .4724 Mtetra
.639 .746 .926 r
.22039 .4724 .22849 .4798 .24036 .4765 .23231 .46886 Mtetra
.569 .718 .942 r
.23231 .46886 .24036 .4765 .2521 .47545 .24414 .467 Mtetra
.355 .599 .939 r
.24414 .467 .2521 .47545 .26354 .47916 .25573 .46895 Mtetra
.159 .436 .871 r
.25573 .46895 .26354 .47916 .27484 .48621 .26715 .47431 Mtetra
.419 .544 .875 r
.26715 .47431 .27484 .48621 .28667 .48771 .27893 .47656 Mtetra
.709 .687 .827 r
.27893 .47656 .28667 .48771 .29938 .47768 .29146 .46961 Mtetra
.814 .766 .808 r
.29146 .46961 .29938 .47768 .31243 .46269 .30441 .45701 Mtetra
.819 .823 .853 r
.30441 .45701 .31243 .46269 .32524 .45124 .31725 .44593 Mtetra
.755 .837 .914 r
.31725 .44593 .32524 .45124 .33779 .44432 .32988 .43845 Mtetra
.691 .813 .94 r
.32988 .43845 .33779 .44432 .35027 .43953 .34243 .43316 Mtetra
.663 .792 .944 r
.34243 .43316 .35027 .43953 .36276 .43532 .35498 .42868 Mtetra
.657 .784 .942 r
.35498 .42868 .36276 .43532 .37531 .4313 .36758 .42436 Mtetra
.657 .776 .937 r
.36758 .42436 .37531 .4313 .38791 .42736 .38024 .42005 Mtetra
.654 .765 .931 r
.38024 .42005 .38791 .42736 .40058 .42333 .39295 .41582 Mtetra
.651 .76 .929 r
.39295 .41582 .40058 .42333 .41331 .41915 .40572 .41167 Mtetra
.65 .762 .931 r
.40572 .41167 .41331 .41915 .42611 .41484 .41855 .40752 Mtetra
.652 .768 .934 r
.41855 .40752 .42611 .41484 .43897 .41046 .43145 .40328 Mtetra
.657 .775 .936 r
.43145 .40328 .43897 .41046 .45189 .40602 .44441 .39887 Mtetra
.661 .778 .935 r
.44441 .39887 .45189 .40602 .46487 .4015 .45743 .3943 Mtetra
.66 .777 .935 r
.45743 .3943 .46487 .4015 .47792 .39694 .47052 .38974 Mtetra
.659 .778 .937 r
.47052 .38974 .47792 .39694 .49102 .39245 .48367 .38518 Mtetra
.654 .775 .938 r
.48367 .38518 .49102 .39245 .50419 .38817 .49688 .38074 Mtetra
.637 .766 .941 r
.49688 .38074 .50419 .38817 .51742 .384 .51015 .3768 Mtetra
.614 .766 .952 r
.51015 .3768 .51742 .384 .53071 .37944 .52349 .37341 Mtetra
.61 .802 .973 r
.52349 .37341 .53071 .37944 .54406 .37371 .53691 .36981 Mtetra
.678 .892 .975 r
.53691 .36981 .54406 .37371 .55747 .36806 .55038 .36396 Mtetra
.711 .895 .963 r
.55038 .36396 .55747 .36806 .57096 .36417 .56389 .3573 Mtetra
.653 .794 .95 r
.56389 .3573 .57096 .36417 .58454 .36169 .57749 .35272 Mtetra
.593 .712 .926 r
.57749 .35272 .58454 .36169 .5982 .35849 .59119 .35003 Mtetra
.58 .721 .939 r
.59119 .35003 .5982 .35849 .6119 .35441 .60499 .34758 Mtetra
.504 .738 .978 r
.60499 .34758 .6119 .35441 .62574 .35222 .6189 .34629 Mtetra
.262 .636 .963 r
.6189 .34629 .62574 .35222 .63985 .35485 .63303 .34829 Mtetra
.192 .572 .938 r
.63303 .34829 .63985 .35485 .65424 .36105 .64735 .35173 Mtetra
.577 .702 .927 r
.64735 .35173 .65424 .36105 .66856 .36212 .66156 .34942 Mtetra
.765 .709 .799 r
.66156 .34942 .66856 .36212 .68242 .35153 .67543 .33803 Mtetra
.793 .707 .77 r
.67543 .33803 .68242 .35153 .69601 .33544 .68916 .32373 Mtetra
.766 .727 .816 r
.68916 .32373 .69601 .33544 .70976 .32282 .70307 .31294 Mtetra
.709 .745 .88 r
.70307 .31294 .70976 .32282 .72383 .31506 .71724 .30598 Mtetra
.67 .75 .911 r
.71724 .30598 .72383 .31506 .7381 .3096 .73157 .30067 Mtetra
.658 .751 .919 r
.73157 .30067 .7381 .3096 .75247 .30469 .746 .29576 Mtetra
.656 .751 .92 r
.746 .29576 .75247 .30469 .76693 .29986 .76051 .29088 Mtetra
.76051 .29088 .76693 .29986 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28105 Mtetra
.78974 .28105 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Mtetra
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Mtetra
.654 .751 .921 r
.20029 .46893 .20849 .47633 .22039 .4724 .21223 .46494 Mtetra
.646 .748 .924 r
.21223 .46494 .22039 .4724 .23231 .46886 .22419 .46117 Mtetra
.603 .73 .934 r
.22419 .46117 .23231 .46886 .24414 .467 .23612 .45851 Mtetra
.469 .655 .941 r
.23612 .45851 .24414 .467 .25573 .46895 .24787 .45869 Mtetra
.292 .515 .899 r
.24787 .45869 .25573 .46895 .26715 .47431 .25943 .4623 Mtetra
.385 .524 .874 r
.25943 .4623 .26715 .47431 .27893 .47656 .27115 .46517 Mtetra
.64 .66 .853 r
.27115 .46517 .27893 .47656 .29146 .46961 .28348 .46133 Mtetra
.782 .762 .835 r
.28348 .46133 .29146 .46961 .30441 .45701 .2963 .45124 Mtetra
.811 .823 .86 r
.2963 .45124 .30441 .45701 .31725 .44593 .30917 .44063 Mtetra
.767 .839 .907 r
.30917 .44063 .31725 .44593 .32988 .43845 .32189 .4326 Mtetra
.709 .819 .933 r
.32189 .4326 .32988 .43845 .34243 .43316 .33452 .4267 Mtetra
.676 .795 .938 r
.33452 .4267 .34243 .43316 .35498 .42868 .34713 .4218 Mtetra
.66 .78 .937 r
.34713 .4218 .35498 .42868 .36758 .42436 .35977 .41737 Mtetra
.653 .775 .938 r
.35977 .41737 .36758 .42436 .38024 .42005 .37247 .41312 Mtetra
.653 .778 .94 r
.37247 .41312 .38024 .42005 .39295 .41582 .38522 .40885 Mtetra
.657 .779 .939 r
.38522 .40885 .39295 .41582 .40572 .41167 .39804 .40444 Mtetra
.66 .773 .933 r
.39804 .40444 .40572 .41167 .41855 .40752 .41092 .39994 Mtetra
.663 .766 .926 r
.41092 .39994 .41855 .40752 .43145 .40328 .42387 .39534 Mtetra
.667 .758 .918 r
.42387 .39534 .43145 .40328 .44441 .39887 .43688 .3906 Mtetra
.659 .747 .916 r
.43688 .3906 .44441 .39887 .45743 .3943 .44995 .38609 Mtetra
.645 .746 .922 r
.44995 .38609 .45743 .3943 .47052 .38974 .46306 .38198 Mtetra
.639 .757 .934 r
.46306 .38198 .47052 .38974 .48367 .38518 .47625 .37801 Mtetra
.628 .772 .949 r
.47625 .37801 .48367 .38518 .49688 .38074 .48949 .37423 Mtetra
.626 .792 .962 r
.48949 .37423 .49688 .38074 .51015 .3768 .50281 .37039 Mtetra
.611 .791 .968 r
.50281 .37039 .51015 .3768 .52349 .37341 .5162 .36685 Mtetra
.58 .776 .973 r
.5162 .36685 .52349 .37341 .53691 .36981 .52966 .36402 Mtetra
.629 .82 .974 r
.52966 .36402 .53691 .36981 .55038 .36396 .5432 .35983 Mtetra
.721 .897 .959 r
.5432 .35983 .55038 .36396 .56389 .3573 .55678 .35284 Mtetra
.702 .885 .965 r
.55678 .35284 .56389 .3573 .57749 .35272 .57041 .34642 Mtetra
.61 .8 .973 r
.57041 .34642 .57749 .35272 .59119 .35003 .58415 .34274 Mtetra
.547 .744 .968 r
.58415 .34274 .59119 .35003 .60499 .34758 .598 .34072 Mtetra
.462 .719 .98 r
.598 .34072 .60499 .34758 .6189 .34629 .61199 .34015 Mtetra
.313 .663 .973 r
.61199 .34015 .6189 .34629 .63303 .34829 .62614 .34152 Mtetra
.397 .69 .978 r
.62614 .34152 .63303 .34829 .64735 .35173 .64038 .34201 Mtetra
.68 .736 .893 r
.64038 .34201 .64735 .35173 .66156 .34942 .6545 .33632 Mtetra
.769 .705 .792 r
.6545 .33632 .66156 .34942 .67543 .33803 .66839 .32436 Mtetra
.77 .698 .783 r
.66839 .32436 .67543 .33803 .68916 .32373 .68226 .31198 Mtetra
.736 .717 .833 r
.68226 .31198 .68916 .32373 .70307 .31294 .69633 .30302 Mtetra
.69 .739 .888 r
.69633 .30302 .70307 .31294 .71724 .30598 .71059 .29682 Mtetra
.664 .748 .913 r
.71059 .29682 .71724 .30598 .73157 .30067 .72499 .29167 Mtetra
.657 .751 .919 r
.72499 .29167 .73157 .30067 .746 .29576 .73947 .28674 Mtetra
.656 .751 .92 r
.73947 .28674 .746 .29576 .76051 .29088 .75403 .28181 Mtetra
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28105 .78336 .2719 Mtetra
.78336 .2719 .78974 .28105 .80447 .27611 .79815 .2669 Mtetra
.14469 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Mtetra
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Mtetra
.655 .751 .92 r
.19202 .46147 .20029 .46893 .21223 .46494 .20399 .45742 Mtetra
.651 .749 .922 r
.20399 .45742 .21223 .46494 .22419 .46117 .216 .45347 Mtetra
.628 .739 .927 r
.216 .45347 .22419 .46117 .23612 .45851 .22801 .45014 Mtetra
.551 .695 .935 r
.22801 .45014 .23612 .45851 .24787 .45869 .23992 .44869 Mtetra
.411 .588 .915 r
.23992 .44869 .24787 .45869 .25943 .4623 .25165 .45031 Mtetra
.381 .525 .876 r
.25165 .45031 .25943 .4623 .27115 .46517 .26337 .45317 Mtetra
.552 .611 .866 r
.26337 .45317 .27115 .46517 .28348 .46133 .2755 .45219 Mtetra
.724 .735 .86 r
.2755 .45219 .28348 .46133 .2963 .45124 .28814 .4451 Mtetra
.794 .816 .87 r
.28814 .4451 .2963 .45124 .30917 .44063 .30101 .43538 Mtetra
.777 .843 .901 r
.30101 .43538 .30917 .44063 .32189 .4326 .31381 .42686 Mtetra
.726 .826 .927 r
.31381 .42686 .32189 .4326 .33452 .4267 .32652 .42037 Mtetra
.687 .803 .937 r
.32652 .42037 .33452 .4267 .34713 .4218 .33919 .41511 Mtetra
.671 .79 .938 r
.33919 .41511 .34713 .4218 .35977 .41737 .3519 .41031 Mtetra
.665 .779 .934 r
.3519 .41031 .35977 .41737 .37247 .41312 .36465 .40568 Mtetra
.659 .767 .93 r
.36465 .40568 .37247 .41312 .38522 .40885 .37745 .40123 Mtetra
.655 .762 .928 r
.37745 .40123 .38522 .40885 .39804 .40444 .3903 .39687 Mtetra
.653 .764 .931 r
.3903 .39687 .39804 .40444 .41092 .39994 .40322 .39254 Mtetra
.661 .772 .932 r
.40322 .39254 .41092 .39994 .42387 .39534 .41621 .38796 Mtetra
.66 .773 .933 r
.41621 .38796 .42387 .39534 .43688 .3906 .42926 .38338 Mtetra
.647 .775 .942 r
.42926 .38338 .43688 .3906 .44995 .38609 .44236 .37914 Mtetra
.65 .785 .946 r
.44236 .37914 .44995 .38609 .46306 .38198 .45552 .37476 Mtetra
.7 .793 .922 r
.45552 .37476 .46306 .38198 .47625 .37801 .46878 .36883 Mtetra
.686 .739 .891 r
.46878 .36883 .47625 .37801 .48949 .37423 .48209 .36319 Mtetra
.662 .689 .865 r
.48209 .36319 .48949 .37423 .50281 .37039 .49545 .35824 Mtetra
.719 .691 .823 r
.49545 .35824 .50281 .37039 .5162 .36685 .50889 .35019 Mtetra
.553 .547 .802 r
.50889 .35019 .5162 .36685 .52966 .36402 .52235 .34937 Mtetra
.518 .558 .835 r
.52235 .34937 .52966 .36402 .5432 .35983 .53592 .34962 Mtetra
.647 .706 .89 r
.53592 .34962 .5432 .35983 .55678 .35284 .54956 .34524 Mtetra
.679 .785 .93 r
.54956 .34524 .55678 .35284 .57041 .34642 .56326 .33982 Mtetra
.61 .792 .969 r
.56326 .33982 .57041 .34642 .58415 .34274 .57705 .33616 Mtetra
.516 .755 .983 r
.57705 .33616 .58415 .34274 .598 .34072 .59096 .33445 Mtetra
.429 .724 .987 r
.59096 .33445 .598 .34072 .61199 .34015 .605 .33409 Mtetra
.4 .716 .987 r
.605 .33409 .61199 .34015 .62614 .34152 .61915 .33407 Mtetra
.588 .762 .962 r
.61915 .33407 .62614 .34152 .64038 .34201 .63332 .33102 Mtetra
.735 .73 .847 r
.63332 .33102 .64038 .34201 .6545 .33632 .64736 .32243 Mtetra
.759 .691 .787 r
.64736 .32243 .6545 .33632 .66839 .32436 .66131 .31075 Mtetra
.741 .689 .801 r
.66131 .31075 .66839 .32436 .68226 .31198 .67533 .30055 Mtetra
.707 .714 .854 r
.67533 .30055 .68226 .31198 .69633 .30302 .68953 .29323 Mtetra
.674 .738 .898 r
.68953 .29323 .69633 .30302 .71059 .29682 .70389 .28764 Mtetra
.66 .749 .916 r
.70389 .28764 .71059 .29682 .72499 .29167 .71834 .28259 Mtetra
.656 .751 .92 r
.71834 .28259 .72499 .29167 .73947 .28674 .73287 .27763 Mtetra
.73287 .27763 .73947 .28674 .75403 .28181 .74748 .27266 Mtetra
.74748 .27266 .75403 .28181 .76866 .27687 .76217 .26768 Mtetra
.76217 .26768 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47017 .14469 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Mtetra
.18368 .45394 .19202 .46147 .20399 .45742 .19568 .44985 Mtetra
.654 .751 .921 r
.19568 .44985 .20399 .45742 .216 .45347 .20774 .44578 Mtetra
.644 .745 .923 r
.20774 .44578 .216 .45347 .22801 .45014 .21982 .44198 Mtetra
.606 .722 .927 r
.21982 .44198 .22801 .45014 .23992 .44869 .23186 .43921 Mtetra
.514 .652 .92 r
.23186 .43921 .23992 .44869 .25165 .45031 .24378 .43872 Mtetra
.427 .56 .885 r
.24378 .43872 .25165 .45031 .26337 .45317 .25559 .44051 Mtetra
.477 .563 .864 r
.25559 .44051 .26337 .45317 .2755 .45219 .26756 .44152 Mtetra
.633 .675 .873 r
.26756 .44152 .2755 .45219 .28814 .4451 .27998 .43791 Mtetra
.751 .789 .883 r
.27998 .43791 .28814 .4451 .30101 .43538 .29276 .43009 Mtetra
.778 .843 .901 r
.29276 .43009 .30101 .43538 .31381 .42686 .30562 .42149 Mtetra
.746 .84 .922 r
.30562 .42149 .31381 .42686 .32652 .42037 .31842 .41423 Mtetra
.707 .815 .932 r
.31842 .41423 .32652 .42037 .33919 .41511 .33118 .40831 Mtetra
.676 .79 .935 r
.33118 .40831 .33919 .41511 .3519 .41031 .34394 .40334 Mtetra
.663 .782 .937 r
.34394 .40334 .3519 .41031 .36465 .40568 .35673 .39872 Mtetra
.659 .783 .94 r
.35673 .39872 .36465 .40568 .37745 .40123 .36957 .3942 Mtetra
.663 .783 .938 r
.36957 .3942 .37745 .40123 .3903 .39687 .38248 .38953 Mtetra
.662 .775 .933 r
.38248 .38953 .3903 .39687 .40322 .39254 .39545 .38489 Mtetra
.668 .769 .926 r
.39545 .38489 .40322 .39254 .41621 .38796 .40849 .38007 Mtetra
.657 .76 .926 r
.40849 .38007 .41621 .38796 .42926 .38338 .42157 .37555 Mtetra
.656 .763 .928 r
.42157 .37555 .42926 .38338 .44236 .37914 .43472 .37104 Mtetra
.667 .76 .92 r
.43472 .37104 .44236 .37914 .45552 .37476 .44794 .36618 Mtetra
.724 .765 .885 r
.44794 .36618 .45552 .37476 .46878 .36883 .46127 .35906 Mtetra
.715 .736 .867 r
.46127 .35906 .46878 .36883 .48209 .36319 .47464 .35204 Mtetra
.667 .691 .863 r
.47464 .35204 .48209 .36319 .49545 .35824 .48803 .34685 Mtetra
.849 .739 .742 r
.48803 .34685 .49545 .35824 .50889 .35019 .50158 .32763 Mtetra
.316 .341 .729 r
.50158 .32763 .50889 .35019 .52235 .34937 .51499 .33682 Mtetra
.372 .517 .873 r
.51499 .33682 .52235 .34937 .53592 .34962 .52858 .34033 Mtetra
.612 .716 .919 r
.52858 .34033 .53592 .34962 .54956 .34524 .54227 .33705 Mtetra
.625 .752 .938 r
.54227 .33705 .54956 .34524 .56326 .33982 .55603 .33324 Mtetra
.575 .782 .977 r
.55603 .33324 .56326 .33982 .57705 .33616 .56988 .33029 Mtetra
.481 .765 .993 r
.56988 .33029 .57705 .33616 .59096 .33445 .58385 .32882 Mtetra
.461 .764 .995 r
.58385 .32882 .59096 .33445 .605 .33409 .59792 .32754 Mtetra
.563 .781 .981 r
.59792 .32754 .605 .33409 .61915 .33407 .61205 .32475 Mtetra
.707 .758 .892 r
.61205 .32475 .61915 .33407 .63332 .33102 .62614 .31799 Mtetra
.744 .699 .809 r
.62614 .31799 .63332 .33102 .64736 .32243 .64017 .30793 Mtetra
.735 .674 .791 r
.64017 .30793 .64736 .32243 .66131 .31075 .65421 .29773 Mtetra
.71 .687 .826 r
.65421 .29773 .66131 .31075 .67533 .30055 .66838 .28975 Mtetra
.683 .719 .877 r
.66838 .28975 .67533 .30055 .68953 .29323 .6827 .28366 Mtetra
.663 .741 .908 r
.6827 .28366 .68953 .29323 .70389 .28764 .69712 .27845 Mtetra
.658 .75 .918 r
.69712 .27845 .70389 .28764 .71834 .28259 .71163 .27343 Mtetra
.656 .751 .92 r
.71163 .27343 .71834 .28259 .73287 .27763 .72622 .26845 Mtetra
.656 .752 .92 r
.72622 .26845 .73287 .27763 .74748 .27266 .74088 .26343 Mtetra
.656 .751 .92 r
.74088 .26343 .74748 .27266 .76217 .26768 .75562 .2584 Mtetra
.656 .752 .92 r
.75562 .2584 .76217 .26768 .77693 .26266 .77043 .25333 Mtetra
.656 .751 .92 r
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46271 .13623 .47017 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Mtetra
.17527 .44635 .18368 .45394 .19568 .44985 .1873 .44221 Mtetra
.655 .751 .92 r
.1873 .44221 .19568 .44985 .20774 .44578 .19939 .43807 Mtetra
.652 .749 .921 r
.19939 .43807 .20774 .44578 .21982 .44198 .21153 .43401 Mtetra
.636 .738 .922 r
.21153 .43401 .21982 .44198 .23186 .43921 .22368 .43038 Mtetra
.59 .701 .92 r
.22368 .43038 .23186 .43921 .24378 .43872 .23578 .42802 Mtetra
.509 .622 .899 r
.23578 .42802 .24378 .43872 .25559 .44051 .24776 .42782 Mtetra
.467 .559 .866 r
.24776 .42782 .25559 .44051 .26756 .44152 .25972 .42901 Mtetra
.531 .595 .863 r
.25972 .42901 .26756 .44152 .27998 .43791 .2719 .42855 Mtetra
.663 .717 .889 r
.2719 .42855 .27998 .43791 .29276 .43009 .28448 .42393 Mtetra
.75 .819 .906 r
.28448 .42393 .29276 .43009 .30562 .42149 .29732 .41637 Mtetra
.757 .85 .92 r
.29732 .41637 .30562 .42149 .31842 .41423 .31021 .40867 Mtetra
.724 .835 .934 r
.31021 .40867 .31842 .41423 .33118 .40831 .32305 .40215 Mtetra
.698 .815 .937 r
.32305 .40215 .33118 .40831 .34394 .40334 .3359 .39642 Mtetra
.679 .79 .934 r
.3359 .39642 .34394 .40334 .35673 .39872 .34875 .39131 Mtetra
.668 .774 .929 r
.34875 .39131 .35673 .39872 .36957 .3942 .36165 .3865 Mtetra
.656 .764 .929 r
.36165 .3865 .36957 .3942 .38248 .38953 .37459 .38205 Mtetra
.657 .772 .934 r
.37459 .38205 .38248 .38953 .39545 .38489 .3876 .37753 Mtetra
.652 .775 .938 r
.3876 .37753 .39545 .38489 .40849 .38007 .40066 .37312 Mtetra
.664 .791 .942 r
.40066 .37312 .40849 .38007 .42157 .37555 .4138 .36829 Mtetra
.667 .784 .936 r
.4138 .36829 .42157 .37555 .43472 .37104 .427 .36338 Mtetra
.691 .781 .92 r
.427 .36338 .43472 .37104 .44794 .36618 .44029 .35767 Mtetra
.614 .734 .931 r
.44029 .35767 .44794 .36618 .46127 .35906 .45358 .35431 Mtetra
.35 .731 .986 r
.45358 .35431 .46127 .35906 .47464 .35204 .46688 .35417 Mtetra
.206 .723 .69 r
.46688 .35417 .47464 .35204 .48803 .34685 .48034 .35027 Mtetra
.715 .217 .054 r
.48034 .35027 .48803 .34685 .50158 .32763 .49371 .36347 Mtetra
.231 0 .266 r
.49371 .36347 .50158 .32763 .51499 .33682 .50747 .34559 Mtetra
0 0 0 r
.50747 .34559 .51499 .33682 .52858 .34033 .52117 .33671 Mtetra
.609 .886 .99 r
.52117 .33671 .52858 .34033 .54227 .33705 .53492 .33194 Mtetra
.6 .839 .989 r
.53492 .33194 .54227 .33705 .55603 .33324 .54874 .32795 Mtetra
.533 .807 .996 r
.54874 .32795 .55603 .33324 .56988 .33029 .56265 .32529 Mtetra
.535 .818 .998 r
.56265 .32529 .56988 .33029 .58385 .32882 .57665 .32242 Mtetra
.606 .804 .976 r
.57665 .32242 .58385 .32882 .59792 .32754 .59072 .31861 Mtetra
.703 .767 .902 r
.59072 .31861 .59792 .32754 .61205 .32475 .6048 .31207 Mtetra
.727 .699 .823 r
.6048 .31207 .61205 .32475 .62614 .31799 .61886 .30323 Mtetra
.721 .665 .795 r
.61886 .30323 .62614 .31799 .64017 .30793 .63295 .29384 Mtetra
.701 .667 .813 r
.63295 .29384 .64017 .30793 .65421 .29773 .64712 .28595 Mtetra
.683 .7 .859 r
.64712 .28595 .65421 .29773 .66838 .28975 .66141 .27964 Mtetra
.665 .73 .898 r
.66141 .27964 .66838 .28975 .6827 .28366 .67581 .2743 Mtetra
.659 .747 .915 r
.67581 .2743 .6827 .28366 .69712 .27845 .69029 .26922 Mtetra
.656 .75 .919 r
.69029 .26922 .69712 .27845 .71163 .27343 .70486 .26421 Mtetra
.656 .752 .92 r
.70486 .26421 .71163 .27343 .72622 .26845 .7195 .25916 Mtetra
.655 .751 .92 r
.7195 .25916 .72622 .26845 .74088 .26343 .73421 .25411 Mtetra
.656 .752 .92 r
.73421 .25411 .74088 .26343 .75562 .2584 .749 .24902 Mtetra
.656 .751 .92 r
.749 .24902 .75562 .2584 .77043 .25333 .76387 .24391 Mtetra
.656 .752 .92 r
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.656 .751 .92 r
.11908 .4552 .12769 .46271 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .43869 Mtetra
.16678 .43869 .17527 .44635 .1873 .44221 .17885 .43452 Mtetra
.17885 .43452 .1873 .44221 .19939 .43807 .19097 .43033 Mtetra
.655 .751 .92 r
.19097 .43033 .19939 .43807 .21153 .43401 .20315 .42614 Mtetra
.65 .747 .921 r
.20315 .42614 .21153 .43401 .22368 .43038 .21537 .42208 Mtetra
.632 .731 .919 r
.21537 .42208 .22368 .43038 .23578 .42802 .2276 .41851 Mtetra
.588 .686 .909 r
.2276 .41851 .23578 .42802 .24776 .42782 .23979 .4162 Mtetra
.527 .612 .881 r
.23979 .4162 .24776 .42782 .25972 .42901 .25189 .41569 Mtetra
.499 .566 .854 r
.25189 .41569 .25972 .42901 .2719 .42855 .264 .41614 Mtetra
.55 .609 .865 r
.264 .41614 .2719 .42855 .28448 .42393 .27633 .41508 Mtetra
.657 .731 .904 r
.27633 .41508 .28448 .42393 .29732 .41637 .28898 .41064 Mtetra
.737 .832 .924 r
.28898 .41064 .29732 .41637 .31021 .40867 .30187 .40362 Mtetra
.743 .854 .931 r
.30187 .40362 .31021 .40867 .32305 .40215 .31481 .39637 Mtetra
.713 .831 .938 r
.31481 .39637 .32305 .40215 .3359 .39642 .32773 .39015 Mtetra
.685 .812 .943 r
.32773 .39015 .3359 .39642 .34875 .39131 .34065 .38478 Mtetra
.674 .803 .944 r
.34065 .38478 .34875 .39131 .36165 .3865 .35361 .37971 Mtetra
.669 .795 .942 r
.35361 .37971 .36165 .3865 .37459 .38205 .36661 .37477 Mtetra
.667 .782 .935 r
.36661 .37477 .37459 .38205 .3876 .37753 .37968 .36988 Mtetra
.659 .771 .932 r
.37968 .36988 .3876 .37753 .40066 .37312 .39279 .36523 Mtetra
.658 .765 .928 r
.39279 .36523 .40066 .37312 .4138 .36829 .40596 .3606 Mtetra
.664 .773 .931 r
.40596 .3606 .4138 .36829 .427 .36338 .41921 .35575 Mtetra
.68 .781 .927 r
.41921 .35575 .427 .36338 .44029 .35767 .43253 .35039 Mtetra
.626 .775 .952 r
.43253 .35039 .44029 .35767 .45358 .35431 .44587 .34653 Mtetra
.573 .742 .956 r
.44587 .34653 .45358 .35431 .46688 .35417 .45926 .34402 Mtetra
.552 .669 .915 r
.45926 .34402 .46688 .35417 .48034 .35027 .47272 .34246 Mtetra
.026 .431 .867 r
.47272 .34246 .48034 .35027 .49371 .36347 .48618 .34831 Mtetra
.662 .628 .806 r
.48618 .34831 .49371 .36347 .50747 .34559 .49989 .3424 Mtetra
.778 .933 .933 r
.49989 .3424 .50747 .34559 .52117 .33671 .51367 .33318 Mtetra
.679 .91 .975 r
.51367 .33318 .52117 .33671 .53492 .33194 .52748 .32682 Mtetra
.644 .855 .98 r
.52748 .32682 .53492 .33194 .54874 .32795 .54136 .32182 Mtetra
.638 .823 .972 r
.54136 .32182 .54874 .32795 .56265 .32529 .5553 .3172 Mtetra
.674 .779 .929 r
.5553 .3172 .56265 .32529 .57665 .32242 .56931 .31176 Mtetra
.7 .727 .87 r
.56931 .31176 .57665 .32242 .59072 .31861 .58336 .30496 Mtetra
.707 .676 .817 r
.58336 .30496 .59072 .31861 .6048 .31207 .59744 .29689 Mtetra
.698 .65 .798 r
.59744 .29689 .6048 .31207 .61886 .30323 .61155 .28876 Mtetra
.687 .656 .813 r
.61155 .28876 .61886 .30323 .63295 .29384 .62574 .28153 Mtetra
.675 .687 .854 r
.62574 .28153 .63295 .29384 .64712 .28595 .64003 .27547 Mtetra
.665 .722 .891 r
.64003 .27547 .64712 .28595 .66141 .27964 .6544 .27009 Mtetra
.658 .743 .912 r
.6544 .27009 .66141 .27964 .67581 .2743 .66887 .265 Mtetra
.656 .749 .918 r
.66887 .265 .67581 .2743 .69029 .26922 .68341 .25994 Mtetra
.656 .751 .92 r
.68341 .25994 .69029 .26922 .70486 .26421 .69802 .25489 Mtetra
.69802 .25489 .70486 .26421 .7195 .25916 .71271 .2498 Mtetra
.71271 .2498 .7195 .25916 .73421 .25411 .72748 .2447 Mtetra
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Mtetra
.74232 .23956 .749 .24902 .76387 .24391 .75725 .2344 Mtetra
.75725 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .43869 .15823 .43097 Mtetra
.15823 .43097 .16678 .43869 .17885 .43452 .17032 .42676 Mtetra
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Mtetra
.18248 .42253 .19097 .43033 .20315 .42614 .19469 .41828 Mtetra
.655 .75 .92 r
.19469 .41828 .20315 .42614 .21537 .42208 .20696 .41405 Mtetra
.65 .746 .919 r
.20696 .41405 .21537 .42208 .2276 .41851 .21927 .40993 Mtetra
.634 .727 .915 r
.21927 .40993 .2276 .41851 .23979 .4162 .2316 .40626 Mtetra
.6 .683 .9 r
.2316 .40626 .23979 .4162 .25189 .41569 .24391 .4036 Mtetra
.553 .617 .87 r
.24391 .4036 .25189 .41569 .264 .41614 .25616 .40238 Mtetra
.526 .573 .846 r
.25616 .40238 .264 .41614 .27633 .41508 .26842 .40209 Mtetra
.548 .599 .857 r
.26842 .40209 .27633 .41508 .28898 .41064 .28083 .40108 Mtetra
.622 .704 .904 r
.28083 .40108 .28898 .41064 .30187 .40362 .2935 .39766 Mtetra
.702 .824 .94 r
.2935 .39766 .30187 .40362 .31481 .39637 .3064 .39175 Mtetra
.733 .869 .944 r
.3064 .39175 .31481 .39637 .32773 .39015 .31943 .38477 Mtetra
.72 .846 .942 r
.31943 .38477 .32773 .39015 .34065 .38478 .33246 .37823 Mtetra
.692 .808 .937 r
.33246 .37823 .34065 .38478 .35361 .37971 .3455 .37259 Mtetra
.669 .788 .938 r
.3455 .37259 .35361 .37971 .36661 .37477 .35855 .36764 Mtetra
.659 .786 .942 r
.35855 .36764 .36661 .37477 .37968 .36988 .37164 .36296 Mtetra
.655 .792 .948 r
.37164 .36296 .37968 .36988 .39279 .36523 .3848 .35834 Mtetra
.65 .793 .951 r
.3848 .35834 .39279 .36523 .40596 .3606 .39801 .35383 Mtetra
.651 .798 .953 r
.39801 .35383 .40596 .3606 .41921 .35575 .41129 .34925 Mtetra
.663 .81 .954 r
.41129 .34925 .41921 .35575 .43253 .35039 .42465 .34428 Mtetra
.655 .821 .963 r
.42465 .34428 .43253 .35039 .44587 .34653 .43807 .33945 Mtetra
.611 .779 .961 r
.43807 .33945 .44587 .34653 .45926 .34402 .45153 .33585 Mtetra
.525 .713 .958 r
.45153 .33585 .45926 .34402 .47272 .34246 .46502 .3344 Mtetra
.525 .718 .961 r
.46502 .3344 .47272 .34246 .48618 .34831 .47861 .3329 Mtetra
.658 .624 .805 r
.47861 .3329 .48618 .34831 .49989 .3424 .49233 .32711 Mtetra
.685 .639 .798 r
.49233 .32711 .49989 .3424 .51367 .33318 .50613 .31982 Mtetra
.668 .661 .833 r
.50613 .31982 .51367 .33318 .52748 .32682 .51997 .31393 Mtetra
.659 .665 .845 r
.51997 .31393 .52748 .32682 .54136 .32182 .53387 .30857 Mtetra
.666 .663 .838 r
.53387 .30857 .54136 .32182 .5553 .3172 .54784 .3028 Mtetra
.673 .649 .818 r
.54784 .3028 .5553 .3172 .56931 .31176 .56186 .2964 Mtetra
.675 .637 .804 r
.56186 .2964 .56931 .31176 .58336 .30496 .57593 .28959 Mtetra
.673 .636 .805 r
.57593 .28959 .58336 .30496 .59744 .29689 .59006 .28289 Mtetra
.67 .656 .827 r
.59006 .28289 .59744 .29689 .61155 .28876 .60426 .2767 Mtetra
.666 .689 .862 r
.60426 .2767 .61155 .28876 .62574 .28153 .61854 .27108 Mtetra
.661 .722 .894 r
.61854 .27108 .62574 .28153 .64003 .27547 .6329 .26583 Mtetra
.658 .741 .912 r
.6329 .26583 .64003 .27547 .6544 .27009 .64734 .26074 Mtetra
.656 .749 .918 r
.64734 .26074 .6544 .27009 .66887 .265 .66186 .25567 Mtetra
.656 .751 .92 r
.66186 .25567 .66887 .265 .68341 .25994 .67645 .25059 Mtetra
.67645 .25059 .68341 .25994 .69802 .25489 .69112 .24548 Mtetra
.69112 .24548 .69802 .25489 .71271 .2498 .70586 .24035 Mtetra
.70586 .24035 .71271 .2498 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75725 .2344 .75056 .22479 Mtetra
.75056 .22479 .75725 .2344 .77224 .22921 .76561 .21956 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Mtetra
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Mtetra
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Mtetra
.18616 .41038 .19469 .41828 .20696 .41405 .19846 .40607 Mtetra
.655 .75 .92 r
.19846 .40607 .20696 .41405 .21927 .40993 .21082 .40178 Mtetra
.651 .745 .919 r
.21082 .40178 .21927 .40993 .2316 .40626 .22323 .39756 Mtetra
.641 .729 .913 r
.22323 .39756 .2316 .40626 .24391 .4036 .23567 .39364 Mtetra
.618 .692 .896 r
.23567 .39364 .24391 .4036 .25616 .40238 .24812 .39039 Mtetra
.585 .636 .868 r
.24812 .39039 .25616 .40238 .26842 .40209 .26055 .38817 Mtetra
.557 .588 .841 r
.26055 .38817 .26842 .40209 .28083 .40108 .27298 .38689 Mtetra
.552 .582 .838 r
.27298 .38689 .28083 .40108 .2935 .39766 .28548 .38578 Mtetra
.58 .639 .873 r
.28548 .38578 .2935 .39766 .3064 .39175 .29814 .38365 Mtetra
.636 .75 .931 r
.29814 .38365 .3064 .39175 .31943 .38477 .311 .37971 Mtetra
.683 .851 .963 r
.311 .37971 .31943 .38477 .33246 .37823 .32403 .37416 Mtetra
.702 .885 .965 r
.32403 .37416 .33246 .37823 .3455 .37259 .33716 .36789 Mtetra
.702 .868 .96 r
.33716 .36789 .3455 .37259 .35855 .36764 .35033 .36171 Mtetra
.688 .83 .951 r
.35033 .36171 .35855 .36764 .37164 .36296 .36352 .35604 Mtetra
.674 .799 .942 r
.36352 .35604 .37164 .36296 .3848 .35834 .37675 .35084 Mtetra
.661 .78 .937 r
.37675 .35084 .3848 .35834 .39801 .35383 .39002 .34602 Mtetra
.648 .769 .937 r
.39002 .34602 .39801 .35383 .41129 .34925 .40334 .34156 Mtetra
.637 .77 .943 r
.40334 .34156 .41129 .34925 .42465 .34428 .41672 .33738 Mtetra
.616 .787 .963 r
.41672 .33738 .42465 .34428 .43807 .33945 .43015 .3336 Mtetra
.584 .809 .985 r
.43015 .3336 .43807 .33945 .45153 .33585 .44365 .33022 Mtetra
.609 .825 .983 r
.44365 .33022 .45153 .33585 .46502 .3344 .45725 .32622 Mtetra
.698 .78 .915 r
.45725 .32622 .46502 .3344 .47861 .3329 .47095 .31999 Mtetra
.716 .688 .821 r
.47095 .31999 .47861 .3329 .49233 .32711 .48474 .31172 Mtetra
.685 .639 .798 r
.48474 .31172 .49233 .32711 .50613 .31982 .49856 .30436 Mtetra
.655 .624 .807 r
.49856 .30436 .50613 .31982 .51997 .31393 .51242 .29865 Mtetra
.646 .623 .813 r
.51242 .29865 .51997 .31393 .53387 .30857 .52634 .29341 Mtetra
.648 .626 .815 r
.52634 .29341 .53387 .30857 .54784 .3028 .54033 .28808 Mtetra
.651 .635 .821 r
.54033 .28808 .54784 .3028 .56186 .2964 .55439 .28268 Mtetra
.655 .654 .836 r
.55439 .28268 .56186 .2964 .57593 .28959 .56851 .27724 Mtetra
.659 .68 .859 r
.56851 .27724 .57593 .28959 .59006 .28289 .5827 .27188 Mtetra
.659 .709 .884 r
.5827 .27188 .59006 .28289 .60426 .2767 .59697 .26666 Mtetra
.658 .731 .904 r
.59697 .26666 .60426 .2767 .61854 .27108 .61131 .26154 Mtetra
.657 .744 .914 r
.61131 .26154 .61854 .27108 .6329 .26583 .62573 .25646 Mtetra
.656 .749 .919 r
.62573 .25646 .6329 .26583 .64734 .26074 .64022 .25137 Mtetra
.656 .751 .92 r
.64022 .25137 .64734 .26074 .66186 .25567 .65479 .24627 Mtetra
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Mtetra
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21956 .75891 .20981 Mtetra
.0928 .43227 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40674 Mtetra
.16527 .40674 .17391 .41467 .18616 .41038 .17755 .40241 Mtetra
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Mtetra
.18988 .39806 .19846 .40607 .21082 .40178 .20228 .3937 Mtetra
.655 .75 .92 r
.20228 .3937 .21082 .40178 .22323 .39756 .21474 .38933 Mtetra
.653 .747 .918 r
.21474 .38933 .22323 .39756 .23567 .39364 .22725 .38499 Mtetra
.648 .735 .913 r
.22725 .38499 .23567 .39364 .24812 .39039 .2398 .38079 Mtetra
.636 .709 .9 r
.2398 .38079 .24812 .39039 .26055 .38817 .25239 .37694 Mtetra
.616 .666 .876 r
.25239 .37694 .26055 .38817 .27298 .38689 .265 .37367 Mtetra
.594 .62 .847 r
.265 .37367 .27298 .38689 .28548 .38578 .27762 .37106 Mtetra
.578 .589 .827 r
.27762 .37106 .28548 .38578 .29814 .38365 .29028 .36897 Mtetra
.576 .589 .829 r
.29028 .36897 .29814 .38365 .311 .37971 .30302 .36695 Mtetra
.59 .629 .858 r
.30302 .36695 .311 .37971 .32403 .37416 .31587 .36443 Mtetra
.618 .706 .908 r
.31587 .36443 .32403 .37416 .33716 .36789 .32886 .36101 Mtetra
.642 .791 .954 r
.32886 .36101 .33716 .36789 .35033 .36171 .34197 .35668 Mtetra
.651 .85 .976 r
.34197 .35668 .35033 .36171 .36352 .35604 .35518 .35176 Mtetra
.649 .872 .982 r
.35518 .35176 .36352 .35604 .37675 .35084 .36846 .34665 Mtetra
.643 .875 .984 r
.36846 .34665 .37675 .35084 .39002 .34602 .3818 .34159 Mtetra
.638 .867 .985 r
.3818 .34159 .39002 .34602 .40334 .34156 .39519 .33668 Mtetra
.639 .856 .982 r
.39519 .33668 .40334 .34156 .41672 .33738 .40865 .33187 Mtetra
.655 .843 .972 r
.40865 .33187 .41672 .33738 .43015 .3336 .42218 .3268 Mtetra
.689 .815 .943 r
.42218 .3268 .43015 .3336 .44365 .33022 .43579 .32093 Mtetra
.716 .758 .886 r
.43579 .32093 .44365 .33022 .45725 .32622 .4495 .31384 Mtetra
.714 .696 .832 r
.4495 .31384 .45725 .32622 .47095 .31999 .46327 .30588 Mtetra
.691 .66 .815 r
.46327 .30588 .47095 .31999 .48474 .31172 .47707 .29861 Mtetra
.672 .669 .838 r
.47707 .29861 .48474 .31172 .49856 .30436 .49091 .29256 Mtetra
.659 .688 .866 r
.49091 .29256 .49856 .30436 .51242 .29865 .5048 .28732 Mtetra
.654 .697 .877 r
.5048 .28732 .51242 .29865 .52634 .29341 .51876 .28232 Mtetra
.652 .702 .883 r
.51876 .28232 .52634 .29341 .54033 .28808 .53279 .27739 Mtetra
.654 .712 .891 r
.53279 .27739 .54033 .28808 .55439 .28268 .54689 .27243 Mtetra
.656 .725 .899 r
.54689 .27243 .55439 .28268 .56851 .27724 .56106 .26737 Mtetra
.657 .735 .907 r
.56106 .26737 .56851 .27724 .5827 .27188 .57531 .2623 Mtetra
.656 .743 .914 r
.57531 .2623 .5827 .27188 .59697 .26666 .58962 .25724 Mtetra
.656 .748 .918 r
.58962 .25724 .59697 .26666 .61131 .26154 .60402 .25216 Mtetra
.656 .75 .92 r
.60402 .25216 .61131 .26154 .62573 .25646 .61848 .24706 Mtetra
.656 .751 .92 r
.61848 .24706 .62573 .25646 .64022 .25137 .63303 .24193 Mtetra
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Mtetra
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19997 Mtetra
.08389 .42449 .0928 .43227 .10474 .42806 .09586 .42025 Mtetra
.09586 .42025 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40674 .15655 .39873 Mtetra
.15655 .39873 .16527 .40674 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Mtetra
.18123 .38998 .18988 .39806 .20228 .3937 .19366 .38558 Mtetra
.19366 .38558 .20228 .3937 .21474 .38933 .20615 .38115 Mtetra
.655 .751 .92 r
.20615 .38115 .21474 .38933 .22725 .38499 .21871 .37671 Mtetra
.655 .749 .919 r
.21871 .37671 .22725 .38499 .2398 .38079 .23132 .37226 Mtetra
.653 .743 .916 r
.23132 .37226 .2398 .38079 .25239 .37694 .24398 .36785 Mtetra
.648 .729 .908 r
.24398 .36785 .25239 .37694 .265 .37367 .2567 .36356 Mtetra
.639 .702 .892 r
.2567 .36356 .265 .37367 .27762 .37106 .26946 .35951 Mtetra
.628 .668 .87 r
.26946 .35951 .27762 .37106 .29028 .36897 .28227 .35574 Mtetra
.616 .633 .844 r
.28227 .35574 .29028 .36897 .30302 .36695 .29512 .35226 Mtetra
.608 .606 .824 r
.29512 .35226 .30302 .36695 .31587 .36443 .30803 .34895 Mtetra
.604 .594 .814 r
.30803 .34895 .31587 .36443 .32886 .36101 .32101 .34571 Mtetra
.608 .599 .817 r
.32101 .34571 .32886 .36101 .34197 .35668 .33407 .34233 Mtetra
.618 .619 .829 r
.33407 .34233 .34197 .35668 .35518 .35176 .34723 .33859 Mtetra
.632 .645 .845 r
.34723 .33859 .35518 .35176 .36846 .34665 .36048 .33439 Mtetra
.647 .669 .857 r
.36048 .33439 .36846 .34665 .3818 .34159 .37383 .32971 Mtetra
.66 .682 .86 r
.37383 .32971 .3818 .34159 .39519 .33668 .38726 .32454 Mtetra
.67 .682 .852 r
.38726 .32454 .39519 .33668 .40865 .33187 .40078 .31887 Mtetra
.676 .67 .836 r
.40078 .31887 .40865 .33187 .42218 .3268 .41437 .31272 Mtetra
.676 .653 .82 r
.41437 .31272 .42218 .3268 .43579 .32093 .42803 .30625 Mtetra
.672 .643 .813 r
.42803 .30625 .43579 .32093 .4495 .31384 .44174 .29981 Mtetra
.666 .651 .826 r
.44174 .29981 .4495 .31384 .46327 .30588 .45549 .29384 Mtetra
.666 .686 .86 r
.45549 .29384 .46327 .30588 .47707 .29861 .4693 .28829 Mtetra
.662 .722 .893 r
.4693 .28829 .47707 .29861 .49091 .29256 .48317 .2831 Mtetra
.66 .742 .911 r
.48317 .2831 .49091 .29256 .5048 .28732 .4971 .27802 Mtetra
.657 .747 .916 r
.4971 .27802 .5048 .28732 .51876 .28232 .51111 .27301 Mtetra
.654 .747 .918 r
.51111 .27301 .51876 .28232 .53279 .27739 .52518 .26807 Mtetra
.655 .748 .918 r
.52518 .26807 .53279 .27739 .54689 .27243 .53933 .26307 Mtetra
.656 .748 .918 r
.53933 .26307 .54689 .27243 .56106 .26737 .55355 .25801 Mtetra
.656 .75 .919 r
.55355 .25801 .56106 .26737 .57531 .2623 .56784 .25294 Mtetra
.656 .751 .92 r
.56784 .25294 .57531 .2623 .58962 .25724 .58221 .24785 Mtetra
.58221 .24785 .58962 .25724 .60402 .25216 .59665 .24272 Mtetra
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Mtetra
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Mtetra
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19997 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42025 .0869 .41236 Mtetra
.0869 .41236 .09586 .42025 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .1601 .38625 Mtetra
.1601 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Mtetra
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Mtetra
.19749 .37292 .20615 .38115 .21871 .37671 .21008 .36843 Mtetra
.21008 .36843 .21871 .37671 .23132 .37226 .22273 .36392 Mtetra
.22273 .36392 .23132 .37226 .24398 .36785 .23544 .35939 Mtetra
.655 .748 .918 r
.23544 .35939 .24398 .36785 .2567 .36356 .24821 .35486 Mtetra
.654 .743 .915 r
.24821 .35486 .2567 .36356 .26946 .35951 .26104 .35031 Mtetra
.652 .731 .907 r
.26104 .35031 .26946 .35951 .28227 .35574 .27393 .34583 Mtetra
.647 .713 .896 r
.27393 .34583 .28227 .35574 .29512 .35226 .28688 .34144 Mtetra
.642 .692 .882 r
.28688 .34144 .29512 .35226 .30803 .34895 .29988 .33715 Mtetra
.639 .672 .866 r
.29988 .33715 .30803 .34895 .32101 .34571 .31295 .33286 Mtetra
.636 .652 .849 r
.31295 .33286 .32101 .34571 .33407 .34233 .32609 .32854 Mtetra
.635 .637 .835 r
.32609 .32854 .33407 .34233 .34723 .33859 .3393 .32413 Mtetra
.636 .627 .825 r
.3393 .32413 .34723 .33859 .36048 .33439 .35259 .31958 Mtetra
.638 .624 .819 r
.35259 .31958 .36048 .33439 .37383 .32971 .36595 .31483 Mtetra
.642 .625 .818 r
.36595 .31483 .37383 .32971 .38726 .32454 .37939 .30989 Mtetra
.646 .631 .821 r
.37939 .30989 .38726 .32454 .40078 .31887 .3929 .30477 Mtetra
.65 .642 .829 r
.3929 .30477 .40078 .31887 .41437 .31272 .40648 .29955 Mtetra
.654 .66 .843 r
.40648 .29955 .41437 .31272 .42803 .30625 .42012 .29431 Mtetra
.657 .685 .864 r
.42012 .29431 .42803 .30625 .44174 .29981 .43383 .28911 Mtetra
.661 .713 .887 r
.43383 .28911 .44174 .29981 .45549 .29384 .44761 .28391 Mtetra
.659 .731 .902 r
.44761 .28391 .45549 .29384 .4693 .28829 .46145 .27882 Mtetra
.659 .743 .912 r
.46145 .27882 .4693 .28829 .48317 .2831 .47535 .27375 Mtetra
.655 .746 .916 r
.47535 .27375 .48317 .2831 .4971 .27802 .48933 .26877 Mtetra
.653 .749 .92 r
.48933 .26877 .4971 .27802 .51111 .27301 .50338 .26385 Mtetra
.655 .753 .922 r
.50338 .26385 .51111 .27301 .52518 .26807 .5175 .25883 Mtetra
.657 .753 .921 r
.5175 .25883 .52518 .26807 .53933 .26307 .5317 .25373 Mtetra
.656 .751 .92 r
.5317 .25373 .53933 .26307 .55355 .25801 .54597 .24863 Mtetra
.54597 .24863 .55355 .25801 .56784 .25294 .56031 .24351 Mtetra
.56031 .24351 .56784 .25294 .58221 .24785 .57473 .23837 Mtetra
.57473 .23837 .58221 .24785 .59665 .24272 .58922 .2332 Mtetra
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .1601 .38625 .15125 .37807 Mtetra
.15125 .37807 .1601 .38625 .1725 .38183 .16369 .3736 Mtetra
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Mtetra
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Mtetra
.656 .752 .92 r
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Mtetra
.656 .751 .92 r
.21406 .35553 .22273 .36392 .23544 .35939 .22681 .35095 Mtetra
.22681 .35095 .23544 .35939 .24821 .35486 .23962 .34636 Mtetra
.655 .75 .92 r
.23962 .34636 .24821 .35486 .26104 .35031 .25249 .34176 Mtetra
.656 .75 .919 r
.25249 .34176 .26104 .35031 .27393 .34583 .26543 .33712 Mtetra
.656 .747 .917 r
.26543 .33712 .27393 .34583 .28688 .34144 .27843 .33244 Mtetra
.656 .741 .913 r
.27843 .33244 .28688 .34144 .29988 .33715 .2915 .32774 Mtetra
.654 .731 .906 r
.2915 .32774 .29988 .33715 .31295 .33286 .30462 .32306 Mtetra
.652 .723 .901 r
.30462 .32306 .31295 .33286 .32609 .32854 .31782 .31841 Mtetra
.651 .716 .896 r
.31782 .31841 .32609 .32854 .3393 .32413 .33107 .31376 Mtetra
.651 .711 .892 r
.33107 .31376 .3393 .32413 .35259 .31958 .3444 .30905 Mtetra
.652 .709 .89 r
.3444 .30905 .35259 .31958 .36595 .31483 .35779 .30429 Mtetra
.653 .71 .889 r
.35779 .30429 .36595 .31483 .37939 .30989 .37126 .29945 Mtetra
.655 .714 .892 r
.37126 .29945 .37939 .30989 .3929 .30477 .38479 .29454 Mtetra
.657 .721 .896 r
.38479 .29454 .3929 .30477 .40648 .29955 .3984 .28956 Mtetra
.658 .728 .901 r
.3984 .28956 .40648 .29955 .42012 .29431 .41208 .28455 Mtetra
.658 .734 .906 r
.41208 .28455 .42012 .29431 .43383 .28911 .42582 .27952 Mtetra
.656 .739 .911 r
.42582 .27952 .43383 .28911 .44761 .28391 .43963 .27456 Mtetra
.656 .746 .916 r
.43963 .27456 .44761 .28391 .46145 .27882 .45351 .26958 Mtetra
.653 .749 .92 r
.45351 .26958 .46145 .27882 .47535 .27375 .46746 .26465 Mtetra
.655 .754 .923 r
.46746 .26465 .47535 .27375 .48933 .26877 .48148 .25965 Mtetra
.658 .756 .922 r
.48148 .25965 .48933 .26877 .50338 .26385 .49558 .25454 Mtetra
.658 .752 .92 r
.49558 .25454 .50338 .26385 .5175 .25883 .50975 .24939 Mtetra
.656 .75 .919 r
.50975 .24939 .5175 .25883 .5317 .25373 .52399 .24428 Mtetra
.655 .75 .92 r
.52399 .24428 .5317 .25373 .54597 .24863 .53831 .23916 Mtetra
.656 .751 .92 r
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20777 Mtetra
.62581 .20777 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Mtetra
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Mtetra
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Mtetra
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Mtetra
.656 .752 .92 r
.23095 .33781 .23962 .34636 .25249 .34176 .24386 .33313 Mtetra
.656 .751 .92 r
.24386 .33313 .25249 .34176 .26543 .33712 .25683 .32845 Mtetra
.655 .75 .92 r
.25683 .32845 .26543 .33712 .27843 .33244 .26987 .32377 Mtetra
.654 .751 .921 r
.26987 .32377 .27843 .33244 .2915 .32774 .28297 .31908 Mtetra
.656 .753 .921 r
.28297 .31908 .2915 .32774 .30462 .32306 .29614 .31432 Mtetra
.657 .752 .92 r
.29614 .31432 .30462 .32306 .31782 .31841 .30938 .30952 Mtetra
.657 .75 .918 r
.30938 .30952 .31782 .31841 .33107 .31376 .32269 .30467 Mtetra
.657 .746 .916 r
.32269 .30467 .33107 .31376 .3444 .30905 .33606 .29981 Mtetra
.656 .743 .914 r
.33606 .29981 .3444 .30905 .35779 .30429 .3495 .29493 Mtetra
.656 .741 .912 r
.3495 .29493 .35779 .30429 .37126 .29945 .363 .29004 Mtetra
.655 .741 .913 r
.363 .29004 .37126 .29945 .38479 .29454 .37658 .28515 Mtetra
.655 .742 .914 r
.37658 .28515 .38479 .29454 .3984 .28956 .39022 .28026 Mtetra
.654 .745 .917 r
.39022 .28026 .3984 .28956 .41208 .28455 .40393 .27535 Mtetra
.654 .749 .919 r
.40393 .27535 .41208 .28455 .42582 .27952 .41771 .27042 Mtetra
.656 .753 .922 r
.41771 .27042 .42582 .27952 .43963 .27456 .43157 .26543 Mtetra
.43157 .26543 .43963 .27456 .45351 .26958 .44549 .2604 Mtetra
.658 .754 .921 r
.44549 .2604 .45351 .26958 .46746 .26465 .45949 .25529 Mtetra
.658 .751 .919 r
.45949 .25529 .46746 .26465 .48148 .25965 .47357 .25014 Mtetra
.655 .747 .918 r
.47357 .25014 .48148 .25965 .49558 .25454 .48771 .24504 Mtetra
.654 .749 .919 r
.48771 .24504 .49558 .25454 .50975 .24939 .50192 .23996 Mtetra
.655 .752 .921 r
.50192 .23996 .50975 .24939 .52399 .24428 .51622 .23481 Mtetra
.656 .752 .921 r
.51622 .23481 .52399 .24428 .53831 .23916 .53058 .22961 Mtetra
.656 .751 .92 r
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Mtetra
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20777 .61838 .1979 Mtetra
.61838 .1979 .62581 .20777 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35237 Mtetra
.15841 .35237 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.656 .752 .92 r
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33852 Mtetra
.656 .751 .92 r
.19649 .33852 .20532 .34707 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Mtetra
.655 .751 .92 r
.22219 .32918 .23095 .33781 .24386 .33313 .23514 .32449 Mtetra
.656 .752 .921 r
.23514 .32449 .24386 .33313 .25683 .32845 .24815 .31976 Mtetra
.656 .752 .92 r
.24815 .31976 .25683 .32845 .26987 .32377 .26123 .31499 Mtetra
.657 .751 .919 r
.26123 .31499 .26987 .32377 .28297 .31908 .27438 .31018 Mtetra
.656 .749 .918 r
.27438 .31018 .28297 .31908 .29614 .31432 .28759 .30538 Mtetra
.655 .748 .919 r
.28759 .30538 .29614 .31432 .30938 .30952 .30086 .30057 Mtetra
.654 .749 .92 r
.30086 .30057 .30938 .30952 .32269 .30467 .3142 .29577 Mtetra
.655 .752 .921 r
.3142 .29577 .32269 .30467 .33606 .29981 .32761 .29093 Mtetra
.655 .754 .922 r
.32761 .29093 .33606 .29981 .3495 .29493 .34109 .28606 Mtetra
.656 .755 .923 r
.34109 .28606 .3495 .29493 .363 .29004 .35464 .28114 Mtetra
.656 .756 .923 r
.35464 .28114 .363 .29004 .37658 .28515 .36826 .27619 Mtetra
.657 .755 .923 r
.36826 .27619 .37658 .28515 .39022 .28026 .38195 .27119 Mtetra
.657 .754 .922 r
.38195 .27119 .39022 .28026 .40393 .27535 .39571 .26615 Mtetra
.657 .752 .92 r
.39571 .26615 .40393 .27535 .41771 .27042 .40954 .26108 Mtetra
.656 .749 .918 r
.40954 .26108 .41771 .27042 .43157 .26543 .42344 .25601 Mtetra
.42344 .25601 .43157 .26543 .44549 .2604 .43741 .25091 Mtetra
.654 .747 .918 r
.43741 .25091 .44549 .2604 .45949 .25529 .45145 .24585 Mtetra
.654 .75 .92 r
.45145 .24585 .45949 .25529 .47357 .25014 .46557 .24077 Mtetra
.656 .753 .922 r
.46557 .24077 .47357 .25014 .48771 .24504 .47976 .23562 Mtetra
.657 .754 .921 r
.47976 .23562 .48771 .24504 .50192 .23996 .49402 .23041 Mtetra
.656 .752 .92 r
.49402 .23041 .50192 .23996 .51622 .23481 .50836 .22518 Mtetra
.655 .751 .92 r
.50836 .22518 .51622 .23481 .53058 .22961 .52278 .21995 Mtetra
.656 .751 .92 r
.52278 .21995 .53058 .22961 .54502 .22439 .53727 .21469 Mtetra
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17154 Mtetra
.65601 .17154 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35237 .14939 .34387 Mtetra
.14939 .34387 .15841 .35237 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33852 .18758 .32991 Mtetra
.18758 .32991 .19649 .33852 .20931 .33387 .20044 .32521 Mtetra
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Mtetra
.656 .752 .92 r
.21336 .32048 .22219 .32918 .23514 .32449 .22635 .31572 Mtetra
.656 .751 .92 r
.22635 .31572 .23514 .32449 .24815 .31976 .2394 .31095 Mtetra
.655 .751 .92 r
.2394 .31095 .24815 .31976 .26123 .31499 .25251 .30617 Mtetra
.655 .751 .921 r
.25251 .30617 .26123 .31499 .27438 .31018 .26569 .30139 Mtetra
.656 .754 .922 r
.26569 .30139 .27438 .31018 .28759 .30538 .27894 .29654 Mtetra
.27894 .29654 .28759 .30538 .30086 .30057 .29226 .29165 Mtetra
.657 .753 .921 r
.29226 .29165 .30086 .30057 .3142 .29577 .30565 .28671 Mtetra
.657 .751 .919 r
.30565 .28671 .3142 .29577 .32761 .29093 .3191 .28176 Mtetra
.656 .749 .918 r
.3191 .28176 .32761 .29093 .34109 .28606 .33263 .27679 Mtetra
.656 .748 .917 r
.33263 .27679 .34109 .28606 .35464 .28114 .34622 .27182 Mtetra
.656 .747 .917 r
.34622 .27182 .35464 .28114 .36826 .27619 .35988 .26682 Mtetra
.655 .747 .918 r
.35988 .26682 .36826 .27619 .38195 .27119 .37361 .26182 Mtetra
.655 .748 .919 r
.37361 .26182 .38195 .27119 .39571 .26615 .38741 .25681 Mtetra
.655 .75 .92 r
.38741 .25681 .39571 .26615 .40954 .26108 .40128 .25178 Mtetra
.655 .752 .921 r
.40128 .25178 .40954 .26108 .42344 .25601 .41522 .2467 Mtetra
.655 .753 .922 r
.41522 .2467 .42344 .25601 .43741 .25091 .42924 .2416 Mtetra
.657 .755 .922 r
.42924 .2416 .43741 .25091 .45145 .24585 .44333 .23643 Mtetra
.657 .754 .921 r
.44333 .23643 .45145 .24585 .46557 .24077 .45749 .2312 Mtetra
.656 .751 .92 r
.45749 .2312 .46557 .24077 .47976 .23562 .47173 .22598 Mtetra
.655 .75 .919 r
.47173 .22598 .47976 .23562 .49402 .23041 .48605 .22076 Mtetra
.655 .751 .92 r
.48605 .22076 .49402 .23041 .50836 .22518 .50043 .21551 Mtetra
.656 .752 .921 r
.50043 .21551 .50836 .22518 .52278 .21995 .5149 .21022 Mtetra
.656 .752 .92 r
.5149 .21022 .52278 .21995 .53727 .21469 .52944 .2049 Mtetra
.656 .751 .92 r
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17154 .6486 .16132 Mtetra
.6486 .16132 .65601 .17154 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.656 .752 .92 r
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Mtetra
.656 .751 .92 r
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Mtetra
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .31169 Mtetra
.655 .751 .92 r
.20445 .31169 .21336 .32048 .22635 .31572 .21747 .30691 Mtetra
.656 .752 .921 r
.21747 .30691 .22635 .31572 .2394 .31095 .23056 .3021 Mtetra
.656 .752 .92 r
.23056 .3021 .2394 .31095 .25251 .30617 .24372 .29724 Mtetra
.657 .751 .92 r
.24372 .29724 .25251 .30617 .26569 .30139 .25694 .29234 Mtetra
.656 .749 .919 r
.25694 .29234 .26569 .30139 .27894 .29654 .27023 .28745 Mtetra
.655 .749 .919 r
.27023 .28745 .27894 .29654 .29226 .29165 .28359 .28255 Mtetra
.654 .75 .92 r
.28359 .28255 .29226 .29165 .30565 .28671 .29701 .27765 Mtetra
.655 .752 .921 r
.29701 .27765 .30565 .28671 .3191 .28176 .3105 .27272 Mtetra
.655 .754 .922 r
.3105 .27272 .3191 .28176 .33263 .27679 .32406 .26775 Mtetra
.656 .755 .923 r
.32406 .26775 .33263 .27679 .34622 .27182 .33769 .26274 Mtetra
.656 .756 .923 r
.33769 .26274 .34622 .27182 .35988 .26682 .3514 .25769 Mtetra
.3514 .25769 .35988 .26682 .37361 .26182 .36517 .25261 Mtetra
.657 .755 .922 r
.36517 .25261 .37361 .26182 .38741 .25681 .37902 .24748 Mtetra
.657 .753 .921 r
.37902 .24748 .38741 .25681 .40128 .25178 .39294 .24233 Mtetra
.656 .751 .92 r
.39294 .24233 .40128 .25178 .41522 .2467 .40693 .23716 Mtetra
.657 .75 .919 r
.40693 .23716 .41522 .2467 .42924 .2416 .42099 .23196 Mtetra
.655 .748 .918 r
.42099 .23196 .42924 .2416 .44333 .23643 .43513 .22678 Mtetra
.654 .749 .919 r
.43513 .22678 .44333 .23643 .45749 .2312 .44934 .22159 Mtetra
.655 .752 .921 r
.44934 .22159 .45749 .2312 .47173 .22598 .46363 .21634 Mtetra
.656 .753 .921 r
.46363 .21634 .47173 .22598 .48605 .22076 .47799 .21104 Mtetra
.656 .752 .92 r
.47799 .21104 .48605 .22076 .50043 .21551 .49243 .20571 Mtetra
.656 .751 .92 r
.49243 .20571 .50043 .21551 .5149 .21022 .50694 .20037 Mtetra
.50694 .20037 .5149 .21022 .52944 .2049 .52153 .19501 Mtetra
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Mtetra
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Mtetra
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Mtetra
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Mtetra
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .31719 Mtetra
.15666 .31719 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.18245 .30764 .19149 .31646 .20445 .31169 .19545 .30283 Mtetra
.656 .752 .92 r
.19545 .30283 .20445 .31169 .21747 .30691 .20851 .29798 Mtetra
.656 .751 .92 r
.20851 .29798 .21747 .30691 .23056 .3021 .22164 .29312 Mtetra
.655 .751 .92 r
.22164 .29312 .23056 .3021 .24372 .29724 .23483 .28824 Mtetra
.655 .751 .921 r
.23483 .28824 .24372 .29724 .25694 .29234 .24809 .28337 Mtetra
.656 .753 .922 r
.24809 .28337 .25694 .29234 .27023 .28745 .26142 .27844 Mtetra
.656 .754 .922 r
.26142 .27844 .27023 .28745 .28359 .28255 .27482 .27346 Mtetra
.657 .753 .921 r
.27482 .27346 .28359 .28255 .29701 .27765 .28829 .26843 Mtetra
.657 .751 .919 r
.28829 .26843 .29701 .27765 .3105 .27272 .30183 .26338 Mtetra
.657 .749 .918 r
.30183 .26338 .3105 .27272 .32406 .26775 .31543 .25832 Mtetra
.656 .748 .917 r
.31543 .25832 .32406 .26775 .33769 .26274 .32911 .25324 Mtetra
.656 .747 .917 r
.32911 .25324 .33769 .26274 .3514 .25769 .34286 .24815 Mtetra
.655 .747 .918 r
.34286 .24815 .3514 .25769 .36517 .25261 .35667 .24305 Mtetra
.655 .748 .918 r
.35667 .24305 .36517 .25261 .37902 .24748 .37056 .23793 Mtetra
.655 .749 .919 r
.37056 .23793 .37902 .24748 .39294 .24233 .38452 .2328 Mtetra
.655 .751 .92 r
.38452 .2328 .39294 .24233 .40693 .23716 .39856 .22763 Mtetra
.655 .752 .921 r
.39856 .22763 .40693 .23716 .42099 .23196 .41267 .22243 Mtetra
.656 .754 .922 r
.41267 .22243 .42099 .23196 .43513 .22678 .42685 .21716 Mtetra
.657 .753 .921 r
.42685 .21716 .43513 .22678 .44934 .22159 .44111 .21185 Mtetra
.656 .751 .92 r
.44111 .21185 .44934 .22159 .46363 .21634 .45544 .20653 Mtetra
.656 .75 .92 r
.45544 .20653 .46363 .21634 .47799 .21104 .46985 .2012 Mtetra
.656 .751 .92 r
.46985 .2012 .47799 .21104 .49243 .20571 .48434 .19584 Mtetra
.656 .752 .92 r
.48434 .19584 .49243 .20571 .50694 .20037 .4989 .19044 Mtetra
.656 .751 .92 r
.4989 .19044 .50694 .20037 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Mtetra
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo0`2W_n/l0:O0j`030000002W`>/0Yl3[00`0Yl3[4P3o
ool00`000000oooo0?ooo`0^0?ooo`007@3oool2000000X0oooo0P00000B0?ooo`@00000C03oool6
0:Nojc/0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000k0?oo
o`800000C03oool50:O0j`D0Yko[>`2W`>/00`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?oo
o`3oool0;@3oool003P0oooo0`00001<0?ooo`<0Z<3[A@2W`>/00`000000Yl3[0:O0j`0=0:O0ja40
oooo0P00000^0?ooo`00=@3oool3000004d0oooo1P2X`>]40:O0j`030000002W`>/0Yl3[00h0Yl3[
4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3oool2000004d0oooo1@2W`N`40:S0j`P0Yl3[0`2W
_n/i0:O0j`030000002W`>/0Yl3[00l0Yl3[4@3oool00`000000oooo0?ooo`0[0?ooo`00<03oool3
000004/0oooo1@2W`>/50:O1k0@0Yko[1@2W`>/60:NojcP0Yl3[00<000000:O0j`2W`>/0402W`>/A
0?ooo`030000003oool0oooo02X0oooo000^0?ooo`<00000B`3oool80:O0j`T0Yko[1@2W`>/50:No
jcP0Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0oooo02X0oooo000[0?ooo`<0
00000`3oool00`000000oooo0?ooo`160?ooo`P0Yl3[0`2X_n/70:Noj`80Z<7[1@2W`>/50:S1jcL0
Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo02T0oooo000Y0?ooo`800000
B`3oool50:Noj`D0Yl3[1P2X_n/40:Noj`D0Z<7[0`2W`>/20:O0k0D0Z<7[=P2W`>/00`000000Yl3[
0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00001:0?ooo`T0Yko[1@2W
`>/50:Roj`D0Z<7/1@2X`N/50:O0k0@0Z<7[202W`>/30:Nojb/0Yl3[00<000000:O0j`2W`>/04P2W
`>/A0?ooo`030000003oool0oooo02P0oooo000T0?ooo`800000B`3oool:0:Noj`80Z<3[1@2W`>/5
0:O0k0D0Z<7/1@2W_n/50:O0k0@0Yko[1@2W`>/60:NojbT0Yl3[0P00000E0:O0ja00oooo0P00000Y
0?ooo`008@3oool3000004/0oooo2P2W_n/50:S0j`D0Yl3[1@2W`>`20:S1k1/0Yko[9P2W`>/30000
0080Yl3[00<000000:O0j`2W`>/04P2W`>/B0?ooo`030000003oool0oooo02H0oooo000O0?ooo`<0
0000B@3oool50:NojPD0Yko[1@2X`N`40:S0j`H0Yl3[102W`>`80:Noj`<0Z<3[1`2W_n/20:S0j`D0
Yko[502W`>/50:Noj`h0Yl3[0`0000050:O0j`030000002W`>/0Yl3[01<0Yl3[4@3oool00`000000
oooo0?ooo`0V0?ooo`007@3oool2000004/0oooo1`2W_nX50:O1k0D0Z<7/1@2W_n/40:O0j`X0Yko[
1P2X`>/40:Noj`D0Z<3[0`2W_n/20:S0j`D0Yl3[1@2W_n/50:O0j`h0Yko[1P2W`>/3000000T0Yl3[
00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`800000
0`3oool4000000X0oooo000E0?ooo`D000000`3oool2000004T0oooo1`2W_nX80:O1k1<0Yko[1@2X
`N/50:S0j`D0Z<7/2P2X`>/20:O0j`P0Yko[0P2W`>/30:Nnj@D0Yko[102X_^T70:Noj`<000003@2W
`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`00
00140?ooo`D0Z;o[102W_nX80:O1k0X0Yko[0`2X`>/50:Noj`@0Yl3/1@2X`N/50:O1k0D0Z<7/1@2W
`>`40:S0j`X0Yko[1P2W_^T20:Noj`<0Z;_W102X_^T20:Noj`80Z;gY0P0000090:Noj`P0Yl3[00<0
00000:O0j`2W`>/04`2W`>/@0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0:0?ooo`005`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000003l0oooo1@2X`>/50:Roj`T0Yl7/2P2W_n/60:S0j`80Yko[1`2W`>`20:S1j`<0Yko[
1@2W`N`50:Noj`D0Yl3/2@2W_n/50:Rlj0D0YkkY1P2X^nL30:Rnj@040:Rmj@000000000000000080
Z;gY0P2W_n/30:Rnj@X0Yko[0P2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?ooo`3o
ool00`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`090?oo
o`003`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03/0oooo1`2X`>/:0:O1k0D0YkoZ102W_n/50:S1k0D0Z<3[2@2W`>`60:Noj`80
Yl7/0`2W_^X>0:Noj`D0YkWV1@2X_>P50:RehPD0Z;_W00@0ZKST00000000000000001@2X_NT60:Rn
j@80Yko[0`2X_nX40:Noj`<0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000:0?ooo`005`3oool0
0`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0h0?ooo`P0Z<3[0P2W`>/5
0:O1k0X0YkoZ2@2X`N`50:Noj`D0Yl3/1@2W_^X40:Noj`H0YkkZ0P2W_n/30:RojPL0Yko[0P2W]^@5
0:NiiP80Z;cX0`2X[]/50:RehP80Z[3L0`0000040:Vhi0D0Z[ST1@2X_^T60:RojP<0Yko[102W`>/0
0`000000Yl3[0:O0j`0B0:O0ja00oooo0P00000;0?ooo`8000002P3oool2000000/0oooo000F0?oo
o`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0oooo1@2W`N`50:S0
j`D0Yl3[0P2W`N`30:Noj`L0YkoZ0`2W`N`50:S1k0@0YkkZ1@2W_n/50:Nmj@D0YkkZ102X_^T50:Nn
jPH0Z;oZ102W_n/50:Nfi0@0YkWV1P2X[]/20:RehP040:^Wd`0000000000000000<0Z[3L0P2Y^>@3
0:b_fPD0Z[ST1@2Z^^D50:RojP@0Z;o[102W`>/00`000000Yl3[0:O0j`0B0:O0ja40oooo00<00000
0?ooo`3oool08@3oool001`0oooo00<000000?ooo`3oool01@3oool200000300oooo102W`>`50:O1
k0D0Yko[102W`>/60:Noj`@0YkoZ1P2W`N`20:S1k0<0YkgY102W_^X20:Noj`<0Z;_W1@2W_NT50:Rk
iP@0Z;kY1@2X_NT50:RojPD0Y[?R102W]^@50:NWePD0Z:kK0`0000020:^Wd`@0Z[3L1P2/[mX20:Zh
i0<0[[?K1@2Z^^D50:Vmj0@0Z;o[0`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40oooo00<000000?oo
o`3oool0803oool001`0oooo0P0000080?ooo`030000003oool0oooo02/0oooo0`2W`>/40:O0k0X0
Yko[1@2X`>/40:Noj`X0Yl7/1P2W_NT30:NnjPH0Z;_W0P2W_NT30:Vfh`D0Z;_V0P2X_^T20:Vhi0D0
Z;gY1@2W/^050:JchP@0YZ;B1@2WYmH01@2X[]/00000000000000000[:;>00D0ZjOC0P2Z/=`20:nW
d0D0[:oJ1P2^/m/20:Zji@<0[[SP102Y_NP50:RojP<0Yl3[00<000000:O0j`2W`>/04P2W`>/A0?oo
o`030000003oool0oooo0200oooo000L0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0:03oool60:O0j`80Yl3/1`2W_n/:0:S0j`T0Yl7/2P2W_NT40:RjiPD0Z;_W1P2Y]^<40:RkiPD0
ZKST0P2X_NT30:R`g@D0Yk;P0P2V/n830:FPd0<0YZ;B0`2WYmH3000000@0[:;>1@2[Ym<50:nWd080
[:oJ0`2cZ]050:jcf`H0[[SP0P2Y_NP20:bli@D0Z;oZ0`2X`>/00`000000Z<3[0:O0j`0B0:O0ja40
oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0S0?ooo`X0Yl3[202W_n/20:O1k0L0Z<3[0`2W`>/50:O1k0T0YkgY1@2X^>D40:RjiPD0Z:oM
1@2Y]^<50:Z_g0@0ZKST1P2X/=d40:Nbh0D0YJ3@0`2VX]83000000<0[:?=1@2/X/h20:^Wd`<0/ZK<
102_Ym060;>Zd080[[?K0`2e[m<50:jhh0D0[;cU0P2X_nX30:Voj@<0Z<3[00<000000:S0j`2W`>/0
4P2W`>/A0?ooo`030000003oool0oooo01h0oooo000K0?ooo`800000303oool00`000000oooo0?oo
o`0O0?ooo`T0Yl3[1@2X`>/50:Noj`D0Yl7/102X`>/60:O0j`80Yl7/0`2W_^T60:Nmj@<0YkKT1@2X
^>D20:RjiP80YjSG1@2X[md20:Vfh`<0ZZKC1@2Z[m`40:b[ePD0Z;3M1@2UWm050:FPd080000000<0
YZ;B0:bSc@2/Xld00`2/Xld50:bRcPD0/ZK<0`2_Ym020;RZb`D0/j[@1P2e[m<20:jhh0<0];KJ102/
_>D60:Voj@80Z<3[00<000000:S0j`2W`>/04`2W`>/@0?ooo`030000003oool0oooo01h0oooo000K
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool?0:O0j`@0Z<3[2P2W`N`4
0:Noj`D0Yl3[1P2W_^T30:Nmj@H0YkKT102X^>D50:NXe`@0Z:oM1P2ZY]<20:Z_g0<0/:S@102/ZmH2
0:R`g@<0Yio>102UWm020:FPd0<00000102/Y]450:bSc@80[:;>0`2d[M450;:Vc0040:nWd02hZ//0
^:[;0;RZb`@0/j[@0P2l[<X50;F_d`D0];KJ1@2`_N<50:Voj@<0Z<3[00<000000:S0j`2W`>/04P2W
`>/A0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0603ooolF0:O0j`@0Yl7/2@2W_n/50:RnjPD0YkkY1@2W]N<40:Nfi0D0YZCD1@2WZ=L4
0:bTd0D0ZZKC1@2`Z=040:b[ePD0Yio>0`2UWm03000000040:FPd02ZZMH0ZZWF0:ZYeP<0[:KA1@2/
Xld50;B]d@D0/ZK<1@2hZ//20;>Zd0<0_:c:102e[m<20;f`c@<0];KJ0P2l]mD50;2mh`D0ZkoY0`2X
`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo0P00000O0?ooo`006`3oool2000000l0oooo00<00000
0?ooo`3oool05@3ooolI0:O0j`T0Yko[1@2X_n/40:RnjPD0Y[GS1@2W]N<40:FQdPD0YZCD0P2WZ=L3
0:fWd@@0[:C@0P2ZY]<30;Jbe0D0/:S@0P2/ZmH20:nSc0@0Yio>0`0000020:FOd0D0ZZWF102/Y]42
0:bSc@<0/k[N1@2d[M420;:Vc0<0^[;B102hZ//60;b/bP80]JoC102m/<d00`2d]]X0_;OE0;bge@02
0;bge@80/;gS0`2e_^440:^oj@<0Z<3[00<000000:S0j`2W`>/04P2W`>/A0?ooo`030000003oool0
oooo01`0oooo000K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3ooolJ0:O0
j`<0Z<3[102W_n/50:S0j`D0Z;o[102V]^@50:Jeh`80YkGS0`2TWm430:FQdPD0YZCD1@2]Ym440:bT
d0D0][;D1@2`Z=040:nSc0050:NOcP00000000000000002WWlh01@2XZ]P50:ZYeP<0[:KA1@2c^]h5
0;B]d@H0^[;B0P2hZ//20;jbc`D0_:c:1P2m/<d50;bge@H0]KkQ0P2[_nT20:g1j0<0Z<3[00<00000
0:S0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo01/0oooo00080?ooo`800000103oool20000
00@0oooo0P0000040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303ooolL0:O0
j`H0Z<3[0P2W_n/20:O0j`D0Z<3[0P2X_n/30:Jgi@@0Y[KT102V]N<50:BOd@@0YJ7B0P2VY=@30:f[
ePD0[JOA0P2/Y=020;O2hPD0][;D0P2`Z=030;N`dP040:nSc0000000000000000080Yio>0`2[ZMD5
0:RZf0@0ZZWF102/and50;>jgP80]:gA0`2ca>H50;ZbdP@0_[;?102l[<X20<:`b@@0_K3=0P35//P3
0;bge@80a;[@1@2e_^450:g1j0<0Z<3[00<000000:S0j`2W`>/04P2W`>/@0?ooo`030000003oool0
oooo01/0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3o
ool2000001<0oooo00<000000?ooo`3oool02P3ooolN0:O0j`D0Z<3[1@2W`>/40:S0j`H0Y[OU0`2V
]^@50:>Od@D0Y9oA0`2UXM850:f[ePD0[JOA102g`^850;Jbe0<0]k3B0`0000030:nSc0D0ZjWE1@2X
Z]P50:?Bn0@0[<O]102c^]h60;?4iP80^[;B0`2d`^@40;jbc`80_:c:1032/<T20;f`c@<0aK;80P2l
]mD40<Bjd080]KkQ0`2j`Ml40:g1j0@0Z<3[00<000000:S0j`2W`>/04@2W`>/A0?ooo`030000003o
ool0oooo01X0oooo00070?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo
0000000E0?ooo`030000003oool0oooo00L0oooo:`2W`>/40:JiiPD0Y[OU102RX=<40:>Od@D0Y9oA
102[[]X50:f[eP80[JOA0`2`d?440;O2hP80][;D0P2banX3000000<0]k3B102_Xl`50:^Ye@80Z:[H
0`2Tf_X50:?Bn0<0[<O]1@2KcOT50;?4iPD0]<;T102n//l60<:`b@D0aK;81P34^]050;[1g`D0[/;X
0`2X`>/00`000000Z<3[0:O0j`0B0:O0ja40oooo00<000000?ooo`3oool06@3oool000030?ooo`00
00000000008000000P3oool010000000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0080oooo8P2W`>/50:Noj`@0Yl3[1@2W^nL40:JiiPD0XZ?E
102RX=<40:>Od@80Y9oA0`2X[]`40:^^fP@0[J_F1P2`d?430;O2hP040;;7jP000000000000000080
//OZ102g/=850:nSc0@0ZjWE1P2Tf_X508S>oP@0R=7o102KcOT50937n`@0]<;T0P2n//l30;bjf0@0
`[390P34]<X40<Fbb0030<^da@34^]00a;[@0080a;[@0P3;_Ld30;[1g`80_/CO1@2^`^P30:S0j`03
0000002X`>/0Yl3[0180Yl3[403oool00`000000oooo0?ooo`0I0?ooo`001`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00<0oooo0P00000F0?ooo`030000002W`>/0Yl3[02@0
Yl3[1@2W_n/40:Nmj@D0Yk_W102RY]T40::Se@D0XZ3C0`2SWm460:R^g0<0ZjkJ1@2WeoP50;3@l@80
Vm?k0P0000050;;7jPD0Z9o>1@2_Xl`20:^Ye@<0[NSi1@2Ie_d508S>oP@0Nl?n101f`oh50937n`<0
]<;T1P2l^]P20<:`b@<0a;C:0`35//P30<^da@80a;[@103;_Ld50;k4g`D0[/?Y0`2X`>/00`000000
Yl3[0:O0j`0A0:O0ja00oooo0P00000J0?ooo`00203oool2000000X0oooo0`0000030?ooo`030000
003oool0oooo0180oooo:`2W`>/20:Noj`<0YkoZ102W_NT20:Nki`<0XjcM0`2RY]T50::Se@@0XZ3C
102UZm/50:R^g0D0Xm_k102WeoP309G?o0<000000`2Kdo/508JgmP@0Z9o>1@2_Xl`20:gXn@@0Vn;m
1@2Ie_d509?8nP@0Nl?n101f`oh40937n`@0U/?f1@2l^]P60<BdbP030<Fbb03;]<D0bkC50080bkC5
1@3;_Ld20=71b`<0_/CO0P32b=l50:k3j@<0Z<3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`030000
003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo0180oooo;02W`>/60:NojP<0YkgY1@2S
[=d40::Vf@@0XZ?E1@2QYMP40:F[f`80Z:kL0`2SgO`50:?Kn`<0WLWf0`00000409c7mP@0Q[Ke0`26
]oH50:ROcP80[j?<0`37k^h2000000@0Vn;m1P2O`?0409c:n0@0Q<7k1@1]^O`306Jgo0@0U/?f0P2l
^]P30:jli0D0a;C:1@3;]<D0103@]l80bkg=0<^mc@3;_Ld30=71b`80_/CO1032b=l50:k3j@80Z<3[
00<000000:S0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01L0oooo000I0?ooo`8000004@3o
ool[0:O0j`@0Yko[1@2W_nX40:Bah@D0XjcM0`2RY]T509jNe0D0XJGH0`2UZm/60:?Mo0@0XlGa0`00
00030:OBmPD0W<Of1026]_D308JgmP@0Z9o>1037k^h0101@EkX0GhCO05n4g`1OQ=l409bgj`<0Wl3`
0`2]b>h409c:n0@0Q<7k1@1f^?X3052Yn@<0U/?f1@2^_>@40<BdbP80`kG<0`3;]<D30=2g`P030<^m
c@3A`L/0dL7;0080dL7;1P32b=l50:k3j@<0Z<3[00<000000:S0j`2W`>/04P2W`>/@0?ooo`030000
003oool0oooo01H0oooo000I0?ooo`030000003oool0oooo00d0oooo:P2W`>/90:Noj`D0YKKU102T
/N440:>/g@@0ViWA1@2NW]@40:6Uf0D0Y=ok1@2Ua>l3000000<0ZLod102Wd_H509:mm0@0SJ_Z00@0
1VkM08JgmP2XWlh0Z9o>102YX<h4051G^P<0GhCO102L]n/60:g8kP@0W<ci1@2<__L407JhnP<0D:Wi
0`1U/?X50:jli080a;C:1033]L`00`3;]<D0d;O20=2g`P020=2g`PD0dL7;00@0f<K90<;8g`32b=l0
`/SO0`33b]l40:k3j@@0Z<3[00<000000:S0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo01D0
oooo000I0?ooo`030000003oool0oooo00T0oooo<02W`>/40:Noj`@0Y[_X1@2U]^D40:Bah@@0VYS@
102KVM4409jNe0H0Y]ok1@2Yanl3000000030:G4k`2Yco@0ZLod00@0ZLod102Pa_<509:mm0@0SJ_Z
00<01VkM0:VPcP2YX<h0102YX<h4051G^P<0GhCO1@2U]><30:g8kP<0/n;g102Lc?T509Bhl0@0PKcj
0P13X_H406F`nP@0[[cT1P33]L`50=2g`P040=Fi_P3A`L/0dL7;0=71b`<0f<K91P33b]l40:k3j@@0
Z<3[00<000000:O0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo01D0oooo000I0?ooo`800000
1`3ooold0:O0j`@0YkkZ102V^nP40:Ffi@D0Vi_B0`2JV=0509^Id@80WYkD0P2VfOT30:KOn`<0[<ca
00D0ZLO_00000000000000000:W7k`040:K<l`<0ZLod0`2^and40:36l`@0T[gd0P0d^K030:Z`g003
00I^g@2YX<h0ZJ3>0080ZJ3>0P2h/=8408f<c@<0Q8kE1@2U]><60;?Rm`@0UkK]1@2D^?03086lnP@0
@j;f0`0aT_0409>ck@@0`kG<0P30/ld30=2g`P<0eKVn00<0dL7;0=S6b@3Ha/T00P3Ha/T0103Mc<P0
`l[O0<?:g`33b]l30<C<h@@0[/?Y0`2X`>/00`000000Z<3[0:O0j`0B0:O0ja00oooo00<000000?oo
o`3oool0503oool001T0oooo00<000000?ooo`3oool00`3ooole0:O0j`<0Yko[102W_^X40:Jkj0@0
WJ;H102KVm8409ZHd0@0ViWA1@2VfOT30:c<l@<000001@2Vbo<40:K<l`H0[/O]1@2M^nh50;Nlg@<0
Z[3L0`2YX<h30;R`dP@0SHc=1024S]D20:Fdh`@0^>Ge1@2Wbo<409Nfk@D0X/[e1028aod303NKl`03
005^g00aT_00<I;`00@0Tk?]0P33]L`30<2cc@80d;O2103E^Kh40=S6b@<0gLc81@34c>450:k3jP<0
Z<3[00<000000:O0j`2W`>/04P2W`>/@0?ooo`030000003oool0oooo01<0oooo000H0?ooo`030000
003oool0oooo00<0oooo=02W`>/60:Noj`<0YkkZ1@2PZmh309fRf0D0Vi_B0`2JV=060:C:m0<0/=Cc
0`0000040:O:lPD0Y/_c102YaNh30:k7k@<0/<O[0`2M^nh20;W3hPD0]kcM0P2Z/=`00`2Y/=d0ZJ3>
0:V`g@040;R`dP@0SHc=0`24S]D40;SUm@<0]^Gf102Wbo<509bgj`D0X/[e102;aO/302R@kP800FkL
102C/nd50<2cc@030=2g`P3E^Kh0eKVn00<0eKVn00@0f[fk0=S6b@3Ha/T0f<K90`3Mc<P0103Pd<P0
a<cQ0<C<h@34c>420<;<hPD0[/?Z0`2X`>/00`000000Yl3[0:O0j`0A0:O0j`l0oooo0P00000E0?oo
o`00603oool010000000oooo0000003ooolg0:O0j`D0Yko[102S/n@50:2[gP<0WJ;H102KVm8409jd
j0<0Y<[d0`2cg_D2000000040;3Dl`2XbO40Z<Wa0:S9l@@0Yl[b1@2X`nd40:W5kPH0/<O[1@2i`n84
0;Nlg@H0ZK3M0`2h/=8408f<c@D0XM7i1P2fiOH409RXh@D0W;O[1@2Yd_D408_5n`<0:93^00<004W3
005^g01aX>h00`1aX>h40<2cc@D0eKVn0`3J_K/0103Ha/T0gLc80=g<b03Mc<P30>3@b0030<C<h@32
c>80`/cR0080`/cR1@2]`nX20:S0j`030000002X`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?oo
o`060?ooo`8000002P3oool001P0oooo00<000000:O0j`2W`>/0>@2W`>/50:Fjj0@0Xk?T102PZmh3
09fRf0D0Uj7K102N]>P20;?Nm@<0000000<0/mke0:S9l@2XbO40102XbO440:S5kPD0Z<?]102Zb>l3
0;37j`<0Z/;[1@2i`n840:nmi0D0ZK3M0`2h/=8609C6n@D0[NCi1@2S/N8409RXh@80W;O[0`2^eoD3
0:WBm@80ZL_b1@2=bO`200f0i0030019``01K]`0LJ3^0080LJ3^0`30/ld20;f`c0<0eKVn103J_K/3
0=g<b0@0h=381032c>820<7;hP@0[L?Z0`2X`>/00`000000Z<3[0:O0j`0A0:O0ja40oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`004@3oool2000000D0oooo00<00000
0?ooo`2W`>/0=P2W`>/50:NnjP@0YK[X0`2S/n@509>Fd`<0TiKD1@2GXM/20;?Rm`<0000000<0/n;g
0:_9l02[bO000P2[bO030:S9l@<0Z/S_102XaNh50:W:l@@0Z/S_1P2Z`^/20;W3hP<0/l_/102__N@5
0:3:mP@0W<[g1P2LcOT40;35j@D0Xk7R0`2HZ>460:kGm@D0ZL_b1@2<c_h00`00H]403H3T000TZ004
076PkP030<2cc@2m/<`0_K3<0080_K3<00<0eKVn0=Zm^`3J_K/00`3J_K/00`3Q`[P0gLc80>3@b003
0>3@b080hM;90P32c>840<7;hP80[L?Z0P2/`^X30:S0j`030000002X`>/0Yl3[0140Yl3[403oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0<`2W`>/40:Noj`D0YkkZ102MZ^0309RNf0@0TiKC102C
U]@209NQf`040:kImP000000000000000080/n;g0`2ac^l40:_9l0H0Z/S_102Va_050:W:l@@0Yl?]
1@2Z`^/60;?;k080[kgT0P2PaO850:3:mP@0WLCc0`2LcOT30;7@l0@0/<GY102S/N850:K;l`D0[<W_
0`2Ybo830;7Gm0@0S<kn0P00H]4010009:P0ChKV04n6iP1?Q^H50;f`c0D0f[fk0P3Q`[P40>3@b0<0
hM;91P31bn850:c2jP<0Z<3[00<000000:S0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool20000
0080oooo<`2W`>/40:Noj`D0X[GV0`2MZ^0409RNf0@0TiKC0`2CU]@3000000<0[]Wf1P2ac^l40:_;
l@<0Z/S_0`2XaNl40:K6l0D0Z<;]102W`nd50:K8lPD0/l_/1@2PaO850:?4l0@0WLCc1P2ad?030;35
j@D0WKGY0`2Vbo<20;3Al@D0[<W_0`2aeo@30;CMm@@0OlSn0P00H]4010009:P0ChKV04n6iP1?Q^H3
0;f`c080_Zg90`3J_K/30>72^0030>S8]P3Pd<P0h=3800@0hM;900@0hM?:0<7;hP31bn80`L_R0`2o
bn<50:c2jP80Z<3[00<000000:S0j`2W`>/04@2W`>/A0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?oooc<0Yl3[102U_>T50::eiP<0WJ[P102HW]P309>Fd`<000000`2R_nh50;SHl@D0[<ga
102[bo460:S5k`@0ZlC]1@2X`^d40:G6l@D0Y/Sb1@2S`Nl50:O6l0D0XlC`102Xb?430;7@l0<0YK3O
0`2N[>4509fej@D0/=7a1@2_co460;CMm@<0OlSn00D003Zk001Rd@001Y<002BX03Q]fP0204n6iP04
0;f`c02n[LT0_Zg90;j]b@<0f[fk0`3Q`[P20>S8]P@0hM;90`3QdlX50;o;h`D0[<;Z0`2X`>/00`00
0000Z<3[0:O0j`0A0:O0ja00oooo0P0000040?ooo`8000002P3oool00100oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`050?oooc00Yl3[0P2W_n/40:Flj@@0X[GV0`2MZ^0409RN
f0<0000000@0U:?O0::okP2R_nh0X[o^0`2kg_430;SHl@80[loa1@2/cO440:O3k@<0Z<G_0`2Ya^h4
0:_4k@D0Z<G^102Ua_450:Fnk0<0Xl7_0P2Xanl50:O6l0D0YL3/102Xb?450:F`g`@0WZcQ1@2_fOH5
0:W6kP<0[loa0`2fg?<50:K^n0<0G:oj00<003Zk0006T`001Y<00`0hKMX50;j]b@040=Zm^`3Q`[P0
hL:h0>72^0<0j<Rf00<0kLfc0>7Bb@3Qd/T00`3QdlX20=oCc0<0_l_S0P2mb^@40:c2jP@0Z<3[00<0
00000:S0j`2W`>/04@2W`>/>0?ooo`<00000403oool00140oooo0P0000040?ooo`8000001`3oool]
0:O0j`D0Yko[102U_>T409FRgP<0SYKG0`0000000`2=U=H0U:?O09BSg`0209BSg`H0^mka1@2_co45
0:_6k@@0Yl?]1P2Ya^h40:W5kPD0Z<G^102X_nX50:Fnk0D0Z<O_1@2V^nP40:G0k0D0[KcT102U/=l6
0:OGn0@0Z<7[1@2Ya^h40;KLl`<0S^oS1017am`0100;Ln00G:oj05b_nP00>[/20006T`<0>6gJ102n
[LT40>72^0<0j<Rf0P3]cK<30>7CbP@0gm?<1@2mb^@40:_2jP@0Z<3[00<000000:O0j`2W`>/04@2W
`>/?0?ooo`030000003oool0oooo00h0oooo000G0?ooo`030000003oool0oooo00L0oooo:02W`>/9
0:Noj`D0W[7U0`2EX]h3000000D0SICF0P2DXml30;?Bl0H0]]C`1@2]b^l40:_6k@D0ZLS`0`2Ya^h2
0:O3kP@0ZLG^1@2Z`^/40:RojPD0Z<K_0`2Xanl20:Rki`D0Y[_X102^aN/50:fli0@0X/gf0`2WeoP3
0:_4k0@0Z<7[1P2^hOP00`2>kn<0=[Z`03Jj/00408fmmP<0?8o_0P0;Ln000`006ZL003Zk0006T`03
03Q]fP<0_Zg90P33[lH20>72^0<0j<Rf0`3]cK<00`3_d;80hM?:0=oCc0030=oCc080g]?=0P2mb^@3
0;c9i0@0Zl;Z0`2X`>/00`000000Z<3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool03@3oool0
01L0oooo00<000000?ooo`3oool0203ooolY0:O0j`@0Yko[102T^^T409jai@<0000000@0UJ;N08jF
e`2>U]L0SYKG102=U=H40;?Bl0<0_][^0`2fe?020;;@k`D0[L[_102Xb?050:W8l0D0Yl?^1@2Ya>d4
0:[2j`@0ZLO_1@2Xa^l50:Rki`80Y[_X0`2/b_040:k5j`D0XL7`102RcOH60:_4k080Z<7[0`2KjOX2
04c9^`0305SBg`2`an/0/<O[00@0/<O[0`2=_OH303b?k`07000]/P0;Ln0001ZW0000R`001Y<0<Eo@
03Q]fP020;j]b@@0`jo600@0hL:h0>S8]P3Xb;H0j<Rf0P3]cK<20>o@/P@0gm?<0`3Ndld50;c9i0D0
Zl;Z0`2X`>/00`000000Yl3[0:O0j`0A0:O0ja00oooo00<000000?ooo`3oool0303oool001L0oooo
0P0000090?ooobX0Yl3[102V_^/40:Bjj@0409jai@000000000009jai@<0UJ;N0`2>U]L609ndi`H0
_][^1@2bd>l50:W8k`@0Z<S`1@2W`nd30:O3kP80Z<G^1@2Ya>d40:S6k`@0ZLO_1@2Y_>L40:Rki`H0
[<[`102T^nX50:71l0@0[<ka1@2[a>`00`2KjOX000000000000409;HoP80^lOS0`2`an/30:^Ob`<0
U8g90`1UNM801000;K802g?P000JY`0008/2035Od0H0`jo60`3Xb;H30>g=/`80km2b00<0l=6b0=oC
c03Odl`0103Ndld0103Ldll0_<WT0;c9i02lbN@20;_9i@D0Zl;Z0`2X`>/00`000000Yl3[0:O0j`0A
0:O0j`l0oooo00<000000?ooo`3oool0303oool001L0oooo00<000000?ooo`3oool02P3ooolT0:O0
j`D0Yko[102V_^/0102I[^H0000000000000000408fMgP<0QY;H0`2<VM/309ndi`<0_=C/0`2nf^h3
0;WEk`<0/]3_0P2]b^l50:W8k`@0Z<C^1@2W`nd50:S5kPD0Y/C_102Xa^l40:Vnj@D0ZKcW102Yc?83
0:c:l0<0Y[WW102T^nX50:[Kn@@0[<ka0P1bh>H20433ePD0Y/C_1@2kan<50:^Ob`<0U8g9101UNM80
0`00;K80006D0000RP03035Od0@0`jo60P3>]/820>S8]P80kLfc0`3_d;820?3A/P@0g]?=0`3Ldll5
0;_9i@D0Zl;Z0`2X`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo00<000000?ooo`3oool02`3oool0
01H0oooo00<000000?ooo`3oool0303ooolU0:O0j`@0Yko[00@0X[[Z0000000000000000102I[^H3
08fMgP@0QY;H0`2<VM/60;cDk0H0^MG_1@2]b^l50:[7k`@0Z<C^1@2Xao030:S5kP80Y/?^1@2Va>l4
0:S1j`@0ZKkY1@2Wc?<40:W<lPH0Y[WW0P2T^nX20:3So0D0Z]_i0`2Cco`50:bih`80Y/C_0`2la^83
0;_7h`80^;?D102[Wl/409B=b@@0IGWB00D002fb0001U00008/0>eo<035Od0030<>_aP@0c[K20`3]
cK<20>o@/P<0l=6b00<0l=:c0=kCc@3Ndld00`3Ldll20=_Dd@80^lWU0`2ibNH40:_2jP<0Z<3[00<0
00000:S0j`2W`>/04@2W`>/@0?ooo`030000003oool0oooo00X0oooo000F0?ooo`8000003P3ooolU
0:O0j`040:Jnj`0000000000000000@0X[[Z102I[^H308fMgP<0QY;H1@2X^nL30;cDk0<0`MW[1P2d
d>h40:_:l0D0Z/O_102Wao050:S7l0D0Y/?^1@2Xa>d40:S1j`@0YL[c1@2Wc?<40:NiiPD0Y[WW1@2P
ho`309o5l`<0Tlol0P2^]Mh40:bih`H0_<KR102h/m@40:^Ob`@0U8g9101UNM800`009Jh002fb0000
RP0203]Oc003035Od033[lH0c[K200@0c[K200<0fl2o0>g=/`3_d;800P3_d;830?3A/P80l=:c0`3L
dll30=_Dd@H0^LWV102Z`^/30:S0j`030000002W`>/0Yl3[0100Yl3[3`3oool2000000`0oooo000F
0?ooo`030000003oool0oooo00h0oooo802W`>/20:Noj`<00000102V_^/30::jjP@0VJkV0`2=WMh4
08bKg@D0Z;_W1031fN/20;kGk0<0]=3^0`2_cNl40:_:l0D0YlK`102Wao050:K2k@<0Y/?^0P2Wa^l5
0:S4k@@0Y<Sb102Ub_<50:Nji`@0YkWV1P2Di_/20:Bnk0D0WlGc1@2^]Mh20:bih`80^LGS0`2la^83
0;g4g`@0^;?D0`2[Wl/509nDb0@0SIGG00<005C@0001U00008X00P0kGl`50<jf`P80fl2o0`3_d;83
0?3A/P<0l=:c00<0l=Bd0=cCc`3Ke=400`3Ke=40103Je]@0^LWV0;W9iP2ibNH30;S9i`@0Z/;[0`2X
`>/00`000000Yl3[0:O0j`0@0:O0ja00oooo00<000000?ooo`3oool02@3oool001H0oooo00<00000
0?ooo`3oool0403ooolM0:O0j`<00000102W_n/40:6kj`<0UZoX1026W>4307n@fP@0S9_M0P2X^nL4
0;oAi`D0_]O/1P2_cNl40:S7k`D0YlK`102W`nh50:K2k@D0YlK_1@2TaO040:C8lP@0YkcX1@2W^^L2
08cVn@80D<g>102V^nP40:Bnk0D0[KCM102^]Mh50;W5h`D0_LCO102h/m@409n@a0D0WiC80`2=UML2
001Dd0040000RP0kGl`0>eo<03]Oc0<0c[K20`3K`;l00`3UbK/0km2b0>o@/P030?3A/P80l=:c0P3`
e;@40=_Dd@<0f]KD1@2hbNL50:[2j`80Z<3[00<000000:S0j`2W`>/04@2W`>/@0?ooo`030000003o
ool0oooo00P0oooo000F0?ooo`8000004P3ooolI0:O0j`<000000`2W`>/50:Joj`@0XK_[0`2F[nP4
08JLh@<0Oi3J0`2<Vmd40;oAi`<0amOV0`2nen`30;WCk@<0[lg_0P2]bo040:S7k`D0Z<K_102W`nh6
0:K7l@@0Y<;_1@2TaO040:S0j`@0YkcX102<i?X50:Nkj0@0Y[_X102//mh50:fdg@@0]LCV0`2iaN<2
0;_>j@@0_LCO1@2QT/D309n@a0D0WiC8102X[=/01017ON8005C@0000RP1@KM4203]Oc0040<jf`P3K
`;l0fl2o0=_0_`<0iLVk0`3`dK830?3B/`80l=Bd00<0lMNf0=_Dd@3Ke=400`3Je]@20=OHf0<0^<WW
0P2fbNT40:[2j`<0Yl3[00<000000:O0j`2W`>/04@2W`>/?0?ooo`030000003oool0oooo00P0oooo
000F0?ooo`030000003oool0oooo0180oooo5@2W`>/3000000P0Yl3[102V_n/30:6kj`<0UZoX1026
W>4307n@fPD0ZKOS1P37enH60;WCk@D0[L_`1@2Xb?440:S6k`D0YLOa1@2U`^h40:C2k`D0Z<C^102X
`>/5097Ro@<0Z;kZ102W^nP50:Vcg`@0[;?N0P2]]=d30;33i`@0]LCV1@2kc^T40:JKb`@0XI;5102O
T<@209nDb0<0/k;G102X[=/00`17ON80002:051]d@02051]d@@0fl2o0`3UbK/00`3[ckP0l=6b0?3A
/P020?3B/`80l=Bd0`3aekH30=[Fe0@0emSH1@2fbNT40:W1j`<0Yl3[00<000000:O0j`2W`>/0402W
`>/?0?ooo`8000002@3oool000<0oooo0P0000040?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool0503ooolA0:O0j`<00000302W`>/30:Joj`@0Uk?[0`22WnH407N?g@<0QiSL0`2Y]n<3
0<39hP<0amOV0`36enH60;GAkP@0ZL[a1@2Xb?450:C6l@@0Y/?_1@2U`^h40:O8l@@0Z<C^1P2Hg?h3
0:W6k`@0Z;kZ0P2W^nP20:Nbh0D0ZK?O0`2//mh50;33i`H0]];_102[Z=@30:JKb`D0XI;50`2OT<@6
0;>be`<0Z:cK0P17ON80100008X0D6gA051]d@1@KM420=_0_`@0iLVk0P3[ckP30?3B/`80l=Bd0`3a
ekH00`3ag;X0emSH0=OHf0030=OHf080dm[M0P2fbNT30;?8jP@0ZL7[0`2W`>/00`000000Yl3[0:O0
j`0@0:O0j`/0oooo0`0000000`3oool000000?ooo`080?ooo`000P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool>0:O0j`800000
3@2W`>/30:Joj`<0X[c/102G/n/308:OiP@0MhoM0`27V=`00`2Y]n<0`<WR0<39hP030<39hP@0a]OV
0P34e^P30;GAkP<0/=3`102Yb_450:G6l@<0Y<Ka0P2Va_040:K3k`D0YLWc102Wb?4509kBnP80E/o1
1P2Ya^l30:RnjPD0Yk;P102Y/ml40:g2j@<0/<?W0P2`d_830;KBk`<0[kGN0`2[Z=@40:JKb`@0XI;5
102[[=L50;>be`@0[;7L0P1ZS^<4051]d@040=_0_`3UbK/0iLVk0>G9^`<0jlnh00@0k]>g0?3B/`3`
e;@0l=Bd0`3aekH20?7L^P040?3Q_`3Gf=P0emSH0=OHf0<0dm[M1@2cb>X50:W1j`80Yl3[00<00000
0:O0j`2W`>/04@2W`>/60?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`000P3oool01000
0000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`8000005`3oool:0:O0j`<000003@2W
`>/60:Joj`<0X[c/0`2G/n/408:OiP<0MhoM0`27V=`40<39hP@0bm3N1@34e^P60;3@l0@0Yl[b1@2U
a_450:K6l0@0XlSc1@2UbO<50:78m080E<jl1@2[e?H40:W6k`@0Y;7Q102W/^050:[1jP@0[L;Y1@2`
d_850:negP@0ZjSD0`2VVl/50:2Nd`@0ZjcG0P2c/]L30;Bhg0@0[;7L00<0JXkS0000RP1[R=d00P1[
R=d40>G9^`80jlnh0P3^dkL30?3D]0<0lMNf00@0lMbj0?3Q_`3`hKl0l>6o103Cf]d20<gJh`@0/lSZ
1@2Y`N/30:O0j`030000002W`>/0Yl3[0140Yl3[0P3oool3000000P0oooo00<000000?ooo`3oool0
1`3oool00080oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0
603oool50:O0j`<000004P2W`>/40:Joj`@0VkS]0`23Y^/406f?hP<0NY3M102R[=l50<_@gP80cm;L
0`34e^P30<7Fj@D0[=3c102Wb_860:C8lP@0X/Kb102Sb?<50:?4l0<0XLSd1@2ZioX409n`h`@0X[3R
102T/N440:Noj`D0Z/7Z1@2/dO<40:noiP@0[kGN102[Z=@409ZDc0D0X9kC0`2[[=L50;Bhg0@0[;7L
0P1ZS^<406^8g@80iLVk0`3[ckP20>kC]`80lMVg0`3aekH20?7L^P<0l>6o00<0k^K60=?Jg@3Cf]d0
103=f^<40:o7j`<0ZL7[0P2X`N/30:O0j`030000002W`>/0Yl3[0100Yl3[0P00000<0?ooo`030000
003oool0oooo00H0oooo00020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0I0?ooo`040:O0j`0000000000000001H0Yl3[102T_^`409^hk@<0
PjK[0`1]Sn8407Z@g@80XZcO0P2i_=`30<_@gP@0cm;L1031e^T30;gFk0@0[=3c1@2Sbo@50:77l`@0
X/Kb102TaO050:?4l0@0VO7^102O]>L409n`h`<0X[3R1@2T_^`40:Noj`D0Z=3e1@2]aN`40:noiP@0
W936102JSlL309ZDc0D0X9kC102a^^040;Bhg0D0Z[?O0P1fUN<406^8g@030>G9^`3[ckP0jlnh0080
k]>g0`3afKL0103ch;T0lMNf0?7G]P3ag;X30?3Q_`<0k^K60`3=f^<30<GGi`@0[lO[1@2X`N/30:O0
j`030000002W`>/0Yl3[0100Yl3[3@3oool00`000000oooo0?ooo`060?ooo`000`3oool2000000X0
oooo0`0000030?ooo`800000603oool3000001X0Yl3[102T_^`408fak`80JIKZ101]Sn8307Z@g@D0
^KcL1@3?d]`30=7BfPH0_MK/1@2Vd?H409o;m`D0XLOc102Sb?<40:C5l080M>;V0P2IlNh50:32l0@0
WkCW0`2O/><40:6mk@D0Y;k/102UcoH30:S@m@80Z/O_1@2]aN`409nBaP<0W936102JSlL409ZDc080
X9kC0`2^_N@80;6jh0@0Z[?O0P1fUN<406^8g@<0jlnh0P3^dkL30?7I]`80ln2i0P3ag;X30?3Q_`80
k^K60P3YjLh50<GGi`D0[LG/0P2X`N/30:S0j`80Yl3[00<000000:O0j`2W`>/0402W`>/=0?ooo`03
0000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo01D0oooo0`0000040?oooaX0Yl3[
102P_Nd408fak`80JIKZ0`1QQ^0408fLg@<0^KcL0`38`mD20<oBg0<0dM;J0`3BdMP60;[GkP@0Wm7i
102OboL509k;m`@0XlSc0P2;h_`207STd0@0X=cl102P`_0409ndi`@0W;c^102Q_Nd50:7>m`@0YLof
1@2Zanl50:6Da`<0Wi;6102LT<H409Z?a`<0VYC<1@2^_N@20;6jh0<0[[_S102a^^040:FbhP80N9OT
1023ZNd00`3[ckP0k]>g0>kC]`030?7I]`<0ln2i00@0lnNl0?3Q_`3`hKl0l>6o0P3^i/H30>WYcP04
0>;[f035enL0aMOW0<GGi`80_M?[102]aN`50:S0j`<0Yl3[00<000000:O0j`2W`>/0402W`>/<0?oo
o`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo0180oooo0`0000080?oooaH0
Yl3[102V_n`40:2mk@<0SK7_0`1YU^X30666h0@0SIcM00<0^KcL0<S3e@38`mD00`38`mD30=7BfP@0
d]7H00@0dloE0;[GkP2jenh0^]O^0`2geo0409oAn@@0U/gk1@2NboL409GFoPD0QNW[0`2Pg?`408jg
l@@0U[W`102L_>h409g=n0D0XLkg1@2Wa_040::Fb0@0XIC7102OT/H309b@aP@0VXo7102Z_>L40:jm
i0D0[[_S0P2a^^030:fhhP@0YK;R0P1hUn@308>Yk@<0k]>g0`3afKL20??P^@80lnNl0P3ak<820>kV
aP<0jNW>0`3RjmP50;gCj`@0Z/?/0`2X`>/50:O0j`030000002W`>/0Yl3[0100Yl3[2`3oool00`00
0000oooo0?ooo`060?ooo`00503oool200000100oooo0`00000<0?oooaH0Yl3[102V_n`409Zjk`<0
N:O`0`1:PnH30666h0<0SIcM1@38`mD30=34cP@0d]7H0`3CcmD60;OGl0D0Tm7m0`2FcO/609C@o0D0
VlCd0`28^OH308Nem0@0S[Oa102F^O0509S9n@<0WLgh1@2T`^l80::Fb0@0XIC7102OT/H309b@aPD0
YKKU102Z_>L40:Zii0@0[[_S1P2]^>830:FbhP<0N9OT102;`oX30?7I]`80ln2i0P3cik`30?7/`P04
0>k^a`3YjLh0jNW>0>WYcP<0h^_H0P3HjN450;C=k0@0Z/?/202W`>/00`000000Yl3[0:O0j`0@0:O0
j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool0303oool300000140
oooo5@2W`>/40:Fok0@0V[[_0`1hYo0304Z3iP80HXKO102SZ=X30<S3e@<0d<C>0P3D`/L20=;Af0<0
dloE0`3DbLl60;OCk`D0R/on0`28col205KAe`0307SSj@2jbNH0^/WV00D0VlCd0`28^OH308Nem0@0
SkC`1@2C`_L40:2`h`@0X[_[102RULL80::Fb0<0XIC7102OT/H40::^h0@0YKKU1@2Y^>@40:Zii0@0
[;[T1@2]^>8409n`i080MIKU1@1gcOl20?7I]`80ln2i0P3cik`20?7/`P80k^k70P3[l<`30>;[f080
f>WQ0P3<hnT40;C=k0D0ZL7[1`2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3o
ool01P3oool001@0oooo00<000000?ooo`3oool02P3oool2000001D0oooo5@2W`>/40:Fok0@0TKOa
0`1JVO0304Z3iP80HXKO102SZ=X40=34cP@0e<;70`3CcmD40=C9c`040=BoaP2gdnl0]m?_0;OCk`@0
^lST1@2@bo/207SSj@D0^/WV1@2KT<P3092Bd@<0SJ7Q102?]?0509jSf0@0X;3S102SU<D30::Ea`P0
XYK80`2QU<L50:6WfP@0XZkP102Z^^D50:Vhi0@0ZkgW102/^^@50:Vii0@0Wk3T0`1eU^D407O=o`80
ln2i0P3cik`20?7/`P80k^k70P3[l<`20>Sad0<0f>WQ103<hnT40:k7k@@0ZL7[202W`>/00`000000
Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01@3oool001@0oooo00<000000?ooo`3oool0
1`3oool3000001P0oooo5@2W`>/40:>nk@@0TKOa0`1JVO0202Q_gP<0HXKO0P2SZ=X20;F_d`80d<C>
103D`/L30=Nm`0@0e<W?0`3D_lH40;_8i0@0`KO@102fcN/30<o4d0@0/:79102KT<P4092Bd@<0SJ7Q
102NV<d409jSf080X;3S0`2TTl@30:>Da@@0XYG7102RU/P40:>Qd`<0XJ;F102QYmX50:^nj0@0Z[[U
1@2Z_^T40:^mi`@0ZK[U102Y^N@409n`i0<0MIKU0P0LGM@305?2n080lnNl00@0B;[f0?7/`P3^k/L0
k^k70P3[l<`30>Sad080i??E0`3<hnT30;kIk@@0[/O]102X`>/80:O0j`030000002W`>/0Yl3[00l0
Yl3[2P3oool00`000000oooo0?ooo`050?ooo`004`3oool3000000D0oooo0`00000L0?oooaD0Yl3[
102S_^d4096gl@<0FYW`0P0XKmh206^;g`D0]JoC103D`/L40=Nm`0030=Rh^@3DbLl0e<W?00@0e;o6
0P3D]K/50<6gd080b[;20P2fcN/40<o4d0040=2ob`2`XLT0/:790;2Qb@@0Vi38102@T]4409nBaP@0
WYS=0`2NXmP50:BCa0@0XiC50`2RULL50:FRdP<0Xj7C102QX]H20:6WfP80Z/7[1@2[_^P40:Rmj@@0
Z[kY1@2X^NH40:Vji@@0YKKU102H[ND3076Di@0403E_f`0LGM@015[D000X/0<0G/;l0P3^k/L20>_`
c0<0j?7@0P3TlmD20=gcg@D0_]W]1@2Z`n`40:S0j`P0Yl3[00<000000:O0j`2W`>/03`2W`>/90?oo
o`030000003oool0oooo00D0oooo000C0?ooo`030000003oool0oooo0080oooo0`00000P0?oooaD0
Yl3[1@2Q_^d308Ndl`80=8GZ0`0XKmh206^;g`<0]JoC0P31///20=C2a`@0ekg00`3H^;T40=BoaP<0
e;Fk00@0e:jb0<6gd031]m00`KO@103://840<o4d080d;o;102`XLT309^@b0D0XY730`2OT/H409jH
c@@0YiK4102TTl@40:>Da@80XYG70P2WYM@40:FRdP@0Xj7C0`2QX]H50:[1j`D0Yk[W102X_NT40:Ri
i@@0Z;WV1@2W^NH40:Ffi@<0V:gU101aU>D203E_f`0400AJe000:;00Plko08?>o`<0XmSj0`3XlM02
0>Cce@80gO?M0`3Cl>H40;?>kP@0Z/?/302W`>/00`000000Yl3[0:O0j`0@0:O0j`P0oooo00<00000
0?ooo`3oool01@3oool001<0oooo00<000000?ooo`0000000P00000T0?oooa40Yl3[102V_n`50:6n
k@<0QkCc0P0dQNX2001Gd@<0Jh_O00<0]JoC0<6bb`31///00P31///40=Nm`0@0f;Ri00<0fK>b0=Bo
aP3D_lH0103D]K/20=B^/P030<6gd03://80b[;200<0b[;200<0fkjl0<o4d03?a=00103@_l/30;2Q
b@@0YIO7102RTL<409nBaP80WYS=0P2ZW<P30:NFa0@0Y9?4102SU<D40:NUe0@0YJ;B102SXM<50:W4
k@@0Y[SV102W^^L50:RkiP@0Z;WU102X_>L40:NiiP@0YKKU0`2H[ND4076Di@<0=FoK00<0@HCX0:?H
nP2Sf?X00P2Sf?X30;_QlP040>Cce@3Mlmd0gO?M0=gcg@80do3V0`35i>h40;?>kP@0Z<7/302W`>/0
0`000000Yl3[0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool01@3oool001<0oooo0`00000W0?oo
oa40Yl3[102V_n`509nnkP<0OK3d0P05J]`2001Gd@80M93P1@31///01038/L@0ekg00=Nm`03G_L03
0=Rh^@<0fK>b103D]K/30=B^/PD0b[;20`3K_[`50=2ob`@0Z:;@0`2UUlL40::A``@0Wi;6102ZW<P4
0:NFa0<0Y9?41@2ZZmL40:NUe0<0YJ;B1@2XaNh50:Ngi0@0Y[SV0P2W^^L20:Vmj0@0Z;_V0P2X^ND3
0:Rmj@@0Z;cW0`2W^NH50:6diP<0TJWV101^T^@00`1>On40=FoK03E_f`020464j0<0^n7b0P3<jN/3
0=G`i@030=?`iP35i>h0aNC^00<0aNC^1@2/a^d40:S1k0`0Yl3[00<000000:O0j`2W`>/03`2W`>/7
0?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003oool0oooo02L0oooo4@2W`>/50:Jo
k0@0Wkk^0`1m/?@200EZg004001Gd@1dT>00M93P07B@h0<0`K;;0`38/L@00`3G_L00f;Ri0=Rh^@02
0=Rh^@<0fK>b00@0fK2]0=Be^`3D]K/0e;Fk0`3D[[80103I/:l0b[;20<Zb`P3://840=^n_0040>O?
_P3@_l/0d;o;0=2ob`80_KcI0`2XX]040:FGa`<0XY731@2]Y<h40:ZLb0<0YiK4102//]`50:Z[e`<0
YjGD1@2Wa>l40:Nfi0D0YkOT0`2V^>H50:Vmj0<0Z;_V1P2X_NT30:Rli`@0YKSW1@2Q]>H3096YiP@0
KY;T0P1>On430464j0<0c>W[0`3El>D0103Gm^80d_KV0=;fiP3Bm^H40;KDk`@0[<K]1@2X`>/;0:O0
j`030000002W`>/0Yl3[0100Yl3[1`3oool00`000000oooo0?ooo`040?ooo`002`3oool5000000D0
oooo0P00000Y0?oooa00Yl3[1@2V_n`409nmkP<0M:kf00<004c500EZg000Em400`1dT>000`31///0
b;740<Raa0020<Raa0@0f;Ri0`3I/k820=V`[@80e;Fk103D[[820=V`[`030<Zb`P3K_[`0fkjl0080
fkjl0`3Wckh50;flf@<0Z:;@0`2UUlL40:^[e`D0[JC>0`2ZW<P40:bihP@0[;;L102ZZmL40:K3kP<0
YlC_0P2W]^<40:Nfi0@0YkOT102Y`>X40:Vmj0@0YkcY1@2X_NT40:JhiP@0YKSW1@2L/>H308^Ti@<0
Ki7S0`1>On4407BWl@<0eO3U00@0eoKR0=;fiP3Bm^H0d_KV0P36k>h40;KDk`@0ZL;/102X`>/<0:O0
j`030000002W`>/0Yl3[0100Yl3[1P3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02L0oooo402W`>/50:Jok0@0Wkg^0`1d[_H00`00C<D0
03Bh07B@h00207B@h0D0b;7400@0c;2n0=Rh^@3H^;T0f;Ri0`3I/k830=V`[@040=Be^`3D[[80e:jb
0=B^/P<0fK2_103K_[`40>O?_P030>;Ba`2m_=T0_KcI0080_KcI0`2XX]040:2ZgP@0Zj_G102]Y<h4
0:Vli`@0[;WR0`2//]`50:G0k@@0Y/?^1@2W]^<30:Nfi0D0Z<;/102Y`>X40:Jkj0@0YkcY2@2V^>H4
0:>fiP@0W;3V102;Y>D306nAh`80J97V1@2La?<20=OfhP<0d_KV0`36k>h50:g7k@@0ZL;/402W`>/0
0`000000Yl3[0:O0j`0@0:O0j`D0oooo00<000000?ooo`3oool0103oool000d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0W0?oooa40Yl3[102V_n`409nmkP<0LJgf00<003>^000d
^01hTn400P1hTn430<Raa0<0c;2n00@0f;Ri0=Vc/P3I/k80fK>b103I/:d40=B^/P<0fK2_00<0hkb_
0=^n_03K_[`0103Wckh30>;Ba`@0YJoN0`2EYN040:2ZgP<0Zj_G1@2T^NP40:Vli`<0[;WR102T_>X4
0:G0k@D0YkOT102W]^<40:S2k@@0Z<;/1@2V^NH40:Jkj0@0Yk[W102V^>H50:Jjj0@0XkKV0`2L/>H4
08^Ti@<0Ki7S101XTNH40;_Nl@80bo;[1036k>h20;OGl@@0[LO]1@2X`>/@0:O0j`030000002W`>/0
Yl3[00l0Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02L0oooo4@2W`>/50:Jok0<0Wkg^0`1a[OH00`00<jh003Bh07RCh@0207RC
h@030<Raa03</;h0c;2n0080c;2n103I/k840=V`[@030=ba[03D[[80e:jb00@0fK2_0P3S_:l40>O?
_P<0h];70P3Da/d40:F_gP<0UJGP0`2PZ]h409nciP@0Y;WX102Y_>L40:Bhi`@0Y;cZ102X^>D50:Ng
i0@0Yl;]102X`^d40:Nhi@@0Y[WV1@2X_NP40:Nji`@0Y[cY102V^^P509nciP<0UjcV1025W^<307JE
h`@0QZW/0P2kg_420<_bj`<0c?WX1@2geo450:W2k1<0Yl3[00<000000:O0j`2W`>/0402W`>/40?oo
o`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00X0oooo0P00000X0?oooa80
Yl3[102V_n`309nnkP<0LJgf00@002NQ07RCh@1hTn40N9?Q1@3</;h00`3?/;/0fK>b0=Vc/P040=V`
[@<0g;6/00@0e:jb0=V`[`3I/:l0fK2_0`3S_:l00`3]b[00ilnn0>O?_P030>;Ba`<0e<K=102U[mh3
09FUh0@0VjkT102O/nH40:Fgi@@0YKKU102T^>L40:Rki`@0Z;SU1@2V`N`40:O2k@P0YkSU102X_nX4
0:Rmj0D0Y[_Y102V_>T40:>fiP@0Wk?V102G[>H308FNh`@0MYGS0`26ZN`20<_bj`<0c?WX0`34k_05
0:c7kP80ZL;/0`2X`>/C0:O0j`030000002W`>/0Yl3[00l0Yl3[103oool00`000000oooo0?ooo`04
0?ooo`00303oool2000000h0oooo00<000000?ooo`3oool09P3ooolB0:O0j`@0Y[o/0`2O_^h3076]
mP04000WX@1aTn@0LI?T076Ci0<0c;2n0`3?/;/00`3I/k80fK2]0=V`[@020=V`[@<0g;6/103I/:l3
0>>l[`80kLZ`0`3Rd/L40=C6c@D0X:[N0`2FZ>8409^^i0@0Y;OV102U]nD30:Ffi@D0Z;gY102X^nL4
0:Joj`@0Y/7/2@2W^>D40:S0j`@0Z;oZ102V^^L40:Jkj@D0YKOV102S]^H309nciPD0T:CR0P24Vn44
07JEh`<0Yl[b0`30k_820<C^l0@0]MKa102/anh50:S0ja@0Yl3[00<000000:O0j`2W`>/03`2W`>/3
0?ooo`030000003oool0oooo00@0oooo000M0?ooo`030000003oool0oooo02H0oooo4P2W`>/40:K0
k0@0X;k^0`1e[oH3076Ci0030<b`_P3?/;/0ck2k0080ck2k103I/:d40=ba[0040=nf[@3I/:l0fK2_
0=V`[`80hkb_0`3]b[020>o?/@@0e<K=0P38_<h40:2ZgP@0UZSR102P/nH40:BgiP<0YKOU102W_NX5
0:Rmj@@0Y[cY102V_n/40:Rhi@@0YkSU1@2W`N`40:S0j`@0Y[SV102V^^L40:JiiP@0YKOV1@2R]^L3
09^^i0@0T:CR0`24Vn4408JRiP@0`>kb00@0a?[Z0;o/lP2ok?80_ncb102ee_440:S1k1T0Yl3[00<0
00000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo00<0oooo000N0?ooo`030000003oool0
oooo02H0oooo4P2W`>/40:K0k0@0XKk^0P1j/OH3076Ci0D0ck2k00@0dK>l0=V`[@3I/:d0fK2]103L
/J`00`3O]Zd0fK2_0=V`[`030>>l[`<0kLZ`0P3_ck400`3]c;<0e<K=0=C6c@040<RlcP<0X:[N1@2K
[N<40:2ciP<0Y;OV102U^nT40:NmjPD0YKWW102V_>T40:RiiP@0Z;SU202W`N`50:Jhi@@0Y[SV102W
_>P40:JiiP@0Y;WX1@2R]^L309^^i0<0T:CR1024Vn4509o1l0030<CjjP2ok?80_ncb00<0_ncb1@2[
a^dL0:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?ooo`007`3oool2
000002P0oooo5@2W`>/40:6nkP80N[7f0`1@R>P30<n`^`80dK>l0P3I/:d40=ba[0<0gkJ]00@0fK2_
0>>l[`3S_:l0hkb_0P3]b[030>o?/@80kLbc1@38_<h40:>[g@@0VjgS1@2R]>D30:>gi`@0YK_Y102V
^>H40:Fii`D0Z;_W102X^NH40:O0k0@0Yl7/102W]nD40:Jhi@D0YkkY102W_>P80:Bij0@0X[KW102F
Yn8308fOh0@0Rj;S0P2O`O020;W_m0<0_?W/1@2adO040:S1k1`0Yl3[00<000000:O0j`2W`>/0402W
`>/00`3oool000000?ooo`040?ooo`008@3oool00`000000oooo0?ooo`0V0?oooaD0Yl3[102R_^d2
07ncm@80D8SX0`3?/;/30=6c_0030=V`[@3L/J`0g;6/0080g;6/0`3O]Zd30>>l[`<0kLZ`0P3_ck43
0>g</`040>O7]`38_<h0b;c>0<RlcP80`kO>102SZmd40:6ah`D0X[CU0`2S]nL40:NiiP@0Y[SV102X
_NP40:Rki`D0Ykk[102W`>`40:Nhi@@0YkOU102W_n/40:Nnj@D0YKSW102T^NP40:6ah`@0WJgR102F
Yn8308fOh0<0Rj;S0P2iko@30;cik0<0^NCd0P2adO030:W3k0@0Z<7/702W`>/00`000000Yl3[0:O0
j`0?0:O0j`030?ooo`000000oooo00@0oooo000R0?ooo`030000003oool0oooo02H0oooo5@2W`>/4
0::nk@80Ok?e00<005oE0528j03?/;/0103A/k`40=ba[0@0gkJ]00<0i;ja0>>l[`3S_:l00P3]b[03
0>o?/@80kLbc0`3WakL50<>gcP@0Z:kL102Q/N<40::di@P0YkWV102X_NT40:Rmj0@0Y[cY102W_^/5
0:Rhi@@0YkSU102W`>/40:Noj`@0YKOU102U^>L50:Fei0@0XK7S0`2M[N8409JWhP<0SIoP102Qa?82
0;;fl0D0^NCd1@2Y`n`Q0:O0j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool0
02<0oooo00<000000?ooo`3oool09P3ooolE0:O0j`@0X[k]0P23]?D00`00GmD0dK>l0=6c_0030=6c
_0040=6j``3L/J`0g;6/0=ba[0<0gkJ]0`3T_[430>g:/080klna0`3]c;<30>O7]`040>73^`33]lh0
`kO>0<>gcP80`[G>102X[]`30:6ah`D0YKOU102W^NH40:Nkj0@0Z;gY102V^^L40:Jlj@@0Z;WU102X
^>D90:O0j`@0Y[KT102U]nD40:Jii`@0YKGT102Q/N<409ZWg`@0TYoM102AY>830;;fl0<0^?Ga1@2]
bNl40:S0jb00Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2
000002L0oooo5@2W`>/40::nk@80PkCe00@005oE0=6c_03A/k`0dK>l0P3A^/<20=ba[0@0gkJ]0`3T
_[420>W7/`<0klna0P3]c;<30>O7]`<0hL>k00<0`kO>0<:ecP32]Lh00P32]Lh20:R^g080[[7J0`2U
/n840:Fgi@D0Y[SV102W^nP40:NiiP@0Y[[W102Y^nH40:Rii@@0Yko[102W`>/50:Nfi0@0Y[KT102W
_>T40:Jii`@0XK;T102O[n<409ZWg`<0TYoM0P2AY>830:KInP030;Sel@2be_<0/]Kc00<0/]Kc1@2X
`N`40:S0jb00Yl3[00<000000:O0j`2W`>/02`2W`>/30?ooo`030000003oool0oooo00<0oooo000V
0?ooo`030000003oool0oooo02D0oooo5@2W`>/40:>ok@80Q[Kd00<005oE0=6c_03A^/<00`3A^/<0
103L/J`0gkJ]0=nf[@3O]Zd30>Bn/@<0jLNc0P3^cK830>g</`<0ilNg0`3Q`k/50<:ecPD0[[7J0`2U
/n840:Ngi0@0Y[SV1@2X^ND40:NiiP@0ZKcW102Y^nH40:NnjP@0Yko[102W]^<40:Nfi0D0YkkZ102W
_>T40:>bh`@0XK;T0`2O[n<409ZWg`<0TYoM102VfOX0102Yn>P0]NOf0;GWmP2eioH40:W4k@@0Z<7/
9@2W`>/00`000000Yl3[0:O0j`060:O0j`P0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool09@3ooolE0:O0j`@0Xko]0P29]o@50=6j``@0gkJ]0`3T_[420>W7/`<0k/fb0P3`
d;430>O7]`@0hL>k00@0g<6n0<:ecP32]Lh0`[G>0P32]Ld40:jafP@0ZKCP102W]n@40:Vii@@0Z;WU
1@2Y_NP40:Vli`@0YkcX102W_^X40:Rgi0@0YkKS102W_n/40:NnjPD0Y;7R102S/^<30:6bi0@0VIkG
102DW]X409N`j0030:Whj02eioH0]NOf00@0[<W_102Ya>dX0:O0j`030000002W`>/0Yl3[00<0Yl3[
2`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`0V0?oooa@0Yl3[1@2S
_nd01029]o@0dK[30=6j``3A^/<20<g3d080gkJ]0`3T_[430>W7/`80k/fb0`3`d;400`3_dK<0ilNg
0>O7]`030>73^`<0g<6n1@32]Ld40;:bf0@0ZKCP102Y^><40:Vii@@0Z;_W102Y_NP50:NiiP@0YkcX
102Y^>@40:Rgi0P0Yko[102U/N440:BahPD0Y:kO0`2OYMX409VNe`<0U9kJ0P2OlO830:odl`<0[];c
0`2/bNl]0:O0j`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00
000W0?oooaD0Yl3[102T_nd00`2<^?<0dK[30<g3d0030<g3d0040=nf[@3T_[40i;ja0>Bn/@80jLNc
0`3^cK820?3@/@<0km6c103Q`k/30=c1_P040=S0`P32]Ld0`[G=0<:ec@80a;K<102b/]P40:fdgP@0
ZKSS102Y^>@40:Rki`@0Z;ST102W^NH50:Vii@@0ZKST102W_^X40:Noj`@0Y[7P102U/N440:Jei0@0
Y:kO102OYMX309VNe`<0W][l0`2IlnD50:kBl`@0Z<7/:P2W`>/30?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool09@3ooolE0:O0j`@0Y;o]
1@3=`m030>Bn/@<0jLNc0P3^cK830?3@/@<0km6c00<0k=6h0>73^`3Q`k/00`3L`Kh30=S0`P030<:e
c@34]/`0a;K<0080a;K<0P2b/]P20;Jce@@0[KCN102/]^440:Vhi0@0Z[SS102X^>@40:ZkiP@0ZKWU
1@2X_>P30:NnjPD0Yk7O102V/N040:JiiP@0Y[GT0`2T[]l409nUfP@0V[O]0P2IlnD50;3Mm`@0ZL;/
102X`N`U0:O0j`P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00;03o
ool00`000000oooo0?ooo`0U0?oooaD0Yl3[102T_nd30<g3d080`l[O0P3T_[420>W7/`<0k/fb0P3`
d;430>oA/`<0k=6h0`3L`Kh40=S0`PD0a;K<1@2f/mD40;6df`@0[;KQ102/^>840:Zhh`P0Z[_V102X
^^H40:Rlj0@0Z;;O102W/Ml50:Nji`@0Y[WV0`2V]N@409^Ld`@0VJ?L0P2J]nd40:gXn@D0Z/K^102Y
`^`U0:O0j`/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00;@3oool0
0`000000oooo0?ooo`0V0?oooa@0Yl3[102T_nd50<?:g`<0jLNc0P3^cK830?3@/@80km6c103/dKP0
0`3XdKl0g<6n0=S0`P030=S0`P80eL760P34]/`30<Fgc080][?E0`2j/m<30;6df`D0[[GN102/^>84
0:^ih`@0Z[_V102X]^<40:RjiP@0ZK?P102X/]l80:Nji`D0XI_?0`2NVm0409^Ld`<0VJ?L0`2RkoH4
0:_:l0@0Z/K^9P2W`>/?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool0
02h0oooo00<000000?ooo`3oool09P3ooolD0:O0j`@0YKo/00<0U;_b0;_@jP2kd>X00`2kd>X30>k=
/P80l=2a0`3_dK<30>cA^080j=6o103H`<830=G1aPD0aKO<1@2j/m<20;6df`80/k;G102^]Mh50:bd
g`@0ZkWS102Z]>040:Rfh`@0ZkGP102Y/n040:Rii@@0Yk[W102SWLh40:6Kc`@0WY_@0`2KW=<00`20
in/0X^of0:;_mP040:_>lP@0Zl[`9@2W`>/D0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00@3oool002l0oooo0P00000W0?oooa@0Yl3[102U_n`0102I_?40^m3Z0;_@jP2kd>X30;cJ
k`<0l=2a0P3_dK<30>cA^0<0j=6o00<0h]C90=S0`P3H`<80103E`LH0103Ca<`0aKO<0<Fgc035]l`2
0<Jic@@0^[?C1@2c/]L40;2af@@0[;CO1@2]/md30:Zdh0D0[;KP102[]N040:RfhP@0Z;WU102UWLh4
0:>McP<0XI_?102NVm000`2<ho/0S^g/08k]k0040:[Bm@@0Zlkb102X`>/Q0:O0jaP0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0U0?oo
oa@0Yl3[1@2U_n`40;cJk`<0`nK_0P3_dK<30>cA^0<0j=6o0`3Re<T40=G1aP<0dlC<00<0aKO<0<Ji
c@36^Ld00P36^Ld20;Zcd`80_K?A0`2c/]L20;Nad`P0/;7I102]/md40:fdgP@0[;KP1@2Y/=d30:Rf
hPD0YYk=102UWLh30:>McP<0XI_?102Gf?d40:SDm`<0Z];e1@2X`N/40:O1k0@0Z<3[602W`>/L0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3o
ool09@3ooolE0:O0j`@0Y[o/00<0WKg_0<?Vk`33i^l00P33i^l20<O]kP<0`O3a0`3XdKl30>;Db@80
fmWF0P3E`LH40=?4c0D0a[W=1@2m/m450;Nad`80/;7I0P2d/=@40;2af@@0[ZoI102]]=h40:VYe`@0
ZK3M102XWld40:JNc@@0YIg>102Sao8409k<n080Y]Oi102Xe?L50:S2k0@0Yl3/102W`N`40:Noja@0
Yl3[803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000c0?ooo`030000
003oool0oooo02D0oooo5@2W`>/40:Jok080XKk^0P37kNh40<7`l@<0[nog0`3Re<T40=_IeP@0dlC<
0P3?c=L30<Jic@80akoC0`2m/m420;nhd`@0]k7C1@2d/=@20;2af@80/JcC102^[mT40:bVd@@0ZJWG
102[Xll40:ROc@<0YYk=1@2Vb?440:?7lP0305gEc@2VeoT0Y]Oi00<0Y]Oi1@2Xa>h40:O0j`@0Yl3/
202W_n/@0:O0jb@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`00=03o
ool2000002H0oooo5@2W`>/40:K0k0@0XKk^00<0Q[Sf0:o_m`2_koL01@29i?X40=_IeP80c>;W0P3C
a<`40<o<e`D0akoC1@2o^=<20;Nad`80^[CD102d/=@50;6/d`80[ZoI0P2aZ]440:bVd@80ZJWG0P2`
[M@40:^Sc`<0Z9o=102Xco@40:K8l@80CL[41@2SeoX40:S5k`D0Yko[0`2W`>/80:Noja00Yl3[:@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0040oooo000f0?ooo`030000003oool0
oooo02D0oooo502W`>/40:K0k0@0Y;o]0`2F_?8305VZn@<0BLC/1@3<h^L40<o<e`80a=_Z0`37_m<2
0<C>hP@0_kSC1@2j]=@40;Nce@@0/JcC1@2aZ]430:bVd@D0/:gD0`2[Xll40:GLnP@0Z<od0`2Ne?/3
0:7Gn`D0YlK_102W_^X40:Noj`@0Z<3[102W_n/40:O1k0`0Yl3[;03oool00`000000oooo0?ooo`07
0?ooo`4000000@3oool10?ooo`00=`3oool00`000000oooo0?ooo`0U0?oooaP0Yl3[0`2T_nd409nn
k`@0P[Wh0P0TU^d00`0a0000Y^Ok0:KWn`030:KWn`D0a=_Z1@34c^820;nhd`80`LSP0`2j]=@20;g;
i0@0]k?E102i^m/40;6Zd@@0]/7R102`[M@509GVn`<0YMcj0`2NdOX40:K5k`@0YlG_202W_^X40:S1
k0@0Z<3[102W`>`40:O1k0D0Yko[0`2W`>/`0?ooo`030000003oool0oooo00H0oooo0@0000010?oo
o`40oooo000h0?ooo`030000003oool0oooo02D0oooo5`2W`>/50:Jok0<0Wkk_1@2H__8306bdn`03
00N;g@17`n`0Al?/0080Al?/102?h_d40<C>hPD0`LSP102mbn@20;Nce@<0]m_c0`2i^m/20;6Zd@<0
/Mkg102f`N8406_Li`80AlSJ1@2Nc_P40:K3kP@0Y/G_202W_^X40:O1k0@0Z<7/102W`>/40:O0k0@0
Yko[>03oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>@3oool2000002H0oooo
702W`>/40:Bok@@0X[o^102A_O@305jcn`0300F?f02?h_d0Sn;m0080Sn;m102RiO`509cVo0<0_L_T
1@2gfo<30;Vkf`D0/Mkg0P0h_/H00`0R[/40L];m07;Bo@0207;Bo@D0Wl_f102V`^d30:K3kPD0Z;kZ
0`2W_^X50:O2k0<0Yl7/1@2W_n/30:O0j`D0Yko[>`3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool10?ooo`00>`3oool00`000000oooo0?ooo`0T0?oooa`0Yl3[102V`>`40::okP@0XKo^102?
__H305ngo0<04Y_L0`0S[]<309cVo0D0L]ga1@0Y/lX203Bhg`@0TlWj1@2R`o030:77l`D0Y/3/0`2V
`^d40:RojP@0Z;kZ1@2W`N`30:O2k0D0YkoZ102X`N`40:O0jcl0oooo00<000000?ooo`3oool0103o
ool100000040oooo0@3oool003`0oooo00<000000?ooo`3oool0903ooolL0:O0j`P0Y/3/2@2Q_nh3
09>om@D0V/3c0`24`_/409O3mP@0PlKm102Ka?@40:C1kP@0X/?`102W_n/40:K0k0@0Z<3[102X_nX5
0:O1k0P0YkkZ102W`N`40:S1k4<0oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool0
03d0oooo00<000000?ooo`3oool0903ooolQ0:O0j``0Y/3/0`2S`>h50:G0k@<0X<7_102U`>d40:71
l0@0Y/3/102T`Nh80:Noj`D0Z<7[0`2X`>/50:O1k0@0Z;oZ0`2W_^X80:O1k4P0oooo00<000000?oo
o`3oool00P3oool100000040oooo0@3oool003h0oooo0P00000U0?ooobT0Yl3[0`2V`>`40:O0k0@0
YL3]102V`>`40:G0k@@0Yl3/102V`>`50:O0j`<0Yko[1@2W`N`40:Noj`<0Yl3/202X_nX80:O1k4/0
oooo00<000000?ooo`3oool00`3oool100000040oooo00100?ooo`030000003oool0oooo02<0oooo
;02W`>/40:O0k0@0Yl3[102V`>`50:O0j`<0Yl3/2@2W`>/30:O0k0P0Yko[102X`>/40:RojPP0Yl7/
C`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3o
oom80:O0j`P0Yko[202X`>/80:O1k5<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3o
ool00`000000oooo0?ooo`0T0?oood<0Yl3[102X`>/40:Noj`@0Yl7/102X`>/50:O0j`<0Yl7/E`3o
ool010000000oooo0?ooo`0000010?ooo`00@`3oool2000002D0oooo@`2W`>/40:S0j`D0Yl3/0`2W
`N`40:Nojeh0oooo00@000000?ooo`3oool000000@3oool004D0oooo00<000000?ooo`3oool08`3o
oom80:O0j`L0Yko[HP3oool00`000000oooo000000010?ooo`00AP3oool00`000000oooo0?ooo`0S
0?oood<0Yl3[1@2X`>/30:NojfH0oooo0@0000010?ooo`40000000170?ooo`030000003oool0oooo
02<0oooo@`2W`>/40:S0jfX0oooo0P00000004P0oooo0P00000U0?oood80Yl3[K@3oool200000000
BP3oool00`000000oooo0?ooo`0S0?oooch0Yl3[L03oool200000000B`3oool00`000000oooo0?oo
o`0R0?oooc/0Yl3[K`3oool400000080oooo001<0?ooo`030000003oool0oooo02<0oooo<`2W`>]a
0?ooo`@000001P3oool004d0oooo0P00000T0?ooobl0Yl3[L03oool4000000X0oooo001?0?ooo`03
0000003oool0oooo0280oooo:`2W`>]_0?ooo`@000003P3oool00500oooo00<000000?ooo`3oool0
8`3ooolV0:O0jfh0oooo1000000B0?ooo`00D@3oool00`000000oooo0?ooo`0S0?ooob80Yl3[KP3o
ool3000001H0oooo001B0?ooo`800000903ooolN0:O0jfd0oooo1000000I0?ooo`00E03oool00`00
0000oooo0?ooo`0R0?oooaL0Yl3[K`3oool4000001d0oooo001E0?ooo`030000003oool0oooo0240
oooo502W`>]^0?ooo`@000008@3oool005H0oooo00<000000?ooo`3oool08P3oool?0:O0jfd0oooo
1000000U0?ooo`00E`3oool2000002<0oooo2`2W`>]/0?ooo`@00000:@3oool005T0oooo00<00000
0?ooo`3oool08@3oool40:O0jfl0oooo0`00000]0?ooo`00FP3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo06X0oooo1000000`0?ooo`00F`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo06H0oooo1000000d0?ooo`00G03oool200000240oooo00<000000?ooo`3oool0
HP3oool4000003P0oooo001N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3o
ool4000003`0oooo001O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool4
00000400oooo001P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool30000
04@0oooo001Q0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`@00000A`3oool006<0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000B`3oool006@0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`@00000C`3oool006D0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`170?ooo`@00000D`3oool006H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`@00000E`3oool006L0oooo0P00000F0?ooo`03
0000003oool0oooo0400oooo0`00001K0?ooo`00J@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo03`0oooo1000001N0?ooo`00JP3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03P0oooo1000001R0?ooo`00J`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo03@0oooo1000001V0?ooo`00K03oool200000100oooo00<000000?ooo`3oool0<@3oool40000
06X0oooo001^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;@3oool4000006h0
oooo001_0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3oool300000780oooo
001`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool4000007D0oooo001a
0?ooo`8000002`3oool00`000000oooo0?ooo`0R0?ooo`@00000N@3oool007<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000O@3oool007@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000P@3oool007D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0F0?ooo`@00000Q@3oool007H0oooo0P0000060?ooo`030000003o
ool0oooo01<0oooo0`0000290?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00l0oooo1000002<0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo1000002@0?ooo`00NP3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002D0?oo
o`00N`3oool2000000030?ooo`000000oooo00@0oooo1000002H0?ooo`00O@3oool2000000030?oo
o`000000000000800000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66198 Mtetra
.51621 .66198 .52232 .66784 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .66149 .53878 .65559 Mtetra
.53878 .65559 .54483 .66149 .55616 .6583 .55014 .65237 Mtetra
.656 .752 .92 r
.55014 .65237 .55616 .6583 .56753 .6551 .56155 .64913 Mtetra
.656 .751 .92 r
.56155 .64913 .56753 .6551 .57895 .65189 .573 .64588 Mtetra
.656 .75 .92 r
.573 .64588 .57895 .65189 .59042 .64865 .5845 .64263 Mtetra
.655 .751 .92 r
.5845 .64263 .59042 .64865 .60194 .64536 .59604 .63939 Mtetra
.655 .753 .922 r
.59604 .63939 .60194 .64536 .6135 .64208 .60764 .63613 Mtetra
.655 .755 .923 r
.60764 .63613 .6135 .64208 .62511 .6388 .61928 .63284 Mtetra
.656 .756 .923 r
.61928 .63284 .62511 .6388 .63677 .63554 .63098 .6295 Mtetra
.657 .754 .922 r
.63098 .6295 .63677 .63554 .64848 .63227 .64272 .62615 Mtetra
.657 .752 .92 r
.64272 .62615 .64848 .63227 .66024 .62898 .65451 .62278 Mtetra
.656 .75 .919 r
.65451 .62278 .66024 .62898 .67204 .62565 .66635 .61941 Mtetra
.656 .749 .919 r
.66635 .61941 .67204 .62565 .6839 .62231 .67824 .61605 Mtetra
.655 .75 .919 r
.67824 .61605 .6839 .62231 .6958 .61893 .69018 .61269 Mtetra
.655 .751 .92 r
.69018 .61269 .6958 .61893 .70776 .61554 .70217 .60932 Mtetra
.655 .752 .922 r
.70217 .60932 .70776 .61554 .71976 .61212 .71421 .60594 Mtetra
.655 .755 .923 r
.71421 .60594 .71976 .61212 .73182 .60869 .72631 .60253 Mtetra
.656 .757 .924 r
.72631 .60253 .73182 .60869 .74393 .6053 .73845 .59907 Mtetra
.657 .755 .923 r
.73845 .59907 .74393 .6053 .75609 .60192 .75064 .59558 Mtetra
.657 .753 .921 r
.75064 .59558 .75609 .60192 .7683 .59851 .76289 .59208 Mtetra
.656 .75 .919 r
.76289 .59208 .7683 .59851 .78057 .59506 .77519 .5886 Mtetra
.655 .75 .919 r
.77519 .5886 .78057 .59506 .79288 .59157 .78755 .58512 Mtetra
.656 .751 .92 r
.78755 .58512 .79288 .59157 .80525 .58807 .79995 .58161 Mtetra
.656 .752 .92 r
.79995 .58161 .80525 .58807 .81767 .58457 .81241 .57807 Mtetra
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Mtetra
.656 .751 .92 r
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66198 .51005 .65608 Mtetra
.51005 .65608 .51621 .66198 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .64639 Mtetra
.54408 .64639 .55014 .65237 .56155 .64913 .55551 .64314 Mtetra
.655 .752 .921 r
.55551 .64314 .56155 .64913 .573 .64588 .567 .63988 Mtetra
.656 .752 .921 r
.567 .63988 .573 .64588 .5845 .64263 .57853 .63659 Mtetra
.657 .752 .92 r
.57853 .63659 .5845 .64263 .59604 .63939 .59011 .63327 Mtetra
.657 .75 .919 r
.59011 .63327 .59604 .63939 .60764 .63613 .60173 .62993 Mtetra
.656 .748 .917 r
.60173 .62993 .60764 .63613 .61928 .63284 .61341 .6266 Mtetra
.655 .747 .918 r
.61341 .6266 .61928 .63284 .63098 .6295 .62513 .62328 Mtetra
.655 .749 .919 r
.62513 .62328 .63098 .6295 .64272 .62615 .63691 .61996 Mtetra
.655 .751 .92 r
.63691 .61996 .64272 .62615 .65451 .62278 .64873 .61662 Mtetra
.655 .753 .922 r
.64873 .61662 .65451 .62278 .66635 .61941 .66061 .61325 Mtetra
.656 .754 .922 r
.66061 .61325 .66635 .61941 .67824 .61605 .67253 .60985 Mtetra
.67253 .60985 .67824 .61605 .69018 .61269 .68451 .60642 Mtetra
.657 .752 .92 r
.68451 .60642 .69018 .61269 .70217 .60932 .69653 .60297 Mtetra
.657 .75 .919 r
.69653 .60297 .70217 .60932 .71421 .60594 .70861 .5995 Mtetra
.657 .748 .917 r
.70861 .5995 .71421 .60594 .72631 .60253 .72073 .59602 Mtetra
.655 .747 .917 r
.72073 .59602 .72631 .60253 .73845 .59907 .73292 .59258 Mtetra
.655 .748 .918 r
.73292 .59258 .73845 .59907 .75064 .59558 .74515 .58913 Mtetra
.655 .75 .92 r
.74515 .58913 .75064 .59558 .76289 .59208 .75744 .58567 Mtetra
.656 .752 .921 r
.75744 .58567 .76289 .59208 .77519 .5886 .76978 .58216 Mtetra
.656 .753 .921 r
.76978 .58216 .77519 .5886 .78755 .58512 .78217 .57862 Mtetra
.656 .752 .92 r
.78217 .57862 .78755 .58512 .79995 .58161 .79461 .57507 Mtetra
.656 .751 .92 r
.79461 .57507 .79995 .58161 .81241 .57807 .80711 .57151 Mtetra
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54248 Mtetra
.90908 .54248 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .64639 .53797 .64038 Mtetra
.656 .752 .92 r
.53797 .64038 .54408 .64639 .55551 .64314 .54943 .63709 Mtetra
.656 .751 .92 r
.54943 .63709 .55551 .64314 .567 .63988 .56095 .63379 Mtetra
.56095 .63379 .567 .63988 .57853 .63659 .57251 .63048 Mtetra
.655 .751 .92 r
.57251 .63048 .57853 .63659 .59011 .63327 .58412 .62719 Mtetra
.654 .753 .922 r
.58412 .62719 .59011 .63327 .60173 .62993 .59578 .62389 Mtetra
.655 .755 .923 r
.59578 .62389 .60173 .62993 .61341 .6266 .60749 .62055 Mtetra
.656 .756 .923 r
.60749 .62055 .61341 .6266 .62513 .62328 .61925 .61717 Mtetra
.657 .755 .922 r
.61925 .61717 .62513 .62328 .63691 .61996 .63106 .61375 Mtetra
.657 .752 .92 r
.63106 .61375 .63691 .61996 .64873 .61662 .64292 .61033 Mtetra
.656 .75 .919 r
.64292 .61033 .64873 .61662 .66061 .61325 .65482 .6069 Mtetra
.656 .749 .919 r
.65482 .6069 .66061 .61325 .67253 .60985 .66678 .60348 Mtetra
.655 .749 .919 r
.66678 .60348 .67253 .60985 .68451 .60642 .67879 .60007 Mtetra
.655 .75 .92 r
.67879 .60007 .68451 .60642 .69653 .60297 .69085 .59665 Mtetra
.654 .752 .922 r
.69085 .59665 .69653 .60297 .70861 .5995 .70297 .59322 Mtetra
.655 .755 .923 r
.70297 .59322 .70861 .5995 .72073 .59602 .71513 .58976 Mtetra
.656 .757 .924 r
.71513 .58976 .72073 .59602 .73292 .59258 .72735 .58625 Mtetra
.657 .755 .923 r
.72735 .58625 .73292 .59258 .74515 .58913 .73962 .5827 Mtetra
.657 .753 .921 r
.73962 .5827 .74515 .58913 .75744 .58567 .75194 .57915 Mtetra
.656 .751 .92 r
.75194 .57915 .75744 .58567 .76978 .58216 .76431 .57561 Mtetra
.656 .75 .92 r
.76431 .57561 .76978 .58216 .78217 .57862 .77674 .57206 Mtetra
.656 .751 .92 r
.77674 .57206 .78217 .57862 .79461 .57507 .78923 .56849 Mtetra
.656 .752 .92 r
.78923 .56849 .79461 .57507 .80711 .57151 .80176 .5649 Mtetra
.656 .751 .92 r
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54248 .90406 .53563 Mtetra
.90406 .53563 .90908 .54248 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.52036 .6376 .52655 .64364 .53797 .64038 .53181 .6343 Mtetra
.53181 .6343 .53797 .64038 .54943 .63709 .54331 .631 Mtetra
.655 .751 .921 r
.54331 .631 .54943 .63709 .56095 .63379 .55486 .6277 Mtetra
.656 .752 .921 r
.55486 .6277 .56095 .63379 .57251 .63048 .56645 .62437 Mtetra
.656 .753 .921 r
.56645 .62437 .57251 .63048 .58412 .62719 .57809 .621 Mtetra
.656 .751 .919 r
.57809 .621 .58412 .62719 .59578 .62389 .58979 .61762 Mtetra
.655 .749 .919 r
.58979 .61762 .59578 .62389 .60749 .62055 .60153 .61427 Mtetra
.653 .749 .92 r
.60153 .61427 .60749 .62055 .61925 .61717 .61332 .61095 Mtetra
.652 .751 .922 r
.61332 .61095 .61925 .61717 .63106 .61375 .62517 .60764 Mtetra
.652 .756 .925 r
.62517 .60764 .63106 .61375 .64292 .61033 .63706 .60431 Mtetra
.653 .76 .928 r
.63706 .60431 .64292 .61033 .65482 .6069 .64901 .60092 Mtetra
.655 .762 .929 r
.64901 .60092 .65482 .6069 .66678 .60348 .661 .59747 Mtetra
.656 .763 .928 r
.661 .59747 .66678 .60348 .67879 .60007 .67304 .59395 Mtetra
.658 .761 .926 r
.67304 .59395 .67879 .60007 .69085 .59665 .68514 .59039 Mtetra
.658 .757 .923 r
.68514 .59039 .69085 .59665 .70297 .59322 .69728 .5868 Mtetra
.658 .753 .92 r
.69728 .5868 .70297 .59322 .71513 .58976 .70948 .58322 Mtetra
.656 .749 .918 r
.70948 .58322 .71513 .58976 .72735 .58625 .72173 .57969 Mtetra
.655 .749 .919 r
.72173 .57969 .72735 .58625 .73962 .5827 .73404 .57617 Mtetra
.655 .751 .92 r
.73404 .57617 .73962 .5827 .75194 .57915 .7464 .57263 Mtetra
.656 .753 .921 r
.7464 .57263 .75194 .57915 .76431 .57561 .75881 .56906 Mtetra
.656 .752 .921 r
.75881 .56906 .76431 .57561 .77674 .57206 .77128 .56545 Mtetra
.656 .751 .92 r
.77128 .56545 .77674 .57206 .78923 .56849 .7838 .56185 Mtetra
.7838 .56185 .78923 .56849 .80176 .5649 .79637 .55823 Mtetra
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Mtetra
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Mtetra
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Mtetra
.655 .751 .92 r
.51412 .63151 .52036 .6376 .53181 .6343 .52561 .6282 Mtetra
.655 .752 .921 r
.52561 .6282 .53181 .6343 .54331 .631 .53714 .62488 Mtetra
.53714 .62488 .54331 .631 .55486 .6277 .54871 .62157 Mtetra
.652 .752 .923 r
.54871 .62157 .55486 .6277 .56645 .62437 .56034 .61832 Mtetra
.647 .753 .927 r
.56034 .61832 .56645 .62437 .57809 .621 .57202 .61517 Mtetra
.642 .76 .935 r
.57202 .61517 .57809 .621 .58979 .61762 .58375 .61212 Mtetra
.638 .771 .944 r
.58375 .61212 .58979 .61762 .60153 .61427 .59554 .60909 Mtetra
.635 .783 .953 r
.59554 .60909 .60153 .61427 .61332 .61095 .60738 .60605 Mtetra
.633 .794 .959 r
.60738 .60605 .61332 .61095 .62517 .60764 .61927 .60295 Mtetra
.634 .803 .964 r
.61927 .60295 .62517 .60764 .63706 .60431 .63121 .59975 Mtetra
.636 .81 .966 r
.63121 .59975 .63706 .60431 .64901 .60092 .6432 .59643 Mtetra
.641 .815 .967 r
.6432 .59643 .64901 .60092 .661 .59747 .65523 .59296 Mtetra
.647 .817 .965 r
.65523 .59296 .661 .59747 .67304 .59395 .66731 .58934 Mtetra
.653 .816 .962 r
.66731 .58934 .67304 .59395 .68514 .59039 .67944 .58559 Mtetra
.658 .811 .957 r
.67944 .58559 .68514 .59039 .69728 .5868 .69162 .58173 Mtetra
.662 .803 .951 r
.69162 .58173 .69728 .5868 .70948 .58322 .70384 .57782 Mtetra
.665 .793 .943 r
.70384 .57782 .70948 .58322 .72173 .57969 .71611 .57388 Mtetra
.665 .779 .935 r
.71611 .57388 .72173 .57969 .73404 .57617 .72844 .56998 Mtetra
.662 .766 .927 r
.72844 .56998 .73404 .57617 .7464 .57263 .74082 .56617 Mtetra
.659 .757 .922 r
.74082 .56617 .7464 .57263 .75881 .56906 .75326 .56246 Mtetra
.657 .753 .921 r
.75326 .56246 .75881 .56906 .77128 .56545 .76577 .55881 Mtetra
.656 .752 .921 r
.76577 .55881 .77128 .56545 .7838 .56185 .77833 .55517 Mtetra
.77833 .55517 .7838 .56185 .79637 .55823 .79094 .55152 Mtetra
.656 .752 .92 r
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.656 .751 .92 r
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Mtetra
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Mtetra
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .62871 Mtetra
.655 .751 .921 r
.49638 .62871 .50269 .63481 .51412 .63151 .50784 .62541 Mtetra
.653 .752 .922 r
.50784 .62541 .51412 .63151 .52561 .6282 .51935 .62214 Mtetra
.648 .752 .926 r
.51935 .62214 .52561 .6282 .53714 .62488 .53092 .619 Mtetra
.637 .756 .934 r
.53092 .619 .53714 .62488 .54871 .62157 .54253 .61609 Mtetra
.622 .766 .949 r
.54253 .61609 .54871 .62157 .56034 .61832 .5542 .61347 Mtetra
.6 .784 .968 r
.5542 .61347 .56034 .61832 .57202 .61517 .56592 .6111 Mtetra
.569 .805 .988 r
.56592 .6111 .57202 .61517 .58375 .61212 .57771 .60895 Mtetra
.527 .826 .999 r
.57771 .60895 .58375 .61212 .59554 .60909 .58956 .60689 Mtetra
.475 .841 .991 r
.58956 .60689 .59554 .60909 .60738 .60605 .60146 .60476 Mtetra
.422 .843 .959 r
.60146 .60476 .60738 .60605 .61927 .60295 .61342 .6024 Mtetra
.381 .837 .915 r
.61342 .6024 .61927 .60295 .63121 .59975 .62543 .59969 Mtetra
.366 .834 .881 r
.62543 .59969 .63121 .59975 .6432 .59643 .63749 .59659 Mtetra
.379 .843 .869 r
.63749 .59659 .6432 .59643 .65523 .59296 .64958 .59309 Mtetra
.418 .864 .88 r
.64958 .59309 .65523 .59296 .66731 .58934 .66171 .5892 Mtetra
.478 .894 .909 r
.66171 .5892 .66731 .58934 .67944 .58559 .67388 .58492 Mtetra
.55 .919 .944 r
.67388 .58492 .67944 .58559 .69162 .58173 .68608 .58029 Mtetra
.616 .926 .971 r
.68608 .58029 .69162 .58173 .70384 .57782 .69831 .57541 Mtetra
.659 .908 .98 r
.69831 .57541 .70384 .57782 .71611 .57388 .71058 .57046 Mtetra
.678 .875 .973 r
.71058 .57046 .71611 .57388 .72844 .56998 .7229 .56559 Mtetra
.681 .84 .959 r
.7229 .56559 .72844 .56998 .74082 .56617 .73528 .56093 Mtetra
.677 .807 .945 r
.73528 .56093 .74082 .56617 .75326 .56246 .74772 .55653 Mtetra
.669 .781 .933 r
.74772 .55653 .75326 .56246 .76577 .55881 .76023 .55242 Mtetra
.662 .764 .926 r
.76023 .55242 .76577 .55881 .77833 .55517 .77282 .54854 Mtetra
.658 .756 .922 r
.77282 .54854 .77833 .55517 .79094 .55152 .78547 .54478 Mtetra
.657 .753 .921 r
.78547 .54478 .79094 .55152 .80361 .54786 .79817 .54106 Mtetra
.656 .752 .92 r
.79817 .54106 .80361 .54786 .81634 .54418 .81094 .53735 Mtetra
.656 .751 .92 r
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Mtetra
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Mtetra
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62922 Mtetra
.655 .751 .921 r
.46716 .62922 .47359 .63532 .48496 .63202 .47856 .62591 Mtetra
.653 .751 .922 r
.47856 .62591 .48496 .63202 .49638 .62871 .49001 .62264 Mtetra
.647 .752 .926 r
.49001 .62264 .49638 .62871 .50784 .62541 .50151 .61953 Mtetra
.631 .754 .936 r
.50151 .61953 .50784 .62541 .51935 .62214 .51305 .61677 Mtetra
.601 .763 .957 r
.51305 .61677 .51935 .62214 .53092 .619 .52464 .61457 Mtetra
.544 .781 .986 r
.52464 .61457 .53092 .619 .54253 .61609 .5363 .61302 Mtetra
.444 .794 .998 r
.5363 .61302 .54253 .61609 .5542 .61347 .54802 .61196 Mtetra
.3 .77 .937 r
.54802 .61196 .5542 .61347 .56592 .6111 .55981 .61099 Mtetra
.187 .719 .818 r
.55981 .61099 .56592 .6111 .57771 .60895 .57166 .60959 Mtetra
.184 .717 .761 r
.57166 .60959 .57771 .60895 .58956 .60689 .58356 .60743 Mtetra
.286 .787 .814 r
.58356 .60743 .58956 .60689 .60146 .60476 .59551 .60449 Mtetra
.431 .867 .913 r
.59551 .60449 .60146 .60476 .61342 .6024 .60749 .60102 Mtetra
.539 .896 .975 r
.60749 .60102 .61342 .6024 .62543 .59969 .61953 .59735 Mtetra
.589 .884 .992 r
.61953 .59735 .62543 .59969 .63749 .59659 .63162 .59369 Mtetra
.601 .869 .993 r
.63162 .59369 .63749 .59659 .64958 .59309 .64376 .59018 Mtetra
.591 .866 .994 r
.64376 .59018 .64958 .59309 .66171 .5892 .65596 .58682 Mtetra
.565 .876 .993 r
.65596 .58682 .66171 .5892 .67388 .58492 .66822 .58347 Mtetra
.522 .89 .973 r
.66822 .58347 .67388 .58492 .68608 .58029 .68052 .5799 Mtetra
.476 .891 .92 r
.68052 .5799 .68608 .58029 .69831 .57541 .69286 .5758 Mtetra
.466 .891 .867 r
.69286 .5758 .69831 .57541 .71058 .57046 .7052 .5709 Mtetra
.523 .919 .872 r
.7052 .5709 .71058 .57046 .7229 .56559 .71754 .56522 Mtetra
.619 .952 .925 r
.71754 .56522 .7229 .56559 .73528 .56093 .72989 .5591 Mtetra
.686 .939 .964 r
.72989 .5591 .73528 .56093 .74772 .55653 .74229 .55306 Mtetra
.702 .884 .965 r
.74229 .55306 .74772 .55653 .76023 .55242 .75476 .5475 Mtetra
.69 .827 .949 r
.75476 .5475 .76023 .55242 .77282 .54854 .76732 .5426 Mtetra
.674 .786 .934 r
.76732 .5426 .77282 .54854 .78547 .54478 .77997 .53827 Mtetra
.663 .764 .925 r
.77997 .53827 .78547 .54478 .79817 .54106 .7927 .53429 Mtetra
.658 .755 .922 r
.7927 .53429 .79817 .54106 .81094 .53735 .8055 .53048 Mtetra
.656 .752 .921 r
.8055 .53048 .81094 .53735 .82376 .53362 .81836 .52671 Mtetra
.656 .752 .92 r
.81836 .52671 .82376 .53362 .83664 .52988 .83128 .52293 Mtetra
.656 .751 .92 r
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Mtetra
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .62641 Mtetra
.655 .751 .921 r
.44931 .62641 .45581 .63253 .46716 .62922 .46069 .6231 Mtetra
.65 .751 .923 r
.46069 .6231 .46716 .62922 .47856 .62591 .47212 .6199 Mtetra
.637 .752 .931 r
.47212 .6199 .47856 .62591 .49001 .62264 .48359 .61703 Mtetra
.602 .755 .952 r
.48359 .61703 .49001 .62264 .50151 .61953 .49511 .61487 Mtetra
.526 .765 .984 r
.49511 .61487 .50151 .61953 .51305 .61677 .50668 .6137 Mtetra
.374 .761 .989 r
.50668 .6137 .51305 .61677 .52464 .61457 .51831 .61337 Mtetra
.187 .705 .88 r
.51831 .61337 .52464 .61457 .5363 .61302 .53002 .61306 Mtetra
.168 .706 .799 r
.53002 .61306 .5363 .61302 .54802 .61196 .54179 .61169 Mtetra
.4 .85 .909 r
.54179 .61169 .54802 .61196 .55981 .61099 .55361 .60864 Mtetra
.647 .897 .983 r
.55361 .60864 .55981 .61099 .57166 .60959 .56546 .60418 Mtetra
.707 .798 .921 r
.56546 .60418 .57166 .60959 .58356 .60743 .57736 .59907 Mtetra
.695 .711 .86 r
.57736 .59907 .58356 .60743 .59551 .60449 .58929 .59402 Mtetra
.677 .661 .827 r
.58929 .59402 .59551 .60449 .60749 .60102 .60127 .58935 Mtetra
.663 .635 .812 r
.60127 .58935 .60749 .60102 .61953 .59735 .61331 .58511 Mtetra
.653 .622 .806 r
.61331 .58511 .61953 .59735 .63162 .59369 .6254 .58125 Mtetra
.646 .616 .806 r
.6254 .58125 .63162 .59369 .64376 .59018 .63756 .5777 Mtetra
.639 .613 .808 r
.63756 .5777 .64376 .59018 .65596 .58682 .64978 .57448 Mtetra
.631 .612 .813 r
.64978 .57448 .65596 .58682 .66822 .58347 .66208 .57163 Mtetra
.622 .616 .824 r
.66208 .57163 .66822 .58347 .68052 .5799 .67445 .56923 Mtetra
.613 .633 .847 r
.67445 .56923 .68052 .5799 .69286 .5758 .68691 .56721 Mtetra
.607 .678 .892 r
.68691 .56721 .69286 .5758 .7052 .5709 .69943 .56524 Mtetra
.609 .771 .958 r
.69943 .56524 .7052 .5709 .71754 .56522 .71199 .56262 Mtetra
.607 .889 .99 r
.71199 .56262 .71754 .56522 .72989 .5591 .72453 .55855 Mtetra
.602 .944 .932 r
.72453 .55855 .72989 .5591 .74229 .55306 .73701 .55277 Mtetra
.651 .964 .915 r
.73701 .55277 .74229 .55306 .75476 .5475 .74946 .54589 Mtetra
.711 .953 .951 r
.74946 .54589 .75476 .5475 .76732 .5426 .76194 .53903 Mtetra
.717 .888 .959 r
.76194 .53903 .76732 .5426 .77997 .53827 .77452 .533 Mtetra
.692 .819 .943 r
.77452 .533 .77997 .53827 .7927 .53429 .78722 .528 Mtetra
.671 .777 .929 r
.78722 .528 .7927 .53429 .8055 .53048 .80003 .52371 Mtetra
.66 .759 .923 r
.80003 .52371 .8055 .53048 .81836 .52671 .81292 .51977 Mtetra
.657 .753 .921 r
.81292 .51977 .81836 .52671 .83128 .52293 .82588 .51593 Mtetra
.656 .752 .92 r
.82588 .51593 .83128 .52293 .84426 .51914 .83889 .51211 Mtetra
.656 .751 .92 r
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Mtetra
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62358 Mtetra
.654 .751 .921 r
.43138 .62358 .43797 .62973 .44931 .62641 .44275 .62028 Mtetra
.647 .751 .925 r
.44275 .62028 .44931 .62641 .46069 .6231 .45416 .61714 Mtetra
.625 .751 .937 r
.45416 .61714 .46069 .6231 .47212 .6199 .46561 .61454 Mtetra
.565 .753 .966 r
.46561 .61454 .47212 .6199 .48359 .61703 .47709 .61302 Mtetra
.421 .747 .994 r
.47709 .61302 .48359 .61703 .49511 .61487 .48863 .61284 Mtetra
.189 .688 .914 r
.48863 .61284 .49511 .61487 .50668 .6137 .50023 .61326 Mtetra
.143 .685 .818 r
.50023 .61326 .50668 .6137 .51831 .61337 .51191 .61257 Mtetra
.458 .871 .95 r
.51191 .61257 .51831 .61337 .53002 .61306 .52366 .60949 Mtetra
.705 .862 .957 r
.52366 .60949 .53002 .61306 .54179 .61169 .53546 .60429 Mtetra
.719 .74 .868 r
.53546 .60429 .54179 .61169 .55361 .60864 .54729 .59841 Mtetra
.692 .67 .824 r
.54729 .59841 .55361 .60864 .56546 .60418 .55916 .59301 Mtetra
.672 .647 .816 r
.55916 .59301 .56546 .60418 .57736 .59907 .57108 .58842 Mtetra
.662 .652 .829 r
.57108 .58842 .57736 .59907 .58929 .59402 .58305 .5844 Mtetra
.659 .671 .851 r
.58305 .5844 .58929 .59402 .60127 .58935 .59508 .58065 Mtetra
.658 .692 .871 r
.59508 .58065 .60127 .58935 .61331 .58511 .60716 .57701 Mtetra
.657 .708 .885 r
.60716 .57701 .61331 .58511 .6254 .58125 .61929 .57342 Mtetra
.656 .715 .892 r
.61929 .57342 .6254 .58125 .63756 .5777 .63148 .56985 Mtetra
.655 .715 .892 r
.63148 .56985 .63756 .5777 .64978 .57448 .64373 .56631 Mtetra
.653 .707 .886 r
.64373 .56631 .64978 .57448 .66208 .57163 .65603 .5628 Mtetra
.649 .689 .874 r
.65603 .5628 .66208 .57163 .67445 .56923 .66839 .5594 Mtetra
.641 .664 .857 r
.66839 .5594 .67445 .56923 .68691 .56721 .68081 .55628 Mtetra
.625 .636 .841 r
.68081 .55628 .68691 .56721 .69943 .56524 .69333 .55374 Mtetra
.604 .616 .836 r
.69333 .55374 .69943 .56524 .71199 .56262 .70596 .55201 Mtetra
.59 .626 .856 r
.70596 .55201 .71199 .56262 .72453 .55855 .71868 .55077 Mtetra
.599 .701 .915 r
.71868 .55077 .72453 .55855 .73701 .55277 .73144 .54883 Mtetra
.643 .853 .98 r
.73144 .54883 .73701 .55277 .74946 .54589 .74413 .54472 Mtetra
.676 .957 .947 r
.74413 .54472 .74946 .54589 .76194 .53903 .7567 .53815 Mtetra
.717 .974 .926 r
.7567 .53815 .76194 .53903 .77452 .533 .76922 .53045 Mtetra
.74 .932 .952 r
.76922 .53045 .77452 .533 .78722 .528 .78182 .52334 Mtetra
.712 .85 .948 r
.78182 .52334 .78722 .528 .80003 .52371 .79457 .51761 Mtetra
.679 .789 .933 r
.79457 .51761 .80003 .52371 .81292 .51977 .80745 .51299 Mtetra
.663 .762 .924 r
.80745 .51299 .81292 .51977 .82588 .51593 .82043 .50892 Mtetra
.657 .754 .921 r
.82043 .50892 .82588 .51593 .83889 .51211 .83349 .50502 Mtetra
.656 .752 .92 r
.83349 .50502 .83889 .51211 .85197 .50827 .84661 .50114 Mtetra
.656 .751 .92 r
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Mtetra
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Mtetra
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62075 Mtetra
.654 .751 .921 r
.4134 .62075 .42007 .62691 .43138 .62358 .42475 .61743 Mtetra
.646 .75 .925 r
.42475 .61743 .43138 .62358 .44275 .62028 .43613 .61432 Mtetra
.618 .749 .94 r
.43613 .61432 .44275 .62028 .45416 .61714 .44756 .61187 Mtetra
.534 .746 .973 r
.44756 .61187 .45416 .61714 .46561 .61454 .45901 .61083 Mtetra
.327 .714 .982 r
.45901 .61083 .46561 .61454 .47709 .61302 .4705 .6114 Mtetra
.09 .631 .852 r
.4705 .6114 .47709 .61302 .48863 .61284 .48206 .6122 Mtetra
.253 .757 .88 r
.48206 .6122 .48863 .61284 .50023 .61326 .49372 .61083 Mtetra
.656 .894 .982 r
.49372 .61083 .50023 .61326 .51191 .61257 .50547 .60632 Mtetra
.734 .775 .886 r
.50547 .60632 .51191 .61257 .52366 .60949 .51726 .60009 Mtetra
.708 .692 .833 r
.51726 .60009 .52366 .60949 .53546 .60429 .52908 .59415 Mtetra
.685 .67 .829 r
.52908 .59415 .53546 .60429 .54729 .59841 .54094 .58916 Mtetra
.675 .685 .851 r
.54094 .58916 .54729 .59841 .55916 .59301 .55284 .58479 Mtetra
.673 .708 .874 r
.55284 .58479 .55916 .59301 .57108 .58842 .5648 .58064 Mtetra
.671 .72 .885 r
.5648 .58064 .57108 .58842 .58305 .5844 .5768 .57656 Mtetra
.668 .718 .886 r
.5768 .57656 .58305 .5844 .59508 .58065 .58886 .57259 Mtetra
.664 .712 .884 r
.58886 .57259 .59508 .58065 .60716 .57701 .60096 .56875 Mtetra
.659 .706 .881 r
.60096 .56875 .60716 .57701 .61929 .57342 .61313 .56503 Mtetra
.656 .702 .881 r
.61313 .56503 .61929 .57342 .63148 .56985 .62534 .56143 Mtetra
.652 .701 .882 r
.62534 .56143 .63148 .56985 .64373 .56631 .63762 .55795 Mtetra
.648 .701 .885 r
.63762 .55795 .64373 .56631 .65603 .5628 .64996 .55459 Mtetra
.644 .704 .891 r
.64996 .55459 .65603 .5628 .66839 .5594 .66236 .55137 Mtetra
.64 .708 .897 r
.66236 .55137 .66839 .5594 .68081 .55628 .67482 .54825 Mtetra
.637 .708 .898 r
.67482 .54825 .68081 .55628 .69333 .55374 .68734 .54522 Mtetra
.631 .693 .89 r
.68734 .54522 .69333 .55374 .70596 .55201 .69994 .54239 Mtetra
.614 .66 .872 r
.69994 .54239 .70596 .55201 .71868 .55077 .71264 .54018 Mtetra
.588 .628 .859 r
.71264 .54018 .71868 .55077 .73144 .54883 .72546 .53895 Mtetra
.576 .639 .876 r
.72546 .53895 .73144 .54883 .74413 .54472 .73838 .53799 Mtetra
.617 .744 .937 r
.73838 .53799 .74413 .54472 .7567 .53815 .75126 .53528 Mtetra
.698 .913 .969 r
.75126 .53528 .7567 .53815 .76922 .53045 .76397 .52933 Mtetra
.742 .974 .925 r
.76397 .52933 .76922 .53045 .78182 .52334 .77656 .52116 Mtetra
.76 .95 .939 r
.77656 .52116 .78182 .52334 .79457 .51761 .7892 .51321 Mtetra
.727 .866 .947 r
.7892 .51321 .79457 .51761 .80745 .51299 .80199 .50691 Mtetra
.685 .795 .933 r
.80199 .50691 .80745 .51299 .82043 .50892 .81496 .50207 Mtetra
.664 .763 .924 r
.81496 .50207 .82043 .50892 .83349 .50502 .82804 .49791 Mtetra
.657 .754 .921 r
.82804 .49791 .83349 .50502 .84661 .50114 .8412 .49396 Mtetra
.656 .752 .92 r
.8412 .49396 .84661 .50114 .85979 .49725 .85442 .49003 Mtetra
.656 .751 .92 r
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Mtetra
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Mtetra
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Mtetra
.654 .751 .921 r
.39535 .6179 .4021 .62409 .4134 .62075 .40668 .61456 Mtetra
.647 .75 .924 r
.40668 .61456 .4134 .62075 .42475 .61743 .41805 .6114 Mtetra
.619 .748 .938 r
.41805 .6114 .42475 .61743 .43613 .61432 .42945 .60892 Mtetra
.525 .739 .972 r
.42945 .60892 .43613 .61432 .44756 .61187 .44087 .60804 Mtetra
.28 .685 .971 r
.44087 .60804 .44756 .61187 .45901 .61083 .45231 .60911 Mtetra
.034 .587 .824 r
.45231 .60911 .45901 .61083 .4705 .6114 .46382 .61041 Mtetra
.308 .786 .918 r
.46382 .61041 .4705 .6114 .48206 .6122 .47546 .6089 Mtetra
.704 .871 .96 r
.47546 .6089 .48206 .6122 .49372 .61083 .4872 .60368 Mtetra
.74 .751 .862 r
.4872 .60368 .49372 .61083 .50547 .60632 .49899 .59689 Mtetra
.712 .693 .83 r
.49899 .59689 .50547 .60632 .51726 .60009 .51081 .59069 Mtetra
.694 .688 .84 r
.51081 .59069 .51726 .60009 .52908 .59415 .52266 .58544 Mtetra
.684 .7 .859 r
.52266 .58544 .52908 .59415 .54094 .58916 .53455 .58076 Mtetra
.675 .705 .87 r
.53455 .58076 .54094 .58916 .55284 .58479 .54649 .57647 Mtetra
.667 .705 .876 r
.54649 .57647 .55284 .58479 .5648 .58064 .55847 .57252 Mtetra
.66 .709 .884 r
.55847 .57252 .5648 .58064 .5768 .57656 .57051 .5688 Mtetra
.657 .718 .893 r
.57051 .5688 .5768 .57656 .58886 .57259 .5826 .56518 Mtetra
.656 .728 .902 r
.5826 .56518 .58886 .57259 .60096 .56875 .59475 .56157 Mtetra
.656 .736 .909 r
.59475 .56157 .60096 .56875 .61313 .56503 .60695 .55796 Mtetra
.656 .74 .912 r
.60695 .55796 .61313 .56503 .62534 .56143 .6192 .55434 Mtetra
.6192 .55434 .62534 .56143 .63762 .55795 .63151 .55069 Mtetra
.656 .736 .909 r
.63151 .55069 .63762 .55795 .64996 .55459 .64387 .54704 Mtetra
.655 .728 .903 r
.64387 .54704 .64996 .55459 .66236 .55137 .65629 .54341 Mtetra
.651 .716 .896 r
.65629 .54341 .66236 .55137 .67482 .54825 .66876 .53988 Mtetra
.644 .703 .89 r
.66876 .53988 .67482 .54825 .68734 .54522 .68131 .53657 Mtetra
.634 .693 .887 r
.68131 .53657 .68734 .54522 .69994 .54239 .69393 .5336 Mtetra
.622 .685 .889 r
.69393 .5336 .69994 .54239 .71264 .54018 .70664 .53104 Mtetra
.605 .67 .886 r
.70664 .53104 .71264 .54018 .72546 .53895 .71945 .52905 Mtetra
.577 .64 .876 r
.71945 .52905 .72546 .53895 .73838 .53799 .73239 .52802 Mtetra
.559 .63 .879 r
.73239 .52802 .73838 .53799 .75126 .53528 .74544 .52758 Mtetra
.598 .708 .921 r
.74544 .52758 .75126 .53528 .76397 .52933 .75847 .52552 Mtetra
.708 .883 .962 r
.75847 .52552 .76397 .52933 .77656 .52116 .7713 .51964 Mtetra
.773 .97 .922 r
.7713 .51964 .77656 .52116 .7892 .51321 .78394 .51086 Mtetra
.779 .949 .93 r
.78394 .51086 .7892 .51321 .80199 .50691 .79662 .50232 Mtetra
.733 .864 .942 r
.79662 .50232 .80199 .50691 .81496 .50207 .8095 .4958 Mtetra
.684 .791 .931 r
.8095 .4958 .81496 .50207 .82804 .49791 .82256 .49092 Mtetra
.663 .761 .923 r
.82256 .49092 .82804 .49791 .8412 .49396 .83575 .48675 Mtetra
.657 .753 .921 r
.83575 .48675 .8412 .49396 .85442 .49003 .84901 .48275 Mtetra
.656 .752 .92 r
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Mtetra
.656 .751 .92 r
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Mtetra
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Mtetra
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Mtetra
.655 .751 .921 r
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61167 Mtetra
.65 .751 .923 r
.38855 .61167 .39535 .6179 .40668 .61456 .3999 .60842 Mtetra
.628 .748 .934 r
.3999 .60842 .40668 .61456 .41805 .6114 .41129 .60573 Mtetra
.544 .737 .965 r
.41129 .60573 .41805 .6114 .42945 .60892 .42268 .60461 Mtetra
.296 .676 .974 r
.42268 .60461 .42945 .60892 .44087 .60804 .43407 .60585 Mtetra
0 .536 .81 r
.43407 .60585 .44087 .60804 .45231 .60911 .44552 .60796 Mtetra
.231 .736 .896 r
.44552 .60796 .45231 .60911 .46382 .61041 .45712 .60721 Mtetra
.705 .875 .961 r
.45712 .60721 .46382 .61041 .47546 .6089 .46885 .60194 Mtetra
.754 .759 .857 r
.46885 .60194 .47546 .6089 .4872 .60368 .48066 .59447 Mtetra
.727 .702 .827 r
.48066 .59447 .4872 .60368 .49899 .59689 .49248 .58756 Mtetra
.702 .693 .838 r
.49248 .58756 .49899 .59689 .51081 .59069 .50432 .58191 Mtetra
.684 .699 .859 r
.50432 .58191 .51081 .59069 .52266 .58544 .5162 .57723 Mtetra
.671 .709 .877 r
.5162 .57723 .52266 .58544 .53455 .58076 .52812 .57314 Mtetra
.665 .724 .893 r
.52812 .57314 .53455 .58076 .54649 .57647 .54009 .56928 Mtetra
.664 .736 .904 r
.54009 .56928 .54649 .57647 .55847 .57252 .55211 .56543 Mtetra
.665 .74 .906 r
.55211 .56543 .55847 .57252 .57051 .5688 .56418 .56155 Mtetra
.664 .736 .904 r
.56418 .56155 .57051 .5688 .5826 .56518 .5763 .55769 Mtetra
.661 .73 .9 r
.5763 .55769 .5826 .56518 .59475 .56157 .58848 .5539 Mtetra
.659 .724 .897 r
.58848 .5539 .59475 .56157 .60695 .55796 .60071 .55017 Mtetra
.656 .721 .897 r
.60071 .55017 .60695 .55796 .6192 .55434 .61299 .54652 Mtetra
.653 .72 .898 r
.61299 .54652 .6192 .55434 .63151 .55069 .62533 .54293 Mtetra
.651 .722 .9 r
.62533 .54293 .63151 .55069 .64387 .54704 .63773 .53941 Mtetra
.648 .725 .905 r
.63773 .53941 .64387 .54704 .65629 .54341 .65019 .53596 Mtetra
.647 .731 .91 r
.65019 .53596 .65629 .54341 .66876 .53988 .66271 .53253 Mtetra
.647 .735 .913 r
.66271 .53253 .66876 .53988 .68131 .53657 .67529 .52907 Mtetra
.646 .731 .911 r
.67529 .52907 .68131 .53657 .69393 .5336 .68792 .52562 Mtetra
.639 .715 .902 r
.68792 .52562 .69393 .5336 .70664 .53104 .70063 .52239 Mtetra
.622 .691 .894 r
.70063 .52239 .70664 .53104 .71945 .52905 .71343 .51977 Mtetra
.593 .663 .888 r
.71343 .51977 .71945 .52905 .73239 .52802 .72636 .51812 Mtetra
.554 .631 .882 r
.72636 .51812 .73239 .52802 .74544 .52758 .73945 .51776 Mtetra
.534 .624 .887 r
.73945 .51776 .74544 .52758 .75847 .52552 .75267 .51795 Mtetra
.595 .714 .927 r
.75267 .51795 .75847 .52552 .7713 .51964 .76581 .51588 Mtetra
.735 .894 .951 r
.76581 .51588 .7713 .51964 .78394 .51086 .77867 .50913 Mtetra
.803 .968 .909 r
.77867 .50913 .78394 .51086 .79662 .50232 .79133 .49944 Mtetra
.79 .935 .926 r
.79133 .49944 .79662 .50232 .8095 .4958 .80408 .49064 Mtetra
.727 .845 .937 r
.80408 .49064 .8095 .4958 .82256 .49092 .81707 .48429 Mtetra
.678 .781 .927 r
.81707 .48429 .82256 .49092 .83575 .48675 .83026 .47957 Mtetra
.66 .757 .922 r
.83026 .47957 .83575 .48675 .84901 .48275 .84355 .47543 Mtetra
.656 .752 .92 r
.84355 .47543 .84901 .48275 .86234 .47878 .85692 .4714 Mtetra
.656 .751 .92 r
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Mtetra
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Mtetra
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Mtetra
.653 .751 .921 r
.37035 .60878 .37724 .61504 .38855 .61167 .38169 .60544 Mtetra
.64 .749 .928 r
.38169 .60544 .38855 .61167 .3999 .60842 .39306 .60245 Mtetra
.581 .74 .952 r
.39306 .60245 .3999 .60842 .41129 .60573 .40444 .60073 Mtetra
.374 .691 .981 r
.40444 .60073 .41129 .60573 .42268 .60461 .4158 .60158 Mtetra
0 .505 .826 r
.4158 .60158 .42268 .60461 .43407 .60585 .42718 .6045 Mtetra
.022 .585 .799 r
.42718 .6045 .43407 .60585 .44552 .60796 .43869 .60553 Mtetra
.646 .891 .984 r
.43869 .60553 .44552 .60796 .45712 .60721 .45041 .60117 Mtetra
.773 .787 .864 r
.45041 .60117 .45712 .60721 .46885 .60194 .46223 .59308 Mtetra
.747 .716 .822 r
.46223 .59308 .46885 .60194 .48066 .59447 .47408 .58509 Mtetra
.714 .696 .832 r
.47408 .58509 .48066 .59447 .49248 .58756 .48592 .57882 Mtetra
.689 .703 .858 r
.48592 .57882 .49248 .58756 .50432 .58191 .49779 .57392 Mtetra
.676 .717 .88 r
.49779 .57392 .50432 .58191 .5162 .57723 .50969 .56963 Mtetra
.672 .727 .891 r
.50969 .56963 .5162 .57723 .52812 .57314 .52164 .56551 Mtetra
.668 .726 .893 r
.52164 .56551 .52812 .57314 .54009 .56928 .53364 .56152 Mtetra
.662 .721 .893 r
.53364 .56152 .54009 .56928 .55211 .56543 .54569 .55771 Mtetra
.657 .722 .896 r
.54569 .55771 .55211 .56543 .56418 .56155 .5578 .55404 Mtetra
.655 .728 .902 r
.5578 .55404 .56418 .56155 .5763 .55769 .56996 .55042 Mtetra
.655 .735 .909 r
.56996 .55042 .5763 .55769 .58848 .5539 .58217 .5468 Mtetra
.655 .741 .913 r
.58217 .5468 .58848 .5539 .60071 .55017 .59443 .54315 Mtetra
.655 .745 .916 r
.59443 .54315 .60071 .55017 .61299 .54652 .60676 .53947 Mtetra
.656 .745 .915 r
.60676 .53947 .61299 .54652 .62533 .54293 .61913 .53575 Mtetra
.657 .742 .913 r
.61913 .53575 .62533 .54293 .63773 .53941 .63156 .532 Mtetra
.656 .736 .908 r
.63156 .532 .63773 .53941 .65019 .53596 .64404 .52825 Mtetra
.654 .728 .903 r
.64404 .52825 .65019 .53596 .66271 .53253 .65659 .52454 Mtetra
.65 .719 .899 r
.65659 .52454 .66271 .53253 .67529 .52907 .66919 .52098 Mtetra
.644 .715 .9 r
.66919 .52098 .67529 .52907 .68792 .52562 .68187 .5176 Mtetra
.639 .716 .903 r
.68187 .5176 .68792 .52562 .70063 .52239 .69461 .51435 Mtetra
.633 .714 .905 r
.69461 .51435 .70063 .52239 .71343 .51977 .70742 .51128 Mtetra
.614 .695 .901 r
.70742 .51128 .71343 .51977 .72636 .51812 .72034 .50881 Mtetra
.572 .655 .893 r
.72034 .50881 .72636 .51812 .73945 .51776 .73341 .50774 Mtetra
.517 .612 .886 r
.73341 .50774 .73945 .51776 .75267 .51795 .74668 .50842 Mtetra
.508 .62 .897 r
.74668 .50842 .75267 .51795 .76581 .51588 .76006 .50919 Mtetra
.624 .757 .942 r
.76006 .50919 .76581 .51588 .77867 .50913 .77324 .50609 Mtetra
.787 .929 .928 r
.77324 .50609 .77867 .50913 .79133 .49944 .78605 .49743 Mtetra
.829 .963 .895 r
.78605 .49743 .79133 .49944 .80408 .49064 .79873 .48682 Mtetra
.784 .905 .926 r
.79873 .48682 .80408 .49064 .81707 .48429 .8116 .47835 Mtetra
.709 .815 .931 r
.8116 .47835 .81707 .48429 .83026 .47957 .82474 .47255 Mtetra
.669 .768 .924 r
.82474 .47255 .83026 .47957 .84355 .47543 .83805 .46808 Mtetra
.658 .754 .921 r
.83805 .46808 .84355 .47543 .85692 .4714 .85146 .46397 Mtetra
.656 .752 .92 r
.85146 .46397 .85692 .4714 .87035 .46738 .86494 .45991 Mtetra
.656 .751 .92 r
.86494 .45991 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Mtetra
.655 .751 .921 r
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60249 Mtetra
.649 .75 .923 r
.36341 .60249 .37035 .60878 .38169 .60544 .37478 .59924 Mtetra
.617 .745 .937 r
.37478 .59924 .38169 .60544 .39306 .60245 .38616 .59677 Mtetra
.484 .716 .973 r
.38616 .59677 .39306 .60245 .40444 .60073 .39751 .59655 Mtetra
.075 .549 .9 r
.39751 .59655 .40444 .60073 .4158 .60158 .40882 .59952 Mtetra
.201 0 0 r
.40882 .59952 .4158 .60158 .42718 .6045 .42022 .60289 Mtetra
.393 .819 .965 r
.42022 .60289 .42718 .6045 .43869 .60553 .43185 .60112 Mtetra
.782 .838 .895 r
.43185 .60112 .43869 .60553 .45041 .60117 .44368 .59321 Mtetra
.777 .741 .82 r
.44368 .59321 .45041 .60117 .46223 .59308 .45557 .58371 Mtetra
.736 .704 .82 r
.45557 .58371 .46223 .59308 .47408 .58509 .46744 .57613 Mtetra
.702 .703 .848 r
.46744 .57613 .47408 .58509 .48592 .57882 .47931 .57058 Mtetra
.681 .713 .873 r
.47931 .57058 .48592 .57882 .49779 .57392 .4912 .56604 Mtetra
.67 .72 .886 r
.4912 .56604 .49779 .57392 .50969 .56963 .50313 .56197 Mtetra
.662 .724 .895 r
.50313 .56197 .50969 .56963 .52164 .56551 .51511 .55817 Mtetra
.659 .733 .904 r
.51511 .55817 .52164 .56551 .53364 .56152 .52715 .55447 Mtetra
.66 .742 .911 r
.52715 .55447 .53364 .56152 .54569 .55771 .53923 .55071 Mtetra
.661 .745 .912 r
.53923 .55071 .54569 .55771 .5578 .55404 .55137 .54689 Mtetra
.661 .741 .91 r
.55137 .54689 .5578 .55404 .56996 .55042 .56356 .54305 Mtetra
.66 .735 .906 r
.56356 .54305 .56996 .55042 .58217 .5468 .5758 .53924 Mtetra
.658 .73 .903 r
.5758 .53924 .58217 .5468 .59443 .54315 .5881 .53548 Mtetra
.656 .727 .902 r
.5881 .53548 .59443 .54315 .60676 .53947 .60046 .53177 Mtetra
.654 .727 .903 r
.60046 .53177 .60676 .53947 .61913 .53575 .61287 .5281 Mtetra
.652 .728 .905 r
.61287 .5281 .61913 .53575 .63156 .532 .62533 .52448 Mtetra
.65 .732 .909 r
.62533 .52448 .63156 .532 .64404 .52825 .63786 .52089 Mtetra
.65 .738 .914 r
.63786 .52089 .64404 .52825 .65659 .52454 .65045 .51729 Mtetra
.651 .742 .916 r
.65045 .51729 .65659 .52454 .66919 .52098 .66309 .51361 Mtetra
.653 .74 .914 r
.66309 .51361 .66919 .52098 .68187 .5176 .67578 .50988 Mtetra
.65 .73 .908 r
.67578 .50988 .68187 .5176 .69461 .51435 .68854 .50624 Mtetra
.641 .717 .903 r
.68854 .50624 .69461 .51435 .70742 .51128 .70138 .50289 Mtetra
.626 .704 .901 r
.70138 .50289 .70742 .51128 .72034 .50881 .71431 .5 Mtetra
.594 .68 .901 r
.71431 .5 .72034 .50881 .73341 .50774 .72736 .49815 Mtetra
.528 .629 .895 r
.72736 .49815 .73341 .50774 .74668 .50842 .74063 .49836 Mtetra
.459 .582 .89 r
.74063 .49836 .74668 .50842 .76006 .50919 .75412 .50052 Mtetra
.503 .643 .918 r
.75412 .50052 .76006 .50919 .77324 .50609 .76761 .50102 Mtetra
.709 .845 .947 r
.76761 .50102 .77324 .50609 .78605 .49743 .7807 .49516 Mtetra
.842 .956 .887 r
.7807 .49516 .78605 .49743 .79873 .48682 .79341 .484 Mtetra
.835 .942 .894 r
.79341 .484 .79873 .48682 .8116 .47835 .80615 .47326 Mtetra
.755 .859 .926 r
.80615 .47326 .8116 .47835 .82474 .47255 .81921 .46584 Mtetra
.686 .785 .926 r
.81921 .46584 .82474 .47255 .83805 .46808 .83251 .46075 Mtetra
.662 .758 .922 r
.83251 .46075 .83805 .46808 .85146 .46397 .84596 .45648 Mtetra
.656 .752 .92 r
.84596 .45648 .85146 .46397 .86494 .45991 .85948 .45237 Mtetra
.656 .751 .92 r
.85948 .45237 .86494 .45991 .87848 .45583 .87306 .44826 Mtetra
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Mtetra
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59956 Mtetra
.654 .751 .921 r
.34507 .59956 .35209 .60589 .36341 .60249 .35642 .59616 Mtetra
.641 .749 .927 r
.35642 .59616 .36341 .60249 .37478 .59924 .3678 .5931 Mtetra
.576 .735 .951 r
.3678 .5931 .37478 .59924 .38616 .59677 .37917 .59146 Mtetra
.309 .648 .969 r
.37917 .59146 .38616 .59677 .39751 .59655 .39048 .59313 Mtetra
0 .333 .697 r
.39048 .59313 .39751 .59655 .40882 .59952 .40175 .59794 Mtetra
0 .447 .698 r
.40175 .59794 .40882 .59952 .42022 .60289 .41321 .60042 Mtetra
.697 .9 .969 r
.41321 .60042 .42022 .60289 .43185 .60112 .42498 .59504 Mtetra
.812 .788 .83 r
.42498 .59504 .43185 .60112 .44368 .59321 .43694 .5843 Mtetra
.774 .722 .805 r
.43694 .5843 .44368 .59321 .45557 .58371 .44887 .57438 Mtetra
.725 .703 .829 r
.44887 .57438 .45557 .58371 .46744 .57613 .46076 .56748 Mtetra
.689 .707 .861 r
.46076 .56748 .46744 .57613 .47931 .57058 .47264 .56256 Mtetra
.67 .717 .884 r
.47264 .56256 .47931 .57058 .4912 .56604 .48456 .55845 Mtetra
.664 .727 .896 r
.48456 .55845 .4912 .56604 .50313 .56197 .49652 .55456 Mtetra
.664 .733 .901 r
.49652 .55456 .50313 .56197 .51511 .55817 .50854 .55065 Mtetra
.663 .73 .9 r
.50854 .55065 .51511 .55817 .52715 .55447 .5206 .54678 Mtetra
.659 .726 .899 r
.5206 .54678 .52715 .55447 .53923 .55071 .53272 .54303 Mtetra
.655 .725 .901 r
.53272 .54303 .53923 .55071 .55137 .54689 .54489 .53938 Mtetra
.653 .731 .906 r
.54489 .53938 .55137 .54689 .56356 .54305 .55712 .53576 Mtetra
.653 .738 .911 r
.55712 .53576 .56356 .54305 .5758 .53924 .5694 .53212 Mtetra
.654 .744 .916 r
.5694 .53212 .5758 .53924 .5881 .53548 .58173 .52843 Mtetra
.655 .747 .917 r
.58173 .52843 .5881 .53548 .60046 .53177 .59412 .52469 Mtetra
.656 .747 .917 r
.59412 .52469 .60046 .53177 .61287 .5281 .60657 .52089 Mtetra
.658 .745 .914 r
.60657 .52089 .61287 .5281 .62533 .52448 .61906 .51704 Mtetra
.658 .739 .91 r
.61906 .51704 .62533 .52448 .63786 .52089 .63162 .51317 Mtetra
.657 .732 .905 r
.63162 .51317 .63786 .52089 .65045 .51729 .64423 .50933 Mtetra
.653 .725 .902 r
.64423 .50933 .65045 .51729 .66309 .51361 .65691 .5056 Mtetra
.649 .722 .902 r
.65691 .5056 .66309 .51361 .67578 .50988 .66965 .50198 Mtetra
.647 .726 .906 r
.66965 .50198 .67578 .50988 .68854 .50624 .68245 .49839 Mtetra
.647 .728 .908 r
.68245 .49839 .68854 .50624 .70138 .50289 .69531 .49479 Mtetra
.64 .72 .905 r
.69531 .49479 .70138 .50289 .71431 .5 .70824 .49141 Mtetra
.615 .696 .902 r
.70824 .49141 .71431 .5 .72736 .49815 .72129 .48886 Mtetra
.55 .649 .9 r
.72129 .48886 .72736 .49815 .74063 .49836 .73454 .48833 Mtetra
.44 .574 .892 r
.73454 .48833 .74063 .49836 .75412 .50052 .74808 .49087 Mtetra
.396 .56 .899 r
.74808 .49087 .75412 .50052 .76761 .50102 .7618 .49423 Mtetra
.586 .743 .951 r
.7618 .49423 .76761 .50102 .7807 .49516 .77522 .49202 Mtetra
.826 .931 .901 r
.77522 .49202 .7807 .49516 .79341 .484 .78807 .48168 Mtetra
.871 .952 .86 r
.78807 .48168 .79341 .484 .80615 .47326 .80073 .46896 Mtetra
.806 .895 .907 r
.80073 .46896 .80615 .47326 .81921 .46584 .81366 .4595 Mtetra
.713 .808 .924 r
.81366 .4595 .81921 .46584 .83251 .46075 .82694 .45348 Mtetra
.668 .764 .922 r
.82694 .45348 .83251 .46075 .84596 .45648 .8404 .44895 Mtetra
.658 .753 .921 r
.8404 .44895 .84596 .45648 .85948 .45237 .85397 .44477 Mtetra
.656 .752 .92 r
.85397 .44477 .85948 .45237 .87306 .44826 .8676 .44062 Mtetra
.656 .751 .92 r
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Mtetra
.655 .751 .92 r
.32666 .59663 .33376 .60299 .34507 .59956 .33799 .59318 Mtetra
.652 .751 .922 r
.33799 .59318 .34507 .59956 .35642 .59616 .34937 .58981 Mtetra
.628 .746 .932 r
.34937 .58981 .35642 .59616 .3678 .5931 .36076 .58704 Mtetra
.511 .716 .965 r
.36076 .58704 .3678 .5931 .37917 .59146 .37211 .5865 Mtetra
.044 .503 .887 r
.37211 .5865 .37917 .59146 .39048 .59313 .38335 .59027 Mtetra
.427 0 0 r
.38335 .59027 .39048 .59313 .40175 .59794 .3946 .59644 Mtetra
.087 .632 .84 r
.3946 .59644 .40175 .59794 .41321 .60042 .40616 .59705 Mtetra
.812 .87 .89 r
.40616 .59705 .41321 .60042 .42498 .59504 .4181 .58786 Mtetra
.823 .763 .795 r
.4181 .58786 .42498 .59504 .43694 .5843 .43015 .57499 Mtetra
.769 .715 .802 r
.43015 .57499 .43694 .5843 .44887 .57438 .44212 .56518 Mtetra
.711 .702 .84 r
.44212 .56518 .44887 .57438 .46076 .56748 .45402 .55906 Mtetra
.676 .71 .873 r
.45402 .55906 .46076 .56748 .47264 .56256 .46593 .55466 Mtetra
.664 .72 .89 r
.46593 .55466 .47264 .56256 .48456 .55845 .47787 .55073 Mtetra
.659 .724 .897 r
.47787 .55073 .48456 .55845 .49652 .55456 .48986 .54697 Mtetra
.655 .727 .902 r
.48986 .54697 .49652 .55456 .50854 .55065 .50191 .54335 Mtetra
.653 .735 .91 r
.50191 .54335 .50854 .55065 .5206 .54678 .514 .53974 Mtetra
.656 .745 .915 r
.514 .53974 .5206 .54678 .53272 .54303 .52616 .53603 Mtetra
.659 .748 .916 r
.52616 .53603 .53272 .54303 .54489 .53938 .53836 .53222 Mtetra
.66 .744 .912 r
.53836 .53222 .54489 .53938 .55712 .53576 .55062 .52837 Mtetra
.659 .738 .908 r
.55062 .52837 .55712 .53576 .5694 .53212 .56293 .52452 Mtetra
.657 .732 .905 r
.56293 .52452 .5694 .53212 .58173 .52843 .5753 .52071 Mtetra
.656 .729 .904 r
.5753 .52071 .58173 .52843 .59412 .52469 .58772 .51694 Mtetra
.654 .729 .904 r
.58772 .51694 .59412 .52469 .60657 .52089 .6002 .5132 Mtetra
.652 .731 .907 r
.6002 .5132 .60657 .52089 .61906 .51704 .61274 .5095 Mtetra
.651 .736 .911 r
.61274 .5095 .61906 .51704 .63162 .51317 .62534 .5058 Mtetra
.652 .742 .916 r
.62534 .5058 .63162 .51317 .64423 .50933 .638 .50207 Mtetra
.655 .747 .918 r
.638 .50207 .64423 .50933 .65691 .5056 .65071 .49822 Mtetra
.658 .746 .915 r
.65071 .49822 .65691 .5056 .66965 .50198 .66347 .49428 Mtetra
.657 .737 .909 r
.66347 .49428 .66965 .50198 .68245 .49839 .67629 .49035 Mtetra
.652 .726 .903 r
.67629 .49035 .68245 .49839 .69531 .49479 .68918 .48656 Mtetra
.647 .72 .902 r
.68918 .48656 .69531 .49479 .70824 .49141 .70214 .48294 Mtetra
.632 .709 .902 r
.70214 .48294 .70824 .49141 .72129 .48886 .71519 .47979 Mtetra
.576 .669 .902 r
.71519 .47979 .72129 .48886 .73454 .48833 .72842 .47841 Mtetra
.442 .58 .896 r
.72842 .47841 .73454 .48833 .74808 .49087 .74197 .48079 Mtetra
.303 .496 .881 r
.74197 .48079 .74808 .49087 .7618 .49423 .75586 .48629 Mtetra
.43 .631 .939 r
.75586 .48629 .7618 .49423 .77522 .49202 .76961 .48794 Mtetra
.781 .899 .926 r
.76961 .48794 .77522 .49202 .78807 .48168 .78267 .47946 Mtetra
.893 .949 .835 r
.78267 .47946 .78807 .48168 .80073 .46896 .79529 .46523 Mtetra
.852 .916 .875 r
.79529 .46523 .80073 .46896 .81366 .4595 .8081 .45351 Mtetra
.745 .831 .917 r
.8081 .45351 .81366 .4595 .82694 .45348 .82133 .44628 Mtetra
.678 .772 .922 r
.82133 .44628 .82694 .45348 .8404 .44895 .83481 .44138 Mtetra
.659 .755 .921 r
.83481 .44138 .8404 .44895 .85397 .44477 .84841 .4371 Mtetra
.656 .752 .92 r
.84841 .4371 .85397 .44477 .8676 .44062 .86209 .43291 Mtetra
.656 .751 .92 r
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Mtetra
.655 .751 .921 r
.31949 .59022 .32666 .59663 .33799 .59318 .33085 .58675 Mtetra
.649 .75 .923 r
.33085 .58675 .33799 .59318 .34937 .58981 .34226 .58342 Mtetra
.611 .741 .938 r
.34226 .58342 .34937 .58981 .36076 .58704 .35366 .58103 Mtetra
.418 .679 .97 r
.35366 .58103 .36076 .58704 .37211 .5865 .36498 .58177 Mtetra
0 .292 .711 r
.36498 .58177 .37211 .5865 .38335 .59027 .37614 .58773 Mtetra
.527 0 0 r
.37614 .58773 .38335 .59027 .3946 .59644 .38737 .59489 Mtetra
.388 .82 .961 r
.38737 .59489 .3946 .59644 .40616 .59705 .39906 .59306 Mtetra
.858 .839 .825 r
.39906 .59306 .40616 .59705 .4181 .58786 .41118 .58007 Mtetra
.832 .751 .775 r
.41118 .58007 .4181 .58786 .43015 .57499 .42333 .5655 Mtetra
.763 .711 .804 r
.42333 .5655 .43015 .57499 .44212 .56518 .43533 .55605 Mtetra
.696 .7 .85 r
.43533 .55605 .44212 .56518 .45402 .55906 .44724 .55067 Mtetra
.662 .707 .881 r
.44724 .55067 .45402 .55906 .46593 .55466 .45916 .54678 Mtetra
.654 .718 .896 r
.45916 .54678 .46593 .55466 .47787 .55073 .47113 .54318 Mtetra
.655 .729 .904 r
.47113 .54318 .47787 .55073 .48986 .54697 .48315 .53954 Mtetra
.659 .734 .906 r
.48315 .53954 .48986 .54697 .50191 .54335 .49523 .53576 Mtetra
.659 .731 .903 r
.49523 .53576 .50191 .54335 .514 .53974 .50736 .53196 Mtetra
.656 .725 .9 r
.50736 .53196 .514 .53974 .52616 .53603 .51954 .52824 Mtetra
.652 .724 .902 r
.51954 .52824 .52616 .53603 .53836 .53222 .53178 .52461 Mtetra
.651 .73 .907 r
.53178 .52461 .53836 .53222 .55062 .52837 .54407 .521 Mtetra
.652 .738 .913 r
.54407 .521 .55062 .52837 .56293 .52452 .55642 .51735 Mtetra
.653 .745 .917 r
.55642 .51735 .56293 .52452 .5753 .52071 .56883 .51362 Mtetra
.655 .749 .919 r
.56883 .51362 .5753 .52071 .58772 .51694 .58129 .50982 Mtetra
.657 .75 .918 r
.58129 .50982 .58772 .51694 .6002 .5132 .5938 .50593 Mtetra
.659 .747 .915 r
.5938 .50593 .6002 .5132 .61274 .5095 .60637 .50197 Mtetra
.66 .741 .91 r
.60637 .50197 .61274 .5095 .62534 .5058 .619 .49797 Mtetra
.659 .733 .904 r
.619 .49797 .62534 .5058 .638 .50207 .63168 .49398 Mtetra
.655 .725 .901 r
.63168 .49398 .638 .50207 .65071 .49822 .64443 .4901 Mtetra
.652 .724 .902 r
.64443 .4901 .65071 .49822 .66347 .49428 .65723 .4863 Mtetra
.653 .729 .905 r
.65723 .4863 .66347 .49428 .67629 .49035 .6701 .48247 Mtetra
.657 .734 .907 r
.6701 .48247 .67629 .49035 .68918 .48656 .68302 .47849 Mtetra
.657 .73 .903 r
.68302 .47849 .68918 .48656 .70214 .48294 .696 .47446 Mtetra
.648 .717 .898 r
.696 .47446 .70214 .48294 .71519 .47979 .70905 .47075 Mtetra
.602 .683 .899 r
.70905 .47075 .71519 .47979 .72842 .47841 .72226 .46855 Mtetra
.456 .59 .898 r
.72226 .46855 .72842 .47841 .74197 .48079 .73582 .47051 Mtetra
.22 .441 .862 r
.73582 .47051 .74197 .48079 .75586 .48629 .74984 .47771 Mtetra
.239 .501 .901 r
.74984 .47771 .75586 .48629 .76961 .48794 .76389 .48323 Mtetra
.708 .863 .956 r
.76389 .48323 .76961 .48794 .78267 .47946 .77721 .47718 Mtetra
.907 .943 .818 r
.77721 .47718 .78267 .47946 .79529 .46523 .78982 .46183 Mtetra
.888 .921 .839 r
.78982 .46183 .79529 .46523 .8081 .45351 .80251 .44775 Mtetra
.779 .848 .903 r
.80251 .44775 .8081 .45351 .82133 .44628 .81567 .43913 Mtetra
.691 .78 .919 r
.81567 .43913 .82133 .44628 .83481 .44138 .82916 .43377 Mtetra
.662 .756 .92 r
.82916 .43377 .83481 .44138 .84841 .4371 .84281 .42938 Mtetra
.656 .752 .92 r
.84281 .42938 .84841 .4371 .86209 .43291 .85653 .42514 Mtetra
.656 .751 .92 r
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Mtetra
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Mtetra
.655 .751 .921 r
.31227 .58376 .31949 .59022 .33085 .58675 .32366 .58027 Mtetra
.646 .749 .924 r
.32366 .58027 .33085 .58675 .34226 .58342 .33509 .577 Mtetra
.592 .735 .944 r
.33509 .577 .34226 .58342 .35366 .58103 .3465 .57501 Mtetra
.298 .621 .959 r
.3465 .57501 .35366 .58103 .36498 .58177 .35777 .57711 Mtetra
.474 0 0 r
.35777 .57711 .36498 .58177 .37614 .58773 .36885 .58531 Mtetra
.587 .013 0 r
.36885 .58531 .37614 .58773 .38737 .59489 .38006 .59333 Mtetra
.617 .912 .981 r
.38006 .59333 .38737 .59489 .39906 .59306 .39189 .58885 Mtetra
.884 .82 .78 r
.39189 .58885 .39906 .59306 .41118 .58007 .40421 .57204 Mtetra
.841 .748 .761 r
.40421 .57204 .41118 .58007 .42333 .5655 .41647 .5559 Mtetra
.756 .709 .808 r
.41647 .5559 .42333 .5655 .43533 .55605 .42848 .54687 Mtetra
.677 .695 .859 r
.42848 .54687 .43533 .55605 .44724 .55067 .4404 .54229 Mtetra
.648 .704 .888 r
.4404 .54229 .44724 .55067 .45916 .54678 .45234 .53885 Mtetra
.649 .717 .898 r
.45234 .53885 .45916 .54678 .47113 .54318 .46434 .53538 Mtetra
.65 .722 .901 r
.46434 .53538 .47113 .54318 .48315 .53954 .47639 .53187 Mtetra
.647 .725 .906 r
.47639 .53187 .48315 .53954 .49523 .53576 .48849 .52842 Mtetra
.648 .736 .913 r
.48849 .52842 .49523 .53576 .50736 .53196 .50065 .52491 Mtetra
.652 .747 .919 r
.50065 .52491 .50736 .53196 .51954 .52824 .51287 .52125 Mtetra
.657 .751 .919 r
.51287 .52125 .51954 .52824 .53178 .52461 .52514 .51742 Mtetra
.659 .747 .915 r
.52514 .51742 .53178 .52461 .54407 .521 .53747 .51352 Mtetra
.659 .739 .909 r
.53747 .51352 .54407 .521 .55642 .51735 .54985 .50961 Mtetra
.657 .732 .905 r
.54985 .50961 .55642 .51735 .56883 .51362 .56229 .50573 Mtetra
.656 .728 .903 r
.56229 .50573 .56883 .51362 .58129 .50982 .57479 .5019 Mtetra
.654 .728 .903 r
.57479 .5019 .58129 .50982 .5938 .50593 .58734 .49811 Mtetra
.652 .731 .907 r
.58734 .49811 .5938 .50593 .60637 .50197 .59995 .49435 Mtetra
.652 .737 .912 r
.59995 .49435 .60637 .50197 .619 .49797 .61262 .49058 Mtetra
.653 .745 .917 r
.61262 .49058 .619 .49797 .63168 .49398 .62535 .48674 Mtetra
.658 .752 .92 r
.62535 .48674 .63168 .49398 .64443 .4901 .63813 .48272 Mtetra
.663 .751 .916 r
.63813 .48272 .64443 .4901 .65723 .4863 .65096 .47854 Mtetra
.663 .741 .908 r
.65096 .47854 .65723 .4863 .6701 .48247 .66385 .47432 Mtetra
.661 .73 .901 r
.66385 .47432 .6701 .48247 .68302 .47849 .6768 .47016 Mtetra
.662 .727 .897 r
.6768 .47016 .68302 .47849 .696 .47446 .68981 .46594 Mtetra
.662 .723 .894 r
.68981 .46594 .696 .47446 .70905 .47075 .70287 .46171 Mtetra
.628 .696 .894 r
.70287 .46171 .70905 .47075 .72226 .46855 .71607 .45863 Mtetra
.474 .601 .898 r
.71607 .45863 .72226 .46855 .73582 .47051 .72961 .46011 Mtetra
.136 .385 .839 r
.72961 .46011 .73582 .47051 .74984 .47771 .74375 .46888 Mtetra
.015 .345 .824 r
.74375 .46888 .74984 .47771 .76389 .48323 .75811 .47827 Mtetra
.602 .821 .984 r
.75811 .47827 .76389 .48323 .77721 .47718 .77168 .47487 Mtetra
.917 .939 .804 r
.77168 .47487 .77721 .47718 .78982 .46183 .78431 .45854 Mtetra
.915 .915 .803 r
.78431 .45854 .78982 .46183 .80251 .44775 .79688 .44206 Mtetra
.81 .857 .884 r
.79688 .44206 .80251 .44775 .81567 .43913 .80997 .43195 Mtetra
.704 .786 .915 r
.80997 .43195 .81567 .43913 .82916 .43377 .82347 .4261 Mtetra
.664 .758 .92 r
.82347 .4261 .82916 .43377 .84281 .42938 .83715 .42158 Mtetra
.657 .752 .92 r
.83715 .42158 .84281 .42938 .85653 .42514 .85092 .4173 Mtetra
.656 .751 .92 r
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Mtetra
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Mtetra
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Mtetra
.655 .751 .921 r
.30499 .57725 .31227 .58376 .32366 .58027 .31641 .57374 Mtetra
.643 .748 .925 r
.31641 .57374 .32366 .58027 .33509 .577 .32787 .57052 Mtetra
.571 .728 .949 r
.32787 .57052 .33509 .577 .3465 .57501 .33928 .56893 Mtetra
.163 .543 .926 r
.33928 .56893 .3465 .57501 .35777 .57711 .3505 .57237 Mtetra
.622 .077 0 r
.3505 .57237 .35777 .57711 .36885 .58531 .36148 .58281 Mtetra
.634 .072 0 r
.36148 .58281 .36885 .58531 .38006 .59333 .37267 .5918 Mtetra
.744 .935 .95 r
.37267 .5918 .38006 .59333 .39189 .58885 .38466 .58482 Mtetra
.904 .811 .746 r
.38466 .58482 .39189 .58885 .40421 .57204 .39719 .56415 Mtetra
.853 .751 .749 r
.39719 .56415 .40421 .57204 .41647 .5559 .40956 .54626 Mtetra
.751 .708 .811 r
.40956 .54626 .41647 .5559 .42848 .54687 .4216 .53755 Mtetra
.657 .686 .865 r
.4216 .53755 .42848 .54687 .4404 .54229 .43352 .53372 Mtetra
.631 .695 .891 r
.43352 .53372 .4404 .54229 .45234 .53885 .44547 .53082 Mtetra
.636 .712 .902 r
.44547 .53082 .45234 .53885 .46434 .53538 .45749 .52773 Mtetra
.645 .726 .907 r
.45749 .52773 .46434 .53538 .47639 .53187 .46957 .52433 Mtetra
.654 .733 .907 r
.46957 .52433 .47639 .53187 .48849 .52842 .48171 .52063 Mtetra
.656 .728 .902 r
.48171 .52063 .48849 .52842 .50065 .52491 .4939 .51684 Mtetra
.653 .719 .897 r
.4939 .51684 .50065 .52491 .51287 .52125 .50615 .51313 Mtetra
.649 .718 .899 r
.50615 .51313 .51287 .52125 .52514 .51742 .51846 .50955 Mtetra
.647 .725 .905 r
.51846 .50955 .52514 .51742 .53747 .51352 .53082 .50599 Mtetra
.649 .736 .913 r
.53082 .50599 .53747 .51352 .54985 .50961 .54324 .50237 Mtetra
.651 .746 .919 r
.54324 .50237 .54985 .50961 .56229 .50573 .55571 .49864 Mtetra
.655 .752 .922 r
.55571 .49864 .56229 .50573 .57479 .5019 .56825 .49477 Mtetra
.659 .754 .92 r
.56825 .49477 .57479 .5019 .58734 .49811 .58083 .49077 Mtetra
.662 .749 .915 r
.58083 .49077 .58734 .49811 .59995 .49435 .59347 .48665 Mtetra
.663 .741 .908 r
.59347 .48665 .59995 .49435 .61262 .49058 .60617 .48247 Mtetra
.662 .73 .9 r
.60617 .48247 .61262 .49058 .62535 .48674 .61893 .47831 Mtetra
.657 .721 .895 r
.61893 .47831 .62535 .48674 .63813 .48272 .63174 .47429 Mtetra
.654 .72 .897 r
.63174 .47429 .63813 .48272 .65096 .47854 .64462 .47035 Mtetra
.657 .729 .902 r
.64462 .47035 .65096 .47854 .66385 .47432 .65756 .46631 Mtetra
.665 .738 .904 r
.65756 .46631 .66385 .47432 .6768 .47016 .67054 .46197 Mtetra
.674 .737 .898 r
.67054 .46197 .6768 .47016 .68981 .46594 .68357 .45731 Mtetra
.677 .727 .888 r
.68357 .45731 .68981 .46594 .70287 .46171 .69664 .45246 Mtetra
.65 .703 .885 r
.69664 .45246 .70287 .46171 .71607 .45863 .70982 .44857 Mtetra
.489 .607 .896 r
.70982 .44857 .71607 .45863 .72961 .46011 .72337 .44967 Mtetra
.037 .318 .804 r
.72337 .44967 .72961 .46011 .74375 .46888 .73763 .46018 Mtetra
0 .166 .696 r
.73763 .46018 .74375 .46888 .75811 .47827 .75228 .47348 Mtetra
.456 .764 .996 r
.75228 .47348 .75811 .47827 .77168 .47487 .7661 .47259 Mtetra
.927 .934 .789 r
.7661 .47259 .77168 .47487 .78431 .45854 .77872 .45515 Mtetra
.934 .903 .771 r
.77872 .45515 .78431 .45854 .79688 .44206 .79119 .43626 Mtetra
.834 .857 .862 r
.79119 .43626 .79688 .44206 .80997 .43195 .80422 .42469 Mtetra
.715 .789 .91 r
.80422 .42469 .80997 .43195 .82347 .4261 .81773 .41835 Mtetra
.667 .758 .919 r
.81773 .41835 .82347 .4261 .83715 .42158 .83145 .41372 Mtetra
.657 .752 .92 r
.83145 .41372 .83715 .42158 .85092 .4173 .84526 .40939 Mtetra
.656 .751 .92 r
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Mtetra
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Mtetra
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57069 Mtetra
.654 .751 .921 r
.29766 .57069 .30499 .57725 .31641 .57374 .30911 .56715 Mtetra
.641 .748 .926 r
.30911 .56715 .31641 .57374 .32787 .57052 .32058 .56398 Mtetra
.552 .721 .952 r
.32058 .56398 .32787 .57052 .33928 .56893 .332 .56274 Mtetra
.033 .458 .877 r
.332 .56274 .33928 .56893 .3505 .57237 .34317 .56737 Mtetra
.712 .188 0 r
.34317 .56737 .3505 .57237 .36148 .58281 .35405 .57998 Mtetra
.68 .132 0 r
.35405 .57998 .36148 .58281 .37267 .5918 .36519 .59026 Mtetra
.806 .932 .916 r
.36519 .59026 .37267 .5918 .38466 .58482 .37732 .58132 Mtetra
.92 .808 .72 r
.37732 .58132 .38466 .58482 .39719 .56415 .39008 .55685 Mtetra
.871 .759 .737 r
.39008 .55685 .39719 .56415 .40956 .54626 .4026 .53674 Mtetra
.753 .712 .814 r
.4026 .53674 .40956 .54626 .4216 .53755 .41467 .52802 Mtetra
.635 .674 .87 r
.41467 .52802 .4216 .53755 .43352 .53372 .42659 .52495 Mtetra
.613 .684 .893 r
.42659 .52495 .43352 .53372 .44547 .53082 .43856 .52257 Mtetra
.63 .705 .9 r
.43856 .52257 .44547 .53082 .45749 .52773 .4506 .51963 Mtetra
.639 .713 .901 r
.4506 .51963 .45749 .52773 .46957 .52433 .4627 .51641 Mtetra
.639 .719 .906 r
.4627 .51641 .46957 .52433 .48171 .52063 .47487 .51315 Mtetra
.644 .734 .914 r
.47487 .51315 .48171 .52063 .4939 .51684 .48709 .50971 Mtetra
.655 .749 .919 r
.48709 .50971 .4939 .51684 .50615 .51313 .49937 .50591 Mtetra
.666 .75 .913 r
.49937 .50591 .50615 .51313 .51846 .50955 .51172 .50173 Mtetra
.671 .736 .899 r
.51172 .50173 .51846 .50955 .53082 .50599 .52411 .49737 Mtetra
.668 .715 .883 r
.52411 .49737 .53082 .50599 .54324 .50237 .53656 .49303 Mtetra
.661 .696 .872 r
.53656 .49303 .54324 .50237 .55571 .49864 .54906 .48888 Mtetra
.653 .684 .867 r
.54906 .48888 .55571 .49864 .56825 .49477 .56162 .48498 Mtetra
.646 .682 .869 r
.56162 .48498 .56825 .49477 .58083 .49077 .57424 .48134 Mtetra
.641 .689 .879 r
.57424 .48134 .58083 .49077 .59347 .48665 .58693 .47787 Mtetra
.64 .705 .894 r
.58693 .47787 .59347 .48665 .60617 .48247 .59968 .47444 Mtetra
.644 .727 .909 r
.59968 .47444 .60617 .48247 .61893 .47831 .61248 .47083 Mtetra
.656 .748 .918 r
.61248 .47083 .61893 .47831 .63174 .47429 .62534 .46682 Mtetra
.667 .753 .915 r
.62534 .46682 .63174 .47429 .64462 .47035 .63824 .46244 Mtetra
.671 .743 .905 r
.63824 .46244 .64462 .47035 .65756 .46631 .6512 .4579 Mtetra
.671 .73 .895 r
.6512 .4579 .65756 .46631 .67054 .46197 .66421 .45332 Mtetra
.678 .728 .888 r
.66421 .45332 .67054 .46197 .68357 .45731 .67727 .44845 Mtetra
.691 .728 .879 r
.67727 .44845 .68357 .45731 .69664 .45246 .69035 .44301 Mtetra
.671 .707 .875 r
.69035 .44301 .69664 .45246 .70982 .44857 .70352 .43827 Mtetra
.491 .604 .893 r
.70352 .43827 .70982 .44857 .72337 .44967 .71709 .43934 Mtetra
0 .224 .746 r
.71709 .43934 .72337 .44967 .73763 .46018 .73151 .45208 Mtetra
0 0 .525 r
.73151 .45208 .73763 .46018 .75228 .47348 .74643 .46924 Mtetra
.287 .691 .973 r
.74643 .46924 .75228 .47348 .7661 .47259 .76044 .47028 Mtetra
.937 .927 .77 r
.76044 .47028 .7661 .47259 .77872 .45515 .77305 .45141 Mtetra
.945 .886 .743 r
.77305 .45141 .77872 .45515 .79119 .43626 .78542 .43019 Mtetra
.851 .851 .842 r
.78542 .43019 .79119 .43626 .80422 .42469 .79841 .4173 Mtetra
.725 .791 .904 r
.79841 .4173 .80422 .42469 .81773 .41835 .81194 .41053 Mtetra
.669 .759 .918 r
.81194 .41053 .81773 .41835 .83145 .41372 .8257 .40579 Mtetra
.657 .752 .92 r
.8257 .40579 .83145 .41372 .84526 .40939 .83956 .40141 Mtetra
.656 .751 .92 r
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Mtetra
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.27883 .56766 .28625 .57425 .29766 .57069 .29026 .56407 Mtetra
.654 .751 .921 r
.29026 .56407 .29766 .57069 .30911 .56715 .30174 .56052 Mtetra
.638 .747 .927 r
.30174 .56052 .30911 .56715 .32058 .56398 .31324 .55737 Mtetra
.535 .715 .955 r
.31324 .55737 .32058 .56398 .332 .56274 .32467 .55642 Mtetra
0 .379 .823 r
.32467 .55642 .332 .56274 .34317 .56737 .33579 .56206 Mtetra
.765 .262 0 r
.33579 .56206 .34317 .56737 .35405 .57998 .34657 .57658 Mtetra
.722 .19 0 r
.34657 .57658 .35405 .57998 .36519 .59026 .35765 .58842 Mtetra
.828 .919 .897 r
.35765 .58842 .36519 .59026 .37732 .58132 .36988 .57849 Mtetra
.932 .808 .701 r
.36988 .57849 .37732 .58132 .39008 .55685 .38287 .55071 Mtetra
.893 .774 .723 r
.38287 .55071 .39008 .55685 .4026 .53674 .39556 .52778 Mtetra
.768 .727 .814 r
.39556 .52778 .4026 .53674 .41467 .52802 .4077 .51829 Mtetra
.621 .666 .872 r
.4077 .51829 .41467 .52802 .42659 .52495 .41963 .51567 Mtetra
.592 .665 .89 r
.41963 .51567 .42659 .52495 .43856 .52257 .4316 .51389 Mtetra
.621 .692 .895 r
.4316 .51389 .43856 .52257 .4506 .51963 .44366 .51122 Mtetra
.656 .712 .89 r
.44366 .51122 .4506 .51963 .4627 .51641 .4558 .50741 Mtetra
.683 .708 .867 r
.4558 .50741 .4627 .51641 .47487 .51315 .46802 .50249 Mtetra
.689 .677 .833 r
.46802 .50249 .47487 .51315 .48709 .50971 .4803 .49691 Mtetra
.678 .638 .802 r
.4803 .49691 .48709 .50971 .49937 .50591 .49261 .4913 Mtetra
.663 .608 .782 r
.49261 .4913 .49937 .50591 .51172 .50173 .50497 .48607 Mtetra
.651 .59 .773 r
.50497 .48607 .51172 .50173 .52411 .49737 .51737 .4813 Mtetra
.643 .582 .771 r
.51737 .4813 .52411 .49737 .53656 .49303 .52982 .47692 Mtetra
.638 .579 .772 r
.52982 .47692 .53656 .49303 .54906 .48888 .54233 .47279 Mtetra
.635 .578 .774 r
.54233 .47279 .54906 .48888 .56162 .48498 .55489 .46885 Mtetra
.631 .576 .775 r
.55489 .46885 .56162 .48498 .57424 .48134 .56752 .46508 Mtetra
.626 .573 .775 r
.56752 .46508 .57424 .48134 .58693 .47787 .5802 .46158 Mtetra
.619 .569 .776 r
.5802 .46158 .58693 .47787 .59968 .47444 .59296 .45847 Mtetra
.61 .568 .783 r
.59296 .45847 .59968 .47444 .61248 .47083 .6058 .45583 Mtetra
.603 .577 .797 r
.6058 .45583 .61248 .47083 .62534 .46682 .61872 .4536 Mtetra
.605 .604 .823 r
.61872 .4536 .62534 .46682 .63824 .46244 .63171 .45134 Mtetra
.622 .65 .856 r
.63171 .45134 .63824 .46244 .6512 .4579 .64476 .44841 Mtetra
.654 .699 .879 r
.64476 .44841 .6512 .4579 .66421 .45332 .65782 .44435 Mtetra
.684 .724 .88 r
.65782 .44435 .66421 .45332 .67727 .44845 .6709 .43914 Mtetra
.704 .724 .866 r
.6709 .43914 .67727 .44845 .69035 .44301 .68399 .43303 Mtetra
.681 .701 .862 r
.68399 .43303 .69035 .44301 .70352 .43827 .69717 .42778 Mtetra
.462 .586 .891 r
.69717 .42778 .70352 .43827 .71709 .43934 .71081 .42958 Mtetra
0 .089 .64 r
.71081 .42958 .71709 .43934 .73151 .45208 .72541 .44515 Mtetra
.641 .166 0 r
.72541 .44515 .73151 .45208 .74643 .46924 .74056 .46566 Mtetra
.156 .63 .927 r
.74056 .46566 .74643 .46924 .76044 .47028 .75469 .46764 Mtetra
.946 .911 .751 r
.75469 .46764 .76044 .47028 .77305 .45141 .76728 .44707 Mtetra
.949 .867 .723 r
.76728 .44707 .77305 .45141 .78542 .43019 .77957 .42378 Mtetra
.861 .843 .825 r
.77957 .42378 .78542 .43019 .79841 .4173 .79254 .40977 Mtetra
.733 .791 .899 r
.79254 .40977 .79841 .4173 .81194 .41053 .80609 .40263 Mtetra
.671 .759 .917 r
.80609 .40263 .81194 .41053 .8257 .40579 .81989 .39778 Mtetra
.657 .752 .92 r
.81989 .39778 .8257 .40579 .83956 .40141 .8338 .39336 Mtetra
.656 .751 .92 r
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Mtetra
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Mtetra
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Mtetra
.654 .751 .921 r
.2828 .5574 .29026 .56407 .30174 .56052 .29431 .55382 Mtetra
.636 .746 .928 r
.29431 .55382 .30174 .56052 .31324 .55737 .30584 .5507 Mtetra
.52 .709 .957 r
.30584 .5507 .31324 .55737 .32467 .55642 .31728 .55 Mtetra
0 .313 .772 r
.31728 .55 .32467 .55642 .33579 .56206 .32836 .55643 Mtetra
.796 .307 0 r
.32836 .55643 .33579 .56206 .34657 .57658 .33905 .57245 Mtetra
.751 .234 0 r
.33905 .57245 .34657 .57658 .35765 .58842 .35006 .58579 Mtetra
.823 .896 .894 r
.35006 .58579 .35765 .58842 .36988 .57849 .36234 .57598 Mtetra
.937 .807 .69 r
.36234 .57598 .36988 .57849 .38287 .55071 .37553 .54616 Mtetra
.916 .791 .709 r
.37553 .54616 .38287 .55071 .39556 .52778 .38843 .52015 Mtetra
.807 .761 .81 r
.38843 .52015 .39556 .52778 .4077 .51829 .40068 .50856 Mtetra
.642 .675 .866 r
.40068 .50856 .4077 .51829 .41963 .51567 .41266 .50516 Mtetra
.62 .651 .859 r
.41266 .50516 .41963 .51567 .4316 .51389 .42467 .50251 Mtetra
.663 .652 .829 r
.42467 .50251 .4316 .51389 .44366 .51122 .4368 .49803 Mtetra
.677 .631 .796 r
.4368 .49803 .44366 .51122 .4558 .50741 .44899 .49241 Mtetra
.663 .602 .777 r
.44899 .49241 .4558 .50741 .46802 .50249 .46123 .48705 Mtetra
.646 .589 .777 r
.46123 .48705 .46802 .50249 .4803 .49691 .47349 .4826 Mtetra
.635 .598 .795 r
.47349 .4826 .4803 .49691 .49261 .4913 .4858 .47893 Mtetra
.632 .625 .825 r
.4858 .47893 .49261 .4913 .50497 .48607 .49816 .47562 Mtetra
.635 .663 .859 r
.49816 .47562 .50497 .48607 .51737 .4813 .51058 .47233 Mtetra
.641 .699 .888 r
.51058 .47233 .51737 .4813 .52982 .47692 .52306 .46888 Mtetra
.648 .727 .906 r
.52306 .46888 .52982 .47692 .54233 .47279 .5356 .46518 Mtetra
.656 .742 .913 r
.5356 .46518 .54233 .47279 .55489 .46885 .5482 .4612 Mtetra
.664 .745 .911 r
.5482 .4612 .55489 .46885 .56752 .46508 .56086 .45695 Mtetra
.671 .735 .898 r
.56086 .45695 .56752 .46508 .5802 .46158 .57357 .45245 Mtetra
.672 .711 .877 r
.57357 .45245 .5802 .46158 .59296 .45847 .58633 .44778 Mtetra
.666 .676 .85 r
.58633 .44778 .59296 .45847 .6058 .45583 .59915 .44314 Mtetra
.651 .634 .82 r
.59915 .44314 .6058 .45583 .61872 .4536 .61203 .43884 Mtetra
.628 .594 .796 r
.61203 .43884 .61872 .4536 .63171 .45134 .62499 .43534 Mtetra
.607 .569 .785 r
.62499 .43534 .63171 .45134 .64476 .44841 .63805 .43278 Mtetra
.602 .571 .792 r
.63805 .43278 .64476 .44841 .65782 .44435 .6512 .4305 Mtetra
.628 .609 .811 r
.6512 .4305 .65782 .44435 .6709 .43914 .66438 .42708 Mtetra
.672 .658 .828 r
.66438 .42708 .6709 .43914 .68399 .43303 .67753 .42179 Mtetra
.659 .668 .847 r
.67753 .42179 .68399 .43303 .69717 .42778 .69078 .41728 Mtetra
.369 .535 .889 r
.69078 .41728 .69717 .42778 .71081 .42958 .70456 .42117 Mtetra
0 0 .467 r
.70456 .42117 .71081 .42958 .72541 .44515 .71935 .43985 Mtetra
.742 .257 0 r
.71935 .43985 .72541 .44515 .74056 .46566 .73465 .46238 Mtetra
.145 .633 .918 r
.73465 .46238 .74056 .46566 .75469 .46764 .74882 .46416 Mtetra
.949 .887 .736 r
.74882 .46416 .75469 .46764 .76728 .44707 .76138 .44194 Mtetra
.949 .848 .709 r
.76138 .44194 .76728 .44707 .77957 .42378 .77365 .41702 Mtetra
.868 .836 .812 r
.77365 .41702 .77957 .42378 .79254 .40977 .78661 .40211 Mtetra
.739 .791 .894 r
.78661 .40211 .79254 .40977 .80609 .40263 .80019 .39465 Mtetra
.672 .76 .916 r
.80019 .39465 .80609 .40263 .81989 .39778 .81404 .38971 Mtetra
.658 .752 .92 r
.81404 .38971 .81989 .39778 .8338 .39336 .82799 .38524 Mtetra
.656 .751 .92 r
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Mtetra
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37636 Mtetra
.85611 .37636 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Mtetra
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55068 Mtetra
.653 .751 .921 r
.27529 .55068 .2828 .5574 .29431 .55382 .28683 .54708 Mtetra
.634 .746 .929 r
.28683 .54708 .29431 .55382 .30584 .5507 .29838 .54399 Mtetra
.505 .703 .959 r
.29838 .54399 .30584 .5507 .31728 .55 .30982 .54352 Mtetra
0 .257 .725 r
.30982 .54352 .31728 .55 .32836 .55643 .32088 .5506 Mtetra
.813 .333 0 r
.32088 .5506 .32836 .55643 .33905 .57245 .33149 .56761 Mtetra
.763 .254 0 r
.33149 .56761 .33905 .57245 .35006 .58579 .34245 .58189 Mtetra
.802 .861 .893 r
.34245 .58189 .35006 .58579 .36234 .57598 .35476 .57281 Mtetra
.932 .798 .69 r
.35476 .57281 .36234 .57598 .37553 .54616 .36806 .54275 Mtetra
.93 .8 .696 r
.36806 .54275 .37553 .54616 .38843 .52015 .38116 .51414 Mtetra
.863 .793 .781 r
.38116 .51414 .38843 .52015 .40068 .50856 .39364 .49819 Mtetra
.724 .692 .82 r
.39364 .49819 .40068 .50856 .41266 .50516 .40578 .49088 Mtetra
.653 .605 .788 r
.40578 .49088 .41266 .50516 .42467 .50251 .41786 .4863 Mtetra
.63 .572 .771 r
.41786 .4863 .42467 .50251 .4368 .49803 .42996 .4826 Mtetra
.614 .573 .784 r
.42996 .4826 .4368 .49803 .44899 .49241 .4421 .47985 Mtetra
.603 .608 .829 r
.4421 .47985 .44899 .49241 .46123 .48705 .45428 .47775 Mtetra
.597 .672 .892 r
.45428 .47775 .46123 .48705 .47349 .4826 .46653 .47571 Mtetra
.594 .74 .945 r
.46653 .47571 .47349 .4826 .4858 .47893 .47885 .47336 Mtetra
.596 .785 .971 r
.47885 .47336 .4858 .47893 .49816 .47562 .49125 .47061 Mtetra
.605 .809 .978 r
.49125 .47061 .49816 .47562 .51058 .47233 .50371 .46748 Mtetra
.617 .819 .978 r
.50371 .46748 .51058 .47233 .52306 .46888 .51624 .46403 Mtetra
.629 .824 .975 r
.51624 .46403 .52306 .46888 .5356 .46518 .52883 .46029 Mtetra
.641 .827 .972 r
.52883 .46029 .5356 .46518 .5482 .4612 .54148 .45628 Mtetra
.652 .83 .969 r
.54148 .45628 .5482 .4612 .56086 .45695 .55418 .45199 Mtetra
.663 .833 .965 r
.55418 .45199 .56086 .45695 .57357 .45245 .56694 .44742 Mtetra
.676 .835 .96 r
.56694 .44742 .57357 .45245 .58633 .44778 .57975 .44252 Mtetra
.69 .833 .951 r
.57975 .44252 .58633 .44778 .59915 .44314 .5926 .43723 Mtetra
.704 .816 .934 r
.5926 .43723 .59915 .44314 .61203 .43884 .60549 .43156 Mtetra
.71 .777 .904 r
.60549 .43156 .61203 .43884 .62499 .43534 .61843 .42557 Mtetra
.697 .711 .859 r
.61843 .42557 .62499 .43534 .63805 .43278 .63141 .41964 Mtetra
.667 .638 .811 r
.63141 .41964 .63805 .43278 .6512 .4305 .64446 .41436 Mtetra
.638 .585 .779 r
.64446 .41436 .6512 .4305 .66438 .42708 .65761 .41005 Mtetra
.619 .566 .773 r
.65761 .41005 .66438 .42708 .67753 .42179 .67086 .40668 Mtetra
.562 .559 .807 r
.67086 .40668 .67753 .42179 .69078 .41728 .68432 .40612 Mtetra
.166 .395 .84 r
.68432 .40612 .69078 .41728 .70456 .42117 .69835 .41441 Mtetra
.681 .205 0 r
.69835 .41441 .70456 .42117 .71935 .43985 .7133 .43569 Mtetra
.772 .282 0 r
.7133 .43569 .71935 .43985 .73465 .46238 .72862 .45839 Mtetra
.265 .691 .966 r
.72862 .45839 .73465 .46238 .74882 .46416 .7428 .45933 Mtetra
.943 .859 .727 r
.7428 .45933 .74882 .46416 .76138 .44194 .75538 .43606 Mtetra
.946 .833 .701 r
.75538 .43606 .76138 .44194 .77365 .41702 .76765 .41004 Mtetra
.873 .831 .803 r
.76765 .41004 .77365 .41702 .78661 .40211 .78063 .39438 Mtetra
.745 .793 .891 r
.78063 .39438 .78661 .40211 .80019 .39465 .79424 .38661 Mtetra
.674 .761 .916 r
.79424 .38661 .80019 .39465 .81404 .38971 .80813 .38156 Mtetra
.658 .753 .92 r
.80813 .38156 .81404 .38971 .82799 .38524 .82213 .37705 Mtetra
.656 .751 .92 r
.82213 .37705 .82799 .38524 .84202 .38081 .83621 .37257 Mtetra
.83621 .37257 .84202 .38081 .85611 .37636 .85035 .36808 Mtetra
.85035 .36808 .85611 .37636 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Mtetra
.25619 .54757 .2638 .55432 .27529 .55068 .26771 .5439 Mtetra
.653 .751 .921 r
.26771 .5439 .27529 .55068 .28683 .54708 .27928 .54028 Mtetra
.631 .745 .93 r
.27928 .54028 .28683 .54708 .29838 .54399 .29086 .53723 Mtetra
.488 .696 .961 r
.29086 .53723 .29838 .54399 .30982 .54352 .3023 .537 Mtetra
0 .204 .677 r
.3023 .537 .30982 .54352 .32088 .5506 .31333 .54469 Mtetra
.823 .349 0 r
.31333 .54469 .32088 .5506 .33149 .56761 .32389 .5623 Mtetra
.754 .245 0 r
.32389 .5623 .33149 .56761 .34245 .58189 .33484 .57661 Mtetra
.791 .822 .876 r
.33484 .57661 .34245 .58189 .35476 .57281 .3472 .56758 Mtetra
.916 .775 .691 r
.3472 .56758 .35476 .57281 .36806 .54275 .36057 .53796 Mtetra
.922 .78 .687 r
.36057 .53796 .36806 .54275 .38116 .51414 .37385 .50781 Mtetra
.883 .779 .742 r
.37385 .50781 .38116 .51414 .39364 .49819 .38657 .48745 Mtetra
.769 .7 .786 r
.38657 .48745 .39364 .49819 .40578 .49088 .39887 .47667 Mtetra
.64 .601 .794 r
.39887 .47667 .40578 .49088 .41786 .4863 .41094 .47276 Mtetra
.558 .57 .822 r
.41094 .47276 .41786 .4863 .42996 .4826 .42295 .4723 Mtetra
.522 .615 .886 r
.42295 .4723 .42996 .4826 .4421 .47985 .43502 .47242 Mtetra
.52 .694 .947 r
.43502 .47242 .4421 .47985 .45428 .47775 .4472 .47179 Mtetra
.543 .752 .974 r
.4472 .47179 .45428 .47775 .46653 .47571 .45947 .4702 Mtetra
.574 .781 .977 r
.45947 .4702 .46653 .47571 .47885 .47336 .47184 .46784 Mtetra
.601 .79 .972 r
.47184 .46784 .47885 .47336 .49125 .47061 .48427 .46495 Mtetra
.619 .792 .965 r
.48427 .46495 .49125 .47061 .50371 .46748 .49678 .46166 Mtetra
.632 .792 .959 r
.49678 .46166 .50371 .46748 .51624 .46403 .50935 .45809 Mtetra
.642 .792 .954 r
.50935 .45809 .51624 .46403 .52883 .46029 .52198 .45428 Mtetra
.65 .794 .951 r
.52198 .45428 .52883 .46029 .54148 .45628 .53468 .45025 Mtetra
.658 .796 .949 r
.53468 .45025 .54148 .45628 .55418 .45199 .54742 .446 Mtetra
.666 .801 .947 r
.54742 .446 .55418 .45199 .56694 .44742 .56023 .4415 Mtetra
.675 .807 .946 r
.56023 .4415 .56694 .44742 .57975 .44252 .57309 .4367 Mtetra
.687 .815 .944 r
.57309 .4367 .57975 .44252 .5926 .43723 .58599 .43152 Mtetra
.706 .825 .938 r
.58599 .43152 .5926 .43723 .60549 .43156 .59894 .42573 Mtetra
.729 .827 .926 r
.59894 .42573 .60549 .43156 .61843 .42557 .61191 .41918 Mtetra
.751 .815 .903 r
.61191 .41918 .61843 .42557 .63141 .41964 .62489 .41167 Mtetra
.756 .774 .868 r
.62489 .41167 .63141 .41964 .64446 .41436 .63788 .40342 Mtetra
.723 .7 .828 r
.63788 .40342 .64446 .41436 .65761 .41005 .65093 .39577 Mtetra
.639 .61 .805 r
.65093 .39577 .65761 .41005 .67086 .40668 .66416 .39164 Mtetra
.469 .508 .816 r
.66416 .39164 .67086 .40668 .68432 .40612 .6778 .39453 Mtetra
0 .233 .75 r
.6778 .39453 .68432 .40612 .69835 .41441 .69206 .40727 Mtetra
.701 .233 0 r
.69206 .40727 .69835 .41441 .7133 .43569 .7071 .43006 Mtetra
.728 .242 0 r
.7071 .43006 .7133 .43569 .72862 .45839 .7224 .45224 Mtetra
.388 .688 .979 r
.7224 .45224 .72862 .45839 .7428 .45933 .73662 .45306 Mtetra
.93 .833 .727 r
.73662 .45306 .7428 .45933 .75538 .43606 .74928 .42969 Mtetra
.944 .825 .696 r
.74928 .42969 .75538 .43606 .76765 .41004 .7616 .40295 Mtetra
.879 .83 .795 r
.7616 .40295 .76765 .41004 .78063 .39438 .7746 .3866 Mtetra
.752 .795 .888 r
.7746 .3866 .78063 .39438 .79424 .38661 .78824 .3785 Mtetra
.676 .762 .915 r
.78824 .3785 .79424 .38661 .80813 .38156 .80217 .37335 Mtetra
.658 .753 .92 r
.80217 .37335 .80813 .38156 .82213 .37705 .81622 .36878 Mtetra
.656 .751 .92 r
.81622 .36878 .82213 .37705 .83621 .37257 .83034 .36426 Mtetra
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Mtetra
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Mtetra
.24852 .54077 .25619 .54757 .26771 .5439 .26007 .53707 Mtetra
.653 .751 .922 r
.26007 .53707 .26771 .5439 .27928 .54028 .27167 .53343 Mtetra
.628 .744 .931 r
.27167 .53343 .27928 .54028 .29086 .53723 .28327 .53042 Mtetra
.468 .688 .962 r
.28327 .53042 .29086 .53723 .3023 .537 .29472 .53048 Mtetra
0 .151 .625 r
.29472 .53048 .3023 .537 .31333 .54469 .30571 .53877 Mtetra
.829 .357 0 r
.30571 .53877 .31333 .54469 .32389 .5623 .31624 .55671 Mtetra
.713 .194 0 r
.31624 .55671 .32389 .5623 .33484 .57661 .32724 .56997 Mtetra
.807 .786 .833 r
.32724 .56997 .33484 .57661 .3472 .56758 .33974 .55904 Mtetra
.893 .738 .683 r
.33974 .55904 .3472 .56758 .36057 .53796 .35325 .5286 Mtetra
.885 .731 .685 r
.35325 .5286 .36057 .53796 .37385 .50781 .36657 .49927 Mtetra
.855 .747 .743 r
.36657 .49927 .37385 .50781 .38657 .48745 .37929 .48041 Mtetra
.791 .778 .841 r
.37929 .48041 .38657 .48745 .39887 .47667 .3916 .47055 Mtetra
.66 .783 .94 r
.3916 .47055 .39887 .47667 .41094 .47276 .40371 .4665 Mtetra
.519 .731 .971 r
.40371 .4665 .41094 .47276 .42295 .4723 .41577 .46546 Mtetra
.485 .699 .963 r
.41577 .46546 .42295 .4723 .43502 .47242 .42788 .4652 Mtetra
.521 .703 .953 r
.42788 .4652 .43502 .47242 .4472 .47179 .44009 .46443 Mtetra
.565 .717 .944 r
.44009 .46443 .4472 .47179 .45947 .4702 .4524 .46279 Mtetra
.597 .729 .936 r
.4524 .46279 .45947 .4702 .47184 .46784 .46479 .46041 Mtetra
.617 .736 .931 r
.46479 .46041 .47184 .46784 .48427 .46495 .47726 .45749 Mtetra
.631 .741 .927 r
.47726 .45749 .48427 .46495 .49678 .46166 .4898 .45419 Mtetra
.641 .745 .924 r
.4898 .45419 .49678 .46166 .50935 .45809 .50241 .45059 Mtetra
.648 .748 .922 r
.50241 .45059 .50935 .45809 .52198 .45428 .51508 .44675 Mtetra
.656 .75 .92 r
.51508 .44675 .52198 .45428 .53468 .45025 .52781 .44267 Mtetra
.662 .752 .917 r
.52781 .44267 .53468 .45025 .54742 .446 .5406 .43835 Mtetra
.669 .754 .914 r
.5406 .43835 .54742 .446 .56023 .4415 .55344 .43379 Mtetra
.678 .756 .91 r
.55344 .43379 .56023 .4415 .57309 .4367 .56634 .42894 Mtetra
.688 .758 .905 r
.56634 .42894 .57309 .4367 .58599 .43152 .57929 .42369 Mtetra
.701 .761 .899 r
.57929 .42369 .58599 .43152 .59894 .42573 .59227 .41795 Mtetra
.72 .769 .892 r
.59227 .41795 .59894 .42573 .61191 .41918 .60529 .41146 Mtetra
.741 .778 .883 r
.60529 .41146 .61191 .41918 .62489 .41167 .61833 .40404 Mtetra
.753 .784 .878 r
.61833 .40404 .62489 .41167 .63788 .40342 .63138 .39606 Mtetra
.737 .789 .894 r
.63138 .39606 .63788 .40342 .65093 .39577 .6445 .38888 Mtetra
.647 .776 .942 r
.6445 .38888 .65093 .39577 .66416 .39164 .65778 .38482 Mtetra
.348 .637 .962 r
.65778 .38482 .66416 .39164 .6778 .39453 .6714 .3867 Mtetra
0 .209 .719 r
.6714 .3867 .6778 .39453 .69206 .40727 .6856 .39781 Mtetra
0 0 .401 r
.6856 .39781 .69206 .40727 .7071 .43006 .70058 .41967 Mtetra
0 0 .422 r
.70058 .41967 .7071 .43006 .7224 .45224 .71592 .44263 Mtetra
.391 .582 .918 r
.71592 .44263 .7224 .45224 .73662 .45306 .73029 .44536 Mtetra
.912 .81 .734 r
.73029 .44536 .73662 .45306 .74928 .42969 .7431 .423 Mtetra
.943 .82 .694 r
.7431 .423 .74928 .42969 .7616 .40295 .75549 .39585 Mtetra
.885 .831 .788 r
.75549 .39585 .7616 .40295 .7746 .3866 .76851 .3788 Mtetra
.759 .799 .885 r
.76851 .3788 .7746 .3866 .78824 .3785 .78218 .37033 Mtetra
.678 .763 .915 r
.78218 .37033 .78824 .3785 .80217 .37335 .79615 .36506 Mtetra
.659 .753 .92 r
.79615 .36506 .80217 .37335 .81622 .36878 .81025 .36044 Mtetra
.656 .752 .92 r
.81025 .36044 .81622 .36878 .83034 .36426 .82442 .35588 Mtetra
.656 .751 .92 r
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Mtetra
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Mtetra
.24079 .53391 .24852 .54077 .26007 .53707 .25237 .53018 Mtetra
.652 .751 .922 r
.25237 .53018 .26007 .53707 .27167 .53343 .264 .52652 Mtetra
.625 .743 .932 r
.264 .52652 .27167 .53343 .28327 .53042 .27562 .52358 Mtetra
.445 .679 .964 r
.27562 .52358 .28327 .53042 .29472 .53048 .28707 .52394 Mtetra
0 .101 .576 r
.28707 .52394 .29472 .53048 .30571 .53877 .29802 .5328 Mtetra
.827 .354 0 r
.29802 .5328 .30571 .53877 .31624 .55671 .30854 .55065 Mtetra
.587 .054 0 r
.30854 .55065 .31624 .55671 .32724 .56997 .31967 .56162 Mtetra
.827 .75 .779 r
.31967 .56162 .32724 .56997 .33974 .55904 .33243 .54703 Mtetra
.872 .705 .673 r
.33243 .54703 .33974 .55904 .35325 .5286 .34608 .51539 Mtetra
.846 .691 .69 r
.34608 .51539 .35325 .5286 .36657 .49927 .35928 .4897 Mtetra
.798 .728 .786 r
.35928 .4897 .36657 .49927 .37929 .48041 .37177 .47723 Mtetra
.704 .889 .965 r
.37177 .47723 .37929 .48041 .3916 .47055 .38396 .4715 Mtetra
.453 .885 .864 r
.38396 .4715 .3916 .47055 .40371 .4665 .39616 .46673 Mtetra
.493 .901 .908 r
.39616 .46673 .40371 .4665 .41577 .46546 .4084 .46211 Mtetra
.599 .863 .993 r
.4084 .46211 .41577 .46546 .42788 .4652 .42066 .45845 Mtetra
.603 .751 .948 r
.42066 .45845 .42788 .4652 .44009 .46443 .43295 .4558 Mtetra
.598 .695 .911 r
.43295 .4558 .44009 .46443 .4524 .46279 .4453 .45355 Mtetra
.604 .683 .897 r
.4453 .45355 .4524 .46279 .46479 .46041 .45772 .45116 Mtetra
.616 .688 .895 r
.45772 .45116 .46479 .46041 .47726 .45749 .47021 .44841 Mtetra
.627 .698 .896 r
.47021 .44841 .47726 .45749 .4898 .45419 .48278 .44528 Mtetra
.637 .707 .897 r
.48278 .44528 .4898 .45419 .50241 .45059 .49542 .44181 Mtetra
.646 .714 .897 r
.49542 .44181 .50241 .45059 .51508 .44675 .50812 .43803 Mtetra
.654 .72 .897 r
.50812 .43803 .51508 .44675 .52781 .44267 .52089 .43397 Mtetra
.662 .724 .895 r
.52089 .43397 .52781 .44267 .5406 .43835 .53371 .42961 Mtetra
.67 .726 .892 r
.53371 .42961 .5406 .43835 .55344 .43379 .54659 .42493 Mtetra
.68 .728 .886 r
.54659 .42493 .55344 .43379 .56634 .42894 .55952 .41988 Mtetra
.689 .727 .879 r
.55952 .41988 .56634 .42894 .57929 .42369 .5725 .41441 Mtetra
.699 .726 .871 r
.5725 .41441 .57929 .42369 .59227 .41795 .58553 .40847 Mtetra
.701 .723 .867 r
.58553 .40847 .59227 .41795 .60529 .41146 .59859 .40238 Mtetra
.692 .73 .88 r
.59859 .40238 .60529 .41146 .61833 .40404 .61172 .39676 Mtetra
.664 .77 .929 r
.61172 .39676 .61833 .40404 .63138 .39606 .62494 .39222 Mtetra
.576 .855 .996 r
.62494 .39222 .63138 .39606 .6445 .38888 .63825 .38867 Mtetra
.347 .823 .868 r
.63825 .38867 .6445 .38888 .65778 .38482 .65163 .38523 Mtetra
.193 .724 .774 r
.65163 .38523 .65778 .38482 .6714 .3867 .66513 .38278 Mtetra
0 .468 .83 r
.66513 .38278 .6714 .3867 .6856 .39781 .67905 .38725 Mtetra
0 .005 .567 r
.67905 .38725 .6856 .39781 .70058 .41967 .69381 .40528 Mtetra
0 0 .52 r
.69381 .40528 .70058 .41967 .71592 .44263 .70919 .4294 Mtetra
.312 .455 .843 r
.70919 .4294 .71592 .44263 .73029 .44536 .7238 .43585 Mtetra
.879 .78 .747 r
.7238 .43585 .73029 .44536 .7431 .423 .73684 .41581 Mtetra
.938 .814 .695 r
.73684 .41581 .7431 .423 .75549 .39585 .74932 .38869 Mtetra
.89 .831 .781 r
.74932 .38869 .75549 .39585 .76851 .3788 .76237 .37097 Mtetra
.766 .802 .882 r
.76237 .37097 .76851 .3788 .78218 .37033 .77607 .36211 Mtetra
.681 .764 .914 r
.77607 .36211 .78218 .37033 .79615 .36506 .79008 .3567 Mtetra
.659 .753 .92 r
.79008 .3567 .79615 .36506 .81025 .36044 .80423 .35202 Mtetra
.656 .752 .92 r
.80423 .35202 .81025 .36044 .82442 .35588 .81845 .34742 Mtetra
.656 .751 .92 r
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Mtetra
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Mtetra
.655 .751 .92 r
.23299 .52699 .24079 .53391 .25237 .53018 .24461 .52323 Mtetra
.652 .75 .922 r
.24461 .52323 .25237 .53018 .264 .52652 .25626 .51956 Mtetra
.621 .742 .934 r
.25626 .51956 .264 .52652 .27562 .52358 .26791 .51669 Mtetra
.421 .668 .964 r
.26791 .51669 .27562 .52358 .28707 .52394 .27935 .51736 Mtetra
0 .071 .544 r
.27935 .51736 .28707 .52394 .29802 .5328 .29028 .52659 Mtetra
.809 .327 0 r
.29028 .52659 .29802 .5328 .30854 .55065 .30083 .54358 Mtetra
0 .244 .72 r
.30083 .54358 .30854 .55065 .31967 .56162 .31218 .55115 Mtetra
.831 .719 .74 r
.31218 .55115 .31967 .56162 .33243 .54703 .32518 .5331 Mtetra
.857 .689 .672 r
.32518 .5331 .33243 .54703 .34608 .51539 .33885 .50237 Mtetra
.827 .689 .711 r
.33885 .50237 .34608 .51539 .35928 .4897 .35187 .48151 Mtetra
.744 .747 .855 r
.35187 .48151 .35928 .4897 .37177 .47723 .36417 .47392 Mtetra
.521 .837 .999 r
.36417 .47392 .37177 .47723 .38396 .4715 .37627 .47144 Mtetra
.369 .834 .89 r
.37627 .47144 .38396 .4715 .39616 .46673 .38846 .46832 Mtetra
.424 .868 .818 r
.38846 .46832 .39616 .46673 .4084 .46211 .40078 .46322 Mtetra
.556 .934 .877 r
.40078 .46322 .4084 .46211 .42066 .45845 .4132 .45703 Mtetra
.665 .938 .966 r
.4132 .45703 .42066 .45845 .43295 .4558 .42564 .45112 Mtetra
.678 .843 .962 r
.42564 .45112 .43295 .4558 .4453 .45355 .4381 .4462 Mtetra
.654 .753 .923 r
.4381 .4462 .4453 .45355 .45772 .45116 .45059 .44218 Mtetra
.639 .705 .894 r
.45059 .44218 .45772 .45116 .47021 .44841 .46313 .43864 Mtetra
.636 .686 .88 r
.46313 .43864 .47021 .44841 .48278 .44528 .47573 .43517 Mtetra
.639 .681 .873 r
.47573 .43517 .48278 .44528 .49542 .44181 .48839 .43156 Mtetra
.646 .681 .869 r
.48839 .43156 .49542 .44181 .50812 .43803 .50112 .42768 Mtetra
.653 .683 .865 r
.50112 .42768 .50812 .43803 .52089 .43397 .51391 .42351 Mtetra
.66 .684 .862 r
.51391 .42351 .52089 .43397 .53371 .42961 .52676 .41903 Mtetra
.664 .684 .858 r
.52676 .41903 .53371 .42961 .54659 .42493 .53967 .41434 Mtetra
.666 .685 .858 r
.53967 .41434 .54659 .42493 .55952 .41988 .55264 .40954 Mtetra
.663 .69 .865 r
.55264 .40954 .55952 .41988 .5725 .41441 .56566 .40489 Mtetra
.649 .704 .887 r
.56566 .40489 .5725 .41441 .58553 .40847 .57876 .40083 Mtetra
.618 .743 .936 r
.57876 .40083 .58553 .40847 .59859 .40238 .59193 .39764 Mtetra
.534 .807 .996 r
.59193 .39764 .59859 .40238 .61172 .39676 .6052 .39529 Mtetra
.345 .807 .93 r
.6052 .39529 .61172 .39676 .62494 .39222 .61855 .39309 Mtetra
.235 .751 .763 r
.61855 .39309 .62494 .39222 .63825 .38867 .63195 .3898 Mtetra
.382 .843 .794 r
.63195 .3898 .63825 .38867 .65163 .38523 .64535 .38456 Mtetra
.565 .931 .927 r
.64535 .38456 .65163 .38523 .66513 .38278 .65878 .37871 Mtetra
.382 .76 .991 r
.65878 .37871 .66513 .38278 .67905 .38725 .67251 .37809 Mtetra
0 .163 .693 r
.67251 .37809 .67905 .38725 .69381 .40528 .68702 .39106 Mtetra
0 0 .536 r
.68702 .39106 .69381 .40528 .70919 .4294 .70231 .41416 Mtetra
.22 .363 .795 r
.70231 .41416 .70919 .4294 .7238 .43585 .71712 .42411 Mtetra
.83 .737 .762 r
.71712 .42411 .7238 .43585 .73684 .41581 .73045 .40754 Mtetra
.926 .799 .701 r
.73045 .40754 .73684 .41581 .74932 .38869 .74308 .38126 Mtetra
.891 .826 .776 r
.74308 .38126 .74932 .38869 .76237 .37097 .75617 .36307 Mtetra
.773 .804 .878 r
.75617 .36307 .76237 .37097 .77607 .36211 .7699 .35382 Mtetra
.684 .766 .914 r
.7699 .35382 .77607 .36211 .79008 .3567 .78396 .34826 Mtetra
.659 .753 .92 r
.78396 .34826 .79008 .3567 .80423 .35202 .79815 .34353 Mtetra
.656 .752 .92 r
.79815 .34353 .80423 .35202 .81845 .34742 .81243 .33888 Mtetra
.656 .751 .92 r
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Mtetra
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Mtetra
.21354 .5238 .22143 .53075 .23299 .52699 .22513 .52002 Mtetra
.655 .751 .92 r
.22513 .52002 .23299 .52699 .24461 .52323 .23678 .51623 Mtetra
.651 .75 .922 r
.23678 .51623 .24461 .52323 .25626 .51956 .24846 .51255 Mtetra
.617 .741 .935 r
.24846 .51255 .25626 .51956 .26791 .51669 .26013 .50974 Mtetra
.403 .66 .963 r
.26013 .50974 .26791 .51669 .27935 .51736 .27157 .51063 Mtetra
0 .079 .555 r
.27157 .51063 .27935 .51736 .29028 .52659 .2825 .51981 Mtetra
.755 .259 0 r
.2825 .51981 .29028 .52659 .30083 .54358 .29316 .53506 Mtetra
.222 .516 .913 r
.29316 .53506 .30083 .54358 .31218 .55115 .30474 .53901 Mtetra
.826 .699 .724 r
.30474 .53901 .31218 .55115 .32518 .5331 .31789 .51947 Mtetra
.85 .69 .684 r
.31789 .51947 .32518 .5331 .33885 .50237 .33144 .49196 Mtetra
.824 .72 .75 r
.33144 .49196 .33885 .50237 .35187 .48151 .34428 .47541 Mtetra
.711 .799 .919 r
.34428 .47541 .35187 .48151 .36417 .47392 .35653 .46969 Mtetra
.536 .813 .997 r
.35653 .46969 .36417 .47392 .37627 .47144 .36866 .46742 Mtetra
.539 .822 .998 r
.36866 .46742 .37627 .47144 .38846 .46832 .38086 .46497 Mtetra
.568 .855 .997 r
.38086 .46497 .38846 .46832 .40078 .46322 .39317 .46175 Mtetra
.556 .903 .975 r
.39317 .46175 .40078 .46322 .4132 .45703 .40557 .45755 Mtetra
.514 .913 .897 r
.40557 .45755 .4132 .45703 .42564 .45112 .41806 .45229 Mtetra
.519 .917 .863 r
.41806 .45229 .42564 .45112 .4381 .4462 .43062 .44636 Mtetra
.587 .942 .92 r
.43062 .44636 .4381 .4462 .45059 .44218 .44322 .44038 Mtetra
.65 .928 .973 r
.44322 .44038 .45059 .44218 .46313 .43864 .45586 .43479 Mtetra
.668 .873 .976 r
.45586 .43479 .46313 .43864 .47573 .43517 .46854 .42973 Mtetra
.665 .821 .958 r
.46854 .42973 .47573 .43517 .48839 .43156 .48126 .42512 Mtetra
.658 .788 .944 r
.48126 .42512 .48839 .43156 .50112 .42768 .49404 .4208 Mtetra
.651 .774 .938 r
.49404 .4208 .50112 .42768 .51391 .42351 .50687 .41669 Mtetra
.643 .774 .943 r
.50687 .41669 .51391 .42351 .52676 .41903 .51977 .41277 Mtetra
.63 .788 .958 r
.51977 .41277 .52676 .41903 .53967 .41434 .53272 .40909 Mtetra
.601 .813 .981 r
.53272 .40909 .53967 .41434 .55264 .40954 .54575 .40575 Mtetra
.538 .84 .999 r
.54575 .40575 .55264 .40954 .56566 .40489 .55885 .40284 Mtetra
.426 .839 .968 r
.55885 .40284 .56566 .40489 .57876 .40083 .57203 .40025 Mtetra
.298 .79 .877 r
.57203 .40025 .57876 .40083 .59193 .39764 .58529 .39778 Mtetra
.267 .774 .825 r
.58529 .39778 .59193 .39764 .6052 .39529 .59862 .39493 Mtetra
.395 .85 .891 r
.59862 .39493 .6052 .39529 .61855 .39309 .612 .39111 Mtetra
.585 .915 .973 r
.612 .39111 .61855 .39309 .63195 .3898 .62541 .38609 Mtetra
.688 .899 .972 r
.62541 .38609 .63195 .3898 .64535 .38456 .63885 .38002 Mtetra
.705 .878 .962 r
.63885 .38002 .64535 .38456 .65878 .37871 .65233 .37373 Mtetra
.548 .811 .994 r
.65233 .37373 .65878 .37871 .67251 .37809 .66601 .37105 Mtetra
0 .325 .795 r
.66601 .37105 .67251 .37809 .68702 .39106 .68032 .3795 Mtetra
0 0 .55 r
.68032 .3795 .68702 .39106 .70231 .41416 .69541 .39919 Mtetra
.146 .32 .782 r
.69541 .39919 .70231 .41416 .71712 .42411 .71031 .41062 Mtetra
.776 .696 .775 r
.71031 .41062 .71712 .42411 .73045 .40754 .72391 .39774 Mtetra
.904 .778 .712 r
.72391 .39774 .73045 .40754 .74308 .38126 .73674 .3732 Mtetra
.885 .814 .773 r
.73674 .3732 .74308 .38126 .75617 .36307 .74991 .35501 Mtetra
.777 .802 .873 r
.74991 .35501 .75617 .36307 .7699 .35382 .76368 .34545 Mtetra
.687 .767 .913 r
.76368 .34545 .7699 .35382 .78396 .34826 .77778 .33975 Mtetra
.66 .754 .919 r
.77778 .33975 .78396 .34826 .79815 .34353 .79202 .33496 Mtetra
.656 .752 .92 r
.79202 .33496 .79815 .34353 .81243 .33888 .80635 .33027 Mtetra
.656 .751 .92 r
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Mtetra
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32085 Mtetra
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Mtetra
.20559 .5168 .21354 .5238 .22513 .52002 .21721 .51299 Mtetra
.655 .751 .92 r
.21721 .51299 .22513 .52002 .23678 .51623 .22888 .50917 Mtetra
.65 .75 .923 r
.22888 .50917 .23678 .51623 .24846 .51255 .2406 .50547 Mtetra
.614 .74 .936 r
.2406 .50547 .24846 .51255 .26013 .50974 .25229 .50269 Mtetra
.401 .658 .963 r
.25229 .50269 .26013 .50974 .27157 .51063 .26375 .50361 Mtetra
0 .137 .62 r
.26375 .50361 .27157 .51063 .2825 .51981 .27472 .51218 Mtetra
.633 .13 0 r
.27472 .51218 .2825 .51981 .29316 .53506 .28552 .52513 Mtetra
.452 .6 .908 r
.28552 .52513 .29316 .53506 .30474 .53901 .29729 .52633 Mtetra
.818 .692 .725 r
.29729 .52633 .30474 .53901 .31789 .51947 .31044 .50747 Mtetra
.847 .705 .705 r
.31044 .50747 .31789 .51947 .33144 .49196 .32383 .48395 Mtetra
.824 .761 .793 r
.32383 .48395 .33144 .49196 .34428 .47541 .33656 .4703 Mtetra
.698 .829 .946 r
.33656 .4703 .34428 .47541 .35653 .46969 .34884 .46497 Mtetra
.583 .814 .987 r
.34884 .46497 .35653 .46969 .36866 .46742 .36104 .4621 Mtetra
.601 .8 .976 r
.36104 .4621 .36866 .46742 .38086 .46497 .3733 .45906 Mtetra
.627 .79 .96 r
.3733 .45906 .38086 .46497 .39317 .46175 .38566 .45558 Mtetra
.633 .784 .954 r
.38566 .45558 .39317 .46175 .40557 .45755 .39807 .45199 Mtetra
.624 .803 .968 r
.39807 .45199 .40557 .45755 .41806 .45229 .41055 .44846 Mtetra
.6 .854 .992 r
.41055 .44846 .41806 .45229 .43062 .44636 .42309 .44478 Mtetra
.538 .896 .974 r
.42309 .44478 .43062 .44636 .44322 .44038 .43571 .44074 Mtetra
.438 .876 .883 r
.43571 .44074 .44322 .44038 .45586 .43479 .44839 .43631 Mtetra
.356 .828 .79 r
.44839 .43631 .45586 .43479 .46854 .42973 .46113 .43165 Mtetra
.313 .798 .746 r
.46113 .43165 .46854 .42973 .48126 .42512 .47393 .42701 Mtetra
.293 .784 .738 r
.47393 .42701 .48126 .42512 .49404 .4208 .48679 .42254 Mtetra
.275 .774 .738 r
.48679 .42254 .49404 .4208 .50687 .41669 .4997 .41835 Mtetra
.247 .755 .73 r
.4997 .41835 .50687 .41669 .51977 .41277 .51267 .41448 Mtetra
.209 .728 .708 r
.51267 .41448 .51977 .41277 .53272 .40909 .5257 .41091 Mtetra
.181 .706 .686 r
.5257 .41091 .53272 .40909 .54575 .40575 .53881 .40748 Mtetra
.203 .723 .701 r
.53881 .40748 .54575 .40575 .55885 .40284 .55198 .40387 Mtetra
.31 .8 .79 r
.55198 .40387 .55885 .40284 .57203 .40025 .56522 .39978 Mtetra
.501 .903 .92 r
.56522 .39978 .57203 .40025 .58529 .39778 .57851 .39484 Mtetra
.65 .91 .981 r
.57851 .39484 .58529 .39778 .59862 .39493 .59184 .38932 Mtetra
.68 .834 .957 r
.59184 .38932 .59862 .39493 .612 .39111 .60524 .38398 Mtetra
.671 .785 .935 r
.60524 .38398 .612 .39111 .62541 .38609 .6187 .37905 Mtetra
.677 .791 .935 r
.6187 .37905 .62541 .38609 .63885 .38002 .63222 .3739 Mtetra
.687 .824 .949 r
.63222 .3739 .63885 .38002 .65233 .37373 .64578 .36835 Mtetra
.583 .814 .987 r
.64578 .36835 .65233 .37373 .66601 .37105 .6595 .36512 Mtetra
.031 .472 .879 r
.6595 .36512 .66601 .37105 .68032 .3795 .6737 .37042 Mtetra
0 .058 .6 r
.6737 .37042 .68032 .3795 .69541 .39919 .68857 .38589 Mtetra
.115 .331 .8 r
.68857 .38589 .69541 .39919 .71031 .41062 .70342 .39652 Mtetra
.736 .673 .789 r
.70342 .39652 .71031 .41062 .72391 .39774 .71723 .38642 Mtetra
.877 .755 .724 r
.71723 .38642 .72391 .39774 .73674 .3732 .73029 .36423 Mtetra
.871 .796 .775 r
.73029 .36423 .73674 .3732 .74991 .35501 .74357 .34662 Mtetra
.776 .796 .869 r
.74357 .34662 .74991 .35501 .76368 .34545 .7574 .33697 Mtetra
.688 .766 .911 r
.7574 .33697 .76368 .34545 .77778 .33975 .77155 .33116 Mtetra
.661 .754 .919 r
.77155 .33116 .77778 .33975 .79202 .33496 .78584 .32631 Mtetra
.656 .752 .92 r
.78584 .32631 .79202 .33496 .80635 .33027 .80021 .32157 Mtetra
.656 .751 .92 r
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Mtetra
.81466 .31683 .82074 .32557 .83521 .32085 .82917 .31206 Mtetra
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Mtetra
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Mtetra
.655 .751 .92 r
.20922 .5059 .21721 .51299 .22888 .50917 .22092 .50205 Mtetra
.65 .75 .923 r
.22092 .50205 .22888 .50917 .2406 .50547 .23267 .49833 Mtetra
.615 .74 .935 r
.23267 .49833 .2406 .50547 .25229 .50269 .24439 .49551 Mtetra
.42 .664 .962 r
.24439 .49551 .25229 .50269 .26375 .50361 .25588 .49618 Mtetra
0 .244 .726 r
.25588 .49618 .26375 .50361 .27472 .51218 .26694 .50362 Mtetra
0 .052 .57 r
.26694 .50362 .27472 .51218 .28552 .52513 .2779 .51423 Mtetra
.527 .614 .883 r
.2779 .51423 .28552 .52513 .29729 .52633 .28977 .51403 Mtetra
.809 .695 .739 r
.28977 .51403 .29729 .52633 .31044 .50747 .30283 .49729 Mtetra
.846 .726 .731 r
.30283 .49729 .31044 .50747 .32383 .48395 .31606 .47735 Mtetra
.822 .794 .825 r
.31606 .47735 .32383 .48395 .33656 .4703 .32876 .46534 Mtetra
.705 .836 .945 r
.32876 .46534 .33656 .4703 .34884 .46497 .34109 .45976 Mtetra
.624 .812 .972 r
.34109 .45976 .34884 .46497 .36104 .4621 .35336 .45619 Mtetra
.624 .79 .961 r
.35336 .45619 .36104 .4621 .3733 .45906 .36569 .45275 Mtetra
.632 .781 .953 r
.36569 .45275 .3733 .45906 .38566 .45558 .37808 .44919 Mtetra
.641 .782 .949 r
.37808 .44919 .38566 .45558 .39807 .45199 .39054 .44539 Mtetra
.65 .779 .942 r
.39054 .44539 .39807 .45199 .41055 .44846 .40308 .44135 Mtetra
.653 .766 .932 r
.40308 .44135 .41055 .44846 .42309 .44478 .41567 .43724 Mtetra
.65 .753 .925 r
.41567 .43724 .42309 .44478 .43571 .44074 .42832 .43322 Mtetra
.646 .753 .928 r
.42832 .43322 .43571 .44074 .44839 .43631 .44103 .42932 Mtetra
.642 .769 .94 r
.44103 .42932 .44839 .43631 .46113 .43165 .45379 .42545 Mtetra
.64 .793 .956 r
.45379 .42545 .46113 .43165 .47393 .42701 .46663 .4215 Mtetra
.64 .817 .968 r
.46663 .4215 .47393 .42701 .48679 .42254 .47952 .41739 Mtetra
.644 .831 .972 r
.47952 .41739 .48679 .42254 .4997 .41835 .49249 .41306 Mtetra
.655 .831 .967 r
.49249 .41306 .4997 .41835 .51267 .41448 .50551 .40847 Mtetra
.67 .813 .952 r
.50551 .40847 .51267 .41448 .5257 .41091 .5186 .4036 Mtetra
.676 .776 .926 r
.5186 .4036 .5257 .41091 .53881 .40748 .53174 .39863 Mtetra
.665 .732 .899 r
.53174 .39863 .53881 .40748 .55198 .40387 .54494 .39393 Mtetra
.647 .7 .885 r
.54494 .39393 .55198 .40387 .56522 .39978 .55821 .38983 Mtetra
.624 .691 .892 r
.55821 .38983 .56522 .39978 .57851 .39484 .57156 .3865 Mtetra
.622 .733 .926 r
.57156 .3865 .57851 .39484 .59184 .38932 .58498 .3831 Mtetra
.655 .809 .957 r
.58498 .3831 .59184 .38932 .60524 .38398 .59845 .37849 Mtetra
.69 .844 .957 r
.59845 .37849 .60524 .38398 .6187 .37905 .61195 .37279 Mtetra
.69 .821 .945 r
.61195 .37279 .6187 .37905 .63222 .3739 .62551 .36713 Mtetra
.668 .8 .945 r
.62551 .36713 .63222 .3739 .64578 .36835 .63915 .36217 Mtetra
.578 .786 .978 r
.63915 .36217 .64578 .36835 .6595 .36512 .65293 .35929 Mtetra
.156 .565 .931 r
.65293 .35929 .6595 .36512 .6737 .37042 .66709 .36282 Mtetra
0 .18 .687 r
.66709 .36282 .6737 .37042 .68857 .38589 .68179 .37445 Mtetra
.148 .394 .843 r
.68179 .37445 .68857 .38589 .70342 .39652 .69652 .38277 Mtetra
.718 .671 .803 r
.69652 .38277 .70342 .39652 .71723 .38642 .71045 .37405 Mtetra
.852 .738 .737 r
.71045 .37405 .71723 .38642 .73029 .36423 .72372 .35425 Mtetra
.85 .776 .779 r
.72372 .35425 .73029 .36423 .74357 .34662 .73715 .33778 Mtetra
.768 .784 .866 r
.73715 .33778 .74357 .34662 .7574 .33697 .75105 .32833 Mtetra
.688 .764 .91 r
.75105 .32833 .7574 .33697 .77155 .33116 .76525 .32248 Mtetra
.661 .754 .919 r
.76525 .32248 .77155 .33116 .78584 .32631 .77959 .31758 Mtetra
.656 .752 .92 r
.77959 .31758 .78584 .32631 .80021 .32157 .79402 .3128 Mtetra
.656 .751 .92 r
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Mtetra
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Mtetra
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Mtetra
.655 .751 .92 r
.20116 .49875 .20922 .5059 .22092 .50205 .2129 .49487 Mtetra
.651 .75 .922 r
.2129 .49487 .22092 .50205 .23267 .49833 .22467 .4911 Mtetra
.619 .741 .934 r
.22467 .4911 .23267 .49833 .24439 .49551 .23643 .48817 Mtetra
.458 .678 .959 r
.23643 .48817 .24439 .49551 .25588 .49618 .24799 .4883 Mtetra
0 .372 .831 r
.24799 .4883 .25588 .49618 .26694 .50362 .25916 .49426 Mtetra
0 .224 .735 r
.25916 .49426 .26694 .50362 .2779 .51423 .27026 .50284 Mtetra
.535 .609 .873 r
.27026 .50284 .2779 .51423 .28977 .51403 .28215 .50246 Mtetra
.794 .701 .762 r
.28215 .50246 .28977 .51403 .30283 .49729 .29507 .48847 Mtetra
.842 .748 .759 r
.29507 .48847 .30283 .49729 .31606 .47735 .30818 .47138 Mtetra
.818 .811 .844 r
.30818 .47138 .31606 .47735 .32876 .46534 .32088 .46019 Mtetra
.718 .834 .936 r
.32088 .46019 .32876 .46534 .34109 .45976 .33329 .45417 Mtetra
.65 .808 .959 r
.33329 .45417 .34109 .45976 .35336 .45619 .34563 .45005 Mtetra
.642 .789 .953 r
.34563 .45005 .35336 .45619 .36569 .45275 .35801 .4462 Mtetra
.646 .779 .944 r
.35801 .4462 .36569 .45275 .37808 .44919 .37046 .44227 Mtetra
.645 .769 .938 r
.37046 .44227 .37808 .44919 .39054 .44539 .38296 .43839 Mtetra
.642 .766 .939 r
.38296 .43839 .39054 .44539 .40308 .44135 .39552 .43458 Mtetra
.642 .774 .944 r
.39552 .43458 .40308 .44135 .41567 .43724 .40815 .43072 Mtetra
.646 .784 .948 r
.40815 .43072 .41567 .43724 .42832 .43322 .42084 .42669 Mtetra
.652 .787 .946 r
.42084 .42669 .42832 .43322 .44103 .42932 .43359 .42248 Mtetra
.657 .78 .939 r
.43359 .42248 .44103 .42932 .45379 .42545 .44641 .41815 Mtetra
.66 .768 .93 r
.44641 .41815 .45379 .42545 .46663 .4215 .45929 .41374 Mtetra
.661 .756 .921 r
.45929 .41374 .46663 .4215 .47952 .41739 .47224 .40927 Mtetra
.661 .748 .914 r
.47224 .40927 .47952 .41739 .49249 .41306 .48524 .40479 Mtetra
.659 .744 .913 r
.48524 .40479 .49249 .41306 .50551 .40847 .4983 .40037 Mtetra
.654 .748 .919 r
.4983 .40037 .50551 .40847 .5186 .4036 .51142 .39607 Mtetra
.655 .765 .93 r
.51142 .39607 .5186 .4036 .53174 .39863 .52461 .3917 Mtetra
.67 .789 .938 r
.52461 .3917 .53174 .39863 .54494 .39393 .53786 .38683 Mtetra
.685 .789 .929 r
.53786 .38683 .54494 .39393 .55821 .38983 .55117 .38147 Mtetra
.683 .755 .906 r
.55117 .38147 .55821 .38983 .57156 .3865 .56453 .37609 Mtetra
.646 .692 .879 r
.56453 .37609 .57156 .3865 .58498 .3831 .57797 .37192 Mtetra
.607 .66 .876 r
.57797 .37192 .58498 .3831 .59845 .37849 .5915 .36911 Mtetra
.617 .707 .909 r
.5915 .36911 .59845 .37849 .61195 .37279 .60511 .36587 Mtetra
.662 .794 .945 r
.60511 .36587 .61195 .37279 .62551 .36713 .61875 .36106 Mtetra
.666 .823 .959 r
.61875 .36106 .62551 .36713 .63915 .36217 .63244 .35599 Mtetra
.571 .786 .98 r
.63244 .35599 .63915 .36217 .65293 .35929 .64629 .35321 Mtetra
.235 .61 .954 r
.64629 .35321 .65293 .35929 .66709 .36282 .66045 .35583 Mtetra
0 .317 .786 r
.66045 .35583 .66709 .36282 .68179 .37445 .67502 .36439 Mtetra
.247 .495 .896 r
.67502 .36439 .68179 .37445 .69652 .38277 .68962 .36973 Mtetra
.721 .685 .814 r
.68962 .36973 .69652 .38277 .71045 .37405 .70359 .36112 Mtetra
.831 .726 .749 r
.70359 .36112 .71045 .37405 .72372 .35425 .71705 .3434 Mtetra
.826 .758 .787 r
.71705 .3434 .72372 .35425 .73715 .33778 .73065 .32844 Mtetra
.755 .771 .866 r
.73065 .32844 .73715 .33778 .75105 .32833 .74464 .31949 Mtetra
.685 .76 .908 r
.74464 .31949 .75105 .32833 .76525 .32248 .7589 .3137 Mtetra
.66 .753 .919 r
.7589 .3137 .76525 .32248 .77959 .31758 .77329 .30876 Mtetra
.656 .752 .92 r
.77329 .30876 .77959 .31758 .79402 .3128 .78776 .30394 Mtetra
.656 .751 .92 r
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Mtetra
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Mtetra
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Mtetra
.655 .751 .92 r
.19304 .49154 .20116 .49875 .2129 .49487 .2048 .48762 Mtetra
.651 .75 .922 r
.2048 .48762 .2129 .49487 .22467 .4911 .21661 .4838 Mtetra
.626 .742 .931 r
.21661 .4838 .22467 .4911 .23643 .48817 .22841 .48065 Mtetra
.505 .694 .954 r
.22841 .48065 .23643 .48817 .24799 .4883 .24005 .48005 Mtetra
.149 .487 .902 r
.24005 .48005 .24799 .4883 .25916 .49426 .25137 .48434 Mtetra
.007 .345 .824 r
.25137 .48434 .25916 .49426 .27026 .50284 .26258 .49125 Mtetra
.51 .594 .874 r
.26258 .49125 .27026 .50284 .28215 .50246 .27444 .4915 Mtetra
.77 .706 .791 r
.27444 .4915 .28215 .50246 .29507 .48847 .28719 .48044 Mtetra
.834 .764 .785 r
.28719 .48044 .29507 .48847 .30818 .47138 .3002 .46565 Mtetra
.814 .819 .854 r
.3002 .46565 .30818 .47138 .32088 .46019 .31294 .45485 Mtetra
.732 .831 .926 r
.31294 .45485 .32088 .46019 .33329 .45417 .32542 .44831 Mtetra
.671 .806 .948 r
.32542 .44831 .33329 .45417 .34563 .45005 .33783 .44366 Mtetra
.652 .786 .946 r
.33783 .44366 .34563 .45005 .35801 .4462 .35027 .43953 Mtetra
.647 .778 .943 r
.35027 .43953 .35801 .4462 .37046 .44227 .36275 .43554 Mtetra
.65 .777 .941 r
.36275 .43554 .37046 .44227 .38296 .43839 .3753 .43146 Mtetra
.654 .774 .937 r
.3753 .43146 .38296 .43839 .39552 .43458 .38792 .42725 Mtetra
.655 .764 .929 r
.38792 .42725 .39552 .43458 .40815 .43072 .40059 .42303 Mtetra
.653 .754 .923 r
.40059 .42303 .40815 .43072 .42084 .42669 .41332 .41885 Mtetra
.652 .75 .921 r
.41332 .41885 .42084 .42669 .43359 .42248 .42612 .41469 Mtetra
.653 .753 .923 r
.42612 .41469 .43359 .42248 .44641 .41815 .43897 .41047 Mtetra
.657 .758 .924 r
.43897 .41047 .44641 .41815 .45929 .41374 .45189 .40609 Mtetra
.661 .761 .925 r
.45189 .40609 .45929 .41374 .47224 .40927 .46487 .4016 Mtetra
.662 .762 .925 r
.46487 .4016 .47224 .40927 .48524 .40479 .47792 .39706 Mtetra
.66 .761 .925 r
.47792 .39706 .48524 .40479 .4983 .40037 .49102 .39254 Mtetra
.656 .758 .925 r
.49102 .39254 .4983 .40037 .51142 .39607 .50419 .38812 Mtetra
.644 .751 .927 r
.50419 .38812 .51142 .39607 .52461 .3917 .51742 .38406 Mtetra
.624 .754 .94 r
.51742 .38406 .52461 .3917 .53786 .38683 .53071 .38052 Mtetra
.631 .799 .963 r
.53071 .38052 .53786 .38683 .55117 .38147 .54408 .37653 Mtetra
.669 .855 .971 r
.54408 .37653 .55117 .38147 .56453 .37609 .5575 .37128 Mtetra
.706 .87 .959 r
.5575 .37128 .56453 .37609 .57797 .37192 .57097 .36495 Mtetra
.681 .798 .937 r
.57097 .36495 .57797 .37192 .5915 .36911 .5845 .35958 Mtetra
.619 .706 .907 r
.5845 .35958 .5915 .36911 .60511 .36587 .59814 .35625 Mtetra
.606 .699 .909 r
.59814 .35625 .60511 .36587 .61875 .36106 .61187 .3533 Mtetra
.624 .758 .943 r
.61187 .3533 .61875 .36106 .63244 .35599 .62566 .3496 Mtetra
.556 .774 .98 r
.62566 .3496 .63244 .35599 .64629 .35321 .63957 .34715 Mtetra
.278 .64 .965 r
.63957 .34715 .64629 .35321 .66045 .35583 .65375 .34909 Mtetra
.023 .447 .871 r
.65375 .34909 .66045 .35583 .67502 .36439 .66824 .35511 Mtetra
.386 .602 .933 r
.66824 .35511 .67502 .36439 .68962 .36973 .68271 .35726 Mtetra
.737 .702 .818 r
.68271 .35726 .68962 .36973 .70359 .36112 .69668 .34792 Mtetra
.813 .718 .76 r
.69668 .34792 .70359 .36112 .71705 .3434 .7103 .33192 Mtetra
.801 .742 .798 r
.7103 .33192 .71705 .3434 .73065 .32844 .72406 .31869 Mtetra
.737 .757 .869 r
.72406 .31869 .73065 .32844 .74464 .31949 .73816 .31047 Mtetra
.679 .755 .908 r
.73816 .31047 .74464 .31949 .7589 .3137 .75248 .30482 Mtetra
.66 .752 .919 r
.75248 .30482 .7589 .3137 .77329 .30876 .76693 .29987 Mtetra
.656 .751 .92 r
.76693 .29987 .77329 .30876 .78776 .30394 .78145 .295 Mtetra
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Mtetra
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Mtetra
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Mtetra
.655 .751 .92 r
.18485 .48427 .19304 .49154 .2048 .48762 .19664 .48032 Mtetra
.653 .751 .921 r
.19664 .48032 .2048 .48762 .21661 .4838 .20848 .47642 Mtetra
.634 .744 .928 r
.20848 .47642 .21661 .4838 .22841 .48065 .22033 .47302 Mtetra
.551 .711 .946 r
.22033 .47302 .22841 .48065 .24005 .48005 .23207 .47155 Mtetra
.31 .574 .933 r
.23207 .47155 .24005 .48005 .25137 .48434 .24354 .47409 Mtetra
.15 .43 .868 r
.24354 .47409 .25137 .48434 .26258 .49125 .25487 .47954 Mtetra
.464 .571 .877 r
.25487 .47954 .26258 .49125 .27444 .4915 .26665 .4808 Mtetra
.732 .701 .822 r
.26665 .4808 .27444 .4915 .28719 .48044 .27922 .47271 Mtetra
.818 .772 .809 r
.27922 .47271 .28719 .48044 .3002 .46565 .29214 .45998 Mtetra
.812 .823 .859 r
.29214 .45998 .3002 .46565 .31294 .45485 .30492 .44938 Mtetra
.745 .83 .917 r
.30492 .44938 .31294 .45485 .32542 .44831 .31748 .44232 Mtetra
.686 .807 .94 r
.31748 .44232 .32542 .44831 .33783 .44366 .32996 .4372 Mtetra
.664 .789 .941 r
.32996 .4372 .33783 .44366 .35027 .43953 .34245 .43273 Mtetra
.658 .778 .938 r
.34245 .43273 .35027 .43953 .36275 .43554 .35499 .42843 Mtetra
.652 .769 .934 r
.35499 .42843 .36275 .43554 .3753 .43146 .36758 .42427 Mtetra
.648 .766 .935 r
.36758 .42427 .3753 .43146 .38792 .42725 .38023 .42021 Mtetra
.649 .772 .938 r
.38023 .42021 .38792 .42725 .40059 .42303 .39294 .4161 Mtetra
.654 .778 .939 r
.39294 .4161 .40059 .42303 .41332 .41885 .40571 .41182 Mtetra
.658 .777 .937 r
.40571 .41182 .41332 .41885 .42612 .41469 .41855 .4074 Mtetra
.664 .773 .93 r
.41855 .4074 .42612 .41469 .43897 .41047 .43146 .40279 Mtetra
.664 .762 .923 r
.43146 .40279 .43897 .41047 .45189 .40609 .44442 .39817 Mtetra
.656 .754 .922 r
.44442 .39817 .45189 .40609 .46487 .4016 .45745 .39378 Mtetra
.647 .755 .928 r
.45745 .39378 .46487 .4016 .47792 .39706 .47052 .38966 Mtetra
.635 .764 .941 r
.47052 .38966 .47792 .39706 .49102 .39254 .48366 .38579 Mtetra
.622 .781 .957 r
.48366 .38579 .49102 .39254 .50419 .38812 .49687 .38215 Mtetra
.626 .808 .97 r
.49687 .38215 .50419 .38812 .51742 .38406 .51015 .37822 Mtetra
.642 .818 .968 r
.51015 .37822 .51742 .38406 .53071 .38052 .52349 .37386 Mtetra
.614 .783 .963 r
.52349 .37386 .53071 .38052 .54408 .37653 .53691 .37033 Mtetra
.612 .798 .971 r
.53691 .37033 .54408 .37653 .5575 .37128 .5504 .36671 Mtetra
.676 .872 .973 r
.5504 .36671 .5575 .37128 .57097 .36495 .56394 .36108 Mtetra
.72 .905 .96 r
.56394 .36108 .57097 .36495 .5845 .35958 .57751 .35404 Mtetra
.679 .845 .962 r
.57751 .35404 .5845 .35958 .59814 .35625 .59116 .34849 Mtetra
.611 .754 .946 r
.59116 .34849 .59814 .35625 .61187 .3533 .60492 .3451 Mtetra
.587 .732 .944 r
.60492 .3451 .61187 .3533 .62566 .3496 .61879 .34242 Mtetra
.525 .737 .972 r
.61879 .34242 .62566 .3496 .63957 .34715 .63278 .34085 Mtetra
.31 .653 .971 r
.63278 .34085 .63957 .34715 .65375 .34909 .64699 .34244 Mtetra
.185 .564 .935 r
.64699 .34244 .65375 .34909 .66824 .35511 .66141 .34608 Mtetra
.528 .687 .94 r
.66141 .34608 .66824 .35511 .68271 .35726 .67576 .34496 Mtetra
.755 .713 .812 r
.67576 .34496 .68271 .35726 .69668 .34792 .68972 .33453 Mtetra
.796 .711 .771 r
.68972 .33453 .69668 .34792 .7103 .33192 .70348 .32008 Mtetra
.774 .728 .811 r
.70348 .32008 .7103 .33192 .72406 .31869 .71741 .30867 Mtetra
.717 .746 .875 r
.71741 .30867 .72406 .31869 .73816 .31047 .73161 .3013 Mtetra
.673 .751 .909 r
.73161 .3013 .73816 .31047 .75248 .30482 .74601 .29585 Mtetra
.658 .751 .919 r
.74601 .29585 .75248 .30482 .76693 .29987 .76051 .29089 Mtetra
.656 .751 .92 r
.76051 .29089 .76693 .29987 .78145 .295 .77509 .28598 Mtetra
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Mtetra
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Mtetra
.17658 .47694 .18485 .48427 .19664 .48032 .18841 .47295 Mtetra
.654 .751 .921 r
.18841 .47295 .19664 .48032 .20848 .47642 .20029 .46899 Mtetra
.643 .747 .925 r
.20029 .46899 .20848 .47642 .22033 .47302 .21219 .46533 Mtetra
.59 .724 .937 r
.21219 .46533 .22033 .47302 .23207 .47155 .22403 .46299 Mtetra
.435 .637 .941 r
.22403 .46299 .23207 .47155 .24354 .47409 .23566 .46377 Mtetra
.268 .5 .894 r
.23566 .46377 .24354 .47409 .25487 .47954 .24711 .46771 Mtetra
.416 .545 .878 r
.24711 .46771 .25487 .47954 .26665 .4808 .25881 .46992 Mtetra
.672 .68 .85 r
.25881 .46992 .26665 .4808 .27922 .47271 .27118 .46485 Mtetra
.792 .77 .833 r
.27118 .46485 .27922 .47271 .29214 .45998 .284 .45424 Mtetra
.807 .823 .863 r
.284 .45424 .29214 .45998 .30492 .44938 .29682 .44391 Mtetra
.758 .833 .909 r
.29682 .44391 .30492 .44938 .31748 .44232 .30946 .43628 Mtetra
.702 .81 .932 r
.30946 .43628 .31748 .44232 .32996 .4372 .32202 .43063 Mtetra
.672 .79 .937 r
.32202 .43063 .32996 .4372 .34245 .43273 .33456 .42589 Mtetra
.659 .779 .938 r
.33456 .42589 .34245 .43273 .35499 .42843 .34715 .42151 Mtetra
.658 .778 .937 r
.34715 .42151 .35499 .42843 .36758 .42427 .35979 .41714 Mtetra
.659 .773 .933 r
.35979 .41714 .36758 .42427 .38023 .42021 .37249 .41273 Mtetra
.659 .764 .927 r
.37249 .41273 .38023 .42021 .39294 .4161 .38525 .4083 Mtetra
.656 .756 .923 r
.38525 .4083 .39294 .4161 .40571 .41182 .39806 .40395 Mtetra
.659 .755 .921 r
.39806 .40395 .40571 .41182 .41855 .4074 .41094 .39949 Mtetra
.662 .756 .92 r
.41094 .39949 .41855 .4074 .43146 .40279 .42388 .39493 Mtetra
.652 .756 .925 r
.42388 .39493 .43146 .40279 .44442 .39817 .43688 .39064 Mtetra
.645 .764 .935 r
.43688 .39064 .44442 .39817 .45745 .39378 .44994 .38652 Mtetra
.658 .777 .936 r
.44994 .38652 .45745 .39378 .47052 .38966 .46306 .38198 Mtetra
.665 .768 .926 r
.46306 .38198 .47052 .38966 .48366 .38579 .47626 .37721 Mtetra
.661 .743 .911 r
.47626 .37721 .48366 .38579 .49687 .38215 .48951 .37255 Mtetra
.662 .719 .891 r
.48951 .37255 .49687 .38215 .51015 .37822 .50283 .3678 Mtetra
.666 .703 .875 r
.50283 .3678 .51015 .37822 .52349 .37386 .51621 .36277 Mtetra
.653 .685 .867 r
.51621 .36277 .52349 .37386 .53691 .37033 .52966 .35817 Mtetra
.581 .632 .867 r
.52966 .35817 .53691 .37033 .5504 .36671 .54318 .35615 Mtetra
.594 .673 .895 r
.54318 .35615 .5504 .36671 .56394 .36108 .55679 .3536 Mtetra
.687 .789 .928 r
.55679 .3536 .56394 .36108 .57751 .35404 .57043 .34795 Mtetra
.702 .835 .947 r
.57043 .34795 .57751 .35404 .59116 .34849 .58413 .34177 Mtetra
.629 .795 .962 r
.58413 .34177 .59116 .34849 .60492 .3451 .59793 .33769 Mtetra
.563 .748 .964 r
.59793 .33769 .60492 .3451 .61879 .34242 .61185 .33534 Mtetra
.486 .724 .976 r
.61185 .33534 .61879 .34242 .63278 .34085 .62591 .33443 Mtetra
.338 .668 .975 r
.62591 .33443 .63278 .34085 .64699 .34244 .64015 .33563 Mtetra
.358 .667 .974 r
.64015 .33563 .64699 .34244 .66141 .34608 .65451 .33676 Mtetra
.645 .734 .914 r
.65451 .33676 .66141 .34608 .67576 .34496 .66875 .33233 Mtetra
.766 .712 .802 r
.66875 .33233 .67576 .34496 .68972 .33453 .68271 .32096 Mtetra
.776 .703 .782 r
.68271 .32096 .68972 .33453 .70348 .32008 .69661 .30816 Mtetra
.745 .718 .827 r
.69661 .30816 .70348 .32008 .71741 .30867 .7107 .29858 Mtetra
.697 .739 .883 r
.7107 .29858 .71741 .30867 .73161 .3013 .72501 .29205 Mtetra
.666 .748 .912 r
.72501 .29205 .73161 .3013 .74601 .29585 .73947 .28679 Mtetra
.657 .751 .919 r
.73947 .28679 .74601 .29585 .76051 .29089 .75403 .28182 Mtetra
.656 .751 .92 r
.75403 .28182 .76051 .29089 .77509 .28598 .76866 .27687 Mtetra
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .26691 Mtetra
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Mtetra
.16825 .46955 .17658 .47694 .18841 .47295 .18011 .46552 Mtetra
.655 .751 .921 r
.18011 .46552 .18841 .47295 .20029 .46899 .19202 .46149 Mtetra
.649 .749 .922 r
.19202 .46149 .20029 .46899 .21219 .46533 .20397 .45762 Mtetra
.62 .736 .929 r
.20397 .45762 .21219 .46533 .22403 .46299 .2159 .45453 Mtetra
.526 .682 .937 r
.2159 .45453 .22403 .46299 .23566 .46377 .2277 .45363 Mtetra
.379 .568 .911 r
.2277 .45363 .23566 .46377 .24711 .46771 .2393 .45581 Mtetra
.391 .531 .877 r
.2393 .45581 .24711 .46771 .25881 .46992 .25097 .45845 Mtetra
.59 .639 .867 r
.25097 .45845 .25881 .46992 .27118 .46485 .26312 .45632 Mtetra
.747 .752 .856 r
.26312 .45632 .27118 .46485 .284 .45424 .27579 .44828 Mtetra
.796 .819 .87 r
.27579 .44828 .284 .45424 .29682 .44391 .28862 .4385 Mtetra
.769 .836 .904 r
.28862 .4385 .29682 .44391 .30946 .43628 .30135 .43037 Mtetra
.718 .818 .928 r
.30135 .43037 .30946 .43628 .32202 .43063 .31399 .42416 Mtetra
.684 .797 .935 r
.31399 .42416 .32202 .43063 .33456 .42589 .3266 .419 Mtetra
.67 .783 .934 r
.3266 .419 .33456 .42589 .34715 .42151 .33924 .41427 Mtetra
.659 .771 .932 r
.33924 .41427 .34715 .42151 .35979 .41714 .35192 .40984 Mtetra
.654 .769 .933 r
.35192 .40984 .35979 .41714 .37249 .41273 .36466 .40554 Mtetra
.654 .773 .936 r
.36466 .40554 .37249 .41273 .38525 .4083 .37745 .4012 Mtetra
.659 .778 .937 r
.37745 .4012 .38525 .4083 .39806 .40395 .39031 .3967 Mtetra
.666 .777 .932 r
.39031 .3967 .39806 .40395 .41094 .39949 .40324 .39198 Mtetra
.663 .769 .929 r
.40324 .39198 .41094 .39949 .42388 .39493 .41623 .38735 Mtetra
.648 .764 .934 r
.41623 .38735 .42388 .39493 .43688 .39064 .42926 .38314 Mtetra
.661 .771 .931 r
.42926 .38314 .43688 .39064 .44994 .38652 .44237 .3785 Mtetra
.695 .768 .908 r
.44237 .3785 .44994 .38652 .46306 .38198 .45557 .3727 Mtetra
.689 .736 .887 r
.45557 .3727 .46306 .38198 .47626 .37721 .46882 .36698 Mtetra
.67 .709 .877 r
.46882 .36698 .47626 .37721 .48951 .37255 .48211 .36183 Mtetra
.714 .715 .849 r
.48211 .36183 .48951 .37255 .50283 .3678 .49548 .35458 Mtetra
.712 .671 .808 r
.49548 .35458 .50283 .3678 .51621 .36277 .5089 .3465 Mtetra
.61 .582 .798 r
.5089 .3465 .51621 .36277 .52966 .35817 .52236 .34316 Mtetra
.497 .54 .831 r
.52236 .34316 .52966 .35817 .54318 .35615 .5359 .34418 Mtetra
.52 .608 .881 r
.5359 .34418 .54318 .35615 .55679 .3536 .54955 .34394 Mtetra
.635 .715 .905 r
.54955 .34394 .55679 .3536 .57043 .34795 .56326 .33996 Mtetra
.675 .774 .925 r
.56326 .33996 .57043 .34795 .58413 .34177 .57702 .33466 Mtetra
.623 .783 .958 r
.57702 .33466 .58413 .34177 .59793 .33769 .59088 .33076 Mtetra
.542 .756 .976 r
.59088 .33076 .59793 .33769 .61185 .33534 .60486 .32865 Mtetra
.454 .723 .983 r
.60486 .32865 .61185 .33534 .62591 .33443 .61898 .32807 Mtetra
.39 .702 .983 r
.61898 .32807 .62591 .33443 .64015 .33563 .63323 .32836 Mtetra
.534 .745 .973 r
.63323 .32836 .64015 .33563 .65451 .33676 .64752 .32645 Mtetra
.718 .74 .869 r
.64752 .32645 .65451 .33676 .66875 .33233 .66166 .31893 Mtetra
.763 .701 .793 r
.66166 .31893 .66875 .33233 .68271 .32096 .67566 .30733 Mtetra
.751 .693 .797 r
.67566 .30733 .68271 .32096 .69661 .30816 .68971 .29648 Mtetra
.716 .714 .846 r
.68971 .29648 .69661 .30816 .7107 .29858 .70394 .28862 Mtetra
.68 .737 .894 r
.70394 .28862 .7107 .29858 .72501 .29205 .71835 .28278 Mtetra
.661 .748 .915 r
.71835 .28278 .72501 .29205 .73947 .28679 .73287 .27766 Mtetra
.656 .751 .919 r
.73287 .27766 .73947 .28679 .75403 .28182 .74748 .27267 Mtetra
.656 .751 .92 r
.74748 .27267 .75403 .28182 .76866 .27687 .76217 .26767 Mtetra
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .26691 .79176 .25761 Mtetra
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Mtetra
.655 .751 .92 r
.17174 .45803 .18011 .46552 .19202 .46149 .18368 .45395 Mtetra
.653 .75 .921 r
.18368 .45395 .19202 .46149 .20397 .45762 .19567 .44993 Mtetra
.639 .743 .924 r
.19567 .44993 .20397 .45762 .2159 .45453 .20769 .44629 Mtetra
.589 .713 .929 r
.20769 .44629 .2159 .45453 .2277 .45363 .21963 .44395 Mtetra
.483 .632 .919 r
.21963 .44395 .2277 .45363 .2393 .45581 .23142 .44413 Mtetra
.412 .549 .883 r
.23142 .44413 .2393 .45581 .25097 .45845 .24313 .44623 Mtetra
.505 .585 .869 r
.24313 .44623 .25097 .45845 .26312 .45632 .2551 .44649 Mtetra
.67 .705 .874 r
.2551 .44649 .26312 .45632 .27579 .44828 .26756 .44161 Mtetra
.767 .802 .881 r
.26756 .44161 .27579 .44828 .28862 .4385 .28034 .43315 Mtetra
.775 .839 .901 r
.28034 .43315 .28862 .4385 .30135 .43037 .29314 .42469 Mtetra
.737 .829 .922 r
.29314 .42469 .30135 .43037 .31399 .42416 .30587 .41779 Mtetra
.697 .804 .932 r
.30587 .41779 .31399 .42416 .3266 .419 .31855 .41221 Mtetra
.673 .788 .935 r
.31855 .41221 .3266 .419 .33924 .41427 .33124 .40733 Mtetra
.667 .783 .936 r
.33124 .40733 .33924 .41427 .35192 .40984 .34398 .40262 Mtetra
.666 .776 .932 r
.34398 .40262 .35192 .40984 .36466 .40554 .35677 .39794 Mtetra
.663 .766 .926 r
.35677 .39794 .36466 .40554 .37745 .4012 .36961 .39333 Mtetra
.66 .758 .923 r
.36961 .39333 .37745 .4012 .39031 .3967 .38252 .3888 Mtetra
.66 .759 .923 r
.38252 .3888 .39031 .3967 .40324 .39198 .39548 .38424 Mtetra
.657 .763 .928 r
.39548 .38424 .40324 .39198 .41623 .38735 .4085 .37975 Mtetra
.657 .768 .932 r
.4085 .37975 .41623 .38735 .42926 .38314 .42158 .37524 Mtetra
.682 .768 .917 r
.42158 .37524 .42926 .38314 .44237 .3785 .43475 .3699 Mtetra
.705 .758 .893 r
.43475 .3699 .44237 .3785 .45557 .3727 .448 .36361 Mtetra
.675 .738 .898 r
.448 .36361 .45557 .3727 .46882 .36698 .46128 .3584 Mtetra
.608 .728 .93 r
.46128 .3584 .46882 .36698 .48211 .36183 .47459 .35525 Mtetra
.777 .829 .893 r
.47459 .35525 .48211 .36183 .49548 .35458 .48804 .34618 Mtetra
.846 .791 .797 r
.48804 .34618 .49548 .35458 .5089 .3465 .50156 .331 Mtetra
.439 .5 .825 r
.50156 .331 .5089 .3465 .52236 .34316 .515 .33381 Mtetra
.313 .563 .926 r
.515 .33381 .52236 .34316 .5359 .34418 .52858 .33691 Mtetra
.501 .726 .973 r
.52858 .33691 .5359 .34418 .54955 .34394 .54226 .33575 Mtetra
.629 .753 .937 r
.54226 .33575 .54955 .34394 .56326 .33996 .55602 .33185 Mtetra
.645 .762 .934 r
.55602 .33185 .56326 .33996 .57702 .33466 .56984 .32745 Mtetra
.592 .77 .964 r
.56984 .32745 .57702 .33466 .59088 .33076 .58376 .32428 Mtetra
.513 .76 .986 r
.58376 .32428 .59088 .33076 .60486 .32865 .5978 .3225 Mtetra
.453 .743 .991 r
.5978 .3225 .60486 .32865 .61898 .32807 .61196 .3216 Mtetra
.512 .762 .987 r
.61196 .3216 .61898 .32807 .63323 .32836 .6262 .31979 Mtetra
.673 .767 .921 r
.6262 .31979 .63323 .32836 .64752 .32645 .6404 .31437 Mtetra
.744 .716 .825 r
.6404 .31437 .64752 .32645 .66166 .31893 .6545 .30475 Mtetra
.744 .683 .793 r
.6545 .30475 .66166 .31893 .67566 .30733 .66858 .29408 Mtetra
.721 .689 .819 r
.66858 .29408 .67566 .30733 .68971 .29648 .68278 .28537 Mtetra
.69 .716 .869 r
.68278 .28537 .68971 .29648 .70394 .28862 .69714 .27889 Mtetra
.667 .74 .904 r
.69714 .27889 .70394 .28862 .71835 .28278 .71163 .27351 Mtetra
.658 .749 .917 r
.71163 .27351 .71835 .28278 .73287 .27766 .72622 .26845 Mtetra
.656 .751 .92 r
.72622 .26845 .73287 .27766 .74748 .27267 .74088 .26343 Mtetra
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Mtetra
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25761 .78532 .24824 Mtetra
.655 .751 .92 r
.12769 .46271 .13623 .47017 .14801 .46614 .1395 .45866 Mtetra
.656 .752 .92 r
.1395 .45866 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.656 .751 .92 r
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Mtetra
.16329 .45047 .17174 .45803 .18368 .45395 .17527 .44635 Mtetra
.655 .751 .92 r
.17527 .44635 .18368 .45395 .19567 .44993 .1873 .44224 Mtetra
.65 .748 .922 r
.1873 .44224 .19567 .44993 .20769 .44629 .19937 .43827 Mtetra
.627 .734 .924 r
.19937 .43827 .20769 .44629 .21963 .44395 .21144 .4349 Mtetra
.566 .686 .921 r
.21144 .4349 .21963 .44395 .23142 .44413 .22342 .43314 Mtetra
.481 .601 .896 r
.22342 .43314 .23142 .44413 .24313 .44623 .23528 .43363 Mtetra
.464 .559 .867 r
.23528 .43363 .24313 .44623 .2551 .44649 .24716 .43486 Mtetra
.568 .63 .873 r
.24716 .43486 .2551 .44649 .26756 .44161 .25937 .43327 Mtetra
.701 .751 .891 r
.25937 .43327 .26756 .44161 .28034 .43315 .27199 .42738 Mtetra
.763 .829 .904 r
.27199 .42738 .28034 .43315 .29314 .42469 .28482 .41937 Mtetra
.751 .842 .92 r
.28482 .41937 .29314 .42469 .30587 .41779 .29764 .41192 Mtetra
.719 .824 .931 r
.29764 .41192 .30587 .41779 .31855 .41221 .31041 .40558 Mtetra
.689 .798 .932 r
.31041 .40558 .31855 .41221 .33124 .40733 .32318 .40016 Mtetra
.671 .78 .931 r
.32318 .40016 .33124 .40733 .34398 .40262 .33596 .39529 Mtetra
.658 .773 .934 r
.33596 .39529 .34398 .40262 .35677 .39794 .34878 .39079 Mtetra
.661 .78 .937 r
.34878 .39079 .35677 .39794 .36961 .39333 .36167 .38619 Mtetra
.659 .78 .939 r
.36167 .38619 .36961 .39333 .38252 .3888 .37461 .38162 Mtetra
.668 .783 .935 r
.37461 .38162 .38252 .3888 .39548 .38424 .38763 .37677 Mtetra
.662 .774 .933 r
.38763 .37677 .39548 .38424 .4085 .37975 .4007 .37208 Mtetra
.678 .775 .924 r
.4007 .37208 .4085 .37975 .42158 .37524 .41385 .36688 Mtetra
.662 .752 .917 r
.41385 .36688 .42158 .37524 .43475 .3699 .42704 .36216 Mtetra
.647 .765 .935 r
.42704 .36216 .43475 .3699 .448 .36361 .44028 .35786 Mtetra
.523 .781 .991 r
.44028 .35786 .448 .36361 .46128 .3584 .45355 .35576 Mtetra
.624 .911 .982 r
.45355 .35576 .46128 .3584 .47459 .35525 .46695 .35043 Mtetra
.825 .881 .884 r
.46695 .35043 .47459 .35525 .48804 .34618 .4805 .33928 Mtetra
.789 .316 0 r
.4805 .33928 .48804 .34618 .50156 .331 .49373 .36188 Mtetra
.094 0 .186 r
.49373 .36188 .50156 .331 .515 .33381 .5075 .34061 Mtetra
0 0 0 r
.5075 .34061 .515 .33381 .52858 .33691 .52117 .33309 Mtetra
.565 .864 .996 r
.52117 .33309 .52858 .33691 .54226 .33575 .53491 .32921 Mtetra
.648 .811 .961 r
.53491 .32921 .54226 .33575 .55602 .33185 .54871 .3245 Mtetra
.598 .769 .962 r
.54871 .3245 .55602 .33185 .56984 .32745 .5626 .3212 Mtetra
.563 .79 .985 r
.5626 .3212 .56984 .32745 .58376 .32428 .57658 .31833 Mtetra
.502 .774 .993 r
.57658 .31833 .58376 .32428 .5978 .3225 .59067 .31645 Mtetra
.552 .794 .989 r
.59067 .31645 .5978 .3225 .61196 .3216 .60484 .31366 Mtetra
.659 .78 .938 r
.60484 .31366 .61196 .3216 .6262 .31979 .61903 .30864 Mtetra
.729 .729 .85 r
.61903 .30864 .6262 .31979 .6404 .31437 .63317 .30026 Mtetra
.73 .68 .801 r
.63317 .30026 .6404 .31437 .6545 .30475 .6473 .29055 Mtetra
.715 .672 .807 r
.6473 .29055 .6545 .30475 .66858 .29408 .66151 .28178 Mtetra
.691 .694 .848 r
.66151 .28178 .66858 .29408 .68278 .28537 .67584 .27499 Mtetra
.672 .727 .891 r
.67584 .27499 .68278 .28537 .69714 .27889 .6903 .26936 Mtetra
.659 .744 .913 r
.6903 .26936 .69714 .27889 .71163 .27351 .70486 .26424 Mtetra
.657 .751 .919 r
.70486 .26424 .71163 .27351 .72622 .26845 .7195 .25916 Mtetra
.655 .751 .92 r
.7195 .25916 .72622 .26845 .74088 .26343 .73421 .25412 Mtetra
.656 .752 .92 r
.73421 .25412 .74088 .26343 .75562 .25839 .749 .24901 Mtetra
.655 .751 .92 r
.749 .24901 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.656 .752 .92 r
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23876 Mtetra
.11908 .4552 .12769 .46271 .1395 .45866 .13092 .4511 Mtetra
.656 .751 .92 r
.13092 .4511 .1395 .45866 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Mtetra
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Mtetra
.16678 .4387 .17527 .44635 .1873 .44224 .17885 .43453 Mtetra
.654 .75 .921 r
.17885 .43453 .1873 .44224 .19937 .43827 .19097 .43039 Mtetra
.646 .745 .921 r
.19097 .43039 .19937 .43827 .21144 .4349 .20312 .42645 Mtetra
.62 .722 .92 r
.20312 .42645 .21144 .4349 .22342 .43314 .21526 .42325 Mtetra
.562 .666 .907 r
.21526 .42325 .22342 .43314 .23528 .43363 .22732 .42164 Mtetra
.5 .591 .877 r
.22732 .42164 .23528 .43363 .24716 .43486 .23929 .42186 Mtetra
.502 .573 .859 r
.23929 .42186 .24716 .43486 .25937 .43327 .25134 .4222 Mtetra
.591 .653 .88 r
.25134 .4222 .25937 .43327 .27199 .42738 .2637 .41986 Mtetra
.703 .775 .908 r
.2637 .41986 .27199 .42738 .28482 .41937 .27641 .41395 Mtetra
.75 .841 .92 r
.27641 .41395 .28482 .41937 .29764 .41192 .28928 .40649 Mtetra
.734 .841 .93 r
.28928 .40649 .29764 .41192 .31041 .40558 .30215 .39958 Mtetra
.704 .821 .938 r
.30215 .39958 .31041 .40558 .32318 .40016 .31499 .39367 Mtetra
.687 .805 .938 r
.31499 .39367 .32318 .40016 .33596 .39529 .32785 .38825 Mtetra
.676 .788 .933 r
.32785 .38825 .33596 .39529 .34878 .39079 .34074 .38316 Mtetra
.668 .77 .926 r
.34074 .38316 .34878 .39079 .36167 .38619 .35368 .37831 Mtetra
.659 .762 .926 r
.35368 .37831 .36167 .38619 .37461 .38162 .36667 .37371 Mtetra
.656 .761 .927 r
.36667 .37371 .37461 .38162 .38763 .37677 .37971 .36918 Mtetra
.656 .771 .934 r
.37971 .36918 .38763 .37677 .4007 .37208 .39281 .36461 Mtetra
.674 .781 .93 r
.39281 .36461 .4007 .37208 .41385 .36688 .406 .35947 Mtetra
.677 .785 .931 r
.406 .35947 .41385 .36688 .42704 .36216 .41926 .3542 Mtetra
.643 .76 .934 r
.41926 .3542 .42704 .36216 .44028 .35786 .43254 .34997 Mtetra
.578 .74 .953 r
.43254 .34997 .44028 .35786 .45355 .35576 .44585 .34739 Mtetra
.622 .743 .934 r
.44585 .34739 .45355 .35576 .46695 .35043 .45927 .34375 Mtetra
.591 .783 .972 r
.45927 .34375 .46695 .35043 .4805 .33928 .47275 .34055 Mtetra
.456 0 0 r
.47275 .34055 .4805 .33928 .49373 .36188 .48621 .34579 Mtetra
.591 .581 .81 r
.48621 .34579 .49373 .36188 .5075 .34061 .49988 .34313 Mtetra
.612 .949 .787 r
.49988 .34313 .5075 .34061 .52117 .33309 .51367 .33342 Mtetra
.645 .966 .891 r
.51367 .33342 .52117 .33309 .53491 .32921 .52748 .32521 Mtetra
.653 .891 .982 r
.52748 .32521 .53491 .32921 .54871 .3245 .54135 .3196 Mtetra
.591 .845 .993 r
.54135 .3196 .54871 .3245 .5626 .3212 .55529 .31562 Mtetra
.583 .822 .99 r
.55529 .31562 .5626 .3212 .57658 .31833 .56932 .31203 Mtetra
.614 .812 .976 r
.56932 .31203 .57658 .31833 .59067 .31645 .58342 .30796 Mtetra
.682 .774 .92 r
.58342 .30796 .59067 .31645 .60484 .31366 .59756 .30217 Mtetra
.716 .718 .851 r
.59756 .30217 .60484 .31366 .61903 .30864 .61171 .29438 Mtetra
.714 .671 .806 r
.61171 .29438 .61903 .30864 .63317 .30026 .62587 .28562 Mtetra
.7 .66 .807 r
.62587 .28562 .63317 .30026 .6473 .29055 .6401 .27755 Mtetra
.685 .68 .839 r
.6401 .27755 .6473 .29055 .66151 .28178 .65444 .27084 Mtetra
.67 .715 .882 r
.65444 .27084 .66151 .28178 .67584 .27499 .66888 .26519 Mtetra
.661 .739 .908 r
.66888 .26519 .67584 .27499 .6903 .26936 .68341 .25998 Mtetra
.657 .749 .918 r
.68341 .25998 .6903 .26936 .70486 .26424 .69802 .2549 Mtetra
.656 .751 .92 r
.69802 .2549 .70486 .26424 .7195 .25916 .71271 .24981 Mtetra
.656 .752 .92 r
.71271 .24981 .7195 .25916 .73421 .25412 .72748 .2447 Mtetra
.656 .751 .92 r
.72748 .2447 .73421 .25412 .749 .24901 .74232 .23956 Mtetra
.656 .752 .92 r
.74232 .23956 .749 .24901 .76387 .24391 .75724 .2344 Mtetra
.656 .751 .92 r
.75724 .2344 .76387 .24391 .77881 .23876 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Mtetra
.15823 .43097 .16678 .4387 .17885 .43453 .17032 .42676 Mtetra
.17032 .42676 .17885 .43453 .19097 .43039 .18248 .42254 Mtetra
.653 .749 .92 r
.18248 .42254 .19097 .43039 .20312 .42645 .19468 .41836 Mtetra
.645 .742 .919 r
.19468 .41836 .20312 .42645 .21526 .42325 .20692 .4144 Mtetra
.62 .715 .914 r
.20692 .4144 .21526 .42325 .22732 .42164 .21916 .41115 Mtetra
.574 .659 .895 r
.21916 .41115 .22732 .42164 .23929 .42186 .23133 .40925 Mtetra
.526 .593 .865 r
.23133 .40925 .23929 .42186 .25134 .4222 .24345 .40885 Mtetra
.522 .578 .853 r
.24345 .40885 .25134 .4222 .2637 .41986 .25564 .40863 Mtetra
.584 .65 .881 r
.25564 .40863 .2637 .41986 .27641 .41395 .26808 .40644 Mtetra
.681 .774 .921 r
.26808 .40644 .27641 .41395 .28928 .40649 .28082 .40125 Mtetra
.735 .848 .934 r
.28082 .40125 .28928 .40649 .30215 .39958 .29374 .39428 Mtetra
.73 .847 .936 r
.29374 .39428 .30215 .39958 .31499 .39367 .3067 .38744 Mtetra
.7 .817 .938 r
.3067 .38744 .31499 .39367 .32785 .38825 .31963 .3816 Mtetra
.677 .801 .941 r
.31963 .3816 .32785 .38825 .34074 .38316 .33257 .37643 Mtetra
.668 .797 .944 r
.33257 .37643 .34074 .38316 .35368 .37831 .34556 .37151 Mtetra
.667 .796 .944 r
.34556 .37151 .35368 .37831 .36667 .37371 .3586 .36659 Mtetra
.665 .788 .94 r
.3586 .36659 .36667 .37371 .37971 .36918 .3717 .36173 Mtetra
.66 .778 .937 r
.3717 .36173 .37971 .36918 .39281 .36461 .38485 .35702 Mtetra
.663 .776 .933 r
.38485 .35702 .39281 .36461 .406 .35947 .39808 .35218 Mtetra
.672 .789 .936 r
.39808 .35218 .406 .35947 .41926 .3542 .41137 .34704 Mtetra
.658 .789 .944 r
.41137 .34704 .41926 .3542 .43254 .34997 .42472 .34228 Mtetra
.629 .766 .945 r
.42472 .34228 .43254 .34997 .44585 .34739 .4381 .33835 Mtetra
.62 .727 .923 r
.4381 .33835 .44585 .34739 .45927 .34375 .45155 .33474 Mtetra
.569 .709 .936 r
.45155 .33474 .45927 .34375 .47275 .34055 .46505 .33249 Mtetra
.396 .655 .962 r
.46505 .33249 .47275 .34055 .48621 .34579 .4786 .33335 Mtetra
.526 .61 .879 r
.4786 .33335 .48621 .34579 .49988 .34313 .49227 .33277 Mtetra
.696 .728 .875 r
.49227 .33277 .49988 .34313 .51367 .33342 .50609 .3263 Mtetra
.746 .823 .911 r
.50609 .3263 .51367 .33342 .52748 .32521 .51996 .3183 Mtetra
.702 .82 .938 r
.51996 .3183 .52748 .32521 .54135 .3196 .53388 .31195 Mtetra
.67 .791 .939 r
.53388 .31195 .54135 .3196 .55529 .31562 .54787 .3066 Mtetra
.675 .757 .912 r
.54787 .3066 .55529 .31562 .56932 .31203 .56192 .30104 Mtetra
.69 .718 .87 r
.56192 .30104 .56932 .31203 .58342 .30796 .57602 .29461 Mtetra
.696 .677 .828 r
.57602 .29461 .58342 .30796 .59756 .30217 .59016 .28727 Mtetra
.691 .652 .807 r
.59016 .28727 .59756 .30217 .61171 .29438 .60434 .27966 Mtetra
.682 .651 .813 r
.60434 .27966 .61171 .29438 .62587 .28562 .61859 .27261 Mtetra
.674 .676 .844 r
.61859 .27261 .62587 .28562 .6401 .27755 .63293 .26642 Mtetra
.666 .71 .881 r
.63293 .26642 .6401 .27755 .65444 .27084 .64735 .26091 Mtetra
.66 .736 .906 r
.64735 .26091 .65444 .27084 .66888 .26519 .66186 .25571 Mtetra
.657 .747 .917 r
.66186 .25571 .66888 .26519 .68341 .25998 .67645 .2506 Mtetra
.656 .751 .92 r
.67645 .2506 .68341 .25998 .69802 .2549 .69112 .24548 Mtetra
.69112 .24548 .69802 .2549 .71271 .24981 .70586 .24035 Mtetra
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .2248 Mtetra
.75056 .2248 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Mtetra
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41893 Mtetra
.16172 .41893 .17032 .42676 .18248 .42254 .17391 .41467 Mtetra
.655 .751 .92 r
.17391 .41467 .18248 .42254 .19468 .41836 .18615 .41039 Mtetra
.654 .749 .92 r
.18615 .41039 .19468 .41836 .20692 .4144 .19845 .40615 Mtetra
.647 .741 .918 r
.19845 .40615 .20692 .4144 .21916 .41115 .21079 .40208 Mtetra
.628 .715 .909 r
.21079 .40208 .21916 .41115 .23133 .40925 .22314 .39856 Mtetra
.594 .665 .888 r
.22314 .39856 .23133 .40925 .24345 .40885 .23545 .39605 Mtetra
.555 .606 .859 r
.23545 .39605 .24345 .40885 .25564 .40863 .24774 .39477 Mtetra
.539 .58 .844 r
.24774 .39477 .25564 .40863 .26808 .40644 .26006 .39404 Mtetra
.565 .62 .866 r
.26006 .39404 .26808 .40644 .28082 .40125 .27254 .39243 Mtetra
.632 .728 .917 r
.27254 .39243 .28082 .40125 .29374 .39428 .28526 .38867 Mtetra
.698 .835 .949 r
.28526 .38867 .29374 .39428 .3067 .38744 .2982 .38284 Mtetra
.723 .869 .95 r
.2982 .38284 .3067 .38744 .31963 .3816 .31124 .37612 Mtetra
.714 .844 .944 r
.31124 .37612 .31963 .3816 .33257 .37643 .32431 .36973 Mtetra
.691 .806 .936 r
.32431 .36973 .33257 .37643 .34556 .37151 .33738 .36408 Mtetra
.67 .781 .933 r
.33738 .36408 .34556 .37151 .3586 .36659 .35047 .35905 Mtetra
.661 .777 .935 r
.35047 .35905 .3586 .36659 .3717 .36173 .36361 .35428 Mtetra
.655 .779 .94 r
.36361 .35428 .3717 .36173 .38485 .35702 .3768 .34967 Mtetra
.652 .782 .943 r
.3768 .34967 .38485 .35702 .39808 .35218 .39006 .3451 Mtetra
.655 .792 .947 r
.39006 .3451 .39808 .35218 .41137 .34704 .40339 .34039 Mtetra
.657 .806 .955 r
.40339 .34039 .41137 .34704 .42472 .34228 .41678 .33555 Mtetra
.648 .803 .957 r
.41678 .33555 .42472 .34228 .4381 .33835 .43023 .33093 Mtetra
.627 .777 .953 r
.43023 .33093 .4381 .33835 .45155 .33474 .44374 .32694 Mtetra
.573 .747 .959 r
.44374 .32694 .45155 .33474 .46505 .33249 .45729 .3243 Mtetra
.541 .723 .958 r
.45729 .3243 .46505 .33249 .4786 .33335 .47091 .32245 Mtetra
.638 .695 .887 r
.47091 .32245 .4786 .33335 .49227 .33277 .48466 .31816 Mtetra
.682 .648 .81 r
.48466 .31816 .49227 .33277 .50609 .3263 .4985 .31124 Mtetra
.684 .644 .804 r
.4985 .31124 .50609 .3263 .51996 .3183 .5124 .30406 Mtetra
.669 .65 .822 r
.5124 .30406 .51996 .3183 .53388 .31195 .52634 .29788 Mtetra
.663 .65 .827 r
.52634 .29788 .53388 .31195 .54787 .3066 .54035 .29203 Mtetra
.666 .645 .819 r
.54035 .29203 .54787 .3066 .56192 .30104 .55442 .28592 Mtetra
.666 .637 .812 r
.55442 .28592 .56192 .30104 .57602 .29461 .56854 .27964 Mtetra
.666 .64 .815 r
.56854 .27964 .57602 .29461 .59016 .28727 .58273 .2734 Mtetra
.665 .657 .833 r
.58273 .2734 .59016 .28727 .60434 .27966 .59699 .26743 Mtetra
.663 .687 .862 r
.59699 .26743 .60434 .27966 .61859 .27261 .61132 .26185 Mtetra
.661 .717 .89 r
.61132 .26185 .61859 .27261 .63293 .26642 .62573 .25655 Mtetra
.658 .738 .909 r
.62573 .25655 .63293 .26642 .64735 .26091 .64022 .2514 Mtetra
.656 .747 .917 r
.64022 .2514 .64735 .26091 .66186 .25571 .65479 .24628 Mtetra
.656 .751 .92 r
.65479 .24628 .66186 .25571 .67645 .2506 .66943 .24114 Mtetra
.66943 .24114 .67645 .2506 .69112 .24548 .68415 .23599 Mtetra
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .2248 .7438 .2151 Mtetra
.7438 .2151 .75056 .2248 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42383 Mtetra
.11673 .42383 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41532 Mtetra
.14088 .41532 .14959 .42318 .16172 .41893 .15305 .41104 Mtetra
.15305 .41104 .16172 .41893 .17391 .41467 .16527 .40673 Mtetra
.16527 .40673 .17391 .41467 .18615 .41039 .17755 .40241 Mtetra
.17755 .40241 .18615 .41039 .19845 .40615 .18988 .39807 Mtetra
.654 .749 .92 r
.18988 .39807 .19845 .40615 .21079 .40208 .20228 .39375 Mtetra
.65 .742 .917 r
.20228 .39375 .21079 .40208 .22314 .39856 .21472 .38953 Mtetra
.639 .722 .908 r
.21472 .38953 .22314 .39856 .23545 .39605 .22719 .38563 Mtetra
.617 .683 .889 r
.22719 .38563 .23545 .39605 .24774 .39477 .23966 .38236 Mtetra
.589 .631 .861 r
.23966 .38236 .24774 .39477 .26006 .39404 .25213 .37997 Mtetra
.567 .592 .838 r
.25213 .37997 .26006 .39404 .27254 .39243 .26462 .37832 Mtetra
.562 .59 .839 r
.26462 .37832 .27254 .39243 .28526 .38867 .27718 .37679 Mtetra
.585 .643 .874 r
.27718 .37679 .28526 .38867 .2982 .38284 .28988 .37444 Mtetra
.629 .742 .929 r
.28988 .37444 .2982 .38284 .31124 .37612 .30276 .37067 Mtetra
.669 .838 .964 r
.30276 .37067 .31124 .37612 .32431 .36973 .3158 .36551 Mtetra
.687 .879 .97 r
.3158 .36551 .32431 .36973 .33738 .36408 .32894 .35962 Mtetra
.691 .874 .967 r
.32894 .35962 .33738 .36408 .35047 .35905 .34214 .35364 Mtetra
.685 .846 .96 r
.34214 .35364 .35047 .35905 .36361 .35428 .35538 .34797 Mtetra
.674 .819 .953 r
.35538 .34797 .36361 .35428 .3768 .34967 .36865 .34266 Mtetra
.662 .796 .947 r
.36865 .34266 .3768 .34967 .39006 .3451 .38197 .33774 Mtetra
.651 .785 .945 r
.38197 .33774 .39006 .3451 .40339 .34039 .39534 .33312 Mtetra
.64 .785 .951 r
.39534 .33312 .40339 .34039 .41678 .33555 .40876 .32877 Mtetra
.626 .796 .964 r
.40876 .32877 .41678 .33555 .43023 .33093 .42225 .32469 Mtetra
.613 .809 .975 r
.42225 .32469 .43023 .33093 .44374 .32694 .4358 .32076 Mtetra
.632 .818 .972 r
.4358 .32076 .44374 .32694 .45729 .3243 .44944 .31634 Mtetra
.689 .786 .924 r
.44944 .31634 .45729 .3243 .47091 .32245 .46318 .31042 Mtetra
.701 .699 .845 r
.46318 .31042 .47091 .32245 .48466 .31816 .477 .30325 Mtetra
.69 .649 .804 r
.477 .30325 .48466 .31816 .4985 .31124 .49087 .29576 Mtetra
.669 .632 .804 r
.49087 .29576 .4985 .31124 .5124 .30406 .50479 .28923 Mtetra
.654 .635 .819 r
.50479 .28923 .5124 .30406 .52634 .29788 .51876 .28364 Mtetra
.651 .643 .83 r
.51876 .28364 .52634 .29788 .54035 .29203 .53279 .27831 Mtetra
.651 .653 .838 r
.53279 .27831 .54035 .29203 .55442 .28592 .54689 .27304 Mtetra
.653 .669 .853 r
.54689 .27304 .55442 .28592 .56854 .27964 .56107 .2678 Mtetra
.657 .692 .871 r
.56107 .2678 .56854 .27964 .58273 .2734 .57531 .26255 Mtetra
.658 .714 .889 r
.57531 .26255 .58273 .2734 .59699 .26743 .58963 .25734 Mtetra
.657 .732 .905 r
.58963 .25734 .59699 .26743 .61132 .26185 .60402 .25219 Mtetra
.656 .744 .914 r
.60402 .25219 .61132 .26185 .62573 .25655 .61849 .24707 Mtetra
.656 .749 .918 r
.61849 .24707 .62573 .25655 .64022 .2514 .63303 .24194 Mtetra
.656 .751 .92 r
.63303 .24194 .64022 .2514 .65479 .24628 .64765 .23678 Mtetra
.64765 .23678 .65479 .24628 .66943 .24114 .66234 .23161 Mtetra
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42383 .10788 .41598 Mtetra
.10788 .41598 .11673 .42383 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41532 .1321 .4074 Mtetra
.1321 .4074 .14088 .41532 .15305 .41104 .14429 .40307 Mtetra
.14429 .40307 .15305 .41104 .16527 .40673 .15655 .39873 Mtetra
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Mtetra
.16886 .39437 .17755 .40241 .18988 .39807 .18123 .38998 Mtetra
.18123 .38998 .18988 .39807 .20228 .39375 .19366 .38558 Mtetra
.655 .75 .92 r
.19366 .38558 .20228 .39375 .21472 .38953 .20615 .38117 Mtetra
.653 .746 .918 r
.20615 .38117 .21472 .38953 .22719 .38563 .2187 .3768 Mtetra
.648 .733 .911 r
.2187 .3768 .22719 .38563 .23966 .38236 .23129 .37257 Mtetra
.637 .707 .897 r
.23129 .37257 .23966 .38236 .25213 .37997 .24391 .36863 Mtetra
.62 .668 .874 r
.24391 .36863 .25213 .37997 .26462 .37832 .25657 .36516 Mtetra
.603 .627 .848 r
.25657 .36516 .26462 .37832 .27718 .37679 .26925 .3622 Mtetra
.589 .598 .828 r
.26925 .3622 .27718 .37679 .28988 .37444 .28197 .35965 Mtetra
.586 .594 .827 r
.28197 .35965 .28988 .37444 .30276 .37067 .29476 .35722 Mtetra
.594 .62 .847 r
.29476 .35722 .30276 .37067 .3158 .36551 .30765 .35452 Mtetra
.614 .678 .887 r
.30765 .35452 .3158 .36551 .32894 .35962 .32066 .35117 Mtetra
.635 .748 .929 r
.32066 .35117 .32894 .35962 .34214 .35364 .33378 .34711 Mtetra
.649 .807 .959 r
.33378 .34711 .34214 .35364 .35538 .34797 .34701 .3425 Mtetra
.652 .84 .973 r
.34701 .3425 .35538 .34797 .36865 .34266 .36031 .33759 Mtetra
.651 .853 .977 r
.36031 .33759 .36865 .34266 .38197 .33774 .37369 .33257 Mtetra
.651 .851 .977 r
.37369 .33257 .38197 .33774 .39534 .33312 .38713 .32754 Mtetra
.657 .842 .971 r
.38713 .32754 .39534 .33312 .40876 .32877 .40064 .32242 Mtetra
.672 .824 .957 r
.40064 .32242 .40876 .32877 .42225 .32469 .41422 .31702 Mtetra
.693 .794 .927 r
.41422 .31702 .42225 .32469 .4358 .32076 .42788 .31099 Mtetra
.705 .746 .883 r
.42788 .31099 .4358 .32076 .44944 .31634 .44162 .3042 Mtetra
.701 .697 .843 r
.44162 .3042 .44944 .31634 .46318 .31042 .45542 .29701 Mtetra
.692 .673 .827 r
.45542 .29701 .46318 .31042 .477 .30325 .46927 .28988 Mtetra
.674 .667 .835 r
.46927 .28988 .477 .30325 .49087 .29576 .48316 .28366 Mtetra
.661 .685 .862 r
.48316 .28366 .49087 .29576 .50479 .28923 .4971 .27826 Mtetra
.657 .708 .885 r
.4971 .27826 .50479 .28923 .51876 .28364 .51111 .27316 Mtetra
.656 .719 .895 r
.51111 .27316 .51876 .28364 .53279 .27831 .52518 .26811 Mtetra
.654 .726 .902 r
.52518 .26811 .53279 .27831 .54689 .27304 .53933 .26311 Mtetra
.655 .734 .908 r
.53933 .26311 .54689 .27304 .56107 .2678 .55355 .25807 Mtetra
.657 .74 .912 r
.55355 .25807 .56107 .2678 .57531 .26255 .56784 .25296 Mtetra
.656 .745 .915 r
.56784 .25296 .57531 .26255 .58963 .25734 .58221 .24785 Mtetra
.656 .749 .918 r
.58221 .24785 .58963 .25734 .60402 .25219 .59665 .24273 Mtetra
.656 .751 .92 r
.59665 .24273 .60402 .25219 .61849 .24707 .61117 .23758 Mtetra
.61117 .23758 .61849 .24707 .63303 .24194 .62577 .2324 Mtetra
.62577 .2324 .63303 .24194 .64765 .23678 .64044 .2272 Mtetra
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19003 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40307 .13546 .39504 Mtetra
.13546 .39504 .14429 .40307 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38626 Mtetra
.16009 .38626 .16886 .39437 .18123 .38998 .1725 .38183 Mtetra
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37739 Mtetra
.18497 .37739 .19366 .38558 .20615 .38117 .19749 .37292 Mtetra
.655 .751 .92 r
.19749 .37292 .20615 .38117 .2187 .3768 .21008 .36844 Mtetra
.655 .749 .919 r
.21008 .36844 .2187 .3768 .23129 .37257 .22273 .36395 Mtetra
.653 .743 .915 r
.22273 .36395 .23129 .37257 .24391 .36863 .23543 .35949 Mtetra
.65 .73 .908 r
.23543 .35949 .24391 .36863 .25657 .36516 .24819 .35511 Mtetra
.642 .706 .894 r
.24819 .35511 .25657 .36516 .26925 .3622 .26099 .35092 Mtetra
.633 .678 .875 r
.26099 .35092 .26925 .3622 .28197 .35965 .27385 .34693 Mtetra
.625 .647 .852 r
.27385 .34693 .28197 .35965 .29476 .35722 .28675 .34312 Mtetra
.618 .622 .832 r
.28675 .34312 .29476 .35722 .30765 .35452 .29972 .33941 Mtetra
.614 .605 .819 r
.29972 .33941 .30765 .35452 .32066 .35117 .31276 .33577 Mtetra
.615 .602 .815 r
.31276 .33577 .32066 .35117 .33378 .34711 .32587 .33202 Mtetra
.621 .61 .819 r
.32587 .33202 .33378 .34711 .34701 .3425 .33907 .32805 Mtetra
.631 .625 .826 r
.33907 .32805 .34701 .3425 .36031 .33759 .35236 .32371 Mtetra
.641 .64 .833 r
.35236 .32371 .36031 .33759 .37369 .33257 .36574 .31899 Mtetra
.652 .65 .835 r
.36574 .31899 .37369 .33257 .38713 .32754 .3792 .31383 Mtetra
.659 .652 .832 r
.3792 .31383 .38713 .32754 .40064 .32242 .39275 .30828 Mtetra
.664 .648 .824 r
.39275 .30828 .40064 .32242 .41422 .31702 .40637 .30239 Mtetra
.665 .642 .817 r
.40637 .30239 .41422 .31702 .42788 .31099 .42005 .29634 Mtetra
.664 .642 .818 r
.42005 .29634 .42788 .31099 .44162 .3042 .43379 .29032 Mtetra
.662 .654 .831 r
.43379 .29032 .44162 .3042 .45542 .29701 .44759 .28453 Mtetra
.658 .677 .857 r
.44759 .28453 .45542 .29701 .46927 .28988 .46144 .2792 Mtetra
.659 .715 .889 r
.46144 .2792 .46927 .28988 .48316 .28366 .47535 .27403 Mtetra
.661 .741 .909 r
.47535 .27403 .48316 .28366 .4971 .27826 .48933 .26887 Mtetra
.658 .747 .915 r
.48933 .26887 .4971 .27826 .51111 .27316 .50338 .26376 Mtetra
.655 .747 .918 r
.50338 .26376 .51111 .27316 .52518 .26811 .5175 .25876 Mtetra
.654 .749 .919 r
.5175 .25876 .52518 .26811 .53933 .26311 .5317 .25375 Mtetra
.656 .751 .919 r
.5317 .25375 .53933 .26311 .55355 .25807 .54597 .24865 Mtetra
.656 .75 .919 r
.54597 .24865 .55355 .25807 .56784 .25296 .56031 .24351 Mtetra
.656 .751 .92 r
.56031 .24351 .56784 .25296 .58221 .24785 .57473 .23837 Mtetra
.57473 .23837 .58221 .24785 .59665 .24273 .58922 .2332 Mtetra
.58922 .2332 .59665 .24273 .61117 .23758 .60379 .22801 Mtetra
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Mtetra
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19003 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38626 .15125 .37807 Mtetra
.15125 .37807 .16009 .38626 .1725 .38183 .16369 .37361 Mtetra
.16369 .37361 .1725 .38183 .18497 .37739 .17619 .36912 Mtetra
.17619 .36912 .18497 .37739 .19749 .37292 .18875 .36461 Mtetra
.18875 .36461 .19749 .37292 .21008 .36844 .20138 .36008 Mtetra
.20138 .36008 .21008 .36844 .22273 .36395 .21406 .35553 Mtetra
.21406 .35553 .22273 .36395 .23543 .35949 .22681 .35096 Mtetra
.655 .749 .919 r
.22681 .35096 .23543 .35949 .24819 .35511 .23962 .34639 Mtetra
.655 .745 .916 r
.23962 .34639 .24819 .35511 .26099 .35092 .25249 .34178 Mtetra
.653 .735 .909 r
.25249 .34178 .26099 .35092 .27385 .34693 .26542 .3372 Mtetra
.65 .72 .9 r
.26542 .3372 .27385 .34693 .28675 .34312 .27841 .33269 Mtetra
.645 .704 .889 r
.27841 .33269 .28675 .34312 .29972 .33941 .29146 .32827 Mtetra
.643 .689 .878 r
.29146 .32827 .29972 .33941 .31276 .33577 .30457 .32383 Mtetra
.642 .673 .865 r
.30457 .32383 .31276 .33577 .32587 .33202 .31775 .31936 Mtetra
.642 .66 .853 r
.31775 .31936 .32587 .33202 .33907 .32805 .33101 .31479 Mtetra
.641 .651 .844 r
.33101 .31479 .33907 .32805 .35236 .32371 .34434 .31013 Mtetra
.643 .647 .839 r
.34434 .31013 .35236 .32371 .36574 .31899 .35774 .30533 Mtetra
.645 .647 .838 r
.35774 .30533 .36574 .31899 .3792 .31383 .37121 .30041 Mtetra
.648 .653 .841 r
.37121 .30041 .3792 .31383 .39275 .30828 .38476 .29537 Mtetra
.651 .664 .85 r
.38476 .29537 .39275 .30828 .40637 .30239 .39837 .29028 Mtetra
.655 .681 .863 r
.39837 .29028 .40637 .30239 .42005 .29634 .41205 .28513 Mtetra
.658 .702 .879 r
.41205 .28513 .42005 .29634 .43379 .29032 .4258 .27999 Mtetra
.659 .722 .896 r
.4258 .27999 .43379 .29032 .44759 .28453 .43962 .27487 Mtetra
.662 .741 .908 r
.43962 .27487 .44759 .28453 .46144 .2792 .45351 .26966 Mtetra
.66 .744 .912 r
.45351 .26966 .46144 .2792 .47535 .27403 .46746 .26451 Mtetra
.655 .744 .915 r
.46746 .26451 .47535 .27403 .48933 .26887 .48149 .25949 Mtetra
.653 .748 .919 r
.48149 .25949 .48933 .26887 .50338 .26376 .49558 .25453 Mtetra
.655 .753 .922 r
.49558 .25453 .50338 .26376 .5175 .25876 .50975 .24948 Mtetra
.657 .754 .921 r
.50975 .24948 .5175 .25876 .5317 .25375 .52399 .24433 Mtetra
.657 .752 .92 r
.52399 .24433 .5317 .25375 .54597 .24865 .53831 .23915 Mtetra
.656 .751 .92 r
.53831 .23915 .54597 .24865 .56031 .24351 .5527 .234 Mtetra
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Mtetra
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .37361 .15481 .3653 Mtetra
.15481 .3653 .16369 .37361 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Mtetra
.656 .752 .92 r
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34706 Mtetra
.656 .751 .92 r
.20532 .34706 .21406 .35553 .22681 .35096 .2181 .34245 Mtetra
.2181 .34245 .22681 .35096 .23962 .34639 .23095 .3378 Mtetra
.655 .75 .92 r
.23095 .3378 .23962 .34639 .25249 .34178 .24386 .33317 Mtetra
.655 .751 .92 r
.24386 .33317 .25249 .34178 .26542 .3372 .25683 .3285 Mtetra
.656 .75 .919 r
.25683 .3285 .26542 .3372 .27841 .33269 .26987 .32378 Mtetra
.657 .746 .915 r
.26987 .32378 .27841 .33269 .29146 .32827 .28298 .319 Mtetra
.655 .738 .91 r
.28298 .319 .29146 .32827 .30457 .32383 .29615 .31424 Mtetra
.654 .73 .905 r
.29615 .31424 .30457 .32383 .31775 .31936 .30938 .30948 Mtetra
.653 .724 .901 r
.30938 .30948 .31775 .31936 .33101 .31479 .32268 .30474 Mtetra
.653 .721 .899 r
.32268 .30474 .33101 .31479 .34434 .31013 .33605 .29996 Mtetra
.653 .72 .898 r
.33605 .29996 .34434 .31013 .35774 .30533 .34948 .29515 Mtetra
.654 .721 .898 r
.34948 .29515 .35774 .30533 .37121 .30041 .36299 .29026 Mtetra
.655 .723 .899 r
.36299 .29026 .37121 .30041 .38476 .29537 .37657 .28532 Mtetra
.657 .727 .901 r
.37657 .28532 .38476 .29537 .39837 .29028 .39022 .28032 Mtetra
.657 .73 .904 r
.39022 .28032 .39837 .29028 .41205 .28513 .40393 .27531 Mtetra
.657 .735 .907 r
.40393 .27531 .41205 .28513 .4258 .27999 .41772 .27028 Mtetra
.656 .738 .91 r
.41772 .27028 .4258 .27999 .43962 .27487 .43157 .26525 Mtetra
.652 .74 .914 r
.43157 .26525 .43962 .27487 .45351 .26966 .4455 .26032 Mtetra
.653 .749 .92 r
.4455 .26032 .45351 .26966 .46746 .26451 .45949 .25536 Mtetra
.655 .755 .923 r
.45949 .25536 .46746 .26451 .48149 .25949 .47356 .2503 Mtetra
.658 .756 .923 r
.47356 .2503 .48149 .25949 .49558 .25453 .48771 .24513 Mtetra
.658 .752 .92 r
.48771 .24513 .49558 .25453 .50975 .24948 .50193 .23992 Mtetra
.656 .749 .918 r
.50193 .23992 .50975 .24948 .52399 .24433 .51622 .23476 Mtetra
.655 .75 .92 r
.51622 .23476 .52399 .24433 .53831 .23915 .53058 .22961 Mtetra
.656 .752 .92 r
.53058 .22961 .53831 .23915 .5527 .234 .54502 .2244 Mtetra
.54502 .2244 .5527 .234 .56717 .22881 .55954 .21915 Mtetra
.656 .751 .92 r
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .3653 .14584 .35693 Mtetra
.14584 .35693 .15481 .3653 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34706 .19649 .33853 Mtetra
.19649 .33853 .20532 .34706 .2181 .34245 .20931 .33387 Mtetra
.20931 .33387 .2181 .34245 .23095 .3378 .22219 .32919 Mtetra
.656 .752 .92 r
.22219 .32919 .23095 .3378 .24386 .33317 .23514 .32446 Mtetra
.656 .751 .92 r
.23514 .32446 .24386 .33317 .25683 .3285 .24816 .31973 Mtetra
.655 .75 .919 r
.24816 .31973 .25683 .3285 .26987 .32378 .26123 .31499 Mtetra
.654 .75 .92 r
.26123 .31499 .26987 .32378 .28298 .319 .27437 .31027 Mtetra
.655 .753 .922 r
.27437 .31027 .28298 .319 .29615 .31424 .28758 .3055 Mtetra
.656 .754 .922 r
.28758 .3055 .29615 .31424 .30938 .30948 .30086 .30068 Mtetra
.657 .754 .921 r
.30086 .30068 .30938 .30948 .32268 .30474 .3142 .2958 Mtetra
.657 .751 .92 r
.3142 .2958 .32268 .30474 .33605 .29996 .32762 .2909 Mtetra
.657 .749 .918 r
.32762 .2909 .33605 .29996 .34948 .29515 .3411 .28597 Mtetra
.656 .748 .918 r
.3411 .28597 .34948 .29515 .36299 .29026 .35465 .28105 Mtetra
.655 .748 .918 r
.35465 .28105 .36299 .29026 .37657 .28532 .36826 .27611 Mtetra
.655 .749 .919 r
.36826 .27611 .37657 .28532 .39022 .28032 .38195 .27117 Mtetra
.655 .751 .921 r
.38195 .27117 .39022 .28032 .40393 .27531 .3957 .26621 Mtetra
.655 .754 .923 r
.3957 .26621 .40393 .27531 .41772 .27028 .40953 .26122 Mtetra
.655 .756 .924 r
.40953 .26122 .41772 .27028 .43157 .26525 .42343 .2562 Mtetra
.658 .759 .924 r
.42343 .2562 .43157 .26525 .4455 .26032 .4374 .25105 Mtetra
.658 .754 .921 r
.4374 .25105 .4455 .26032 .45949 .25536 .45145 .24586 Mtetra
.657 .749 .918 r
.45145 .24586 .45949 .25536 .47356 .2503 .46557 .24068 Mtetra
.655 .747 .917 r
.46557 .24068 .47356 .2503 .48771 .24513 .47976 .23555 Mtetra
.654 .749 .919 r
.47976 .23555 .48771 .24513 .50193 .23992 .49402 .23042 Mtetra
.655 .752 .921 r
.49402 .23042 .50193 .23992 .51622 .23476 .50836 .22522 Mtetra
.656 .753 .921 r
.50836 .22522 .51622 .23476 .53058 .22961 .52278 .21996 Mtetra
.656 .751 .92 r
.52278 .21996 .53058 .22961 .54502 .2244 .53727 .21469 Mtetra
.53727 .21469 .54502 .2244 .55954 .21915 .55184 .2094 Mtetra
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Mtetra
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38455 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33459 Mtetra
.656 .752 .92 r
.17479 .33459 .18373 .34316 .19649 .33853 .18758 .32991 Mtetra
.656 .751 .92 r
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .3252 Mtetra
.20044 .3252 .20931 .33387 .22219 .32919 .21336 .32047 Mtetra
.655 .751 .92 r
.21336 .32047 .22219 .32919 .23514 .32446 .22635 .31574 Mtetra
.656 .752 .921 r
.22635 .31574 .23514 .32446 .24816 .31973 .2394 .31098 Mtetra
.656 .753 .921 r
.2394 .31098 .24816 .31973 .26123 .31499 .25251 .30617 Mtetra
.657 .752 .92 r
.25251 .30617 .26123 .31499 .27437 .31027 .2657 .3013 Mtetra
.656 .749 .918 r
.2657 .3013 .27437 .31027 .28758 .3055 .27895 .29643 Mtetra
.656 .748 .918 r
.27895 .29643 .28758 .3055 .30086 .30068 .29227 .29156 Mtetra
.655 .747 .918 r
.29227 .29156 .30086 .30068 .3142 .2958 .30565 .2867 Mtetra
.655 .749 .919 r
.30565 .2867 .3142 .2958 .32762 .2909 .3191 .2818 Mtetra
.655 .75 .92 r
.3191 .2818 .32762 .2909 .3411 .28597 .33262 .27688 Mtetra
.656 .752 .921 r
.33262 .27688 .3411 .28597 .35465 .28105 .34621 .27192 Mtetra
.34621 .27192 .35465 .28105 .36826 .27611 .35987 .26691 Mtetra
.657 .752 .92 r
.35987 .26691 .36826 .27611 .38195 .27117 .3736 .26186 Mtetra
.657 .75 .919 r
.3736 .26186 .38195 .27117 .3957 .26621 .38741 .25678 Mtetra
.657 .749 .918 r
.38741 .25678 .3957 .26621 .40953 .26122 .40128 .25167 Mtetra
.657 .747 .916 r
.40128 .25167 .40953 .26122 .42343 .2562 .41523 .24654 Mtetra
.654 .744 .916 r
.41523 .24654 .42343 .2562 .4374 .25105 .42924 .24147 Mtetra
.654 .747 .918 r
.42924 .24147 .4374 .25105 .45145 .24586 .44333 .23639 Mtetra
.654 .751 .921 r
.44333 .23639 .45145 .24586 .46557 .24068 .45749 .23126 Mtetra
.656 .754 .922 r
.45749 .23126 .46557 .24068 .47976 .23555 .47173 .22605 Mtetra
.657 .754 .921 r
.47173 .22605 .47976 .23555 .49402 .23042 .48604 .22077 Mtetra
.656 .752 .92 r
.48604 .22077 .49402 .23042 .50836 .22522 .50043 .21549 Mtetra
.655 .75 .92 r
.50043 .21549 .50836 .22522 .52278 .21996 .5149 .21021 Mtetra
.656 .751 .92 r
.5149 .21021 .52278 .21996 .53727 .21469 .52944 .2049 Mtetra
.656 .752 .92 r
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Mtetra
.656 .751 .92 r
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Mtetra
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37635 .03814 .38455 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Mtetra
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Mtetra
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33459 .16576 .32593 Mtetra
.16576 .32593 .17479 .33459 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .3252 .19149 .31647 Mtetra
.19149 .31647 .20044 .3252 .21336 .32047 .20445 .3117 Mtetra
.656 .752 .92 r
.20445 .3117 .21336 .32047 .22635 .31574 .21747 .30689 Mtetra
.656 .751 .92 r
.21747 .30689 .22635 .31574 .2394 .31098 .23056 .30207 Mtetra
.655 .75 .92 r
.23056 .30207 .2394 .31098 .25251 .30617 .24372 .29724 Mtetra
.654 .751 .921 r
.24372 .29724 .25251 .30617 .2657 .3013 .25693 .29242 Mtetra
.655 .753 .922 r
.25693 .29242 .2657 .3013 .27895 .29643 .27022 .28755 Mtetra
.656 .755 .923 r
.27022 .28755 .27895 .29643 .29227 .29156 .28358 .28264 Mtetra
.657 .755 .922 r
.28358 .28264 .29227 .29156 .30565 .2867 .29701 .27767 Mtetra
.657 .753 .921 r
.29701 .27767 .30565 .2867 .3191 .2818 .3105 .27267 Mtetra
.657 .752 .92 r
.3105 .27267 .3191 .2818 .33262 .27688 .32407 .26765 Mtetra
.656 .751 .92 r
.32407 .26765 .33262 .27688 .34621 .27192 .3377 .26263 Mtetra
.656 .75 .92 r
.3377 .26263 .34621 .27192 .35987 .26691 .3514 .25759 Mtetra
.655 .75 .92 r
.3514 .25759 .35987 .26691 .3736 .26186 .36518 .25255 Mtetra
.655 .752 .921 r
.36518 .25255 .3736 .26186 .38741 .25678 .37902 .24749 Mtetra
.655 .753 .922 r
.37902 .24749 .38741 .25678 .40128 .25167 .39294 .2424 Mtetra
.655 .755 .924 r
.39294 .2424 .40128 .25167 .41523 .24654 .40693 .23729 Mtetra
.657 .758 .924 r
.40693 .23729 .41523 .24654 .42924 .24147 .42099 .23208 Mtetra
.658 .756 .922 r
.42099 .23208 .42924 .24147 .44333 .23639 .43513 .22682 Mtetra
.657 .752 .92 r
.43513 .22682 .44333 .23639 .45749 .23126 .44934 .22154 Mtetra
.656 .749 .919 r
.44934 .22154 .45749 .23126 .47173 .22605 .46363 .21629 Mtetra
.655 .749 .919 r
.46363 .21629 .47173 .22605 .48604 .22077 .47799 .21103 Mtetra
.655 .751 .92 r
.47799 .21103 .48604 .22077 .50043 .21549 .49243 .20574 Mtetra
.656 .752 .921 r
.49243 .20574 .50043 .21549 .5149 .21021 .50694 .20038 Mtetra
.656 .752 .92 r
.50694 .20038 .5149 .21021 .52944 .2049 .52153 .19501 Mtetra
.656 .751 .92 r
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17872 Mtetra
.56578 .17872 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .1397 Mtetra
.67184 .1397 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35448 Mtetra
.056 .35448 .06538 .36287 .07772 .35833 .06836 .34989 Mtetra
.06836 .34989 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Mtetra
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32666 Mtetra
.13112 .32666 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31647 .18245 .30764 Mtetra
.18245 .30764 .19149 .31647 .20445 .3117 .19545 .30282 Mtetra
.655 .751 .92 r
.19545 .30282 .20445 .3117 .21747 .30689 .20851 .298 Mtetra
.655 .752 .921 r
.20851 .298 .21747 .30689 .23056 .30207 .22164 .29315 Mtetra
.656 .752 .921 r
.22164 .29315 .23056 .30207 .24372 .29724 .23483 .28825 Mtetra
.657 .752 .92 r
.23483 .28825 .24372 .29724 .25693 .29242 .2481 .2833 Mtetra
.657 .75 .919 r
.2481 .2833 .25693 .29242 .27022 .28755 .26143 .27833 Mtetra
.656 .748 .918 r
.26143 .27833 .27022 .28755 .28358 .28264 .27483 .27337 Mtetra
.655 .748 .918 r
.27483 .27337 .28358 .28264 .29701 .27767 .28829 .26841 Mtetra
.655 .749 .919 r
.28829 .26841 .29701 .27767 .3105 .27267 .30182 .26342 Mtetra
.655 .751 .92 r
.30182 .26342 .3105 .27267 .32407 .26765 .31543 .25841 Mtetra
.656 .752 .921 r
.31543 .25841 .32407 .26765 .3377 .26263 .3291 .25335 Mtetra
.656 .753 .921 r
.3291 .25335 .3377 .26263 .3514 .25759 .34285 .24826 Mtetra
.34285 .24826 .3514 .25759 .36518 .25255 .35667 .24312 Mtetra
.657 .752 .92 r
.35667 .24312 .36518 .25255 .37902 .24749 .37056 .23795 Mtetra
.657 .75 .919 r
.37056 .23795 .37902 .24749 .39294 .2424 .38452 .23274 Mtetra
.657 .749 .918 r
.38452 .23274 .39294 .2424 .40693 .23729 .39856 .22751 Mtetra
.655 .746 .917 r
.39856 .22751 .40693 .23729 .42099 .23208 .41267 .22231 Mtetra
.654 .747 .918 r
.41267 .22231 .42099 .23208 .43513 .22682 .42685 .21711 Mtetra
.654 .75 .92 r
.42685 .21711 .43513 .22682 .44934 .22154 .44111 .21187 Mtetra
.656 .753 .921 r
.44111 .21187 .44934 .22154 .46363 .21629 .45544 .20657 Mtetra
.45544 .20657 .46363 .21629 .47799 .21103 .46985 .20121 Mtetra
.656 .752 .92 r
.46985 .20121 .47799 .21103 .49243 .20574 .48434 .19583 Mtetra
.656 .751 .92 r
.48434 .19583 .49243 .20574 .50694 .20038 .4989 .19044 Mtetra
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Mtetra
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17408 Mtetra
.54307 .17408 .55095 .18418 .56578 .17872 .55795 .16857 Mtetra
.55795 .16857 .56578 .17872 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .1397 .66439 .12915 Mtetra
.66439 .12915 .67184 .1397 .68732 .134 .67994 .1234 Mtetra
.67994 .1234 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo?`2W`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<0
00000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4000004`0oooo@@2W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
odD0Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<0
0000C03oool30:Noj`D0Yl3[1@2W_n/50:O0j`D0Yko[<@2W`>/00`000000Yl3[0:O0j`0=0:O0ja40
oooo0P00000^0?ooo`00=@3oool3000004d0oooo1P2W_n/20:O0j`P0Yko[1@2W`>/50:Nojc00Yl3[
00<000000:O0j`2W`>/03P2W`>/A0?ooo`030000003oool0oooo02`0oooo000c0?ooo`800000C@3o
oolA0:Noj`<0Z<7[1@2W`>/20:Nojc80Yl3[00<000000:O0j`2W`>/03`2W`>/A0?ooo`030000003o
ool0oooo02/0oooo000`0?ooo`<00000B`3oool50:NnjPD0Yko[102X`>/50:Noj`H0Z<7[>02W`>/0
0`000000Yl3[0:O0j`0@0:O0ja40oooo00<000000?ooo`3oool0:P3oool002h0oooo0`00001;0?oo
o`<0Z;o[1@2W_^X20:Noj`<0Z<7/102X`>/50:O1k0D0Z<7[>02W`>/00`000000Yl3[0:O0j`0@0:O0
ja40oooo00<000000?ooo`3oool0:P3oool002/0oooo0`0000030?ooo`030000003oool0oooo04H0
oooo1P2X_n/40:NnjPH0Z<7/0P2X`>/20:O0j`D0Yl7/1@2W_n/50:O0j`D0Yko[;@2W`>/00`000000
Yl3[0:O0j`0A0:O0ja40oooo00<000000?ooo`3oool0:@3oool002T0oooo0P00001;0?ooo`X0Z;o[
1@2X`^`50:S1k0D0Yl3[0`2W`N`20:NojPD0Yko[0P2W`>/80:Nojb`0Yl3[00<000000:O0j`2W`>/0
4@2W`>/B0?ooo`030000003oool0oooo02P0oooo000V0?ooo`<00000BP3oool40:S0j`D0Z;o[1@2W
`N`50:S2k0D0Yko[1@2W`>/50:NojP`0Yko[0`2X`>/[0:O0j`030000002W`>/0Yl3[0180Yl3[4@3o
ool00`000000oooo0?ooo`0X0?ooo`00903oool2000004/0oooo0`2W`>/40:S0j`<0Z;o[0P2W`>`5
0:O1k0D0YkkZ1@2W_n/50:Roj`D0YkoZ102X`>/50:Noj`H0Z<3[302W`>/30:Noj`L0Yl3[0P2W_n/A
0:O0j`8000005@2W`>/@0?ooo`800000:@3oool00240oooo0`00001;0?ooo`H0Yl3[102X`>/50:O0
k080Yl7/0`2X_nX50:NnjP80Yko[0`2X`N/50:Roj`D0Z<7/102X`>/50:S1j`D0Z<3[1@2W_n/50:O0
j`H0Yko[102W`>/50:Noj`80Yl3[0`2W_nX80:O0j`<000000P2W`>/00`000000Yl3[0:O0j`0B0:O0
ja80oooo00<000000?ooo`3oool09P3oool001l0oooo0`0000190?ooo`l0Yl3[102W`>`60:RojP@0
YkkZ1P2X`N/20:Roj`<0Yl7/1@2X`N`20:S0j`80Yl3/1@2X`N/50:O0j`D0Yko[1@2W_^X50:Noj`D0
YkkY102W_n/60:NojP80Yl3[0P2X_nX3000000D0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`03
0000003oool0oooo02H0oooo000M0?ooo`800000B`3oool70:O0j`D0Yko[1@2W`>/50:Roj`@0Z;oZ
1@2X`^`50:S1j`H0Yl7/102X`N`50:O0k0<0Z<7[0P2W_n/50:O0j`D0Z;gY1@2W_^X50:Rki`@0YkkY
1@2X_>P50:NojP040:RojP000000000000000080Z;oZ1`2W`>/00`000000Yl3[0:O0j`0C0:O0ja40
oooo00<000000?ooo`3oool0303oool2000000@0oooo0P0000030?ooo`@000002P3oool001D0oooo
1@0000030?ooo`800000B@3oool70:O0j`P0Yko[2P2X_n/50:O1k0@0Z<;/1@2W_n/50:O1k0D0Yko[
1@2W`>`50:Noj`80Yl3[0`2W^nP50:Rmj@80YkkZ0`2X]^<50:Rki`@0ZKOS1@2X_>P20:Rli`<00000
1@2X_nX50:Roj`<0Yl3[00<000000:O0j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0;0?ooo`005`3oool00`000000oooo
0?ooo`030?ooo`<00000A03oool90:O0j`P0Yko[0`2X`>/70:Roj`P0Yl7/102V_NT50:Noj`D0YkkZ
3P2W_n/60:Nkj0@0Z;gY1P2X]^<20:Rki`<0ZJoL102Y]n<20:Rlj080Z[GQ0P0000040:Rli`D0ZKgX
1@2X_n/30:S0j`030000002X`>/0Yl3[01<0Yl3[403oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00000o0?ooo`D0Yko[2P2W`>/40:Noj`H0Z<3[102X_n/80:O1k0<0
YkcX102V_NT20:Noj`<0Z;kY1@2W_^X50:RojPD0Yko[102W^NH50:Nkj0D0Z;7N1@2X]^<60:V_g0<0
ZKOS00@0Z[GQ00000000000000000P2Z]N420:Rli`<0ZkOQ1@2Y_NP50:Rnj@80Z<3[00<000000:S0
j`2W`>/04`2W`>/A0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool02@3oool000l0oooo100000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`L0Yko[1@2X`>/:0:O0
j`@0Z<3[1@2W`>/50:O1k0H0YkcX0`2V_NT60:Rnj@80YkkZ0`2Y_NP50:RojPD0YkSU102W^NH50:N[
fPD0Z;7N0P2X]^<30:ZXe@D0ZJoL00@0[:gH00000000000000001@2Z]N460:^gh@80ZKgX0`2/^^@4
0:Rnj@80Z<3[00<0Z;oZ0000002X_nX0502W`>/A0?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000:0?ooo`005`3oool00`000000oooo0?oo
o`020?ooo`800000103oool00`000000oooo0?ooo`0h0?ooo`P0Yko[1`2X`>/:0:O0j`D0Yko[102W
`>/50:Rlj0D0YkcX1@2Y_NP40:Rnj@H0ZKgX0P2X_nX30:RehPD0YkSU0P2W^NH20:JWePD0Yj_J102X
/Mh60:ZXe@80ZJoL0`0000040:b]f080Z[GQ0`2_[]H50:^gh@H0[;[T0`2X_^T40:RojP030000002X
_nX0Yl3[0180Yl3[403oool2000000/0oooo0P00000:0?ooo`8000002`3oool001H0oooo0P000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool:0:Noj`L0Z<3[0`2W_n/7
0:O0j`P0Yko[102X^^L50:Rlj0D0Z;SU1@2Y_NP40:Rgh`D0ZKgX1P2X]N840:Nhi@@0YZOF1@2WZmX5
0:ZSd0@0ZZSE0`0000030:jVd0@0[:gH1P2_[]H20:^gh@<0/;7I1@2/^^@40:Zmi`@0Z;oZ00<00000
0:O0j`2W`>/04P2W`>/A0?ooo`030000003oool0oooo0240oooo000L0?ooo`030000003oool0oooo
00D0oooo0P00000`0?ooo`@0Z;o[1@2W_n/50:S1k0@0Z<3[1P2W_n/40:O0j`P0Yko[0`2X^^H40:Rj
i`80Z;cX0`2X/n450:Rhi@80ZKgX0`2X[M/40:Rgh`D0ZJoL1@2X]N850:JTe0@0YZOF0P2WZmX30:ZS
c`D0ZZ?@0`0000020;2VcP@0[ZK@0P2/[MP30;>XcPD0[jkF1P2`/MT20:bji0<0/;ON102Z_NL30:Vo
jP030000002Y_nX0Yl3[01<0Yl3[4@3oool00`000000oooo0?ooo`0P0?ooo`00703oool2000000P0
oooo00<000000?ooo`3oool0:`3oool30:S0j`@0Z;o[1@2W`N`50:S1k1<0Yko[1P2X^^H30:Rji`H0
Z;?Q102X^>D60:R]f`80Z;OS0P2/Z]D50:V_g080Z;GR0`2WX]440:JTe0@0YZOF1@2ZXll20:ZSd0<0
00001@2`Y/h40:jVd0H0/jS>0P2_[]H30;N/cPD0/;7I1@2`]mh20:Zmi`<0[[cT0`2Y_nX00`000000
ZKoZ0:S0j`040:S0j`h0Yl3[4@3oool00`000000oooo0?ooo`0P0?ooo`00703oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02P0oooo1P2X`>/20:Roj`80Yl3/1@2W`N`:0:Noj`D0Z;o[
102W_n/50:NiiPD0Z;[V102W[]`50:Rch@D0ZJOD1@2X[M/40:bZe@D0ZJoL1@2WX]450:JTe080YZOF
0P2ZYM430:ZSc`<0000000@0ZZ?@0;:]d`2b[M<0/ZgC1@2`Y/h20:jVd080]Z_>1@2cZ<h60;N/cP80
/;7I0`2h/=440;2ggPH0[[cT0P2Y_nX00`2Z_nT000000:Zoj@040:S0j`l0Yl3[4@3oool00`000000
oooo0?ooo`0O0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo
1@2W`>/50:S0j`D0Yl3/0`2W`N`90:Noj`<0Z<3[1@2X_n/40:Nhi@D0YkWV1@2VZMT40:N^g080Z;?Q
0`2YY=450:VWe080Z:gK0`2a[=<40:bZe@80ZJoL0`2[XLd50:NRd@@0YZCD102ZYM4300000080ZZ??
1@2b[M<50;2VcP@0]Z_>102cZ<h20;Z^c@D0]jc>1P2h/=420;2ggP80]kKH1@2^_>@40:Zoj@030000
002Z_nT0Z<3[00<0Z<3[3`2W`>/A0?ooo`030000003oool0oooo01h0oooo000K0?ooo`800000303o
ool00`000000oooo0?ooo`0O0?ooo`h0Yl3[1@2W`>`90:Noj`H0Z<3[0P2X_n/70:Nhi@80YkWV0`2U
YmL50:JYf@<0YjkL1@2YY=450:VWe0D0/JcC102/Z]D50:^Qc@D0Yj;A1@2YY]<0102ZYM4000000000
002ZYM420:ZSc`<0/;ON1@2b[M<20;2VcP<0]kOI102fZlh20;>XcP<0^Zk=102g[<h20;j^b`D0^;3A
1@2g]]P50;:mhP<0Z[oY00<000000:Zoj@2X`>/0102X`>/?0:O0ja00oooo00<000000?ooo`3oool0
7P3oool001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`X0Yl3[1@2W
_n/40:O0j`X0Yko[102X`N/50:S0j`T0YkSU1@2UYmL50:JYf@@0ZZCA1@2YY=420:VWe0<0/k;G1@2a
[=<20:bZe@80/:K=1@2[XLd20:NRd@<0ZjKB0P2YY]<3000000<0ZZGA1@2`]mh50;:]d`D0]kOI102f
Zlh60;Z^c@80]jc>0`2n[//40;R`d@80`;7<0`2g]]P20;jgd`D0/[gR0`2/`>P00`000000[<3X0:S0
j`030:S0j`l0Yl3[4@3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01P0oooo302W`>/50:Noj`D0Z<3[102W_n/50:O1k0@0Z<7[1@2W^>H5
0:Nhi@@0YJGF1@2UYmL20:JYf@<0ZJGB102ZY=440:VTd@H0/k;G102a[=<40;2Vc@D0Zj7=102[Y]83
000000<0ZJKC102/`NT50;2ggP80/ZgC0`2^a^/50;Ngf@80]Z_>0P2j^]T50;Z^c@H0_Zk;0P2h/=43
0<2ac080]kKH102n]m<20;:mhP<0]kkO0`2/`>P00`000000Z<3[0:S0j`030:S0j`h0Yl3[403oool2
000001l0oooo000K0?ooo`8000003`3oool00`000000oooo0?ooo`0E0?ooo`l0Yl3[0P2W_n/30:O0
j`D0Z<3[102W`>`50:O1k0@0YkWV1@2W^>H50:BUeP@0YJGF102UYmL50:VUdPD0ZZCA0P2YY=420;Bn
hPD0/k;G1@2c/]P40;2Vc@80Zj7=0`2_Y<d300000080ZjKB0P2YY]<30:_:l0@0[<7Y102`]mh60:k6
j`@0]kOI1@2j^]T20;Z^c@<0_[OC1@2n[//50<2ac0H0_[OC1P2g_]l20:g1j0030000002]`NP0Z<3[
00@0Z<3[3P2W`>/A0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04@3ooolH0:O0j`80Z<3[0`2W_n/40:O0k0D0Yk[W102W^NH30:NhiP80
Y:KH102TYMH50:FUeP@0Z:KD1@2YYM840:ZTd@D0];kR0P2c/]L30;39k0@0/k;H102`Y/d20:nTc@<0
00001@2[Y]860:_:l0<0[<7Y1@2McoT50:k6j`D0Z<O`102j^]T50;jgd`@0_Zk;0P33/l/30<2ac080
a[?8102n]m<20<Jjc`@0]kkO0P2l`Mh20:g1j0030000002]`NP0Z<3[00@0Z<3[3P2W`>/A0?ooo`03
0000003oool0oooo01/0oooo00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0303ooolL0:O0j`H0Yko[0P2W`>`20:Nlj0D0Yk[W
102W^NH40:BVf0D0Y:GF0P2UYMH30:JVe@<0Z:KD1@2YYM850;7;k@@0];kR1@2`bN`50;>bf080/:K=
0`0000040:nTc@80ZjKB0`2cdO050:_:l0@0UM;m1@2McoT508g;o@D0Z<O`0P2j^]T20:c4j`D0_[OC
0P2n[//40<>cb`030<2ac036/lP0a[?80080a[?80P2n]m<40<Jjc`80]kkO0`2l`Mh20:g1j0030:o2
j0000000[l;X00D0Z<3[3P2W`>/@0?ooo`030000003oool0oooo01/0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool2000001<0oooo00<000000?ooo`3o
ool02P3ooolJ0:O0j`T0Yko[1@2W_>P40:Nji`D0Y:SJ102TY]P40:BUePD0YZKE102XY]@20:VUdP<0
[=;d1@2abnd40:7An0D0/<W/0`2c/]P300000080[ZG?1@2_Y<d60;?Al0H0UmSn0`2Ed_d50836oPD0
SL_m102Xao040:c4j`D0_[OC1P33/l/50<Jcb0H0a[[?1@2l`Mh40:o2j0040000002_`^P0Z<3[0:S0
j`<0ZL7[3@2W`>/A0?ooo`030000003oool0oooo01X0oooo00070?ooo`040000003oool0oooo0000
00/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo00L0oooo7@2W`>/4
0:Noj`D0Z;kZ1@2W_>P40:B/g@D0Y:SJ0`2TY]P50:BSe@D0YZKE0`2XY]@60:cBm0D0W<oi102QdOP4
0;39k0<000000P2S/N<40:jUc`80[jC=102nd^T60:OTn`D0VLCf102@b_`40836oPD0Lkkm1023`o`4
0:c4j`80_[OC0`2g_Mh40<>cb`80a;K=1036/lP00`3;]/D0a[[?0<Jjc`020<Jjc`80cKg<0`2l`Mh2
0<75g@<0[l;X00<000000:o2j02Y`N/0102Y`N/>0:O0ja40oooo00<000000?ooo`3oool06@3oool0
00030?ooo`0000000000008000000P3oool010000000oooo0?ooo`0000090?ooo`800000103oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo8P2W`>/50:Noj`@0Z;kZ1@2T/>04
0:B/g@@0Y:SJ102QWm<50:BSe@@0YZKE1@2XeoP50:3;mPD0W<oi102B_oD30000000308Zim@2S/N<0
Xk7S00<0Xk7S0`2^YLl50;kBj@<0YOOT1@2UcoH509W4mP@0UlGf1@23`_`407>no@<0Pl?l102/a>/6
0;NmgP80`k?;0`34]/d30<Jcb0<0bkK50P36^/l40<fmc0D0`LGM0`2``nP00`000000/<?X0:W1j`03
0:W1j`l0Yl3[403oool00`000000oooo0?ooo`0I0?ooo`001`3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00<0oooo0P00000F0?ooo`030000002W`>/0Yl3[02@0Yl3[1@2W_n/4
0:Fdh`D0Y;3P0`2T[=d509jLd@@0XIoC102TXmD50:KInP<0Z=Oh0`2Sb?<40:3;mPD0X<Kc00<0T[oe
0000000000000P2B_oD308Zim@@0Xk7S1@2b^]l20;kBj@<0YOOT0P2@gOh50:G?mPD0YL?_102GaOH5
08[1n@@0M;Wk0`1S/o/408Rnn@D0]kgN1P34]/d00`36/lP0bkK50<^fa@020<^fa@D0cKg<0P3C`/T3
0<75g@80a<SM0`2``nP00`000000ZL7[0:W1j`030:W1j`h0Yl3[403oool2000001X0oooo00080?oo
o`8000002P3oool3000000<0oooo00<000000?ooo`3oool04P3oool[0:O0j`80Yko[0`2V^>H40:Fd
h`@0Y;3P102MV]0409jLd@D0XIoC0P2TXmD20:KJnPD0Y]Wj1P2Sb?<40:G=m080X<Kc0`000005096e
k`80IJOf1@26W>450;:jg`80YOOT1@2@gOh50:70k`@0YL?_1@2Ob?D508[1n@@0M;Wk0`1S/o/408Rn
n@D0YK_Y1@34]/d40<^fa@80d;O20`3=_L`30=?2b@80`LGM1034b=d20;33j0030;34j@000000ZL7[
00@0ZL7[3P2W`>/A0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo0180
oooo8`2W`>/50:Noj`@0Yl3[1P2V^>H30:Fdh`D0WI[A0`2MV]0509jLd@@0XIoC1@2Vf_X60:K8l@D0
Z<kd0P2UcO@3000000@0W[[/1@2A]Nl206FWmPD0QYcQ0P2b^]l209cbb@03071od`1@T>d0D93]00D0
P;Wi1@2Q`>l40:c6k0D0WlSe1@2@_oH407bin@<0EZ_i101KZ_T40:Fkj@@0a;K=0P31]/l20<^fa@@0
d;O200<0cKg<0=?2b@3C`/T00P3C`/T60<C8g@<0/<CY00<000000;34j@2X`N/0102X`N/>0:O0ja00
oooo00<000000?ooo`3oool05`3oool001T0oooo0P00000A0?ooobH0Yl3[1@2W_n/40:Nlj0D0Y[SV
102NWm@409fJd@@0WI[@102NW=460:KGn@@0ZL_b0`2Vb?430:O:lP<0Z<kd0`0000030:74l@D0W[[/
1@2Gb?P00`3ChN80IJOf08JLh@0308JLh@80W?;9101`Om<3052@k@@0P;Wi1@2R]nL40:c6k0D0XL_f
1@2@_oH307bin@@0EZ_i101KZ_T40:Fkj@80a;K=0`31]/l00`3;]/D0d;O20=2g`P030=2g`PD0dl;9
00@0fLK70<C8g@34b=d0a<SM0`36bmh20;34j@030:o4j@000000[lCY00D0Z<7[3P2W`>/@0?ooo`03
0000003oool0oooo01H0oooo000I0?ooo`030000003oool0oooo00d0oooo:P2W`>/50:NnjP@0YkcX
1@2OYMX309jOe0D0WI[A0`2MV]060:K>m@D0[=7c102Ybo850:O:lP<000000`2XbO440:74l@D0Wkk_
0`2Gb?P30=?QhPH0UiC?1@2LU<`307n:e0@0QI_Q1@2R]nL40;?ElPD0XL_f1@2F^o4408Jln0<0CjOh
0`0_T>l40:Fkj@D0`KK?1P3@]l80103D^Kl0dl;90=?2b@3C`/T30=W6a`D0a/_N102_a>T010000000
[lCY0:S1j`2X`N/30:S0j`d0Yl3[4@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`000000
oooo0?ooo`090?ooob/0Yl3[1@2W_n/40:NnjP@0XZgO102OYMX409jOe0@0WI[A1@2R_nd30:K>m@80
[mSe1@2/dO<50:K8l@<000000P2/bNl50:S9l@@0Tkgc1@2O_^l40=?QhP80a]CT102GU<l20;J[cP@0
W9C<0`1oR]@508FKh@80X[OW0`2_bNd40;?ElPD0W<7b102F^o4508k6nP<0Aj?g0`0_T>l408N_l0<0
`KK?0P2l/m440=2g`P<0e;Vo00<0dl;90=W6a`3Ia/L00P3Ia/L0103NblH0a/_N0<K;gP36bmh20<K=
g`@0[lCY00<000000:S0j`2X`>/00`2X`>/>0:O0ja00oooo00<000000?ooo`3oool05@3oool001T0
oooo0P0000070?ooobl0Yl3[1@2W_n/40:Bdi0@0XZgO102OYMX309jOe0D0WJgS1@2R_nd50:oHm@D0
YlO`00D0Y/Sa00000000000000000:K8l@050:c9k`D0Y<;_102C_O<209nnk`@0WnWk1036e>@309ND
c`<0]Z_>1@2LU<`307n:e0@0QI_Q1P2_bNd40:gHmPD0W<7b102O`_4508k6nP<0Aj?g0`05L]h408N_
l0040<6fc`2l/m40_;?A0;bcd@<0d;O2103D^Kl40=W6a`<0g/_61@36cMl30:o4j@030000002_a>T0
Z<3[00<0Z<3[3`2W`>/@0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo
00<0oooo<`2W`>/20:Noj`<0Y[[X102T]>@40::]g`<0WjGJ102HW]P509f]h`80X[o]102`goL50:W6
k`040:O7l00000000000000000D0ZLK^0`2/bNl20:g8kPD0Y<;_0`2C_O<209oYn`D0Vk[^0`36e>@0
0`2f]mT0UiC?0;Jgf@040;J[cP@0W9C<0`1oR]@509R/i@<0[lW]0`2hioD40:gHmPD0Vk;X102O`_45
09;9nP<0?9cd0`05L]h306:JkPD0_;?A00<0d;O20=Bi_`3D^Kl00`3D^Kl00`3J_;`0fLK70=W6a`04
0=k;aP040>;@a@36cMl0a/gO0<K=g`80aLgP0`2_a>T00`000000Z<3[0:S0j`030:S0j`l0Yl3[403o
ool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`030?oooc@0Yl3[1P2V^^P3
0:Bdi0@0XZgO102FV=<409RNf0@0WJgS102`goL30:_7kP80ZLK_0`0000040:S7k`D0ZLK^1@2]b>h5
0:G3k`<0QLOm0P2/_>D509^jkPD0][OI102fZlh50:N_g@<0U:7M1@2H[>D50;SWm@D0W[CX1@2K/^P5
0:[Bm@@0T/Wj100lW?@200EbgP<0HY[^102l/m450=Bi_`80f[bl00<0fLK70=k;aP3NblH00P3NblH2
0>;@a@80a/gO1035cN030:k3j@030000002X`>/0Z<3[00<0Z<3[3P2W`>/?0?ooo`8000005@3oool0
01P0oooo00@000000?ooo`000000oooo<`2W`>/40:NnjPD0Y[[X102JX=T409JId`<0UYSC1@2HW]P5
0:oQn0D0ZlO^0P0000040:[9l0@0Z<O_1@2/anh30:g8kP80ZL3Z1@2U`nl50:bli@<0Vk[^0P2[]N05
0;Jgf@80]Z_>0P2Z/ml50:N_g@<0U:7M1P2]goT40:k<k`D0W[CX1@2Ybo420:[Bm@<0Zlca102CbOX4
02N@kP03001Ab@1RV^h0HY[^0080HY[^0P2l/m420;R_d0<0e;Vo0`3J_;`40=k;aP<0h]351@35cN02
0<C=h@80[/?Y00<000000:k3j@2X`>/0102X`>/=0:O0ja40oooo00<000000?ooo`3oool01P3oool2
000000X0oooo000H0?ooo`030000002W`>/0Yl3[0300Yl3[1@2W_n/40:NnjPD0WZ_O0`2JX=T409JI
d`@0UYSC0P2HW]P40:_FmPD0/<k_0`0000020:[;l@D0Z/W`102WaNl50:c7kPD0ZL3Z1@2d`^@50:bl
i@D0ZkGP102f]mT50:Zcg`@0YjoM102Lc?P30:gOn@<0]=ke102^c>l509fdj0@0ZL_a1P2[c?4409G@
o0<01gSQ00<002j_001Ab@0oO^D00P0oO^D50;R_d0030=Bi_`3J_;`0f[bl0080f[bl00<0h<6i0=k;
aP3NblH0103Rd<D0103TdlH0aLgP0<G=h035cN030<C=h@<0[L?Z00<000000:g3jP2X`>/00`2X`>/>
0:O0ja40oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`004@3oool2
000000D0oooo00<000000?ooo`2W`>/0<P2W`>/40:Noj`@0XkCU102NZml409ZPf@@0UYWC0`2FV=<4
0:_FmP<0]]Sa00D0/<k_00000000000000000;3>k`050:[;l@D0Yl;]102WaNl50:g6k0<0ZL3Z0P2^
a>X50;C2i0D0/;cS102[]N050:Vhi0@0Z[?O1@2Mb?H409c<n0H0]=ke102KZ>0509fdj0D0/=;a1P2_
d_8309G@o0<01gSQ00<002j_03mni@0oO^D00P0oO^D40;R_d0@0f[bl0`3P`KT40>;@a@<0i=?61034
cN420<;<hP<0[L?Z00<000000:g3jP2X`>/00`2X`>/>0:O0ja00oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo03<0Yl3[102U^nT40:>di@@0WZ_O0`2JX=T409JId`D0XKg]0`2ff?43000000D0Zlca
0`2Zbo420:S3k@D0Yl;]102Ya^h50:g6k0D0[/CZ0P2d`^@30;74j0D0/;cS102Y_^T50:Vhi080Z[?O
0P2TdOL509g8mPD0Zm[h1@2U/N4409^Xh080WKCX0`2`f?@30;3Bl@80[L[_0`2_d_830;CPmP<0S<on
00<005?;00Mhh@07N>40100oO^D30;R_d080]j_=0`3J_;`30>31^@030>O7]P3Rd<D0h]3500<0i=?6
0P3Se<L20<C=h@@0`/cR0`2]`nX00`000000[L?Z0:S0j`030:S0j`h0Yl3[403oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0
oooo0P0000020?ooobh0Yl3[1@2W_^/40:Fkj@@0XkCU0`2NZml408nGeP@0UJCO0`2Q_Nd0102ig_<0
00000000000000040:g=l0D0Zlca1@2X`nd50:_8k`@0ZLK^1@2Xa>h40:k4jPH0/LCX0P2`_><30:[4
k@@0ZKkY102Y^>@50:CAm`H0XLcf102^`NL50:Fah@<0VjSP1P2`f?@50:g:k`D0]>3f102<coh2001C
b`04000>V@0UI=L0?gkU03mni@80^:o@0`2gZld20=Zl_0@0h<6i0P3WakH30>CCaP@0hmC71@32c>83
0:g3jP030000002]`nX0Z<3[00@0Z<3[3@2W`>/A0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`020?ooob`0Yl3[0P2W_n/50:Nnj`<0YK_Y1@2FXM`3096GeP@0SiOF102EY=l3000000040;WNl`2c
dO00/m7`0;?Al0@0[Lg`1@2[aNd30:S3k@80Z<O`1@2[b>l40:S3k@D0Z<C^102YaNh50;74j0D0Z/C]
102Y_^T60:3>n0@0Wl7`0`2Qc?H30:o9k@@0[/7W102U/N450:O?m0D0ZlS_0P2]b^l40;3Vn0D0T>k]
0`1Q`_d00`00:K4005?;000>V@0202ETe`H0]j_=00@0f[bl0>31^@3P`KT0h<6i0`3WakH00`3]c;<0
i=?60>?Da`030>?Da`80h]C90P32c>830<3;h`<0[L?Z00<000000:c2jP2X`>/0102X`>/=0:O0ja00
oooo0P0000040?ooo`8000002P3oool00100oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`050?ooobP0Yl3[1@2W_n/40:Nnj`@0WJkS102FXM`4096GeP<0SiOF00@0/]Gb00000000
000000000P2beO860;?Al0@0[LW^1@2[aNd50:S7l0D0Z<;/102X`nd50:G3k`@0ZLG^1@2Xa^l40:[4
k@H0WlOd1@2T`>d409o1l0D0[lW]102^`NL509nkk@80Ylod0`2^eO@40:_8k`@0/>Kh00<0F=;N0:G6
l@2Ua_400`2Ua_4305VSmP8007OD00<002Va001Cb`0UI=L00P0UI=L50;N[c@@0h<6i0P3WakH20>g<
/`@0hmC70`3Re<T60<3;h`<0[<;Z00<000000:c2jP2X`>/0102X`>/=0:O0j`h0oooo0`00000@0?oo
o`004@3oool2000000@0oooo0P0000070?ooobP0Yl3[1@2W_n/40:>hj0@0WJkS102FXM`3096GeP05
0:6jjP00000000000000002Q^^X00`2beO820;[Hk`<0/m7`0`2_c_040:g9kPD0ZLO_0`2Xao070:S2
k0D0ZLC]202U`nl50:S6k`D0X/?`1@2W`^`40:C0k@D0ZlW`102_bNd509n`i0@0Wk_]1P2^eO@509GZ
n@80Tm[n0P2lbN@50:G6l@<0FJ?f0P00Mm@00`00:K40002<01eDc00202ETe`80]j_=0`2l[<T20>31
^@<0ilNf0P3]c;<00`3`d;40hmC70>?Da`040>;Db@040>7Db`30bn<0`<_S0<3;h`<0_/_T0`2/`^X0
0`000000Z<3[0:S0j`030:S0j`h0Yl3[3`3oool00`000000oooo0?ooo`0>0?ooo`005`3oool00`00
0000oooo0?ooo`070?ooobP0Yl3[1@2V_NX40:>hj0<0WJkS102FXM`0102@W]d00000000000000005
0:6jjPD0^]S_1P2_c_050:S5k`@0ZLO_202X`^`20:[6kPD0ZLC]102V`N`40:G3k`D0YL7]0`2R`o02
0:S2k0D0Yl;/102W`nh50:_9l0@0YK?R1@2O/>@50:KXn`H0IMWT0`2YaNd50;c9i0D0Xic>0P1hP]00
1@00=KP007OD0001T@00:K40002<00807EC<1P2l[<T00`3P`KT0ilNf0>O7]P030>g</`80l=2a103R
e<T30>7Db`D0_/_T0`2/`^X00`000000[<;Z0:S0j`030:S0j`h0Yl3[403oool00`000000oooo0?oo
o`0=0?ooo`005`3oool00`000000oooo0?ooo`080?ooob@0Yl3[1@2W_n/40:JmjP@0V:[S0`2>Vm/0
1029U=P00000000000000004092Ng@80XK[Z102lfNl60;CBl0@0ZlO^1@2XaNl40:W4k@D0Z<;/1@2Z
a^h50:W1j`@0Y/7/102W`N`50:G1k@D0Z<;/1@2W_n/40:O3kPD0Z[_V102U/n86083Wj`0304C6d`28
c_h0R<kn00@0R<kn0`2YaNd30<38h0<0_<WT0P2i/m<40:>LcP<0N8;@00@003^o0001T@000I400029
0`0ME<`50;b/b@<0ilNf0P3]c;<30?3@/@030?7A/@3Re<T0h]C900<0hMC;0P3Oe<d20;k;i0<0_L[T
0`2/`^X00`000000Z<3[0:S0j`030:S0j`h0Yl3[403oool00`000000oooo0?ooo`0<0?ooo`005`3o
ool2000000T0oooo9@2W`>/50:Noj`@0X;OX0`2HZ^<208jKf`8000001029U=P3092Ng@D0_=W_0P2k
enh30;CBl0<0/<c^102[anh50:[6kP@0ZLC]1P2Xanl40:S1j`D0ZL7[102Y`n`40:O1k0D0ZL?/0`2X
`^`20:Rnj@D0Yko[102]a^d50:ZkiP80Clc:1@1]e_L509jnk`D0/K[Q1P30b>040;Vcd`D0Xic>0`1h
P]001P00>kl0006A0001T@0008`09E7801eDc0@0_:c90P36//H0103WakH0kLbc0>g</`3]c;<30?3@
/@80lM6a0`3Qe</30=oDc@H0_L[T0`2[`^X00`000000Z<3[0:S0j`030:S0j`h0Yl3[3`3oool00`00
0000oooo0?ooo`0<0?ooo`005`3oool00`000000oooo0?ooo`0:0?ooob@0Yl3[1@2U_N/40:2gj004
09RZh`0000000000000000<0SY_K0`29U=P60:k6j`D0^mO^1P2`c>h40:[8k`D0Z/K^102WaNl30:S7
k`<0Yl7/102X`N/50:W5kP@0ZL?/102Y`^`50:W3k0D0Z;kY0P2W_n/30:_@l`@0[LK]0P0c^K<508WG
o`D0Y[CS0`2N_^l20;>ig@<0/K[Q0P2man840<38h080`LKN102i/m<40:>LcP<0N8;@0P00>kl01@00
0I40002902EAb00UDLP07EC<0080_:c90`36//H40>g</`80l=2a0`3adK400`3adk80hMC;0=oDc@03
0=oDc@040=kFc`2mb^@0_L[T0;g:i0<0^l[V0`2[`^X00`000000Z<3[0:S0j`030:S0j`d0Yl3[403o
ool00`000000oooo0?ooo`0;0?ooo`005P3oool00`000000oooo0?ooo`0<0?ooob00Yl3[1@2W_n/4
0:Fmj`040:2gj0000000000000000080V:[S102>Vm/409FVh@<0[/K[0`2oen/30;_GkP80^=;^0`2`
c>h30:c9k`@0Z/S_1@2Wa>h40:O5k`H0Yl7/0P2X`N/20:S6k`D0ZLG^102X`^`40:W2k0D0ZKoY102X
_^T60:_@l`80;[B_1@2Id?/40:V`g@D0Y[CS1@2c^Md50;g7hP80`<SP0`31a]h40;Vcd`D0WY350`2?
Slh0100ZIML0006A0001T@0008T202EAb0D0a[;600<0e;c30>g</`3]c;<00`3`d;420?7A/@80lM>b
103Oe<d30=kFc`D0^l[V0`2[`^/00`000000Zl;[0:S0j`030:S0j`h0Yl3[403oool00`000000oooo
0?ooo`0:0?ooo`005P3oool2000000h0oooo802W`>/50:Noj`0409jgj@0000000000000000<0TZSU
0`26Umd408FCfP@0UJKQ1P2oen/50;SBkPH0[<W_102XaNh50:O4kP@0Z<?]1@2W`N`50:S6k`D0Yl3/
102X`^`40:W1j`D0ZKoY1@2We?L203Fj]@D0XLWe1@2Z[m/40:V`g@D0/[WN0`2c^Md20;S4i0@0_LOR
1@31a]h50:>Ea`@0WY35102?Slh00`0ZIML0006A0000Q@0302EAb0<0a[;60`3D_<<0103]c;<0l=2a
0?3@/@3`d;420?7A/@80lM>b00<0l]Fc0=oDc@3Oe<d0103Ne/l0103Lem<0^l[V0;_:iP2kb^H20;W:
i`<0Zl;[00<000000:S0j`2X`>/00`2X`>/=0:O0j`l0oooo0P00000<0?ooo`005P3oool00`000000
oooo0?ooo`0>0?ooob00Yl3[0P2U_N/3000000@0W[OY0`2BZ>D308JGg@@0QI?J0P2EY^420;?6j0<0
_mO[1030en/50;;=kPD0ZlS_2@2XaNh40:S3k@H0YlO`102V_n/50:O0k0@0Z<C^102Y`N/60:CDn080
?l6j1@2Ta_440:V_f`D0ZZoK0P2Y/=d20;2jh@D0/[WN1@2ha>@20;g7hP80`=3W0`31a]h20:ZSc`@0
XiG7102NT<D408n?cP80:VGG00@000250000R@0hG</09E780`36//H30=Bl``<0l=2a0P3adK430?7C
/P80l]Fc103Ne/l30=cGd`D0^L[W0`2Z`^/00`000000Z<3[0:S0j`030:S0j`d0Yl3[403oool00`00
0000oooo0?ooo`090?ooo`005P3oool00`000000oooo0?ooo`0@0?oooa/0Yl3[0P2W_n/3000000@0
YKg[0`2N]nT309:Xi@<0QYOM1025TmX50;?6j0D0`=O[0P2le>`30;;=kP<0[lc_102[b>l40:S7k`D0
Z<G^102VaO030:O7l0<0Yl7/102V_n/50:S7l0@0Z<C^1@2SdOL204K6_0D0Y/K`0`2Ta_420:R_g0@0
ZJoK102Z[m/50;2jh@80/[WN0`2c`^H40;S4i0D0`=3W102ZXll50:>Ea`<0WY351@2XZmP00`1NR><0
00250000Q@0203QLb`0302EAb036//H0e;c300<0e;c300<0hLNo0?3@/@3`d;400P3adK420?7C/P<0
l]Fc00<0l]Ve0=kFc`3Ne/l00`3Lem<20=WIe`80^L[W0`2gbNP20:[2j`030000002Z`^/0Z<3[00@0
Z<3[3@2W`>/@0?ooo`030000003oool0oooo00P0oooo000F0?ooo`8000004P3ooolI0:O0j`<00000
0`2W_n/40:Fmj`@0Sj[X0`1oUn03082Bf`@0UjOQ0`2ca^P40<?Di`D0_=C/1P2_c>l40:S7l0@0Z<O_
1@2Ua>l40:K5l0H0Yl7/0P2V_n/20:K9lP@0Z<O`1@2Sbo@30:?Am`@0Z<Wa1@2Va_050:R_g0<0ZJoK
1@2^^^840;2jh@D0/l;V1P2jdnd40;:ff`@0ZZ??102SULL209j@a@80[:SC1@2XZmP00`1NR><00025
0000Q@0203QLb`@0e;c30`3Qakl20?7A/@<0lM>b0`3beK<20?;I]@<0g=OC0`3IfML50;O9j0<0ZL;[
00<000000:W2j`2X`>/00`2X`>/>0:O0j`l0oooo00<000000?ooo`3oool0203oool001H0oooo00<0
00000?ooo`3oool04P3ooolE0:O0j`<000000`2W`>/20:Noj`80YKk[102N^>/408nZj080OiOP1020
T]/409NWh@@0`mCW0`36e^H30;cDk080]m7]0`2_c>l30:c:k`@0Z<O`1@2Va>l40:G4k`@0Yl?]1@2W
`N`50:K9lP@0Y<C`1@2Sbo@30:[Bm@@0Z<Wa1@2W[]d40:R_g0@0ZkWT1@2^^^840;32i`<0/l;V0P2d
do030;[Ck@<0]LKW102b]]/30:ZSc`@0XiG71@2/Z=<40:R[f080GXSS00@0002503QLb`0hG</0>5c;
0`3D_<<30>77_`040>W?^`3adk80lM>b0?7C/P<0l]Fc0`3bfKD00`3bgKT0fMWG0=WIe`020=WIe`80
eM_L0`2gbNP20;C9jP<0ZL;[00<000000:O0j`2W`>/0402W`>/?0?ooo`8000002@3oool000<0oooo
0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0503ooolA0:O0j`<00000
1P2W`>/50:Fnj`@0W[S[0`2?Z^P307nGh0@0P9;K1@2c`>@60<KFiPD0]m7]1P2/b^l40:S7l0D0Y/C_
102Wa^l40:O3k@H0YLSb102U`>d40:C4l00305_CbP2[goT0Zmoi00D0Z];e102U[]h40:N^g@D0ZKWU
102[^N@50:g1j0@0/<;W1@2ddo050;G6i`@0/[KK0`2ZXll50:2Kc`@0[:SC1@2^/m`207JFi0050000
Q@1?M=L0>5c;03QLb`3D_<<00`3Qakl20>W?^`030>kE^P3adk80lM>b00<0l]Fc0P3bfKD20?;M^@03
0?7R_P3IfML0fMWG00@0eM_L1@2dbNX30:W1j`030000002W`>/0Yl3[0100Yl3[2`3oool300000003
0?ooo`000000oooo00P0oooo00020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0E0?ooo`h0Yl3[0P0000060:O0j`@0Yko[1@2U_^/4092_
j`<0NiWU0P1fSmd5096Qg`<0/l3T0P34cN430<KFiP@0a=KW1@2ccnh50:W9l0@0Z<O`1@2Va_040:O6
k`D0Y<Ka1@2V`>`40:G0k@80Fm?:1@2[goT50:>^g`@0YJkN0P2W[]d20:Nhi@D0ZKWU0P2[^N@20:_1
j@@0[L7X1P2_d?440;C@k`@0]LKW1@2KTLP309ZBbPD0X9_?0P2/Z=<20;Big@@0[[?L0`1fU^@304md
e`<0hLNo0`3Yck/20>kE^P<0l]Fc0P3bfKD20?;M^@<0lN:n103Efm`20<oKhP80]<WZ0`2`an/20:W1
j`030000002Y`N/0Yl3[0140Yl3[1P3oool4000000@0oooo00<000000?ooo`3oool01`3oool00080
oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000001L0oooo2P2W`>/3
000000T0Yl3[102W_n/50:2kk0@0T:o[0P1kVND307J?g@D0TJ7O00<0/l3T0<C=h@34cN400P34cN45
0<CFi`80`]GX0`2ccnh30:o>l0@0ZLW`102Uao450:K6l0D0Y<C`102Wa>h50:K0k080L>3R1@2VkOT4
0::_h@D0XjkO0`2U[]h50:Nhi@@0ZKWU1@2[`NT40:c>lP<0[m3a0`2`eO<40;C@k`@0X9S;102KTLP4
09ZBbP@0X9_?1@2d^Md30:jcg0<0MYKT00@0001/04mde`1?M=L0CgCG0P3Qakl20>W?^`<0k]Fj00<0
lM^j0?;E/`3beK<00P3bfKD20?;M^@<0lN:n00<0knO50=GKg03Efm`00`3?fn850;37j`<0Z<7[00<0
00000:S1j`2W`>/04@2W`>/20?ooo`<00000203oool00`000000oooo0?ooo`070?ooo`000P3oool0
10000000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0H0?ooo`D0Yl3[0`00
000=0:O0j`D0Y[o/102P^n`3092_j`<0NiWU0`1fSmd4096Qg`@0a<gQ103;dMh50<;Ej0H0[lk`102V
bO840:G7l@D0YLC`0`2Ta?020:K7l@@0YlC^1029iOT409Kaj`@0XkCT102R[n440:>^g`@0YKKU102W
^>D50:W0jP<0Zl7Y0P2ZcO840:c>lPD0/=Gc1@2VX]430:2Hb`D0Vi780`2JT/X50:nih@@0];WM102[
]=l307fJi0<0CgCG00@0hLNo0>W?^`3Yck/0jLnk0P3^eKX30?7K^P80l]Ve0P3bgKT30?7R_P80knO5
103?fn820<OIi`<0/<O[0P2]aN`30:S1j`030000002W`>/0Yl3[0100Yl3[0P00000<0?ooo`030000
003oool0oooo00H0oooo00020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0I0?ooo`040:O0j`000000000000000180Yl3[102V_n`409Jfk@<0
Nj7[0P1YS>8307J?g@H0ZkCO1@3;dMh20<kBg0<0`]GX0`2ne>X50:_>lP@0Y/Wb102Uao450:G4l0D0
Y/Oa1@2If_d209Kaj`D0Yl3/102S]>@40:2bi@@0XkCU102U]^D40:Noj`D0ZL3Z1@2ZcO850:gEm@@0
ZZgI102VX]440:2Hb`@0Vi78102W/^440:nih@D0/;[Q102[]=l307fJi080I9C[0`3Yck/30>kE^P<0
lM^j00@0l^>l0?;M^@3bgKT0l]fi0P3ah[h30>oWa@80j^[=1@37fNL50:g5k0<0Z<3[00<000000:O0
j`2W`>/0402W`>/=0?ooo`030000003oool0oooo00H0oooo00030?ooo`8000002P3oool3000000<0
oooo0P00000H0?ooo`<000005P2W`>/40:>nk0@0U[K]0`1kXN/206V<hP@0PIGN0`2[]=l20;o0f`<0
bm7N103>d]`40;kDjP80^mC]1@2[c_850:C9l`<0YLOa1P2Tb?8509o=m`80Q>[L102]eoH50:O0k0@0
WK3U102P/^D30:>di@D0YKo/102W_n/50:S;lPH0ZMGg102/]^040:Z]f@@0YZ;A0`2PV</509nVf`@0
Yk;Q0P2_^N420:fjh`@0/;[Q1@2V/n8207fKi@<0I9C[0P3Yck/20>kE^P<0lM^j0P3bhk`20?;Y`080
lN:n0`3_ilD20>[Zc@80hn_F0P37fNL30;kDjP80[LG/0`2[`n`20:S0j`030000002X`>/0Yl3[0100
Yl3[3@3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`<00000
103ooolA0:O0j`D0Yko[102S_^`309Jfk@<0Nj7[0`1YS>84086EgPD0_l3K103>d]`40<oBf`D0^mC]
1P2Vc_D409o:mP@0XLOc1@2Rb?@309o=m`80PnWU0`2Zl?L30:gGmPD0VZkU102M/>D30:2bi@@0Y;k/
1@2U_n`50:K;l`@0Y]Ch0`2YeOL30:^li@@0[;KP0`2Z[MT40:JRd@@0VY[B102OY]/40:Nbh@D0[K[S
0P2`^^420:fjh`D0Y[?R0P1mVnD306>`nP<0k]Fj0P3afkX20?;S_0<0l^W000@0kng50>oWa@3_ilD0
knO50P3Zj/d30>?[ePD0_]CZ1@2[`n`30:O0j`030000002W`>/0Yl3[0100Yl3[303oool00`000000
oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0B0?ooo`<00000203ooolB0:O0j`@0Yko[
102N_>d308J^k`<0HI7Y0P1TQn0509NSg@<0_l3K0`3:aMD50<oBf`<0d=7J1@2geNl509o?n0@0Wl[f
102Pb_D50:;8m080PnWU0P2Zl?L409[0lP<0VK7Y102J[^D409f`i@@0XKg]102T_^`50:C:m0<0Y/_c
0P2TdoP40:KDn0D0ZkcU102/]^0409bAb0@0VY?<102JV]8309nVf`D0Zk[U2@2]^^<40:JchP<0OI_U
101S/?X30?7K^P80l^>l0P3bjL020>o]a@80kNo90P3Zj/d30>?[eP<0f^[O102fc^`30:_3k080ZL;/
0`2W`>/00`000000Yl3[0:O0j`0@0:O0j`/0oooo00<000000?ooo`3oool01P3oool001@0oooo0P00
000@0?ooo`<00000303ooolB0:O0j`@0Y[o/102N_>d308J^k`<0HI7Y0P1TQn0509NSg@030;o0f`3:
aMD0b/GE0080b/GE00@0dLG?0<oBf`3?d]/0cm;K0`3@dMX20=7?f0<0]mG_0P2de_4509o?n0@0VLci
102Pb_D208kWn@80S^oP1@2Ig?h409[0lP<0VK7Y0`2J[^D509flkP@0XKg]102Qb_D50:C:m0D0Y=?h
102Y_^T40:^li@D0WY760`2LTLP409ZCc0@0VY[B102[_^L40:^ji@D0[;cU102]^^<50:2bi0<0NIWU
00D08V;F04>`m`13/?L0@k3g0?7K^P020?;S_080l^W00P3_kLD20>g_b@80j_3=0`3SjmH30=[Zg`80
c^GX102fc^`50:W2k0<0Yl3[00<000000:O0j`2W`>/0402W`>/:0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`030000003oool0oooo00`0oooo0`00000A0?oooa40Yl3[102V_n`409Nik`<0Kj?`
0P14On@306B7h0@0Uj?M103:aMD30=75c`@0d=7J103AcmP50;CFl@H0UM3l0`2Ic?T4097Jo`D0O^KX
102Ig?h309[0lP@0T;Oa0`2H^^l509flkPD0W/[g0`2Qb_D50:7Bn@D0YkgY102Y_^T40:2BaP@0WY76
102LTLP309ZCc0D0Z/3Z102[_^L40:Zli`D0[;cU102Y^N@40:2bi0@0NIWU00<08V;F02FRj`0UX^/0
0P3bhk`20?;Y`0<0kng500@0kNo90>[`c@3Zl<d0j_3=0P3XlM430=[Zg`<0c^GX1@2_b>d20:W2k0<0
Z<7[0P2W`>/00`000000Yl3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo
00<000000?ooo`3oool02P3oool2000001D0oooo4@2W`>/40:Bok0@0UkW_0`1_Xo0204Aoi080JX_P
1@2/[]T20<[5e@@0dLG?0`3E`lP40=7?f0<0d/_C1@2be?8608W@o`<0RM;o00<0G]GS0:S8l02Xb?00
0P2Xb?0308Bkn0@0O;;f0`25/o<4092gl@<0V;[_1P2Ib_P409[?nP@0WM7j102U^^L50:Nmj@@0XI?6
0`2PT/H409jAaP@0W978102W_n/50:[0jP@0Z;[V102Z_>L50:Vji@@0ZKWT0`2P/^@407VIi@808V;F
00@002Zb02NQk@0WXNd09j7]0`3_kLD0103]klT0j_3=0>[`c@3Zl<d20>Sad@80i?;E103>iNP20<7K
k@@0[lS]1@2X`N/30:O0j`030000002W`>/0Yl3[0100Yl3[2P3oool00`000000oooo0?ooo`050?oo
o`00503oool00`000000oooo0?ooo`070?ooo`<00000603ooolA0:O0j`@0Y;o/0`2G^Nl306nSl080
A7oT0`1ZRn050:b^f@@0dLG?103E`lP00`3G_l80dLoH0=7?f0040=;;d`040=;2b`2be?80/]Cb0;;D
lP@0]/c[1@25e_l00`2dhoL0b/OG0<[7e`040:S8l0<0Q;_h0`1l/_H408Fcl`@0Rl3i102BaoX509S8
n0@0V/oj102T/^<40:Fji`D0XY?60`2QTlH40:2BaP<0WY761@2T^^P40:Noj`D0YkSU102X^^H40:Vj
iP@0ZK[U1@2U]nD309Z^iP@0M9OU00<0>73L029ReP03F=801019/?T0103]klT0j_3=0>[`c@3Zl<d2
0>Sad@80i?;E0`3Nlm`50<7Kk@@0ZlC/0`2X`N/50:O0j`030000002W`>/0Yl3[00l0Yl3[2P3oool0
0`000000oooo0?ooo`050?ooo`004`3oool3000000D0oooo0`00000L0?oooa40Yl3[102R_^d308ff
lP<0Ci;^00<09VkN04Aoi01ZRn000P1ZRn020:b^f@<0^k?B0P3AaLl40=G3b0<0eko2103Bbm<30=;2
b`@0]/c[102n_mX30;CSm`@0b/OG102SVL/308jAdP<0QIgR1@25/O8308_0n@D0V;ga0`2Hb?P50::Y
f`@0Y;;S102SU<D40::CaP@0XI?60`2PT/H40:>di0D0Y;[X102X^>D40:Nhi@D0ZKgX102Y^^H40:Rj
i`@0YKOU102J[^H407BGi@80>73L0P03F=8509[Bn`80j?7A0P3Tl]D30=kcg080eO7T1@2ed>h40:_4
k0P0Yl3[00<000000:O0j`2W`>/03`2W`>/90?ooo`030000003oool0oooo00D0oooo000C0?ooo`03
0000003oool0oooo0080oooo0`00000P0?oooa40Yl3[102R_^d308fflP<0Ci;^00@09VkN06Z;h01Z
Rn00JX_P1P2k/m840=G3b0@0eko200<0f;Vk0=;;d`3Bbm<0103B`//20=:h_`D0_[oJ0`3<^/T40<[7
e`80a;?9102SVL/308jAdP<0QIgR1@2JVm@409R/i0@0XYW;0`2QWm<40::Yf`D0Y9C50`2SU<D40::C
aP@0XI?6102T/>440:>di0D0ZK[V102X^>D40:W0jP@0ZKgX1@2X^nP40:Rji`<0YKOU1@2CZnH3076D
i@<0>73L00@0?H3V00=HdP2Jd_/0V];k0`2eg?@20>Cbe@<0g_?L0P3ElN@20<SWk@@0]M3^1@2X`N`7
0:O0j`030000002W`>/0Yl3[0100Yl3[203oool00`000000oooo0?ooo`050?ooo`004`3oool00`00
0000oooo00000002000002@0oooo4@2W`>/40:2mkP<0PK7d0P0VO>H202I^gP<0MY;P102k/m820<Fd
bP80eL?8103G_l830=Ri^`@0d/;;0`3B^;l0103C/;H0_[oJ0;jofP2n_mX40<bjb@030=Zo_P3:amL0
b/OG00<0a;?9102SVL/40:6Ba@<0WI;8102JVm@209R/i0<0YIK60`2RVL/40:6Od`@0YYO5102TU<D4
0:>Da@<0XY?61@2U[]h40:B`h@80XkCT0P2Y_NP40:VjiP80Z;SU0`2X`>/40:W0jP@0Yk[W102X^nP4
0:Rji`@0XKGV1@2CZnH3076Di@80CGkQ0P0mP>H40;GLm080anK]0P3Ck^H30=Gai0@0b>O]102]and4
0:S1k0P0Yl3[00<000000:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00D0oooo000C0?oo
o`<000009`3oool=0:O0j`@0Y[o/102P_Nh3086am0809WcV00<00ESB02I^gP1fT^000P1fT^020;^c
dP@0aKC:103G_l840=Ri^`030=Rd]03B`//0d/;;00<0d[Ro0`3C/;H50<bjb@<0f[nn1@34/lT20:>I
b`80Yi[90`2QT/D409fBb0<0VY_D1@2UU/H40::Ib`80XIoC0P2YVlP30:JGa@D0Y9C50`2SU<D40:N_
g@@0YJkN102T/>450:Vmj0<0ZK[V1@2X`>/50:JiiP@0Yk[W0`2X^nP50:FhiP@0XKGV102CZnH3076D
i@<0CGkQ0`1^XO030<OVk@80dnkV0`3Gm><30<SWk@<0^]S_102]and50:S0j`L0Yl3[00<000000:O0
j`2W`>/03`2W`>/70?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003oool0oooo02L0
oooo3@2W`>/40:Jok0D0W[g_0`1e[OD00`0VO>H00ESB07JBh00307JBh0D0aKC:00<0bk?30=No`P3G
_l80103H^K/30=Rd]0@0d[Ro0`3C/;H0103H/;00c;[90<bjb@3<^/T40=Zo_P030>;7_@34/lT0a;?9
0080a;?9102WV/T40:6Ba@<0WI;8102YV/H50:FFaP<0XYW;102YVlP40:JGa@@0Y9C5102Y/]l40:N_
g@<0YJkN1@2Y_nX40:Vmj0@0YkkZ0`2X`>/20:NiiPD0Y[WV0`2W^^L40:Jii`D0YKSV102M/^H408bV
iP80L9;T101=O^4306jQl0<0dnkV0P3Gm><30=Cfi@D0^]S_1@2Y`^`20:S0j`T0Yl3[00<000000:O0
j`2W`>/0402W`>/70?ooo`030000003oool0oooo00@0oooo000;0?ooo`D000001@3oool2000002T0
oooo302W`>/40:Jok0D0W[g_0`1e[OD2005HdP@0PYSO0`35]<X30<^c``@0f;Vk103H];@00`3I/:l0
d[Ro0=:h_`040=>`]P80f;2`00<0c;[90=Zo_P3J_kh00P3J_kh20>;7_@80a;?90`2i/M440:NJb@<0
XI;50P2MT/P20:fQb`<0ZI[61@2UU/H40:fSc@@0ZI_80`2VUlD50:^ghP@0ZK;O0`2W[md40:S1j`D0
ZKoZ102V_>T40:NnjPD0YkWV102V^NH40:Rlj0@0Y[WW1@2S^>L409fbiP<0S:KV0`1`T^@306F?iPD0
U[kc00<0eoCS0=Cfi@3Dm^D00P3Dm^D30<[_k@@0[l[^102Y`^`<0:O0j`030000002W`>/0Yl3[0100
Yl3[1P3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02L0oooo302W`>/40:Jok0D0WKg_0`1[ZOH00`00?[T00ESB08:Hg`0308:Hg`030<Fd
bP3;/l<0bk?30080bk?300@0ck6m0=Ri^`3H^K/0f;Vk0`3H];@30=V`[`040=:h_`3C/;H0dk2f0=>`
]P<0f;2`103J_kh30>;7_@H0^K7A0`2WV/T30:6Ba@@0[J7;102YV/H20:FFaP<0/:gE0`2]Xld40:VK
b080YYO50P2[_>H40:^ghP@0ZK;O102W`>`40:S1j`D0Y[_X102V_>T40:Rki`@0YkWV1@2X_^X40:Rl
j0@0YK[X102S^>L409fbiP<0S:KV101`T^@306F?iP@0]MSb0`39kNd30<[_k@<0^mga102_b^h40:S1
j``0Yl3[00<000000:O0j`2W`>/0402W`>/50?ooo`030000003oool0oooo00@0oooo000=0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool09`3oool<0:O0j`D0Y[o/102M_Nl306^YmP03
000n^@22V=l0PYSO0080PYSO103;/l<30<na_@030=Ri^`3H];@0f;Bd0080f;Bd0`3I/:l40=>`]P<0
f;2`00<0h[^_0=Zo_P3J_kh0103Rakd00`3LblL0^K7A0;Vad@030;Vad@<0Yi[9102YY]@40:fQb`<0
ZI[61@2`[MD40:fSc@<0ZI_81@2[_>H30:^ghPD0Y[k[102W`>`40:Nji`@0Y[_X1@2X_NP40:Rki`@0
Yko[102X_^X50:Fii`@0YK[X102P]>H409R^iP<0Qj7U101eU><3082Tj`80]MSb0`39kNd20<ggj0D0
^mga1@2Y`n`@0:O0j`030000002W`>/0Yl3[00l0Yl3[1@3oool00`000000oooo0?ooo`040?ooo`00
3@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo302W`>/50:Jok0@0WKg_
0`1VZ?H00`008ih0R9_O08RKg`0208RKg`<0bk?30`3?/Kd40=Rd]0@0fK2_00<0fk2/0=>`]P3C/;H0
103H/;020>:k[`@0h/Nm0`3LblL50:B/g@<0WZKK102YY]@30:fQb`@0[[GM102`[MD40:fSc@@0Z[oY
102[_>H40:Jlj@@0Y[k[2@2W^^L40:RojP@0Z;gX1@2V_NX40:Noj`@0Y[SV102U^NL50:Bgi`@0X;CV
0`2H[^H408NQi@<0MICS1020Y>/30<W]k@80cOOX0`37l^h40:o;kP<0ZL?/0P2X`N/?0:O0j`030000
002W`>/0Yl3[0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?oo
o`0:0?ooo`800000:03oool<0:O0j`H0Y[o/0`2M_Nl306JXmP03000SWP28Vml0R9_O0080R9_O00<0
bk?30<na_@3?/Kd00P3?/Kd0103A/KT0f;Bd0=Rd]03H];@30=V`[`<0fk2/00@0dk2f0=R`/03H/;00
f;2`0`3R^jl00`3/ajl0h/Nm0>;7_@040=c;a`030<k2c`2T[=d0Y:cM0080Y:cM102NY]/30:VVe0@0
YkKS102^]Md30;2]e@D0Yko[102Z_nT40:Fii`@0Y[cY102X^nL50:Nji`@0Z;o[102X_nX40:Jlj@@0
Y[gZ1@2W^NH40:JhiP@0Y[[X102T]nL509faiP<0TZOT1024W>8208:Ni@D0Wl7a0P3=mnP30<ObkP<0
^]gb102_bnh40:S1ja00Yl3[00<000000:O0j`2W`>/03`2W`>/40?ooo`030000003oool0oooo00@0
oooo000<0?ooo`8000003P3oool00`000000oooo0?ooo`0V0?ooo`d0Yl3[1@2V_n`309fmk`<0IjSf
1028Vml40<na_@<0dK6i00<0f;Bd0=V`[`3I/:l00P3I/:l30=^`[0@0f;2`0`3R^jl20>c7[`@0g<_7
0`3>`/l30:B/g@@0WZKK102N/ND40:Nfh`<0[[GM102T^nT40:Noj`D0Y[OV102U^NL40:Rmj0@0Z;_W
1@2W_n/40:Roj`@0Y[_X102V_>T40:Rki`@0YkWV1@2W_NT40:Jjj0@0X[KW102M/NH409:Wi0<0Q9cR
1022W^D30;cTl`<0aOS/1@2jgO850:W3k1@0Yl3[00<000000:O0j`2W`>/03`2W`>/30?ooo`030000
003oool0oooo00@0oooo000M0?ooo`030000003oool0oooo02H0oooo3P2W`>/40:Jok0<0WKg_0`1W
Z?H408JMhP<0ck6m0`3A/KT40=V`[`@0fk2/00@0gkB/0=R`/03H/;00f;2`0P3R^jl30>c7[`030>k<
/P3LblL0g<_700@0c/;?102NZ]l409NZh`@0W[7U0`2W]^<40:>hi`@0Y;_Y102W^>D50:JgiP@0Z;oZ
102X_NP40:NnjP@0Yko[1@2W^^L40:Jkj0@0Z;gX102X^nL40:JmjP@0YkgY1@2S]nL40::fi`<0WK7V
102BYn@308BLhPD0V;K]1035n>`30<;cl0@0[LW^1@2X`>/D0:O0j`030000002W`>/0Yl3[00h0Yl3[
103oool00`000000oooo0?ooo`030?ooo`007P3oool00`000000oooo0?ooo`0V0?ooo`h0Yl3[102V
_n`409jmk`80Jj_f1026WN800`3?/Kd0dK6i0=6a^@020=6a^@040=>b^@3I/:l0fK2_0=V`[`@0fk2/
00<0gkB/0=R`/03H/;000`3R^jl30>c7[`80k/bb103>`/l20<Bjd0@0WZ[O0`2GZ^<50:6diP<0XkKV
102S^>L40:NjiP@0YkSU1@2X`>/40:RojP@0Y[cY102W_^X80:Nji`D0Z;kY102X_NP40:Jlj@@0Y[gZ
102T]nH40:>gi`D0Wk3T0`2GZN<408fQh@<0R9oS0`2H]^d30;GRmP030<;cl02ffO80]]Wb00<0]]Wb
102X`^`40:S0ja@0Yl3[00<000000:O0j`2W`>/0402W`>/20?ooo`030000003oool0oooo00<0oooo
000O0?ooo`800000:03oool=0:O0j`@0Y[o/102O_^h2076]mP<0QYgR103A/KT20=>b^@80fK2_103K
/:`30=nd[0040=R`/03R^jl0h[^_0>:k[`80k<N_0`3^c;800`3Zb[D0c/;?0<k2c`040<Bjd0<0WZ[O
102L[n@40:6diP@0XkKV102W^nP40:NjiP@0Y[o[102X`>/50:Jjj0@0Y[cY102X^nL40:Nji`@0YkoZ
102X_^T50:Jkj0@0Y[cY102V^>H40:BgiP@0XkOV1@2O/>@309NYh`<0SJ7Q1028Wn<30;GRmP80_OW/
0P2mk_<30;KIlP80ZlK]102X`^`H0:O0j`030000002W`>/0Yl3[0100Yl3[00<0oooo0000003oool0
103oool00240oooo00<000000?ooo`3oool09P3oool=0:O0j`@0Y/3/102O_^h2076]mP<0LiWX0`3A
/KT30=>b^@030=V`[`3K/:`0fk2/0080fk2/0`3O]:`30>:k[`<0k<N_0P3^c;830>[:]@D0a;[@102R
[=h409b_i0<0XKCV1@2U^NP40:Nkj0@0YKcY102V_n/40:JiiP@0Y[[X1@2X_>P40:Rki`P0YkoZ102V
^^L40:Jkj0D0Yk[W102V^>H40:Fkj@@0XkOV102O/>@309NYh`@0Sj7Q102I]N/20;gik0D0_Nkc1@2[
a^dL0:O0j`030000002W`>/0Yl3[00l0Yl3[00<0oooo0000003oool0103oool00280oooo00<00000
0?ooo`3oool09P3oool=0:O0j`@0Y/3/102P_^h207N`mP80LiWX0P3A/KT40=>b^@@0fk2/103O]:`0
0`3T_:h0h[^_0>:k[`030>c7[`80k/bb0`3Zb[D0103Ta[T0a;[@0<Bjd034^]020<2fd0@0XZcN102Q
/N@30::fiPD0YKWX102U^NL40:Flj@@0YkWV102V^NH40:Rnj@@0Z;cX1@2W_^X40:NojP@0Yk[W102V
^^L40:Nlj0@0Yk[W1@2U_>T40:Fkj@@0WjoS102JZn8309>Sh0@0Sj7Q0P2I]N/0102bjOP0]oW]0;Oi
k@2gnNd50;7Al@D0Z<7/702W`>/00`000000Yl3[0:O0j`0?0:O0j`030000003oool0oooo00<0oooo
000S0?ooo`030000003oool0oooo02H0oooo3@2W`>/40:O0k0@0X;k^0P1g/?H00`0hQ>T0LiWX0=6a
^@040=>b^@040=Bh_@3K/:`0fk2/0=^`[0<0gkB/0`3T_:h30>c7[`80k/bb0`3Zb[D30>C6^@D0`;K@
102X[md40:6ai0<0X[KV1@2V^>H40:Fii`@0Z;_W102W^NH40:RojP@0Z;kY102W_>T40:NnjPD0Yk[V
102W^^L40:Rmj@@0YkcX102U^nP40:Flj@D0X[7S102O[n<309Z[hP@0Tj?P0`2?XN400`2bjOP0]oW]
0;Oik@020;Oik@<0]n?e102Y`n`40:S1k1`0Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo
0?ooo`030?ooo`00903oool2000002L0oooo3@2W`>/40:O0k0@0XKk^0P1l/_H00`0hQ>T0dk:i0=>b
^@020=>b^@80e;Rm0P3K/:`40=nd[0<0i;b^00<0j/J`0>c7[`3/ajl00P3^c;830>[:]@<0i<Ji00@0
g/:l0<2fd030]]00`;K@0P30]Ll40:R_g@<0XK7T102V]nD40:JhiPT0Z;_W102W_^X40:RojP@0Yk_W
102W_>T40:Rji`@0Yk[V1@2W_^X40:Rmj@@0YKWW102U^nP40:Bch`@0X[7S102O[n<309Z[hPD0Tj?P
0P2M_^l30:gdlP<0]n?e0`2/bNl40:W3k200Yl3[00<000000:O0j`2W`>/02`2W`>/30?ooo`030000
003oool0oooo00<0oooo000V0?ooo`030000003oool0oooo02D0oooo4@2W`>/40:6nkP0307bbmP0h
Q>T0>8CY00<0dk:i0`3D^;d0103K/:`0gkB/0=nd[03O]:`30>Bl[P<0j/J`0P3^c;830>[:]@<0i<Ji
0`3N`[`50<2ec`80Z:oM0P2]/M/30:Fdh`@0Y[OU102W^^L40:Rki`D0YkcX102W_^X40:NiiP@0Yk_W
102X_>L40:Rji`P0YkkZ1@2V^>H40:Fii`@0Y[OU102T/n<40:6ah`@0WJSO0`2FX=/409>Sh080[OCb
102flo<50:c9k`D0Z<3[802W`>/00`000000Yl3[0:O0j`060:O0j`P0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool09@3ooolA0:O0j`@0X[k]00@0PK?e000n^00hQ>T0dk:i
103D^;d40=nd[0<0i;b^0`3Za[020>k</0030>o>/03Zb[D0j/Ze0080i<Ji103N`[`00`3J`;l0`;G?
0<2ec`020<2ec`D0[K7K0`2U]><40:Ngi@@0Yk[W102W^^H40:Nlj0D0Z;WV102W^NH40:Vmj0@0Z;cW
102W_NT40:NnjP@0YkSU102V^>H50:Nji`@0Y[OU102S]ND40:6ah`<0WJSO102FX=/30:CJnP<0Y_KZ
1@2`do840:S1k0@0Z<3[802W`>/00`000000Yl3[0:O0j`030:O0j`/0oooo00<000000?ooo`3oool0
0P3oool002P0oooo00<000000?ooo`3oool09P3oool@0:O0j`@0X[k]00<0QKGd000n^03D^;d0103D
^;d00`3C_lL0gkB/0=nd[0030>Bl[P<0j/J`0P3^c;030>o>/080i<Ji103N`[`30=[0_`80`;G?0P31
]Lh40:faf`@0ZKCQ102W]nD40:Rii@@0Yk[V102Y^^H40:RiiPD0ZKkY102Y_NP40:Nlj0@0YkgY202W
^>D40:Nlj0@0Yk[W2@2S]ND30:6ah`<0WJSO1@2I/nX20:KfjP@0/n;g1@2Y`nd40:S1k2@0Yl3[00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00:@3oool2000002L0oooo402W`>/5
0::nk@04000n^03D^;d0e;Rm0=Bh_@<0dko700@0gkB/0>Bl[P3T_:h0i;b^0`3Za[020>k</0<0klj`
00<0k/jc0=k2_03N`[`00P3N`[`40=[0_`D0`KG>102b/mT40:Vdh@@0ZKSS102X^ND40:VkiP@0ZK[V
102X_NT40:Vnj@D0Yk[V0`2W_>P50:Rii@@0YkSU102W_NT40:Nlj0@0Y;CT102S]ND509nRe`<0VYgF
0`2GX=/309VcjP0409[akP2_l?H0[o3f0:o`mP@0ZlO^102Y`ndV0:O0j`<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`0U0?oooa40Yl3[
102S_nd00`00?[P0e;Rm0=>oa`030=>oa`<0i;b^0`3Za[020>k</0<0klj`0P3^c[<00`3[c[P0g/:l
0=k2_0040=[0_`80eko20`31]Lh20<>fc@@0/[?I102]]Ml40:Vhh`@0ZK[U102Y^nH40:Rki`@0Z;gY
102X^>D40:NjiP@0ZK[V102X^ND90:Nmj@@0YK?R102T]>@40:BYf`@0Wj;G102JWMH309NPf`0309[a
kP2_l?H0[o3f00@0[Lka102[anhU0:O0j`P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?oooa40Yl3[102S_nd40=>oa`80c/WE0P3T
_:h30>[6/080k/b`0`3_c[020>k>/`80jljh103J`;l30=No`P80`KG>0`33]/d20;:cf@<0][?G102]
]Ml40:^ghP@0ZK[U102Y^ND40:Rki`@0ZKST102X^>D40:Vli`@0ZK[V102W_>P40:Nmj@D0Y[?Q102U
/n840:J`g`@0Y:WK0`2OX]L409ZMeP<0Vn?m00@0W_?/0:kGm@2^eoD0[]Oe102]c_440:S0jb40Yl3[
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000]0?ooo`030000003o
ool0oooo02H0oooo402W`>/40:Bok@80dko7103>bMD30>[6/080k/b`0`3_c[020>k>/`<0jljh00<0
ilnn0=[0_`3J`;l0103G_l850<>fc@D0][?G1@2`]=`30:^ghPD0ZkSR102Y^ND40:^ii0@0ZKST102Z
_NL40:Vli`D0Yk[V0`2W_>P40:Nch@@0Y[?Q1@2W]>830:J`g`@0Y:WK0`2OX]L509_5m@0309kck02^
eoD0[]Oe00<0[]Oe1@2X`N`30:S0jah0Yl3[3`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0040oooo000^0?ooo`030000003oool0oooo02H0oooo402W`>/40:Bok@@0c/WE0P3:d^02
0>[6/080k/b`0`3_c[020>k>/`80jljh0`3Wckh50=No`P040=C0aP33]/d0`kK=0<>fc@80a;O=0`2f
/mL20;Vce0@0/;CL102^]]l40:^hhPD0[;[T102[^N@40:Vli`@0Z[gW102X]n@30:NjiP80ZKKR0`2X
]>440:Nch@@0YkOT102W]>830:J`g`D0W:;H102K[N@00`25jml0[Moi0:gOn@030:gOn@@0ZLC]102X
`N`M0:O0ja@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00;`3oool2
000002L0oooo402W`>/40:Bok080c/WE103:d^020>k</0<0klj`0P3^c[<30>_>^0<0ilnn00@0h]77
0=No`P3G_l80eko20`3D`<H50<Bgc@D0^K?D102c/mT40:jfg`@0[KOQ102/^^@50:Zii0<0ZKcW1@2X
]N840:Rgi0@0ZKKR102X]>480:Ngi0@0XIc@0`2OWM8409bRf080MnCM1@2Xj?X40:[7k`@0ZLC]102W
`>/50:Noja@0Yl3[603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo02D0oooo402W`>/40:Bok0@0b];P0P3=g>@30=;Ui0<0k/jc0P3[c[P3
0>O?_P<0h]7700<0eko20=C0aP3D`<H00P3D`<H0103B`l/0a;O=0<Bgc@34]ld20<JhcP<0^K?D0P2l
]=440;>cf@@0/;?K102]]n440:^eh0@0Z[WT102Z]>040:RehPD0ZkOR0`2Y]^850:RehP@0YkOT102S
W<h40:6Ld0<0WigB101ii>/209g]n0D0Z/_a102W_n/80:O0j`@0Yko[402W`>/L0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3oool09@3oool@
0:O0j`D0YKo/0`3=g>@30=;Ui0<0dn_U0`3[c[P30>O?_P<0h]77103D`<H30=;3b`030<Bgc@36^<h0
a[S>0080a[S>1@2l]=420;>cf@80][;D102`/m/40:nbf`@0ZkGP102/]=h40:Zdh0@0ZkSR102[]n84
0:RagP@0Z;GR1@2UWLh40:>LcP<0XIc@1@25hoT00`2MkOP0ZLgc0:W=l`030:W=l`P0Yko[102X`>/D
0:O0jb00oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`00<`3oool00`00
0000oooo0?ooo`0U0?oooa40Yl3[102V_n`0102L_O00d^GT0=;Ui03BiN@30=?[i@<0c^kZ0`3Wckh3
0>;Aa`80fmKC0P3D`<H40=;3b`@0a[S>0P36_M440;bdd@D0][;D0P2`/m/20;>aeP@0[k;K102_/m/4
0:bdgP@0[;GO102[^>840:R[f@@0Z;7N102WWlh40:FMcP@0Xic>102@h?h208c[l@D0Z<od102X`>/4
0:Noj`@0Z<7/102X`>/@0:O0jb@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`01
0?ooo`00=03oool2000002H0oooo4@2W`>/40:Jok080X;k^0P3CjnD40<k^jP<0_^oc0`3RdLL40=_F
d`@0d/?;0P3?bM@20<JhcP@0a[gA0P2l]=420;ngdP@0][;D1@2c/MH40;6`e`@0[k?K102/[mT40:be
g`@0ZJKD102XZmT40:VRc`@0Yio>0`2UWLh509OMoP80N^CX102Wd?H50:S1k0<0Z<3[1@2W`N`30:S1
k0D0Yko[0`2W`>/50:Noj`<0Yl3[:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0040oooo000f0?ooo`030000003oool0oooo02D0oooo402W`>/40:K0k0@0X;k^00<0P[Og0;k_l`2n
ko<01@2MjO/40=_Fd`80cmkS0P3B`l/40<o9e0D0a[gA1@2o]m840;Zcd`<0/k7F0P2f/M@40;6`e`@0
[j_D102/[mT40:bUd0@0ZJKD102]ZM<40:VRc`<0Yio>1@2Ig_h00`1[gN40YM7g0:GAm`030:GAm`@0
Z<;]102X`N`80:O1k100Yko[;03oool00`000000oooo0?ooo`070?ooo`4000000@3oool10?ooo`00
=`3oool00`000000oooo0?ooo`0U0?oooa00Yl3[0`2V`>`50:Bok@<0Tkcc0`1?YOP306?AmPD0cmkS
103?bM@20<SFi@<0a[gA0P35bMd30;ngdP80`L;K102j/m<40;Jae080/K3G0`2e/MD30:n[e0D0/J_B
102/YM020:VVe080/KKL102]ZM<30:VRc`D0U^;m00<0HMON0:C@m`2Td?L00`2Td?L40:O3k@@0Z<;]
102W`>`40:O1k0@0YkoZ102W_n/50:S0j`<0Yko[<03oool00`000000oooo0?ooo`060?ooo`400000
0@3oool10?ooo`00>03oool00`000000oooo0?ooo`0U0?oooa<0Yl3[102T_nd409fnk`@0NkOi00<0
4hcV001b/P00L[801@2bi_P50<SFi@D0aLWM1031`]/20;Zcd`<0_L3L0`2f/M@50;Fae@80[j_D0P2h
_Mh40;6[dP@0[:G@102a]]`40:fYd`@0RNGi0P1MeN450:;?m`P0Yl?]102W_n/40:O0k0@0Z;oZ102W
_nX40:S1k3P0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool003T0oooo0P00000V
0?oooa<0Yl3[1@2V_n`309fnk`D0U;gc0`1O/?/406CAm`D0YNCk0P35bMd30;COmP<0`L;K1@2m`=`2
0;Jae080^lKR102e/MD50;RmgP<0/J_B1@2dc>/30;6fg080K]gY1@1/eoD40:;=mPD0Yl;]0`2W`nd8
0:Noj`D0Z;o[0`2X_nX50:O1k3/0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool0
03/0oooo00<000000?ooo`3oool0903ooolH0:O0j`@0Xko]102P_nl408^lm`<0Bjgi00@008W?0:GT
n`2Ui?/0YNCk1@2dgoH40;CNm@@0_L3L1@2ka^840;CLm0@0^;gN1@2UiO/30;C<j`80BLW@00<0;kO2
0:;8l`2Rb?<00`2Rb?<30:;;m@@0Y/7/102W`^d80:Noj`D0Z<3[102W`>`40:O1k3l0oooo00<00000
0?ooo`3oool0103oool100000040oooo0@3oool003`0oooo00<000000?ooo`3oool0903ooolH0:O0
j`@0Y/3/102P_nl409jol0@0Q[gh0`17[oP00`08U]80C/W[04k9j`0304k9j`<0]=ke1@2Wi?/507GN
l`<0]=cd1@1VfNP00`0_^=40C<G_097>o003097>o0@0XlGa102Rb?<40:K0k0@0Y/7/1@2W_n/80:O1
k0@0Yl3[102W`>a30?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`40oooo000m0?ooo`03
0000003oool0oooo02@0oooo602W`>/40:K0k0@0YKo/2@2N_o0308Rnn@@0T<3g101[_oh3032`j@@0
Gl;m1@2;ao`409o4lP@0VLSg102T`^l40:?5l@D0Yko[0`2V`>`50:S0j`@0Yl3/0`2W`N`50:Noj`<0
Yl3[B03oool00`000000oooo0?ooo`020?ooo`4000000@3oool10?ooo`00?P3oool2000002D0oooo
7@2W`>/80:Fok0@0YL3/0`2O`>l40:?0kP@0V/7c102Q`Nl409W3m0@0Xl7_102Oa?850:G0k@<0Y<;_
1@2W_n/40:O1k0<0Z<7/1@2W`>/30:O0k0P0Yko[B`3oool00`000000oooo0?ooo`030?ooo`400000
0@3oool00400oooo00<000000?ooo`3oool08`3ooolU0:O0j`<0YL3/102V`>`40:?0kP@0YL3]102Q
`Nl50:G0k@<0Xl7_1@2V`>`70:O0j`P0Yl7/102W_n/40:O0j`P0Yko[C`3oool00`000000oooo0?oo
o`020?ooo`4000000@3oool00440oooo00<000000?ooo`3oool08`3ooolX0:O0j`@0Y/3/102W`>`4
0:G0k@D0Yl3/3`2W`>/40:O0k0@0Yl7/202W_n/40:S0j`@0Yko[D`3oool01@000000oooo0?ooo`3o
ool000000040oooo00120?ooo`030000003oool0oooo02@0oooo;02W`>/30:O0k1P0Yl3[102W`>`4
0:NojP@0Yko[1@2X`N`30:S0jeL0oooo00@000000?ooo`3oool000000@3oool004<0oooo0P00000U
0?ooodL0Yl3[102X_n/40:NojP@0Yl7/GP3oool010000000oooo0?ooo`0000010?ooo`00A@3oool0
0`000000oooo0?ooo`0S0?oood<0Yl3[1@2X`>/30:Roj`@0Yl7/HP3oool00`000000oooo00000001
0?ooo`00AP3oool00`000000oooo0?ooo`0S0?ooodP0Yl3[0`2W`>aV0?ooo`4000000@3oool10000
0000A`3oool00`000000oooo0?ooo`0S0?ooocl0Yl3[102W_n/40:O0jfX0oooo0P00000004P0oooo
0P00000U0?oooch0Yl3[102W_n]]0?ooo`800000001:0?ooo`030000003oool0oooo02<0oooo?P2W
`>]`0?ooo`800000001;0?ooo`030000003oool0oooo0280oooo>`2W`>]_0?ooo`@000000P3oool0
04`0oooo00<000000?ooo`3oool08`3ooolc0:O0jg40oooo100000060?ooo`00C@3oool2000002@0
oooo;`2W`>]`0?ooo`@000002P3oool004l0oooo00<000000?ooo`3oool08P3oool[0:O0jfl0oooo
1000000>0?ooo`00D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo001A
0?ooo`030000003oool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580oooo0P00000T0?oo
oah0Yl3[K@3oool4000001T0oooo001D0?ooo`030000003oool0oooo0280oooo5`2W`>]_0?ooo`@0
00007@3oool005D0oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00EP3o
ool00`000000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?ooo`8000008`3oool;
0:O0jf`0oooo1000000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool30000
02d0oooo001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool400000300
oooo001K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0oooo
001L0?ooo`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool005h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00000L0?ooo`030000
003oool0oooo05<0oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo04/0oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
04L0oooo1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0
oooo1000001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03oool3000005/0oooo
001Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4000005h0oooo001Z
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?ooo`80
0000403oool00`000000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`030000003oool0oooo
0280oooo1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0
oooo1000001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
100000210?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo1000
00250?ooo`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`050000
003oool0oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003oool0
103oool4000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3oool2
00000:00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.51621 .66199 .52232 .66784 .53355 .66467 .52747 .65879 Mtetra
.656 .752 .92 r
.52747 .65879 .53355 .66467 .54483 .6615 .53878 .65559 Mtetra
.656 .751 .92 r
.53878 .65559 .54483 .6615 .55616 .65831 .55014 .65237 Mtetra
.55014 .65237 .55616 .65831 .56753 .65509 .56155 .64914 Mtetra
.655 .751 .921 r
.56155 .64914 .56753 .65509 .57895 .65185 .573 .64592 Mtetra
.656 .753 .922 r
.573 .64592 .57895 .65185 .59042 .64861 .5845 .64266 Mtetra
.657 .753 .921 r
.5845 .64266 .59042 .64861 .60194 .64541 .59604 .63936 Mtetra
.657 .751 .919 r
.59604 .63936 .60194 .64541 .6135 .64219 .60764 .63603 Mtetra
.657 .748 .917 r
.60764 .63603 .6135 .64219 .62511 .63895 .61928 .6327 Mtetra
.656 .746 .916 r
.61928 .6327 .62511 .63895 .63677 .63566 .63097 .62938 Mtetra
.63097 .62938 .63677 .63566 .64848 .63234 .64271 .62607 Mtetra
.656 .746 .917 r
.64271 .62607 .64848 .63234 .66024 .62901 .6545 .62274 Mtetra
.656 .748 .918 r
.6545 .62274 .66024 .62901 .67204 .62568 .66634 .6194 Mtetra
.66634 .6194 .67204 .62568 .6839 .62234 .67823 .61603 Mtetra
.657 .748 .917 r
.67823 .61603 .6839 .62234 .69581 .61901 .69017 .61263 Mtetra
.657 .747 .916 r
.69017 .61263 .69581 .61901 .70776 .61566 .70216 .60921 Mtetra
.656 .746 .916 r
.70216 .60921 .70776 .61566 .71977 .61229 .7142 .6058 Mtetra
.656 .745 .915 r
.7142 .6058 .71977 .61229 .73183 .60885 .7263 .60238 Mtetra
.655 .746 .916 r
.7263 .60238 .73183 .60885 .74393 .60539 .73844 .59896 Mtetra
.654 .748 .919 r
.73844 .59896 .74393 .60539 .75609 .60191 .75064 .59557 Mtetra
.655 .752 .921 r
.75064 .59557 .75609 .60191 .7683 .59844 .76289 .59213 Mtetra
.656 .754 .922 r
.76289 .59213 .7683 .59844 .78056 .595 .77519 .58864 Mtetra
.656 .753 .921 r
.77519 .58864 .78056 .595 .79288 .59157 .78755 .58512 Mtetra
.656 .751 .92 r
.78755 .58512 .79288 .59157 .80525 .58809 .79995 .5816 Mtetra
.79995 .5816 .80525 .58809 .81767 .58458 .81241 .57807 Mtetra
.81241 .57807 .81767 .58458 .83015 .58105 .82493 .57452 Mtetra
.656 .752 .92 r
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Mtetra
.656 .751 .92 r
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.656 .752 .92 r
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Mtetra
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Mtetra
.656 .751 .92 r
.55551 .64314 .56155 .64914 .573 .64592 .567 .63985 Mtetra
.656 .75 .919 r
.567 .63985 .573 .64592 .5845 .64266 .57853 .63656 Mtetra
.655 .75 .919 r
.57853 .63656 .5845 .64266 .59604 .63936 .59011 .6333 Mtetra
.654 .751 .921 r
.59011 .6333 .59604 .63936 .60764 .63603 .60174 .63004 Mtetra
.654 .755 .924 r
.60174 .63004 .60764 .63603 .61928 .6327 .61341 .62675 Mtetra
.655 .757 .925 r
.61341 .62675 .61928 .6327 .63097 .62938 .62514 .62341 Mtetra
.656 .758 .925 r
.62514 .62341 .63097 .62938 .64271 .62607 .63691 .62005 Mtetra
.656 .757 .924 r
.63691 .62005 .64271 .62607 .6545 .62274 .64874 .61666 Mtetra
.656 .755 .923 r
.64874 .61666 .6545 .62274 .66634 .6194 .66061 .61327 Mtetra
.655 .755 .923 r
.66061 .61327 .66634 .6194 .67823 .61603 .67253 .60988 Mtetra
.67253 .60988 .67823 .61603 .69017 .61263 .68451 .60649 Mtetra
.655 .756 .924 r
.68451 .60649 .69017 .61263 .70216 .60921 .69654 .60309 Mtetra
.655 .757 .925 r
.69654 .60309 .70216 .60921 .7142 .6058 .70861 .59965 Mtetra
.656 .758 .925 r
.70861 .59965 .7142 .6058 .7263 .60238 .72074 .59618 Mtetra
.656 .757 .924 r
.72074 .59618 .7263 .60238 .73844 .59896 .73292 .59268 Mtetra
.657 .755 .922 r
.73292 .59268 .73844 .59896 .75064 .59557 .74515 .58914 Mtetra
.657 .751 .92 r
.74515 .58914 .75064 .59557 .76289 .59213 .75743 .58562 Mtetra
.656 .749 .919 r
.75743 .58562 .76289 .59213 .77519 .58864 .76977 .58212 Mtetra
.655 .75 .919 r
.76977 .58212 .77519 .58864 .78755 .58512 .78217 .57862 Mtetra
.656 .751 .92 r
.78217 .57862 .78755 .58512 .79995 .5816 .79461 .57508 Mtetra
.656 .752 .921 r
.79461 .57508 .79995 .5816 .81241 .57807 .80711 .57151 Mtetra
.656 .752 .92 r
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Mtetra
.656 .751 .92 r
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Mtetra
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54248 Mtetra
.90908 .54248 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94825 .53132 Mtetra
.94825 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Mtetra
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Mtetra
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .6371 Mtetra
.655 .751 .921 r
.54943 .6371 .55551 .64314 .567 .63985 .56095 .63382 Mtetra
.655 .753 .921 r
.56095 .63382 .567 .63985 .57853 .63656 .57251 .63052 Mtetra
.656 .753 .921 r
.57251 .63052 .57853 .63656 .59011 .6333 .58412 .62718 Mtetra
.657 .752 .92 r
.58412 .62718 .59011 .6333 .60174 .63004 .59578 .6238 Mtetra
.657 .749 .918 r
.59578 .6238 .60174 .63004 .61341 .62675 .60749 .62043 Mtetra
.656 .747 .917 r
.60749 .62043 .61341 .62675 .62514 .62341 .61925 .61708 Mtetra
.655 .747 .918 r
.61925 .61708 .62514 .62341 .63691 .62005 .63106 .61375 Mtetra
.654 .749 .919 r
.63106 .61375 .63691 .62005 .64874 .61666 .64292 .6104 Mtetra
.655 .751 .92 r
.64292 .6104 .64874 .61666 .66061 .61327 .65483 .60702 Mtetra
.656 .752 .921 r
.65483 .60702 .66061 .61327 .67253 .60988 .66679 .6036 Mtetra
.657 .752 .92 r
.66679 .6036 .67253 .60988 .68451 .60649 .67879 .60013 Mtetra
.657 .751 .919 r
.67879 .60013 .68451 .60649 .69654 .60309 .69085 .59663 Mtetra
.657 .749 .917 r
.69085 .59663 .69654 .60309 .70861 .59965 .70296 .59313 Mtetra
.657 .747 .917 r
.70296 .59313 .70861 .59965 .72074 .59618 .71513 .58964 Mtetra
.655 .747 .917 r
.71513 .58964 .72074 .59618 .73292 .59268 .72735 .58616 Mtetra
.654 .748 .919 r
.72735 .58616 .73292 .59268 .74515 .58914 .73962 .5827 Mtetra
.655 .752 .921 r
.73962 .5827 .74515 .58914 .75743 .58562 .75194 .57919 Mtetra
.656 .754 .922 r
.75194 .57919 .75743 .58562 .76977 .58212 .76432 .57564 Mtetra
.656 .753 .921 r
.76432 .57564 .76977 .58212 .78217 .57862 .77674 .57206 Mtetra
.656 .751 .92 r
.77674 .57206 .78217 .57862 .79461 .57508 .78922 .56849 Mtetra
.78922 .56849 .79461 .57508 .80711 .57151 .80176 .5649 Mtetra
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Mtetra
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Mtetra
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54248 .90406 .53563 Mtetra
.90406 .53563 .90908 .54248 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94825 .53132 .94336 .52438 Mtetra
.94336 .52438 .94825 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Mtetra
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Mtetra
.655 .751 .92 r
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63432 Mtetra
.655 .752 .921 r
.53181 .63432 .53797 .64037 .54943 .6371 .54331 .63102 Mtetra
.54331 .63102 .54943 .6371 .56095 .63382 .55486 .62771 Mtetra
.654 .751 .921 r
.55486 .62771 .56095 .63382 .57251 .63052 .56645 .62443 Mtetra
.65 .751 .924 r
.56645 .62443 .57251 .63052 .58412 .62718 .5781 .62124 Mtetra
.646 .756 .929 r
.5781 .62124 .58412 .62718 .59578 .6238 .5898 .61812 Mtetra
.643 .765 .937 r
.5898 .61812 .59578 .6238 .60749 .62043 .60154 .61502 Mtetra
.641 .775 .945 r
.60154 .61502 .60749 .62043 .61925 .61708 .61335 .6119 Mtetra
.641 .784 .95 r
.61335 .6119 .61925 .61708 .63106 .61375 .6252 .60873 Mtetra
.642 .791 .954 r
.6252 .60873 .63106 .61375 .64292 .6104 .6371 .60548 Mtetra
.644 .797 .956 r
.6371 .60548 .64292 .6104 .65483 .60702 .64905 .60214 Mtetra
.647 .8 .956 r
.64905 .60214 .65483 .60702 .66679 .6036 .66105 .59869 Mtetra
.65 .801 .955 r
.66105 .59869 .66679 .6036 .67879 .60013 .6731 .59514 Mtetra
.654 .8 .953 r
.6731 .59514 .67879 .60013 .69085 .59663 .68519 .5915 Mtetra
.658 .797 .949 r
.68519 .5915 .69085 .59663 .70296 .59313 .69733 .58777 Mtetra
.661 .79 .944 r
.69733 .58777 .70296 .59313 .71513 .58964 .70952 .58399 Mtetra
.662 .781 .937 r
.70952 .58399 .71513 .58964 .72735 .58616 .72176 .58018 Mtetra
.662 .771 .93 r
.72176 .58018 .72735 .58616 .73962 .5827 .73405 .5764 Mtetra
.66 .76 .924 r
.73405 .5764 .73962 .5827 .75194 .57919 .7464 .57269 Mtetra
.657 .754 .921 r
.7464 .57269 .75194 .57919 .76432 .57564 .75881 .56907 Mtetra
.656 .752 .92 r
.75881 .56907 .76432 .57564 .77674 .57206 .77128 .56548 Mtetra
.656 .752 .921 r
.77128 .56548 .77674 .57206 .78922 .56849 .7838 .56186 Mtetra
.656 .752 .92 r
.7838 .56186 .78922 .56849 .80176 .5649 .79637 .55823 Mtetra
.656 .751 .92 r
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Mtetra
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Mtetra
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Mtetra
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .63811 Mtetra
.4913 .63811 .4976 .64414 .50896 .64088 .50269 .63482 Mtetra
.655 .751 .921 r
.50269 .63482 .50896 .64088 .52036 .6376 .51412 .63154 Mtetra
.654 .752 .922 r
.51412 .63154 .52036 .6376 .53181 .63432 .52561 .62828 Mtetra
.65 .752 .924 r
.52561 .62828 .53181 .63432 .54331 .63102 .53714 .62511 Mtetra
.642 .755 .931 r
.53714 .62511 .54331 .63102 .55486 .62771 .54872 .62212 Mtetra
.631 .764 .943 r
.54872 .62212 .55486 .62771 .56645 .62443 .56035 .61933 Mtetra
.617 .778 .958 r
.56035 .61933 .56645 .62443 .5781 .62124 .57204 .61672 Mtetra
.6 .796 .975 r
.57204 .61672 .5781 .62124 .5898 .61812 .58379 .61425 Mtetra
.578 .815 .989 r
.58379 .61425 .5898 .61812 .60154 .61502 .5956 .61187 Mtetra
.552 .836 .998 r
.5956 .61187 .60154 .61502 .61335 .6119 .60746 .60946 Mtetra
.526 .854 .997 r
.60746 .60946 .61335 .6119 .6252 .60873 .61938 .60691 Mtetra
.505 .867 .986 r
.61938 .60691 .6252 .60873 .6371 .60548 .63134 .60411 Mtetra
.496 .877 .972 r
.63134 .60411 .6371 .60548 .64905 .60214 .64335 .60098 Mtetra
.506 .888 .965 r
.64335 .60098 .64905 .60214 .66105 .59869 .65541 .59751 Mtetra
.533 .9 .967 r
.65541 .59751 .66105 .59869 .6731 .59514 .6675 .5937 Mtetra
.573 .909 .975 r
.6675 .5937 .6731 .59514 .68519 .5915 .67962 .58956 Mtetra
.614 .908 .983 r
.67962 .58956 .68519 .5915 .69733 .58777 .69179 .58517 Mtetra
.647 .896 .983 r
.69179 .58517 .69733 .58777 .70952 .58399 .70399 .58063 Mtetra
.666 .873 .976 r
.70399 .58063 .70952 .58399 .72176 .58018 .71623 .57606 Mtetra
.674 .845 .965 r
.71623 .57606 .72176 .58018 .73405 .5764 .72853 .57157 Mtetra
.675 .819 .953 r
.72853 .57157 .73405 .5764 .7464 .57269 .74089 .56721 Mtetra
.672 .795 .941 r
.74089 .56721 .7464 .57269 .75881 .56907 .7533 .56302 Mtetra
.666 .774 .93 r
.7533 .56302 .75881 .56907 .77128 .56548 .76578 .55905 Mtetra
.661 .761 .924 r
.76578 .55905 .77128 .56548 .7838 .56186 .77833 .55525 Mtetra
.658 .754 .921 r
.77833 .55525 .7838 .56186 .79637 .55823 .79094 .55154 Mtetra
.656 .752 .921 r
.79094 .55154 .79637 .55823 .809 .5546 .80361 .54786 Mtetra
.656 .752 .92 r
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Mtetra
.656 .751 .92 r
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Mtetra
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Mtetra
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Mtetra
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63533 Mtetra
.655 .751 .921 r
.47359 .63533 .47997 .64138 .4913 .63811 .48496 .63204 Mtetra
.653 .751 .922 r
.48496 .63204 .4913 .63811 .50269 .63482 .49637 .6288 Mtetra
.648 .752 .925 r
.49637 .6288 .50269 .63482 .51412 .63154 .50784 .62568 Mtetra
.635 .755 .934 r
.50784 .62568 .51412 .63154 .52561 .62828 .51935 .62286 Mtetra
.611 .764 .952 r
.51935 .62286 .52561 .62828 .53714 .62511 .53092 .62048 Mtetra
.57 .781 .978 r
.53092 .62048 .53714 .62511 .54872 .62212 .54254 .61862 Mtetra
.501 .801 .999 r
.54254 .61862 .54872 .62212 .56035 .61933 .55423 .61718 Mtetra
.395 .803 .98 r
.55423 .61718 .56035 .61933 .57204 .61672 .56598 .61593 Mtetra
.276 .77 .896 r
.56598 .61593 .57204 .61672 .58379 .61425 .5778 .61449 Mtetra
.209 .735 .803 r
.5778 .61449 .58379 .61425 .5956 .61187 .58966 .61254 Mtetra
.223 .744 .776 r
.58966 .61254 .5956 .61187 .60746 .60946 .60158 .60999 Mtetra
.296 .793 .817 r
.60158 .60999 .60746 .60946 .61938 .60691 .61354 .60695 Mtetra
.383 .844 .88 r
.61354 .60695 .61938 .60691 .63134 .60411 .62555 .6036 Mtetra
.448 .873 .927 r
.62555 .6036 .63134 .60411 .64335 .60098 .6376 .60014 Mtetra
.478 .882 .948 r
.6376 .60014 .64335 .60098 .65541 .59751 .64971 .59666 Mtetra
.478 .883 .948 r
.64971 .59666 .65541 .59751 .6675 .5937 .66187 .59315 Mtetra
.457 .878 .928 r
.66187 .59315 .6675 .5937 .67962 .58956 .67408 .58953 Mtetra
.432 .871 .891 r
.67408 .58953 .67962 .58956 .69179 .58517 .68633 .58559 Mtetra
.427 .871 .858 r
.68633 .58559 .69179 .58517 .70399 .58063 .6986 .58115 Mtetra
.469 .893 .858 r
.6986 .58115 .70399 .58063 .71623 .57606 .71089 .57609 Mtetra
.555 .931 .902 r
.71089 .57609 .71623 .57606 .72853 .57157 .72319 .5705 Mtetra
.643 .946 .954 r
.72319 .5705 .72853 .57157 .74089 .56721 .73551 .56472 Mtetra
.688 .916 .972 r
.73551 .56472 .74089 .56721 .7533 .56302 .74789 .55911 Mtetra
.694 .864 .963 r
.74789 .55911 .7533 .56302 .76578 .55905 .76034 .55393 Mtetra
.684 .816 .946 r
.76034 .55393 .76578 .55905 .77833 .55525 .77287 .54927 Mtetra
.671 .782 .933 r
.77287 .54927 .77833 .55525 .79094 .55154 .78549 .54506 Mtetra
.662 .763 .925 r
.78549 .54506 .79094 .55154 .80361 .54786 .79818 .54115 Mtetra
.658 .755 .922 r
.79818 .54115 .80361 .54786 .81634 .54418 .81094 .53737 Mtetra
.656 .752 .921 r
.81094 .53737 .81634 .54418 .82912 .54048 .82376 .53363 Mtetra
.656 .752 .92 r
.82376 .53363 .82912 .54048 .84196 .53677 .83664 .52988 Mtetra
.656 .751 .92 r
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Mtetra
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Mtetra
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Mtetra
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63254 Mtetra
.654 .751 .921 r
.45581 .63254 .46227 .63861 .47359 .63533 .46716 .62926 Mtetra
.65 .751 .924 r
.46716 .62926 .47359 .63533 .48496 .63204 .47856 .6261 Mtetra
.636 .752 .932 r
.47856 .6261 .48496 .63204 .49637 .6288 .49 .62326 Mtetra
.605 .757 .951 r
.49 .62326 .49637 .6288 .50784 .62568 .50149 .62104 Mtetra
.541 .77 .982 r
.50149 .62104 .50784 .62568 .51935 .62286 .51304 .61967 Mtetra
.417 .776 .995 r
.51304 .61967 .51935 .62286 .53092 .62048 .52464 .61901 Mtetra
.248 .739 .918 r
.52464 .61901 .53092 .62048 .54254 .61862 .53632 .61847 Mtetra
.181 .714 .818 r
.53632 .61847 .54254 .61862 .55423 .61718 .54806 .61719 Mtetra
.322 .808 .868 r
.54806 .61719 .55423 .61718 .56598 .61593 .55985 .61457 Mtetra
.566 .904 .978 r
.55985 .61457 .56598 .61593 .5778 .61449 .57167 .61069 Mtetra
.684 .851 .963 r
.57167 .61069 .5778 .61449 .58966 .61254 .58354 .60607 Mtetra
.696 .76 .902 r
.58354 .60607 .58966 .61254 .60158 .60999 .59544 .60131 Mtetra
.682 .698 .858 r
.59544 .60131 .60158 .60999 .61354 .60695 .60739 .59675 Mtetra
.668 .662 .834 r
.60739 .59675 .61354 .60695 .62555 .6036 .6194 .59254 Mtetra
.657 .642 .823 r
.6194 .59254 .62555 .6036 .6376 .60014 .63146 .58868 Mtetra
.649 .632 .82 r
.63146 .58868 .6376 .60014 .64971 .59666 .64359 .58516 Mtetra
.641 .628 .822 r
.64359 .58516 .64971 .59666 .66187 .59315 .65578 .58199 Mtetra
.633 .631 .83 r
.65578 .58199 .66187 .59315 .67408 .58953 .66804 .57918 Mtetra
.625 .643 .848 r
.66804 .57918 .67408 .58953 .68633 .58559 .68038 .57672 Mtetra
.618 .673 .881 r
.68038 .57672 .68633 .58559 .6986 .58115 .69279 .57447 Mtetra
.613 .735 .932 r
.69279 .57447 .6986 .58115 .71089 .57609 .70526 .57205 Mtetra
.606 .831 .986 r
.70526 .57205 .71089 .57609 .72319 .5705 .71775 .5689 Mtetra
.585 .913 .975 r
.71775 .5689 .72319 .5705 .73551 .56472 .73022 .56445 Mtetra
.586 .942 .918 r
.73022 .56445 .73551 .56472 .74789 .55911 .74265 .55864 Mtetra
.647 .961 .925 r
.74265 .55864 .74789 .55911 .76034 .55393 .75507 .55205 Mtetra
.704 .944 .959 r
.75507 .55205 .76034 .55393 .77287 .54927 .76753 .54557 Mtetra
.71 .88 .96 r
.76753 .54557 .77287 .54927 .78549 .54506 .78008 .53982 Mtetra
.689 .817 .944 r
.78008 .53982 .78549 .54506 .79818 .54115 .79275 .53493 Mtetra
.671 .778 .93 r
.79275 .53493 .79818 .54115 .81094 .53737 .80551 .53068 Mtetra
.661 .76 .923 r
.80551 .53068 .81094 .53737 .82376 .53363 .81836 .52676 Mtetra
.657 .753 .921 r
.81836 .52676 .82376 .53363 .83664 .52988 .83128 .52294 Mtetra
.656 .752 .92 r
.83128 .52294 .83664 .52988 .84958 .52612 .84426 .51914 Mtetra
.656 .751 .92 r
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Mtetra
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Mtetra
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Mtetra
.655 .751 .92 r
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62974 Mtetra
.653 .751 .922 r
.43797 .62974 .44451 .63583 .45581 .63254 .4493 .62648 Mtetra
.645 .751 .926 r
.4493 .62648 .45581 .63254 .46716 .62926 .46068 .62343 Mtetra
.621 .752 .94 r
.46068 .62343 .46716 .62926 .47856 .6261 .4721 .62093 Mtetra
.56 .757 .97 r
.4721 .62093 .47856 .6261 .49 .62326 .48356 .61945 Mtetra
.426 .756 .995 r
.48356 .61945 .49 .62326 .50149 .62104 .49507 .61912 Mtetra
.22 .711 .923 r
.49507 .61912 .50149 .62104 .51304 .61967 .50665 .61921 Mtetra
.174 .707 .835 r
.50665 .61921 .51304 .61967 .52464 .61901 .5183 .61829 Mtetra
.442 .864 .943 r
.5183 .61829 .52464 .61901 .53632 .61847 .53002 .61532 Mtetra
.687 .874 .969 r
.53002 .61532 .53632 .61847 .54806 .61719 .54178 .61048 Mtetra
.717 .757 .884 r
.54178 .61048 .54806 .61719 .55985 .61457 .55357 .6049 Mtetra
.694 .68 .833 r
.55357 .6049 .55985 .61457 .57167 .61069 .56541 .5996 Mtetra
.674 .647 .816 r
.56541 .5996 .57167 .61069 .58354 .60607 .57729 .59496 Mtetra
.662 .642 .82 r
.57729 .59496 .58354 .60607 .59544 .60131 .58923 .59087 Mtetra
.657 .653 .834 r
.58923 .59087 .59544 .60131 .60739 .59675 .60122 .58711 Mtetra
.656 .669 .851 r
.60122 .58711 .60739 .59675 .6194 .59254 .61327 .58349 Mtetra
.656 .682 .863 r
.61327 .58349 .6194 .59254 .63146 .58868 .62537 .57993 Mtetra
.655 .69 .87 r
.62537 .57993 .63146 .58868 .64359 .58516 .63752 .57639 Mtetra
.654 .69 .871 r
.63752 .57639 .64359 .58516 .65578 .58199 .64973 .57287 Mtetra
.652 .681 .865 r
.64973 .57287 .65578 .58199 .66804 .57918 .66199 .5694 Mtetra
.647 .666 .854 r
.66199 .5694 .66804 .57918 .68038 .57672 .67431 .56607 Mtetra
.637 .645 .841 r
.67431 .56607 .68038 .57672 .69279 .57447 .68671 .56307 Mtetra
.623 .625 .832 r
.68671 .56307 .69279 .57447 .70526 .57205 .6992 .56064 Mtetra
.606 .617 .836 r
.6992 .56064 .70526 .57205 .71775 .5689 .71178 .55886 Mtetra
.596 .64 .865 r
.71178 .55886 .71775 .5689 .73022 .56445 .72446 .55738 Mtetra
.607 .723 .928 r
.72446 .55738 .73022 .56445 .74265 .55864 .73716 .55513 Mtetra
.638 .867 .985 r
.73716 .55513 .74265 .55864 .75507 .55205 .7498 .55097 Mtetra
.658 .954 .947 r
.7498 .55097 .75507 .55205 .76753 .54557 .76234 .54469 Mtetra
.7 .97 .931 r
.76234 .54469 .76753 .54557 .78008 .53982 .77485 .53738 Mtetra
.731 .934 .955 r
.77485 .53738 .78008 .53982 .79275 .53493 .78741 .53049 Mtetra
.711 .857 .951 r
.78741 .53049 .79275 .53493 .80551 .53068 .80011 .52478 Mtetra
.682 .795 .935 r
.80011 .52478 .80551 .53068 .81836 .52676 .81295 .52011 Mtetra
.664 .765 .925 r
.81295 .52011 .81836 .52676 .83128 .52294 .82588 .51601 Mtetra
.658 .755 .921 r
.82588 .51601 .83128 .52294 .84426 .51914 .8389 .51212 Mtetra
.656 .752 .92 r
.8389 .51212 .84426 .51914 .85729 .51534 .85197 .50827 Mtetra
.656 .751 .92 r
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Mtetra
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Mtetra
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Mtetra
.655 .751 .92 r
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62693 Mtetra
.653 .751 .922 r
.42007 .62693 .42668 .63304 .43797 .62974 .43138 .62367 Mtetra
.642 .75 .928 r
.43138 .62367 .43797 .62974 .4493 .62648 .44274 .6207 Mtetra
.606 .75 .946 r
.44274 .6207 .4493 .62648 .46068 .62343 .45413 .6185 Mtetra
.512 .749 .981 r
.45413 .6185 .46068 .62343 .4721 .62093 .46555 .61768 Mtetra
.305 .718 .975 r
.46555 .61768 .4721 .62093 .48356 .61945 .47702 .61814 Mtetra
.125 .661 .856 r
.47702 .61814 .48356 .61945 .49507 .61912 .48857 .61841 Mtetra
.329 .803 .913 r
.48857 .61841 .49507 .61912 .50665 .61921 .50021 .61649 Mtetra
.671 .886 .977 r
.50021 .61649 .50665 .61921 .5183 .61829 .51191 .61185 Mtetra
.727 .766 .884 r
.51191 .61185 .5183 .61829 .53002 .61532 .52366 .60589 Mtetra
.702 .688 .833 r
.52366 .60589 .53002 .61532 .54178 .61048 .53544 .60026 Mtetra
.68 .665 .829 r
.53544 .60026 .54178 .61048 .55357 .6049 .54727 .59551 Mtetra
.67 .679 .849 r
.54727 .59551 .55357 .6049 .56541 .5996 .55914 .59134 Mtetra
.669 .704 .874 r
.55914 .59134 .56541 .5996 .57729 .59496 .57106 .58736 Mtetra
.668 .723 .89 r
.57106 .58736 .57729 .59496 .58923 .59087 .58303 .58343 Mtetra
.667 .727 .894 r
.58303 .58343 .58923 .59087 .60122 .58711 .59506 .57956 Mtetra
.664 .724 .894 r
.59506 .57956 .60122 .58711 .61327 .58349 .60713 .57576 Mtetra
.66 .718 .892 r
.60713 .57576 .61327 .58349 .62537 .57993 .61926 .57208 Mtetra
.656 .715 .891 r
.61926 .57208 .62537 .57993 .63752 .57639 .63144 .56851 Mtetra
.652 .713 .893 r
.63144 .56851 .63752 .57639 .64973 .57287 .64368 .56505 Mtetra
.649 .714 .896 r
.64368 .56505 .64973 .57287 .66199 .5694 .65598 .5617 Mtetra
.645 .717 .9 r
.65598 .5617 .66199 .5694 .67431 .56607 .66834 .55845 Mtetra
.643 .719 .903 r
.66834 .55845 .67431 .56607 .68671 .56307 .68077 .55523 Mtetra
.642 .714 .9 r
.68077 .55523 .68671 .56307 .6992 .56064 .69325 .55207 Mtetra
.636 .693 .886 r
.69325 .55207 .6992 .56064 .71178 .55886 .7058 .5491 Mtetra
.62 .658 .866 r
.7058 .5491 .71178 .55886 .72446 .55738 .71845 .54671 Mtetra
.597 .629 .854 r
.71845 .54671 .72446 .55738 .73716 .55513 .73122 .54521 Mtetra
.584 .64 .872 r
.73122 .54521 .73716 .55513 .7498 .55097 .74408 .54405 Mtetra
.613 .734 .932 r
.74408 .54405 .7498 .55097 .76234 .54469 .75693 .54153 Mtetra
.679 .896 .975 r
.75693 .54153 .76234 .54469 .77485 .53738 .76964 .53621 Mtetra
.72 .969 .934 r
.76964 .53621 .77485 .53738 .78741 .53049 .78223 .52864 Mtetra
.748 .957 .94 r
.78223 .52864 .78741 .53049 .80011 .52478 .79483 .52086 Mtetra
.731 .884 .951 r
.79483 .52086 .80011 .52478 .81295 .52011 .80757 .5144 Mtetra
.691 .808 .937 r
.80757 .5144 .81295 .52011 .82588 .51601 .82047 .50935 Mtetra
.667 .769 .926 r
.82047 .50935 .82588 .51601 .8389 .51212 .8335 .50511 Mtetra
.658 .755 .922 r
.8335 .50511 .8389 .51212 .85197 .50827 .84661 .50115 Mtetra
.656 .752 .92 r
.84661 .50115 .85197 .50827 .86511 .50441 .85979 .49725 Mtetra
.656 .751 .92 r
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Mtetra
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62743 Mtetra
.655 .751 .92 r
.39085 .62743 .39757 .63354 .4088 .63024 .4021 .6241 Mtetra
.653 .751 .922 r
.4021 .6241 .4088 .63024 .42007 .62693 .4134 .62083 Mtetra
.641 .75 .928 r
.4134 .62083 .42007 .62693 .43138 .62367 .42473 .61785 Mtetra
.6 .748 .948 r
.42473 .61785 .43138 .62367 .44274 .6207 .4361 .61578 Mtetra
.481 .738 .984 r
.4361 .61578 .44274 .6207 .45413 .6185 .44748 .61538 Mtetra
.222 .676 .95 r
.44748 .61538 .45413 .6185 .46555 .61768 .4589 .61643 Mtetra
.097 .642 .838 r
.4589 .61643 .46555 .61768 .47702 .61814 .47041 .61684 Mtetra
.459 .859 .969 r
.47041 .61684 .47702 .61814 .48857 .61841 .48204 .61423 Mtetra
.723 .84 .937 r
.48204 .61423 .48857 .61841 .50021 .61649 .49374 .60866 Mtetra
.727 .73 .853 r
.49374 .60866 .50021 .61649 .51191 .61185 .50549 .6023 Mtetra
.701 .686 .832 r
.50549 .6023 .51191 .61185 .52366 .60589 .51726 .59668 Mtetra
.687 .688 .846 r
.51726 .59668 .52366 .60589 .53544 .60026 .52907 .59184 Mtetra
.681 .705 .865 r
.52907 .59184 .53544 .60026 .54727 .59551 .54093 .58736 Mtetra
.675 .71 .874 r
.54093 .58736 .54727 .59551 .55914 .59134 .55283 .58314 Mtetra
.668 .707 .877 r
.55283 .58314 .55914 .59134 .57106 .58736 .56478 .57917 Mtetra
.662 .706 .88 r
.56478 .57917 .57106 .58736 .58303 .58343 .57679 .57542 Mtetra
.658 .71 .886 r
.57679 .57542 .58303 .58343 .59506 .57956 .58884 .57178 Mtetra
.657 .717 .893 r
.58884 .57178 .59506 .57956 .60713 .57576 .60095 .5682 Mtetra
.656 .723 .898 r
.60095 .5682 .60713 .57576 .61926 .57208 .61312 .56462 Mtetra
.656 .727 .901 r
.61312 .56462 .61926 .57208 .63144 .56851 .62533 .56102 Mtetra
.62533 .56102 .63144 .56851 .64368 .56505 .6376 .5574 Mtetra
.656 .723 .899 r
.6376 .5574 .64368 .56505 .65598 .5617 .64993 .55379 Mtetra
.654 .716 .894 r
.64993 .55379 .65598 .5617 .66834 .55845 .66231 .55022 Mtetra
.65 .707 .889 r
.66231 .55022 .66834 .55845 .68077 .55523 .67475 .54678 Mtetra
.643 .699 .887 r
.67475 .54678 .68077 .55523 .69325 .55207 .68726 .54355 Mtetra
.635 .695 .889 r
.68726 .54355 .69325 .55207 .7058 .5491 .69985 .54058 Mtetra
.627 .693 .891 r
.69985 .54058 .7058 .5491 .71845 .54671 .71251 .53786 Mtetra
.616 .68 .888 r
.71251 .53786 .71845 .54671 .73122 .54521 .72526 .53552 Mtetra
.594 .651 .876 r
.72526 .53552 .73122 .54521 .74408 .54405 .73812 .53395 Mtetra
.573 .632 .872 r
.73812 .53395 .74408 .54405 .75693 .54153 .75111 .53314 Mtetra
.589 .683 .906 r
.75111 .53314 .75693 .54153 .76964 .53621 .76413 .53151 Mtetra
.673 .838 .963 r
.76413 .53151 .76964 .53621 .78223 .52864 .77699 .52682 Mtetra
.746 .959 .94 r
.77699 .52682 .78223 .52864 .79483 .52086 .78966 .51902 Mtetra
.769 .962 .929 r
.78966 .51902 .79483 .52086 .80757 .5144 .8023 .51055 Mtetra
.744 .892 .946 r
.8023 .51055 .80757 .5144 .82047 .50935 .81509 .50359 Mtetra
.696 .811 .936 r
.81509 .50359 .82047 .50935 .8335 .50511 .82808 .49835 Mtetra
.668 .768 .925 r
.82808 .49835 .8335 .50511 .84661 .50115 .84121 .49404 Mtetra
.658 .755 .921 r
.84121 .49404 .84661 .50115 .85979 .49725 .85442 .49004 Mtetra
.656 .752 .92 r
.85442 .49004 .85979 .49725 .87303 .49335 .8677 .4861 Mtetra
.656 .751 .92 r
.8677 .4861 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Mtetra
.37283 .6246 .37964 .63075 .39085 .62743 .38407 .62126 Mtetra
.654 .751 .921 r
.38407 .62126 .39085 .62743 .4021 .6241 .39535 .61796 Mtetra
.644 .75 .926 r
.39535 .61796 .4021 .6241 .4134 .62083 .40667 .6149 Mtetra
.605 .746 .944 r
.40667 .6149 .4134 .62083 .42473 .61785 .41801 .61272 Mtetra
.482 .731 .981 r
.41801 .61272 .42473 .61785 .4361 .61578 .42935 .61238 Mtetra
.19 .647 .942 r
.42935 .61238 .4361 .61578 .44748 .61538 .44072 .61389 Mtetra
.048 .602 .822 r
.44072 .61389 .44748 .61538 .4589 .61643 .45219 .61486 Mtetra
.475 .859 .979 r
.45219 .61486 .4589 .61643 .47041 .61684 .46379 .6123 Mtetra
.737 .829 .921 r
.46379 .6123 .47041 .61684 .48204 .61423 .4755 .60625 Mtetra
.736 .729 .845 r
.4755 .60625 .48204 .61423 .49374 .60866 .48725 .59935 Mtetra
.711 .694 .833 r
.48725 .59935 .49374 .60866 .50549 .6023 .49902 .5933 Mtetra
.693 .696 .848 r
.49902 .5933 .50549 .6023 .51726 .59668 .51082 .58818 Mtetra
.68 .703 .865 r
.51082 .58818 .51726 .59668 .52907 .59184 .52266 .58373 Mtetra
.668 .71 .879 r
.52266 .58373 .52907 .59184 .54093 .58736 .53455 .57976 Mtetra
.663 .722 .893 r
.53455 .57976 .54093 .58736 .55283 .58314 .54648 .57601 Mtetra
.662 .736 .905 r
.54648 .57601 .55283 .58314 .56478 .57917 .55847 .57228 Mtetra
.662 .744 .911 r
.55847 .57228 .56478 .57917 .57679 .57542 .57051 .56851 Mtetra
.57051 .56851 .57679 .57542 .58884 .57178 .5826 .56474 Mtetra
.661 .74 .909 r
.5826 .56474 .58884 .57178 .60095 .5682 .59474 .56099 Mtetra
.658 .736 .907 r
.59474 .56099 .60095 .5682 .61312 .56462 .60693 .5573 Mtetra
.656 .733 .906 r
.60693 .5573 .61312 .56462 .62533 .56102 .61918 .55368 Mtetra
.653 .732 .907 r
.61918 .55368 .62533 .56102 .6376 .5574 .63149 .55011 Mtetra
.651 .734 .91 r
.63149 .55011 .6376 .5574 .64993 .55379 .64385 .5466 Mtetra
.649 .737 .913 r
.64385 .5466 .64993 .55379 .66231 .55022 .65628 .54313 Mtetra
.649 .741 .916 r
.65628 .54313 .66231 .55022 .67475 .54678 .66875 .53964 Mtetra
.65 .74 .915 r
.66875 .53964 .67475 .54678 .68726 .54355 .68129 .53611 Mtetra
.649 .732 .91 r
.68129 .53611 .68726 .54355 .69985 .54058 .69388 .53261 Mtetra
.642 .715 .9 r
.69388 .53261 .69985 .54058 .71251 .53786 .70655 .52932 Mtetra
.628 .695 .893 r
.70655 .52932 .71251 .53786 .72526 .53552 .7193 .52652 Mtetra
.608 .675 .889 r
.7193 .52652 .72526 .53552 .73812 .53395 .73216 .5244 Mtetra
.58 .65 .884 r
.73216 .5244 .73812 .53395 .75111 .53314 .74516 .52322 Mtetra
.554 .63 .881 r
.74516 .52322 .75111 .53314 .76413 .53151 .75829 .5229 Mtetra
.574 .673 .906 r
.75829 .5229 .76413 .53151 .77699 .52682 .77145 .52169 Mtetra
.679 .827 .954 r
.77145 .52169 .77699 .52682 .78966 .51902 .7844 .51688 Mtetra
.773 .955 .931 r
.7844 .51688 .78966 .51902 .8023 .51055 .79712 .50841 Mtetra
.79 .958 .922 r
.79712 .50841 .8023 .51055 .81509 .50359 .8098 .49939 Mtetra
.748 .883 .941 r
.8098 .49939 .81509 .50359 .82808 .49835 .82268 .49229 Mtetra
.693 .803 .933 r
.82268 .49229 .82808 .49835 .84121 .49404 .83578 .48709 Mtetra
.665 .764 .924 r
.83578 .48709 .84121 .49404 .85442 .49004 .84901 .48281 Mtetra
.657 .754 .921 r
.84901 .48281 .85442 .49004 .8677 .4861 .86234 .47879 Mtetra
.656 .752 .92 r
.86234 .47879 .8677 .4861 .88105 .48214 .87572 .47479 Mtetra
.656 .751 .92 r
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Mtetra
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61842 Mtetra
.655 .751 .921 r
.36597 .61842 .37283 .6246 .38407 .62126 .37724 .61507 Mtetra
.649 .75 .924 r
.37724 .61507 .38407 .62126 .39535 .61796 .38854 .61188 Mtetra
.62 .747 .937 r
.38854 .61188 .39535 .61796 .40667 .6149 .39987 .60939 Mtetra
.515 .731 .972 r
.39987 .60939 .40667 .6149 .41801 .61272 .41119 .6087 Mtetra
.22 .644 .955 r
.41119 .6087 .41801 .61272 .42935 .61238 .4225 .61041 Mtetra
0 .53 .793 r
.4225 .61041 .42935 .61238 .44072 .61389 .4339 .61241 Mtetra
.367 .809 .955 r
.4339 .61241 .44072 .61389 .45219 .61486 .44546 .61082 Mtetra
.738 .846 .931 r
.44546 .61082 .45219 .61486 .46379 .6123 .45717 .60473 Mtetra
.753 .743 .843 r
.45717 .60473 .46379 .6123 .4755 .60625 .46893 .59706 Mtetra
.724 .701 .828 r
.46893 .59706 .4755 .60625 .48725 .59935 .48071 .59032 Mtetra
.699 .697 .845 r
.48071 .59032 .48725 .59935 .49902 .5933 .49251 .58493 Mtetra
.68 .707 .868 r
.49251 .58493 .49902 .5933 .51082 .58818 .50433 .58047 Mtetra
.672 .722 .887 r
.50433 .58047 .51082 .58818 .52266 .58373 .5162 .57638 Mtetra
.67 .732 .896 r
.5162 .57638 .52266 .58373 .53455 .57976 .52812 .57236 Mtetra
.668 .731 .897 r
.52812 .57236 .53455 .57976 .54648 .57601 .54009 .5684 Mtetra
.664 .724 .894 r
.54009 .5684 .54648 .57601 .55847 .57228 .5521 .56456 Mtetra
.659 .721 .894 r
.5521 .56456 .55847 .57228 .57051 .56851 .56417 .56085 Mtetra
.657 .722 .897 r
.56417 .56085 .57051 .56851 .5826 .56474 .57629 .55722 Mtetra
.656 .727 .901 r
.57629 .55722 .5826 .56474 .59474 .56099 .58847 .5536 Mtetra
.656 .731 .905 r
.58847 .5536 .59474 .56099 .60693 .5573 .6007 .54998 Mtetra
.656 .734 .907 r
.6007 .54998 .60693 .5573 .61918 .55368 .61299 .54632 Mtetra
.61299 .54632 .61918 .55368 .63149 .55011 .62532 .54264 Mtetra
.656 .732 .905 r
.62532 .54264 .63149 .55011 .64385 .5466 .63772 .53894 Mtetra
.655 .727 .902 r
.63772 .53894 .64385 .5466 .65628 .54313 .65017 .53526 Mtetra
.652 .721 .899 r
.65017 .53526 .65628 .54313 .66875 .53964 .66268 .53166 Mtetra
.648 .717 .898 r
.66268 .53166 .66875 .53964 .68129 .53611 .67525 .52819 Mtetra
.644 .718 .902 r
.67525 .52819 .68129 .53611 .69388 .53261 .68789 .52484 Mtetra
.641 .722 .907 r
.68789 .52484 .69388 .53261 .70655 .52932 .70059 .52155 Mtetra
.639 .722 .908 r
.70059 .52155 .70655 .52932 .7193 .52652 .71335 .51832 Mtetra
.627 .706 .903 r
.71335 .51832 .7193 .52652 .73216 .5244 .7262 .51547 Mtetra
.599 .676 .894 r
.7262 .51547 .73216 .5244 .74516 .52322 .73918 .51356 Mtetra
.558 .639 .887 r
.73918 .51356 .74516 .52322 .75829 .5229 .75233 .51303 Mtetra
.527 .619 .887 r
.75233 .51303 .75829 .5229 .77145 .52169 .76563 .51344 Mtetra
.57 .683 .917 r
.76563 .51344 .77145 .52169 .7844 .51688 .7789 .51219 Mtetra
.712 .856 .951 r
.7789 .51219 .7844 .51688 .79712 .50841 .79188 .5063 Mtetra
.805 .96 .912 r
.79188 .5063 .79712 .50841 .8098 .49939 .80459 .49669 Mtetra
.802 .943 .918 r
.80459 .49669 .8098 .49939 .82268 .49229 .81735 .48739 Mtetra
.739 .859 .936 r
.81735 .48739 .82268 .49229 .83578 .48709 .83035 .48058 Mtetra
.684 .787 .929 r
.83035 .48058 .83578 .48709 .84901 .48281 .84357 .47564 Mtetra
.662 .759 .922 r
.84357 .47564 .84901 .48281 .86234 .47879 .85692 .47143 Mtetra
.657 .752 .921 r
.85692 .47143 .86234 .47879 .87572 .47479 .87035 .46738 Mtetra
.656 .751 .92 r
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Mtetra
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Mtetra
.655 .751 .92 r
.34781 .61556 .35476 .62177 .36597 .61842 .35906 .61219 Mtetra
.653 .751 .922 r
.35906 .61219 .36597 .61842 .37724 .61507 .37035 .60888 Mtetra
.636 .748 .93 r
.37035 .60888 .37724 .61507 .38854 .61188 .38167 .60599 Mtetra
.565 .737 .957 r
.38167 .60599 .38854 .61188 .39987 .60939 .39298 .60457 Mtetra
.32 .67 .975 r
.39298 .60457 .39987 .60939 .41119 .6087 .40426 .60588 Mtetra
0 .474 .791 r
.40426 .60588 .41119 .6087 .4225 .61041 .41557 .60896 Mtetra
.106 .646 .85 r
.41557 .60896 .4225 .61041 .4339 .61241 .42704 .60942 Mtetra
.7 .88 .965 r
.42704 .60942 .4339 .61241 .44546 .61082 .43872 .60424 Mtetra
.775 .771 .85 r
.43872 .60424 .44546 .61082 .45717 .60473 .45052 .5958 Mtetra
.745 .713 .822 r
.45052 .5958 .45717 .60473 .46893 .59706 .46233 .58794 Mtetra
.711 .7 .838 r
.46233 .58794 .46893 .59706 .48071 .59032 .47412 .58191 Mtetra
.688 .709 .864 r
.47412 .58191 .48071 .59032 .49251 .58493 .48594 .57711 Mtetra
.677 .721 .883 r
.48594 .57711 .49251 .58493 .50433 .58047 .49779 .57282 Mtetra
.669 .724 .89 r
.49779 .57282 .50433 .58047 .5162 .57638 .50969 .56881 Mtetra
.662 .725 .896 r
.50969 .56881 .5162 .57638 .52812 .57236 .52164 .56505 Mtetra
.658 .731 .904 r
.52164 .56505 .52812 .57236 .54009 .5684 .53364 .56141 Mtetra
.657 .742 .912 r
.53364 .56141 .54009 .5684 .5521 .56456 .54569 .55774 Mtetra
.659 .748 .916 r
.54569 .55774 .5521 .56456 .56417 .56085 .5578 .55402 Mtetra
.659 .749 .916 r
.5578 .55402 .56417 .56085 .57629 .55722 .56995 .55025 Mtetra
.659 .746 .914 r
.56995 .55025 .57629 .55722 .58847 .5536 .58216 .5465 Mtetra
.657 .742 .912 r
.58216 .5465 .58847 .5536 .6007 .54998 .59443 .54277 Mtetra
.656 .739 .911 r
.59443 .54277 .6007 .54998 .61299 .54632 .60675 .53909 Mtetra
.654 .738 .912 r
.60675 .53909 .61299 .54632 .62532 .54264 .61912 .53544 Mtetra
.652 .74 .914 r
.61912 .53544 .62532 .54264 .63772 .53894 .63155 .53183 Mtetra
.651 .743 .917 r
.63155 .53183 .63772 .53894 .65017 .53526 .64404 .52823 Mtetra
.652 .747 .919 r
.64404 .52823 .65017 .53526 .66268 .53166 .65659 .52458 Mtetra
.653 .747 .918 r
.65659 .52458 .66268 .53166 .67525 .52819 .66919 .52087 Mtetra
.654 .741 .914 r
.66919 .52087 .67525 .52819 .68789 .52484 .68185 .51714 Mtetra
.65 .729 .907 r
.68185 .51714 .68789 .52484 .70059 .52155 .69457 .51353 Mtetra
.642 .718 .903 r
.69457 .51353 .70059 .52155 .71335 .51832 .70736 .51017 Mtetra
.633 .712 .903 r
.70736 .51017 .71335 .51832 .7262 .51547 .72024 .50709 Mtetra
.617 .699 .903 r
.72024 .50709 .7262 .51547 .73918 .51356 .73321 .50452 Mtetra
.578 .666 .898 r
.73321 .50452 .73918 .51356 .75233 .51303 .74634 .50322 Mtetra
.519 .618 .89 r
.74634 .50322 .75233 .51303 .76563 .51344 .75967 .50377 Mtetra
.496 .61 .896 r
.75967 .50377 .76563 .51344 .7789 .51219 .77315 .5049 Mtetra
.597 .727 .935 r
.77315 .5049 .7789 .51219 .79188 .5063 .78646 .50264 Mtetra
.773 .908 .933 r
.78646 .50264 .79188 .5063 .80459 .49669 .79937 .49454 Mtetra
.834 .961 .892 r
.79937 .49454 .80459 .49669 .81735 .48739 .81207 .48373 Mtetra
.796 .914 .92 r
.81207 .48373 .81735 .48739 .83035 .48058 .82494 .47477 Mtetra
.718 .824 .931 r
.82494 .47477 .83035 .48058 .84357 .47564 .83811 .46866 Mtetra
.672 .771 .924 r
.83811 .46866 .84357 .47564 .85692 .47143 .85147 .46407 Mtetra
.659 .755 .921 r
.85147 .46407 .85692 .47143 .87035 .46738 .86494 .45992 Mtetra
.656 .752 .92 r
.86494 .45992 .87035 .46738 .88385 .46334 .87848 .45583 Mtetra
.656 .751 .92 r
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Mtetra
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Mtetra
.655 .751 .921 r
.34082 .6093 .34781 .61556 .35906 .61219 .35209 .60592 Mtetra
.647 .75 .924 r
.35209 .60592 .35906 .61219 .37035 .60888 .3634 .60272 Mtetra
.61 .743 .94 r
.3634 .60272 .37035 .60888 .38167 .60599 .37472 .60042 Mtetra
.456 .707 .976 r
.37472 .60042 .38167 .60599 .39298 .60457 .386 .60056 Mtetra
.01 .51 .867 r
.386 .60056 .39298 .60457 .40426 .60588 .39723 .60389 Mtetra
0 .401 .683 r
.39723 .60389 .40426 .60588 .41557 .60896 .40857 .60707 Mtetra
.489 .857 .987 r
.40857 .60707 .41557 .60896 .42704 .60942 .42016 .60456 Mtetra
.79 .821 .877 r
.42016 .60456 .42704 .60942 .43872 .60424 .43198 .59609 Mtetra
.775 .735 .816 r
.43198 .59609 .43872 .60424 .45052 .5958 .44384 .58658 Mtetra
.734 .705 .823 r
.44384 .58658 .45052 .5958 .46233 .58794 .45567 .57921 Mtetra
.7 .706 .852 r
.45567 .57921 .46233 .58794 .47412 .58191 .46748 .57381 Mtetra
.679 .715 .876 r
.46748 .57381 .47412 .58191 .48594 .57711 .47932 .56941 Mtetra
.667 .723 .891 r
.47932 .56941 .48594 .57711 .49779 .57282 .4912 .56546 Mtetra
.663 .732 .901 r
.4912 .56546 .49779 .57282 .50969 .56881 .50313 .56164 Mtetra
.664 .738 .905 r
.50313 .56164 .50969 .56881 .52164 .56505 .51512 .55777 Mtetra
.664 .736 .904 r
.51512 .55777 .52164 .56505 .53364 .56141 .52715 .55389 Mtetra
.661 .729 .9 r
.52715 .55389 .53364 .56141 .54569 .55774 .53923 .55009 Mtetra
.658 .725 .899 r
.53923 .55009 .54569 .55774 .5578 .55402 .55137 .54638 Mtetra
.655 .726 .901 r
.55137 .54638 .5578 .55402 .56995 .55025 .56356 .54273 Mtetra
.655 .73 .904 r
.56356 .54273 .56995 .55025 .58216 .5465 .5758 .53909 Mtetra
.655 .734 .907 r
.5758 .53909 .58216 .5465 .59443 .54277 .5881 .53542 Mtetra
.656 .737 .909 r
.5881 .53542 .59443 .54277 .60675 .53909 .60045 .5317 Mtetra
.657 .737 .909 r
.60045 .5317 .60675 .53909 .61912 .53544 .61286 .52795 Mtetra
.657 .735 .907 r
.61286 .52795 .61912 .53544 .63155 .53183 .62533 .52416 Mtetra
.656 .73 .904 r
.62533 .52416 .63155 .53183 .64404 .52823 .63784 .52038 Mtetra
.654 .725 .901 r
.63784 .52038 .64404 .52823 .65659 .52458 .65042 .51666 Mtetra
.651 .723 .902 r
.65042 .51666 .65659 .52458 .66919 .52087 .66306 .51304 Mtetra
.648 .725 .905 r
.66306 .51304 .66919 .52087 .68185 .51714 .67577 .50949 Mtetra
.647 .731 .91 r
.67577 .50949 .68185 .51714 .69457 .51353 .68853 .50592 Mtetra
.648 .734 .911 r
.68853 .50592 .69457 .51353 .70736 .51017 .70135 .50231 Mtetra
.644 .726 .908 r
.70135 .50231 .70736 .51017 .72024 .50709 .71424 .49883 Mtetra
.63 .71 .904 r
.71424 .49883 .72024 .50709 .73321 .50452 .72722 .4958 Mtetra
.599 .685 .902 r
.72722 .4958 .73321 .50452 .74634 .50322 .74033 .49379 Mtetra
.533 .636 .898 r
.74033 .49379 .74634 .50322 .75967 .50377 .75366 .49379 Mtetra
.457 .584 .892 r
.75366 .49379 .75967 .50377 .77315 .5049 .76724 .49597 Mtetra
.484 .626 .914 r
.76724 .49597 .77315 .5049 .78646 .50264 .78084 .49705 Mtetra
.686 .82 .948 r
.78084 .49705 .78646 .50264 .79937 .49454 .79405 .49194 Mtetra
.839 .948 .89 r
.79405 .49194 .79937 .49454 .81207 .48373 .80681 .48094 Mtetra
.843 .944 .887 r
.80681 .48094 .81207 .48373 .82494 .47477 .81956 .4698 Mtetra
.765 .867 .924 r
.81956 .4698 .82494 .47477 .83811 .46866 .83263 .46199 Mtetra
.691 .79 .926 r
.83263 .46199 .83811 .46866 .85147 .46407 .84598 .45673 Mtetra
.663 .759 .922 r
.84598 .45673 .85147 .46407 .86494 .45992 .85948 .4524 Mtetra
.657 .752 .92 r
.85948 .4524 .86494 .45992 .87848 .45583 .87306 .44826 Mtetra
.656 .751 .92 r
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Mtetra
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Mtetra
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .603 Mtetra
.653 .751 .921 r
.33376 .603 .34082 .6093 .35209 .60592 .34506 .59962 Mtetra
.638 .748 .928 r
.34506 .59962 .35209 .60592 .3634 .60272 .35639 .59664 Mtetra
.564 .733 .954 r
.35639 .59664 .3634 .60272 .37472 .60042 .3677 .59522 Mtetra
.263 .627 .961 r
.3677 .59522 .37472 .60042 .386 .60056 .37893 .59727 Mtetra
0 .302 .662 r
.37893 .59727 .386 .60056 .39723 .60389 .39012 .60225 Mtetra
0 .497 .743 r
.39012 .60225 .39723 .60389 .40857 .60707 .40152 .60428 Mtetra
.732 .891 .952 r
.40152 .60428 .40857 .60707 .42016 .60456 .41328 .59818 Mtetra
.812 .779 .822 r
.41328 .59818 .42016 .60456 .43198 .59609 .42521 .58717 Mtetra
.772 .721 .805 r
.42521 .58717 .43198 .59609 .44384 .58658 .43711 .57743 Mtetra
.723 .705 .833 r
.43711 .57743 .44384 .58658 .45567 .57921 .44895 .57075 Mtetra
.687 .71 .866 r
.44895 .57075 .45567 .57921 .46748 .57381 .46079 .56597 Mtetra
.67 .721 .887 r
.46079 .56597 .46748 .57381 .47932 .56941 .47265 .56188 Mtetra
.666 .728 .896 r
.47265 .56188 .47932 .56941 .4912 .56546 .48456 .55796 Mtetra
.662 .729 .899 r
.48456 .55796 .4912 .56546 .50313 .56164 .49653 .55415 Mtetra
.656 .728 .902 r
.49653 .55415 .50313 .56164 .51512 .55777 .50854 .55049 Mtetra
.654 .734 .909 r
.50854 .55049 .51512 .55777 .52715 .55389 .5206 .54691 Mtetra
.654 .744 .916 r
.5206 .54691 .52715 .55389 .53923 .55009 .53272 .54328 Mtetra
.656 .751 .92 r
.53272 .54328 .53923 .55009 .55137 .54638 .54489 .53956 Mtetra
.658 .752 .92 r
.54489 .53956 .55137 .54638 .56356 .54273 .55712 .53578 Mtetra
.658 .749 .917 r
.55712 .53578 .56356 .54273 .5758 .53909 .56939 .53199 Mtetra
.657 .745 .915 r
.56939 .53199 .5758 .53909 .5881 .53542 .58173 .52821 Mtetra
.655 .743 .914 r
.58173 .52821 .5881 .53542 .60045 .5317 .59412 .52447 Mtetra
.654 .742 .915 r
.59412 .52447 .60045 .5317 .61286 .52795 .60656 .52076 Mtetra
.653 .744 .917 r
.60656 .52076 .61286 .52795 .62533 .52416 .61907 .51707 Mtetra
.652 .748 .92 r
.61907 .51707 .62533 .52416 .63784 .52038 .63163 .51336 Mtetra
.654 .751 .921 r
.63163 .51336 .63784 .52038 .65042 .51666 .64424 .50959 Mtetra
.656 .751 .92 r
.64424 .50959 .65042 .51666 .66306 .51304 .65691 .50572 Mtetra
.657 .745 .915 r
.65691 .50572 .66306 .51304 .67577 .50949 .66964 .50181 Mtetra
.655 .735 .909 r
.66964 .50181 .67577 .50949 .68853 .50592 .68243 .49797 Mtetra
.65 .726 .905 r
.68243 .49797 .68853 .50592 .70135 .50231 .69528 .4943 Mtetra
.646 .724 .905 r
.69528 .4943 .70135 .50231 .71424 .49883 .7082 .49073 Mtetra
.64 .72 .906 r
.7082 .49073 .71424 .49883 .72722 .4958 .7212 .48733 Mtetra
.618 .702 .904 r
.7212 .48733 .72722 .4958 .74033 .49379 .7343 .48463 Mtetra
.556 .656 .903 r
.7343 .48463 .74033 .49379 .75366 .49379 .74761 .48387 Mtetra
.445 .58 .894 r
.74761 .48387 .75366 .49379 .76724 .49597 .76123 .48625 Mtetra
.386 .553 .897 r
.76123 .48625 .76724 .49597 .78084 .49705 .77506 .48989 Mtetra
.56 .72 .948 r
.77506 .48989 .78084 .49705 .79405 .49194 .7886 .48842 Mtetra
.816 .921 .907 r
.7886 .48842 .79405 .49194 .80681 .48094 .80153 .47852 Mtetra
.875 .951 .856 r
.80153 .47852 .80681 .48094 .81956 .4698 .8142 .46558 Mtetra
.815 .9 .902 r
.8142 .46558 .81956 .4698 .83263 .46199 .82714 .45571 Mtetra
.719 .813 .924 r
.82714 .45571 .83263 .46199 .84598 .45673 .84045 .44945 Mtetra
.67 .766 .922 r
.84045 .44945 .84598 .45673 .85948 .4524 .85397 .44484 Mtetra
.658 .754 .921 r
.85397 .44484 .85948 .4524 .87306 .44826 .8676 .44062 Mtetra
.656 .752 .92 r
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Mtetra
.656 .751 .92 r
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Mtetra
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Mtetra
.655 .751 .92 r
.31537 .60008 .32251 .60641 .33376 .603 .32666 .59664 Mtetra
.651 .75 .922 r
.32666 .59664 .33376 .603 .34506 .59962 .33798 .59331 Mtetra
.624 .745 .933 r
.33798 .59331 .34506 .59962 .35639 .59664 .34932 .59064 Mtetra
.493 .71 .967 r
.34932 .59064 .35639 .59664 .3677 .59522 .3606 .59036 Mtetra
0 .467 .859 r
.3606 .59036 .3677 .59522 .37893 .59727 .37175 .59449 Mtetra
.438 0 0 r
.37175 .59449 .37893 .59727 .39012 .60225 .38292 .60064 Mtetra
.183 .696 .892 r
.38292 .60064 .39012 .60225 .40152 .60428 .39444 .60061 Mtetra
.821 .857 .874 r
.39444 .60061 .40152 .60428 .41328 .59818 .40637 .59082 Mtetra
.821 .757 .792 r
.40637 .59082 .41328 .59818 .42521 .58717 .41841 .57793 Mtetra
.766 .715 .804 r
.41841 .57793 .42521 .58717 .43711 .57743 .43034 .5684 Mtetra
.709 .704 .844 r
.43034 .5684 .43711 .57743 .44895 .57075 .44219 .56247 Mtetra
.675 .712 .876 r
.44219 .56247 .44895 .57075 .46079 .56597 .45404 .55815 Mtetra
.662 .72 .892 r
.45404 .55815 .46079 .56597 .47265 .56188 .46593 .55431 Mtetra
.657 .726 .9 r
.46593 .55431 .47265 .56188 .48456 .55796 .47787 .55065 Mtetra
.657 .734 .907 r
.47787 .55065 .48456 .55796 .49653 .55415 .48986 .54698 Mtetra
.66 .74 .909 r
.48986 .54698 .49653 .55415 .50854 .55049 .50191 .54318 Mtetra
.661 .738 .906 r
.50191 .54318 .50854 .55049 .5206 .54691 .51401 .53933 Mtetra
.659 .73 .902 r
.51401 .53933 .5206 .54691 .53272 .54328 .52615 .53552 Mtetra
.656 .725 .9 r
.52615 .53552 .53272 .54328 .54489 .53956 .53836 .5318 Mtetra
.654 .725 .901 r
.53836 .5318 .54489 .53956 .55712 .53578 .55062 .52813 Mtetra
.654 .729 .905 r
.55062 .52813 .55712 .53578 .56939 .53199 .56293 .52446 Mtetra
.654 .734 .908 r
.56293 .52446 .56939 .53199 .58173 .52821 .5753 .52075 Mtetra
.656 .737 .909 r
.5753 .52075 .58173 .52821 .59412 .52447 .58772 .51697 Mtetra
.657 .737 .909 r
.58772 .51697 .59412 .52447 .60656 .52076 .6002 .51314 Mtetra
.658 .735 .906 r
.6002 .51314 .60656 .52076 .61907 .51707 .61274 .50926 Mtetra
.657 .73 .903 r
.61274 .50926 .61907 .51707 .63163 .51336 .62533 .50538 Mtetra
.655 .726 .901 r
.62533 .50538 .63163 .51336 .64424 .50959 .63798 .50155 Mtetra
.652 .724 .901 r
.63798 .50155 .64424 .50959 .65691 .50572 .65069 .49781 Mtetra
.65 .728 .906 r
.65069 .49781 .65691 .50572 .66964 .50181 .66346 .49412 Mtetra
.651 .735 .911 r
.66346 .49412 .66964 .50181 .68243 .49797 .67629 .49036 Mtetra
.655 .739 .912 r
.67629 .49036 .68243 .49797 .69528 .4943 .68918 .48647 Mtetra
.654 .734 .908 r
.68918 .48647 .69528 .4943 .7082 .49073 .70212 .48258 Mtetra
.649 .724 .904 r
.70212 .48258 .7082 .49073 .7212 .48733 .71514 .47887 Mtetra
.634 .711 .902 r
.71514 .47887 .7212 .48733 .7343 .48463 .72825 .47564 Mtetra
.582 .675 .903 r
.72825 .47564 .7343 .48463 .74761 .48387 .74153 .47406 Mtetra
.452 .588 .898 r
.74153 .47406 .74761 .48387 .76123 .48625 .75516 .47617 Mtetra
.304 .497 .881 r
.75516 .47617 .76123 .48625 .77506 .48989 .76915 .4817 Mtetra
.405 .61 .932 r
.76915 .4817 .77506 .48989 .7886 .48842 .78302 .48399 Mtetra
.763 .886 .933 r
.78302 .48399 .7886 .48842 .80153 .47852 .79619 .47614 Mtetra
.894 .948 .835 r
.79619 .47614 .80153 .47852 .8142 .46558 .80883 .46188 Mtetra
.859 .918 .87 r
.80883 .46188 .8142 .46558 .82714 .45571 .82164 .44977 Mtetra
.752 .836 .915 r
.82164 .44977 .82714 .45571 .84045 .44945 .83489 .44225 Mtetra
.681 .774 .922 r
.83489 .44225 .84045 .44945 .85397 .44484 .84842 .43724 Mtetra
.66 .755 .921 r
.84842 .43724 .85397 .44484 .8676 .44062 .86209 .43292 Mtetra
.656 .752 .92 r
.86209 .43292 .8676 .44062 .88129 .43645 .87583 .42871 Mtetra
.656 .751 .92 r
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Mtetra
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42025 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Mtetra
.655 .751 .921 r
.30818 .5937 .31537 .60008 .32666 .59664 .31949 .59024 Mtetra
.648 .75 .924 r
.31949 .59024 .32666 .59664 .33798 .59331 .33084 .58696 Mtetra
.606 .74 .94 r
.33084 .58696 .33798 .59331 .34932 .59064 .34219 .58469 Mtetra
.39 .669 .97 r
.34219 .58469 .34932 .59064 .3606 .59036 .35342 .58574 Mtetra
0 .25 .669 r
.35342 .58574 .3606 .59036 .37175 .59449 .36449 .59202 Mtetra
.521 0 0 r
.36449 .59202 .37175 .59449 .38292 .60064 .37565 .59896 Mtetra
.48 .859 .981 r
.37565 .59896 .38292 .60064 .39444 .60061 .38731 .59634 Mtetra
.859 .828 .816 r
.38731 .59634 .39444 .60061 .40637 .59082 .39943 .5829 Mtetra
.828 .747 .775 r
.39943 .5829 .40637 .59082 .41841 .57793 .41156 .56854 Mtetra
.759 .711 .807 r
.41156 .56854 .41841 .57793 .43034 .5684 .42351 .55943 Mtetra
.693 .702 .854 r
.42351 .55943 .43034 .5684 .44219 .56247 .43537 .55424 Mtetra
.661 .71 .884 r
.43537 .55424 .44219 .56247 .45404 .55815 .44724 .55041 Mtetra
.655 .722 .898 r
.44724 .55041 .45404 .55815 .46593 .55431 .45916 .54678 Mtetra
.657 .729 .902 r
.45916 .54678 .46593 .55431 .47787 .55065 .47113 .54309 Mtetra
.656 .729 .903 r
.47113 .54309 .47787 .55065 .48986 .54698 .48315 .53941 Mtetra
.651 .728 .905 r
.48315 .53941 .48986 .54698 .50191 .54318 .49523 .53585 Mtetra
.649 .735 .912 r
.49523 .53585 .50191 .54318 .51401 .53933 .50735 .53234 Mtetra
.651 .746 .92 r
.50735 .53234 .51401 .53933 .52615 .53552 .51954 .52876 Mtetra
.654 .755 .924 r
.51954 .52876 .52615 .53552 .53836 .5318 .53178 .52504 Mtetra
.657 .757 .924 r
.53178 .52504 .53836 .5318 .55062 .52813 .54407 .52123 Mtetra
.657 .754 .921 r
.54407 .52123 .55062 .52813 .56293 .52446 .55642 .51738 Mtetra
.657 .749 .918 r
.55642 .51738 .56293 .52446 .5753 .52075 .56883 .51355 Mtetra
.655 .746 .917 r
.56883 .51355 .5753 .52075 .58772 .51697 .58129 .50974 Mtetra
.654 .746 .917 r
.58129 .50974 .58772 .51697 .6002 .51314 .5938 .50597 Mtetra
.653 .748 .92 r
.5938 .50597 .6002 .51314 .61274 .50926 .60638 .50221 Mtetra
.653 .753 .923 r
.60638 .50221 .61274 .50926 .62533 .50538 .61901 .49841 Mtetra
.655 .757 .925 r
.61901 .49841 .62533 .50538 .63798 .50155 .6317 .49451 Mtetra
.659 .757 .922 r
.6317 .49451 .63798 .50155 .65069 .49781 .64444 .49048 Mtetra
.661 .75 .916 r
.64444 .49048 .65069 .49781 .66346 .49412 .65724 .48638 Mtetra
.659 .738 .908 r
.65724 .48638 .66346 .49412 .67629 .49036 .67009 .48232 Mtetra
.655 .73 .904 r
.67009 .48232 .67629 .49036 .68918 .48647 .68302 .47839 Mtetra
.654 .729 .904 r
.68302 .47839 .68918 .48647 .70212 .48258 .696 .47447 Mtetra
.656 .73 .904 r
.696 .47447 .70212 .48258 .71514 .47887 .70904 .47048 Mtetra
.649 .72 .9 r
.70904 .47048 .71514 .47887 .72825 .47564 .72215 .46669 Mtetra
.607 .689 .9 r
.72215 .46669 .72825 .47564 .74153 .47406 .73542 .4643 Mtetra
.468 .6 .9 r
.73542 .4643 .74153 .47406 .75516 .47617 .74903 .46593 Mtetra
.232 .449 .866 r
.74903 .46593 .75516 .47617 .76915 .4817 .76315 .47292 Mtetra
.224 .485 .893 r
.76315 .47292 .76915 .4817 .78302 .48399 .77734 .47892 Mtetra
.681 .845 .961 r
.77734 .47892 .78302 .48399 .79619 .47614 .79078 .47366 Mtetra
.904 .942 .822 r
.79078 .47366 .79619 .47614 .80883 .46188 .80343 .4585 Mtetra
.893 .923 .834 r
.80343 .4585 .80883 .46188 .82164 .44977 .81611 .44406 Mtetra
.787 .853 .9 r
.81611 .44406 .82164 .44977 .83489 .44225 .82929 .4351 Mtetra
.694 .783 .919 r
.82929 .4351 .83489 .44225 .84842 .43724 .84283 .4296 Mtetra
.662 .757 .92 r
.84283 .4296 .84842 .43724 .86209 .43292 .85653 .42516 Mtetra
.656 .752 .92 r
.85653 .42516 .86209 .43292 .87583 .42871 .87032 .4209 Mtetra
.656 .751 .92 r
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Mtetra
.88417 .41664 .88963 .42449 .90351 .42025 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Mtetra
.655 .751 .921 r
.30093 .58727 .30818 .5937 .31949 .59024 .31227 .58379 Mtetra
.645 .749 .925 r
.31227 .58379 .31949 .59024 .33084 .58696 .32364 .58057 Mtetra
.584 .734 .946 r
.32364 .58057 .33084 .58696 .34219 .58469 .33499 .57875 Mtetra
.258 .602 .952 r
.33499 .57875 .34219 .58469 .35342 .58574 .34618 .5812 Mtetra
.511 0 0 r
.34618 .5812 .35342 .58574 .36449 .59202 .35715 .58967 Mtetra
.569 0 0 r
.35715 .58967 .36449 .59202 .37565 .59896 .3683 .59724 Mtetra
.68 .921 .972 r
.3683 .59724 .37565 .59896 .38731 .59634 .38013 .59183 Mtetra
.882 .811 .775 r
.38013 .59183 .38731 .59634 .39943 .5829 .39244 .57474 Mtetra
.836 .744 .763 r
.39244 .57474 .39943 .5829 .41156 .56854 .40467 .55905 Mtetra
.751 .709 .812 r
.40467 .55905 .41156 .56854 .42351 .55943 .41664 .55043 Mtetra
.675 .697 .863 r
.41664 .55043 .42351 .55943 .43537 .55424 .42851 .54597 Mtetra
.648 .707 .889 r
.42851 .54597 .43537 .55424 .44724 .55041 .44039 .54255 Mtetra
.647 .717 .9 r
.44039 .54255 .44724 .55041 .45916 .54678 .45234 .53916 Mtetra
.647 .725 .905 r
.45234 .53916 .45916 .54678 .47113 .54309 .46433 .53574 Mtetra
.65 .735 .911 r
.46433 .53574 .47113 .54309 .48315 .53941 .47638 .5322 Mtetra
.657 .741 .912 r
.47638 .5322 .48315 .53941 .49523 .53585 .48849 .52843 Mtetra
.66 .737 .907 r
.48849 .52843 .49523 .53585 .50735 .53234 .50066 .52454 Mtetra
.659 .727 .9 r
.50066 .52454 .50735 .53234 .51954 .52876 .51287 .52068 Mtetra
.655 .719 .896 r
.51287 .52068 .51954 .52876 .53178 .52504 .52514 .51694 Mtetra
.652 .719 .897 r
.52514 .51694 .53178 .52504 .54407 .52123 .53747 .51326 Mtetra
.652 .723 .901 r
.53747 .51326 .54407 .52123 .55642 .51738 .54985 .50958 Mtetra
.653 .729 .905 r
.54985 .50958 .55642 .51738 .56883 .51355 .56229 .50584 Mtetra
.656 .733 .907 r
.56229 .50584 .56883 .51355 .58129 .50974 .57479 .502 Mtetra
.658 .734 .906 r
.57479 .502 .58129 .50974 .5938 .50597 .58734 .49807 Mtetra
.659 .731 .902 r
.58734 .49807 .5938 .50597 .60638 .50221 .59994 .49408 Mtetra
.659 .725 .898 r
.59994 .49408 .60638 .50221 .61901 .49841 .61261 .49008 Mtetra
.656 .72 .896 r
.61261 .49008 .61901 .49841 .6317 .49451 .62533 .48616 Mtetra
.652 .719 .897 r
.62533 .48616 .6317 .49451 .64444 .49048 .63812 .48235 Mtetra
.651 .725 .903 r
.63812 .48235 .64444 .49048 .65724 .48638 .65096 .47856 Mtetra
.654 .736 .91 r
.65096 .47856 .65724 .48638 .67009 .48232 .66386 .47465 Mtetra
.66 .744 .912 r
.66386 .47465 .67009 .48232 .68302 .47839 .67682 .47051 Mtetra
.663 .74 .907 r
.67682 .47051 .68302 .47839 .696 .47447 .68982 .46625 Mtetra
.664 .731 .9 r
.68982 .46625 .696 .47447 .70904 .47048 .70289 .46196 Mtetra
.662 .724 .895 r
.70289 .46196 .70904 .47048 .72215 .46669 .71601 .4577 Mtetra
.631 .7 .895 r
.71601 .4577 .72215 .46669 .73542 .4643 .72926 .4545 Mtetra
.489 .612 .9 r
.72926 .4545 .73542 .4643 .74903 .46593 .74287 .45557 Mtetra
.162 .403 .847 r
.74287 .45557 .74903 .46593 .76315 .47292 .75709 .4639 Mtetra
.016 .339 .82 r
.75709 .4639 .76315 .47292 .77734 .47892 .77159 .47359 Mtetra
.563 .793 .985 r
.77159 .47359 .77734 .47892 .79078 .47366 .7853 .47115 Mtetra
.912 .938 .811 r
.7853 .47115 .79078 .47366 .80343 .4585 .79798 .45523 Mtetra
.919 .917 .798 r
.79798 .45523 .80343 .4585 .81611 .44406 .81054 .43843 Mtetra
.818 .861 .88 r
.81054 .43843 .81611 .44406 .82929 .4351 .82364 .42793 Mtetra
.708 .789 .915 r
.82364 .42793 .82929 .4351 .84283 .4296 .83718 .4219 Mtetra
.665 .758 .92 r
.83718 .4219 .84283 .4296 .85653 .42516 .85092 .41733 Mtetra
.657 .752 .92 r
.85092 .41733 .85653 .42516 .87032 .4209 .86476 .41302 Mtetra
.656 .751 .92 r
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Mtetra
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58079 Mtetra
.654 .751 .921 r
.29362 .58079 .30093 .58727 .31227 .58379 .30499 .57729 Mtetra
.641 .748 .926 r
.30499 .57729 .31227 .58379 .32364 .58057 .31639 .57413 Mtetra
.561 .726 .951 r
.31639 .57413 .32364 .58057 .33499 .57875 .32774 .57275 Mtetra
.108 .512 .908 r
.32774 .57275 .33499 .57875 .34618 .5812 .33886 .57659 Mtetra
.647 .104 0 r
.33886 .57659 .34618 .5812 .35715 .58967 .34973 .58726 Mtetra
.607 .037 0 r
.34973 .58726 .35715 .58967 .3683 .59724 .36087 .59555 Mtetra
.786 .928 .928 r
.36087 .59555 .3683 .59724 .38013 .59183 .37286 .58744 Mtetra
.899 .802 .744 r
.37286 .58744 .38013 .59183 .39244 .57474 .3854 .56666 Mtetra
.846 .746 .753 r
.3854 .56666 .39244 .57474 .40467 .55905 .39774 .5495 Mtetra
.745 .707 .816 r
.39774 .5495 .40467 .55905 .41664 .55043 .40973 .54129 Mtetra
.654 .688 .869 r
.40973 .54129 .41664 .55043 .42851 .54597 .42159 .53759 Mtetra
.631 .699 .894 r
.42159 .53759 .42851 .54597 .44039 .54255 .43349 .53468 Mtetra
.639 .716 .903 r
.43349 .53468 .44039 .54255 .45234 .53916 .44546 .53149 Mtetra
.649 .726 .905 r
.44546 .53149 .45234 .53916 .46433 .53574 .45748 .52798 Mtetra
.65 .725 .903 r
.45748 .52798 .46433 .53574 .47638 .5322 .46957 .52441 Mtetra
.646 .723 .905 r
.46957 .52441 .47638 .5322 .48849 .52843 .4817 .52098 Mtetra
.644 .733 .914 r
.4817 .52098 .48849 .52843 .50066 .52454 .4939 .51757 Mtetra
.648 .749 .924 r
.4939 .51757 .50066 .52454 .51287 .52068 .50615 .514 Mtetra
.655 .761 .928 r
.50615 .514 .51287 .52068 .52514 .51694 .51845 .51017 Mtetra
.661 .761 .924 r
.51845 .51017 .52514 .51694 .53747 .51326 .53082 .50615 Mtetra
.663 .752 .917 r
.53082 .50615 .53747 .51326 .54985 .50958 .54323 .50207 Mtetra
.66 .741 .91 r
.54323 .50207 .54985 .50958 .56229 .50584 .55571 .49807 Mtetra
.655 .733 .907 r
.55571 .49807 .56229 .50584 .57479 .502 .56824 .49421 Mtetra
.651 .732 .909 r
.56824 .49421 .57479 .502 .58734 .49807 .58083 .49048 Mtetra
.648 .737 .915 r
.58083 .49048 .58734 .49807 .59994 .49408 .59348 .48682 Mtetra
.648 .748 .922 r
.59348 .48682 .59994 .49408 .61261 .49008 .60619 .4831 Mtetra
.653 .76 .927 r
.60619 .4831 .61261 .49008 .62533 .48616 .61895 .47919 Mtetra
.661 .763 .926 r
.61895 .47919 .62533 .48616 .63812 .48235 .63177 .47502 Mtetra
.666 .755 .917 r
.63177 .47502 .63812 .48235 .65096 .47856 .64463 .47068 Mtetra
.665 .74 .906 r
.64463 .47068 .65096 .47856 .66386 .47465 .65756 .46638 Mtetra
.66 .729 .9 r
.65756 .46638 .66386 .47465 .67682 .47051 .67055 .46222 Mtetra
.661 .729 .9 r
.67055 .46222 .67682 .47051 .68982 .46625 .6836 .45798 Mtetra
.67 .734 .898 r
.6836 .45798 .68982 .46625 .70289 .46196 .69669 .45342 Mtetra
.677 .731 .891 r
.69669 .45342 .70289 .46196 .71601 .4577 .70982 .44858 Mtetra
.654 .708 .887 r
.70982 .44858 .71601 .4577 .72926 .4545 .72306 .44455 Mtetra
.507 .619 .898 r
.72306 .44455 .72926 .4545 .74287 .45557 .73666 .44514 Mtetra
.081 .349 .821 r
.73666 .44514 .74287 .45557 .75709 .4639 .751 .45494 Mtetra
0 .175 .705 r
.751 .45494 .75709 .4639 .77159 .47359 .76579 .46839 Mtetra
.4 .719 .988 r
.76579 .46839 .77159 .47359 .7853 .47115 .77977 .46866 Mtetra
.92 .936 .8 r
.77977 .46866 .7853 .47115 .79798 .45523 .79247 .45189 Mtetra
.937 .905 .767 r
.79247 .45189 .79798 .45523 .81054 .43843 .80491 .43272 Mtetra
.842 .862 .858 r
.80491 .43272 .81054 .43843 .82364 .42793 .81794 .42069 Mtetra
.721 .793 .909 r
.81794 .42069 .82364 .42793 .83718 .4219 .83149 .41414 Mtetra
.668 .759 .919 r
.83149 .41414 .83718 .4219 .85092 .41733 .84527 .40943 Mtetra
.657 .752 .92 r
.84527 .40943 .85092 .41733 .86476 .41302 .85915 .40508 Mtetra
.656 .751 .92 r
.85915 .40508 .86476 .41302 .87866 .40872 .8731 .40074 Mtetra
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Mtetra
.26359 .58133 .27102 .5878 .28229 .5843 .2749 .57779 Mtetra
.2749 .57779 .28229 .5843 .29362 .58079 .28625 .57425 Mtetra
.654 .751 .921 r
.28625 .57425 .29362 .58079 .30499 .57729 .29765 .57074 Mtetra
.638 .747 .927 r
.29765 .57074 .30499 .57729 .31639 .57413 .30907 .56763 Mtetra
.538 .717 .955 r
.30907 .56763 .31639 .57413 .32774 .57275 .32042 .56665 Mtetra
0 .413 .845 r
.32042 .56665 .32774 .57275 .33886 .57659 .33149 .57177 Mtetra
.73 .21 0 r
.33149 .57177 .33886 .57659 .34973 .58726 .34225 .58459 Mtetra
.647 .089 0 r
.34225 .58459 .34973 .58726 .36087 .59555 .35335 .59389 Mtetra
.838 .918 .888 r
.35335 .59389 .36087 .59555 .37286 .58744 .36551 .58351 Mtetra
.915 .8 .719 r
.36551 .58351 .37286 .58744 .3854 .56666 .37829 .55905 Mtetra
.862 .754 .742 r
.37829 .55905 .3854 .56666 .39774 .5495 .39076 .54 Mtetra
.743 .709 .82 r
.39076 .54 .39774 .5495 .40973 .54129 .40277 .53195 Mtetra
.633 .677 .874 r
.40277 .53195 .40973 .54129 .42159 .53759 .41464 .52897 Mtetra
.616 .689 .895 r
.41464 .52897 .42159 .53759 .43349 .53468 .42655 .52651 Mtetra
.63 .707 .901 r
.42655 .52651 .43349 .53468 .44546 .53149 .43853 .52358 Mtetra
.641 .718 .904 r
.43853 .52358 .44546 .53149 .45748 .52798 .45058 .52028 Mtetra
.658 .73 .903 r
.45058 .52028 .45748 .52798 .46957 .52441 .4627 .51642 Mtetra
.68 .73 .888 r
.4627 .51642 .46957 .52441 .4817 .52098 .47489 .51179 Mtetra
.69 .705 .859 r
.47489 .51179 .4817 .52098 .4939 .51757 .48713 .50654 Mtetra
.685 .667 .827 r
.48713 .50654 .4939 .51757 .50615 .514 .49941 .5011 Mtetra
.671 .633 .803 r
.49941 .5011 .50615 .514 .51845 .51017 .51174 .49587 Mtetra
.658 .609 .787 r
.51174 .49587 .51845 .51017 .53082 .50615 .52411 .491 Mtetra
.648 .594 .78 r
.52411 .491 .53082 .50615 .54323 .50207 .53653 .4865 Mtetra
.641 .586 .777 r
.53653 .4865 .54323 .50207 .55571 .49807 .54901 .48231 Mtetra
.636 .581 .777 r
.54901 .48231 .55571 .49807 .56824 .49421 .56155 .4784 Mtetra
.63 .579 .778 r
.56155 .4784 .56824 .49421 .58083 .49048 .57414 .47476 Mtetra
.625 .577 .781 r
.57414 .47476 .58083 .49048 .59348 .48682 .58681 .47144 Mtetra
.618 .578 .787 r
.58681 .47144 .59348 .48682 .60619 .4831 .59954 .46851 Mtetra
.611 .585 .799 r
.59954 .46851 .60619 .4831 .61895 .47919 .61235 .46596 Mtetra
.608 .603 .821 r
.61235 .46596 .61895 .47919 .63177 .47502 .62524 .46361 Mtetra
.614 .638 .851 r
.62524 .46361 .63177 .47502 .64463 .47068 .6382 .46107 Mtetra
.63 .684 .882 r
.6382 .46107 .64463 .47068 .65756 .46638 .6512 .45791 Mtetra
.653 .722 .9 r
.6512 .45791 .65756 .46638 .67055 .46222 .66424 .45396 Mtetra
.668 .735 .9 r
.66424 .45396 .67055 .46222 .6836 .45798 .67731 .44945 Mtetra
.677 .732 .891 r
.67731 .44945 .6836 .45798 .69669 .45342 .69043 .44457 Mtetra
.688 .729 .881 r
.69043 .44457 .69669 .45342 .70982 .44858 .70357 .43921 Mtetra
.673 .711 .877 r
.70357 .43921 .70982 .44858 .72306 .44455 .7168 .43439 Mtetra
.515 .62 .894 r
.7168 .43439 .72306 .44455 .73666 .44514 .73042 .43477 Mtetra
0 .273 .778 r
.73042 .43477 .73666 .44514 .751 .45494 .74489 .44645 Mtetra
0 .005 .552 r
.74489 .44645 .751 .45494 .76579 .46839 .75996 .46365 Mtetra
.208 .622 .951 r
.75996 .46365 .76579 .46839 .77977 .46866 .77417 .46617 Mtetra
.93 .931 .784 r
.77417 .46617 .77977 .46866 .79247 .45189 .78687 .44826 Mtetra
.948 .89 .74 r
.78687 .44826 .79247 .45189 .80491 .43272 .79921 .42677 Mtetra
.86 .857 .837 r
.79921 .42677 .80491 .43272 .81794 .42069 .81218 .41333 Mtetra
.731 .795 .903 r
.81218 .41333 .81794 .42069 .83149 .41414 .82574 .40629 Mtetra
.67 .76 .918 r
.82574 .40629 .83149 .41414 .84527 .40943 .83956 .40147 Mtetra
.657 .752 .92 r
.83956 .40147 .84527 .40943 .85915 .40508 .85349 .39706 Mtetra
.656 .751 .92 r
.85349 .39706 .85915 .40508 .8731 .40074 .86748 .39268 Mtetra
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.25611 .57479 .26359 .58133 .2749 .57779 .26744 .57123 Mtetra
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Mtetra
.654 .751 .921 r
.27883 .56766 .28625 .57425 .29765 .57074 .29026 .56413 Mtetra
.636 .746 .928 r
.29026 .56413 .29765 .57074 .30907 .56763 .3017 .56107 Mtetra
.518 .709 .958 r
.3017 .56107 .30907 .56763 .32042 .56665 .31305 .56042 Mtetra
0 .321 .775 r
.31305 .56042 .32042 .56665 .33149 .57177 .32406 .56665 Mtetra
.781 .281 0 r
.32406 .56665 .33149 .57177 .34225 .58459 .33471 .58142 Mtetra
.688 .143 0 r
.33471 .58142 .34225 .58459 .35335 .59389 .34576 .59202 Mtetra
.859 .904 .864 r
.34576 .59202 .35335 .59389 .36551 .58351 .35805 .58024 Mtetra
.927 .8 .7 r
.35805 .58024 .36551 .58351 .37829 .55905 .37107 .5524 Mtetra
.882 .767 .73 r
.37107 .5524 .37829 .55905 .39076 .54 .38371 .53089 Mtetra
.753 .72 .821 r
.38371 .53089 .39076 .54 .40277 .53195 .39577 .52235 Mtetra
.619 .667 .874 r
.39577 .52235 .40277 .53195 .41464 .52897 .40765 .51981 Mtetra
.609 .674 .887 r
.40765 .51981 .41464 .52897 .42655 .52651 .41957 .51754 Mtetra
.654 .696 .877 r
.41957 .51754 .42655 .52651 .43853 .52358 .4316 .51379 Mtetra
.688 .691 .847 r
.4316 .51379 .43853 .52358 .45058 .52028 .44373 .50852 Mtetra
.692 .657 .811 r
.44373 .50852 .45058 .52028 .4627 .51642 .45591 .5025 Mtetra
.676 .62 .786 r
.45591 .5025 .4627 .51642 .47489 .51179 .46812 .49674 Mtetra
.657 .598 .778 r
.46812 .49674 .47489 .51179 .48713 .50654 .48036 .49179 Mtetra
.644 .596 .785 r
.48036 .49179 .48713 .50654 .49941 .5011 .49265 .48762 Mtetra
.639 .61 .805 r
.49265 .48762 .49941 .5011 .51174 .49587 .50498 .48391 Mtetra
.639 .635 .83 r
.50498 .48391 .51174 .49587 .52411 .491 .51737 .48036 Mtetra
.643 .662 .853 r
.51737 .48036 .52411 .491 .53653 .4865 .52982 .47677 Mtetra
.649 .684 .869 r
.52982 .47677 .53653 .4865 .54901 .48231 .54233 .47302 Mtetra
.655 .697 .877 r
.54233 .47302 .54901 .48231 .56155 .4784 .55489 .46908 Mtetra
.659 .699 .875 r
.55489 .46908 .56155 .4784 .57414 .47476 .56751 .46494 Mtetra
.662 .689 .865 r
.56751 .46494 .57414 .47476 .58681 .47144 .58019 .46064 Mtetra
.659 .669 .848 r
.58019 .46064 .58681 .47144 .59954 .46851 .59292 .4563 Mtetra
.651 .64 .826 r
.59292 .4563 .59954 .46851 .61235 .46596 .60571 .4521 Mtetra
.636 .609 .806 r
.60571 .4521 .61235 .46596 .62524 .46361 .61857 .44838 Mtetra
.616 .581 .792 r
.61857 .44838 .62524 .46361 .6382 .46107 .63152 .44547 Mtetra
.599 .568 .791 r
.63152 .44547 .6382 .46107 .6512 .45791 .64457 .44338 Mtetra
.593 .58 .807 r
.64457 .44338 .6512 .45791 .66424 .45396 .65771 .44158 Mtetra
.612 .623 .837 r
.65771 .44158 .66424 .45396 .67731 .44945 .6709 .43901 Mtetra
.652 .679 .862 r
.6709 .43901 .67731 .44945 .69043 .44457 .68408 .4349 Mtetra
.69 .712 .865 r
.68408 .4349 .69043 .44457 .70357 .43921 .69725 .42928 Mtetra
.682 .704 .864 r
.69725 .42928 .70357 .43921 .7168 .43439 .71049 .42395 Mtetra
.499 .607 .891 r
.71049 .42395 .7168 .43439 .73042 .43477 .72416 .42478 Mtetra
0 .161 .699 r
.72416 .42478 .73042 .43477 .74489 .44645 .73881 .43894 Mtetra
.606 .142 0 r
.73881 .43894 .74489 .44645 .75996 .46365 .75413 .45955 Mtetra
.043 .531 .884 r
.75413 .45955 .75996 .46365 .77417 .46617 .76849 .46345 Mtetra
.939 .919 .766 r
.76849 .46345 .77417 .46617 .78687 .44826 .78117 .44409 Mtetra
.953 .871 .719 r
.78117 .44409 .78687 .44826 .79921 .42677 .79343 .42049 Mtetra
.871 .849 .819 r
.79343 .42049 .79921 .42677 .81218 .41333 .80637 .40583 Mtetra
.74 .795 .897 r
.80637 .40583 .81218 .41333 .82574 .40629 .81995 .39837 Mtetra
.673 .761 .917 r
.81995 .39837 .82574 .40629 .83956 .40147 .83381 .39343 Mtetra
.658 .752 .92 r
.83381 .39343 .83956 .40147 .85349 .39706 .84778 .38897 Mtetra
.656 .751 .92 r
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38455 Mtetra
.86182 .38455 .86748 .39268 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Mtetra
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Mtetra
.653 .751 .921 r
.27134 .56102 .27883 .56766 .29026 .56413 .2828 .55747 Mtetra
.633 .746 .929 r
.2828 .55747 .29026 .56413 .3017 .56107 .29427 .55445 Mtetra
.499 .701 .96 r
.29427 .55445 .3017 .56107 .31305 .56042 .30562 .55409 Mtetra
0 .243 .71 r
.30562 .55409 .31305 .56042 .32406 .56665 .31658 .56122 Mtetra
.81 .326 0 r
.31658 .56122 .32406 .56665 .33471 .58142 .32714 .57756 Mtetra
.719 .188 0 r
.32714 .57756 .33471 .58142 .34576 .59202 .33812 .5895 Mtetra
.859 .885 .855 r
.33812 .5895 .34576 .59202 .35805 .58024 .35049 .57738 Mtetra
.934 .799 .689 r
.35049 .57738 .35805 .58024 .37107 .5524 .36372 .54716 Mtetra
.905 .783 .716 r
.36372 .54716 .37107 .5524 .38371 .53089 .37657 .52264 Mtetra
.788 .745 .813 r
.37657 .52264 .38371 .53089 .39577 .52235 .38876 .51211 Mtetra
.653 .668 .852 r
.38876 .51211 .39577 .52235 .40765 .51981 .40069 .50829 Mtetra
.651 .643 .83 r
.40069 .50829 .40765 .51981 .41957 .51754 .41269 .50437 Mtetra
.671 .627 .797 r
.41269 .50437 .41957 .51754 .4316 .51379 .42478 .49912 Mtetra
.661 .604 .78 r
.42478 .49912 .4316 .51379 .44373 .50852 .4369 .494 Mtetra
.641 .596 .789 r
.4369 .494 .44373 .50852 .45591 .5025 .44905 .49004 Mtetra
.625 .619 .824 r
.44905 .49004 .45591 .5025 .46812 .49674 .46123 .48706 Mtetra
.618 .67 .878 r
.46123 .48706 .46812 .49674 .48036 .49179 .47346 .48444 Mtetra
.614 .731 .929 r
.47346 .48444 .48036 .49179 .49265 .48762 .48576 .48175 Mtetra
.612 .778 .961 r
.48576 .48175 .49265 .48762 .50498 .48391 .49813 .47879 Mtetra
.614 .806 .974 r
.49813 .47879 .50498 .48391 .51737 .48036 .51056 .47555 Mtetra
.621 .82 .977 r
.51056 .47555 .51737 .48036 .52982 .47677 .52306 .47204 Mtetra
.63 .827 .976 r
.52306 .47204 .52982 .47677 .54233 .47302 .53561 .46829 Mtetra
.639 .831 .974 r
.53561 .46829 .54233 .47302 .55489 .46908 .54823 .46431 Mtetra
.649 .833 .971 r
.54823 .46431 .55489 .46908 .56751 .46494 .56089 .46009 Mtetra
.659 .835 .967 r
.56089 .46009 .56751 .46494 .58019 .46064 .57362 .45564 Mtetra
.67 .833 .962 r
.57362 .45564 .58019 .46064 .59292 .4563 .58639 .45093 Mtetra
.682 .825 .952 r
.58639 .45093 .59292 .4563 .60571 .4521 .59921 .44594 Mtetra
.692 .803 .933 r
.59921 .44594 .60571 .4521 .61857 .44838 .61208 .44068 Mtetra
.693 .758 .902 r
.61208 .44068 .61857 .44838 .63152 .44547 .62499 .43533 Mtetra
.675 .693 .859 r
.62499 .43533 .63152 .44547 .64457 .44338 .63797 .43034 Mtetra
.642 .627 .819 r
.63797 .43034 .64457 .44338 .65771 .44158 .65104 .42635 Mtetra
.612 .582 .795 r
.65104 .42635 .65771 .44158 .6709 .43901 .66422 .42355 Mtetra
.609 .578 .794 r
.66422 .42355 .6709 .43901 .68408 .4349 .67749 .42092 Mtetra
.639 .613 .808 r
.67749 .42092 .68408 .4349 .69725 .42928 .69076 .41692 Mtetra
.645 .642 .833 r
.69076 .41692 .69725 .42928 .71049 .42395 .7041 .41285 Mtetra
.429 .555 .881 r
.7041 .41285 .71049 .42395 .72416 .42478 .71791 .41567 Mtetra
0 .01 .562 r
.71791 .41567 .72416 .42478 .73881 .43894 .73276 .43287 Mtetra
.72 .242 0 r
.73276 .43287 .73881 .43894 .75413 .45955 .74826 .45587 Mtetra
0 .499 .849 r
.74826 .45587 .75413 .45955 .76849 .46345 .76269 .46003 Mtetra
.944 .898 .751 r
.76269 .46003 .76849 .46345 .78117 .44409 .77535 .4392 Mtetra
.953 .853 .705 r
.77535 .4392 .78117 .44409 .79343 .42049 .78757 .41387 Mtetra
.878 .841 .805 r
.78757 .41387 .79343 .42049 .80637 .40583 .80049 .3982 Mtetra
.747 .796 .892 r
.80049 .3982 .80637 .40583 .81995 .39837 .8141 .39037 Mtetra
.675 .761 .916 r
.8141 .39037 .81995 .39837 .83381 .39343 .828 .38531 Mtetra
.658 .753 .92 r
.828 .38531 .83381 .39343 .84778 .38897 .84202 .38081 Mtetra
.656 .751 .92 r
.84202 .38081 .84778 .38897 .86182 .38455 .85611 .37635 Mtetra
.85611 .37635 .86182 .38455 .87594 .38012 .87028 .37188 Mtetra
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Mtetra
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55433 Mtetra
.653 .751 .921 r
.2638 .55433 .27134 .56102 .2828 .55747 .27528 .55076 Mtetra
.63 .745 .93 r
.27528 .55076 .2828 .55747 .29427 .55445 .28678 .54778 Mtetra
.48 .693 .962 r
.28678 .54778 .29427 .55445 .30562 .55409 .29813 .5477 Mtetra
0 .178 .651 r
.29813 .5477 .30562 .55409 .31658 .56122 .30905 .55558 Mtetra
.827 .353 0 r
.30905 .55558 .31658 .56122 .32714 .57756 .31952 .573 Mtetra
.732 .209 0 r
.31952 .573 .32714 .57756 .33812 .5895 .33046 .58584 Mtetra
.845 .856 .852 r
.33046 .58584 .33812 .5895 .35049 .57738 .34287 .5741 Mtetra
.931 .792 .685 r
.34287 .5741 .35049 .57738 .36372 .54716 .35626 .54291 Mtetra
.921 .789 .699 r
.35626 .54291 .36372 .54716 .37657 .52264 .36935 .51502 Mtetra
.839 .76 .776 r
.36935 .51502 .37657 .52264 .38876 .51211 .38178 .49991 Mtetra
.705 .655 .797 r
.38178 .49991 .38876 .51211 .40069 .50829 .39385 .49295 Mtetra
.637 .584 .778 r
.39385 .49295 .40069 .50829 .41269 .50437 .40585 .48903 Mtetra
.607 .57 .786 r
.40585 .48903 .41269 .50437 .42478 .49912 .41785 .48661 Mtetra
.588 .601 .832 r
.41785 .48661 .42478 .49912 .4369 .494 .42989 .48508 Mtetra
.574 .671 .905 r
.42989 .48508 .4369 .494 .44905 .49004 .442 .48365 Mtetra
.566 .744 .961 r
.442 .48365 .44905 .49004 .46123 .48706 .45419 .48183 Mtetra
.571 .787 .98 r
.45419 .48183 .46123 .48706 .47346 .48444 .46646 .4795 Mtetra
.588 .804 .982 r
.46646 .4795 .47346 .48444 .48576 .48175 .4788 .47673 Mtetra
.606 .808 .978 r
.4788 .47673 .48576 .48175 .49813 .47879 .49122 .47362 Mtetra
.62 .808 .972 r
.49122 .47362 .49813 .47879 .51056 .47555 .50369 .47023 Mtetra
.631 .807 .967 r
.50369 .47023 .51056 .47555 .52306 .47204 .51623 .46661 Mtetra
.639 .807 .964 r
.51623 .46661 .52306 .47204 .53561 .46829 .52883 .4628 Mtetra
.647 .808 .961 r
.52883 .4628 .53561 .46829 .54823 .46431 .54149 .4588 Mtetra
.653 .811 .959 r
.54149 .4588 .54823 .46431 .56089 .46009 .5542 .45461 Mtetra
.66 .815 .958 r
.5542 .45461 .56089 .46009 .57362 .45564 .56697 .45022 Mtetra
.668 .82 .957 r
.56697 .45022 .57362 .45564 .58639 .45093 .5798 .44559 Mtetra
.678 .827 .955 r
.5798 .44559 .58639 .45093 .59921 .44594 .59267 .44066 Mtetra
.689 .833 .952 r
.59267 .44066 .59921 .44594 .61208 .44068 .60559 .43537 Mtetra
.703 .837 .946 r
.60559 .43537 .61208 .44068 .62499 .43533 .61854 .42965 Mtetra
.719 .83 .933 r
.61854 .42965 .62499 .43533 .63797 .43034 .63153 .42342 Mtetra
.727 .794 .906 r
.63153 .42342 .63797 .43034 .65104 .42635 .64455 .41682 Mtetra
.711 .723 .86 r
.64455 .41682 .65104 .42635 .66422 .42355 .65762 .41031 Mtetra
.672 .64 .809 r
.65762 .41031 .66422 .42355 .67749 .42092 .67077 .40469 Mtetra
.633 .583 .78 r
.67077 .40469 .67749 .42092 .69076 .41692 .68405 .40064 Mtetra
.571 .549 .791 r
.68405 .40064 .69076 .41692 .7041 .41285 .69756 .39972 Mtetra
.277 .424 .83 r
.69756 .39972 .7041 .41285 .71791 .41567 .71165 .40719 Mtetra
.574 .127 0 r
.71165 .40719 .71791 .41567 .73276 .43287 .72672 .42778 Mtetra
.762 .28 0 r
.72672 .42778 .73276 .43287 .74826 .45587 .74229 .45171 Mtetra
.059 .543 .891 r
.74229 .45171 .74826 .45587 .76269 .46003 .75674 .45539 Mtetra
.94 .87 .742 r
.75674 .45539 .76269 .46003 .77535 .4392 .76942 .43355 Mtetra
.951 .838 .696 r
.76942 .43355 .77535 .4392 .78757 .41387 .78164 .40702 Mtetra
.884 .836 .794 r
.78164 .40702 .78757 .41387 .80049 .3982 .79457 .3905 Mtetra
.754 .798 .888 r
.79457 .3905 .80049 .3982 .8141 .39037 .80819 .3823 Mtetra
.677 .762 .915 r
.80819 .3823 .8141 .39037 .828 .38531 .82214 .37713 Mtetra
.658 .753 .92 r
.82214 .37713 .828 .38531 .84202 .38081 .83621 .37258 Mtetra
.656 .752 .92 r
.83621 .37258 .84202 .38081 .85611 .37635 .85035 .36808 Mtetra
.656 .751 .92 r
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Mtetra
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.24472 .55124 .25235 .55796 .2638 .55433 .25619 .54758 Mtetra
.652 .751 .922 r
.25619 .54758 .2638 .55433 .27528 .55076 .2677 .54399 Mtetra
.627 .744 .931 r
.2677 .54399 .27528 .55076 .28678 .54778 .27922 .54107 Mtetra
.458 .685 .963 r
.27922 .54107 .28678 .54778 .29813 .5477 .29058 .54128 Mtetra
0 .119 .593 r
.29058 .54128 .29813 .5477 .30905 .55558 .30145 .54983 Mtetra
.836 .367 .004 r
.30145 .54983 .30905 .55558 .31952 .573 .31187 .56789 Mtetra
.717 .193 0 r
.31187 .56789 .31952 .573 .33046 .58584 .3228 .5807 Mtetra
.833 .819 .835 r
.3228 .5807 .33046 .58584 .34287 .5741 .33528 .5688 Mtetra
.917 .769 .682 r
.33528 .5688 .34287 .5741 .35626 .54291 .34878 .53728 Mtetra
.914 .768 .686 r
.34878 .53728 .35626 .54291 .36935 .51502 .36209 .50691 Mtetra
.859 .751 .742 r
.36209 .50691 .36935 .51502 .38178 .49991 .37475 .48786 Mtetra
.726 .666 .79 r
.37475 .48786 .38178 .49991 .39385 .49295 .3869 .47959 Mtetra
.59 .588 .818 r
.3869 .47959 .39385 .49295 .40585 .48903 .39882 .47799 Mtetra
.507 .59 .872 r
.39882 .47799 .40585 .48903 .41785 .48661 .41073 .47864 Mtetra
.483 .659 .939 r
.41073 .47864 .41785 .48661 .42989 .48508 .42274 .47891 Mtetra
.508 .729 .973 r
.42274 .47891 .42989 .48508 .442 .48365 .43487 .47805 Mtetra
.552 .768 .978 r
.43487 .47805 .442 .48365 .45419 .48183 .4471 .47617 Mtetra
.59 .78 .971 r
.4471 .47617 .45419 .48183 .46646 .4795 .45941 .47359 Mtetra
.614 .78 .961 r
.45941 .47359 .46646 .4795 .4788 .47673 .47179 .47053 Mtetra
.628 .777 .952 r
.47179 .47053 .4788 .47673 .49122 .47362 .48425 .46718 Mtetra
.638 .773 .945 r
.48425 .46718 .49122 .47362 .50369 .47023 .49676 .46361 Mtetra
.644 .77 .94 r
.49676 .46361 .50369 .47023 .51623 .46661 .50934 .45987 Mtetra
.65 .769 .936 r
.50934 .45987 .51623 .46661 .52883 .4628 .52198 .45597 Mtetra
.654 .769 .933 r
.52198 .45597 .52883 .4628 .54149 .4588 .53468 .45192 Mtetra
.659 .77 .932 r
.53468 .45192 .54149 .4588 .5542 .45461 .54744 .44772 Mtetra
.663 .772 .931 r
.54744 .44772 .5542 .45461 .56697 .45022 .56025 .44338 Mtetra
.668 .776 .931 r
.56025 .44338 .56697 .45022 .5798 .44559 .57312 .43887 Mtetra
.673 .782 .932 r
.57312 .43887 .5798 .44559 .59267 .44066 .58604 .43418 Mtetra
.682 .794 .934 r
.58604 .43418 .59267 .44066 .60559 .43537 .59901 .42917 Mtetra
.697 .808 .934 r
.59901 .42917 .60559 .43537 .61854 .42965 .61203 .42367 Mtetra
.719 .822 .929 r
.61203 .42367 .61854 .42965 .63153 .42342 .62507 .41741 Mtetra
.747 .828 .914 r
.62507 .41741 .63153 .42342 .64455 .41682 .63812 .4101 Mtetra
.769 .813 .887 r
.63812 .4101 .64455 .41682 .65762 .41031 .65116 .40166 Mtetra
.761 .762 .853 r
.65116 .40166 .65762 .41031 .67077 .40469 .66422 .39285 Mtetra
.695 .675 .826 r
.66422 .39285 .67077 .40469 .68405 .40064 .67741 .38637 Mtetra
.536 .557 .824 r
.67741 .38637 .68405 .40064 .69756 .39972 .691 .38673 Mtetra
.086 .304 .784 r
.691 .38673 .69756 .39972 .71165 .40719 .70531 .39815 Mtetra
.62 .182 0 r
.70531 .39815 .71165 .40719 .72672 .42778 .72053 .42123 Mtetra
.727 .256 0 r
.72053 .42123 .72672 .42778 .74229 .45171 .73613 .44543 Mtetra
.199 .569 .938 r
.73613 .44543 .74229 .45171 .75674 .45539 .75063 .44921 Mtetra
.926 .841 .741 r
.75063 .44921 .75674 .45539 .76942 .43355 .76339 .42732 Mtetra
.948 .828 .691 r
.76339 .42732 .76942 .43355 .78164 .40702 .77564 .40005 Mtetra
.889 .835 .786 r
.77564 .40005 .78164 .40702 .79457 .3905 .78859 .38275 Mtetra
.762 .801 .884 r
.78859 .38275 .79457 .3905 .80819 .3823 .80224 .37417 Mtetra
.679 .764 .915 r
.80224 .37417 .80819 .3823 .82214 .37713 .81623 .36888 Mtetra
.659 .753 .92 r
.81623 .36888 .82214 .37713 .83621 .37258 .83034 .36427 Mtetra
.656 .752 .92 r
.83034 .36427 .83621 .37258 .85035 .36808 .84454 .35973 Mtetra
.656 .751 .92 r
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Mtetra
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Mtetra
.655 .751 .92 r
.23702 .54446 .24472 .55124 .25619 .54758 .24852 .54078 Mtetra
.652 .75 .922 r
.24852 .54078 .25619 .54758 .2677 .54399 .26006 .53718 Mtetra
.623 .743 .933 r
.26006 .53718 .2677 .54399 .27922 .54107 .2716 .53431 Mtetra
.432 .674 .964 r
.2716 .53431 .27922 .54107 .29058 .54128 .28295 .53486 Mtetra
.462 0 0 r
.28295 .53486 .29058 .54128 .30145 .54983 .29379 .54407 Mtetra
.839 .373 .012 r
.29379 .54407 .30145 .54983 .31187 .56789 .30417 .56237 Mtetra
.646 .111 0 r
.30417 .56237 .31187 .56789 .3228 .5807 .31518 .57385 Mtetra
.836 .777 .796 r
.31518 .57385 .3228 .5807 .33528 .5688 .32783 .55988 Mtetra
.892 .732 .676 r
.32783 .55988 .33528 .5688 .34878 .53728 .34146 .52778 Mtetra
.882 .728 .685 r
.34146 .52778 .34878 .53728 .36209 .50691 .35478 .49869 Mtetra
.849 .751 .755 r
.35478 .49869 .36209 .50691 .37475 .48786 .36742 .48132 Mtetra
.759 .787 .876 r
.36742 .48132 .37475 .48786 .3869 .47959 .37959 .47366 Mtetra
.571 .761 .968 r
.37959 .47366 .3869 .47959 .39882 .47799 .39156 .47159 Mtetra
.453 .698 .972 r
.39156 .47159 .39882 .47799 .41073 .47864 .40352 .47167 Mtetra
.474 .689 .961 r
.40352 .47167 .41073 .47864 .42274 .47891 .41556 .47165 Mtetra
.533 .706 .95 r
.41556 .47165 .42274 .47891 .43487 .47805 .42772 .47067 Mtetra
.577 .721 .941 r
.42772 .47067 .43487 .47805 .4471 .47617 .43998 .46877 Mtetra
.605 .731 .934 r
.43998 .46877 .4471 .47617 .45941 .47359 .45232 .4662 Mtetra
.621 .738 .93 r
.45232 .4662 .45941 .47359 .47179 .47053 .46474 .46318 Mtetra
.632 .744 .929 r
.46474 .46318 .47179 .47053 .48425 .46718 .47723 .45986 Mtetra
.639 .748 .928 r
.47723 .45986 .48425 .46718 .49676 .46361 .48978 .45632 Mtetra
.644 .752 .927 r
.48978 .45632 .49676 .46361 .50934 .45987 .5024 .45259 Mtetra
.649 .755 .927 r
.5024 .45259 .50934 .45987 .52198 .45597 .51507 .44871 Mtetra
.654 .758 .926 r
.51507 .44871 .52198 .45597 .53468 .45192 .52781 .44467 Mtetra
.658 .761 .925 r
.52781 .44467 .53468 .45192 .54744 .44772 .54061 .44047 Mtetra
.664 .763 .924 r
.54061 .44047 .54744 .44772 .56025 .44338 .55346 .43609 Mtetra
.67 .765 .922 r
.55346 .43609 .56025 .44338 .57312 .43887 .56637 .43149 Mtetra
.678 .766 .917 r
.56637 .43149 .57312 .43887 .58604 .43418 .57934 .42661 Mtetra
.687 .765 .911 r
.57934 .42661 .58604 .43418 .59901 .42917 .59235 .42141 Mtetra
.698 .764 .903 r
.59235 .42141 .59901 .42917 .61203 .42367 .6054 .41576 Mtetra
.713 .765 .893 r
.6054 .41576 .61203 .42367 .62507 .41741 .61849 .40948 Mtetra
.734 .772 .883 r
.61849 .40948 .62507 .41741 .63812 .4101 .63159 .40229 Mtetra
.756 .782 .874 r
.63159 .40229 .63812 .4101 .65116 .40166 .64469 .39411 Mtetra
.76 .791 .878 r
.64469 .39411 .65116 .40166 .66422 .39285 .65782 .3858 Mtetra
.71 .793 .916 r
.65782 .3858 .66422 .39285 .67741 .38637 .67108 .37969 Mtetra
.476 .711 .972 r
.67108 .37969 .67741 .38637 .691 .38673 .68468 .37934 Mtetra
0 .278 .768 r
.68468 .37934 .691 .38673 .70531 .39815 .69892 .38895 Mtetra
0 0 .407 r
.69892 .38895 .70531 .39815 .72053 .42123 .71405 .41062 Mtetra
0 0 .393 r
.71405 .41062 .72053 .42123 .73613 .44543 .72966 .43535 Mtetra
.25 .485 .888 r
.72966 .43535 .73613 .44543 .75063 .44921 .74433 .44122 Mtetra
.9 .809 .749 r
.74433 .44122 .75063 .44921 .76339 .42732 .75726 .42063 Mtetra
.946 .821 .69 r
.75726 .42063 .76339 .42732 .77564 .40005 .76959 .39304 Mtetra
.895 .835 .778 r
.76959 .39304 .77564 .40005 .78859 .38275 .78255 .37498 Mtetra
.77 .804 .881 r
.78255 .37498 .78859 .38275 .80224 .37417 .79623 .36599 Mtetra
.682 .765 .914 r
.79623 .36599 .80224 .37417 .81623 .36888 .81026 .36055 Mtetra
.659 .753 .92 r
.81026 .36055 .81623 .36888 .83034 .36427 .82442 .35589 Mtetra
.656 .752 .92 r
.82442 .35589 .83034 .36427 .84454 .35973 .83867 .35131 Mtetra
.656 .751 .92 r
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Mtetra
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Mtetra
.655 .751 .92 r
.22926 .53763 .23702 .54446 .24852 .54078 .24079 .53392 Mtetra
.651 .75 .922 r
.24079 .53392 .24852 .54078 .26006 .53718 .25236 .53031 Mtetra
.619 .742 .934 r
.25236 .53031 .26006 .53718 .2716 .53431 .26392 .52752 Mtetra
.403 .661 .964 r
.26392 .52752 .2716 .53431 .28295 .53486 .27526 .52843 Mtetra
.512 0 0 r
.27526 .52843 .28295 .53486 .29379 .54407 .28605 .53823 Mtetra
.834 .364 0 r
.28605 .53823 .29379 .54407 .30417 .56237 .29644 .55619 Mtetra
0 .106 .568 r
.29644 .55619 .30417 .56237 .31518 .57385 .30762 .56492 Mtetra
.841 .739 .752 r
.30762 .56492 .31518 .57385 .32783 .55988 .32054 .54742 Mtetra
.869 .7 .671 r
.32054 .54742 .32783 .55988 .34146 .52778 .33424 .51538 Mtetra
.845 .698 .699 r
.33424 .51538 .34146 .52778 .35478 .49869 .34737 .49129 Mtetra
.808 .77 .818 r
.34737 .49129 .35478 .49869 .36742 .48132 .35977 .47986 Mtetra
.674 .934 .968 r
.35977 .47986 .36742 .48132 .37959 .47366 .37192 .47409 Mtetra
.485 .899 .9 r
.37192 .47409 .37959 .47366 .39156 .47159 .38405 .46947 Mtetra
.555 .884 .989 r
.38405 .46947 .39156 .47159 .40352 .47167 .39619 .46586 Mtetra
.58 .773 .97 r
.39619 .46586 .40352 .47167 .41556 .47165 .40835 .46349 Mtetra
.577 .699 .925 r
.40835 .46349 .41556 .47165 .42772 .47067 .42056 .46172 Mtetra
.586 .682 .907 r
.42056 .46172 .42772 .47067 .43998 .46877 .43284 .45983 Mtetra
.602 .689 .904 r
.43284 .45983 .43998 .46877 .45232 .4662 .4452 .4575 Mtetra
.616 .702 .906 r
.4452 .4575 .45232 .4662 .46474 .46318 .45765 .45472 Mtetra
.628 .713 .908 r
.45765 .45472 .46474 .46318 .47723 .45986 .47016 .45156 Mtetra
.637 .722 .909 r
.47016 .45156 .47723 .45986 .48978 .45632 .48275 .4481 Mtetra
.644 .727 .909 r
.48275 .4481 .48978 .45632 .5024 .45259 .4954 .44439 Mtetra
.651 .731 .908 r
.4954 .44439 .5024 .45259 .51507 .44871 .50811 .44046 Mtetra
.656 .733 .906 r
.50811 .44046 .51507 .44871 .52781 .44467 .52088 .43634 Mtetra
.661 .733 .903 r
.52088 .43634 .52781 .44467 .54061 .44047 .53372 .43202 Mtetra
.666 .732 .899 r
.53372 .43202 .54061 .44047 .55346 .43609 .54661 .42752 Mtetra
.671 .732 .896 r
.54661 .42752 .55346 .43609 .56637 .43149 .55955 .42282 Mtetra
.676 .732 .892 r
.55955 .42282 .56637 .43149 .57934 .42661 .57255 .41789 Mtetra
.686 .735 .888 r
.57255 .41789 .57934 .42661 .59235 .42141 .5856 .41258 Mtetra
.698 .738 .882 r
.5856 .41258 .59235 .42141 .6054 .41576 .59869 .40673 Mtetra
.71 .738 .873 r
.59869 .40673 .6054 .41576 .61849 .40948 .61182 .40031 Mtetra
.714 .737 .869 r
.61182 .40031 .61849 .40948 .63159 .40229 .62498 .39367 Mtetra
.701 .747 .887 r
.62498 .39367 .63159 .40229 .64469 .39411 .63821 .38771 Mtetra
.662 .799 .948 r
.63821 .38771 .64469 .39411 .65782 .3858 .65155 .38309 Mtetra
.528 .873 .989 r
.65155 .38309 .65782 .3858 .67108 .37969 .66499 .37953 Mtetra
.24 .756 .828 r
.66499 .37953 .67108 .37969 .68468 .37934 .67856 .37713 Mtetra
0 .466 .756 r
.67856 .37713 .68468 .37934 .69892 .38895 .69252 .38054 Mtetra
0 .005 .545 r
.69252 .38054 .69892 .38895 .71405 .41062 .70735 .39697 Mtetra
0 0 .497 r
.70735 .39697 .71405 .41062 .72966 .43535 .72292 .42156 Mtetra
.205 .376 .813 r
.72292 .42156 .72966 .43535 .74433 .44122 .73784 .43103 Mtetra
.857 .768 .763 r
.73784 .43103 .74433 .44122 .75726 .42063 .75104 .41325 Mtetra
.939 .812 .693 r
.75104 .41325 .75726 .42063 .76959 .39304 .76348 .38593 Mtetra
.9 .833 .771 r
.76348 .38593 .76959 .39304 .78255 .37498 .77647 .36719 Mtetra
.778 .807 .877 r
.77647 .36719 .78255 .37498 .79623 .36599 .79017 .35775 Mtetra
.685 .767 .913 r
.79017 .35775 .79623 .36599 .81026 .36055 .80424 .35216 Mtetra
.66 .754 .92 r
.80424 .35216 .81026 .36055 .82442 .35589 .81845 .34743 Mtetra
.656 .752 .92 r
.81845 .34743 .82442 .35589 .83867 .35131 .83275 .34281 Mtetra
.656 .751 .92 r
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Mtetra
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Mtetra
.655 .751 .92 r
.22143 .53075 .22926 .53763 .24079 .53392 .23299 .52701 Mtetra
.651 .75 .922 r
.23299 .52701 .24079 .53392 .25236 .53031 .24459 .52338 Mtetra
.614 .74 .936 r
.24459 .52338 .25236 .53031 .26392 .52752 .25617 .52069 Mtetra
.374 .647 .963 r
.25617 .52069 .26392 .52752 .27526 .52843 .2675 .52194 Mtetra
.536 .007 0 r
.2675 .52194 .27526 .52843 .28605 .53823 .27827 .53206 Mtetra
.809 .328 0 r
.27827 .53206 .28605 .53823 .29644 .55619 .28872 .54884 Mtetra
.045 .442 .874 r
.28872 .54884 .29644 .55619 .30762 .56492 .30014 .55389 Mtetra
.838 .711 .723 r
.30014 .55389 .30762 .56492 .32054 .54742 .31329 .53349 Mtetra
.854 .687 .675 r
.31329 .53349 .32054 .54742 .33424 .51538 .32695 .50351 Mtetra
.824 .7 .727 r
.32695 .50351 .33424 .51538 .34737 .49129 .33984 .48481 Mtetra
.736 .789 .895 r
.33984 .48481 .34737 .49129 .35977 .47986 .35205 .47815 Mtetra
.499 .872 .979 r
.35205 .47815 .35977 .47986 .37192 .47409 .36412 .475 Mtetra
.432 .874 .862 r
.36412 .475 .37192 .47409 .38405 .46947 .37631 .47051 Mtetra
.557 .934 .885 r
.37631 .47051 .38405 .46947 .39619 .46586 .38862 .46449 Mtetra
.667 .937 .966 r
.38862 .46449 .39619 .46586 .40835 .46349 .40096 .45861 Mtetra
.669 .832 .962 r
.40096 .45861 .40835 .46349 .42056 .46172 .4133 .454 Mtetra
.635 .735 .92 r
.4133 .454 .42056 .46172 .43284 .45983 .42566 .4506 Mtetra
.618 .69 .894 r
.42566 .4506 .43284 .45983 .4452 .4575 .43806 .44776 Mtetra
.617 .678 .885 r
.43806 .44776 .4452 .4575 .45765 .45472 .45053 .44494 Mtetra
.624 .681 .883 r
.45053 .44494 .45765 .45472 .47016 .45156 .46306 .44191 Mtetra
.632 .688 .884 r
.46306 .44191 .47016 .45156 .48275 .4481 .47567 .43859 Mtetra
.639 .695 .885 r
.47567 .43859 .48275 .4481 .4954 .44439 .48835 .435 Mtetra
.646 .701 .886 r
.48835 .435 .4954 .44439 .50811 .44046 .5011 .43115 Mtetra
.654 .706 .886 r
.5011 .43115 .50811 .44046 .52088 .43634 .5139 .42703 Mtetra
.661 .71 .884 r
.5139 .42703 .52088 .43634 .53372 .43202 .52677 .42264 Mtetra
.669 .712 .881 r
.52677 .42264 .53372 .43202 .54661 .42752 .53969 .41792 Mtetra
.677 .711 .874 r
.53969 .41792 .54661 .42752 .55955 .42282 .55267 .41285 Mtetra
.684 .706 .865 r
.55267 .41285 .55955 .42282 .57255 .41789 .5657 .40741 Mtetra
.685 .697 .855 r
.5657 .40741 .57255 .41789 .5856 .41258 .57877 .40181 Mtetra
.679 .689 .853 r
.57877 .40181 .5856 .41258 .59869 .40673 .59191 .39642 Mtetra
.662 .693 .868 r
.59191 .39642 .59869 .40673 .61182 .40031 .60511 .39179 Mtetra
.627 .723 .916 r
.60511 .39179 .61182 .40031 .62498 .39367 .61842 .38841 Mtetra
.543 .794 .991 r
.61842 .38841 .62498 .39367 .63821 .38771 .63183 .38611 Mtetra
.364 .816 .939 r
.63183 .38611 .63821 .38771 .65155 .38309 .64532 .38375 Mtetra
.304 .798 .799 r
.64532 .38375 .65155 .38309 .66499 .37953 .65883 .37983 Mtetra
.441 .878 .857 r
.65883 .37983 .66499 .37953 .67856 .37713 .67235 .37462 Mtetra
.357 .794 .964 r
.67235 .37462 .67856 .37713 .69252 .38054 .68611 .37306 Mtetra
0 .224 .725 r
.68611 .37306 .69252 .38054 .70735 .39697 .70064 .38383 Mtetra
0 0 .534 r
.70064 .38383 .70735 .39697 .72292 .42156 .71606 .40622 Mtetra
.129 .301 .77 r
.71606 .40622 .72292 .42156 .73784 .43103 .73116 .41862 Mtetra
.798 .719 .777 r
.73116 .41862 .73784 .43103 .75104 .41325 .74467 .40461 Mtetra
.923 .796 .702 r
.74467 .40461 .75104 .41325 .76348 .38593 .75729 .37847 Mtetra
.899 .827 .766 r
.75729 .37847 .76348 .38593 .77647 .36719 .77033 .35932 Mtetra
.785 .809 .872 r
.77033 .35932 .77647 .36719 .79017 .35775 .78406 .34945 Mtetra
.689 .769 .912 r
.78406 .34945 .79017 .35775 .80424 .35216 .79817 .34369 Mtetra
.66 .754 .919 r
.79817 .34369 .80424 .35216 .81845 .34743 .81243 .3389 Mtetra
.656 .752 .92 r
.81243 .3389 .81845 .34743 .83275 .34281 .82677 .33423 Mtetra
.656 .751 .92 r
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Mtetra
.202 .52757 .20992 .53448 .22143 .53075 .21354 .52381 Mtetra
.655 .751 .92 r
.21354 .52381 .22143 .53075 .23299 .52701 .22513 .52003 Mtetra
.65 .75 .923 r
.22513 .52003 .23299 .52701 .24459 .52338 .23676 .51641 Mtetra
.609 .739 .938 r
.23676 .51641 .24459 .52338 .25617 .52069 .24836 .5138 Mtetra
.353 .637 .961 r
.24836 .5138 .25617 .52069 .2675 .52194 .25969 .51528 Mtetra
.516 0 0 r
.25969 .51528 .2675 .52194 .27827 .53206 .27046 .52524 Mtetra
.745 .246 0 r
.27046 .52524 .27827 .53206 .28872 .54884 .28104 .54001 Mtetra
.416 .611 .929 r
.28104 .54001 .28872 .54884 .30014 .55389 .29271 .5415 Mtetra
.832 .696 .714 r
.29271 .5415 .30014 .55389 .31329 .53349 .30596 .52033 Mtetra
.848 .693 .689 r
.30596 .52033 .31329 .53349 .32695 .50351 .31946 .49403 Mtetra
.819 .732 .769 r
.31946 .49403 .32695 .50351 .33984 .48481 .33218 .4793 Mtetra
.691 .812 .94 r
.33218 .4793 .33984 .48481 .35205 .47815 .34434 .47426 Mtetra
.534 .823 .999 r
.34434 .47426 .35205 .47815 .36412 .475 .35642 .47188 Mtetra
.546 .853 .998 r
.35642 .47188 .36412 .475 .37631 .47051 .36859 .46891 Mtetra
.575 .906 .979 r
.36859 .46891 .37631 .47051 .38862 .46449 .38088 .46461 Mtetra
.584 .939 .927 r
.38088 .46461 .38862 .46449 .40096 .45861 .39328 .45891 Mtetra
.623 .954 .921 r
.39328 .45891 .40096 .45861 .4133 .454 .40575 .45248 Mtetra
.682 .939 .964 r
.40575 .45248 .4133 .454 .42566 .4506 .41826 .44626 Mtetra
.691 .858 .962 r
.41826 .44626 .42566 .4506 .43806 .44776 .43078 .4409 Mtetra
.669 .774 .928 r
.43078 .4409 .43806 .44776 .45053 .44494 .44332 .43638 Mtetra
.651 .722 .901 r
.44332 .43638 .45053 .44494 .46306 .44191 .45591 .43242 Mtetra
.644 .698 .885 r
.45591 .43242 .46306 .44191 .47567 .43859 .46856 .42866 Mtetra
.643 .688 .877 r
.46856 .42866 .47567 .43859 .48835 .435 .48126 .42488 Mtetra
.647 .686 .873 r
.48126 .42488 .48835 .435 .5011 .43115 .49404 .42094 Mtetra
.651 .687 .87 r
.49404 .42094 .5011 .43115 .5139 .42703 .50687 .41681 Mtetra
.655 .689 .869 r
.50687 .41681 .5139 .42703 .52677 .42264 .51977 .41251 Mtetra
.657 .693 .871 r
.51977 .41251 .52677 .42264 .53969 .41792 .53272 .40813 Mtetra
.657 .701 .879 r
.53272 .40813 .53969 .41792 .55267 .41285 .54574 .40379 Mtetra
.651 .717 .896 r
.54574 .40379 .55267 .41285 .5657 .40741 .55882 .39966 Mtetra
.639 .749 .928 r
.55882 .39966 .5657 .40741 .57877 .40181 .57197 .39586 Mtetra
.605 .794 .972 r
.57197 .39586 .57877 .40181 .59191 .39642 .58519 .39258 Mtetra
.517 .832 1 r
.58519 .39258 .59191 .39642 .60511 .39179 .59851 .38994 Mtetra
.372 .816 .95 r
.59851 .38994 .60511 .39179 .61842 .38841 .61191 .38773 Mtetra
.301 .792 .88 r
.61191 .38773 .61842 .38841 .63183 .38611 .62539 .38523 Mtetra
.423 .861 .92 r
.62539 .38523 .63183 .38611 .64532 .38375 .6389 .38148 Mtetra
.611 .919 .976 r
.6389 .38148 .64532 .38375 .65883 .37983 .65242 .37614 Mtetra
.688 .902 .973 r
.65242 .37614 .65883 .37983 .67235 .37462 .66597 .36998 Mtetra
.577 .835 .994 r
.66597 .36998 .67235 .37462 .68611 .37306 .6797 .36657 Mtetra
0 .417 .853 r
.6797 .36657 .68611 .37306 .70064 .38383 .69403 .37315 Mtetra
0 .005 .567 r
.69403 .37315 .70064 .38383 .71606 .40622 .70922 .39164 Mtetra
.065 .272 .762 r
.70922 .39164 .71606 .40622 .73116 .41862 .72435 .40477 Mtetra
.742 .678 .789 r
.72435 .40477 .73116 .41862 .74467 .40461 .73815 .3944 Mtetra
.899 .774 .714 r
.73815 .3944 .74467 .40461 .75729 .37847 .75099 .3703 Mtetra
.891 .813 .765 r
.75099 .3703 .75729 .37847 .77033 .35932 .76412 .35126 Mtetra
.789 .807 .867 r
.76412 .35126 .77033 .35932 .78406 .34945 .77789 .34106 Mtetra
.692 .77 .911 r
.77789 .34106 .78406 .34945 .79817 .34369 .79204 .33514 Mtetra
.661 .754 .919 r
.79204 .33514 .79817 .34369 .81243 .3389 .80635 .33028 Mtetra
.656 .752 .92 r
.80635 .33028 .81243 .3389 .82677 .33423 .82074 .32557 Mtetra
.656 .751 .92 r
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Mtetra
.19402 .5206 .202 .52757 .21354 .52381 .20559 .51681 Mtetra
.655 .751 .92 r
.20559 .51681 .21354 .52381 .22513 .52003 .21721 .51301 Mtetra
.649 .75 .923 r
.21721 .51301 .22513 .52003 .23676 .51641 .22887 .50936 Mtetra
.606 .738 .938 r
.22887 .50936 .23676 .51641 .24836 .5138 .24048 .5068 Mtetra
.352 .635 .96 r
.24048 .5068 .24836 .5138 .25969 .51528 .25183 .5083 Mtetra
0 .077 .558 r
.25183 .5083 .25969 .51528 .27046 .52524 .26266 .51753 Mtetra
.603 .1 0 r
.26266 .51753 .27046 .52524 .28104 .54001 .27339 .52986 Mtetra
.555 .642 .891 r
.27339 .52986 .28104 .54001 .29271 .5415 .28525 .52889 Mtetra
.824 .693 .719 r
.28525 .52889 .29271 .5415 .30596 .52033 .29847 .50894 Mtetra
.846 .71 .712 r
.29847 .50894 .30596 .52033 .31946 .49403 .31179 .48659 Mtetra
.816 .772 .811 r
.31179 .48659 .31946 .49403 .33218 .4793 .32442 .47429 Mtetra
.682 .828 .953 r
.32442 .47429 .33218 .4793 .34434 .47426 .33662 .4694 Mtetra
.59 .811 .984 r
.33662 .4694 .34434 .47426 .35642 .47188 .34876 .46646 Mtetra
.608 .799 .973 r
.34876 .46646 .35642 .47188 .36859 .46891 .36097 .46332 Mtetra
.624 .799 .966 r
.36097 .46332 .36859 .46891 .38088 .46461 .37327 .45987 Mtetra
.622 .827 .979 r
.37327 .45987 .38088 .46461 .39328 .45891 .38563 .45621 Mtetra
.601 .887 .991 r
.38563 .45621 .39328 .45891 .40575 .45248 .39807 .45205 Mtetra
.549 .92 .941 r
.39807 .45205 .40575 .45248 .41826 .44626 .4106 .44711 Mtetra
.514 .914 .879 r
.4106 .44711 .41826 .44626 .43078 .4409 .42319 .44151 Mtetra
.545 .928 .895 r
.42319 .44151 .43078 .4409 .44332 .43638 .43584 .43568 Mtetra
.606 .938 .95 r
.43584 .43568 .44332 .43638 .45591 .43242 .44854 .43003 Mtetra
.646 .913 .98 r
.44854 .43003 .45591 .43242 .46856 .42866 .46127 .42476 Mtetra
.657 .871 .979 r
.46127 .42476 .46856 .42866 .48126 .42488 .47404 .41988 Mtetra
.656 .836 .969 r
.47404 .41988 .48126 .42488 .49404 .42094 .48687 .41533 Mtetra
.65 .816 .963 r
.48687 .41533 .49404 .42094 .50687 .41681 .49975 .41103 Mtetra
.641 .808 .964 r
.49975 .41103 .50687 .41681 .51977 .41251 .5127 .40697 Mtetra
.625 .812 .972 r
.5127 .40697 .51977 .41251 .53272 .40813 .5257 .40319 Mtetra
.593 .823 .987 r
.5257 .40319 .53272 .40813 .54574 .40379 .53878 .39985 Mtetra
.531 .834 .999 r
.53878 .39985 .54574 .40379 .55882 .39966 .55192 .3971 Mtetra
.414 .821 .978 r
.55192 .3971 .55882 .39966 .57197 .39586 .56516 .395 Mtetra
.268 .769 .88 r
.56516 .395 .57197 .39586 .58519 .39258 .57848 .39307 Mtetra
.222 .744 .786 r
.57848 .39307 .58519 .39258 .59851 .38994 .59186 .39034 Mtetra
.375 .841 .844 r
.59186 .39034 .59851 .38994 .61191 .38773 .60529 .38601 Mtetra
.602 .927 .965 r
.60529 .38601 .61191 .38773 .62539 .38523 .61874 .38048 Mtetra
.678 .865 .97 r
.61874 .38048 .62539 .38523 .6389 .38148 .63226 .37494 Mtetra
.679 .808 .944 r
.63226 .37494 .6389 .38148 .65242 .37614 .64583 .36966 Mtetra
.682 .812 .945 r
.64583 .36966 .65242 .37614 .66597 .36998 .65947 .36427 Mtetra
.605 .812 .979 r
.65947 .36427 .66597 .36998 .6797 .36657 .67325 .36066 Mtetra
.139 .548 .923 r
.67325 .36066 .6797 .36657 .69403 .37315 .68748 .36458 Mtetra
0 .098 .631 r
.68748 .36458 .69403 .37315 .70922 .39164 .70244 .37888 Mtetra
.044 .292 .783 r
.70244 .37888 .70922 .39164 .72435 .40477 .71749 .39065 Mtetra
.702 .659 .804 r
.71749 .39065 .72435 .40477 .73815 .3944 .73148 .38278 Mtetra
.872 .752 .728 r
.73148 .38278 .73815 .3944 .75099 .3703 .74458 .36116 Mtetra
.876 .795 .768 r
.74458 .36116 .75099 .3703 .76412 .35126 .75783 .34282 Mtetra
.787 .799 .862 r
.75783 .34282 .76412 .35126 .77789 .34106 .77165 .33255 Mtetra
.694 .769 .909 r
.77165 .33255 .77789 .34106 .79204 .33514 .78585 .32651 Mtetra
.662 .754 .919 r
.78585 .32651 .79204 .33514 .80635 .33028 .80021 .32159 Mtetra
.656 .752 .92 r
.80021 .32159 .80635 .33028 .82074 .32557 .81466 .31683 Mtetra
.656 .751 .92 r
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Mtetra
.18597 .51357 .19402 .5206 .20559 .51681 .19757 .50975 Mtetra
.655 .751 .921 r
.19757 .50975 .20559 .51681 .21721 .51301 .20922 .50592 Mtetra
.649 .75 .923 r
.20922 .50592 .21721 .51301 .22887 .50936 .2209 .50225 Mtetra
.606 .738 .938 r
.2209 .50225 .22887 .50936 .24048 .5068 .23255 .49965 Mtetra
.377 .644 .96 r
.23255 .49965 .24048 .5068 .25183 .5083 .24393 .50087 Mtetra
0 .191 .678 r
.24393 .50087 .25183 .5083 .26266 .51753 .25485 .50888 Mtetra
0 .09 .608 r
.25485 .50888 .26266 .51753 .27339 .52986 .26575 .51891 Mtetra
.594 .642 .868 r
.26575 .51891 .27339 .52986 .28525 .52889 .2777 .51687 Mtetra
.816 .698 .735 r
.2777 .51687 .28525 .52889 .29847 .50894 .29081 .49929 Mtetra
.845 .732 .739 r
.29081 .49929 .29847 .50894 .31179 .48659 .30397 .48026 Mtetra
.812 .799 .84 r
.30397 .48026 .31179 .48659 .32442 .47429 .31658 .46925 Mtetra
.694 .831 .949 r
.31658 .46925 .32442 .47429 .33662 .4694 .32884 .46401 Mtetra
.626 .805 .969 r
.32884 .46401 .33662 .4694 .34876 .46646 .34105 .46048 Mtetra
.627 .788 .959 r
.34105 .46048 .34876 .46646 .36097 .46332 .35332 .45701 Mtetra
.638 .781 .95 r
.35332 .45701 .36097 .46332 .37327 .45987 .36566 .45332 Mtetra
.647 .777 .943 r
.36566 .45332 .37327 .45987 .38563 .45621 .37807 .44941 Mtetra
.646 .77 .939 r
.37807 .44941 .38563 .45621 .39807 .45205 .39054 .44553 Mtetra
.638 .778 .948 r
.39054 .44553 .39807 .45205 .4106 .44711 .40306 .44179 Mtetra
.625 .813 .972 r
.40306 .44179 .4106 .44711 .42319 .44151 .41564 .43809 Mtetra
.597 .868 .993 r
.41564 .43809 .42319 .44151 .43584 .43568 .42829 .43421 Mtetra
.535 .898 .97 r
.42829 .43421 .43584 .43568 .44854 .43003 .44101 .43006 Mtetra
.454 .882 .901 r
.44101 .43006 .44854 .43003 .46127 .42476 .45379 .42568 Mtetra
.388 .849 .835 r
.45379 .42568 .46127 .42476 .47404 .41988 .46663 .42119 Mtetra
.349 .824 .798 r
.46663 .42119 .47404 .41988 .48687 .41533 .47953 .4167 Mtetra
.331 .813 .785 r
.47953 .4167 .48687 .41533 .49975 .41103 .49249 .4123 Mtetra
.324 .809 .787 r
.49249 .4123 .49975 .41103 .5127 .40697 .50551 .40801 Mtetra
.332 .815 .802 r
.50551 .40801 .5127 .40697 .5257 .40319 .5186 .4038 Mtetra
.379 .844 .842 r
.5186 .4038 .5257 .40319 .53878 .39985 .53174 .39945 Mtetra
.488 .897 .918 r
.53174 .39945 .53878 .39985 .55192 .3971 .54495 .3947 Mtetra
.624 .916 .98 r
.54495 .3947 .55192 .3971 .56516 .395 .55821 .3894 Mtetra
.677 .833 .958 r
.55821 .3894 .56516 .395 .57848 .39307 .57153 .38416 Mtetra
.648 .727 .906 r
.57153 .38416 .57848 .39307 .59186 .39034 .58492 .37999 Mtetra
.613 .679 .888 r
.58492 .37999 .59186 .39034 .60529 .38601 .59841 .37699 Mtetra
.618 .714 .915 r
.59841 .37699 .60529 .38601 .61874 .38048 .61197 .37374 Mtetra
.664 .798 .947 r
.61197 .37374 .61874 .38048 .63226 .37494 .62556 .36892 Mtetra
.691 .83 .95 r
.62556 .36892 .63226 .37494 .64583 .36966 .63918 .36319 Mtetra
.677 .813 .948 r
.63918 .36319 .64583 .36966 .65947 .36427 .65288 .35789 Mtetra
.597 .789 .972 r
.65288 .35789 .65947 .36427 .67325 .36066 .66673 .35461 Mtetra
.244 .615 .956 r
.66673 .35461 .67325 .36066 .68748 .36458 .68094 .35717 Mtetra
0 .225 .722 r
.68094 .35717 .68748 .36458 .70244 .37888 .69572 .3679 Mtetra
.086 .363 .83 r
.69572 .3679 .70244 .37888 .71749 .39065 .71063 .3771 Mtetra
.688 .661 .819 r
.71063 .3771 .71749 .39065 .73148 .38278 .72472 .37026 Mtetra
.847 .736 .741 r
.72472 .37026 .73148 .38278 .74458 .36116 .73804 .35101 Mtetra
.855 .776 .773 r
.73804 .35101 .74458 .36116 .75783 .34282 .75145 .33391 Mtetra
.778 .787 .86 r
.75145 .33391 .75783 .34282 .77165 .33255 .76536 .32387 Mtetra
.693 .766 .908 r
.76536 .32387 .77165 .33255 .78585 .32651 .77961 .31779 Mtetra
.662 .754 .919 r
.77961 .31779 .78585 .32651 .80021 .32159 .79402 .31282 Mtetra
.656 .752 .92 r
.79402 .31282 .80021 .32159 .81466 .31683 .80851 .30801 Mtetra
.656 .751 .92 r
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Mtetra
.17785 .50649 .18597 .51357 .19757 .50975 .18948 .50263 Mtetra
.655 .751 .921 r
.18948 .50263 .19757 .50975 .20922 .50592 .20116 .49877 Mtetra
.649 .75 .923 r
.20116 .49877 .20922 .50592 .2209 .50225 .21288 .49506 Mtetra
.611 .738 .936 r
.21288 .49506 .2209 .50225 .23255 .49965 .22456 .49233 Mtetra
.422 .662 .96 r
.22456 .49233 .23255 .49965 .24393 .50087 .23601 .49298 Mtetra
0 .327 .799 r
.23601 .49298 .24393 .50087 .25485 .50888 .24705 .49948 Mtetra
0 .253 .758 r
.24705 .49948 .25485 .50888 .26575 .51891 .25809 .50759 Mtetra
.59 .634 .863 r
.25809 .50759 .26575 .51891 .2777 .51687 .27004 .50566 Mtetra
.803 .707 .759 r
.27004 .50566 .2777 .51687 .29081 .49929 .283 .49086 Mtetra
.841 .753 .766 r
.283 .49086 .29081 .49929 .30397 .48026 .29605 .47439 Mtetra
.808 .813 .855 r
.29605 .47439 .30397 .48026 .31658 .46925 .30867 .46398 Mtetra
.708 .827 .939 r
.30867 .46398 .31658 .46925 .32884 .46401 .321 .45829 Mtetra
.65 .803 .956 r
.321 .45829 .32884 .46401 .34105 .46048 .33328 .45421 Mtetra
.643 .785 .949 r
.33328 .45421 .34105 .46048 .35332 .45701 .34561 .45036 Mtetra
.644 .774 .943 r
.34561 .45036 .35332 .45701 .36566 .45332 .358 .44652 Mtetra
.642 .77 .941 r
.358 .44652 .36566 .45332 .37807 .44941 .37044 .44272 Mtetra
.646 .776 .942 r
.37044 .44272 .37807 .44941 .39054 .44553 .38294 .43878 Mtetra
.653 .777 .939 r
.38294 .43878 .39054 .44553 .40306 .44179 .39552 .43463 Mtetra
.658 .767 .93 r
.39552 .43463 .40306 .44179 .41564 .43809 .40816 .43035 Mtetra
.658 .752 .919 r
.40816 .43035 .41564 .43809 .42829 .43421 .42086 .42607 Mtetra
.656 .741 .912 r
.42086 .42607 .42829 .43421 .44101 .43006 .43361 .42183 Mtetra
.656 .74 .912 r
.43361 .42183 .44101 .43006 .45379 .42568 .44643 .41758 Mtetra
.658 .745 .914 r
.44643 .41758 .45379 .42568 .46663 .42119 .4593 .41324 Mtetra
.66 .751 .917 r
.4593 .41324 .46663 .42119 .47953 .4167 .47224 .40879 Mtetra
.662 .754 .918 r
.47224 .40879 .47953 .4167 .49249 .4123 .48524 .40428 Mtetra
.661 .751 .917 r
.48524 .40428 .49249 .4123 .50551 .40801 .4983 .39978 Mtetra
.656 .745 .915 r
.4983 .39978 .50551 .40801 .5186 .4038 .51143 .39541 Mtetra
.648 .739 .916 r
.51143 .39541 .5186 .4038 .53174 .39945 .52461 .39129 Mtetra
.639 .743 .924 r
.52461 .39129 .53174 .39945 .54495 .3947 .53786 .3874 Mtetra
.638 .768 .942 r
.53786 .3874 .54495 .3947 .55821 .3894 .55118 .38346 Mtetra
.662 .819 .959 r
.55118 .38346 .55821 .3894 .57153 .38416 .56456 .37864 Mtetra
.696 .843 .953 r
.56456 .37864 .57153 .38416 .58492 .37999 .57798 .37277 Mtetra
.688 .791 .928 r
.57798 .37277 .58492 .37999 .59841 .37699 .59146 .36723 Mtetra
.635 .705 .897 r
.59146 .36723 .59841 .37699 .61197 .37374 .60505 .36343 Mtetra
.608 .681 .893 r
.60505 .36343 .61197 .37374 .62556 .36892 .61873 .36051 Mtetra
.639 .743 .924 r
.61873 .36051 .62556 .36892 .63918 .36319 .63246 .35649 Mtetra
.662 .803 .951 r
.63246 .35649 .63918 .36319 .65288 .35789 .64623 .35162 Mtetra
.591 .792 .976 r
.64623 .35162 .65288 .35789 .66673 .35461 .66013 .3484 Mtetra
.302 .647 .968 r
.66013 .3484 .66673 .35461 .68094 .35717 .67435 .35019 Mtetra
0 .353 .813 r
.67435 .35019 .68094 .35717 .69572 .3679 .68902 .35816 Mtetra
.19 .467 .887 r
.68902 .35816 .69572 .3679 .71063 .3771 .70377 .36434 Mtetra
.695 .679 .83 r
.70377 .36434 .71063 .3771 .72472 .37026 .7179 .35731 Mtetra
.828 .726 .753 r
.7179 .35731 .72472 .37026 .73804 .35101 .7314 .34002 Mtetra
.832 .758 .782 r
.7314 .34002 .73804 .35101 .75145 .33391 .74498 .32447 Mtetra
.764 .773 .86 r
.74498 .32447 .75145 .33391 .76536 .32387 .75899 .31497 Mtetra
.69 .762 .906 r
.75899 .31497 .76536 .32387 .77961 .31779 .77331 .30896 Mtetra
.662 .753 .918 r
.77331 .30896 .77961 .31779 .79402 .31282 .78777 .30396 Mtetra
.656 .752 .92 r
.78777 .30396 .79402 .31282 .80851 .30801 .80231 .29911 Mtetra
.656 .751 .92 r
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Mtetra
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49546 Mtetra
.655 .751 .92 r
.18133 .49546 .18948 .50263 .20116 .49877 .19304 .49156 Mtetra
.65 .75 .922 r
.19304 .49156 .20116 .49877 .21288 .49506 .20479 .48779 Mtetra
.619 .74 .933 r
.20479 .48779 .21288 .49506 .22456 .49233 .21652 .48483 Mtetra
.476 .682 .956 r
.21652 .48483 .22456 .49233 .23601 .49298 .22805 .48469 Mtetra
.094 .451 .883 r
.22805 .48469 .23601 .49298 .24705 .49948 .23923 .48953 Mtetra
.029 .359 .832 r
.23923 .48953 .24705 .49948 .25809 .50759 .25039 .49617 Mtetra
.56 .62 .869 r
.25039 .49617 .25809 .50759 .27004 .50566 .26228 .49509 Mtetra
.783 .714 .786 r
.26228 .49509 .27004 .50566 .283 .49086 .27507 .48314 Mtetra
.834 .768 .79 r
.27507 .48314 .283 .49086 .29605 .47439 .28804 .46867 Mtetra
.805 .819 .862 r
.28804 .46867 .29605 .47439 .30867 .46398 .30069 .45851 Mtetra
.723 .825 .928 r
.30069 .45851 .30867 .46398 .321 .45829 .3131 .4523 Mtetra
.667 .8 .946 r
.3131 .4523 .321 .45829 .33328 .45421 .32545 .44778 Mtetra
.652 .784 .944 r
.32545 .44778 .33328 .45421 .34561 .45036 .33783 .44368 Mtetra
.651 .777 .941 r
.33783 .44368 .34561 .45036 .358 .44652 .35026 .43962 Mtetra
.654 .773 .936 r
.35026 .43962 .358 .44652 .37044 .44272 .36276 .43548 Mtetra
.651 .763 .931 r
.36276 .43548 .37044 .44272 .38294 .43878 .3753 .43142 Mtetra
.647 .759 .931 r
.3753 .43142 .38294 .43878 .39552 .43463 .38791 .42744 Mtetra
.646 .765 .935 r
.38791 .42744 .39552 .43463 .40816 .43035 .40058 .42345 Mtetra
.65 .776 .94 r
.40058 .42345 .40816 .43035 .42086 .42607 .41331 .41933 Mtetra
.655 .783 .942 r
.41331 .41933 .42086 .42607 .43361 .42183 .42611 .41501 Mtetra
.662 .783 .939 r
.42611 .41501 .43361 .42183 .44643 .41758 .43897 .4105 Mtetra
.661 .776 .935 r
.43897 .4105 .44643 .41758 .4593 .41324 .45189 .40601 Mtetra
.654 .771 .935 r
.45189 .40601 .4593 .41324 .47224 .40879 .46487 .40168 Mtetra
.644 .773 .941 r
.46487 .40168 .47224 .40879 .48524 .40428 .47791 .39761 Mtetra
.633 .784 .954 r
.47791 .39761 .48524 .40428 .4983 .39978 .49101 .39376 Mtetra
.624 .802 .968 r
.49101 .39376 .4983 .39978 .51143 .39541 .50418 .38998 Mtetra
.625 .823 .976 r
.50418 .38998 .51143 .39541 .52461 .39129 .51741 .38598 Mtetra
.631 .83 .977 r
.51741 .38598 .52461 .39129 .53786 .3874 .53072 .38178 Mtetra
.632 .821 .973 r
.53072 .38178 .53786 .3874 .55118 .38346 .54409 .37762 Mtetra
.626 .813 .972 r
.54409 .37762 .55118 .38346 .56456 .37864 .55753 .37361 Mtetra
.654 .85 .975 r
.55753 .37361 .56456 .37864 .57798 .37277 .57102 .3687 Mtetra
.704 .894 .966 r
.57102 .3687 .57798 .37277 .59146 .36723 .58455 .36223 Mtetra
.707 .867 .958 r
.58455 .36223 .59146 .36723 .60505 .36343 .59813 .35586 Mtetra
.648 .772 .939 r
.59813 .35586 .60505 .36343 .61873 .36051 .61182 .35147 Mtetra
.612 .718 .92 r
.61182 .35147 .61873 .36051 .63246 .35649 .62562 .34828 Mtetra
.62 .745 .936 r
.62562 .34828 .63246 .35649 .64623 .35162 .63948 .34474 Mtetra
.571 .766 .97 r
.63948 .34474 .64623 .35162 .66013 .3484 .65347 .3421 Mtetra
.334 .666 .974 r
.65347 .3421 .66013 .3484 .67435 .35019 .66771 .3434 Mtetra
.053 .466 .884 r
.66771 .3434 .67435 .35019 .68902 .35816 .6823 .34911 Mtetra
.331 .577 .931 r
.6823 .34911 .68902 .35816 .70377 .36434 .69691 .3522 Mtetra
.717 .7 .833 r
.69691 .3522 .70377 .36434 .7179 .35731 .71102 .34419 Mtetra
.812 .72 .763 r
.71102 .34419 .7179 .35731 .7314 .34002 .72468 .32842 Mtetra
.807 .743 .792 r
.72468 .32842 .7314 .34002 .74498 .32447 .73844 .3146 Mtetra
.746 .759 .863 r
.73844 .3146 .74498 .32447 .75899 .31497 .75256 .30587 Mtetra
.684 .756 .906 r
.75256 .30587 .75899 .31497 .77331 .30896 .76694 .30004 Mtetra
.661 .752 .918 r
.76694 .30004 .77331 .30896 .78777 .30396 .78146 .29502 Mtetra
.656 .751 .92 r
.78146 .29502 .78777 .30396 .80231 .29911 .79606 .29013 Mtetra
.79606 .29013 .80231 .29911 .81694 .29425 .81073 .28522 Mtetra
.16141 .49214 .16967 .49935 .18133 .49546 .1731 .48822 Mtetra
.655 .751 .92 r
.1731 .48822 .18133 .49546 .19304 .49156 .18484 .48428 Mtetra
.652 .75 .922 r
.18484 .48428 .19304 .49156 .20479 .48779 .19663 .48044 Mtetra
.629 .743 .93 r
.19663 .48044 .20479 .48779 .21652 .48483 .20841 .47719 Mtetra
.529 .702 .949 r
.20841 .47719 .21652 .48483 .22805 .48469 .22005 .47614 Mtetra
.264 .546 .925 r
.22005 .47614 .22805 .48469 .23923 .48953 .23139 .47926 Mtetra
.151 .43 .868 r
.23139 .47926 .23923 .48953 .25039 .49617 .24263 .48467 Mtetra
.51 .597 .877 r
.24263 .48467 .25039 .49617 .26228 .49509 .25443 .48483 Mtetra
.751 .713 .816 r
.25443 .48483 .26228 .49509 .27507 .48314 .26704 .47571 Mtetra
.821 .776 .811 r
.26704 .47571 .27507 .48314 .28804 .46867 .27994 .46298 Mtetra
.804 .821 .865 r
.27994 .46298 .28804 .46867 .30069 .45851 .29264 .4529 Mtetra
.735 .824 .919 r
.29264 .4529 .30069 .45851 .3131 .4523 .30513 .44621 Mtetra
.683 .802 .939 r
.30513 .44621 .3131 .4523 .32545 .44778 .31755 .44122 Mtetra
.662 .784 .939 r
.31755 .44122 .32545 .44778 .33783 .44368 .32998 .43681 Mtetra
.655 .774 .937 r
.32998 .43681 .33783 .44368 .35026 .43962 .34246 .43261 Mtetra
.65 .77 .936 r
.34246 .43261 .35026 .43962 .36276 .43548 .35499 .42853 Mtetra
.653 .773 .937 r
.35499 .42853 .36276 .43548 .3753 .43142 .36758 .42435 Mtetra
.658 .773 .934 r
.36758 .42435 .3753 .43142 .38791 .42744 .38024 .42002 Mtetra
.661 .764 .927 r
.38024 .42002 .38791 .42744 .40058 .42345 .39296 .4156 Mtetra
.66 .753 .919 r
.39296 .4156 .40058 .42345 .41331 .41933 .40574 .41116 Mtetra
.663 .747 .912 r
.40574 .41116 .41331 .41933 .42611 .41501 .41858 .40662 Mtetra
.659 .74 .91 r
.41858 .40662 .42611 .41501 .43897 .4105 .43148 .40219 Mtetra
.65 .741 .916 r
.43148 .40219 .43897 .4105 .45189 .40601 .44443 .39802 Mtetra
.648 .75 .924 r
.44443 .39802 .45189 .40601 .46487 .40168 .45744 .39389 Mtetra
.65 .757 .927 r
.45744 .39389 .46487 .40168 .47791 .39761 .47052 .38966 Mtetra
.651 .754 .925 r
.47052 .38966 .47791 .39761 .49101 .39376 .48367 .38538 Mtetra
.654 .744 .916 r
.48367 .38538 .49101 .39376 .50418 .38998 .49688 .381 Mtetra
.659 .732 .903 r
.49688 .381 .50418 .38998 .51741 .38598 .51015 .37643 Mtetra
.664 .72 .89 r
.51015 .37643 .51741 .38598 .53072 .38178 .52349 .3716 Mtetra
.655 .703 .882 r
.52349 .3716 .53072 .38178 .54409 .37762 .5369 .36705 Mtetra
.622 .682 .886 r
.5369 .36705 .54409 .37762 .55753 .37361 .55037 .36363 Mtetra
.599 .687 .904 r
.55037 .36363 .55753 .37361 .57102 .3687 .56394 .36093 Mtetra
.648 .766 .935 r
.56394 .36093 .57102 .3687 .58455 .36223 .57755 .35657 Mtetra
.713 .85 .947 r
.57755 .35657 .58455 .36223 .59813 .35586 .59119 .35005 Mtetra
.694 .841 .954 r
.59119 .35005 .59813 .35586 .61182 .35147 .6049 .3441 Mtetra
.626 .773 .951 r
.6049 .3441 .61182 .35147 .62562 .34828 .61872 .34024 Mtetra
.592 .74 .947 r
.61872 .34024 .62562 .34828 .63948 .34474 .63266 .33736 Mtetra
.541 .739 .967 r
.63266 .33736 .63948 .34474 .65347 .3421 .64672 .3355 Mtetra
.354 .669 .975 r
.64672 .3355 .65347 .3421 .66771 .3434 .66101 .33664 Mtetra
.19 .563 .936 r
.66101 .33664 .66771 .3434 .6823 .34911 .67554 .34032 Mtetra
.477 .669 .947 r
.67554 .34032 .6823 .34911 .69691 .3522 .69002 .34028 Mtetra
.741 .715 .827 r
.69002 .34028 .69691 .3522 .71102 .34419 .7041 .33093 Mtetra
.798 .715 .773 r
.7041 .33093 .71102 .34419 .72468 .32842 .71789 .31647 Mtetra
.781 .73 .805 r
.71789 .31647 .72468 .32842 .73844 .3146 .73182 .30444 Mtetra
.725 .747 .869 r
.73182 .30444 .73844 .3146 .75256 .30587 .74606 .29662 Mtetra
.677 .752 .907 r
.74606 .29662 .75256 .30587 .76694 .30004 .76052 .29101 Mtetra
.659 .751 .918 r
.76052 .29101 .76694 .30004 .78146 .29502 .77509 .28599 Mtetra
.656 .751 .92 r
.77509 .28599 .78146 .29502 .79606 .29013 .78974 .28106 Mtetra
.78974 .28106 .79606 .29013 .81073 .28522 .80447 .27611 Mtetra
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Mtetra
.16481 .48092 .1731 .48822 .18484 .48428 .17658 .47695 Mtetra
.653 .751 .921 r
.17658 .47695 .18484 .48428 .19663 .48044 .1884 .47302 Mtetra
.639 .746 .926 r
.1884 .47302 .19663 .48044 .20841 .47719 .20024 .46949 Mtetra
.574 .718 .94 r
.20024 .46949 .20841 .47719 .22005 .47614 .21198 .46751 Mtetra
.397 .616 .939 r
.21198 .46751 .22005 .47614 .23139 .47926 .22349 .46888 Mtetra
.251 .489 .89 r
.22349 .46888 .23139 .47926 .24263 .48467 .23484 .47305 Mtetra
.454 .568 .881 r
.23484 .47305 .24263 .48467 .25443 .48483 .24654 .47443 Mtetra
.7 .698 .845 r
.24654 .47443 .25443 .48483 .26704 .47571 .25895 .46821 Mtetra
.8 .777 .832 r
.25895 .46821 .26704 .47571 .27994 .46298 .27176 .45726 Mtetra
.802 .822 .867 r
.27176 .45726 .27994 .46298 .29264 .4529 .28451 .44728 Mtetra
.748 .826 .912 r
.28451 .44728 .29264 .4529 .30513 .44621 .29709 .44003 Mtetra
.695 .804 .932 r
.29709 .44003 .30513 .44621 .31755 .44122 .30957 .43461 Mtetra
.67 .787 .936 r
.30957 .43461 .31755 .44122 .32998 .43681 .32206 .42996 Mtetra
.661 .779 .936 r
.32206 .42996 .32998 .43681 .34246 .43261 .33458 .42553 Mtetra
.66 .773 .933 r
.33458 .42553 .34246 .43261 .35499 .42853 .34717 .42114 Mtetra
.656 .764 .929 r
.34717 .42114 .35499 .42853 .36758 .42435 .3598 .41686 Mtetra
.653 .761 .929 r
.3598 .41686 .36758 .42435 .38024 .42002 .37249 .41265 Mtetra
.652 .765 .932 r
.37249 .41265 .38024 .42002 .39296 .4156 .38524 .40843 Mtetra
.66 .774 .934 r
.38524 .40843 .39296 .4156 .40574 .41116 .39806 .40394 Mtetra
.662 .774 .933 r
.39806 .40394 .40574 .41116 .41858 .40662 .41094 .39937 Mtetra
.65 .771 .937 r
.41094 .39937 .41858 .40662 .43148 .40219 .42388 .39513 Mtetra
.649 .777 .942 r
.42388 .39513 .43148 .40219 .44443 .39802 .43687 .39089 Mtetra
.669 .783 .934 r
.43687 .39089 .44443 .39802 .45744 .39389 .44995 .38605 Mtetra
.676 .766 .919 r
.44995 .38605 .45744 .39389 .47052 .38966 .46308 .38098 Mtetra
.673 .744 .904 r
.46308 .38098 .47052 .38966 .48367 .38538 .47628 .37593 Mtetra
.687 .73 .883 r
.47628 .37593 .48367 .38538 .49688 .381 .48954 .37025 Mtetra
.693 .705 .857 r
.48954 .37025 .49688 .381 .51015 .37643 .50286 .36403 Mtetra
.665 .664 .839 r
.50286 .36403 .51015 .37643 .52349 .3716 .51622 .35874 Mtetra
.641 .646 .839 r
.51622 .35874 .52349 .3716 .5369 .36705 .52965 .3544 Mtetra
.615 .639 .851 r
.52965 .3544 .5369 .36705 .55037 .36363 .54315 .35115 Mtetra
.564 .618 .865 r
.54315 .35115 .55037 .36363 .56394 .36093 .55675 .3497 Mtetra
.574 .649 .887 r
.55675 .3497 .56394 .36093 .57755 .35657 .57043 .34781 Mtetra
.659 .746 .914 r
.57043 .34781 .57755 .35657 .59119 .35005 .58416 .34307 Mtetra
.695 .809 .935 r
.58416 .34307 .59119 .35005 .6049 .3441 .59792 .33711 Mtetra
.642 .792 .954 r
.59792 .33711 .6049 .3441 .61872 .34024 .61178 .3327 Mtetra
.577 .751 .96 r
.61178 .3327 .61872 .34024 .63266 .33736 .62577 .33003 Mtetra
.507 .727 .972 r
.62577 .33003 .63266 .33736 .64672 .3355 .6399 .32881 Mtetra
.365 .674 .976 r
.6399 .32881 .64672 .3355 .66101 .33664 .65423 .32975 Mtetra
.333 .65 .969 r
.65423 .32975 .66101 .33664 .67554 .34032 .6687 .33133 Mtetra
.605 .727 .931 r
.6687 .33133 .67554 .34032 .69002 .34028 .68307 .32809 Mtetra
.759 .719 .815 r
.68307 .32809 .69002 .34028 .7041 .33093 .69712 .31748 Mtetra
.781 .707 .782 r
.69712 .31748 .7041 .33093 .71789 .31647 .71104 .30439 Mtetra
.754 .72 .821 r
.71104 .30439 .71789 .31647 .73182 .30444 .72515 .29419 Mtetra
.705 .739 .878 r
.72515 .29419 .73182 .30444 .74606 .29662 .73951 .28728 Mtetra
.669 .748 .91 r
.73951 .28728 .74606 .29662 .76052 .29101 .75403 .28189 Mtetra
.658 .751 .919 r
.75403 .28189 .76052 .29101 .77509 .28599 .76866 .27688 Mtetra
.656 .751 .92 r
.76866 .27688 .77509 .28599 .78974 .28106 .78336 .2719 Mtetra
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Mtetra
.14469 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Mtetra
.15645 .47356 .16481 .48092 .17658 .47695 .16825 .46955 Mtetra
.655 .751 .921 r
.16825 .46955 .17658 .47695 .1884 .47302 .18011 .46556 Mtetra
.646 .748 .923 r
.18011 .46556 .1884 .47302 .20024 .46949 .19199 .46178 Mtetra
.609 .731 .932 r
.19199 .46178 .20024 .46949 .21198 .46751 .20384 .45897 Mtetra
.498 .667 .938 r
.20384 .45897 .21198 .46751 .22349 .46888 .21552 .45863 Mtetra
.351 .549 .907 r
.21552 .45863 .22349 .46888 .23484 .47305 .227 .46128 Mtetra
.41 .544 .88 r
.227 .46128 .23484 .47305 .24654 .47443 .23863 .46351 Mtetra
.627 .664 .866 r
.23863 .46351 .24654 .47443 .25895 .46821 .25082 .46019 Mtetra
.764 .765 .853 r
.25082 .46019 .25895 .46821 .27176 .45726 .26351 .4514 Mtetra
.796 .82 .871 r
.26351 .4514 .27176 .45726 .28451 .44728 .27629 .4417 Mtetra
.76 .83 .906 r
.27629 .4417 .28451 .44728 .29709 .44003 .28895 .43395 Mtetra
.711 .811 .927 r
.28895 .43395 .29709 .44003 .30957 .43461 .30152 .42799 Mtetra
.681 .791 .933 r
.30152 .42799 .30957 .43461 .32206 .42996 .31407 .42297 Mtetra
.666 .778 .933 r
.31407 .42297 .32206 .42996 .33458 .42553 .32664 .41839 Mtetra
.657 .772 .934 r
.32664 .41839 .33458 .42553 .34717 .42114 .33926 .41404 Mtetra
.659 .775 .935 r
.33926 .41404 .34717 .42114 .3598 .41686 .35194 .40961 Mtetra
.662 .772 .931 r
.35194 .40961 .3598 .41686 .37249 .41265 .36468 .40509 Mtetra
.665 .766 .925 r
.36468 .40509 .37249 .41265 .38524 .40843 .37748 .40047 Mtetra
.665 .756 .918 r
.37748 .40047 .38524 .40843 .39806 .40394 .39035 .39581 Mtetra
.658 .75 .918 r
.39035 .39581 .39806 .40394 .41094 .39937 .40327 .39136 Mtetra
.649 .751 .924 r
.40327 .39136 .41094 .39937 .42388 .39513 .41623 .38716 Mtetra
.672 .761 .917 r
.41623 .38716 .42388 .39513 .43687 .39089 .42929 .38221 Mtetra
.696 .75 .894 r
.42929 .38221 .43687 .39089 .44995 .38605 .44243 .37633 Mtetra
.678 .721 .882 r
.44243 .37633 .44995 .38605 .46308 .38098 .45561 .37098 Mtetra
.648 .705 .888 r
.45561 .37098 .46308 .38098 .47628 .37593 .46882 .3667 Mtetra
.69 .739 .888 r
.46882 .3667 .47628 .37593 .48954 .37025 .48212 .36089 Mtetra
.742 .752 .86 r
.48212 .36089 .48954 .37025 .50286 .36403 .4955 .35266 Mtetra
.679 .69 .853 r
.4955 .35266 .50286 .36403 .51622 .35874 .5089 .3469 Mtetra
.626 .66 .863 r
.5089 .3469 .51622 .35874 .52965 .3544 .52236 .34324 Mtetra
.595 .66 .884 r
.52236 .34324 .52965 .3544 .54315 .35115 .53589 .34067 Mtetra
.525 .645 .909 r
.53589 .34067 .54315 .35115 .55675 .3497 .54952 .33999 Mtetra
.537 .671 .923 r
.54952 .33999 .55675 .3497 .57043 .34781 .56325 .33881 Mtetra
.631 .731 .92 r
.56325 .33881 .57043 .34781 .58416 .34307 .57703 .33493 Mtetra
.673 .77 .924 r
.57703 .33493 .58416 .34307 .59792 .33711 .59086 .32967 Mtetra
.634 .778 .95 r
.59086 .32967 .59792 .33711 .61178 .3327 .60478 .32551 Mtetra
.561 .757 .97 r
.60478 .32551 .61178 .3327 .62577 .33003 .61883 .32305 Mtetra
.478 .726 .98 r
.61883 .32305 .62577 .33003 .6399 .32881 .63302 .32217 Mtetra
.394 .695 .981 r
.63302 .32217 .6399 .32881 .65423 .32975 .64737 .32256 Mtetra
.487 .726 .977 r
.64737 .32256 .65423 .32975 .6687 .33133 .66178 .32157 Mtetra
.694 .745 .89 r
.66178 .32157 .6687 .33133 .68307 .32809 .67604 .31521 Mtetra
.763 .71 .802 r
.67604 .31521 .68307 .32809 .69712 .31748 .6901 .30389 Mtetra
.759 .698 .794 r
.6901 .30389 .69712 .31748 .71104 .30439 .70416 .29249 Mtetra
.726 .714 .84 r
.70416 .29249 .71104 .30439 .72515 .29419 .71843 .28404 Mtetra
.686 .736 .889 r
.71843 .28404 .72515 .29419 .73951 .28728 .73289 .27792 Mtetra
.663 .748 .913 r
.73289 .27792 .73951 .28728 .75403 .28189 .74749 .2727 Mtetra
.657 .751 .919 r
.74749 .2727 .75403 .28189 .76866 .27688 .76217 .26768 Mtetra
.656 .751 .92 r
.76217 .26768 .76866 .27688 .78336 .2719 .77693 .26266 Mtetra
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Mtetra
.13623 .47016 .14469 .47755 .15645 .47356 .14801 .46614 Mtetra
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Mtetra
.655 .751 .92 r
.15985 .46209 .16825 .46955 .18011 .46556 .17174 .45804 Mtetra
.652 .75 .922 r
.17174 .45804 .18011 .46556 .19199 .46178 .18367 .45408 Mtetra
.633 .74 .926 r
.18367 .45408 .19199 .46178 .20384 .45897 .1956 .45063 Mtetra
.57 .703 .932 r
.1956 .45063 .20384 .45897 .21552 .45863 .20745 .44877 Mtetra
.451 .612 .917 r
.20745 .44877 .21552 .45863 .227 .46128 .21911 .44959 Mtetra
.406 .546 .883 r
.21911 .44959 .227 .46128 .23863 .46351 .23073 .45179 Mtetra
.539 .611 .874 r
.23073 .45179 .23863 .46351 .25082 .46019 .24271 .4511 Mtetra
.702 .73 .872 r
.24271 .4511 .25082 .46019 .26351 .4514 .25521 .44507 Mtetra
.777 .81 .879 r
.25521 .44507 .26351 .4514 .27629 .4417 .26798 .43623 Mtetra
.769 .834 .902 r
.26798 .43623 .27629 .4417 .28895 .43395 .28072 .42804 Mtetra
.727 .82 .923 r
.28072 .42804 .28895 .43395 .30152 .42799 .29337 .42149 Mtetra
.691 .798 .932 r
.29337 .42149 .30152 .42799 .31407 .42297 .30598 .41612 Mtetra
.675 .786 .933 r
.30598 .41612 .31407 .42297 .32664 .41839 .31862 .41124 Mtetra
.668 .776 .931 r
.31862 .41124 .32664 .41839 .33926 .41404 .33129 .40654 Mtetra
.661 .766 .927 r
.33129 .40654 .33926 .41404 .35194 .40961 .34401 .40203 Mtetra
.656 .763 .928 r
.34401 .40203 .35194 .40961 .36468 .40509 .35679 .39765 Mtetra
.657 .768 .931 r
.35679 .39765 .36468 .40509 .37748 .40047 .36962 .3932 Mtetra
.661 .776 .934 r
.36962 .3932 .37748 .40047 .39035 .39581 .38252 .38863 Mtetra
.661 .779 .936 r
.38252 .38863 .39035 .39581 .40327 .39136 .39549 .38402 Mtetra
.662 .776 .934 r
.39549 .38402 .40327 .39136 .41623 .38716 .40851 .37937 Mtetra
.684 .771 .917 r
.40851 .37937 .41623 .38716 .42929 .38221 .42163 .37397 Mtetra
.684 .76 .909 r
.42163 .37397 .42929 .38221 .44243 .37633 .43479 .36854 Mtetra
.645 .761 .933 r
.43479 .36854 .44243 .37633 .45561 .37098 .44799 .36433 Mtetra
.565 .768 .974 r
.44799 .36433 .45561 .37098 .46882 .3667 .46121 .36182 Mtetra
.682 .862 .967 r
.46121 .36182 .46882 .3667 .48212 .36089 .47457 .35616 Mtetra
.833 .881 .877 r
.47457 .35616 .48212 .36089 .4955 .35266 .48805 .3446 Mtetra
.532 .713 .955 r
.48805 .3446 .4955 .35266 .5089 .3469 .50147 .34314 Mtetra
.734 .909 .954 r
.50147 .34314 .5089 .3469 .52236 .34324 .515 .33567 Mtetra
.575 .747 .959 r
.515 .33567 .52236 .34324 .53589 .34067 .52857 .33311 Mtetra
.467 .7 .969 r
.52857 .33311 .53589 .34067 .54952 .33999 .54224 .33272 Mtetra
.55 .748 .969 r
.54224 .33272 .54952 .33999 .56325 .33881 .55601 .33057 Mtetra
.629 .753 .936 r
.55601 .33057 .56325 .33881 .57703 .33493 .56983 .32664 Mtetra
.652 .761 .93 r
.56983 .32664 .57703 .33493 .59086 .32967 .58372 .32201 Mtetra
.607 .763 .954 r
.58372 .32201 .59086 .32967 .60478 .32551 .59771 .31854 Mtetra
.537 .756 .977 r
.59771 .31854 .60478 .32551 .61883 .32305 .61182 .31647 Mtetra
.463 .734 .986 r
.61182 .31647 .61883 .32305 .63302 .32217 .62606 .31561 Mtetra
.476 .742 .987 r
.62606 .31561 .63302 .32217 .64737 .32256 .64041 .31449 Mtetra
.631 .766 .944 r
.64041 .31449 .64737 .32256 .66178 .32157 .65473 .31032 Mtetra
.738 .731 .844 r
.65473 .31032 .66178 .32157 .67604 .31521 .66892 .30143 Mtetra
.751 .693 .796 r
.66892 .30143 .67604 .31521 .6901 .30389 .68304 .29048 Mtetra
.731 .691 .813 r
.68304 .29048 .6901 .30389 .70416 .29249 .69727 .28107 Mtetra
.698 .715 .861 r
.69727 .28107 .70416 .29249 .71843 .28404 .71167 .27413 Mtetra
.671 .738 .901 r
.71167 .27413 .71843 .28404 .73289 .27792 .72622 .26856 Mtetra
.659 .748 .916 r
.72622 .26856 .73289 .27792 .74749 .2727 .74088 .26345 Mtetra
.656 .751 .92 r
.74088 .26345 .74749 .2727 .76217 .26768 .75562 .25839 Mtetra
.75562 .25839 .76217 .26768 .77693 .26266 .77043 .25333 Mtetra
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24823 Mtetra
.12769 .46271 .13623 .47016 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Mtetra
.15137 .45457 .15985 .46209 .17174 .45804 .16329 .45048 Mtetra
.654 .751 .921 r
.16329 .45048 .17174 .45804 .18367 .45408 .17526 .4464 Mtetra
.647 .747 .922 r
.17526 .4464 .18367 .45408 .1956 .45063 .18727 .44253 Mtetra
.616 .727 .925 r
.18727 .44253 .1956 .45063 .20745 .44877 .19925 .4395 Mtetra
.541 .669 .921 r
.19925 .4395 .20745 .44877 .21911 .44959 .21111 .43837 Mtetra
.455 .583 .892 r
.21111 .43837 .21911 .44959 .23073 .45179 .22284 .43945 Mtetra
.476 .57 .871 r
.22284 .43945 .23073 .45179 .24271 .4511 .23468 .44035 Mtetra
.608 .664 .879 r
.23468 .44035 .24271 .4511 .25521 .44507 .24693 .43755 Mtetra
.73 .776 .89 r
.24693 .43755 .25521 .44507 .26798 .43623 .25959 .43061 Mtetra
.766 .832 .903 r
.25959 .43061 .26798 .43623 .28072 .42804 .27237 .42249 Mtetra
.745 .834 .919 r
.27237 .42249 .28072 .42804 .29337 .42149 .28512 .41527 Mtetra
.709 .811 .929 r
.28512 .41527 .29337 .42149 .30598 .41612 .29782 .40928 Mtetra
.682 .79 .931 r
.29782 .40928 .30598 .41612 .31862 .41124 .31051 .40412 Mtetra
.666 .779 .933 r
.31051 .40412 .31862 .41124 .33129 .40654 .32322 .39944 Mtetra
.667 .78 .934 r
.32322 .39944 .33129 .40654 .34401 .40203 .336 .39471 Mtetra
.665 .775 .932 r
.336 .39471 .34401 .40203 .35679 .39765 .34882 .39003 Mtetra
.668 .768 .925 r
.34882 .39003 .35679 .39765 .36962 .3932 .36172 .38523 Mtetra
.661 .758 .922 r
.36172 .38523 .36962 .3932 .38252 .38863 .37466 .38061 Mtetra
.666 .759 .92 r
.37466 .38061 .38252 .38863 .39549 .38402 .38767 .37582 Mtetra
.664 .755 .918 r
.38767 .37582 .39549 .38402 .40851 .37937 .40074 .37107 Mtetra
.673 .756 .913 r
.40074 .37107 .40851 .37937 .42163 .37397 .41388 .36601 Mtetra
.641 .756 .932 r
.41388 .36601 .42163 .37397 .43479 .36854 .42705 .36192 Mtetra
.628 .792 .961 r
.42705 .36192 .43479 .36854 .44799 .36433 .44028 .35798 Mtetra
.652 .809 .958 r
.44028 .35798 .44799 .36433 .46121 .36182 .4536 .35334 Mtetra
.763 .779 .866 r
.4536 .35334 .46121 .36182 .47457 .35616 .46706 .34431 Mtetra
.757 .711 .809 r
.46706 .34431 .47457 .35616 .48805 .3446 .48057 .33396 Mtetra
0 0 .452 r
.48057 .33396 .48805 .3446 .50147 .34314 .49383 .35165 Mtetra
0 0 0 r
.49383 .35165 .50147 .34314 .515 .33567 .50751 .33836 Mtetra
.355 .815 .711 r
.50751 .33836 .515 .33567 .52857 .33311 .52118 .3321 Mtetra
.429 .863 .927 r
.52118 .3321 .52857 .33311 .54224 .33272 .53491 .32824 Mtetra
.629 .868 .987 r
.53491 .32824 .54224 .33272 .55601 .33057 .5487 .32342 Mtetra
.639 .79 .955 r
.5487 .32342 .55601 .33057 .56983 .32664 .56258 .31902 Mtetra
.632 .775 .949 r
.56258 .31902 .56983 .32664 .58372 .32201 .57653 .31487 Mtetra
.569 .766 .971 r
.57653 .31487 .58372 .32201 .59771 .31854 .59058 .31212 Mtetra
.518 .767 .987 r
.59058 .31212 .59771 .31854 .61182 .31647 .60475 .31014 Mtetra
.506 .766 .989 r
.60475 .31014 .61182 .31647 .62606 .31561 .61902 .30832 Mtetra
.614 .784 .962 r
.61902 .30832 .62606 .31561 .64041 .31449 .63331 .30443 Mtetra
.714 .748 .878 r
.63331 .30443 .64041 .31449 .65473 .31032 .64756 .2971 Mtetra
.739 .698 .812 r
.64756 .2971 .65473 .31032 .66892 .30143 .66174 .28722 Mtetra
.725 .677 .804 r
.66174 .28722 .66892 .30143 .68304 .29048 .67598 .27782 Mtetra
.702 .693 .839 r
.67598 .27782 .68304 .29048 .69727 .28107 .69035 .27034 Mtetra
.676 .722 .884 r
.69035 .27034 .69727 .28107 .71167 .27413 .70487 .26447 Mtetra
.662 .743 .91 r
.70487 .26447 .71167 .27413 .72622 .26856 .7195 .2592 Mtetra
.656 .749 .918 r
.7195 .2592 .72622 .26856 .74088 .26345 .73421 .25412 Mtetra
.656 .751 .92 r
.73421 .25412 .74088 .26345 .75562 .25839 .749 .24902 Mtetra
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Mtetra
.656 .752 .92 r
.76387 .24391 .77043 .25333 .78532 .24823 .77881 .23877 Mtetra
.656 .751 .92 r
.11908 .4552 .12769 .46271 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Mtetra
.14282 .44699 .15137 .45457 .16329 .45048 .15478 .44285 Mtetra
.655 .751 .92 r
.15478 .44285 .16329 .45048 .17526 .4464 .16678 .43871 Mtetra
.653 .75 .921 r
.16678 .43871 .17526 .4464 .18727 .44253 .17884 .43462 Mtetra
.641 .742 .922 r
.17884 .43462 .18727 .44253 .19925 .4395 .19092 .43086 Mtetra
.604 .711 .92 r
.19092 .43086 .19925 .4395 .21111 .43837 .20295 .42812 Mtetra
.534 .644 .905 r
.20295 .42812 .21111 .43837 .22284 .43945 .21488 .42725 Mtetra
.481 .577 .874 r
.21488 .42725 .22284 .43945 .23468 .44035 .22674 .42794 Mtetra
.52 .593 .867 r
.22674 .42794 .23468 .44035 .24693 .43755 .23877 .42772 Mtetra
.636 .698 .89 r
.23877 .42772 .24693 .43755 .25959 .43061 .25119 .42398 Mtetra
.733 .803 .907 r
.25119 .42398 .25959 .43061 .27237 .42249 .26393 .41707 Mtetra
.751 .84 .918 r
.26393 .41707 .27237 .42249 .28512 .41527 .27675 .40958 Mtetra
.726 .831 .93 r
.27675 .40958 .28512 .41527 .29782 .40928 .28954 .40297 Mtetra
.701 .81 .933 r
.28954 .40297 .29782 .40928 .31051 .40412 .30231 .39719 Mtetra
.683 .79 .931 r
.30231 .39719 .31051 .40412 .32322 .39944 .3151 .39195 Mtetra
.668 .772 .928 r
.3151 .39195 .32322 .39944 .336 .39471 .32792 .38716 Mtetra
.66 .769 .93 r
.32792 .38716 .336 .39471 .34882 .39003 .34078 .38258 Mtetra
.657 .772 .934 r
.34078 .38258 .34882 .39003 .36172 .38523 .35369 .37806 Mtetra
.66 .782 .939 r
.35369 .37806 .36172 .38523 .37466 .38061 .36668 .37343 Mtetra
.665 .784 .937 r
.36668 .37343 .37466 .38061 .38767 .37582 .37973 .36861 Mtetra
.678 .788 .932 r
.37973 .36861 .38767 .37582 .40074 .37107 .39287 .36336 Mtetra
.672 .773 .926 r
.39287 .36336 .40074 .37107 .41388 .36601 .40605 .3583 Mtetra
.631 .762 .941 r
.40605 .3583 .41388 .36601 .42705 .36192 .41925 .35442 Mtetra
.596 .757 .955 r
.41925 .35442 .42705 .36192 .44028 .35798 .4325 .35136 Mtetra
.639 .799 .959 r
.4325 .35136 .44028 .35798 .4536 .35334 .44586 .34706 Mtetra
.649 .813 .962 r
.44586 .34706 .4536 .35334 .46706 .34431 .45929 .34243 Mtetra
.236 .735 .905 r
.45929 .34243 .46706 .34431 .48057 .33396 .47273 .34152 Mtetra
.229 0 0 r
.47273 .34152 .48057 .33396 .49383 .35165 .48629 .33921 Mtetra
.608 .647 .863 r
.48629 .33921 .49383 .35165 .50751 .33836 .49994 .33605 Mtetra
.564 .903 .978 r
.49994 .33605 .50751 .33836 .52118 .3321 .51367 .33128 Mtetra
.625 .95 .935 r
.51367 .33128 .52118 .3321 .53491 .32824 .52748 .32439 Mtetra
.698 .907 .969 r
.52748 .32439 .53491 .32824 .5487 .32342 .54134 .31767 Mtetra
.655 .84 .972 r
.54134 .31767 .5487 .32342 .56258 .31902 .55526 .31255 Mtetra
.602 .801 .976 r
.55526 .31255 .56258 .31902 .57653 .31487 .56927 .30884 Mtetra
.557 .798 .989 r
.56927 .30884 .57653 .31487 .59058 .31212 .58338 .30592 Mtetra
.563 .796 .987 r
.58338 .30592 .59058 .31212 .60475 .31014 .59758 .3029 Mtetra
.636 .794 .958 r
.59758 .3029 .60475 .31014 .61902 .30832 .61182 .29844 Mtetra
.707 .75 .885 r
.61182 .29844 .61902 .30832 .63331 .30443 .62606 .29146 Mtetra
.725 .697 .823 r
.62606 .29146 .63331 .30443 .64756 .2971 .64029 .28258 Mtetra
.713 .669 .805 r
.64029 .28258 .64756 .2971 .66174 .28722 .65456 .27375 Mtetra
.695 .678 .829 r
.65456 .27375 .66174 .28722 .67598 .27782 .66893 .26635 Mtetra
.677 .708 .871 r
.66893 .26635 .67598 .27782 .69035 .27034 .68342 .26031 Mtetra
.663 .735 .903 r
.68342 .26031 .69035 .27034 .70487 .26447 .69802 .25496 Mtetra
.657 .747 .916 r
.69802 .25496 .70487 .26447 .7195 .2592 .71271 .24981 Mtetra
.656 .751 .92 r
.71271 .24981 .7195 .2592 .73421 .25412 .72748 .2447 Mtetra
.72748 .2447 .73421 .25412 .749 .24902 .74232 .23956 Mtetra
.656 .752 .92 r
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Mtetra
.656 .751 .92 r
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Mtetra
.14618 .43516 .15478 .44285 .16678 .43871 .15823 .43098 Mtetra
.655 .751 .92 r
.15823 .43098 .16678 .43871 .17884 .43462 .17032 .42678 Mtetra
.652 .748 .92 r
.17032 .42678 .17884 .43462 .19092 .43086 .18246 .42268 Mtetra
.638 .736 .92 r
.18246 .42268 .19092 .43086 .20295 .42812 .19462 .41894 Mtetra
.602 .7 .912 r
.19462 .41894 .20295 .42812 .21488 .42725 .20674 .41622 Mtetra
.545 .634 .89 r
.20674 .41622 .21488 .42725 .22674 .42794 .21878 .41514 Mtetra
.507 .58 .863 r
.21878 .41514 .22674 .42794 .23877 .42772 .23078 .41525 Mtetra
.539 .602 .866 r
.23078 .41525 .23877 .42772 .25119 .42398 .24296 .41447 Mtetra
.634 .707 .899 r
.24296 .41447 .25119 .42398 .26393 .41707 .25546 .41075 Mtetra
.721 .813 .922 r
.25546 .41075 .26393 .41707 .27675 .40958 .26825 .40427 Mtetra
.74 .845 .929 r
.26825 .40427 .27675 .40958 .28954 .40297 .28113 .39714 Mtetra
.716 .829 .934 r
.28113 .39714 .28954 .40297 .30231 .39719 .29399 .39081 Mtetra
.691 .809 .938 r
.29399 .39081 .30231 .39719 .3151 .39195 .30684 .38528 Mtetra
.681 .8 .939 r
.30684 .38528 .3151 .39195 .32792 .38716 .31973 .38003 Mtetra
.675 .787 .934 r
.31973 .38003 .32792 .38716 .34078 .38258 .33266 .37496 Mtetra
.67 .773 .927 r
.33266 .37496 .34078 .38258 .35369 .37806 .34564 .37002 Mtetra
.661 .76 .923 r
.34564 .37002 .35369 .37806 .36668 .37343 .35867 .36532 Mtetra
.658 .758 .924 r
.35867 .36532 .36668 .37343 .37973 .36861 .37175 .3607 Mtetra
.667 .768 .925 r
.37175 .3607 .37973 .36861 .39287 .36336 .38491 .35578 Mtetra
.676 .78 .928 r
.38491 .35578 .39287 .36336 .40605 .3583 .39814 .35054 Mtetra
.658 .771 .933 r
.39814 .35054 .40605 .3583 .41925 .35442 .41142 .34585 Mtetra
.629 .741 .928 r
.41142 .34585 .41925 .35442 .4325 .35136 .42473 .34202 Mtetra
.621 .719 .916 r
.42473 .34202 .4325 .35136 .44586 .34706 .4381 .33845 Mtetra
.591 .727 .938 r
.4381 .33845 .44586 .34706 .45929 .34243 .45153 .3356 Mtetra
.517 .751 .981 r
.45153 .3356 .45929 .34243 .47273 .34152 .46503 .33387 Mtetra
.548 .74 .965 r
.46503 .33387 .47273 .34152 .48629 .33921 .47862 .33178 Mtetra
.505 .728 .973 r
.47862 .33178 .48629 .33921 .49994 .33605 .4923 .33046 Mtetra
.582 .819 .989 r
.4923 .33046 .49994 .33605 .51367 .33128 .50609 .32696 Mtetra
.711 .897 .963 r
.50609 .32696 .51367 .33128 .52748 .32439 .51996 .32002 Mtetra
.729 .9 .956 r
.51996 .32002 .52748 .32439 .54134 .31767 .53388 .31254 Mtetra
.676 .867 .972 r
.53388 .31254 .54134 .31767 .55526 .31255 .54787 .30667 Mtetra
.63 .832 .978 r
.54787 .30667 .55526 .31255 .56927 .30884 .56193 .30209 Mtetra
.637 .808 .965 r
.56193 .30209 .56927 .30884 .58338 .30592 .57606 .2975 Mtetra
.675 .775 .926 r
.57606 .2975 .58338 .30592 .59758 .3029 .59025 .29192 Mtetra
.704 .725 .867 r
.59025 .29192 .59758 .3029 .61182 .29844 .60447 .28483 Mtetra
.707 .68 .821 r
.60447 .28483 .61182 .29844 .62606 .29146 .61872 .27673 Mtetra
.697 .659 .809 r
.61872 .27673 .62606 .29146 .64029 .28258 .63301 .26883 Mtetra
.684 .669 .829 r
.63301 .26883 .64029 .28258 .65456 .27375 .64739 .26194 Mtetra
.672 .7 .867 r
.64739 .26194 .65456 .27375 .66893 .26635 .66188 .25603 Mtetra
.663 .729 .899 r
.66188 .25603 .66893 .26635 .68342 .26031 .67646 .25067 Mtetra
.658 .745 .914 r
.67646 .25067 .68342 .26031 .69802 .25496 .69112 .2455 Mtetra
.656 .75 .919 r
.69112 .2455 .69802 .25496 .71271 .24981 .70586 .24035 Mtetra
.656 .751 .92 r
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Mtetra
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Mtetra
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Mtetra
.13752 .42741 .14618 .43516 .15823 .43098 .14959 .42318 Mtetra
.14959 .42318 .15823 .43098 .17032 .42678 .16172 .41894 Mtetra
.655 .751 .92 r
.16172 .41894 .17032 .42678 .18246 .42268 .17391 .41469 Mtetra
.651 .747 .92 r
.17391 .41469 .18246 .42268 .19462 .41894 .18614 .41053 Mtetra
.639 .733 .917 r
.18614 .41053 .19462 .41894 .20674 .41622 .1984 .40671 Mtetra
.61 .697 .905 r
.1984 .40671 .20674 .41622 .21878 .41514 .21063 .40373 Mtetra
.566 .637 .881 r
.21063 .40373 .21878 .41514 .23078 .41525 .22281 .40206 Mtetra
.532 .587 .855 r
.22281 .40206 .23078 .41525 .24296 .41447 .23497 .40149 Mtetra
.543 .597 .858 r
.23497 .40149 .24296 .41447 .25546 .41075 .24724 .40059 Mtetra
.608 .685 .897 r
.24724 .40059 .25546 .41075 .26825 .40427 .25977 .39761 Mtetra
.691 .801 .933 r
.25977 .39761 .26825 .40427 .28113 .39714 .27257 .39208 Mtetra
.729 .854 .94 r
.27257 .39208 .28113 .39714 .29399 .39081 .28552 .38525 Mtetra
.721 .84 .938 r
.28552 .38525 .29399 .39081 .30684 .38528 .29849 .3787 Mtetra
.693 .807 .936 r
.29849 .3787 .30684 .38528 .31973 .38003 .31145 .37304 Mtetra
.673 .792 .938 r
.31145 .37304 .31973 .38003 .33266 .37496 .32442 .36798 Mtetra
.664 .791 .942 r
.32442 .36798 .33266 .37496 .34564 .37002 .33744 .36314 Mtetra
.664 .795 .945 r
.33744 .36314 .34564 .37002 .35867 .36532 .35052 .35827 Mtetra
.661 .791 .944 r
.35052 .35827 .35867 .36532 .37175 .3607 .36365 .35349 Mtetra
.661 .787 .942 r
.36365 .35349 .37175 .3607 .38491 .35578 .37685 .34868 Mtetra
.666 .793 .942 r
.37685 .34868 .38491 .35578 .39814 .35054 .39012 .34369 Mtetra
.665 .801 .948 r
.39012 .34369 .39814 .35054 .41142 .34585 .40345 .33868 Mtetra
.652 .789 .948 r
.40345 .33868 .41142 .34585 .42473 .34202 .41683 .33404 Mtetra
.638 .763 .938 r
.41683 .33404 .42473 .34202 .4381 .33845 .43027 .32983 Mtetra
.621 .741 .932 r
.43027 .32983 .4381 .33845 .45153 .3356 .44376 .32614 Mtetra
.588 .707 .925 r
.44376 .32614 .45153 .3356 .46503 .33387 .45731 .3234 Mtetra
.534 .659 .916 r
.45731 .3234 .46503 .33387 .47862 .33178 .47091 .32221 Mtetra
.525 .679 .935 r
.47091 .32221 .47862 .33178 .4923 .33046 .48462 .32102 Mtetra
.62 .724 .921 r
.48462 .32102 .4923 .33046 .50609 .32696 .49845 .31731 Mtetra
.706 .751 .886 r
.49845 .31731 .50609 .32696 .51996 .32002 .51237 .31048 Mtetra
.723 .76 .882 r
.51237 .31048 .51996 .32002 .53388 .31254 .52634 .30294 Mtetra
.698 .751 .893 r
.52634 .30294 .53388 .31254 .54787 .30667 .54037 .29645 Mtetra
.682 .732 .889 r
.54037 .29645 .54787 .30667 .56193 .30209 .55446 .29049 Mtetra
.685 .705 .863 r
.55446 .29049 .56193 .30209 .57606 .2975 .56861 .28413 Mtetra
.686 .675 .833 r
.56861 .28413 .57606 .2975 .59025 .29192 .5828 .27725 Mtetra
.683 .653 .815 r
.5828 .27725 .59025 .29192 .60447 .28483 .59705 .27016 Mtetra
.677 .651 .817 r
.59705 .27016 .60447 .28483 .61872 .27673 .61136 .26338 Mtetra
.671 .67 .841 r
.61136 .26338 .61872 .27673 .63301 .26883 .62575 .25722 Mtetra
.665 .702 .874 r
.62575 .25722 .63301 .26883 .64739 .26194 .64023 .25162 Mtetra
.66 .729 .901 r
.64023 .25162 .64739 .26194 .66188 .25603 .65479 .24633 Mtetra
.657 .744 .914 r
.65479 .24633 .66188 .25603 .67646 .25067 .66943 .24115 Mtetra
.656 .75 .919 r
.66943 .24115 .67646 .25067 .69112 .2455 .68415 .23599 Mtetra
.656 .751 .92 r
.68415 .23599 .69112 .2455 .70586 .24035 .69895 .23081 Mtetra
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Mtetra
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Mtetra
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Mtetra
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Mtetra
.15305 .41104 .16172 .41894 .17391 .41469 .16527 .40674 Mtetra
.655 .751 .92 r
.16527 .40674 .17391 .41469 .18614 .41053 .17754 .40243 Mtetra
.652 .747 .919 r
.17754 .40243 .18614 .41053 .1984 .40671 .18987 .39818 Mtetra
.644 .735 .915 r
.18987 .39818 .1984 .40671 .21063 .40373 .20223 .39417 Mtetra
.624 .703 .902 r
.20223 .39417 .21063 .40373 .22281 .40206 .2146 .39073 Mtetra
.592 .652 .879 r
.2146 .39073 .22281 .40206 .23497 .40149 .22694 .38826 Mtetra
.561 .602 .852 r
.22694 .38826 .23497 .40149 .24724 .40059 .23927 .38678 Mtetra
.551 .588 .845 r
.23927 .38678 .24724 .40059 .25977 .39761 .25165 .38563 Mtetra
.576 .635 .873 r
.25165 .38563 .25977 .39761 .27257 .39208 .26419 .38361 Mtetra
.635 .74 .924 r
.26419 .38361 .27257 .39208 .28552 .38525 .27695 .37972 Mtetra
.689 .837 .954 r
.27695 .37972 .28552 .38525 .29849 .3787 .28991 .37409 Mtetra
.714 .869 .955 r
.28991 .37409 .29849 .3787 .31145 .37304 .30297 .36762 Mtetra
.71 .847 .948 r
.30297 .36762 .31145 .37304 .32442 .36798 .31607 .36132 Mtetra
.692 .809 .938 r
.31607 .36132 .32442 .36798 .33744 .36314 .32919 .35561 Mtetra
.674 .781 .931 r
.32919 .35561 .33744 .36314 .35052 .35827 .34233 .35044 Mtetra
.664 .772 .93 r
.34233 .35044 .35052 .35827 .36365 .35349 .35551 .34556 Mtetra
.656 .768 .932 r
.35551 .34556 .36365 .35349 .37685 .34868 .36874 .34088 Mtetra
.655 .772 .935 r
.36874 .34088 .37685 .34868 .39012 .34369 .38204 .3362 Mtetra
.656 .782 .941 r
.38204 .3362 .39012 .34369 .40345 .33868 .3954 .33147 Mtetra
.655 .791 .947 r
.3954 .33147 .40345 .33868 .41683 .33404 .40884 .32669 Mtetra
.648 .786 .948 r
.40884 .32669 .41683 .33404 .43027 .32983 .42233 .32212 Mtetra
.629 .771 .948 r
.42233 .32212 .43027 .32983 .44376 .32614 .43588 .31806 Mtetra
.599 .75 .95 r
.43588 .31806 .44376 .32614 .45731 .3234 .44948 .31481 Mtetra
.588 .733 .944 r
.44948 .31481 .45731 .3234 .47091 .32221 .46315 .31188 Mtetra
.621 .703 .904 r
.46315 .31188 .47091 .32221 .48462 .32102 .47693 .30813 Mtetra
.67 .672 .843 r
.47693 .30813 .48462 .32102 .49845 .31731 .4908 .30223 Mtetra
.686 .646 .804 r
.4908 .30223 .49845 .31731 .51237 .31048 .50475 .29491 Mtetra
.677 .636 .801 r
.50475 .29491 .51237 .31048 .52634 .30294 .51875 .28789 Mtetra
.665 .638 .813 r
.51875 .28789 .52634 .30294 .54037 .29645 .5328 .28165 Mtetra
.662 .641 .819 r
.5328 .28165 .54037 .29645 .55446 .29049 .54691 .27563 Mtetra
.54691 .27563 .55446 .29049 .56861 .28413 .56109 .26962 Mtetra
.66 .646 .825 r
.56109 .26962 .56861 .28413 .5828 .27725 .57533 .26373 Mtetra
.661 .663 .841 r
.57533 .26373 .5828 .27725 .59705 .27016 .58964 .25801 Mtetra
.661 .689 .865 r
.58964 .25801 .59705 .27016 .61136 .26338 .60403 .25249 Mtetra
.66 .716 .89 r
.60403 .25249 .61136 .26338 .62575 .25722 .61849 .24717 Mtetra
.658 .736 .907 r
.61849 .24717 .62575 .25722 .64023 .25162 .63303 .24196 Mtetra
.656 .746 .916 r
.63303 .24196 .64023 .25162 .65479 .24633 .64765 .23679 Mtetra
.656 .75 .919 r
.64765 .23679 .65479 .24633 .66943 .24115 .66234 .23161 Mtetra
.656 .751 .92 r
.66234 .23161 .66943 .24115 .68415 .23599 .67711 .2264 Mtetra
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Mtetra
.14429 .40308 .15305 .41104 .16527 .40674 .15655 .39873 Mtetra
.15655 .39873 .16527 .40674 .17754 .40243 .16886 .39437 Mtetra
.655 .751 .92 r
.16886 .39437 .17754 .40243 .18987 .39818 .18123 .39 Mtetra
.654 .748 .919 r
.18123 .39 .18987 .39818 .20223 .39417 .19365 .38565 Mtetra
.649 .739 .915 r
.19365 .38565 .20223 .39417 .2146 .39073 .20613 .38141 Mtetra
.638 .717 .905 r
.20613 .38141 .2146 .39073 .22694 .38826 .21863 .3775 Mtetra
.618 .678 .884 r
.21863 .3775 .22694 .38826 .23927 .38678 .23114 .37414 Mtetra
.594 .631 .857 r
.23114 .37414 .23927 .38678 .25165 .38563 .24366 .37152 Mtetra
.576 .598 .837 r
.24366 .37152 .25165 .38563 .26419 .38361 .2562 .36948 Mtetra
.572 .596 .839 r
.2562 .36948 .26419 .38361 .27695 .37972 .26881 .36758 Mtetra
.589 .641 .87 r
.26881 .36758 .27695 .37972 .28991 .37409 .28155 .3651 Mtetra
.622 .726 .921 r
.28155 .3651 .28991 .37409 .30297 .36762 .29445 .36151 Mtetra
.656 .817 .961 r
.29445 .36151 .30297 .36762 .31607 .36132 .3075 .35673 Mtetra
.672 .867 .973 r
.3075 .35673 .31607 .36132 .32919 .35561 .32065 .35123 Mtetra
.679 .875 .972 r
.32065 .35123 .32919 .35561 .34233 .35044 .33388 .34549 Mtetra
.677 .86 .969 r
.33388 .34549 .34233 .35044 .35551 .34556 .34715 .3399 Mtetra
.671 .839 .964 r
.34715 .3399 .35551 .34556 .36874 .34088 .36047 .33455 Mtetra
.661 .818 .959 r
.36047 .33455 .36874 .34088 .38204 .3362 .37384 .32955 Mtetra
.651 .807 .958 r
.37384 .32955 .38204 .3362 .3954 .33147 .38725 .3248 Mtetra
.641 .805 .962 r
.38725 .3248 .3954 .33147 .40884 .32669 .40072 .32029 Mtetra
.632 .811 .969 r
.40072 .32029 .40884 .32669 .42233 .32212 .41426 .31594 Mtetra
.629 .818 .973 r
.41426 .31594 .42233 .32212 .43588 .31806 .42786 .31158 Mtetra
.646 .816 .965 r
.42786 .31158 .43588 .31806 .44948 .31481 .44155 .30681 Mtetra
.679 .784 .929 r
.44155 .30681 .44948 .31481 .46315 .31188 .45533 .30118 Mtetra
.702 .727 .87 r
.45533 .30118 .46315 .31188 .47693 .30813 .46919 .2943 Mtetra
.694 .668 .82 r
.46919 .2943 .47693 .30813 .4908 .30223 .48312 .28689 Mtetra
.675 .639 .805 r
.48312 .28689 .4908 .30223 .50475 .29491 .49708 .28004 Mtetra
.66 .639 .818 r
.49708 .28004 .50475 .29491 .51875 .28789 .5111 .27413 Mtetra
.653 .654 .838 r
.5111 .27413 .51875 .28789 .5328 .28165 .52518 .26875 Mtetra
.653 .67 .853 r
.52518 .26875 .5328 .28165 .54691 .27563 .53933 .26348 Mtetra
.653 .685 .867 r
.53933 .26348 .54691 .27563 .56109 .26962 .55355 .2583 Mtetra
.655 .704 .883 r
.55355 .2583 .56109 .26962 .57533 .26373 .56785 .25314 Mtetra
.657 .722 .896 r
.56785 .25314 .57533 .26373 .58964 .25801 .58221 .24794 Mtetra
.657 .735 .907 r
.58221 .24794 .58964 .25801 .60403 .25249 .59665 .24276 Mtetra
.656 .744 .915 r
.59665 .24276 .60403 .25249 .61849 .24717 .61117 .23759 Mtetra
.656 .749 .918 r
.61117 .23759 .61849 .24717 .63303 .24196 .62577 .23241 Mtetra
.656 .751 .92 r
.62577 .23241 .63303 .24196 .64765 .23679 .64044 .2272 Mtetra
.64044 .2272 .64765 .23679 .66234 .23161 .65518 .22198 Mtetra
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19003 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Mtetra
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Mtetra
.16009 .38625 .16886 .39437 .18123 .39 .1725 .38183 Mtetra
.1725 .38183 .18123 .39 .19365 .38565 .18497 .37739 Mtetra
.655 .749 .919 r
.18497 .37739 .19365 .38565 .20613 .38141 .19749 .37295 Mtetra
.653 .745 .917 r
.19749 .37295 .20613 .38141 .21863 .3775 .21007 .36853 Mtetra
.648 .732 .91 r
.21007 .36853 .21863 .3775 .23114 .37414 .2227 .36424 Mtetra
.639 .707 .896 r
.2227 .36424 .23114 .37414 .24366 .37152 .23537 .3602 Mtetra
.625 .672 .875 r
.23537 .3602 .24366 .37152 .2562 .36948 .24807 .35652 Mtetra
.611 .636 .851 r
.24807 .35652 .2562 .36948 .26881 .36758 .2608 .35322 Mtetra
.6 .608 .831 r
.2608 .35322 .26881 .36758 .28155 .3651 .27358 .35024 Mtetra
.595 .599 .825 r
.27358 .35024 .28155 .3651 .29445 .36151 .28643 .34741 Mtetra
.598 .613 .837 r
.28643 .34741 .29445 .36151 .3075 .35673 .29936 .34447 Mtetra
.613 .653 .866 r
.29936 .34447 .3075 .35673 .32065 .35123 .3124 .34109 Mtetra
.63 .705 .9 r
.3124 .34109 .32065 .35123 .33388 .34549 .32554 .33718 Mtetra
.645 .758 .931 r
.32554 .33718 .33388 .34549 .34715 .3399 .33879 .33277 Mtetra
.653 .794 .949 r
.33879 .33277 .34715 .3399 .36047 .33455 .35212 .32802 Mtetra
.659 .813 .958 r
.35212 .32802 .36047 .33455 .37384 .32955 .36553 .32304 Mtetra
.662 .816 .957 r
.36553 .32304 .37384 .32955 .38725 .3248 .37901 .31793 Mtetra
.67 .809 .95 r
.37901 .31793 .38725 .3248 .40072 .32029 .39257 .31261 Mtetra
.68 .791 .933 r
.39257 .31261 .40072 .32029 .41426 .31594 .40619 .307 Mtetra
.691 .762 .906 r
.40619 .307 .41426 .31594 .42786 .31158 .4199 .30092 Mtetra
.696 .725 .873 r
.4199 .30092 .42786 .31158 .44155 .30681 .43368 .29432 Mtetra
.693 .69 .842 r
.43368 .29432 .44155 .30681 .45533 .30118 .44752 .28736 Mtetra
.681 .663 .826 r
.44752 .28736 .45533 .30118 .46919 .2943 .46141 .28067 Mtetra
.669 .662 .834 r
.46141 .28067 .46919 .2943 .48312 .28689 .47534 .2746 Mtetra
.661 .683 .861 r
.47534 .2746 .48312 .28689 .49708 .28004 .48933 .26914 Mtetra
.658 .712 .888 r
.48933 .26914 .49708 .28004 .5111 .27413 .50338 .26396 Mtetra
.658 .729 .902 r
.50338 .26396 .5111 .27413 .52518 .26875 .5175 .25882 Mtetra
.656 .735 .908 r
.5175 .25882 .52518 .26875 .53933 .26348 .5317 .25373 Mtetra
.655 .74 .913 r
.5317 .25373 .53933 .26348 .55355 .2583 .54597 .24867 Mtetra
.656 .745 .915 r
.54597 .24867 .55355 .2583 .56785 .25314 .56031 .24354 Mtetra
.656 .747 .917 r
.56031 .24354 .56785 .25314 .58221 .24794 .57473 .23838 Mtetra
.656 .749 .919 r
.57473 .23838 .58221 .24794 .59665 .24276 .58922 .2332 Mtetra
.656 .751 .92 r
.58922 .2332 .59665 .24276 .61117 .23759 .60379 .22801 Mtetra
.60379 .22801 .61117 .23759 .62577 .23241 .61843 .22278 Mtetra
.61843 .22278 .62577 .23241 .64044 .2272 .63316 .21753 Mtetra
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19003 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Mtetra
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .37361 Mtetra
.16369 .37361 .1725 .38183 .18497 .37739 .17619 .36912 Mtetra
.17619 .36912 .18497 .37739 .19749 .37295 .18875 .36461 Mtetra
.655 .751 .92 r
.18875 .36461 .19749 .37295 .21007 .36853 .20138 .36009 Mtetra
.655 .749 .919 r
.20138 .36009 .21007 .36853 .2227 .36424 .21406 .35556 Mtetra
.654 .743 .915 r
.21406 .35556 .2227 .36424 .23537 .3602 .2268 .35104 Mtetra
.651 .732 .908 r
.2268 .35104 .23537 .3602 .24807 .35652 .2396 .34657 Mtetra
.645 .712 .896 r
.2396 .34657 .24807 .35652 .2608 .35322 .25245 .34226 Mtetra
.638 .688 .88 r
.25245 .34226 .2608 .35322 .27358 .35024 .26535 .33808 Mtetra
.632 .662 .862 r
.26535 .33808 .27358 .35024 .28643 .34741 .27831 .33402 Mtetra
.627 .639 .843 r
.27831 .33402 .28643 .34741 .29936 .34447 .29133 .32998 Mtetra
.623 .62 .827 r
.29133 .32998 .29936 .34447 .3124 .34109 .30442 .32599 Mtetra
.622 .612 .819 r
.30442 .32599 .3124 .34109 .32554 .33718 .31758 .32191 Mtetra
.625 .611 .816 r
.31758 .32191 .32554 .33718 .33879 .33277 .33083 .3177 Mtetra
.631 .618 .819 r
.33083 .3177 .33879 .33277 .35212 .32802 .34416 .31321 Mtetra
.638 .625 .821 r
.34416 .31321 .35212 .32802 .36553 .32304 .35757 .30843 Mtetra
.646 .633 .823 r
.35757 .30843 .36553 .32304 .37901 .31793 .37107 .30332 Mtetra
.652 .636 .822 r
.37107 .30332 .37901 .31793 .39257 .31261 .38464 .29791 Mtetra
.656 .637 .82 r
.38464 .29791 .39257 .31261 .40619 .307 .39829 .29226 Mtetra
.657 .638 .819 r
.39829 .29226 .40619 .307 .4199 .30092 .412 .28651 Mtetra
.657 .644 .825 r
.412 .28651 .4199 .30092 .43368 .29432 .42578 .28083 Mtetra
.656 .659 .841 r
.42578 .28083 .43368 .29432 .44752 .28736 .43961 .27537 Mtetra
.658 .688 .867 r
.43961 .27537 .44752 .28736 .46141 .28067 .4535 .27006 Mtetra
.66 .719 .892 r
.4535 .27006 .46141 .28067 .47534 .2746 .46746 .26483 Mtetra
.661 .74 .908 r
.46746 .26483 .47534 .2746 .48933 .26914 .48148 .25962 Mtetra
.659 .746 .914 r
.48148 .25962 .48933 .26914 .50338 .26396 .49558 .25443 Mtetra
.655 .746 .917 r
.49558 .25443 .50338 .26396 .5175 .25882 .50975 .24936 Mtetra
.654 .748 .919 r
.50975 .24936 .5175 .25882 .5317 .25373 .52399 .24433 Mtetra
.655 .752 .921 r
.52399 .24433 .5317 .25373 .54597 .24867 .53831 .2392 Mtetra
.657 .752 .92 r
.53831 .2392 .54597 .24867 .56031 .24354 .5527 .234 Mtetra
.656 .751 .92 r
.5527 .234 .56031 .24354 .57473 .23838 .56717 .2288 Mtetra
.56717 .2288 .57473 .23838 .58922 .2332 .58171 .22359 Mtetra
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Mtetra
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Mtetra
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09303 .38761 Mtetra
.09303 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Mtetra
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .37361 .15481 .36531 Mtetra
.15481 .36531 .16369 .37361 .17619 .36912 .16734 .36078 Mtetra
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Mtetra
.17994 .35623 .18875 .36461 .20138 .36009 .1926 .35166 Mtetra
.1926 .35166 .20138 .36009 .21406 .35556 .20532 .34706 Mtetra
.655 .75 .92 r
.20532 .34706 .21406 .35556 .2268 .35104 .2181 .34246 Mtetra
.655 .749 .919 r
.2181 .34246 .2268 .35104 .2396 .34657 .23094 .33784 Mtetra
.656 .747 .917 r
.23094 .33784 .2396 .34657 .25245 .34226 .24385 .33317 Mtetra
.655 .739 .911 r
.24385 .33317 .25245 .34226 .26535 .33808 .25683 .32851 Mtetra
.652 .727 .904 r
.25683 .32851 .26535 .33808 .27831 .33402 .26986 .32389 Mtetra
.648 .714 .896 r
.26986 .32389 .27831 .33402 .29133 .32998 .28295 .31935 Mtetra
.647 .703 .888 r
.28295 .31935 .29133 .32998 .30442 .32599 .29611 .3148 Mtetra
.646 .692 .879 r
.29611 .3148 .30442 .32599 .31758 .32191 .30933 .31023 Mtetra
.646 .683 .87 r
.30933 .31023 .31758 .32191 .33083 .3177 .32263 .30556 Mtetra
.646 .675 .863 r
.32263 .30556 .33083 .3177 .34416 .31321 .336 .30082 Mtetra
.647 .671 .859 r
.336 .30082 .34416 .31321 .35757 .30843 .34944 .29597 Mtetra
.649 .671 .858 r
.34944 .29597 .35757 .30843 .37107 .30332 .36295 .29105 Mtetra
.651 .677 .862 r
.36295 .29105 .37107 .30332 .38464 .29791 .37653 .28604 Mtetra
.653 .687 .869 r
.37653 .28604 .38464 .29791 .39829 .29226 .39019 .28099 Mtetra
.656 .701 .88 r
.39019 .28099 .39829 .29226 .412 .28651 .40391 .27588 Mtetra
.658 .716 .891 r
.40391 .27588 .412 .28651 .42578 .28083 .4177 .27074 Mtetra
.661 .731 .901 r
.4177 .27074 .42578 .28083 .43961 .27537 .43156 .26552 Mtetra
.66 .737 .907 r
.43156 .26552 .43961 .27537 .4535 .27006 .4455 .26033 Mtetra
.658 .74 .911 r
.4455 .26033 .4535 .27006 .46746 .26483 .4595 .2552 Mtetra
.655 .743 .915 r
.4595 .2552 .46746 .26483 .48148 .25962 .47357 .25014 Mtetra
.653 .747 .919 r
.47357 .25014 .48148 .25962 .49558 .25443 .48771 .24514 Mtetra
.655 .754 .923 r
.48771 .24514 .49558 .25443 .50975 .24936 .50192 .24004 Mtetra
.657 .755 .922 r
.50192 .24004 .50975 .24936 .52399 .24433 .51622 .23483 Mtetra
.657 .752 .92 r
.51622 .23483 .52399 .24433 .53831 .2392 .53058 .22959 Mtetra
.656 .75 .919 r
.53058 .22959 .53831 .2392 .5527 .234 .54502 .22438 Mtetra
.655 .751 .92 r
.54502 .22438 .5527 .234 .56717 .2288 .55954 .21915 Mtetra
.656 .752 .92 r
.55954 .21915 .56717 .2288 .58171 .22359 .57414 .21388 Mtetra
.656 .751 .92 r
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38388 Mtetra
.07169 .38388 .08086 .39201 .09303 .38761 .0839 .37944 Mtetra
.0839 .37944 .09303 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Mtetra
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Mtetra
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Mtetra
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Mtetra
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Mtetra
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Mtetra
.18373 .34316 .1926 .35166 .20532 .34706 .19649 .33853 Mtetra
.656 .752 .92 r
.19649 .33853 .20532 .34706 .2181 .34246 .20931 .33386 Mtetra
.656 .751 .92 r
.20931 .33386 .2181 .34246 .23094 .33784 .2222 .32917 Mtetra
.655 .75 .92 r
.2222 .32917 .23094 .33784 .24385 .33317 .23514 .3245 Mtetra
.655 .751 .92 r
.23514 .3245 .24385 .33317 .25683 .32851 .24815 .3198 Mtetra
.656 .751 .92 r
.24815 .3198 .25683 .32851 .26986 .32389 .26123 .31504 Mtetra
.657 .749 .918 r
.26123 .31504 .26986 .32389 .28295 .31935 .27438 .31021 Mtetra
.657 .743 .914 r
.27438 .31021 .28295 .31935 .29611 .3148 .28759 .30537 Mtetra
.656 .737 .909 r
.28759 .30537 .29611 .3148 .30933 .31023 .30087 .30052 Mtetra
.654 .731 .906 r
.30087 .30052 .30933 .31023 .32263 .30556 .31421 .2957 Mtetra
.654 .728 .904 r
.31421 .2957 .32263 .30556 .336 .30082 .32762 .29084 Mtetra
.654 .727 .902 r
.32762 .29084 .336 .30082 .34944 .29597 .3411 .28597 Mtetra
.655 .727 .902 r
.3411 .28597 .34944 .29597 .36295 .29105 .35465 .28104 Mtetra
.655 .728 .903 r
.35465 .28104 .36295 .29105 .37653 .28604 .36826 .27607 Mtetra
.656 .731 .904 r
.36826 .27607 .37653 .28604 .39019 .28099 .38195 .27105 Mtetra
.656 .733 .906 r
.38195 .27105 .39019 .28099 .40391 .27588 .39571 .26602 Mtetra
.655 .735 .908 r
.39571 .26602 .40391 .27588 .4177 .27074 .40954 .261 Mtetra
.653 .739 .912 r
.40954 .261 .4177 .27074 .43156 .26552 .42344 .25602 Mtetra
.653 .745 .918 r
.42344 .25602 .43156 .26552 .4455 .26033 .4374 .25102 Mtetra
.654 .752 .922 r
.4374 .25102 .4455 .26033 .4595 .2552 .45145 .24598 Mtetra
.656 .756 .924 r
.45145 .24598 .4595 .2552 .47357 .25014 .46557 .24086 Mtetra
.658 .756 .922 r
.46557 .24086 .47357 .25014 .48771 .24514 .47976 .23562 Mtetra
.658 .752 .919 r
.47976 .23562 .48771 .24514 .50192 .24004 .49402 .23037 Mtetra
.656 .748 .918 r
.49402 .23037 .50192 .24004 .51622 .23483 .50836 .22516 Mtetra
.655 .749 .919 r
.50836 .22516 .51622 .23483 .53058 .22959 .52278 .21996 Mtetra
.656 .752 .921 r
.52278 .21996 .53058 .22959 .54502 .22438 .53727 .2147 Mtetra
.53727 .2147 .54502 .22438 .55954 .21915 .55184 .2094 Mtetra
.656 .751 .92 r
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20407 Mtetra
.56648 .20407 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38455 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38388 .06244 .37567 Mtetra
.06244 .37567 .07169 .38388 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36218 Mtetra
.09934 .36218 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Mtetra
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Mtetra
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Mtetra
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .3299 Mtetra
.18758 .3299 .19649 .33853 .20931 .33386 .20044 .32521 Mtetra
.656 .752 .921 r
.20044 .32521 .20931 .33386 .2222 .32917 .21336 .32049 Mtetra
.656 .752 .92 r
.21336 .32049 .2222 .32917 .23514 .3245 .22635 .31572 Mtetra
.657 .751 .919 r
.22635 .31572 .23514 .3245 .24815 .3198 .2394 .31092 Mtetra
.656 .749 .919 r
.2394 .31092 .24815 .3198 .26123 .31504 .25252 .30613 Mtetra
.654 .749 .92 r
.25252 .30613 .26123 .31504 .27438 .31021 .2657 .30137 Mtetra
.654 .752 .922 r
.2657 .30137 .27438 .31021 .28759 .30537 .27894 .29657 Mtetra
.655 .754 .923 r
.27894 .29657 .28759 .30537 .30087 .30052 .29226 .29174 Mtetra
.656 .756 .923 r
.29226 .29174 .30087 .30052 .31421 .2957 .30564 .28683 Mtetra
.656 .755 .923 r
.30564 .28683 .31421 .2957 .32762 .29084 .31909 .28191 Mtetra
.657 .755 .922 r
.31909 .28191 .32762 .29084 .3411 .28597 .33262 .27694 Mtetra
.656 .753 .922 r
.33262 .27694 .3411 .28597 .35465 .28104 .34621 .27197 Mtetra
.656 .754 .922 r
.34621 .27197 .35465 .28104 .36826 .27607 .35987 .26699 Mtetra
.655 .754 .923 r
.35987 .26699 .36826 .27607 .38195 .27105 .3736 .26199 Mtetra
.655 .756 .924 r
.3736 .26199 .38195 .27105 .39571 .26602 .3874 .25697 Mtetra
.656 .757 .925 r
.3874 .25697 .39571 .26602 .40954 .261 .40127 .2519 Mtetra
.658 .758 .924 r
.40127 .2519 .40954 .261 .42344 .25602 .41522 .24675 Mtetra
.658 .755 .922 r
.41522 .24675 .42344 .25602 .4374 .25102 .42924 .24155 Mtetra
.658 .751 .919 r
.42924 .24155 .4374 .25102 .45145 .24598 .44333 .23633 Mtetra
.657 .748 .917 r
.44333 .23633 .45145 .24598 .46557 .24086 .4575 .23112 Mtetra
.654 .746 .917 r
.4575 .23112 .46557 .24086 .47976 .23562 .47173 .22596 Mtetra
.654 .749 .92 r
.47173 .22596 .47976 .23562 .49402 .23037 .48604 .22079 Mtetra
.655 .753 .922 r
.48604 .22079 .49402 .23037 .50836 .22516 .50043 .21554 Mtetra
.657 .754 .921 r
.50043 .21554 .50836 .22516 .52278 .21996 .5149 .21022 Mtetra
.656 .752 .92 r
.5149 .21022 .52278 .21996 .53727 .2147 .52944 .20489 Mtetra
.656 .751 .92 r
.52944 .20489 .53727 .2147 .55184 .2094 .54406 .19955 Mtetra
.54406 .19955 .55184 .2094 .56648 .20407 .55875 .19418 Mtetra
.55875 .19418 .56648 .20407 .58121 .19873 .57353 .18878 Mtetra
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37636 .03814 .38455 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36218 .09011 .35377 Mtetra
.09011 .35377 .09934 .36218 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Mtetra
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33996 Mtetra
.12766 .33996 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Mtetra
.16576 .32593 .17479 .33458 .18758 .3299 .17859 .32121 Mtetra
.656 .752 .92 r
.17859 .32121 .18758 .3299 .20044 .32521 .19149 .31646 Mtetra
.656 .751 .92 r
.19149 .31646 .20044 .32521 .21336 .32049 .20445 .31169 Mtetra
.655 .751 .92 r
.20445 .31169 .21336 .32049 .22635 .31572 .21747 .30691 Mtetra
.655 .752 .921 r
.21747 .30691 .22635 .31572 .2394 .31092 .23056 .30212 Mtetra
.656 .753 .921 r
.23056 .30212 .2394 .31092 .25252 .30613 .24371 .29727 Mtetra
.657 .753 .921 r
.24371 .29727 .25252 .30613 .2657 .30137 .25694 .29236 Mtetra
.657 .751 .919 r
.25694 .29236 .2657 .30137 .27894 .29657 .27023 .28742 Mtetra
.657 .748 .917 r
.27023 .28742 .27894 .29657 .29226 .29174 .28359 .28247 Mtetra
.655 .746 .917 r
.28359 .28247 .29226 .29174 .30564 .28683 .29702 .27754 Mtetra
.29702 .27754 .30564 .28683 .31909 .28191 .31051 .27258 Mtetra
.655 .747 .917 r
.31051 .27258 .31909 .28191 .33262 .27694 .32407 .26761 Mtetra
.656 .748 .918 r
.32407 .26761 .33262 .27694 .34621 .27197 .3377 .26259 Mtetra
.3377 .26259 .34621 .27197 .35987 .26699 .35141 .25754 Mtetra
.656 .748 .917 r
.35141 .25754 .35987 .26699 .3736 .26199 .36518 .25245 Mtetra
.656 .747 .916 r
.36518 .25245 .3736 .26199 .3874 .25697 .37903 .24733 Mtetra
.656 .745 .916 r
.37903 .24733 .3874 .25697 .40127 .2519 .39295 .2422 Mtetra
.655 .745 .916 r
.39295 .2422 .40127 .2519 .41522 .24675 .40693 .23709 Mtetra
.654 .746 .918 r
.40693 .23709 .41522 .24675 .42924 .24155 .42099 .23197 Mtetra
.654 .75 .92 r
.42099 .23197 .42924 .24155 .44333 .23633 .43513 .22683 Mtetra
.655 .753 .922 r
.43513 .22683 .44333 .23633 .4575 .23112 .44934 .22164 Mtetra
.657 .755 .923 r
.44934 .22164 .4575 .23112 .47173 .22596 .46363 .21636 Mtetra
.657 .754 .921 r
.46363 .21636 .47173 .22596 .48604 .22079 .47799 .21103 Mtetra
.656 .751 .92 r
.47799 .21103 .48604 .22079 .50043 .21554 .49243 .2057 Mtetra
.655 .75 .919 r
.49243 .2057 .50043 .21554 .5149 .21022 .50694 .20038 Mtetra
.656 .751 .92 r
.50694 .20038 .5149 .21022 .52944 .20489 .52153 .19502 Mtetra
.656 .752 .92 r
.52153 .19502 .52944 .20489 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Mtetra
.656 .751 .92 r
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17872 Mtetra
.56578 .17872 .57353 .18878 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .1397 Mtetra
.67184 .1397 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37636 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35448 Mtetra
.056 .35448 .06538 .36287 .07772 .35833 .06836 .34989 Mtetra
.06836 .34989 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33996 .11844 .33135 Mtetra
.11844 .33135 .12766 .33996 .1403 .3353 .13112 .32666 Mtetra
.13112 .32666 .1403 .3353 .153 .33063 .14385 .32194 Mtetra
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.656 .752 .92 r
.18245 .30764 .19149 .31646 .20445 .31169 .19545 .30284 Mtetra
.19545 .30284 .20445 .31169 .21747 .30691 .20851 .29799 Mtetra
.657 .751 .92 r
.20851 .29799 .21747 .30691 .23056 .30212 .22164 .2931 Mtetra
.656 .75 .919 r
.22164 .2931 .23056 .30212 .24371 .29727 .23484 .28821 Mtetra
.654 .749 .92 r
.23484 .28821 .24371 .29727 .25694 .29236 .24809 .28335 Mtetra
.654 .752 .921 r
.24809 .28335 .25694 .29236 .27023 .28742 .26142 .27846 Mtetra
.655 .754 .923 r
.26142 .27846 .27023 .28742 .28359 .28247 .27481 .27353 Mtetra
.656 .756 .924 r
.27481 .27353 .28359 .28247 .29702 .27754 .28828 .26854 Mtetra
.656 .756 .923 r
.28828 .26854 .29702 .27754 .31051 .27258 .30182 .26351 Mtetra
.657 .756 .923 r
.30182 .26351 .31051 .27258 .32407 .26761 .31543 .25845 Mtetra
.656 .754 .922 r
.31543 .25845 .32407 .26761 .3377 .26259 .3291 .25338 Mtetra
.3291 .25338 .3377 .26259 .35141 .25754 .34285 .2483 Mtetra
.655 .754 .923 r
.34285 .2483 .35141 .25754 .36518 .25245 .35666 .2432 Mtetra
.655 .756 .924 r
.35666 .2432 .36518 .25245 .37903 .24733 .37055 .23808 Mtetra
.656 .757 .924 r
.37055 .23808 .37903 .24733 .39295 .2422 .38452 .23293 Mtetra
.657 .758 .924 r
.38452 .23293 .39295 .2422 .40693 .23709 .39855 .22769 Mtetra
.658 .756 .923 r
.39855 .22769 .40693 .23709 .42099 .23197 .41267 .22241 Mtetra
.657 .753 .921 r
.41267 .22241 .42099 .23197 .43513 .22683 .42685 .2171 Mtetra
.657 .751 .919 r
.42685 .2171 .43513 .22683 .44934 .22164 .44111 .21179 Mtetra
.655 .748 .918 r
.44111 .21179 .44934 .22164 .46363 .21636 .45544 .2065 Mtetra
.655 .749 .919 r
.45544 .2065 .46363 .21636 .47799 .21103 .46985 .20121 Mtetra
.655 .751 .921 r
.46985 .20121 .47799 .21103 .49243 .2057 .48434 .19586 Mtetra
.656 .753 .921 r
.48434 .19586 .49243 .2057 .50694 .20038 .4989 .19045 Mtetra
.656 .752 .92 r
.4989 .19045 .50694 .20038 .52153 .19502 .51355 .18502 Mtetra
.656 .751 .92 r
.51355 .18502 .52153 .19502 .5362 .18961 .52827 .17957 Mtetra
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17408 Mtetra
.54307 .17408 .55095 .18418 .56578 .17872 .55795 .16857 Mtetra
.55795 .16857 .56578 .17872 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .1397 .66439 .12915 Mtetra
.66439 .12915 .67184 .1397 .68732 .134 .67994 .1234 Mtetra
.67994 .1234 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3ooolg0:O0j`030000002W`>/0
Yl3[00X0Yl3[4P3oool00`000000oooo0?ooo`0`0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01T0oooo0P00001>0?ooocT0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01D0oooo0`00001<0?ooocd0Yl3[00<000000:O0j`2W`>/02`2W`>/B
0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000004`3oool3000004d0oooo0`2W_n/50:O0j`D0Yko[<P2W`>/00`000000Yl3[0:O0
j`0<0:O0ja80oooo00<000000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4
000004`0oooo1P2W_n/50:O0j`D0Yko[<@2W`>/00`000000Yl3[0:O0j`0=0:O0ja80oooo00<00000
0?ooo`3oool0;@3oool003/0oooo0P00001<0?ooo`X0Yko[1P2W`>/40:Nojc40Yl3[00<000000:O0
j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo02d0oooo000h0?ooo`<00000BP3oool50:S0j`D0
Yko[1@2X`N/50:O0j`D0Z<7[<@2W`>/00`000000Yl3[0:O0j`0=0:O0ja40oooo0P00000^0?ooo`00
=@3oool3000004`0oooo1`2X`>/20:Noj`<0Z<7/1@2X`N/50:O0k0D0Z<7[<02W`>/00`000000Yl3[
0:O0j`0>0:O0ja40oooo00<000000?ooo`3oool0;03oool003<0oooo0P00001=0?ooo`T0Z<3[1P2X
`N`20:S1j`<0Yko[1@2W`>`20:S1j`<0Yko[;`2W`>/00`000000Yl3[0:O0j`0?0:O0ja40oooo00<0
00000?ooo`3oool0:`3oool00300oooo0`00001;0?ooo`D0Z<7/1@2X`>/40:O0k0D0Z<7/1P2W_n/4
0:O0k0H0Yko[0P2W`>/30:NojbT0Yl3[00<000000:O0j`2W`>/0402W`>/A0?ooo`030000003oool0
oooo02X0oooo000^0?ooo`<00000B`3oool30:S2k0D0Z<7/1@2W_n/40:O0k0D0YkkZ5@2W_n/X0:O0
j`030000002W`>/0Yl3[0100Yl3[4@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0
oooo00<000000?ooo`3oool0AP3oool60:S2k080Z<7/0`2W_^/50:Noj`80Yl3/0P2X_nX50:NnjPD0
Z<3[1@2W_n/50:S0j`D0Yko[6`2W`>/30:Noj`X0Yl3[00<000000:O0j`2W`>/04@2W`>/A0?ooo`03
0000003oool0oooo02T0oooo000Y0?ooo`800000B`3oool50:O1k0D0Z<;/1P2W_^/40:Noj`D0Z;oZ
0`2W_^X20:S1k0D0Z<3[0P2W_n/30:S1k0X0Z<3[1@2W`>/50:Noj`D0Yl3[102W_n/50:O0j`H0Yko[
2@2W`>/00`000000Yl3[0:O0j`0A0:O0ja80oooo00<000000?ooo`3oool0:03oool002H0oooo0`00
001:0?ooo`T0Yl7/1@2W_^X50:Nnj`D0Z<3[1@2X_nX50:S1k0@0Z<3[1P2X`N`20:S0j`<0Yl3[1@2X
`>/20:O0j`<0YkoZ1@2W_n/50:NnjP@0Yko[1@2W_^X:0:Noj`@0Yl3[00<000000:O0j`2W`>/04P2W
`>/A0?ooo`030000003oool0oooo02P0oooo000T0?ooo`800000B`3oool:0:O1k0L0YkkZ1@2X`N`5
0:S0j`D0Yl7/1@2X`N`40:O1k0D0Z<7/1P2W`>/40:S0j`H0YkoZ0P2W_n/30:Rlj0D0YkkZ0P2W_n/2
0:Rlj0D0YkkZ1@2X_^T70:Noj`80000000<0Yko[0:O0j`2W`>/04P2W`>/@0?ooo`800000:@3oool0
0240oooo0`00001;0?ooo`X0Yl7/1`2W_^X30:S2k0D0Z<7/0P2X`>/30:O0k0D0Yl7/1@2W_n/40:O1
k0D0Yko[1@2W`>/50:NnjPD0YkoZ1P2X_>P40:NnjPD0Z;cX0P2W_^X30:RjiPP0Z;kY0`0000020:No
j`030000002W_n/0Yl3[0180Yl3[4P3oool00`000000oooo0?ooo`0V0?ooo`007`3oool3000004T0
oooo2P2W`N`50:NojP@0YkkZ1P2X`^`40:S1k0H0Yl3/0P2W`N`30:NnjPD0Yko[102W_^X50:Noj`D0
YkgY1@2W_^X50:Rhi@D0Z;cX1@2X]n<40:Rlj0H0Z;[V0P2X_^T20:VjiP<000000`2X_^T20:Noj`03
0000002X_nX0Z;oZ01<0Yl3[4@3oool00`000000oooo0?ooo`0V0?ooo`007@3oool2000004/0oooo
1`2W`N`:0:NojPD0Yl7/102X`^`50:Nnj`D0Yl3/1P2W_^X20:Noj`<0Z;kY102W_^X30:Noj`80YkcX
1@2W_NT20:NnjP<0YkCR1@2X^>D50:V`g@@0Z;OS1@2Z/ml50:RjiP040:VjiP000000000000000080
ZK[V102X_^T30:RojP030000002X_nX0Z;oZ0080Yl3[0P2W_n/?0:O0ja40oooo00<000000?ooo`3o
ool0303oool2000000@0oooo0P0000030?ooo`@000002P3oool001D0oooo1@0000030?ooo`800000
B@3oool70:O1k0<0Yko[1@2W_nX:0:O1k0D0YkgY102W_^/50:Rmj@D0YkkZ1P2X_^T40:NnjPD0YkcX
102W_NT60:NdhP80Z;SU0`2YZML50:V`g@80Z;OS0P2[ZmL50:Zcg`80[;?M0`0000050:VjiPD0ZKcW
0`2X_nX00`000000Z;oZ0:Noj`040:Noj`l0Yl3[4@3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool02`3oool001L0oooo00<000000?ooo`3oool0
0`3oool3000004@0oooo1@2X`N`40:O1k0H0Yko[0P2W_nX:0:O1k0<0YkcX1@2W_NT40:Rlj0D0Z;gY
1@2Y_NP50:Rnj@D0Z;[V102W_>P50:N_g@D0YkCR1@2YZML50:V`g@D0Zj_G0P2Z/ml20:n[e0800000
102//md20:VjiP<0[KGN1@2Y_>L30:Vnj0030000002Y_^P0Yko[00<0Yko[402W`>/@0?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0:0?ooo`00
5`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000003l0oooo1@2W`N`50:S1k0T0
Yko[2P2W`N`60:Nlj080YkgY0`2Y^nH40:Rlj080Z;gY0`2X^>@50:Vmj0D0Z;KS1@2X^^H40:N[fPD0
YjoM0P2W]>830:RUd`D0ZJWG0P2Y/=d30:fVd@@0Zj_G00D0[j_D00000000000000000:n[e0050:bc
g@H0[KGN0P2Y_>L30:fhhP80ZKkX00<000000:Vnj02X_nX0102X_nX?0:O0ja40oooo00<000000?oo
o`3oool00`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`09
0?ooo`003`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03/0oooo1`2W`N`50:NojPD0Yko[2@2W`N`50:Nki`D0YkcX1P2Y^nH30:Rl
j0H0Z;ST0P2Y_NP30:V^g0D0Z;KS0P2X^^H30:NWeP@0Yj_J102W[md50:RUd`D0ZJWG1P2]Y]40102[
ZmL000000000000000050:n[e080[;?M0`2a[M@50:fegPD0[KSR0P2Y_^P00`2[_>H000000:^liP05
0:RojPD0Z<3[2P2W`>/A0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000:0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`800000103o
ool00`000000oooo0?ooo`0h0?ooo`P0Yl7/0P2W_^X50:NojPD0Yl3/1@2W`N`90:Nki`D0Z;OT1@2Y
^nH50:R`g@@0Z;ST1P2Y[]`40:Rfh`D0YjOF102WZmX50:VTd@D0Z:GC0P2YZML30:jWd0<0[JKA0`00
00030;:Xc`D0[j_D1P2a[M@20:fegP<0/k7F102]^>840:^liP040000002[_>H0Z;oZ0:RojP<0ZKoY
1@2X`>/90:O0ja00oooo0P00000;0?ooo`8000002P3oool2000000/0oooo000F0?ooo`800000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0oooo2P2W`N`50:NnjP80YkoZ0`2X
`N`50:O0k080Yl7/0`2W^^L60:Nki`<0Yk?Q1@2X]n@20:VkiP<0YjSG1@2X/=d40:^Ye@D0ZJkL1@2X
Xm450:NWeP80Yj_J1`2YY=440:RUd`D0[ZO@0`0000000`2]Y]40]:kB0;B^dP040;:Xc`80[j_D0`2f
Zlh50;6]e0H0/k7F0P2]^>820;:gg0@0ZkcV00<000000:Voj@2Y_nT0102Y_nT50:S0j`T0Yl3[4@3o
ool00`000000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03oool4
0:O0j`D0Yl7/2@2W_^X60:S1k0@0Yl3/1P2W^^L30:Nki`H0Yk?Q102X]n@60:NXe`80Z;3M0`2^ZM<4
0:^Ye@80ZJkL0`2/Xlh50:RSd@@0YjOF2@2YY=450:n/e@050:jWd000000000000000002^Ym000P2]
Y]430;B^dP@0/ZS?1P2fZlh20;6]e0<0^Jg=1@2c/MH50;:gg0<0[kcS00<000000:nlh`2Y_nT0102Y
_nT50:S0j`X0Yl3[4@3oool00`000000oooo0?ooo`0P0?ooo`00703oool2000000P0oooo00<00000
0?ooo`3oool0:`3oool30:Noj`@0Yl3[1@2X_nX50:NnjPD0Yl7/102X`N`50:NjiPD0Yk[W102W[mh5
0:Nch@D0Z:CC1@2WZ=L50:jYd`@0ZjWE1@2/Xlh50:RSd@D0ZZ?@1P2YY=430:ndg080[jcE0`000004
0:jWd0H0]:kB0P2bZ<l20;VbdPD0]Z_>1P2i[Ld20;>aeP<0^k3@0`2b]m`20;Vfe`<0[kcS00<00000
0:nlh`2[_nP0102[_nP40:S0j`X0Yl3[4@3oool00`000000oooo0?ooo`0P0?ooo`00703oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo1P2W_n/20:O0j`80Z<3[1@2X_nX:0:O1
k0T0Yk[V1@2V[M`40:N_gP<0Yk?Q0P2XXm450:RTd`80YjSG0`2a/=L50:jYd`80ZjWE0P2aZm450:bS
cP80Z:?A0`2]X/d40:ZSd0@0ZJCA102_]=`3000000<0[jcE1@2d^Md50;B^dP@0^K;B102fZlh20;fb
c`D0^Jg=1@2k/=020;:gg0@0^KKG0P2__><00`2d_N0000000;Bmh0040:^oj0D0Z<3[2P2W`>/A0?oo
o`030000003oool0oooo01l0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool08`3oool:0:Noj`D0Z<3[0`2X_nX90:O1k0<0Yk[W1`2W^^H20:J[f`D0YZgL102W[mh40:RSd@D0
Z:CC1@2a/=L50:jYd`@0/J_A1@2/Xlh50:fRc@D0ZZ?@0P2YY=420:jkh`<000000P2_]=`20:n/e@<0
[<K]1@2d^Md20;B^dP<0];oR102i/]820;J[cP<0_K;?102i[Ld20<2ab`@0^k3@1P2i]]L40;Bmh004
0000002d_N00ZkoX0:^oj080[L3X1@2X`>/:0:O0ja40oooo00<000000?ooo`3oool07P3oool001/0
oooo0P00000<0?ooo`030000003oool0oooo01l0oooo1@2X`>/40:Noj`X0Z<3[2@2W`N`60:Nji`@0
Yk[V102VZm/50:J]g0D0Yj?A102XXm420:RTd`<0/[WO1@2a/=L20:jYd`<0/k[N102aZm420:bScP<0
[jG=1@2]X/d40:ZSd080[[_S0P0000000`2^^n<0[kCL0:ndg0020:ndg0H0[<K]102d^Md50;BohP@0
^K;B1P2m//l20;V]c@<0`;7;0`2k/=020<:bb`@0^KKG0P31^=830;Bmh0030000002d_N00[L3X00@0
[L3X0P2X`>/30:W0j`X0Yl3[403oool00`000000oooo0?ooo`0N0?ooo`006`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01X0oooo1@2W`>/50:S0j`D0Yl3[102X`>/50:O0k0D0Yl7/
102W^nL50:Nji`D0YJ_K102VZm/20:J]g0<0YZ;B102WXm440:RSd@H0/[WO102a/=L50;>jgP@0/J_A
1@2_YLd50:fRc@<0//3T0`0000030:jkh`D0Xlkg1@2/a^d50:;;m@@0];oR0P2i/]830;Joh0D0_K;?
1P30/L/00`2k/=00`[;;0<:bb`020<:bb`80^KKG1031^=820;Bmh0030;VogP000000^KoN00@0[L3X
1P2Y`>/90:O0ja40oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0H0?ooo`L0Yl3[0P2X`>/80:O0j`D0Yko[102W`>`50:Nlj0@0Yk_W1@2U
[=`50:F[f`<0YZ_K1@2VX]850:NSd@80Z:?A0P2``nL50;:ig`D0[LS]1@2c^]h20;6[d@80ZjcG1@2_
YLd20:fRc@80^L;Q0`0000030;;0i0@0XMCj1@2Sc_L5093;o0D0X/_e0`2d_n860;Joh080_K;?0`2l
^mP50<2ab`D0`[;;1P31^=840;VogP030000002_`NL0[l7W00<0[l7W1@2Y`>/90:O0ja00oooo0P00
000O0?ooo`006`3oool2000000l0oooo00<000000?ooo`3oool05@3ooolA0:O0j`P0Yko[102X_^T5
0:Nlj0@0YJkN1@2U[=`40:F[f`@0YJ;B1@2VX]840:NSd@D0/<?W0`2b^Ml20:G@m`D0[LS]102c^]h4
0:^/e`D0[jG=00@0^L;Q00000000000000000P2i`^420;;0i0<0[Mgh102Qe?X508k<o@D0T<_l102R
boD409g8mPD0][oP1@2l^mP40<2ab`80`kG=0`32///20<Ndb0@0`KSB0P37^/h30;VogP030000002n
`]`0[l7W00@0[l7W1@2Y`>/90:O0ja40oooo00<000000?ooo`3oool0703oool001/0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?oooa80Yl3[202W_n/30:Roj`@0Z;kY0P2W_>P3
0:Fah@@0YJkN102U[=`50:>OdP@0YJ;B102VX]850:k:kPD0/<?W1@2Ud?L40:g8k@D0W[?W102[[=L2
0:nUc@<000001@2i`^460:gMn0@0V/gi1@2>c?d508C4o0@0PLCm102Mb?H20;Joh0<0XLCa1@2l^mP2
0<2ab`@0`kG=00<0`[;;0<Ndb037]<P00P37]<P20<6hdP@0ak[>00D0^KoN0;k2g02n`]`000000;k2
g0020:o1i`<0/<?W102Y`>/:0:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P000004
0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<
0?oooa<0Yl3[1@2X`>/40:Noj`H0Z;o[0`2X_^T50:Fah@D0YJkN102QW]440:>OdPD0YJ;B102[co<5
0:k:kPH0XM7i0`2Ud?L509Jkl@D0W[?W0P2[[=L3000000@0]<3R0P2i`^440;[Vm0D0YmOh102JcOT5
0974n0D0Q<Cl1021a?d309g8mPH0XLCa102l^mP60<>ec@D0akC81P37^/h40;k2g0030000002``nL0
/<?W00@0/<?W102Y`N/:0:O0ja00oooo00<000000?ooo`3oool06`3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000030?ooo`8000004`3oool00`000000oooo0?oo
o`0:0?oooaD0Yl3[1@2X`>/40:O0j`D0Z;o[102U/n<50:Fah@80YJkN0`2OW=030:6Nd@D0XioB0P2U
X]830:W@m0@0Zloc1@2QcoP30:7An@<0XLGb0`2I_o<509Jkl@<0W[?W0`00000209jij`D0]<3R102j
i_@30;;Xn0D0YmOh102Qa_850974n0D0RL7j101f^o`307Vmo0D0XLCa1@2a_^<40<>ec@80`[S@0`37
]<P20<bga@@0ak[>0P3>_/X20;k2g080`lGL00@000000;33i`2``nL0/<?W0`2aa>P40:W1j`T0Yl3[
4@3oool00`000000oooo0?ooo`0J0?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`050000
003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`070?ooob40Yl3[1@2U]^D40:Fch`@0
YK7Q1@2OW=040:6Nd@@0XioB1P2Yd?@40:C>mPD0XLoh1P2QaO8309Vol`@0U[_a0`00000208J]k`@0
W[W[0P2d`>840;KUmPH0/^Sh1@2Sb_@40:76lPH0Vl?d1029`OX307Jko0@0NKgl1@1l^OX50;6nh`80
`kG=0`32^=020<Ndb0@0c;O50P37^/h30<jnbP@0`lGL00<000000<?5g02aa>P0102aa>P50:W1j`T0
Yl3[4@3oool00`000000oooo0?ooo`0I0?ooo`0000<0oooo0000000000000P0000020?ooo`040000
003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool00P3ooolI0:O0j`@0Yko[1@2W`>/40:Jji`D0YKKU102U/n<409nLd@D0Wic@0`2QW]450:S@m@<0
ZM3d0`2Vc_D40:C>mPD0YLWb1@2QaO8409Jdk0<0000000<0R:SZ08J]k`26[Nl00`26[Nl309jij`D0
]^Gf0`2Olnl50:7No0D0Xl[d102V`^h309_3m0<0X/Oc102?`OP407ZinP<0I;7k1@1l^OX40;6nh`D0
`[S@00<0akC80<bga@3<]lD00`3<]lD50<jnbP030=C2b033aM`0`lGL0080`lGL00<000000<O9g02a
a>P00`2aa>P60:W1j`T0Yl3[403oool00`000000oooo0?ooo`0I0?ooo`001`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00<0oooo0P00000F0?ooo`030000002W`>/0Yl3[01/0
Yl3[102W_n/20:O0j`<0YkgY102V^^L40:Ffi@D0WikC0`2OW=4509nLd0D0Yl_b102Xd?D60:K>m@D0
Yl[b102UbO8509jmkP0409Jdk0000000000009Jdk0@0R:SZ1026[Nl609CAo@80Wo?_1@1]g>d40:7N
o0D0XL3_102V`^h60:;7l`<0Sl7h1@21^_P305f/n@@0O;Wj1@2J^^h40<:hd0D0c;O50P3?^<<30<jn
bP<0e<;80P33aM`20<O9g0030000002aa>P0/LCX00<0/LCX1@2Y`N/90:O0ja00oooo0P00000J0?oo
o`00203oool2000000X0oooo0`0000030?ooo`030000003oool0oooo0180oooo8P2W`>/30:Noj`H0
YkgY102V^^L40:2Se`@0WikC102OW=4209nLd0<0YL;^1@2Wbo850:WAm@D0YlS`1@2Wb_840:?3l080
W[g^0`00000409Jdk0@0S;gg1@21^_T4093WnP<0F]2f1@1g/oP408bon0@0XL3_1@2/aN`30:;7l`<0
Y<[d0`2C`?D5086jn0@0GJci0`1EY_P509ZjkP80`[S@0P2m]m<30<bga@@0ckS300<0c[k:0=C2b03D
`/P00P3D`/P40<O9g0030<W<g0000000/LCX00@0/LCX1@2Y`N/90:O0ja40oooo00<000000?ooo`3o
ool05`3oool001T0oooo00<000000?ooo`3oool04P3ooolS0:O0j`D0YkoZ102W_NT50:6Yg0<0X:?G
1@2OW]<309nLd@H0YL;^1@2[e_H30:WAm@80YlG_1@2Wb?050:K9lP80Xl?`0`00000409Njl0@0Q<3k
102<_OL609^Ug0<0^nSd0`2C_oD507Ncn0@0S;oh102Q^n/50:c5k0H0Y<[d0`2C`?D508Zmm`@0FZ_i
0`0`T>l409ZjkPD0_KOC00<0c;O50<nh``3?^<<00`3?^<<40=C2b080f/K50P37bM`20<W<g0040000
0039c=`0/LCX0;74j0<0/LGY102Y`N/:0:O0ja00oooo00<000000?ooo`3oool05`3oool001T0oooo
0P00000A0?ooob40Yl3[1@2W_n/50:NojP@0Xk3Q1@2QZM`30:2Se`@0WikC102Q]>H30:G2kP<0[Mch
1@2[e_H50:O5k`D0Z/gb0`2VbO83000000<0W[SZ1@2G^_0408C0n`@0`KK?102KYM`50;_Xm0<0Tkoe
1@26YNP408V[k0@0XK_[1P2acnl50:35l`<0Ukgb1@2:_OL405Z[n@<0<93_101jZo840;fgd`H0ckS3
00<0dkW00=C2b03D`/P0103Ja/D40<W<g0030000002aaNT0/LGY00@0/LGY102X`N/:0:O0ja00oooo
00<000000?ooo`3oool05P3oool001T0oooo00<000000?ooo`3oool03@3ooolQ0:O0j`T0Yko[1@2U
]^D40:>`h@@0XJWL0`2PXmL509bWg@@0XKCV1P2]g?P50:O4kP<0YlG_0`2Zbo430:[=lP<000000`2Q
_Nd409jhjPH0Y]3f1P31]/l00`28]_@0VjGL09^Ug00208Rfm0D0X:SL0`2HZ>8508JUj0@0RJ_/102X
_^T30;7?k`<0/MOd102PaO<409NmlPD0T/Ch101EZ_T00`0=Mn80<93_032@k`0307Z[lP<0_KOC0P2g
/mD40<nh``80dkW000<0e<;80=[6a@3Ja/D00`3Ja/D00`3Pbl@0bLcL0<W<g0020<W>g@040000002a
aNT0/LGY0;75j@<0/<CY102X`N/90:O0ja40oooo00<000000?ooo`3oool05@3oool001T0oooo00<0
00000?ooo`3oool02@3ooolV0:O0j`D0Yko[102V^nP50:Ffi@<0Xk3Q1@2HVM<309VLePD0W:OM1P2]
goP40:W5kPD0YlC^1@2Zbo4300000080Z<G^1@2Q_Nd40:?<m@<0Y]3f0`33amd40<6fc`80eN7P0`28
]_@20:f`fPD0X:SL0`2HZ>8408JUj0D0TZKS102X_^T60;7Gm0<0X<Gc1P2N_^l409;4n0<0EJ[i0`0=
Mn8307Z[lP80_KOC0`2g/mD30<nh``<0dkW01@3Ja/D20>3;a0D0bLkM00<000000;34j@2`a>T00`2`
a>T50:S1j`T0Yl3[403oool00`000000oooo0?ooo`0E0?ooo`006@3oool2000000L0oooo:P2W`>/2
0:Noj`<0YkkZ102V^nP40:Ffi@@0VI_D102HVM<409VLeP80W:OM0`2/gOT30:gOn0<0[<O^102YaNh5
0:W9l@040:[;l@000000000000000080[LO]102XaNh509S1m0@0Xlce1P33amd20<6fc`@0eN7P1@2]
/=X40:2Xg0@0WJ?I102@W]d509:Vh`80Z;kY0P2ffO830;7Gm0<0YLG`0`2L]n/309jnk`<0ZLgc102G
b_T304fUm`03001Jd00=Mn803GOR0080E9?^1P2g/mD00`3?^<<0dkW00=>i`0020=>i`0040=Rl_@3J
a/D0f/K50=[6a@<0h<_400<0i=330<W>g@39c]d00P39c]d00`000000b<oO0;34j@030;34j@H0Z<7[
2@2W`>/@0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo00<0oooo;@2W
`>/60:NnjP@0Y[_X102LX]T309VKe0D0V9WC0`2IW=H60:cMn@H0[<O^1@2Yb_40102YbO4000000000
000000060:g7k@@0XL?`1@2H`O@40:K?m@D0`lOM103EhN030;g0g0@0[K3J1@2TYMH309fSf@D0T9kM
102BY^<50;KIlPH0YLG`0`2L]n/60:W=l`@0V<Wh0`0nWO@2001Jd0<0E9?^1@2g/mD40=>i`0<0f;bm
00@0f/K50>3;a03Pbl@0h<_40`3Td<<20<W>g@80b<oO00<000000:o4j@2_a>T00`2_a>T50:S1j`X0
Yl3[403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`030?ooob/0Yl3[
1@2W_n/40:NnjPD0WjcO0`2LX]T409VKe0@0V9WC1P2WdOH40;7?l0<0[<O^0`2Ybo420:W:l@<00000
102Za>`30:g7k@<0[<G]102Q`o050:3:mP@0Y/oe1P2^g?L60;g0g080[K3J0P2ZZMH40:BUeP@0WJ?I
102@W]d50:G4k`D0]=ge1@2UaO040:>nk0<0ZLgc0`2]d?8409S9n0<0?Ygd00<003Vh001Jd00`Mn<0
0P1DTnh20;Nce@<0/JgD0`3C^L030=Rl_@@0h<_40`3Td<<40<S?g`030<O>h0000000[lCY00@0[lCY
1@2X`>/90:O0j`l0oooo0P00000E0?ooo`00603oool010000000oooo0000003oool^0:O0j`D0Yko[
102S]>D509n/g`<0W:;I0`2IVm@509nij`<0Ym7f0`2ef?840;7?l0D0ZL_a0P0000040:S2k0@0Z/C/
1P2/aNd40:C1kPD0X<[f1P2@a?T40;2mh`D0_L3L102ZZMH50:BUeP<0WJ?I1@2I[nL30:G4k`80]>Cg
1@2dgOD509^^i0@0Xkk/1@2]d?8609[?nP808hc/00@003Vh001Jd00`Mn<0<7OS1P2a[M@00`3C^L00
f;bm0=Rl_@020=Rl_@030=o0^P3Pbl@0h<_400@0i=3300<0i]?40<S?g`38cml00P37c^000`000000
alkP0:k3j@040:k3j@@0Z<3[2@2W`>/A0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`00
603oool00`000000Yl3[0:O0j`0`0:O0j`D0YK_X102S]>D409n/g`<0W:;I1@2FY=h409nij`H0]MSb
1@2Yb_4300000080ZL;/1@2X`^`40:g9kP<0[<G]0`2/`NT40:C1kPD0YL;^0`2@a?T30:Fdh`@0/;gS
1@2a]=/40:ZYeP@0Y:GF102O[^8509V_i`D0]>Cg1@2R]>D409^^i0H0/=Cc1@2^co4509?EoP03001Z
fP0SS>`003Vh00<0<7OS1@2a[M@40=Rl_@<0gl2j103Td<<30>KCa0@0alkP00<000000<G=h@2^`nT0
0`2^`nT50:S0j`T0Yl3[4@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0
oooo000A0?ooo`8000001@3oool00`000000oooo0:O0j`0]0:O0j`D0YkkZ102U^nP30:>di@D0TiWF
0`2BV=H509JTgPD0]]kd1@2/b_00102Yb_4000000000000000020:_5k@@0ZL;/1@2Zb>l40:g9kPH0
[<7Y102_`^P50:G2kPH0YKCS0P2`_N<20:njhPD0/KCK0`2ZZMH50:Nch@@0WjkR1P2WfOT40;3:k@D0
X[CU102Yc?830;3Dl`<0[Lka0`2^co420;3Vn@D0TmGn0P00J]X01000>KP05UcD031gh`0`Mn<20;6]
e0<0/:WA0`3H_;d30=o0^P040>K6]P3Td<<0i=330>C@``<0i]?400<0i]G50<O>h037c^000P35cN40
0`000000aLgQ0:g3jP030:g3jPD0Z<3[2@2W`>/@0?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0Z0:O0j`@0Yko[1@2W_^X409j]hP<0V:7K102CVMH409:HeP80UZCN0`2`e_@30;KNm0<0/Lk_00@0
[<[`00000000000000001P2[aNd20:W2k080Z<S`1@2Zb>l40:W1j`<0[<7Y0`2_aNX40:o2j0D0[KSQ
1@2U]><50:njhP@0/KCK102Y^><50:Nch@@0X=3h0`2WfOT30;;Gl`@0/<[]1@2N]^X40:W<lPH0[Lka
1@2`i_T505_;mP8006[J00<003Vh01ILe00FG=@01@2`ZM420=Rl_@@0gl2j0P3Va[H0103Td<<0i]?4
0>KCa03Vdl@20>KEa@D0aLgQ00<000000<?=hP2]`nX00`2]`nX50:S0j`T0Yl3[403oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo0000
00@0oooo0P0000020?ooobX0Yl3[102W_n/50:>gi`<0WZgR0`2HXM/509>IeP<0TYSF1P2`e_@30;7>
k`<00000102/bNl50:_5k@D0Z<S`1@2Z`^/40:W1j`H0[lGZ0P2_`^P20;:oi0D0[KSQ1@2/_^L40:nj
hPD0Z;_W102Y^><20:Nch@<0XM;i102Pd?P60;;Gl`@0W:gS1@2N]^X50:gMn0D0W>_i0P1`h=/503g1
d`8007O100<003Vi001ZfP000I400`0FG=@50;2Yd@040=Rl_@3O`;X0gl2j0=o0^P<0i/Jf0`3Vdl@3
0>KEa@070>GEa`35cN40aLgQ0<G=h@33cN8000000<?=hP050:g3jP@0Z<3[2@2W`>/A0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooobX0Yl3[0P2W_n/20:JmjPD0XkOW0`2N[N8309RQf`@0
TiWF1P2R_N`30;SGl0<00000102^c?040:c9k`H0Z<G_102Y`^`50:[2j`@0ZLK_1@2_aNX50;:oi080
[KSQ0`2]a>/40:bni`D0YkkZ1@2X^nL30:Vhh`H0XM;i1@2YdOD50:Fji`@0W:gS0P2N]^X309[]m`H0
K=c[00<0CLc<08OOo@27god00P27god30;G;jP<0NKKh00<004O4001g`@00>KT00P000I400`0;B/P0
5UcD0;2Yd@040;2Yd@@0gl2j0`3Va[H00`3/bk<0i]?40>KEa@020>KEa@<0iMG71033cN800`000000
[L?Z0:g3jP040:g3jP@0Z<3[2@2W`>/@0?ooo`800000103oool2000000X0oooo000@0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool01@3ooolX0:O0j`D0Y[gZ102S]nL309j]hP<0
V:7K1@2CX]l30::mk080^][`0`0000000`2heo00/<o`0;3?l0050:k<l0@0Z<C^0`2XaNl30:_4k0@0
ZL;/1@2Yanl40:W6k`D0[<;Z102b_n@60:g4j`80[;kW0P2V`N`50:NnjP@0Z;_W1@2Qe?X50:?4l@80
ZM7e0`2]eOD40:Fji`@0W:gS0P2JkOL504g:h@80GM3`1@2Yc?850;G;jP@0NKKh0P00Al@01@00>KT0
006A0001T@0;B/P05UcD0080/:WA0`2cZ<d20=o0^P<0i/Jf0P3/bk<40>KEa@<0iMG700H0hmG90<?=
hP33cN80`lgR0<7<h`0000030:g3jP<0[<;Z102X`>/90:O0j`h0oooo0`00000@0?ooo`004@3oool2
000000@0oooo0P0000070?ooob@0Yl3[102W_n/50:JmjP@0UjKQ0`2?V]X308fFf0D0Tj;O00@0^][`
00000000000000000P2jf_050;3?l0D0ZlG]102Xa>h60:_4k080ZL;/0`2Ya^l40:W7k`D0Y/3/102/
`^X40:_8k`D0[LC[1@2V`N`40:NnjPD0Wm;i1@2S_^`40:?4l@H0[MGe0`2U^^L205oGf080Gm3c1@2P
^NX208_;o@<0/koS0`2Yc?830<;:h0@0/JcC1029S]80100FCLP004O40000R0000I4200]:b0H0/jS=
00@0gl2j0>K6]P3Va[H0i/Jf0P3/bk<00`3`ck40i]G50>KEa@030>GEa`<0hmG91031c><00`000000
[<;Z0:c2jP030:c2jPD0Z<3[2@2W`>/?0?ooo`030000003oool0oooo00h0oooo000G0?ooo`030000
003oool0oooo00L0oooo902W`>/40:Noj`D0Wk?V0`2GY^4308nJfP@0SIKH0P2CX]l3000000<0^][`
0`2ge>l30;3?l0<0[/[^102[aNd50:[6kP@0ZlC/1P2Ya^l40:Roj`D0Y/3/102Va_440:_8k`D0Y/7]
102V`N`609o=m`@0YKgZ1@2S_^`509oZnP@0[MGe0`2JboP50:VagP@0X;WZ1P2c_n<40<;:h080`/?J
0`2a[=<508V>dP0401I=b000Al@000280001T@802d[81@2cZ<d30>K6]P<0k<^c0P3`ck430>GEa`<0
hmG90P3Re//20<7<h`030;o;i0000000_l_T00@0[<;Z1@2X`>/90:O0ja00oooo00<000000?ooo`3o
ool03@3oool001L0oooo00<000000?ooo`3oool0203ooolT0:O0j`@0Y;cZ1@2O/nH309NVh@<0Si[J
0P2=U]P3000000@0/<g^1P2ge>l60:k:kP@0Z/O_1@2Za^h40:S4kP<0ZLK_0`2Z`N/40:Roj`D0Y/G_
102Va_440:Fok0D0Y/7]1@2Rb?@50:NnjP@0YKgZ1P1liN/206WBnP@0Xko]0`2JboP20:f`fPD0ZK7N
102f_=h30;>oh`<0`LSO0P32b^030<;3fP@0/JcC1029S]8201I=b080002800<044G300]:b02cZ<d0
0`2cZ<d20;f]b@80i/Jf0P3/bk<30?3?/@80l]:`0`3SeLT30>;Fb`@0_l_T00<000000:c2jP2/`^X0
0`2/`^X40:S0j`X0Yl3[403oool00`000000oooo0?ooo`0<0?ooo`005`3oool2000000T0oooo8@2W
`>/40:Joj`@0Y;cZ102O/nH309NVh@<0Si[J0P00000309^_i@<0/<g^102mf>d50;??kPD0Z/O^102Z
anl50:O3k@@0Z<C^1P2Z`N/40:W6kPD0Y/G_102V_NX40:Fok0D0Y<G`0`2Rb?@20:W0jPD0YkkZ0P1Q
f=L509OBo0D0Y[OU102S_nd50:f`fP80ZK7N0`2e_=l40;JlgPD0`LSO1@32`mX40;6/d`D0TXc:00H0
AVcD01I=b00008P000280115``0;B/P20;>Xc@<0_Jg900@0i/Jf0>c;/`3/bk<0k<^c0`3`ck420?;B
/0030?;C/03SeLT0h]K;00<0h]K;00H0h=O>0;o;i02obn@0_l_T0;g;i@0000050:c2jP@0Z<3[2P2W
`>/?0?ooo`030000003oool0oooo00`0oooo000G0?ooo`030000003oool0oooo00X0oooo802W`>/4
0:Joj`@0W;;W102@Xn4208RFfP<0000000<0RiSK09^_i@2K[nD00`2K[nD40;gHk@<0^MC^0`2ccnh2
0:k:kPD0Z/O^102Ya>d50:O3k@@0Z/C/0`2Z`N/30:S6k`@0ZLK^1@2X_NP40:JmjP@0YlG_1@2TaO05
0:W0jP80YkkZ1@2OcoP309OBo080Z;?Q102V]nD50:nbfP@0[K3J1P2e_=l20;JlgP80^lGR0`31b=l2
0<C@h`@0`/?J1@2RULL409:<bP80AVcD00@0WRh00000R00@AL<044G31@2m[LT30>c;/`<0l<na0P3b
d[020?;C/0@0h]K;0`3Pelh40;g;i@030000002[`^/0Zl;[00<0Zl;[102X`>/90:O0ja00oooo00<0
00000?ooo`3oool02`3oool001H0oooo00<000000?ooo`3oool0303ooolP0:O0j`@0Xk_Z102L/^L2
092Sh@<000000P28U]X308^Hf`H0^=3/1P2ie>h50:k:kPD0ZlK^102Ya>d50:W5kP@0Z/C/1P2Xa^l4
0:Voj@D0Z;gX102Ya^l40:O5k`D0ZL7[102Y`>X30:C>mPD0Wloh1@2X/n420:Jgi@80[kCM1@2_/]X2
0:f`fP80/[cQ1@2e_=l50;_5hPD0a=3S102/Xll40::Ea`@0TXc:0`16K=@20000R003025=a@0@AL<0
_Jg90080_Jg90P3<^<H20>c;/`<0l<na0P3bd[020?;C/0030??F/P3Re//0h]K;00<0h=O>0P3NfM42
0;g;i@030;_;i`000000^l_W00@0Zl;[1@2X`>/90:O0ja00oooo00<000000?ooo`3oool02P3oool0
01H0oooo0P00000>0?oooa`0Yl3[102V_n/40:>kjP80W;;W0`000002092Sh@<0R9KJ1@2R]>H30;S@
k0<0`=O[1@2ecnd30:k:kP<0[<W^102[a^h40:S6k`D0ZLG^102V`nh30:S6k`<0Z<3[102Y_nT50:W8
l0@0ZLK_102X`>X50:W1j`<0Y]3f102Tc_H50:RagP@0Z;?Q1@2_]=d40:nbfPD0/[cQ0P2e_=l30;K3
i080^lGR0`2odnT20<C@h`<0][WL0`2/Xll50::Ea`<0TXc:1016K=@01@0008P08Dg5025=a@0@AL<0
_Jg900@0c;S60`3`ck420?;B/0<0l]>`0P3ce[830>3GcP<0g]WA102kbnL00`000000Zl;[0:_2j`03
0:_2j`@0Z<3[2@2W`>/?0?ooo`800000303oool001H0oooo00<000000?ooo`3oool03P3ooolL0:O0
j`@0Y[o[0P2S^nX3000000<0Rj;S0`21U=`308VJg@D0X[CV1030en/30;kEj`@0]Lo]1P2/bNh40:S5
k`@0Z<K_1@2W`^d40:K3kPH0Z<3[0P2Y_nT20:O8l@D0ZLS`102X_^T40:S0jP0305WBc02We_P0YmKh
00D0Y]3f102W/=h40:RagPD0[KKO102_]=d50:nlh`@0/[cQ1@2f`n@50;oCj@D0][WL102/Xll40::E
a`@0YJCE0`1]S^40102N;P008Dg5025=a@0QCLD50<bhaP030=_4``3`ck40l<na0080l]:`0P3bdk03
0??F/P030??J]03Pelh0g]WA00<0g]WA00H0g=_F0;_;i`2kbnL0^l_W0;S;j00000050:_2j`@0Z<3[
2@2W`>/@0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000003oool0oooo0100oooo6`2W
`>/20:>lj`<000000P2J/nT408^Rh`<0PICL1029V]d20::diP@0^lgX1P2neN/40;3<kP<0[<W^0`2Z
anh40:S5k`@0Yl?]1@2W`^d40:W3k@D0Z<3[1@2Wb?450:Nmj@@0Z;kY0P1Id/`50:OFn0D0YZoN102W
/=h40:^fh@D0[KKO102]^n@50:nlh`@0//?W0`2f`n@20;SBk@<0_m?Y0P2jbnL50;Jig0<0[:??1@2S
W<h40:FTe@<0KHkQ100QCLD30<bhaP<0flC30P3bd[030?;C/080lmJb0P3cf[@40=kId@<0g=_F0`2h
bnP00`000000^<_X0:[2j`040:[2j`@0Z<3[2@2W`>/@0?ooo`030000003oool0oooo00P0oooo000F
0?ooo`8000004P3ooolI0:O0j`<000000`2S_>/309Zcj@@0Rj;S0`21U=`308VJg@D0^lgX0P34e>L3
0;kEj`<0^]7/102`c>h60:[7kP@0Z<G^102W`nd50:S5k`@0ZL?]1P2Va_080:Nmj@80HmWE1P2Xg_X4
0:F_g`D0YZoN0P2W/=h20:VehP@0ZkKQ0P2]]]l30:^ki@@0[K_T0P2__><30:o3j@@0//?W1@2hd^d5
0;[;i`@0][WL102KTl/50:>LcP<0YJCE101]S^400`0dH=008Dg5025=a@020<bhaP@0flC300@0i/no
0?;B/03bdk00l]>`0`3ce[820??J]0030??N^03NfM40g]WA00<0g=_F0P3Gg=/20;S;j0030;G9jP00
0000]LWZ00@0Z/;[3P2W`>/?0?ooo`030000003oool0oooo00P0oooo000F0?ooo`030000003oool0
oooo0180oooo5@2W`>/3000000<0Y[o[0`2S_>/409Zcj@<0Rj;S0`21U=`50::bh`80^lgX1034e>L6
0;[Ak0D0[/[^1@2Yanl40:S5kPD0YlG_102XaNl40:G3k`<0Y/K`0`2X`>/40:Nmj@80M>7V1@2UjOX5
0:B`h0@0YJoO102V[mh50:VehP<0ZkKQ1P2[^nD30:fki0D0[l?Y1P2bc^l50;SDkP@0Y:3A102LU</3
09^Cb`D0Xic>102^]=d307nKi080=63@00<08Dg50<bhaP3Ka<<00`3Ka<<20>K?_`<0l]>`0P3ce[82
0??J]0<0lmjh0`3LfmH30=OLf`@0]LWZ00<000000:W1j`2Y`N/00`2Y`N/=0:O0j`l0oooo0P000009
0?ooo`000`3oool2000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0D0?oo
oa40Yl3[0`0000020:O0j`@0Y[o[102J]^/408RTi`<0Ni?O0`25Umd50::bh`@0a=CW0`34eNH50;K?
k@<0[/[^0P2[bNl50:W7k`@0Y/G_1@2WaNl40:G2kP@0YL?_1P2X`>/20:Nmj@80R>Gh0`2Kl?<40:Bb
hPD0Y;3P0`2U[ml50:NdhP@0ZKGR102Z^nH50:^ki@@0[LCZ0`2_`nT20:k;k`<0//k_0`2ce_820;SD
kP<0[;7K0`2TX=4409bDb`@0Vi?;0P2SW<h30;2fg@@0[[CM0`1oVn@203APd0@0flC30`3Vckl20>gG
_@<0lmJb0P3cf[@30??N^0030?;S_@3Gg=/0emcK0080emcK0P3Ag>430;G9jP030;78j`000000ZL7[
00@0ZL7[3@2W`>/;0?ooo`<0000000<0oooo0000003oool0203oool00080oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo3P2W`>/2
000000H0Yl3[102T_N`409Zfj`@0R:CW0`1kTml308FGg@H0^/KS1034eNH30<;Di`@0]/o]1@2[bNl5
0:O6k`@0Y/G_1@2V`nh40:G2kP@0Z<C^1@2X`>/208SUn080Vo3c102V^>H40:BbhP@0Y;3P102U/n84
0:NdhPD0ZK_W102Z^nH50:_3k0@0[LCZ1@2^bnl50;?FlPD0[;7K102TX=4409bDb`<0Vi?;1@2`]]d4
0:jdg@<0Oi_T0`0dH=020=_4``<0i/no0`3]ekd0103`g[d0lmJb0??J]03cf[@30??N^080l^>m00<0
knO40=OLf`3Gg=/0103Ag>430;78j`030000002ab>/0Z<7[00@0Z<7[3@2W`>/60?ooo`@00000103o
ool00`000000oooo0?ooo`070?ooo`000P3oool010000000oooo0?ooo`00000;0?ooo`040000003o
ool0oooo0?ooo`8000005`3oool:0:O0j`<000001@2W`>/40:Noj`@0Y;g/102J]^/308RTi`<0Ni?O
102KZN430;[6h`<0a/oQ0P34eNH50<;Di`D0/Lg^1@2Yb?040:O6k`@0YlG_1@2V`nh40:O6l0@0Z<C^
0P2Hg_h208_]i@D0ZlK]102V^>H30:BbhPD0Xk7R102U/n840:Nki`D0ZK_W102Y`n`40:_3k0H0[<S^
1@2`eO<40;72iP@0[;7K102TX=4409bDb`@0YZgL102`]]d50:bfh0<0PikT0`0oO><40>K?_`80kMNm
0P3`g[d30??J]0<0lmjh00@0l^>m0>oWa03_il@0knO40`3Ag>430<WJiP80/LS[00<0[/K/0000002^
a^`0102X`N/>0:O0j`80oooo0`0000080?ooo`030000003oool0oooo00L0oooo00020?ooo`040000
003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01P0oooo1@2W`>/3000000T0
Yl3[102W_n/509fjk0<0RZ_[0`1dUN@307VAgP@0VjWQ1P36cn440<;Di`<0_m?Y0`2acNh20:k=l0D0
ZLS`102Va_040:O5k`D0YLKa102Wa_0409o@n080PnWQ0P2`foH50:_6k@<0Y[SV102Q/>850:>ahP@0
Y[_X102W^nL50:S2k0@0ZL?/102[a^h30:c8kP<0[M?d0P2`eO<30;7=kP@0/L;V0`2//M/40:BPd@D0
W9oF102V[M`40;2jh@@0[;KP1023W^@303mlh`80i/no0P3]ekd30?3N_@80lNG00`3cg[P20?;S_@80
knO40P3[j/`50<WJiP@0[/K/00<000000:S1j`2X`N/00`2X`N/=0:O0j`800000303oool00`000000
oooo0?ooo`060?ooo`000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06@3oool0102W`>/0000000000000000=0:O0j`@0YKo/1@2M^^`308Z[
j`<0M9GT0`1iTMh209^Yh@<0/k[O0`36cn430<_AgPH0_m?Y1@2^cO050:K8l@@0Y/K`102TaO050:G6
l@D0XlOb0P23jN450;3KmPD0WJgR0`2O[^840:6`hPD0Y;[X102V^nP40:O2k@D0Z<;/102YaNh40:_6
kPD0[M?d1P2acNh30;72iP@0VI7:102GU<h409bOeP80YZgL0`2]^n@40;2jh@@0YkGS0`21W^D403ml
h`030>K?_`3]ekd0kMNm0080l=jm0`3aiL020?3[a080l^>m0P3_il@30>_Zc0040>C/e@39f^H0bM[V
0<WJiP80`=KZ0`2^a^`00`2[a>`000000:S1j`040:S1j`d0Yl3[3@3oool00`000000oooo0?ooo`06
0?ooo`000`3oool2000000X0oooo0`0000030?ooo`800000603oool300000140Yl3[102U_n`5096c
kP80LicZ0`1dUN@307VAgPH0/k[O103;dMh20<gBg@<0_m?Y102ld^/40:[<lPD0Y/Sa102Ta_440:C5
l0H0YLG`0P2<jo050:k`mP@0W[3T1@2M[N8309n^hP@0XkSX102T^^P50:K1k@@0Yl;]1@2XaNh40:W5
kPD0Zm7d1@2^do<50::KcP<0WIC:0`2ITLX509NDcP<0W9oF1@2]^n@20;2jh@<0[K_T102W]N<4086N
i@80<Y7`0P3]ekd30?3N_@80lNG00`3`jl@00`3^k/P0knO40>oWa0030>_Zc0<0i>cE1@30e^X30:_4
k0030000002[a>`0Z<3[00@0Z<3[302W`>/=0?ooo`030000003oool0oooo00H0oooo000D0?ooo`03
0000003oool0oooo01D0oooo0`0000040?oooa40Yl3[1@2R_Nd4096ckP80LicZ0`1WRn8308VLg`<0
/k[O0`33`mX20<_AgP@0cM;M1@2ld^/20;WCk@@0Z/cb1@2Tb?840:C6l@D0YLKa102Ihod409odj`@0
X[c[102N/>@409f]hP@0X;KX102S^>P40:C0k@D0Y/7]102Wa>h40:S5kPH0Z=3e1@2[eOH40:JSd`@0
XY_>0`2MU<X409VAbP@0UiC>102[_>H:0:fki0<0YkGS1021W^D00`0DFM803h_T00n;i0030?3N_@<0
lNG00P3`jl@20>k^b0040>__c03[j/`0jn[<0>_Zc0<0i>cE0P3Kjmh50;S@k080ZlC/00<0ZL;/0000
002Y`^`0102X`>/=0:O0j``0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3o
ool04P3oool3000000P0oooo3@2W`>/50:Jok0@0X[g]0`2A/nh307>LjP<0Ih_R0`29W=l60<?3fPP0
cM;M1@2idnd40:K=m0D0Y<Sb1@2Sao<509oCnP80WoC[1@2[e?H40::lj`<0W[3T1@2M/nL40:2fj0@0
Xko]102T`>d50:K4k`@0YlC^1@2WcoD50:SEm`80ZmGf0`2XZmT30:JSd`@0XY_>102MU<X309VAbPD0
YkSV102[_>H40:^ki@D0[K_T102Q/nD407fLiP0402UWf00DFM8007oI001of@<0lNG00P3`jl@20>k^
b080jno<0P3Yl<l30>C/e@80fn_N0P3@i^H40;S@k0@0ZL;/00<000000:O0j`2W`>/0402W`>/;0?oo
o`030000003oool0oooo00H0oooo000D0?ooo`800000403oool3000000`0oooo3@2W`>/50:Jok0@0
Vk_^0`1oZ_0205V<j0<0Ih_R102PZMd40<?3fP<0c<KD1@3=d]d30<kAg0D0]M?`0`2VcO@60:39m@@0
Wlcg0`2OdoX209G`k@<0Z^og102[e?H409J^j0<0V[3W102M/nL50:6nk@@0Xko]102TaO050:K4k`@0
YLkf0`2WcoD20:KEn0@0Z=Gg1@2XZmT40:JSd`<0XY_>102MU<X40:6_h@@0YkSV1@2Y^^H40:^ki@D0
ZKWU102Q/nD307fLiP<0:FOH0`0;Qn820?3[a0<0k^k800D0jno<0>W`c`3Yl<l0jO3?0>OadP030=_[
gP@0d>KV102`b^d30:W2k0030:S1j`000000Yl3[0140Yl3[2P3oool00`000000oooo0?ooo`060?oo
o`00503oool00`000000oooo0?ooo`0<0?ooo`<000004@3oool<0:O0j`D0YKo/102K^nh307nZl080
FHcX0`1XRn440:2Yg@80`l?J103<a]@0103Ba/l0cM;M0<gBg@3=d]d30<kAg080c]3J0`2edo020;7D
lP@0X<kh1@2Kc?T409o<m`80UO3]0P2ZkoL409C5n0@0Tk;/102F[^P309Z`i`@0W[c^1@2Q_^d40:?5
l@@0Y<G`1@2Sc_H40:G>mPD0Y]Gh102Y/=d40:R[f@@0YZ?C102KV]8409fSf@@0XJoQ102X^^H50:Vj
iP@0ZK_V102Y^ND40:6ci@<0OIcV100YImP303FOl`<0k^k800@0jno<0>W`c`3Yl<l0jO3?0P3WlM82
0>Cbe@<0d>KV0`33gN`40;3:k@<0Z<7[00<000000:S1j`2W`>/0402W`>/:0?ooo`030000003oool0
oooo00H0oooo000D0?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`d0Yl3[102U_n`409:g
l080IIg`0`1IS>P306R;h@<0X:WM1@3<a]@30=;6c`@0c]7L103>d=X50;7DlP@0Ulok1@2Kc?T209?W
nP80S^oR102>h_d409C5n0@0Tk;/0`2F[^P409Zkk`@0W[c^1@2Pa_<40:?5l@@0XLkg102Sc_H60:?D
n@@0Z;;O102Y/=d30:R[f@D0W9G<102KV]8409fSf@@0Z[gW102X^^H50:Vmj0@0ZK_V102V^>H409^`
iP<0MiWV00@0>g;M02UWf00YImP015KA100eWo<0103[kl`0jO3?0>W`c`3Yl<l20>OadP80i?;E0P3O
lm/50<?Mk0D0[<G/0`2X`>/00`000000Z<3[0:O0j`0@0:O0j`X0oooo00<000000?ooo`3oool01@3o
ool001@0oooo00<000000?ooo`3oool01`3oool3000001P0oooo3@2W`>/40:>nk@@0T[O`0P1UWO02
041mh`<0J8_Q1@2c/]P20<c6e0@0d/K?0P3Ea<X50<k@fP<0clcG1@2^do<309O?n`<0Rm[o0P1^gm`5
07cViP<0S^;m0`2DaOP508Rdl`<0TkS`102J^nl409g7mPD0X<Kc102Nc_P40:7>m`D0XM?i1@2W/^04
0:Rbg`@0Wi?70`2NTlT409bEc0@0Vi[B1@2Z`NX40:Zmi`@0Z;kY102Y_NP50:Nji`@0Y[SV0`2K/>H4
07NIiP80>g;M0P04E]46093;o080io7B0P3Tl]D20=ocf`<0eo7S102gd^h30:c5k080ZL;/0`2X`>/0
0`000000Yl3[0:O0j`0?0:O0j`X0oooo00<000000?ooo`3oool01@3oool001<0oooo0`0000050?oo
o`<00000703oool=0:O0j`@0Xkk]0`2B]o0306FMl080@7gS0`1dTN450;>bf0@0d/K?0`3Ea<X0103G
`<@0c]3J0<k@fP3>d=X40<o<e`040=35c`2^do<0[]?c0:kCl`<0/<o`101ogoX20:c_m`<0`/WP102B
`_L307>bn0<0NK3f0`28]?<409>hl0@0UlOh102MaoH509_>nP@0W/kh1@2NdOX40:J_gP@0Yk;P1@2Q
U<L309nCa`<0WY?91@2LUL`209^JdP80ZL?]102Z`NX50:Nlj0@0Z;kY202W^^L40:JhiP@0U:cW0`1c
U^D303]bg@<0>GcT1@2^f?H0103Tl]D0go?K0=ocf`3Olm/30=Oah`80bnW[102gd^h50:W2k0<0Yl3[
00<000000:O0j`2W`>/03`2W`>/90?ooo`030000003oool0oooo00D0oooo000C0?ooo`030000003o
ool0oooo0080oooo0`00000P0?ooo`d0Yl3[102Q_^h308NclP80@h_/0`10ON<307BAh@80/k;H0`30
]]020=;6c`<0eLC:0`3G`<@50<o<e`<0d<G?102`co030;c9i@80[>og1P32bN0409NFd@<0PIOO0`1k
Z?0308:jn@D0SLCj0`2GaoP509K=n`@0W<Of102Mc_T50:BYfP@0YZoN102RU<H40:6Da`@0Wi?70`2N
TlT409bEc0D0ZL?]102V^NL40:Nlj0T0Yk[W102V^NL40::fiP@0U:cW0`1cU^D304eoh@<0>GcT0`2^
f?H01033h^h0d>_X0=3[j03@jnP30=Oah`<0bnW[1@2_bNd20:W2k0<0Z<7[0P2W`>/00`000000Yl3[
0:O0j`0@0:O0j`P0oooo00<000000?ooo`3oool01@3oool001<0oooo00<000000?ooo`0000000P00
000T0?ooo`T0Yl3[102V_n`40:6nkP<0Qk?b0P13Rn`202I^gP<0M97Q1P30]]040=G4bP<0el340P3H
^kd20<o<e`@0d<G?0P3A^l@40;c9i@<0c/GA00@0fL310<;9h032bN00`/WP0`2iZ/X409NFd@<0PIOO
0`1kZ?0308:jn@D0T;kf102BbOX409fkk@@0W<Of102SX]@50:BYfP80YZoN0P2TU/H30::DaP@0XIC7
102OTlL309jCb@D0Yl;]1@2V^>D40:Jii`@0Z;cX1P2W^^L30:Nkj0@0Y[WW0`2R]^H409B/i`@0LiKU
0`1=On4306NLkP80`n;^0`3@jnP20=Kbh`@0bnW[0P2mfnl40:o9k@D0Z<7[0`2W`>/00`000000Yl3[
0:O0j`0@0:O0j`L0oooo00<000000?ooo`3oool01@3oool001<0oooo0`00000W0?ooo`T0Yl3[102V
_n`409jmkP<0NJkd0P0HLn8202I^gP<0PYSP1030]]020<Rfb@80eLC:0`3G`<@40=Rk_@@0d<G?0`3A
^l@00`3B/kX0_<WU0;c9i@030<k5d@<0fL311@2iZ/X409NFd@<0PIOO102FVM@409:[i`<0T;kf1@2N
Zn0409fkk@@0Xic>102SX]@40:BYfP@0Y9K6102RU<H30:6Da`@0Wi?71@2U_n`40:Nhi@@0Y[SU0P2V
^NL30:VojP@0Z;cX0`2W^^L60:Nkj0<0Y[WW102N/nL408jWi`@0LICT0P1RSND406NLkP<0d>_X0P3F
l^<30=Gfi0D0_M__1@2Z`n`70:O0j`030000002W`>/0Yl3[00l0Yl3[1`3oool00`000000oooo0?oo
o`050?ooo`00503oool00`000000oooo0?ooo`0W0?ooo`T0Yl3[102V_n`409jmkP<0NJkd0P0HLn80
0`07Fm@09VkN08:Hh00208:Hh080`;K@1038]/T40=O0a0@0f;^m00<0f;Ff0=35c`3@aLl00`3A^l@3
0=:c^P@0c/GA0`3I`<400`3K`;d0^J[:0;VZbP020;VZbPD0XiG70`2KTLT409JIe080TZ_W0P2TV<T3
09nNdPD0WZ_P102TV<P40:>LcP<0Xj;D1@2UV<L40:BFaP<0XYC60`2QU<L50:FljP<0YKo/0P2X^ND4
0:Nhi@<0Y[SU1P2Y_nX30:Rlj0@0YkgY1@2W^nP40:>hi`@0W[?W102>YnL3076Di0<0HXgU102?^?83
0=Kbh`80eOKT0`3=lN/50;7=kP80Z/?/0`2X`N/60:O0j`030000002W`>/0Yl3[0100Yl3[1`3oool0
0`000000oooo0?ooo`040?ooo`002`3oool5000000D0oooo0P00000Y0?ooo`P0Yl3[102V_n`409bl
k`<0K:We00<005?<01QchP07Fm@00`22V>050<Rfb@80cKC20P3G`<@40=Rk_@<0f;Ff103A^l@30=:c
^P030=Rb/P3>aM40c/GA00<0fL310`3K`;d20;VZbP80]:O<102SULL409^Ab@<0UYWD102TV<T409nN
dPD0Z9W7102TV<P30:>LcP@0Z9_9102UV<L40:BFaP<0XYC6102V^nP50:FljPD0Z;WU0`2W^>D40:S1
k0D0ZKoZ102V_>T40:Nmj@D0YKWW102S^>L409V_iP@0R:;U0P1dUN@406:=i@D0[m7b00<0eOKT0<ga
j`3=lN/00P3=lN/20;oRl0@0/Lg^1@2X`N/70:O0j`030000002W`>/0Yl3[0100Yl3[1P3oool00`00
0000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02L0
oooo202W`>/40:Jok0@0W;c_0`1/ZOD00`00Dl`01e_D00MKe00308nNgP<0b;K9103=]<840=Rk_@@0
f;Ff00<0fK6`0=6ka03A^l@00`3B/kX30=Rb/P@0fL310`3K`;d40;BWc0D0XiG70`2KTLT40:VJa`@0
Y9S90P2OW]820:fNb@@0Z9W7102TV<P40:^Rc@<0Z9_9102UV<L40:BFaP@0Yk_X102V^nP50:RkiP@0
Z;WU102W`N`40:S1k0D0Y[[W102V_>T40:Jii`@0YKWW1@2Q]NL409V_iP<0R:;U0`1dUN@407^Pj@80
[m7b0P35j>h30<kej@D0_n;`102[a>`<0:O0j`030000002W`>/0Yl3[0100Yl3[1@3oool00`000000
oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo
202W`>/40:Jok0@0Vkc`101PY?D00`00@<801e_D08nNgP0208nNgP030<Rfb@3=]<80cKC200<0cKC2
00@0d;:l0=Rk_@3H^kd0f;^m0`3H]KH30=Va/0@0d[>j0`3H/[800`3Q^Zl0fL310=W0`@040=_0_@03
0=K2aP2dYl`0]:O<0080]:O<102SULL40:^Pc0@0ZI[70`2TV<T40:fNb@@0Z9W70P2TV<P30:nZd`<0
Zj;=102XVlT30:FHa`D0Z;gX102W^nP40:Rki`@0Z;_V1@2W`>`40:O1k0@0Y[WV102V^^L50:Nlj0@0
Y[WW102T^NP40:6ei`@0VJoV0`28X^D407BEi0<0Nj3Y0`35j>h20<kej@<0b_G/1@2bcnl40:S1k0`0
Yl3[00<000000:O0j`2W`>/03`2W`>/50?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool80:O0j`@0Y[o/102K_?04062Tm@040010
`P2?W]h0SikN08nNgPD0cKC20`3@/[`00`3H^kd0f;Ff0=Re]P020=Re]P<0fK6`00<0fZn/0=:c^P3B
/kX00`3H/[830>6j[`@0fl2m0`3F`/H30;BWc0D0YZCD0`2[X<`40:VJa`@0/JS?102]W/T30:RIa`D0
[j[C102[X/d30:RKb@@0ZL3Z102X_NP50:Nkj0@0Z;_W102W_n/40:O0k0D0YkWV102V^NH40:RnjP@0
YkcX1@2U^nT40:Bij0@0WK;W102CZ^D308BNh`@0OYcU102H^^l00`3>mNT0b_G/0<[ek0020<[ek080
_^Cb0`2bcnl20:[4k@@0Z<7/2`2W`>/00`000000Yl3[0:O0j`0@0:O0j`@0oooo00<000000?ooo`3o
ool0103oool000d0oooo00<000000?ooo`3oool02P3oool2000002P0oooo202W`>/40:Jok0D0Vkc`
0`1JX_D01000@<80Uj;L09NRg02GX]`30<fd`P@0d;:l103H]KH30=Va/0<0fZn/00@0d[>j0=Rb/P3H
/[80f;:b0`3Q^Zl00`3Ya:l0fl2m0=_0_@040=K2aP@0Yj_J102VY=@40:^Pc080ZI[70P2`/=P30;6X
c`@0[Ik9102`]=/40:nZd`@0Zj;=102Y`^`40:W0jP@0Yk[W1@2W^nP40:NnjP@0Yko[102X^^L40:Ni
iPD0Yl3[102X_^X40:Fkj0@0YK_Y1@2R]^L409fbi`<0Tj[U1024W^<307jLi@@0]]_c0`35m>h50;kT
lP@0Z/C]402W`>/00`000000Yl3[0:O0j`0?0:O0j`@0oooo00<000000?ooo`3oool0103oool000`0
oooo0P00000>0?ooo`030000003oool0oooo02H0oooo202W`>/40:Jok0D0Vkc`0`1JX_D01@00@<80
Uj;L09NRg02GX]`0cKC200D0d;:l00@0d[6h0=Re]P3H]KH0f;Ff0`3I/K030=Z_[0<0f;:b0`3Q^Zl3
0>W4[`@0e/;60P39_]040:N[fP<0YZCD102[X<`40;2`f0@0/JS?0P2]W/T20:jjh`@0/;CK0`2_Z]<5
0:O2k@@0ZL;/102V^NH40:Nji`T0YkkZ102X_>L40:Rji`P0Yl3[1@2U^NL40:Fkj0@0Y;OW102R]^L4
09fbi`<0Tj[U1024W^<4096^jP80]]_c0P35m>h30<Cfk@D0/<k_102X`N/@0:O0j`030000002W`>/0
Yl3[00l0Yl3[0`3oool00`000000oooo0?ooo`040?ooo`007@3oool00`000000oooo0?ooo`0V0?oo
o`T0Yl3[0`2V_n`509^ml080FZ?f00@001NK09NRg02GX]`0Uj;L1@3@/[`30=:a^0040=Re]P3I/K00
fK6`0=Va/0@0fZn/00<0g[>[0=Rb/P3H/[800`3Q^Zl30>W4[`030>_9/P3F`/H0e/;600@0bKk@0`2W
ZmX30:JTe0D0Yk;P102`/=P30;6Xc`D0[[[S0`2`]=/40:Fok0D0Yl;]102V^>D40:JiiP@0Z;o[102W
_^X50:Rlj0@0Z;cW102V_n/40:O0j`@0Y[WV102U^NL50:Jjj0@0Y;OW102P]>L409V]i0<0SZ?S1026
W^<4096^jP030<GdkP34m^d0a?K]0080a?K]0`2kh_<40:W3k0@0Z<7[402W`>/00`000000Yl3[0:O0
j`0>0:O0j`@0oooo00<000000?ooo`3oool00`3oool001h0oooo00<000000?ooo`3oool09P3oool9
0:O0j`D0Y[o/0`2K_O0205ZSmP04000GV`2HY=h0V:CN09RTgP<0d;:l103B/KP40=Va/0@0fZn/00<0
g[>[0=Rb/P3Q^Zl00P3Q^Zl30>W4[`<0jlVb1@39_]0409jZg`<0VjcS102W/^040;2`f0@0Z;[W102^
^^<40:Bkj@@0YKo/1@2W^>D40:Jhi@@0Z<7[102X_n/40:Nlj0@0Z;cX1@2W_^X40:Joj`@0YkWV102V
^NH40:Nmj@@0Y[[X1@2S^>P40:2di`<0VJgT102>Xn<308JNh`@0[M?d0`2nmO030;_Rl`<0[/__0`2Y
`n`D0:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?ooo`007`3oool2
000002P0oooo202W`>/50:Jok0@0WKg_00<0GjGf000GV`2HY=h00P2HY=h00`3@/[`0d[6h0=:a^003
0=:a^0030=Bb]P3I/K00fK6`00@0fZn/0P3N/j/0103H/[80hKZ_0>6j[`3Q^Zl30>W4[`<0jlVb00@0
ilRg0<Vnd039_]00bKk@0P30^=8409jZg`<0VjcS102Q]>H40:Bgi`@0Z;[W102U^NL40:Bkj@@0Z;[V
102W^>D50:S1k0@0Z<7[102W^nP40:Nlj0@0YkgZ102W_^X50:Nji`@0YkWV102W_n/40:Nmj@@0Y;SX
102S^>P40:2di`@0U:KR102=XN4409:/i`<0__G`0`2om?050:k;k`@0Z<3[502W`>/00`000000Yl3[
0:O0j`0@0:O0j`030?ooo`000000oooo00@0oooo000Q0?ooo`030000003oool0oooo02H0oooo2@2W
`>/40:Jok0@0W[g_00@0IjWf09RTgP2HY=h0V:CN1@3B/KP30=Bb]P030=Va/03J[j`0fZn/0080fZn/
0P3N/j/30>6j[`<0jLB_0`3[bK830>O8]`D0`;SB0`2NZ]l409f`i@@0XKCV0`2T]nL50:Jii`@0YKWW
102X_>P40:RjiP@0Yl7/102X`N`50:Nji`@0Yk_X102W_^T40:NmjP@0Z;cX102W^^L50:Joj`@0Yko[
102T]nH40:Bhj0@0X;7T102K[><409BVhP<0SJ7Q0P2B[>L30:cFmP80_oC`1@2ffo<40:W2k0@0Z<3[
502W`>/00`000000Yl3[0:O0j`0?0:O0j`030?ooo`000000oooo00@0oooo000R0?ooo`030000003o
ool0oooo02H0oooo2@2W`>/40:Jok0@0W[g_00@0IjWf08jTi02>Y>@0SZCT0`3B/KP40=Bb]P@0fZn/
0`3N/j/00`3T^jd0hKZ_0>6j[`030>W4[`<0jlVb0`3Wb;L00`3Qa;X0`;SB0<2hdP020<2hdP@0XZgO
102M/>D30:6diPT0Y[WW102X_NT40:Rlj0@0Y[k[102W`N`40:NiiP@0Yk[W1@2X_^X40:Nnj@P0Z;cX
102V_^X40:Joj`D0YKOU202T]nH40:2ai0<0VjcS102DY^8308fQh@@0[=Kf00@0^?S_0;__m02kko@0
^nod1@2[anh30:W2k1T0Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00
8`3oool00`000000oooo0?ooo`0V0?ooo`T0Yl3[102V_n`409nnkP0506j/mP2>Y>@0SZCT08jTi03B
/KP01@3D/[H0103F][T0fZn/0=Z_[03J[j`30=jcZ`80i;^]0`3Ya:l30>_9/P<0ilRg0`3Qa;X20<2h
dP80_[GA102R[Ml40:6bi0<0XkOW102V^NL50:Jlj@@0Z;gY102V_>T40:Jnj`P0YkWV102X_nX40:Rn
jPD0YkcX102X_>P40:Jmj@@0Y[kZ102V^>H40:Fgi@D0Y[_X102T]nH30:2ai0@0V:KP102BXMl409J^
i`030;Shk`2kko@0^nod0080^nod0P2`dO440:_7kQ`0Yl3[00<000000:O0j`2W`>/03`2W`>/00`00
0000oooo0?ooo`030?ooo`00903oool2000002L0oooo2@2W`>/40:Jok0@0Wkk^0`2>Y>@50=Bb]P80
e[Ji0P3J[j`30=jcZ`<0i;^]00<0j/B^0>W4[`3Ya:l00`3[bK820>O8]`@0hLBj1@2n]M440:N`gP@0
XK;T0`2S]nL40:Fii`@0Y[cY1@2V^^L40:Jlj@@0Z;[V102W^NH40:S0j`@0Z;oZ102W^nP40:Nlj0D0
YkcY102V_NT40:NjiP@0Y[SV102V_NX40:Jkj0D0X;7T0`2M[^<409RVh0@0TZ7O0`2]iOT30;?hkPD0
/=7a102X`N`L0:O0j`030000002W`>/0Yl3[00/0Yl3[0`3oool00`000000oooo0?ooo`030?ooo`00
9P3oool00`000000oooo0?ooo`0U0?ooo`T0Yl3[102V_n`40:2nkP<0JYc]0`3D/[H40=Jf^@040=Z_
[03N/j/0g[>[0=jcZ`<0i;^]0P3Za:h30>_9/P<0ilRg103Qa;X0103L`Kd0_[GA0;jed@2n]M420;jd
d0@0Yk3N102U]><30:FgiP@0YKWW102W^^L40:Jji`D0ZKcW102X^^H40:O0j`@0Z<3[102W^^L40:Nk
j0@0YkgY102W_>T50:Nki`@0Yk[V202V_NX40::ah`@0X;7T102M[^<309RVh0D0W;_^00<0/oS^0;GQ
m@2ehOD00`2ehOD50:W3k0<0Z<7/7@2W`>/00`000000Yl3[0:O0j`060:O0j`P0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<000000?ooo`3oool09@3oool90:O0j`@0Y/3/102P_^h206ZLk@<0
e;:f103F][T40=jcZ`80i;^]0`3Za:h20>k:[`<0ilRg103Qa;X30=c1_@D0_[C@0P2W/=h20:bbg0@0
YKCS0`2U]nH40:RjiP@0Yk[W102X_NP40:Vli`D0YkkZ102W`>/40:NiiP@0Yk[W1@2X_NT30:Nmj@@0
Yk_X102W^nL50:Jlj@@0Y[gZ102T/^<40::ah`<0X;7T1@2HXMX309FSg`<0W;_^00@0Z?Cb0;Cam@2d
lOD0]?7e102[b>h40:W3k200Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`030000003oool0oooo
0080oooo000X0?ooo`030000003oool0oooo02H0oooo202W`>/40:K0k0@0XKk^00<02g7O06ZLk@3D
/[H0103F][T20=Nm`080g[>[0`3T^jd30>[4[P80k/Z_0P3_c;040>74^P@0g<6m00<0f;k00;jdd02n
]=000P2n]=050:bbg0<0YKCS102W^>D40:RjiP@0Z;_X102X_NP40:Nkj0@0YkkZ1@2X^NH40:NiiP@0
Z;kY1@2W^nL70:Nkj0D0Y[_X0`2V_>T50:Jdh`@0Y;;S102R/N8309jXg@@0V:7J102EXml0102Xm?80
]?7e0;Cam@2dlOD30:o@lP@0ZlS^902W`>/00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0080oooo000Y0?ooo`8000009`3oool=0:O0j`<0XKk^00<02g7O0=Jf^@3F][T00P3F][T40=Nm`004
0=jcZ`3T^jd0i;^]0>Bk[@80j/B^0`3^bZl20>o</0030>g</`3Qa;X0hLBj00@0g<6m0P3H_/020;jd
d0<0`;G?102//]`40:VehP@0YkSU102X^NH40:Rkj0@0Yk[V102W^nP40:VjiP@0Z;WV1@2X_nX40:Nj
iPT0Yk_W102W^nP40:NiiP<0YkOT102V]><50:BfiP<0X[7R102NZ=d309RQfP@0Xmgl0P2Um^`50:o@
lPD0Z<7[8@2W`>/30?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool002/0
oooo00<000000?ooo`3oool09@3oool=0:O0j`@0X[k]0P3F][T50=Nm`0<0i;^]0`3Za:h20>k:[`<0
klb`0P3]c;<40=c1_@<0f;k01@30]Ll50;6cfP@0ZKGR102Y^>@40:RiiP@0ZK[V102W^^H40:Vli`@0
ZK[V1@2X_nX40:Rhi@@0Yk[V102X_>P40:Nki`D0Yk[V102W^NH30:Ngi0@0Y;SW102T]^H30::ahPD0
V:?M102K^Nd00`2Um^`0/Mgf0;7MmP030;7MmP@0ZL;/102X`N/M0:O0j`P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?ooo`d0Yl3[
102R_^d50=Nm`080e/K;0P3T^jd30>[4[P80k/Z_0P3_c;030>g</`030>[<^03L`Kd0g<6m00@0f;k0
00@0e[k30<2ec`30]Ll0`;G?0P32]/h40;6cfPD0[;KP102Y^>@40:Zji@@0ZK[V202Y_>L50:Rmj@@0
Z;ST102X^>D40:Vmj0@0Z;cX202W^^H40:NiiP@0YKOV102T^>L409nOe0<0VigF102HXmd209Kaj`D0
/>[h102Za^h40:W2k1d0Yl3[2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo000]0?ooo`030000003oool0oooo02H0oooo302W`>/40::nk@<0ekg0103Fa//00`3T^jd0j/B^
0>[4[P030>k:[`80klb`0P3]c;<30>[<^0@0f;k00`3F_/<50<:fcP@0]KCH102/]^050:^hh`<0Z[[U
1@2Y^nH40:Vli`D0Z;_W102Y^N@40:Rhi0@0ZKkY102Y_NP40:Nii@L0Yk[V1@2V]^D30:FgiPD0XjGG
102OWm@309^MeP80V:?M0P2EjOT20:Cbm0D0[<_`0`2Za^hN0:O0j`l0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`010?ooo`00;P3oool00`000000oooo0?ooo`0V0?ooo``0Yl3[102S
_nd00`3G_L00e/K;0=K6b`030=K6b`<0j/B^0P3^bZl30>o</080kLbc0`3Zc;P00`3VcKh0f;k00=Rn
`0040=Jn``040=>oaP32]/h0`[K>0<:fcP80a;O=102e]=P40:neg@@0ZkSS102Z^N@40:VkiPD0ZKWU
1@2[^nD30:Vii0T0ZKkY102X]n@40:Nii@@0YkOT0`2V]^@40:Jfi@@0YJ[J102SYML409nOe0<0VigF
0P2EjOT00`2Tl_@0[=7c0:cAl`020:cAl`@0[<_`7@2W`>/D0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00@3oool002l0oooo0P00000W0?ooo``0Yl3[0`2S_nd50=K6b`<0eM7E0`3^
bZl20>o</080kLbc0`3Zc;P30>K=_P@0e[k30`3C_lH00`32]/h0a;O=0<Bgc@020<Bgc@80]KCH0P2i
]=D40:neg@@0[KOP102Z^N@40:^ih`<0ZKWU1P2[^nD40:Vli`@0ZKkY1@2X]N880:Rgi0@0YkOT0`2V
]^@40:J^g@@0YJ[J0`2SYML509blkP80S^kV102/f?L40:cAl`D0Z<7[602W`>/H0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool09@3oool<
0:O0j`<0Y;o]0`3Fa//30=GAe@<0f=_J0`3_c;020>g</`<0j/bh0`3VcKh00`3QclH0e[k30=Jn``04
0=>oaPD0a;O=1@2i]=D40;>dfP@0[KOP102]^>840:^ih`D0Zk_U102Y^>@40:Vli`@0ZKCQ102X]N84
0:Vii0@0Z;OT102W]n@40:N`gP@0YZkM0`2UZ]X409j/h@<0W;c^00@0N>CK0:[On@2ZgoT0Z]oi0`2/
f?L50:S2k0D0Yl7/4`2W`>/L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3o
ool00380oooo00<000000?ooo`3oool09@3oool<0:O0j`<0Y;o]103EdMD30=SKfP<0fn;J0P3]c;<3
0>[<^0<0i/fn0`3QclH40=>oaP80d/7:0`34]ld20<FhcP<0^KCE0P2k]=840;>dfP@0/;GM102]^>84
0:bhh`<0Zk_U0P2[]N440:Vhi0@0ZkCP102Y]>440:Zji0@0ZKWT102W[]`70:N`gPD0XZ7D0`2OY=T4
09j/h@0307STf`2ZgoT0Z]oi00<0Z]oi1@2YaNh40:O0j`@0Yl7/102W_n/<0:O0jb00oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`00<`3oool00`000000oooo0?ooo`0U0?oo
o``0Yl3[1@2U_n`30=SKfP<0fn;J0P3Kimd30=K[h`@0i/fn0`3QclH00`3Kdm00dko60=>oaP040=;1
bPD0aKS>1@2k]=820;>dfP80][?F102`]Md40:jdgP@0[;SS1@2[]N440:beg`@0ZkCP102[^N<40:Zj
i0@0Yj_I102W[]`30:N`gP@0Y:3B102RXM@409nTf@0306gNf`2UiO/0YNGk00<0YNGk1@2Yanl40:No
j`@0Yl3[202W_n/80:O0jb@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010?oo
o`00=03oool2000002H0oooo3@2W`>/40:Fok00409^ml03Kh]X0fn;J0=_RfP80fnOM0`3Fjn<20<W]
k@80i/fn0`3QclH30=_Cd0@0d/7:0P3?am830<FhcP80a[c@102k]=850;JceP@0/[;H102^]=h40:jc
g@<0ZkGQ0P2^]=d40:beg`80ZkCP0P2[]=l40:^ih`@0Z:OE102WZmT30:N^g0@0YZ7A102TX=830::Q
e080K]kT1@2Mj?/40:W:l@D0YkoZ0`2W_n/50:S0j`<0Yko[202W`>/Y0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00@3oool003H0oooo00<000000?ooo`3oool09@3oool<0:O0j`@0
YKo/0P2O_^h20=_Wg@<0e^_S1039kNd30>7?aP<0fm?@0P3Bfml20=;1bP@0clOB00<0aKS>0<Jld036
_=000P36_=020;^ddP80_[KB0`2f/mH20;Vcd`@0/[;H102a/]T40:jcg@@0[[CM102/]Ml50:^dg`80
ZkWS0P2YY=440:RWe@<0Yj_I102XY=840:JQd@<0Y:3B0P1dh>d409;Xn@D0Z<cb102X_nX40:NojP@0
Z<7/102X`>/40:O1k0@0Yl3[;03oool00`000000oooo0?ooo`070?ooo`4000000@3oool10?ooo`00
=`3oool00`000000oooo0?ooo`0U0?ooo``0Yl3[102V_n`309nnkP80O[Gg0P39kNd50:k[n0<0fm?@
103Bfml50<o7dPD0a[c@1@2n]]840;Vcd`80/[;H0`2f/MD30;6bf@D0[k3H0`2^]=d50:^]f@@0ZkCO
102YY=440:RWe@@0ZjWE102XY=830:JQd@0307[RlP28i_L0R>Kg00<0R>Kg1@2Wc?<80:RojP@0Yl7/
102X`N`50:O0j`<0Yl7/<03oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00>03o
ool00`000000oooo0?ooo`0U0?ooo``0Yl3[0`2V_n`40:>ok@@0T;_d00<0@j3f07[Kn`1jfo/00`1j
fo/40=;Kg`80^nCc0`3?am820<[Bh080a[c@0`36aMT20;jfdP<0`;kG0`2i/m<50;Jae@@0/joD102_
/=P40:jZe0@0ZjgI1@2/YM030:VTd@D0[[;K0`2[ZMD40:RTdP0307[QlP21hoL0PN?g00@0YLcd102V
cO@40:S0j`@0Z;oZ102W`^`40:O1k0@0Yko[>03oool00`000000oooo0?ooo`050?ooo`4000000@3o
ool10?ooo`00>@3oool2000002H0oooo402W`>/30:>ok@D0W;k`0`1d]?T00`02P]d007nn001o_P05
0;_Tl`@0b];P1@36aMT50<2ne`80^K?C0P2l^]P30;Jae@80^[[J102c[m@40;>`e@@0[Z[D102a[]D4
0:bUd0@0//;V102^/]/30:^Ye@80L]o]00<0O^3h0:C<m02Tc?@00`2Tc?@30:G<m0P0Z<3[1@2W`N`8
0:NnjS/0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool003/0oooo00<000000?oo
o`3oool0903oool@0:O0j`@0YKo/102R_nh4092lm080DJ_i1@1mfo`40;?Qm`<0a/GI0P2lf>h40<2n
e`D0_;[H1@2j^]X20;>_e080^/CR102c/=D20:jZe080]l7R102a[]D20:bUd080[mWf102b`^H30:jb
f`80H]SQ00<0PMgl0:C:m02Tb_@00P2Tb_@40:C<m0D0Yl3[0`2X`>/50:O1k0P0YkkZ?`3oool00`00
0000oooo0?ooo`040?ooo`4000000@3oool10?ooo`00?03oool00`000000oooo0?ooo`0T0?oooa00
Yl3[102W`>`40::okP@0W[o_1023^oP0100hY?@06jGI01^Uf@0KYMT30;?Qm`D0_=S^102le>/30;bj
f080^MO_102j^]X50;[4hP<0/k3E1@2g`N830;6^e@D0[mWf0`2b`^H308gFo`@0Y<Sc102Tb_@50:O0
j`P0Yl7/102X_nX40:NnjT<0oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool003d0
oooo00<000000?ooo`3oool0903oool@0:O0j`@0Yl3/102V_n`409jok`@0V[ka101k^o/0100`YO40
GLod05g?m01Mco@507WKnP<0_=C[1@2ienl40:_RnP@0^/CR1@2_goP30;O1hPD0T>Oj00<0=Kc=04K5
i@2Cd?d00`2Cd?d50:C6l@<0Y<Sc1@2W_n/70:O1k0P0Z;oZB03oool00`000000oooo0?ooo`020?oo
o`4000000@3oool10?ooo`00?P3oool2000002D0oooo502W`>/40:Jok0D0Y;o]0`2J__4509VolP<0
Nkck0`0h[O<301RTeP<0MM_h1@1DcNT30:_RnPD0LMga00<0;[KA03nmj`20cOl00`20cOl409g7m@@0
VL_i1@2T`nl40:NojP<0Yko[202W`N`40:Noj`@0Z;oZB`3oool00`000000oooo0?ooo`030?ooo`40
00000@3oool00400oooo00<000000?ooo`3oool08`3ooolI0:O0j`@0Yl3/202T_nd309^olP@0W/3`
102?`OP409[1l`@0R/Gk102L`o<40977nPD0XL?a0`2MaoD40:G1k@D0Z;o[0`2W_nX40:O2k0@0Yl7/
202W_n]?0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`00@@3oool00`000000oooo0?oo
o`0S0?oooaT0Yl3[202W`>`30:Bok@@0YL3]102N`?040:;0kP@0V/7c1@2R`Nl309c3l`D0Y<7^102W
`>/30:K0k0@0Z<3[102X_n/40:O1k0@0Yl;/102W_^X40:Noje<0oooo00D000000?ooo`3oool0oooo
000000010?ooo`00@P3oool00`000000oooo0?ooo`0T0?oooa/0Yl3[202W`>`40:G0k@D0Y/3/0`2R
`>h50:G0k0@0Yl3/0`2V`>`<0:O0j`@0Z<3[202W`N`80:NnjUL0oooo00@000000?ooo`3oool00000
0@3oool004<0oooo0P00000U0?ooob00Yl3[0`2W`>`90:O0j`@0Yl3/102W`>/30:O0k1D0Yl3[0`2W
`N`40:NnjUh0oooo00@000000?ooo`3oool000000@3oool004D0oooo00<000000?ooo`3oool08`3o
oom30:O0j`D0Yko[102X`>/30:RojV80oooo00<000000?ooo`0000000@3oool004H0oooo00<00000
0?ooo`3oool08`3ooolo0:O0j`@0Yko[202X`>]V0?ooo`4000000@3oool100000000A`3oool00`00
0000oooo0?ooo`0S0?ooocl0Yl3[102W`>`40:S0jfX0oooo0P00000004P0oooo0P00000U0?oooch0
Yl3[102W`>a]0?ooo`800000001:0?ooo`030000003oool0oooo02<0oooo?P2W`>]`0?ooo`800000
001;0?ooo`030000003oool0oooo0280oooo>`2W`>]_0?ooo`@000000P3oool004`0oooo00<00000
0?ooo`3oool08`3ooolc0:O0jg40oooo100000060?ooo`00C@3oool2000002@0oooo;`2W`>]`0?oo
o`@000002P3oool004l0oooo00<000000?ooo`3oool08P3oool[0:O0jfl0oooo1000000>0?ooo`00
D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo001A0?ooo`030000003o
ool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580oooo0P00000T0?oooah0Yl3[K@3oool4
000001T0oooo001D0?ooo`030000003oool0oooo0280oooo5`2W`>]_0?ooo`@000007@3oool005D0
oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00EP3oool00`000000oooo
0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?ooo`8000008`3oool;0:O0jf`0oooo1000
000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool3000002d0oooo001J0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool400000300oooo001K0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0oooo001L0?ooo`800000
8@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool005h0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00000L0?ooo`030000003oool0oooo05<0
oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04l0oooo
1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo1000
001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04L0oooo1000001C
0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0oooo1000001G0?oo
o`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03oool3000005/0oooo001Y0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4000005h0oooo001Z0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?ooo`800000403oool00`00
0000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`030000003oool0oooo0280oooo1000001i
0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo1000001m0?oo
o`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000210?ooo`00
M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo100000250?ooo`00MP3o
ool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`050000003oool0oooo0?oo
o`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003oool0103oool4000009P0
oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3oool200000:00oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.656 .752 .92 r
.50499 .66516 .51113 .671 .52232 .66785 .51621 .66198 Mtetra
.656 .751 .92 r
.51621 .66198 .52232 .66785 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .66149 .53878 .65559 Mtetra
.655 .751 .92 r
.53878 .65559 .54483 .66149 .55616 .65829 .55014 .65238 Mtetra
.656 .752 .921 r
.55014 .65238 .55616 .65829 .56753 .65509 .56155 .64914 Mtetra
.657 .752 .92 r
.56155 .64914 .56753 .65509 .57895 .65191 .573 .64587 Mtetra
.657 .75 .919 r
.573 .64587 .57895 .65191 .59042 .64869 .5845 .64259 Mtetra
.655 .748 .918 r
.5845 .64259 .59042 .64869 .60194 .64541 .59604 .63935 Mtetra
.654 .75 .92 r
.59604 .63935 .60194 .64541 .6135 .6421 .60764 .63611 Mtetra
.654 .753 .923 r
.60764 .63611 .6135 .6421 .62511 .63877 .61929 .63287 Mtetra
.654 .757 .925 r
.61929 .63287 .62511 .63877 .63677 .63546 .63098 .62958 Mtetra
.654 .759 .926 r
.63098 .62958 .63677 .63546 .64847 .63214 .64272 .62627 Mtetra
.655 .76 .927 r
.64272 .62627 .64847 .63214 .66023 .62884 .65451 .62293 Mtetra
.65451 .62293 .66023 .62884 .67204 .62551 .66635 .61958 Mtetra
.66635 .61958 .67204 .62551 .68389 .62217 .67824 .61621 Mtetra
.67824 .61621 .68389 .62217 .6958 .61881 .69018 .61284 Mtetra
.69018 .61284 .6958 .61881 .70775 .61544 .70217 .60943 Mtetra
.655 .76 .926 r
.70217 .60943 .70775 .61544 .71976 .61209 .71422 .60601 Mtetra
.657 .759 .925 r
.71422 .60601 .71976 .61209 .73182 .60872 .72631 .60252 Mtetra
.658 .756 .922 r
.72631 .60252 .73182 .60872 .74393 .60535 .73845 .59901 Mtetra
.657 .752 .92 r
.73845 .59901 .74393 .60535 .75609 .60198 .75064 .59551 Mtetra
.656 .748 .918 r
.75064 .59551 .75609 .60198 .76831 .59855 .76289 .59203 Mtetra
.655 .747 .918 r
.76289 .59203 .76831 .59855 .78057 .59506 .77519 .58859 Mtetra
.655 .749 .919 r
.77519 .58859 .78057 .59506 .79288 .59154 .78755 .58512 Mtetra
.655 .752 .921 r
.78755 .58512 .79288 .59154 .80525 .58805 .79995 .58162 Mtetra
.656 .753 .921 r
.79995 .58162 .80525 .58805 .81767 .58457 .81241 .57807 Mtetra
.656 .752 .92 r
.81241 .57807 .81767 .58457 .83015 .58107 .82493 .57452 Mtetra
.656 .751 .92 r
.82493 .57452 .83015 .58107 .84268 .57753 .83749 .57096 Mtetra
.83749 .57096 .84268 .57753 .85526 .57397 .85012 .56738 Mtetra
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .88059 .56683 .87553 .56018 Mtetra
.87553 .56018 .88059 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54926 Mtetra
.91407 .54926 .91901 .556 .93192 .55236 .92702 .54559 Mtetra
.92702 .54559 .93192 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66198 .51005 .65608 Mtetra
.51005 .65608 .51621 .66198 .52747 .65879 .52135 .65287 Mtetra
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Mtetra
.53269 .64964 .53878 .65559 .55014 .65238 .54408 .64639 Mtetra
.54408 .64639 .55014 .65238 .56155 .64914 .55551 .64314 Mtetra
.655 .751 .921 r
.55551 .64314 .56155 .64914 .573 .64587 .567 .63989 Mtetra
.655 .753 .922 r
.567 .63989 .573 .64587 .5845 .64259 .57853 .63664 Mtetra
.656 .755 .922 r
.57853 .63664 .5845 .64259 .59604 .63935 .59011 .63332 Mtetra
.657 .754 .921 r
.59011 .63332 .59604 .63935 .60764 .63611 .60173 .62997 Mtetra
.658 .75 .918 r
.60173 .62997 .60764 .63611 .61929 .63287 .61341 .62659 Mtetra
.657 .747 .916 r
.61341 .62659 .61929 .63287 .63098 .62958 .62513 .62323 Mtetra
.656 .745 .915 r
.62513 .62323 .63098 .62958 .64272 .62627 .63691 .61987 Mtetra
.656 .744 .915 r
.63691 .61987 .64272 .62627 .65451 .62293 .64873 .61652 Mtetra
.656 .745 .915 r
.64873 .61652 .65451 .62293 .66635 .61958 .66061 .61315 Mtetra
.66061 .61315 .66635 .61958 .67824 .61621 .67253 .60976 Mtetra
.657 .745 .915 r
.67253 .60976 .67824 .61621 .69018 .61284 .6845 .60634 Mtetra
.6845 .60634 .69018 .61284 .70217 .60943 .69653 .60291 Mtetra
.656 .745 .915 r
.69653 .60291 .70217 .60943 .71422 .60601 .7086 .59947 Mtetra
.655 .745 .916 r
.7086 .59947 .71422 .60601 .72631 .60252 .72074 .59605 Mtetra
.654 .747 .918 r
.72074 .59605 .72631 .60252 .73845 .59901 .73292 .59263 Mtetra
.654 .751 .921 r
.73292 .59263 .73845 .59901 .75064 .59551 .74515 .58919 Mtetra
.655 .754 .923 r
.74515 .58919 .75064 .59551 .76289 .59203 .75744 .5857 Mtetra
.656 .755 .923 r
.75744 .5857 .76289 .59203 .77519 .58859 .76978 .58216 Mtetra
.656 .753 .921 r
.76978 .58216 .77519 .58859 .78755 .58512 .78216 .5786 Mtetra
.656 .751 .92 r
.78216 .5786 .78755 .58512 .79995 .58162 .79461 .57506 Mtetra
.655 .75 .92 r
.79461 .57506 .79995 .58162 .81241 .57807 .80711 .57151 Mtetra
.656 .751 .92 r
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56794 Mtetra
.656 .752 .92 r
.81966 .56794 .82493 .57452 .83749 .57096 .83227 .56435 Mtetra
.656 .751 .92 r
.83227 .56435 .83749 .57096 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54926 .90908 .54248 Mtetra
.90908 .54248 .91407 .54926 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94825 .53132 Mtetra
.94825 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .64689 Mtetra
.51518 .64689 .52135 .65287 .53269 .64964 .52655 .64364 Mtetra
.655 .751 .921 r
.52655 .64364 .53269 .64964 .54408 .64639 .53797 .64039 Mtetra
.656 .752 .921 r
.53797 .64039 .54408 .64639 .55551 .64314 .54943 .63711 Mtetra
.54943 .63711 .55551 .64314 .567 .63989 .56095 .63381 Mtetra
.655 .751 .92 r
.56095 .63381 .567 .63989 .57853 .63664 .57251 .63051 Mtetra
.653 .75 .921 r
.57251 .63051 .57853 .63664 .59011 .63332 .58413 .62728 Mtetra
.649 .752 .925 r
.58413 .62728 .59011 .63332 .60173 .62997 .59579 .62412 Mtetra
.647 .759 .931 r
.59579 .62412 .60173 .62997 .61341 .62659 .6075 .62098 Mtetra
.646 .768 .937 r
.6075 .62098 .61341 .62659 .62513 .62323 .61927 .61783 Mtetra
.645 .776 .943 r
.61927 .61783 .62513 .62323 .63691 .61987 .63109 .61462 Mtetra
.646 .783 .947 r
.63109 .61462 .63691 .61987 .64873 .61652 .64295 .61135 Mtetra
.647 .787 .949 r
.64295 .61135 .64873 .61652 .66061 .61315 .65486 .60801 Mtetra
.649 .79 .949 r
.65486 .60801 .66061 .61315 .67253 .60976 .66683 .60459 Mtetra
.652 .79 .948 r
.66683 .60459 .67253 .60976 .6845 .60634 .67884 .6011 Mtetra
.655 .789 .946 r
.67884 .6011 .6845 .60634 .69653 .60291 .6909 .59752 Mtetra
.658 .786 .943 r
.6909 .59752 .69653 .60291 .7086 .59947 .703 .59388 Mtetra
.66 .78 .938 r
.703 .59388 .7086 .59947 .72074 .59605 .71516 .59017 Mtetra
.661 .772 .931 r
.71516 .59017 .72074 .59605 .73292 .59263 .72736 .58646 Mtetra
.66 .762 .925 r
.72736 .58646 .73292 .59263 .74515 .58919 .73962 .58278 Mtetra
.658 .754 .921 r
.73962 .58278 .74515 .58919 .75744 .5857 .75194 .57917 Mtetra
.656 .751 .919 r
.75194 .57917 .75744 .5857 .76978 .58216 .76431 .57563 Mtetra
.655 .751 .92 r
.76431 .57563 .76978 .58216 .78216 .5786 .77674 .57208 Mtetra
.656 .752 .921 r
.77674 .57208 .78216 .5786 .79461 .57506 .78923 .56851 Mtetra
.78923 .56851 .79461 .57506 .80711 .57151 .80176 .56491 Mtetra
.656 .752 .92 r
.80176 .56491 .80711 .57151 .81966 .56794 .81435 .5613 Mtetra
.656 .751 .92 r
.81435 .5613 .81966 .56794 .83227 .56435 .827 .55767 Mtetra
.827 .55767 .83227 .56435 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Mtetra
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54248 .90406 .53563 Mtetra
.90406 .53563 .90908 .54248 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94825 .53132 .94336 .52438 Mtetra
.94336 .52438 .94825 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Mtetra
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Mtetra
.4976 .64414 .50385 .65014 .51518 .64689 .50896 .64088 Mtetra
.655 .751 .921 r
.50896 .64088 .51518 .64689 .52655 .64364 .52036 .63762 Mtetra
.654 .752 .921 r
.52036 .63762 .52655 .64364 .53797 .64039 .53181 .63437 Mtetra
.651 .752 .923 r
.53181 .63437 .53797 .64039 .54943 .63711 .54331 .63118 Mtetra
.646 .754 .928 r
.54331 .63118 .54943 .63711 .56095 .63381 .55486 .62812 Mtetra
.638 .761 .937 r
.55486 .62812 .56095 .63381 .57251 .63051 .56646 .62522 Mtetra
.629 .773 .949 r
.56646 .62522 .57251 .63051 .58413 .62728 .57812 .62243 Mtetra
.619 .787 .962 r
.57812 .62243 .58413 .62728 .59579 .62412 .58983 .61972 Mtetra
.608 .803 .974 r
.58983 .61972 .59579 .62412 .6075 .62098 .60159 .61706 Mtetra
.596 .819 .985 r
.60159 .61706 .6075 .62098 .61927 .61783 .61341 .6144 Mtetra
.585 .836 .992 r
.61341 .6144 .61927 .61783 .63109 .61462 .62528 .61165 Mtetra
.578 .853 .996 r
.62528 .61165 .63109 .61462 .64295 .61135 .63721 .60872 Mtetra
.578 .867 .995 r
.63721 .60872 .64295 .61135 .65486 .60801 .64917 .60555 Mtetra
.587 .877 .993 r
.64917 .60555 .65486 .60801 .66683 .60459 .66119 .60211 Mtetra
.603 .883 .991 r
.66119 .60211 .66683 .60459 .67884 .6011 .67324 .59839 Mtetra
.624 .882 .989 r
.67324 .59839 .67884 .6011 .6909 .59752 .68533 .59444 Mtetra
.644 .874 .984 r
.68533 .59444 .6909 .59752 .703 .59388 .69746 .5903 Mtetra
.658 .859 .976 r
.69746 .5903 .703 .59388 .71516 .59017 .70963 .58607 Mtetra
.666 .841 .967 r
.70963 .58607 .71516 .59017 .72736 .58646 .72185 .58183 Mtetra
.669 .823 .957 r
.72185 .58183 .72736 .58646 .73962 .58278 .73413 .57762 Mtetra
.67 .804 .947 r
.73413 .57762 .73962 .58278 .75194 .57917 .74645 .5735 Mtetra
.667 .785 .937 r
.74645 .5735 .75194 .57917 .76431 .57563 .75884 .56949 Mtetra
.663 .769 .928 r
.75884 .56949 .76431 .57563 .77674 .57208 .77129 .56564 Mtetra
.659 .758 .923 r
.77129 .56564 .77674 .57208 .78923 .56851 .7838 .56192 Mtetra
.657 .753 .921 r
.7838 .56192 .78923 .56851 .80176 .56491 .79637 .55826 Mtetra
.656 .752 .92 r
.79637 .55826 .80176 .56491 .81435 .5613 .809 .55461 Mtetra
.809 .55461 .81435 .5613 .827 .55767 .82169 .55095 Mtetra
.656 .751 .92 r
.82169 .55095 .827 .55767 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Mtetra
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Mtetra
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Mtetra
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64139 Mtetra
.655 .751 .921 r
.47997 .64139 .48629 .64739 .4976 .64414 .4913 .63813 Mtetra
.654 .751 .922 r
.4913 .63813 .4976 .64414 .50896 .64088 .50269 .6349 Mtetra
.649 .752 .925 r
.50269 .6349 .50896 .64088 .52036 .63762 .51412 .63177 Mtetra
.639 .755 .932 r
.51412 .63177 .52036 .63762 .53181 .63437 .52561 .62889 Mtetra
.621 .763 .947 r
.52561 .62889 .53181 .63437 .54331 .63118 .53714 .62635 Mtetra
.592 .779 .969 r
.53714 .62635 .54331 .63118 .55486 .62812 .54873 .6242 Mtetra
.546 .8 .992 r
.54873 .6242 .55486 .62812 .56646 .62522 .56038 .62241 Mtetra
.475 .816 .999 r
.56038 .62241 .56646 .62522 .57812 .62243 .5721 .62084 Mtetra
.38 .812 .962 r
.5721 .62084 .57812 .62243 .58983 .61972 .58388 .61925 Mtetra
.29 .783 .883 r
.58388 .61925 .58983 .61972 .60159 .61706 .59571 .61737 Mtetra
.244 .759 .812 r
.59571 .61737 .60159 .61706 .61341 .6144 .60759 .61505 Mtetra
.248 .761 .788 r
.60759 .61505 .61341 .6144 .62528 .61165 .61952 .6123 Mtetra
.283 .785 .801 r
.61952 .6123 .62528 .61165 .63721 .60872 .6315 .60921 Mtetra
.324 .81 .828 r
.6315 .60921 .63721 .60872 .64917 .60555 .64352 .6059 Mtetra
.353 .828 .846 r
.64352 .6059 .64917 .60555 .66119 .60211 .65559 .60244 Mtetra
.367 .837 .851 r
.65559 .60244 .66119 .60211 .67324 .59839 .66771 .59883 Mtetra
.374 .841 .844 r
.66771 .59883 .67324 .59839 .68533 .59444 .67987 .59499 Mtetra
.391 .85 .839 r
.67987 .59499 .68533 .59444 .69746 .5903 .69206 .59082 Mtetra
.434 .875 .851 r
.69206 .59082 .69746 .5903 .70963 .58607 .70428 .58619 Mtetra
.512 .912 .893 r
.70428 .58619 .70963 .58607 .72185 .58183 .71652 .58112 Mtetra
.599 .939 .944 r
.71652 .58112 .72185 .58183 .73413 .57762 .72878 .57575 Mtetra
.661 .929 .972 r
.72878 .57575 .73413 .57762 .74645 .5735 .74109 .57034 Mtetra
.686 .889 .972 r
.74109 .57034 .74645 .5735 .75884 .56949 .75345 .56516 Mtetra
.687 .844 .959 r
.75345 .56516 .75884 .56949 .77129 .56564 .76587 .56032 Mtetra
.678 .805 .943 r
.76587 .56032 .77129 .56564 .7838 .56192 .77838 .55588 Mtetra
.668 .778 .931 r
.77838 .55588 .7838 .56192 .79637 .55826 .79096 .55179 Mtetra
.661 .761 .924 r
.79096 .55179 .79637 .55826 .809 .55461 .80362 .54794 Mtetra
.658 .755 .921 r
.80362 .54794 .809 .55461 .82169 .55095 .81634 .5442 Mtetra
.656 .752 .921 r
.81634 .5442 .82169 .55095 .83443 .54729 .82912 .54049 Mtetra
.656 .752 .92 r
.82912 .54049 .83443 .54729 .84723 .54361 .84196 .53677 Mtetra
.656 .751 .92 r
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64189 Mtetra
.655 .751 .92 r
.45099 .64189 .45743 .64789 .46867 .64464 .46227 .63862 Mtetra
.654 .751 .921 r
.46227 .63862 .46867 .64464 .47997 .64139 .47359 .63538 Mtetra
.65 .751 .924 r
.47359 .63538 .47997 .64139 .4913 .63813 .48496 .63224 Mtetra
.638 .753 .932 r
.48496 .63224 .4913 .63813 .50269 .6349 .49637 .62939 Mtetra
.611 .759 .95 r
.49637 .62939 .50269 .6349 .51412 .63177 .50783 .62708 Mtetra
.558 .773 .978 r
.50783 .62708 .51412 .63177 .52561 .62889 .51935 .62548 Mtetra
.461 .787 .999 r
.51935 .62548 .52561 .62889 .53714 .62635 .53092 .62451 Mtetra
.316 .77 .954 r
.53092 .62451 .53714 .62635 .54873 .6242 .54257 .62375 Mtetra
.212 .733 .851 r
.54257 .62375 .54873 .6242 .56038 .62241 .55427 .62252 Mtetra
.264 .772 .837 r
.55427 .62252 .56038 .62241 .5721 .62084 .56603 .62029 Mtetra
.455 .874 .936 r
.56603 .62029 .5721 .62084 .58388 .61925 .57783 .61698 Mtetra
.624 .893 .987 r
.57783 .61698 .58388 .61925 .59571 .61737 .58967 .6129 Mtetra
.681 .824 .952 r
.58967 .6129 .59571 .61737 .60759 .61505 .60155 .60852 Mtetra
.684 .755 .905 r
.60155 .60852 .60759 .61505 .61952 .6123 .61347 .60417 Mtetra
.674 .708 .873 r
.61347 .60417 .61952 .6123 .6315 .60921 .62544 .60006 Mtetra
.663 .68 .856 r
.62544 .60006 .6315 .60921 .64352 .6059 .63748 .59625 Mtetra
.653 .666 .85 r
.63748 .59625 .64352 .6059 .65559 .60244 .64957 .59276 Mtetra
.645 .663 .853 r
.64957 .59276 .65559 .60244 .66771 .59883 .66173 .5896 Mtetra
.637 .67 .865 r
.66173 .5896 .66771 .59883 .67987 .59499 .67396 .58675 Mtetra
.63 .692 .889 r
.67396 .58675 .67987 .59499 .69206 .59082 .68626 .58412 Mtetra
.621 .735 .928 r
.68626 .58412 .69206 .59082 .70428 .58619 .69862 .58155 Mtetra
.61 .806 .975 r
.69862 .58155 .70428 .58619 .71652 .58112 .71103 .57866 Mtetra
.584 .883 .992 r
.71103 .57866 .71652 .58112 .72878 .57575 .72345 .57498 Mtetra
.556 .921 .945 r
.72345 .57498 .72878 .57575 .74109 .57034 .73585 .57019 Mtetra
.58 .94 .911 r
.73585 .57019 .74109 .57034 .75345 .56516 .74824 .56437 Mtetra
.652 .956 .939 r
.74824 .56437 .75345 .56516 .76587 .56032 .76063 .55807 Mtetra
.7 .93 .966 r
.76063 .55807 .76587 .56032 .77838 .55588 .77307 .55196 Mtetra
.703 .869 .96 r
.77307 .55196 .77838 .55588 .79096 .55179 .7856 .5465 Mtetra
.686 .813 .943 r
.7856 .5465 .79096 .55179 .80362 .54794 .79823 .54176 Mtetra
.67 .777 .93 r
.79823 .54176 .80362 .54794 .81634 .5442 .81096 .53758 Mtetra
.661 .76 .924 r
.81096 .53758 .81634 .5442 .82912 .54049 .82377 .53368 Mtetra
.657 .754 .921 r
.82377 .53368 .82912 .54049 .84196 .53677 .83664 .52989 Mtetra
.656 .752 .92 r
.83664 .52989 .84196 .53677 .85485 .53305 .84958 .52613 Mtetra
.656 .751 .92 r
.84958 .52613 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63912 Mtetra
.655 .751 .921 r
.43325 .63912 .43976 .64515 .45099 .64189 .44451 .63585 Mtetra
.653 .751 .922 r
.44451 .63585 .45099 .64189 .46227 .63862 .45581 .63263 Mtetra
.644 .751 .927 r
.45581 .63263 .46227 .63862 .47359 .63538 .46716 .62964 Mtetra
.619 .753 .942 r
.46716 .62964 .47359 .63538 .48496 .63224 .47855 .6272 Mtetra
.562 .76 .971 r
.47855 .6272 .48496 .63224 .49637 .62939 .48998 .62568 Mtetra
.441 .766 .997 r
.48998 .62568 .49637 .62939 .50783 .62708 .50147 .62514 Mtetra
.259 .733 .939 r
.50147 .62514 .50783 .62708 .51935 .62548 .51302 .62495 Mtetra
.197 .722 .85 r
.51302 .62495 .51935 .62548 .53092 .62451 .52464 .62394 Mtetra
.405 .848 .928 r
.52464 .62394 .53092 .62451 .54257 .62375 .53633 .6212 Mtetra
.657 .889 .981 r
.53633 .6212 .54257 .62375 .55427 .62252 .54805 .61677 Mtetra
.712 .784 .908 r
.54805 .61677 .55427 .62252 .56603 .62029 .55981 .61151 Mtetra
.697 .699 .848 r
.55981 .61151 .56603 .62029 .57783 .61698 .57161 .60632 Mtetra
.677 .655 .821 r
.57161 .60632 .57783 .61698 .58967 .6129 .58346 .60161 Mtetra
.664 .639 .815 r
.58346 .60161 .58967 .6129 .60155 .60852 .59536 .59742 Mtetra
.657 .64 .821 r
.59536 .59742 .60155 .60852 .61347 .60417 .60732 .59358 Mtetra
.655 .648 .832 r
.60732 .59358 .61347 .60417 .62544 .60006 .61932 .58993 Mtetra
.654 .657 .841 r
.61932 .58993 .62544 .60006 .63748 .59625 .63139 .58637 Mtetra
.653 .662 .847 r
.63139 .58637 .63748 .59625 .64957 .59276 .6435 .58285 Mtetra
.651 .662 .847 r
.6435 .58285 .64957 .59276 .66173 .5896 .65568 .57938 Mtetra
.648 .655 .843 r
.65568 .57938 .66173 .5896 .67396 .58675 .66791 .576 Mtetra
.642 .643 .836 r
.66791 .576 .67396 .58675 .68626 .58412 .6802 .57281 Mtetra
.633 .629 .829 r
.6802 .57281 .68626 .58412 .69862 .58155 .69257 .56998 Mtetra
.621 .62 .828 r
.69257 .56998 .69862 .58155 .71103 .57866 .70502 .56765 Mtetra
.608 .624 .842 r
.70502 .56765 .71103 .57866 .72345 .57498 .71757 .56584 Mtetra
.603 .662 .88 r
.71757 .56584 .72345 .57498 .73585 .57019 .73019 .56408 Mtetra
.613 .756 .947 r
.73019 .56408 .73585 .57019 .74824 .56437 .74283 .56147 Mtetra
.631 .887 .987 r
.74283 .56147 .74824 .56437 .76063 .55807 .75542 .55714 Mtetra
.643 .952 .944 r
.75542 .55714 .76063 .55807 .77307 .55196 .76792 .55102 Mtetra
.688 .965 .936 r
.76792 .55102 .77307 .55196 .7856 .5465 .78041 .54405 Mtetra
.722 .931 .959 r
.78041 .54405 .7856 .5465 .79823 .54176 .79295 .53743 Mtetra
.708 .858 .954 r
.79295 .53743 .79823 .54176 .81096 .53758 .80561 .53181 Mtetra
.682 .799 .937 r
.80561 .53181 .81096 .53758 .82377 .53368 .8184 .52715 Mtetra
.665 .767 .926 r
.8184 .52715 .82377 .53368 .83664 .52989 .83129 .52304 Mtetra
.658 .756 .922 r
.83129 .52304 .83664 .52989 .84958 .52613 .84426 .51916 Mtetra
.656 .752 .921 r
.84426 .51916 .84958 .52613 .86257 .52235 .85729 .51534 Mtetra
.656 .751 .92 r
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63634 Mtetra
.655 .751 .921 r
.41544 .63634 .42204 .64239 .43325 .63912 .42668 .63306 Mtetra
.651 .751 .923 r
.42668 .63306 .43325 .63912 .44451 .63585 .43797 .62988 Mtetra
.637 .751 .93 r
.43797 .62988 .44451 .63585 .45581 .63263 .44929 .62703 Mtetra
.597 .752 .951 r
.44929 .62703 .45581 .63263 .46716 .62964 .46065 .62501 Mtetra
.498 .754 .986 r
.46065 .62501 .46716 .62964 .47855 .6272 .47205 .62427 Mtetra
.302 .727 .972 r
.47205 .62427 .47855 .6272 .48998 .62568 .4835 .62453 Mtetra
.162 .689 .867 r
.4835 .62453 .48998 .62568 .50147 .62514 .49503 .62438 Mtetra
.369 .825 .928 r
.49503 .62438 .50147 .62514 .51302 .62495 .50663 .62217 Mtetra
.671 .883 .977 r
.50663 .62217 .51302 .62495 .52464 .62394 .5183 .6176 Mtetra
.722 .767 .888 r
.5183 .6176 .52464 .62394 .53633 .6212 .53001 .61189 Mtetra
.699 .688 .836 r
.53001 .61189 .53633 .6212 .54805 .61677 .54176 .60646 Mtetra
.677 .661 .827 r
.54176 .60646 .54805 .61677 .55981 .61151 .55355 .60183 Mtetra
.667 .67 .843 r
.55355 .60183 .55981 .61151 .57161 .60632 .56539 .59778 Mtetra
.665 .695 .868 r
.56539 .59778 .57161 .60632 .58346 .60161 .57728 .59395 Mtetra
.665 .718 .888 r
.57728 .59395 .58346 .60161 .59536 .59742 .58922 .59018 Mtetra
.664 .73 .899 r
.58922 .59018 .59536 .59742 .60732 .59358 .6012 .58642 Mtetra
.662 .733 .902 r
.6012 .58642 .60732 .59358 .61932 .58993 .61325 .58271 Mtetra
.659 .731 .903 r
.61325 .58271 .61932 .58993 .63139 .58637 .62534 .57908 Mtetra
.656 .729 .903 r
.62534 .57908 .63139 .58637 .6435 .58285 .63749 .57554 Mtetra
.653 .728 .904 r
.63749 .57554 .6435 .58285 .65568 .57938 .6497 .57208 Mtetra
.65 .728 .906 r
.6497 .57208 .65568 .57938 .66791 .576 .66196 .56871 Mtetra
.648 .728 .908 r
.66196 .56871 .66791 .576 .6802 .57281 .67428 .56538 Mtetra
.647 .725 .905 r
.67428 .56538 .6802 .57281 .69257 .56998 .68666 .56208 Mtetra
.646 .712 .896 r
.68666 .56208 .69257 .56998 .70502 .56765 .6991 .55882 Mtetra
.639 .686 .878 r
.6991 .55882 .70502 .56765 .71757 .56584 .71161 .55578 Mtetra
.623 .652 .858 r
.71161 .55578 .71757 .56584 .73019 .56408 .72422 .55333 Mtetra
.602 .629 .85 r
.72422 .55333 .73019 .56408 .74283 .56147 .73694 .55169 Mtetra
.591 .644 .872 r
.73694 .55169 .74283 .56147 .75542 .55714 .74975 .55033 Mtetra
.614 .736 .933 r
.74975 .55033 .75542 .55714 .76792 .55102 .76256 .5478 Mtetra
.666 .889 .979 r
.76256 .5478 .76792 .55102 .78041 .54405 .77525 .54283 Mtetra
.701 .963 .941 r
.77525 .54283 .78041 .54405 .79295 .53743 .78783 .53575 Mtetra
.734 .96 .942 r
.78783 .53575 .79295 .53743 .80561 .53181 .8004 .52824 Mtetra
.73 .895 .954 r
.8004 .52824 .80561 .53181 .8184 .52715 .81309 .52175 Mtetra
.696 .819 .941 r
.81309 .52175 .8184 .52715 .83129 .52304 .82593 .51658 Mtetra
.67 .774 .928 r
.82593 .51658 .83129 .52304 .84426 .51916 .83891 .51226 Mtetra
.66 .757 .922 r
.83891 .51226 .84426 .51916 .85729 .51534 .85198 .5083 Mtetra
.656 .752 .921 r
.85198 .5083 .85729 .51534 .87039 .51152 .86511 .50442 Mtetra
.656 .752 .92 r
.86511 .50442 .87039 .51152 .88354 .50768 .87831 .50054 Mtetra
.656 .751 .92 r
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Mtetra
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63355 Mtetra
.655 .751 .921 r
.39757 .63355 .40425 .63962 .41544 .63634 .4088 .63026 Mtetra
.651 .751 .923 r
.4088 .63026 .41544 .63634 .42668 .63306 .42006 .62708 Mtetra
.634 .75 .932 r
.42006 .62708 .42668 .63306 .43797 .62988 .43136 .62431 Mtetra
.581 .749 .957 r
.43136 .62431 .43797 .62988 .44929 .62703 .44269 .62259 Mtetra
.442 .739 .99 r
.44269 .62259 .44929 .62703 .46065 .62501 .45405 .62245 Mtetra
.199 .679 .932 r
.45405 .62245 .46065 .62501 .47205 .62427 .46546 .62324 Mtetra
.174 .7 .866 r
.46546 .62324 .47205 .62427 .4835 .62453 .47696 .62288 Mtetra
.547 .885 .986 r
.47696 .62288 .4835 .62453 .49503 .62438 .48856 .6196 Mtetra
.726 .817 .922 r
.48856 .6196 .49503 .62438 .50663 .62217 .50022 .61397 Mtetra
.717 .717 .849 r
.50022 .61397 .50663 .62217 .5183 .6176 .51193 .60799 Mtetra
.692 .68 .834 r
.51193 .60799 .5183 .6176 .53001 .61189 .52366 .60279 Mtetra
.681 .687 .849 r
.52366 .60279 .53001 .61189 .54176 .60646 .53544 .59825 Mtetra
.678 .707 .87 r
.53544 .59825 .54176 .60646 .55355 .60183 .54726 .59396 Mtetra
.675 .716 .879 r
.54726 .59396 .55355 .60183 .56539 .59778 .55913 .58981 Mtetra
.67 .712 .88 r
.55913 .58981 .56539 .59778 .57728 .59395 .57104 .58583 Mtetra
.664 .707 .879 r
.57104 .58583 .57728 .59395 .58922 .59018 .58301 .58203 Mtetra
.66 .706 .881 r
.58301 .58203 .58922 .59018 .6012 .58642 .59503 .57836 Mtetra
.658 .708 .885 r
.59503 .57836 .6012 .58642 .61325 .58271 .6071 .57476 Mtetra
.657 .711 .888 r
.6071 .57476 .61325 .58271 .62534 .57908 .61923 .57119 Mtetra
.656 .714 .89 r
.61923 .57119 .62534 .57908 .63749 .57554 .63141 .56762 Mtetra
.656 .713 .891 r
.63141 .56762 .63749 .57554 .6497 .57208 .64365 .56405 Mtetra
.655 .711 .889 r
.64365 .56405 .6497 .57208 .66196 .56871 .65594 .56051 Mtetra
.652 .706 .887 r
.65594 .56051 .66196 .56871 .67428 .56538 .66828 .55704 Mtetra
.648 .702 .886 r
.66828 .55704 .67428 .56538 .68666 .56208 .68069 .55369 Mtetra
.642 .699 .887 r
.68069 .55369 .68666 .56208 .6991 .55882 .69317 .55053 Mtetra
.636 .7 .892 r
.69317 .55053 .6991 .55882 .71161 .55578 .70572 .54754 Mtetra
.632 .7 .895 r
.70572 .54754 .71161 .55578 .72422 .55333 .71833 .54469 Mtetra
.624 .687 .889 r
.71833 .54469 .72422 .55333 .73694 .55169 .73103 .5421 Mtetra
.606 .657 .874 r
.73103 .5421 .73694 .55169 .74975 .55033 .74383 .54017 Mtetra
.584 .635 .868 r
.74383 .54017 .74975 .55033 .76256 .5478 .75676 .53903 Mtetra
.589 .671 .896 r
.75676 .53903 .76256 .5478 .77525 .54283 .76974 .53752 Mtetra
.651 .807 .958 r
.76974 .53752 .77525 .54283 .78783 .53575 .78261 .53359 Mtetra
.722 .943 .955 r
.78261 .53359 .78783 .53575 .8004 .52824 .7953 .52664 Mtetra
.753 .967 .932 r
.7953 .52664 .8004 .52824 .81309 .52175 .80791 .5185 Mtetra
.748 .914 .948 r
.80791 .5185 .81309 .52175 .82593 .51658 .82064 .51132 Mtetra
.705 .83 .942 r
.82064 .51132 .82593 .51658 .83891 .51226 .83356 .50577 Mtetra
.673 .777 .928 r
.83356 .50577 .83891 .51226 .85198 .5083 .84662 .50131 Mtetra
.66 .758 .922 r
.84662 .50131 .85198 .5083 .86511 .50442 .85979 .49728 Mtetra
.656 .752 .921 r
.85979 .49728 .86511 .50442 .87831 .50054 .87303 .49335 Mtetra
.656 .751 .92 r
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Mtetra
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Mtetra
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Mtetra
.655 .751 .921 r
.37964 .63075 .3864 .63684 .39757 .63355 .39085 .62744 Mtetra
.651 .751 .922 r
.39085 .62744 .39757 .63355 .4088 .63026 .40209 .62423 Mtetra
.635 .749 .931 r
.40209 .62423 .4088 .63026 .42006 .62708 .41338 .62142 Mtetra
.578 .746 .956 r
.41338 .62142 .42006 .62708 .43136 .62431 .42468 .61977 Mtetra
.416 .724 .989 r
.42468 .61977 .43136 .62431 .44269 .62259 .43599 .61997 Mtetra
.139 .639 .908 r
.43599 .61997 .44269 .62259 .45405 .62245 .44735 .62126 Mtetra
.177 .699 .875 r
.44735 .62126 .45405 .62245 .46546 .62324 .45881 .62101 Mtetra
.61 .887 .99 r
.45881 .62101 .46546 .62324 .47696 .62288 .47041 .61725 Mtetra
.738 .791 .895 r
.47041 .61725 .47696 .62288 .48856 .6196 .48208 .61105 Mtetra
.721 .711 .84 r
.48208 .61105 .48856 .6196 .50022 .61397 .49378 .60475 Mtetra
.699 .691 .838 r
.49378 .60475 .50022 .61397 .51193 .60799 .50551 .59931 Mtetra
.688 .699 .855 r
.50551 .59931 .51193 .60799 .52366 .60279 .51727 .59452 Mtetra
.678 .706 .869 r
.51727 .59452 .52366 .60279 .53544 .59825 .52907 .5902 Mtetra
.668 .71 .879 r
.52907 .5902 .53544 .59825 .54726 .59396 .54092 .58628 Mtetra
.661 .718 .89 r
.54092 .58628 .54726 .59396 .55913 .58981 .55283 .5826 Mtetra
.659 .731 .902 r
.55283 .5826 .55913 .58981 .57104 .58583 .56478 .57897 Mtetra
.659 .742 .911 r
.56478 .57897 .57104 .58583 .58301 .58203 .57678 .57532 Mtetra
.659 .748 .915 r
.57678 .57532 .58301 .58203 .59503 .57836 .58884 .57165 Mtetra
.659 .748 .916 r
.58884 .57165 .59503 .57836 .6071 .57476 .60095 .56798 Mtetra
.657 .746 .916 r
.60095 .56798 .6071 .57476 .61923 .57119 .61311 .56433 Mtetra
.655 .745 .915 r
.61311 .56433 .61923 .57119 .63141 .56762 .62532 .56074 Mtetra
.654 .744 .916 r
.62532 .56074 .63141 .56762 .64365 .56405 .63759 .55718 Mtetra
.652 .745 .918 r
.63759 .55718 .64365 .56405 .65594 .56051 .64992 .55366 Mtetra
.651 .746 .919 r
.64992 .55366 .65594 .56051 .66828 .55704 .66231 .55014 Mtetra
.652 .746 .918 r
.66231 .55014 .66828 .55704 .68069 .55369 .67474 .54659 Mtetra
.652 .741 .914 r
.67474 .54659 .68069 .55369 .69317 .55053 .68724 .54302 Mtetra
.651 .729 .906 r
.68724 .54302 .69317 .55053 .70572 .54754 .69979 .5395 Mtetra
.643 .712 .897 r
.69979 .5395 .70572 .54754 .71833 .54469 .71242 .53622 Mtetra
.632 .696 .892 r
.71242 .53622 .71833 .54469 .73103 .5421 .72513 .53334 Mtetra
.617 .684 .89 r
.72513 .53334 .73103 .5421 .74383 .54017 .73793 .53094 Mtetra
.598 .664 .885 r
.73793 .53094 .74383 .54017 .75676 .53903 .75085 .5292 Mtetra
.573 .639 .878 r
.75085 .5292 .75676 .53903 .76974 .53752 .7639 .52832 Mtetra
.573 .655 .892 r
.7639 .52832 .76974 .53752 .78261 .53359 .77703 .52734 Mtetra
.641 .772 .943 r
.77703 .52734 .78261 .53359 .7953 .52664 .79004 .52383 Mtetra
.74 .927 .952 r
.79004 .52383 .7953 .52664 .80791 .5185 .80281 .51669 Mtetra
.776 .965 .924 r
.80281 .51669 .80791 .5185 .82064 .51132 .81547 .50795 Mtetra
.76 .914 .942 r
.81547 .50795 .82064 .51132 .83356 .50577 .82826 .50035 Mtetra
.708 .828 .939 r
.82826 .50035 .83356 .50577 .84662 .50131 .84127 .49466 Mtetra
.672 .775 .927 r
.84127 .49466 .84662 .50131 .85979 .49728 .85443 .49017 Mtetra
.659 .756 .922 r
.85443 .49017 .85979 .49728 .87303 .49335 .86771 .48611 Mtetra
.656 .752 .92 r
.86771 .48611 .87303 .49335 .88633 .48943 .88105 .48214 Mtetra
.656 .751 .92 r
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Mtetra
.655 .751 .92 r
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .62461 Mtetra
.653 .751 .922 r
.37283 .62461 .37964 .63075 .39085 .62744 .38407 .62134 Mtetra
.64 .749 .928 r
.38407 .62134 .39085 .62744 .40209 .62423 .39533 .6184 Mtetra
.589 .744 .95 r
.39533 .6184 .40209 .62423 .41338 .62142 .40661 .61655 Mtetra
.431 .719 .985 r
.40661 .61655 .41338 .62142 .42468 .61977 .41788 .61674 Mtetra
.113 .61 .905 r
.41788 .61674 .42468 .61977 .43599 .61997 .42918 .61855 Mtetra
.107 .646 .851 r
.42918 .61855 .43599 .61997 .44735 .62126 .4406 .61902 Mtetra
.596 .882 .992 r
.4406 .61902 .44735 .62126 .45881 .62101 .45217 .61546 Mtetra
.748 .795 .891 r
.45217 .61546 .45881 .62101 .47041 .61725 .46385 .60883 Mtetra
.733 .718 .837 r
.46385 .60883 .47041 .61725 .48208 .61105 .47556 .60193 Mtetra
.708 .696 .836 r
.47556 .60193 .48208 .61105 .49378 .60475 .48729 .59605 Mtetra
.69 .7 .855 r
.48729 .59605 .49378 .60475 .50551 .59931 .49904 .59118 Mtetra
.675 .71 .874 r
.49904 .59118 .50551 .59931 .51727 .59452 .51083 .58698 Mtetra
.669 .724 .891 r
.51083 .58698 .51727 .59452 .52907 .5902 .52266 .58305 Mtetra
.668 .735 .9 r
.52266 .58305 .52907 .5902 .54092 .58628 .53455 .57914 Mtetra
.668 .736 .901 r
.53455 .57914 .54092 .58628 .55283 .5826 .54648 .57522 Mtetra
.665 .73 .898 r
.54648 .57522 .55283 .5826 .56478 .57897 .55846 .57137 Mtetra
.662 .723 .895 r
.55846 .57137 .56478 .57897 .57678 .57532 .5705 .56763 Mtetra
.659 .72 .894 r
.5705 .56763 .57678 .57532 .58884 .57165 .58258 .56396 Mtetra
.657 .721 .896 r
.58258 .56396 .58884 .57165 .60095 .56798 .59472 .56034 Mtetra
.656 .723 .898 r
.59472 .56034 .60095 .56798 .61311 .56433 .60692 .55672 Mtetra
.656 .724 .899 r
.60692 .55672 .61311 .56433 .62532 .56074 .61917 .5531 Mtetra
.61917 .5531 .62532 .56074 .63759 .55718 .63147 .54946 Mtetra
.655 .723 .898 r
.63147 .54946 .63759 .55718 .64992 .55366 .64383 .54583 Mtetra
.653 .72 .897 r
.64383 .54583 .64992 .55366 .66231 .55014 .65624 .54224 Mtetra
.651 .718 .897 r
.65624 .54224 .66231 .55014 .67474 .54659 .66872 .53873 Mtetra
.647 .718 .9 r
.66872 .53873 .67474 .54659 .68724 .54302 .68125 .53532 Mtetra
.644 .723 .906 r
.68125 .53532 .68724 .54302 .69979 .5395 .69385 .53199 Mtetra
.644 .729 .911 r
.69385 .53199 .69979 .5395 .71242 .53622 .70651 .52864 Mtetra
.643 .727 .91 r
.70651 .52864 .71242 .53622 .72513 .53334 .71923 .52531 Mtetra
.634 .712 .903 r
.71923 .52531 .72513 .53334 .73793 .53094 .73203 .52226 Mtetra
.614 .687 .895 r
.73203 .52226 .73793 .53094 .75085 .5292 .74494 .51989 Mtetra
.584 .658 .888 r
.74494 .51989 .75085 .5292 .7639 .52832 .75799 .51853 Mtetra
.553 .632 .884 r
.75799 .51853 .7639 .52832 .77703 .52734 .77119 .51822 Mtetra
.557 .652 .898 r
.77119 .51822 .77703 .52734 .79004 .52383 .78446 .51761 Mtetra
.649 .779 .943 r
.78446 .51761 .79004 .52383 .80281 .51669 .79756 .51381 Mtetra
.766 .932 .94 r
.79756 .51381 .80281 .51669 .81547 .50795 .81036 .50584 Mtetra
.797 .961 .916 r
.81036 .50584 .81547 .50795 .82826 .50035 .82306 .49649 Mtetra
.763 .9 .937 r
.82306 .49649 .82826 .50035 .84127 .49466 .83594 .48882 Mtetra
.703 .815 .935 r
.83594 .48882 .84127 .49466 .85443 .49017 .84906 .48328 Mtetra
.669 .769 .925 r
.84906 .48328 .85443 .49017 .86771 .48611 .86234 .47887 Mtetra
.658 .755 .921 r
.86234 .47887 .86771 .48611 .88105 .48214 .87572 .4748 Mtetra
.656 .752 .92 r
.87572 .4748 .88105 .48214 .89445 .47817 .88917 .47078 Mtetra
.656 .751 .92 r
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46271 Mtetra
.91626 .46271 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62178 Mtetra
.654 .751 .921 r
.35476 .62178 .36165 .62794 .37283 .62461 .36597 .61845 Mtetra
.646 .75 .925 r
.36597 .61845 .37283 .62461 .38407 .62134 .37722 .61533 Mtetra
.61 .745 .941 r
.37722 .61533 .38407 .62134 .39533 .6184 .38849 .61306 Mtetra
.481 .723 .977 r
.38849 .61306 .39533 .6184 .40661 .61655 .39974 .61281 Mtetra
.146 .608 .927 r
.39974 .61281 .40661 .61655 .41788 .61674 .41098 .6149 Mtetra
0 .543 .795 r
.41098 .6149 .41788 .61674 .42918 .61855 .42232 .61667 Mtetra
.487 .855 .988 r
.42232 .61667 .42918 .61855 .4406 .61902 .43385 .61424 Mtetra
.755 .821 .904 r
.43385 .61424 .4406 .61902 .45217 .61546 .44553 .60749 Mtetra
.751 .732 .835 r
.44553 .60749 .45217 .61546 .46385 .60883 .45726 .59974 Mtetra
.721 .701 .831 r
.45726 .59974 .46385 .60883 .47556 .60193 .469 .59321 Mtetra
.696 .702 .852 r
.469 .59321 .47556 .60193 .48729 .59605 .48074 .58805 Mtetra
.68 .715 .875 r
.48074 .58805 .48729 .59605 .49904 .59118 .49252 .58365 Mtetra
.674 .727 .889 r
.49252 .58365 .49904 .59118 .51083 .58698 .50434 .57951 Mtetra
.669 .728 .893 r
.50434 .57951 .51083 .58698 .52266 .58305 .5162 .57555 Mtetra
.662 .725 .896 r
.5162 .57555 .52266 .58305 .53455 .57914 .52812 .57179 Mtetra
.658 .729 .902 r
.52812 .57179 .53455 .57914 .54648 .57522 .54008 .56818 Mtetra
.656 .738 .91 r
.54008 .56818 .54648 .57522 .55846 .57137 .5521 .56459 Mtetra
.656 .747 .917 r
.5521 .56459 .55846 .57137 .5705 .56763 .56417 .56097 Mtetra
.657 .752 .92 r
.56417 .56097 .5705 .56763 .58258 .56396 .5763 .5573 Mtetra
.657 .753 .92 r
.5763 .5573 .58258 .56396 .59472 .56034 .58847 .55361 Mtetra
.656 .751 .92 r
.58847 .55361 .59472 .56034 .60692 .55672 .6007 .54993 Mtetra
.655 .75 .92 r
.6007 .54993 .60692 .55672 .61917 .5531 .61298 .54628 Mtetra
.654 .749 .92 r
.61298 .54628 .61917 .5531 .63147 .54946 .62532 .54264 Mtetra
.653 .75 .921 r
.62532 .54264 .63147 .54946 .64383 .54583 .63772 .53902 Mtetra
.653 .751 .922 r
.63772 .53902 .64383 .54583 .65624 .54224 .65017 .53538 Mtetra
.654 .751 .921 r
.65017 .53538 .65624 .54224 .66872 .53873 .66268 .5317 Mtetra
.655 .747 .918 r
.66268 .5317 .66872 .53873 .68125 .53532 .67524 .52797 Mtetra
.654 .738 .911 r
.67524 .52797 .68125 .53532 .69385 .53199 .68786 .52426 Mtetra
.649 .726 .905 r
.68786 .52426 .69385 .53199 .70651 .52864 .70054 .52071 Mtetra
.643 .719 .903 r
.70054 .52071 .70651 .52864 .71923 .52531 .7133 .51736 Mtetra
.637 .717 .905 r
.7133 .51736 .71923 .52531 .73203 .52226 .72613 .51418 Mtetra
.628 .711 .906 r
.72613 .51418 .73203 .52226 .74494 .51989 .73904 .51127 Mtetra
.605 .687 .9 r
.73904 .51127 .74494 .51989 .75799 .51853 .75206 .50913 Mtetra
.563 .648 .892 r
.75206 .50913 .75799 .51853 .77119 .51822 .76527 .50839 Mtetra
.523 .619 .889 r
.76527 .50839 .77119 .51822 .78446 .51761 .77865 .50888 Mtetra
.55 .661 .91 r
.77865 .50888 .78446 .51761 .79756 .51381 .79204 .50832 Mtetra
.686 .82 .947 r
.79204 .50832 .79756 .51381 .81036 .50584 .80515 .50328 Mtetra
.802 .948 .917 r
.80515 .50328 .81036 .50584 .82306 .49649 .81792 .49388 Mtetra
.811 .949 .911 r
.81792 .49388 .82306 .49649 .83594 .48882 .83068 .48416 Mtetra
.752 .872 .934 r
.83068 .48416 .83594 .48882 .84906 .48328 .84369 .47687 Mtetra
.69 .794 .929 r
.84369 .47687 .84906 .48328 .86234 .47887 .85695 .47171 Mtetra
.664 .761 .923 r
.85695 .47171 .86234 .47887 .87572 .4748 .87036 .46742 Mtetra
.657 .753 .921 r
.87036 .46742 .87572 .4748 .88917 .47078 .88385 .46334 Mtetra
.656 .752 .92 r
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Mtetra
.656 .751 .92 r
.89741 .45928 .90269 .46676 .91626 .46271 .91103 .4552 Mtetra
.91103 .4552 .91626 .46271 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Mtetra
.655 .751 .92 r
.33661 .61893 .34359 .62512 .35476 .62178 .34781 .61557 Mtetra
.652 .751 .922 r
.34781 .61557 .35476 .62178 .36597 .61845 .35905 .6123 Mtetra
.631 .748 .932 r
.35905 .6123 .36597 .61845 .37722 .61533 .37032 .60954 Mtetra
.547 .733 .962 r
.37032 .60954 .37722 .61533 .38849 .61306 .38157 .60842 Mtetra
.262 .646 .965 r
.38157 .60842 .38849 .61306 .39974 .61281 .39277 .61016 Mtetra
0 .451 .762 r
.39277 .61016 .39974 .61281 .41098 .6149 .404 .61332 Mtetra
.202 .709 .902 r
.404 .61332 .41098 .6149 .42232 .61667 .41543 .61317 Mtetra
.733 .864 .942 r
.41543 .61317 .42232 .61667 .43385 .61424 .4271 .60724 Mtetra
.774 .759 .839 r
.4271 .60724 .43385 .61424 .44553 .60749 .43887 .59856 Mtetra
.742 .711 .822 r
.43887 .59856 .44553 .60749 .45726 .59974 .45063 .59086 Mtetra
.709 .704 .843 r
.45063 .59086 .45726 .59974 .469 .59321 .46238 .58502 Mtetra
.687 .713 .869 r
.46238 .58502 .469 .59321 .48074 .58805 .47415 .58032 Mtetra
.674 .722 .885 r
.47415 .58032 .48074 .58805 .49252 .58365 .48595 .57615 Mtetra
.665 .726 .895 r
.48595 .57615 .49252 .58365 .50434 .57951 .4978 .57229 Mtetra
.662 .734 .903 r
.4978 .57229 .50434 .57951 .5162 .57555 .50969 .56855 Mtetra
.663 .741 .909 r
.50969 .56855 .5162 .57555 .52812 .57179 .52164 .56476 Mtetra
.664 .742 .908 r
.52164 .56476 .52812 .57179 .54008 .56818 .53364 .56091 Mtetra
.663 .735 .904 r
.53364 .56091 .54008 .56818 .5521 .56459 .54569 .55709 Mtetra
.66 .728 .9 r
.54569 .55709 .5521 .56459 .56417 .56097 .55779 .55334 Mtetra
.658 .725 .899 r
.55779 .55334 .56417 .56097 .5763 .5573 .56995 .54965 Mtetra
.656 .725 .9 r
.56995 .54965 .5763 .5573 .58847 .55361 .58215 .54599 Mtetra
.656 .726 .901 r
.58215 .54599 .58847 .55361 .6007 .54993 .59442 .54232 Mtetra
.656 .728 .902 r
.59442 .54232 .6007 .54993 .61298 .54628 .60673 .53864 Mtetra
.60673 .53864 .61298 .54628 .62532 .54264 .61911 .53493 Mtetra
.656 .726 .901 r
.61911 .53493 .62532 .54264 .63772 .53902 .63153 .53122 Mtetra
.654 .724 .9 r
.63153 .53122 .63772 .53902 .65017 .53538 .64402 .52755 Mtetra
.652 .723 .901 r
.64402 .52755 .65017 .53538 .66268 .5317 .65656 .52393 Mtetra
.649 .725 .904 r
.65656 .52393 .66268 .5317 .67524 .52797 .66917 .52038 Mtetra
.648 .73 .909 r
.66917 .52038 .67524 .52797 .68786 .52426 .68183 .51686 Mtetra
.649 .737 .914 r
.68183 .51686 .68786 .52426 .70054 .52071 .69456 .51328 Mtetra
.65 .738 .914 r
.69456 .51328 .70054 .52071 .7133 .51736 .70734 .50964 Mtetra
.646 .729 .909 r
.70734 .50964 .7133 .51736 .72613 .51418 .72018 .50612 Mtetra
.636 .716 .905 r
.72018 .50612 .72613 .51418 .73904 .51127 .73311 .50292 Mtetra
.619 .702 .904 r
.73311 .50292 .73904 .51127 .75206 .50913 .74614 .50026 Mtetra
.583 .673 .901 r
.74614 .50026 .75206 .50913 .76527 .50839 .75932 .49876 Mtetra
.523 .625 .894 r
.75932 .49876 .76527 .50839 .77865 .50888 .77272 .49915 Mtetra
.487 .604 .895 r
.77272 .49915 .77865 .50888 .79204 .50832 .7863 .50054 Mtetra
.572 .701 .929 r
.7863 .50054 .79204 .50832 .80515 .50328 .79974 .49905 Mtetra
.757 .887 .937 r
.79974 .49905 .80515 .50328 .81792 .49388 .81275 .49155 Mtetra
.836 .957 .891 r
.81275 .49155 .81792 .49388 .83068 .48416 .82547 .48063 Mtetra
.806 .921 .914 r
.82547 .48063 .83068 .48416 .84369 .47687 .83835 .47121 Mtetra
.727 .833 .93 r
.83835 .47121 .84369 .47687 .85695 .47171 .85154 .46476 Mtetra
.675 .774 .925 r
.85154 .46476 .85695 .47171 .87036 .46742 .86495 .46004 Mtetra
.659 .756 .921 r
.86495 .46004 .87036 .46742 .88385 .46334 .87848 .45584 Mtetra
.656 .752 .92 r
.87848 .45584 .88385 .46334 .89741 .45928 .89208 .45174 Mtetra
.656 .751 .92 r
.89208 .45174 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Mtetra
.655 .751 .921 r
.32959 .6127 .33661 .61893 .34781 .61557 .34081 .60934 Mtetra
.646 .75 .925 r
.34081 .60934 .34781 .61557 .35905 .6123 .35208 .60619 Mtetra
.602 .742 .943 r
.35208 .60619 .35905 .6123 .37032 .60954 .36334 .60407 Mtetra
.424 .697 .977 r
.36334 .60407 .37032 .60954 .38157 .60842 .37454 .60458 Mtetra
0 .471 .831 r
.37454 .60458 .38157 .60842 .39277 .61016 .38569 .60822 Mtetra
0 .422 .697 r
.38569 .60822 .39277 .61016 .404 .61332 .39696 .61115 Mtetra
.568 .877 .993 r
.39696 .61115 .404 .61332 .41543 .61317 .40854 .6079 Mtetra
.794 .807 .862 r
.40854 .6079 .41543 .61317 .4271 .60724 .42034 .59895 Mtetra
.774 .731 .814 r
.42034 .59895 .4271 .60724 .43887 .59856 .43216 .58948 Mtetra
.732 .707 .827 r
.43216 .58948 .43887 .59856 .45063 .59086 .44394 .58232 Mtetra
.697 .709 .857 r
.44394 .58232 .45063 .59086 .46238 .58502 .45571 .5771 Mtetra
.677 .718 .88 r
.45571 .5771 .46238 .58502 .47415 .58032 .4675 .57281 Mtetra
.668 .728 .894 r
.4675 .57281 .47415 .58032 .48595 .57615 .47933 .56886 Mtetra
.666 .734 .901 r
.47933 .56886 .48595 .57615 .4978 .57229 .49121 .56497 Mtetra
.663 .733 .901 r
.49121 .56497 .4978 .57229 .50969 .56855 .50314 .56113 Mtetra
.658 .729 .902 r
.50314 .56113 .50969 .56855 .52164 .56476 .51512 .55745 Mtetra
.654 .732 .906 r
.51512 .55745 .52164 .56476 .53364 .56091 .52715 .55388 Mtetra
.653 .741 .914 r
.52715 .55388 .53364 .56091 .54569 .55709 .53923 .55031 Mtetra
.654 .75 .92 r
.53923 .55031 .54569 .55709 .55779 .55334 .55137 .54668 Mtetra
.656 .755 .923 r
.55137 .54668 .55779 .55334 .56995 .54965 .56356 .54299 Mtetra
.656 .756 .923 r
.56356 .54299 .56995 .54965 .58215 .54599 .5758 .53927 Mtetra
.656 .755 .923 r
.5758 .53927 .58215 .54599 .59442 .54232 .5881 .53555 Mtetra
.655 .754 .923 r
.5881 .53555 .59442 .54232 .60673 .53864 .60046 .53184 Mtetra
.654 .754 .923 r
.60046 .53184 .60673 .53864 .61911 .53493 .61287 .52813 Mtetra
.653 .754 .924 r
.61287 .52813 .61911 .53493 .63153 .53122 .62533 .52443 Mtetra
.654 .756 .924 r
.62533 .52443 .63153 .53122 .64402 .52755 .63785 .52068 Mtetra
.655 .755 .923 r
.63785 .52068 .64402 .52755 .65656 .52393 .65043 .51688 Mtetra
.657 .751 .919 r
.65043 .51688 .65656 .52393 .66917 .52038 .66306 .51302 Mtetra
.657 .742 .913 r
.66306 .51302 .66917 .52038 .68183 .51686 .67575 .50916 Mtetra
.653 .732 .907 r
.67575 .50916 .68183 .51686 .69456 .51328 .6885 .50541 Mtetra
.648 .726 .906 r
.6885 .50541 .69456 .51328 .70734 .50964 .70132 .50181 Mtetra
.646 .727 .908 r
.70132 .50181 .70734 .50964 .72018 .50612 .71421 .49828 Mtetra
.644 .727 .909 r
.71421 .49828 .72018 .50612 .73311 .50292 .72716 .49479 Mtetra
.633 .716 .907 r
.72716 .49479 .73311 .50292 .74614 .50026 .74019 .49165 Mtetra
.603 .691 .904 r
.74019 .49165 .74614 .50026 .75932 .49876 .75336 .48946 Mtetra
.539 .643 .901 r
.75336 .48946 .75932 .49876 .77272 .49915 .76675 .48925 Mtetra
.457 .586 .894 r
.76675 .48925 .77272 .49915 .7863 .50054 .78041 .4914 Mtetra
.467 .612 .91 r
.78041 .4914 .7863 .50054 .79974 .49905 .79414 .49298 Mtetra
.661 .797 .947 r
.79414 .49298 .79974 .49905 .81275 .49155 .80747 .48862 Mtetra
.835 .94 .894 r
.80747 .48862 .81275 .49155 .82547 .48063 .82028 .47784 Mtetra
.849 .946 .882 r
.82028 .47784 .82547 .48063 .83835 .47121 .83304 .46635 Mtetra
.774 .874 .921 r
.83304 .46635 .83835 .47121 .85154 .46476 .84612 .45815 Mtetra
.696 .795 .926 r
.84612 .45815 .85154 .46476 .86495 .46004 .85951 .45269 Mtetra
.664 .761 .922 r
.85951 .45269 .86495 .46004 .87848 .45584 .87307 .4483 Mtetra
.657 .753 .921 r
.87307 .4483 .87848 .45584 .89208 .45174 .88671 .44413 Mtetra
.656 .751 .92 r
.88671 .44413 .89208 .45174 .90575 .44762 .90042 .43998 Mtetra
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Mtetra
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60642 Mtetra
.653 .751 .922 r
.32251 .60642 .32959 .6127 .34081 .60934 .33376 .60308 Mtetra
.636 .748 .929 r
.33376 .60308 .34081 .60934 .35208 .60619 .34504 .60017 Mtetra
.552 .73 .958 r
.34504 .60017 .35208 .60619 .36334 .60407 .35628 .59898 Mtetra
.213 .603 .949 r
.35628 .59898 .36334 .60407 .37454 .60458 .36742 .6014 Mtetra
.306 0 0 r
.36742 .6014 .37454 .60458 .38569 .60822 .37853 .60652 Mtetra
0 .552 .79 r
.37853 .60652 .38569 .60822 .39696 .61115 .38989 .60806 Mtetra
.757 .88 .934 r
.38989 .60806 .39696 .61115 .40854 .6079 .40163 .60127 Mtetra
.811 .771 .816 r
.40163 .60127 .40854 .6079 .42034 .59895 .41355 .59005 Mtetra
.769 .72 .806 r
.41355 .59005 .42034 .59895 .43216 .58948 .42541 .58049 Mtetra
.72 .706 .837 r
.42541 .58049 .43216 .58948 .44394 .58232 .4372 .57404 Mtetra
.685 .713 .869 r
.4372 .57404 .44394 .58232 .45571 .5771 .44898 .56936 Mtetra
.67 .723 .889 r
.44898 .56936 .45571 .5771 .4675 .57281 .4608 .56531 Mtetra
.664 .728 .897 r
.4608 .56531 .4675 .57281 .47933 .56886 .47266 .56147 Mtetra
.658 .73 .902 r
.47266 .56147 .47933 .56886 .49121 .56497 .48457 .55779 Mtetra
.657 .737 .909 r
.48457 .55779 .49121 .56497 .50314 .56113 .49653 .55415 Mtetra
.659 .744 .913 r
.49653 .55415 .50314 .56113 .51512 .55745 .50854 .55041 Mtetra
.662 .744 .911 r
.50854 .55041 .51512 .55745 .52715 .55388 .5206 .54657 Mtetra
.661 .737 .906 r
.5206 .54657 .52715 .55388 .53923 .55031 .53272 .54272 Mtetra
.659 .729 .901 r
.53272 .54272 .53923 .55031 .55137 .54668 .54489 .53894 Mtetra
.657 .725 .899 r
.54489 .53894 .55137 .54668 .56356 .54299 .55711 .53521 Mtetra
.656 .724 .9 r
.55711 .53521 .56356 .54299 .5758 .53927 .56939 .53151 Mtetra
.655 .726 .901 r
.56939 .53151 .5758 .53927 .5881 .53555 .58172 .5278 Mtetra
.656 .727 .901 r
.58172 .5278 .5881 .53555 .60046 .53184 .59411 .52405 Mtetra
.59411 .52405 .60046 .53184 .61287 .52813 .60655 .52028 Mtetra
.656 .726 .901 r
.60655 .52028 .61287 .52813 .62533 .52443 .61905 .51649 Mtetra
.655 .724 .9 r
.61905 .51649 .62533 .52443 .63785 .52068 .63161 .51274 Mtetra
.653 .724 .901 r
.63161 .51274 .63785 .52068 .65043 .51688 .64422 .50903 Mtetra
.65 .727 .905 r
.64422 .50903 .65043 .51688 .66306 .51302 .6569 .50538 Mtetra
.649 .733 .91 r
.6569 .50538 .66306 .51302 .67575 .50916 .66963 .50173 Mtetra
.652 .741 .915 r
.66963 .50173 .67575 .50916 .6885 .50541 .68243 .49799 Mtetra
.655 .743 .915 r
.68243 .49799 .6885 .50541 .70132 .50181 .69527 .49413 Mtetra
.653 .736 .91 r
.69527 .49413 .70132 .50181 .71421 .49828 .70818 .49031 Mtetra
.648 .727 .906 r
.70818 .49031 .71421 .49828 .72716 .49479 .72116 .48665 Mtetra
.641 .72 .906 r
.72116 .48665 .72716 .49479 .74019 .49165 .73421 .48322 Mtetra
.621 .705 .905 r
.73421 .48322 .74019 .49165 .75336 .48946 .74738 .48041 Mtetra
.563 .663 .905 r
.74738 .48041 .75336 .48946 .76675 .48925 .76074 .47943 Mtetra
.451 .586 .897 r
.76074 .47943 .76675 .48925 .78041 .4914 .77443 .48162 Mtetra
.378 .547 .895 r
.77443 .48162 .78041 .4914 .79414 .49298 .78837 .48549 Mtetra
.534 .698 .944 r
.78837 .48549 .79414 .49298 .80747 .48862 .80205 .48473 Mtetra
.804 .91 .913 r
.80205 .48473 .80747 .48862 .82028 .47784 .81506 .47532 Mtetra
.877 .95 .854 r
.81506 .47532 .82028 .47784 .83304 .46635 .82774 .4622 Mtetra
.823 .905 .897 r
.82774 .4622 .83304 .46635 .84612 .45815 .84069 .45191 Mtetra
.725 .819 .923 r
.84069 .45191 .84612 .45815 .85951 .45269 .85403 .44541 Mtetra
.672 .768 .922 r
.85403 .44541 .85951 .45269 .87307 .4483 .86761 .44071 Mtetra
.658 .754 .921 r
.86761 .44071 .87307 .4483 .88671 .44413 .88129 .43646 Mtetra
.656 .752 .92 r
.88129 .43646 .88671 .44413 .90042 .43998 .89505 .43227 Mtetra
.656 .751 .92 r
.89505 .43227 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Mtetra
.655 .751 .92 r
.30413 .60352 .3113 .60982 .32251 .60642 .31537 .6001 Mtetra
.65 .75 .923 r
.31537 .6001 .32251 .60642 .33376 .60308 .32665 .59679 Mtetra
.62 .744 .935 r
.32665 .59679 .33376 .60308 .34504 .60017 .33793 .59423 Mtetra
.473 .704 .97 r
.33793 .59423 .34504 .60017 .35628 .59898 .34914 .59423 Mtetra
0 .428 .827 r
.34914 .59423 .35628 .59898 .36742 .6014 .3602 .59871 Mtetra
.445 0 0 r
.3602 .59871 .36742 .6014 .37853 .60652 .37129 .6048 Mtetra
.279 .754 .935 r
.37129 .6048 .37853 .60652 .38989 .60806 .38278 .60411 Mtetra
.827 .844 .86 r
.38278 .60411 .38989 .60806 .40163 .60127 .3947 .59375 Mtetra
.819 .753 .79 r
.3947 .59375 .40163 .60127 .41355 .59005 .40672 .58089 Mtetra
.763 .714 .807 r
.40672 .58089 .41355 .59005 .42541 .58049 .41861 .57163 Mtetra
.706 .706 .847 r
.41861 .57163 .42541 .58049 .4372 .57404 .43041 .56588 Mtetra
.673 .713 .879 r
.43041 .56588 .4372 .57404 .44898 .56936 .44221 .56167 Mtetra
.661 .722 .894 r
.44221 .56167 .44898 .56936 .4608 .56531 .45405 .55789 Mtetra
.658 .73 .903 r
.45405 .55789 .4608 .56531 .47266 .56147 .46593 .5542 Mtetra
.66 .736 .906 r
.46593 .5542 .47266 .56147 .48457 .55779 .47787 .55043 Mtetra
.659 .734 .904 r
.47787 .55043 .48457 .55779 .49653 .55415 .48987 .54666 Mtetra
.655 .73 .904 r
.48987 .54666 .49653 .55415 .50854 .55041 .50191 .54303 Mtetra
.651 .732 .909 r
.50191 .54303 .50854 .55041 .5206 .54657 .514 .5395 Mtetra
.65 .742 .917 r
.514 .5395 .5206 .54657 .53272 .54272 .52616 .53597 Mtetra
.652 .753 .924 r
.52616 .53597 .53272 .54272 .54489 .53894 .53836 .53235 Mtetra
.654 .76 .927 r
.53836 .53235 .54489 .53894 .55711 .53521 .55062 .52865 Mtetra
.655 .762 .928 r
.55062 .52865 .55711 .53521 .56939 .53151 .56294 .52489 Mtetra
.655 .761 .928 r
.56294 .52489 .56939 .53151 .58172 .5278 .57531 .52111 Mtetra
.654 .76 .927 r
.57531 .52111 .58172 .5278 .59411 .52405 .58773 .51734 Mtetra
.58773 .51734 .59411 .52405 .60655 .52028 .60021 .51357 Mtetra
.654 .761 .928 r
.60021 .51357 .60655 .52028 .61905 .51649 .61275 .50978 Mtetra
.655 .762 .928 r
.61275 .50978 .61905 .51649 .63161 .51274 .62534 .50593 Mtetra
.657 .761 .926 r
.62534 .50593 .63161 .51274 .64422 .50903 .63799 .50199 Mtetra
.66 .755 .921 r
.63799 .50199 .64422 .50903 .6569 .50538 .6507 .49798 Mtetra
.66 .746 .913 r
.6507 .49798 .6569 .50538 .66963 .50173 .66346 .49395 Mtetra
.656 .734 .907 r
.66346 .49395 .66963 .50173 .68243 .49799 .67628 .49004 Mtetra
.652 .729 .906 r
.67628 .49004 .68243 .49799 .69527 .49413 .68917 .48625 Mtetra
.651 .732 .908 r
.68917 .48625 .69527 .49413 .70818 .49031 .70212 .48247 Mtetra
.653 .734 .909 r
.70212 .48247 .70818 .49031 .72116 .48665 .71512 .4786 Mtetra
.65 .728 .906 r
.71512 .4786 .72116 .48665 .73421 .48322 .7282 .47482 Mtetra
.636 .714 .903 r
.7282 .47482 .73421 .48322 .74738 .48041 .74136 .47149 Mtetra
.587 .679 .904 r
.74136 .47149 .74738 .48041 .76074 .47943 .75471 .46972 Mtetra
.461 .596 .901 r
.75471 .46972 .76074 .47943 .77443 .48162 .7684 .47156 Mtetra
.306 .498 .882 r
.7684 .47156 .77443 .48162 .78837 .48549 .78248 .47708 Mtetra
.383 .591 .926 r
.78248 .47708 .78837 .48549 .80205 .48473 .7965 .47996 Mtetra
.744 .872 .939 r
.7965 .47996 .80205 .48473 .81506 .47532 .80977 .47276 Mtetra
.893 .946 .836 r
.80977 .47276 .81506 .47532 .82774 .4622 .82244 .45853 Mtetra
.865 .921 .864 r
.82244 .45853 .82774 .4622 .84069 .45191 .83525 .44603 Mtetra
.76 .841 .913 r
.83525 .44603 .84069 .45191 .85403 .44541 .84852 .43821 Mtetra
.684 .777 .921 r
.84852 .43821 .85403 .44541 .86761 .44071 .8621 .43308 Mtetra
.66 .756 .921 r
.8621 .43308 .86761 .44071 .88129 .43646 .87583 .42872 Mtetra
.656 .752 .92 r
.87583 .42872 .88129 .43646 .89505 .43227 .88963 .42449 Mtetra
.656 .751 .92 r
.88963 .42449 .89505 .43227 .90888 .42806 .90351 .42024 Mtetra
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Mtetra
.655 .751 .921 r
.29691 .59716 .30413 .60352 .31537 .6001 .30818 .59373 Mtetra
.647 .75 .924 r
.30818 .59373 .31537 .6001 .32665 .59679 .31948 .59048 Mtetra
.6 .739 .942 r
.31948 .59048 .32665 .59679 .33793 .59423 .33076 .58836 Mtetra
.36 .656 .969 r
.33076 .58836 .33793 .59423 .34914 .59423 .34192 .58972 Mtetra
0 .21 .625 r
.34192 .58972 .34914 .59423 .3602 .59871 .35289 .5963 Mtetra
.51 0 0 r
.35289 .5963 .3602 .59871 .37129 .6048 .36398 .60297 Mtetra
.558 .885 .989 r
.36398 .60297 .37129 .6048 .38278 .60411 .37562 .59957 Mtetra
.859 .818 .808 r
.37562 .59957 .38278 .60411 .3947 .59375 .38774 .58571 Mtetra
.825 .744 .775 r
.38774 .58571 .3947 .59375 .40672 .58089 .39985 .57159 Mtetra
.755 .711 .811 r
.39985 .57159 .40672 .58089 .41861 .57163 .41175 .56281 Mtetra
.69 .704 .857 r
.41175 .56281 .41861 .57163 .43041 .56588 .42356 .55779 Mtetra
.661 .713 .886 r
.42356 .55779 .43041 .56588 .44221 .56167 .43538 .55399 Mtetra
.656 .723 .898 r
.43538 .55399 .44221 .56167 .45405 .55789 .44724 .55037 Mtetra
.655 .728 .903 r
.44724 .55037 .45405 .55789 .46593 .5542 .45916 .54676 Mtetra
.651 .73 .907 r
.45916 .54676 .46593 .5542 .47787 .55043 .47113 .54323 Mtetra
.652 .738 .913 r
.47113 .54323 .47787 .55043 .48987 .54666 .48315 .53968 Mtetra
.657 .746 .916 r
.48315 .53968 .48987 .54666 .50191 .54303 .49522 .53595 Mtetra
.661 .746 .913 r
.49522 .53595 .50191 .54303 .514 .5395 .50736 .53207 Mtetra
.662 .737 .905 r
.50736 .53207 .514 .5395 .52616 .53597 .51954 .52815 Mtetra
.659 .726 .899 r
.51954 .52815 .52616 .53597 .53836 .53235 .53178 .52429 Mtetra
.656 .72 .895 r
.53178 .52429 .53836 .53235 .55062 .52865 .54407 .52051 Mtetra
.655 .718 .895 r
.54407 .52051 .55062 .52865 .56294 .52489 .55642 .51676 Mtetra
.655 .719 .895 r
.55642 .51676 .56294 .52489 .57531 .52111 .56882 .51299 Mtetra
.656 .72 .896 r
.56882 .51299 .57531 .52111 .58773 .51734 .58128 .50919 Mtetra
.58128 .50919 .58773 .51734 .60021 .51357 .59379 .50534 Mtetra
.656 .719 .895 r
.59379 .50534 .60021 .51357 .61275 .50978 .60636 .50148 Mtetra
.654 .718 .895 r
.60636 .50148 .61275 .50978 .62534 .50593 .61899 .49766 Mtetra
.652 .719 .897 r
.61899 .49766 .62534 .50593 .63799 .50199 .63168 .49391 Mtetra
.65 .723 .903 r
.63168 .49391 .63799 .50199 .6507 .49798 .64443 .49021 Mtetra
.65 .733 .91 r
.64443 .49021 .6507 .49798 .66346 .49395 .65724 .48648 Mtetra
.654 .744 .916 r
.65724 .48648 .66346 .49395 .67628 .49004 .67011 .4826 Mtetra
.659 .748 .916 r
.67011 .4826 .67628 .49004 .68917 .48625 .68302 .47853 Mtetra
.659 .741 .91 r
.68302 .47853 .68917 .48625 .70212 .48247 .696 .47444 Mtetra
.656 .732 .905 r
.696 .47444 .70212 .48247 .71512 .4786 .70904 .47043 Mtetra
.655 .729 .903 r
.70904 .47043 .71512 .4786 .7282 .47482 .72214 .46644 Mtetra
.65 .722 .901 r
.72214 .46644 .7282 .47482 .74136 .47149 .73531 .46262 Mtetra
.612 .694 .902 r
.73531 .46262 .74136 .47149 .75471 .46972 .74863 .46005 Mtetra
.48 .609 .902 r
.74863 .46005 .75471 .46972 .7684 .47156 .76231 .46134 Mtetra
.245 .458 .869 r
.76231 .46134 .7684 .47156 .78248 .47708 .77652 .46812 Mtetra
.211 .471 .886 r
.77652 .46812 .78248 .47708 .7965 .47996 .79085 .47456 Mtetra
.653 .825 .966 r
.79085 .47456 .7965 .47996 .80977 .47276 .80441 .4701 Mtetra
.901 .941 .826 r
.80441 .4701 .80977 .47276 .82244 .45853 .8171 .45516 Mtetra
.898 .924 .828 r
.8171 .45516 .82244 .45853 .83525 .44603 .82978 .44038 Mtetra
.794 .858 .897 r
.82978 .44038 .83525 .44603 .84852 .43821 .84297 .43107 Mtetra
.698 .785 .919 r
.84297 .43107 .84852 .43821 .8621 .43308 .85656 .42541 Mtetra
.663 .758 .92 r
.85656 .42541 .8621 .43308 .87583 .42872 .87032 .42093 Mtetra
.657 .752 .92 r
.87032 .42093 .87583 .42872 .88963 .42449 .88417 .41664 Mtetra
.656 .751 .92 r
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Mtetra
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Mtetra
.654 .751 .921 r
.28963 .59076 .29691 .59716 .30818 .59373 .30092 .58731 Mtetra
.643 .749 .926 r
.30092 .58731 .30818 .59373 .31948 .59048 .31225 .58414 Mtetra
.576 .731 .948 r
.31225 .58414 .31948 .59048 .33076 .58836 .32353 .58249 Mtetra
.214 .579 .943 r
.32353 .58249 .33076 .58836 .34192 .58972 .33463 .58531 Mtetra
.544 0 0 r
.33463 .58531 .34192 .58972 .35289 .5963 .3455 .59401 Mtetra
.545 0 0 r
.3455 .59401 .35289 .5963 .36398 .60297 .35659 .60109 Mtetra
.728 .921 .957 r
.35659 .60109 .36398 .60297 .37562 .59957 .36841 .59476 Mtetra
.879 .802 .77 r
.36841 .59476 .37562 .59957 .38774 .58571 .38074 .57744 Mtetra
.831 .741 .765 r
.38074 .57744 .38774 .58571 .39985 .57159 .39293 .5622 Mtetra
.746 .708 .816 r
.39293 .5622 .39985 .57159 .41175 .56281 .40485 .55396 Mtetra
.673 .699 .866 r
.40485 .55396 .41175 .56281 .42356 .55779 .41667 .54964 Mtetra
.647 .708 .892 r
.41667 .54964 .42356 .55779 .43538 .55399 .4285 .54626 Mtetra
.646 .72 .902 r
.4285 .54626 .43538 .55399 .44724 .55037 .44039 .54291 Mtetra
.65 .73 .907 r
.44039 .54291 .44724 .55037 .45916 .54676 .45233 .53941 Mtetra
.656 .735 .908 r
.45233 .53941 .45916 .54676 .47113 .54323 .46433 .53571 Mtetra
.657 .732 .905 r
.46433 .53571 .47113 .54323 .48315 .53968 .47639 .53198 Mtetra
.651 .726 .903 r
.47639 .53198 .48315 .53968 .49522 .53595 .48849 .52839 Mtetra
.646 .729 .909 r
.48849 .52839 .49522 .53595 .50736 .53207 .50065 .52495 Mtetra
.645 .743 .92 r
.50065 .52495 .50736 .53207 .51954 .52815 .51287 .52149 Mtetra
.648 .758 .93 r
.51287 .52149 .51954 .52815 .53178 .52429 .52514 .51789 Mtetra
.652 .769 .934 r
.52514 .51789 .53178 .52429 .54407 .52051 .53747 .51414 Mtetra
.655 .771 .935 r
.53747 .51414 .54407 .52051 .55642 .51676 .54986 .51029 Mtetra
.655 .769 .933 r
.54986 .51029 .55642 .51676 .56882 .51299 .5623 .50643 Mtetra
.654 .767 .932 r
.5623 .50643 .56882 .51299 .58128 .50919 .5748 .5026 Mtetra
.652 .766 .933 r
.5748 .5026 .58128 .50919 .59379 .50534 .58735 .49879 Mtetra
.652 .768 .935 r
.58735 .49879 .59379 .50534 .60636 .50148 .59996 .49496 Mtetra
.654 .771 .935 r
.59996 .49496 .60636 .50148 .61899 .49766 .61263 .49103 Mtetra
.659 .771 .932 r
.61263 .49103 .61899 .49766 .63168 .49391 .62535 .48696 Mtetra
.664 .763 .924 r
.62535 .48696 .63168 .49391 .64443 .49021 .63813 .48274 Mtetra
.664 .749 .913 r
.63813 .48274 .64443 .49021 .65724 .48648 .65096 .47851 Mtetra
.659 .734 .905 r
.65096 .47851 .65724 .48648 .67011 .4826 .66385 .47442 Mtetra
.654 .727 .903 r
.66385 .47442 .67011 .4826 .68302 .47853 .67682 .47048 Mtetra
.655 .732 .906 r
.67682 .47048 .68302 .47853 .696 .47444 .68984 .4665 Mtetra
.661 .738 .907 r
.68984 .4665 .696 .47444 .70904 .47043 .70291 .46231 Mtetra
.664 .735 .903 r
.70291 .46231 .70904 .47043 .72214 .46644 .71603 .45798 Mtetra
.663 .727 .897 r
.71603 .45798 .72214 .46644 .73531 .46262 .72921 .45368 Mtetra
.634 .703 .896 r
.72921 .45368 .73531 .46262 .74863 .46005 .74252 .45034 Mtetra
.502 .622 .902 r
.74252 .45034 .74863 .46005 .76231 .46134 .75618 .45102 Mtetra
.188 .421 .854 r
.75618 .45102 .76231 .46134 .77652 .46812 .77049 .45891 Mtetra
.018 .335 .817 r
.77049 .45891 .77652 .46812 .79085 .47456 .78512 .46887 Mtetra
.523 .762 .984 r
.78512 .46887 .79085 .47456 .80441 .4701 .79899 .46737 Mtetra
.906 .938 .819 r
.79899 .46737 .80441 .4701 .8171 .45516 .81172 .45192 Mtetra
.922 .919 .794 r
.81172 .45192 .8171 .45516 .82978 .44038 .82427 .43482 Mtetra
.825 .866 .876 r
.82427 .43482 .82978 .44038 .84297 .43107 .83738 .42392 Mtetra
.712 .792 .914 r
.83738 .42392 .84297 .43107 .85656 .42541 .85096 .41769 Mtetra
.666 .759 .92 r
.85096 .41769 .85656 .42541 .87032 .42093 .86476 .41306 Mtetra
.657 .752 .92 r
.86476 .41306 .87032 .42093 .88417 .41664 .87866 .40873 Mtetra
.656 .751 .92 r
.87866 .40873 .88417 .41664 .89809 .41236 .89262 .40441 Mtetra
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Mtetra
.654 .751 .921 r
.28229 .5843 .28963 .59076 .30092 .58731 .29362 .58084 Mtetra
.64 .748 .927 r
.29362 .58084 .30092 .58731 .31225 .58414 .30496 .57774 Mtetra
.549 .722 .954 r
.30496 .57774 .31225 .58414 .32353 .58249 .31624 .57657 Mtetra
.049 .477 .885 r
.31624 .57657 .32353 .58249 .33463 .58531 .32727 .58084 Mtetra
.669 .128 0 r
.32727 .58084 .33463 .58531 .3455 .59401 .33803 .5917 Mtetra
.573 0 0 r
.33803 .5917 .3455 .59401 .35659 .60109 .34912 .59924 Mtetra
.816 .917 .906 r
.34912 .59924 .35659 .60109 .36841 .59476 .36113 .59003 Mtetra
.895 .795 .742 r
.36113 .59003 .36841 .59476 .38074 .57744 .37368 .5692 Mtetra
.84 .742 .756 r
.37368 .5692 .38074 .57744 .39293 .5622 .38598 .55273 Mtetra
.738 .706 .821 r
.38598 .55273 .39293 .5622 .40485 .55396 .39791 .545 Mtetra
.652 .69 .873 r
.39791 .545 .40485 .55396 .41667 .54964 .40972 .54141 Mtetra
.633 .703 .896 r
.40972 .54141 .41667 .54964 .4285 .54626 .42157 .53845 Mtetra
.642 .718 .903 r
.42157 .53845 .4285 .54626 .44039 .54291 .43348 .53521 Mtetra
.647 .723 .904 r
.43348 .53521 .44039 .54291 .45233 .53941 .44545 .53179 Mtetra
.647 .727 .907 r
.44545 .53179 .45233 .53941 .46433 .53571 .45748 .52834 Mtetra
.654 .737 .91 r
.45748 .52834 .46433 .53571 .47639 .53198 .46956 .52465 Mtetra
.671 .744 .905 r
.46956 .52465 .47639 .53198 .48849 .52839 .48171 .5204 Mtetra
.685 .731 .885 r
.48171 .5204 .48849 .52839 .50065 .52495 .49391 .51559 Mtetra
.686 .7 .857 r
.49391 .51559 .50065 .52495 .51287 .52149 .50617 .5105 Mtetra
.677 .665 .83 r
.50617 .5105 .51287 .52149 .52514 .51789 .51846 .50544 Mtetra
.666 .636 .811 r
.51846 .50544 .52514 .51789 .53747 .51414 .53081 .50061 Mtetra
.655 .616 .799 r
.53081 .50061 .53747 .51414 .54986 .51029 .5432 .4961 Mtetra
.646 .604 .792 r
.5432 .4961 .54986 .51029 .5623 .50643 .55565 .49192 Mtetra
.639 .597 .79 r
.55565 .49192 .5623 .50643 .5748 .5026 .56816 .48804 Mtetra
.633 .594 .792 r
.56816 .48804 .5748 .5026 .58735 .49879 .58073 .48448 Mtetra
.627 .595 .797 r
.58073 .48448 .58735 .49879 .59996 .49496 .59336 .48124 Mtetra
.621 .6 .808 r
.59336 .48124 .59996 .49496 .61263 .49103 .60607 .47834 Mtetra
.617 .614 .825 r
.60607 .47834 .61263 .49103 .62535 .48696 .61885 .47567 Mtetra
.618 .64 .85 r
.61885 .47567 .62535 .48696 .63813 .48274 .6317 .47303 Mtetra
.625 .677 .879 r
.6317 .47303 .63813 .48274 .65096 .47851 .64461 .47011 Mtetra
.641 .717 .903 r
.64461 .47011 .65096 .47851 .66385 .47442 .65757 .46662 Mtetra
.657 .74 .911 r
.65757 .46662 .66385 .47442 .67682 .47048 .67057 .46256 Mtetra
.663 .74 .907 r
.67057 .46256 .67682 .47048 .68984 .4665 .68361 .45827 Mtetra
.663 .733 .901 r
.68361 .45827 .68984 .4665 .70291 .46231 .69672 .45395 Mtetra
.668 .732 .898 r
.69672 .45395 .70291 .46231 .71603 .45798 .70987 .44944 Mtetra
.675 .731 .892 r
.70987 .44944 .71603 .45798 .72921 .45368 .72306 .44465 Mtetra
.656 .712 .889 r
.72306 .44465 .72921 .45368 .74252 .45034 .73636 .4405 Mtetra
.523 .631 .899 r
.73636 .4405 .74252 .45034 .75618 .45102 .75001 .44061 Mtetra
.122 .377 .835 r
.75001 .44061 .75618 .45102 .77049 .45891 .76442 .44971 Mtetra
0 .184 .714 r
.76442 .44971 .77049 .45891 .78512 .46887 .77935 .46326 Mtetra
.346 .673 .976 r
.77935 .46326 .78512 .46887 .79899 .46737 .79351 .46466 Mtetra
.912 .937 .811 r
.79351 .46466 .79899 .46737 .81172 .45192 .80628 .44862 Mtetra
.939 .908 .763 r
.80628 .44862 .81172 .45192 .82427 .43482 .81871 .42919 Mtetra
.85 .867 .853 r
.81871 .42919 .82427 .43482 .83738 .42392 .83173 .4167 Mtetra
.726 .797 .908 r
.83173 .4167 .83738 .42392 .85096 .41769 .84531 .4099 Mtetra
.669 .761 .919 r
.84531 .4099 .85096 .41769 .86476 .41306 .85915 .40513 Mtetra
.657 .752 .92 r
.85915 .40513 .86476 .41306 .87866 .40873 .8731 .40074 Mtetra
.656 .751 .92 r
.8731 .40074 .87866 .40873 .89262 .40441 .88711 .39638 Mtetra
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .5778 Mtetra
.654 .751 .921 r
.2749 .5778 .28229 .5843 .29362 .58084 .28625 .57431 Mtetra
.636 .747 .928 r
.28625 .57431 .29362 .58084 .30496 .57774 .29762 .57129 Mtetra
.523 .712 .958 r
.29762 .57129 .30496 .57774 .31624 .57657 .30889 .57056 Mtetra
0 .363 .805 r
.30889 .57056 .31624 .57657 .32727 .58084 .31985 .57619 Mtetra
.745 .228 0 r
.31985 .57619 .32727 .58084 .33803 .5917 .3305 .58917 Mtetra
.605 .035 0 r
.3305 .58917 .33803 .5917 .34912 .59924 .34156 .59743 Mtetra
.86 .903 .863 r
.34156 .59743 .34912 .59924 .36113 .59003 .35376 .5857 Mtetra
.91 .792 .719 r
.35376 .5857 .36113 .59003 .37368 .5692 .36655 .56131 Mtetra
.853 .749 .748 r
.36655 .56131 .37368 .5692 .38598 .55273 .37897 .54328 Mtetra
.733 .706 .825 r
.37897 .54328 .38598 .55273 .39791 .545 .39092 .53583 Mtetra
.632 .68 .877 r
.39092 .53583 .39791 .545 .40972 .54141 .40273 .53291 Mtetra
.62 .693 .896 r
.40273 .53291 .40972 .54141 .42157 .53845 .41459 .53034 Mtetra
.64 .711 .898 r
.41459 .53034 .42157 .53845 .43348 .53521 .42653 .5271 Mtetra
.667 .721 .889 r
.42653 .5271 .43348 .53521 .44545 .53179 .43855 .52296 Mtetra
.692 .712 .863 r
.43855 .52296 .44545 .53179 .45748 .52834 .45064 .51774 Mtetra
.697 .678 .828 r
.45064 .51774 .45748 .52834 .46956 .52465 .46279 .51183 Mtetra
.683 .637 .797 r
.46279 .51183 .46956 .52465 .48171 .5204 .47497 .50597 Mtetra
.665 .609 .782 r
.47497 .50597 .48171 .5204 .49391 .51559 .48719 .50071 Mtetra
.651 .597 .781 r
.48719 .50071 .49391 .51559 .50617 .5105 .49945 .49614 Mtetra
.644 .6 .79 r
.49945 .49614 .50617 .5105 .51846 .50544 .51175 .49208 Mtetra
.642 .613 .805 r
.51175 .49208 .51846 .50544 .53081 .50061 .52411 .48827 Mtetra
.643 .629 .821 r
.52411 .48827 .53081 .50061 .5432 .4961 .53653 .48452 Mtetra
.646 .644 .834 r
.53653 .48452 .5432 .4961 .55565 .49192 .549 .48072 Mtetra
.65 .653 .84 r
.549 .48072 .55565 .49192 .56816 .48804 .56153 .47681 Mtetra
.652 .654 .84 r
.56153 .47681 .56816 .48804 .58073 .48448 .57411 .47278 Mtetra
.652 .647 .832 r
.57411 .47278 .58073 .48448 .59336 .48124 .58675 .4687 Mtetra
.647 .631 .82 r
.58675 .4687 .59336 .48124 .60607 .47834 .59945 .46468 Mtetra
.638 .611 .806 r
.59945 .46468 .60607 .47834 .61885 .47567 .61222 .46092 Mtetra
.625 .59 .795 r
.61222 .46092 .61885 .47567 .6317 .47303 .62506 .45768 Mtetra
.61 .575 .79 r
.62506 .45768 .6317 .47303 .64461 .47011 .63799 .45514 Mtetra
.597 .574 .799 r
.63799 .45514 .64461 .47011 .65757 .46662 .65102 .45322 Mtetra
.596 .596 .822 r
.65102 .45322 .65757 .46662 .67057 .46256 .66413 .45137 Mtetra
.613 .644 .857 r
.66413 .45137 .67057 .46256 .68361 .45827 .67728 .44882 Mtetra
.643 .695 .884 r
.67728 .44882 .68361 .45827 .69672 .45395 .69046 .44516 Mtetra
.668 .723 .89 r
.69046 .44516 .69672 .45395 .70987 .44944 .70365 .44058 Mtetra
.685 .728 .883 r
.70365 .44058 .70987 .44944 .72306 .44465 .71686 .43533 Mtetra
.674 .714 .878 r
.71686 .43533 .72306 .44465 .73636 .4405 .73014 .43044 Mtetra
.535 .634 .895 r
.73014 .43044 .73636 .4405 .75001 .44061 .7438 .43021 Mtetra
.032 .317 .804 r
.7438 .43021 .75001 .44061 .76442 .44971 .75834 .44088 Mtetra
0 .027 .577 r
.75834 .44088 .76442 .44971 .77935 .46326 .77356 .45804 Mtetra
.137 .557 .925 r
.77356 .45804 .77935 .46326 .79351 .46466 .78797 .46197 Mtetra
.92 .934 .8 r
.78797 .46197 .79351 .46466 .80628 .44862 .80076 .44509 Mtetra
.951 .893 .736 r
.80076 .44509 .80628 .44862 .81871 .42919 .81308 .42336 Mtetra
.868 .862 .831 r
.81308 .42336 .81871 .42919 .83173 .4167 .82603 .40937 Mtetra
.738 .799 .901 r
.82603 .40937 .83173 .4167 .84531 .4099 .83962 .40204 Mtetra
.672 .761 .918 r
.83962 .40204 .84531 .4099 .85915 .40513 .85349 .39712 Mtetra
.658 .753 .92 r
.85349 .39712 .85915 .40513 .8731 .40074 .86749 .39269 Mtetra
.656 .752 .92 r
.86749 .39269 .8731 .40074 .88711 .39638 .88155 .38829 Mtetra
.656 .751 .92 r
.25611 .57479 .26359 .58132 .2749 .5778 .26744 .57124 Mtetra
.653 .751 .921 r
.26744 .57124 .2749 .5778 .28625 .57431 .27882 .56774 Mtetra
.633 .746 .93 r
.27882 .56774 .28625 .57431 .29762 .57129 .29021 .56477 Mtetra
.498 .702 .961 r
.29021 .56477 .29762 .57129 .30889 .57056 .30148 .56443 Mtetra
0 .258 .719 r
.30148 .56443 .30889 .57056 .31985 .57619 .31237 .57126 Mtetra
.792 .297 0 r
.31237 .57126 .31985 .57619 .3305 .58917 .3229 .5862 Mtetra
.642 .082 0 r
.3229 .5862 .3305 .58917 .34156 .59743 .33393 .59549 Mtetra
.879 .888 .836 r
.33393 .59549 .34156 .59743 .35376 .5857 .34628 .58197 Mtetra
.922 .792 .701 r
.34628 .58197 .35376 .5857 .36655 .56131 .35933 .55423 Mtetra
.871 .76 .737 r
.35933 .55423 .36655 .56131 .37897 .54328 .37191 .53405 Mtetra
.74 .714 .826 r
.37191 .53405 .37897 .54328 .39092 .53583 .3839 .52627 Mtetra
.626 .67 .872 r
.3839 .52627 .39092 .53583 .40273 .53291 .39573 .5235 Mtetra
.64 .679 .872 r
.39573 .5235 .40273 .53291 .41459 .53034 .40763 .52026 Mtetra
.682 .681 .843 r
.40763 .52026 .41459 .53034 .42653 .5271 .41965 .51521 Mtetra
.693 .654 .807 r
.41965 .51521 .42653 .5271 .43855 .52296 .43173 .50913 Mtetra
.675 .62 .786 r
.43173 .50913 .43855 .52296 .45064 .51774 .44385 .50344 Mtetra
.652 .604 .787 r
.44385 .50344 .45064 .51774 .46279 .51183 .45598 .49892 Mtetra
.636 .616 .813 r
.45598 .49892 .46279 .51183 .47497 .50597 .46814 .49544 Mtetra
.629 .655 .856 r
.46814 .49544 .47497 .50597 .48719 .50071 .48036 .49246 Mtetra
.626 .708 .905 r
.48036 .49246 .48719 .50071 .49945 .49614 .49263 .48954 Mtetra
.625 .757 .941 r
.49263 .48954 .49945 .49614 .51175 .49208 .50497 .48647 Mtetra
.625 .791 .962 r
.50497 .48647 .51175 .49208 .52411 .48827 .51737 .48317 Mtetra
.628 .811 .97 r
.51737 .48317 .52411 .48827 .53653 .48452 .52983 .47964 Mtetra
.634 .821 .972 r
.52983 .47964 .53653 .48452 .549 .48072 .54234 .4759 Mtetra
.641 .826 .972 r
.54234 .4759 .549 .48072 .56153 .47681 .55492 .47195 Mtetra
.649 .829 .969 r
.55492 .47195 .56153 .47681 .57411 .47278 .56755 .4678 Mtetra
.658 .828 .965 r
.56755 .4678 .57411 .47278 .58675 .4687 .58024 .46344 Mtetra
.668 .822 .957 r
.58024 .46344 .58675 .4687 .59945 .46468 .59297 .45885 Mtetra
.679 .807 .944 r
.59297 .45885 .59945 .46468 .61222 .46092 .60576 .45404 Mtetra
.685 .777 .921 r
.60576 .45404 .61222 .46092 .62506 .45768 .61859 .44906 Mtetra
.679 .727 .886 r
.61859 .44906 .62506 .45768 .63799 .45514 .63148 .44414 Mtetra
.659 .668 .847 r
.63148 .44414 .63799 .45514 .65102 .45322 .64444 .43972 Mtetra
.629 .612 .814 r
.64444 .43972 .65102 .45322 .66413 .45137 .6575 .43636 Mtetra
.6 .577 .799 r
.6575 .43636 .66413 .45137 .67728 .44882 .67068 .43421 Mtetra
.591 .578 .807 r
.67068 .43421 .67728 .44882 .69046 .44516 .68396 .43248 Mtetra
.616 .621 .833 r
.68396 .43248 .69046 .44516 .70365 .44058 .69727 .4297 Mtetra
.663 .676 .852 r
.69727 .4297 .70365 .44058 .71686 .43533 .71055 .42507 Mtetra
.675 .695 .86 r
.71055 .42507 .71686 .43533 .73014 .43044 .72386 .41997 Mtetra
.527 .621 .889 r
.72386 .41997 .73014 .43044 .7438 .43021 .73757 .42003 Mtetra
0 .226 .747 r
.73757 .42003 .7438 .43021 .75834 .44088 .75226 .43286 Mtetra
.568 .116 0 r
.75226 .43286 .75834 .44088 .77356 .45804 .76775 .45342 Mtetra
0 .442 .84 r
.76775 .45342 .77356 .45804 .78797 .46197 .78235 .45912 Mtetra
.929 .926 .785 r
.78235 .45912 .78797 .46197 .80076 .44509 .79513 .44108 Mtetra
.956 .876 .715 r
.79513 .44108 .80076 .44509 .81308 .42336 .80736 .41722 Mtetra
.88 .855 .812 r
.80736 .41722 .81308 .42336 .82603 .40937 .82027 .4019 Mtetra
.748 .8 .895 r
.82027 .4019 .82603 .40937 .83962 .40204 .83387 .39409 Mtetra
.675 .762 .916 r
.83387 .39409 .83962 .40204 .85349 .39712 .84779 .38905 Mtetra
.658 .753 .92 r
.84779 .38905 .85349 .39712 .86749 .39269 .86182 .38456 Mtetra
.656 .751 .92 r
.86182 .38456 .86749 .39269 .88155 .38829 .87594 .38012 Mtetra
.24857 .56821 .25611 .57479 .26744 .57124 .25993 .56463 Mtetra
.653 .751 .922 r
.25993 .56463 .26744 .57124 .27882 .56774 .27134 .56111 Mtetra
.629 .745 .931 r
.27134 .56111 .27882 .56774 .29021 .56477 .28275 .55819 Mtetra
.474 .692 .963 r
.28275 .55819 .29021 .56477 .30148 .56443 .29401 .55821 Mtetra
0 .17 .639 r
.29401 .55821 .30148 .56443 .31237 .57126 .30485 .56604 Mtetra
.821 .341 0 r
.30485 .56604 .31237 .57126 .3229 .5862 .31527 .58261 Mtetra
.673 .125 0 r
.31527 .58261 .3229 .5862 .33393 .59549 .32624 .59302 Mtetra
.881 .871 .823 r
.32624 .59302 .33393 .59549 .34628 .58197 .33871 .57873 Mtetra
.929 .792 .688 r
.33871 .57873 .34628 .58197 .35933 .55423 .35198 .54831 Mtetra
.894 .774 .723 r
.35198 .54831 .35933 .55423 .37191 .53405 .36478 .52514 Mtetra
.774 .728 .81 r
.36478 .52514 .37191 .53405 .3839 .52627 .3769 .51522 Mtetra
.666 .657 .831 r
.3769 .51522 .3839 .52627 .39573 .5235 .38881 .5107 Mtetra
.662 .628 .805 r
.38881 .5107 .39573 .5235 .40763 .52026 .40078 .50601 Mtetra
.66 .608 .785 r
.40078 .50601 .40763 .52026 .41965 .51521 .4128 .50108 Mtetra
.639 .6 .793 r
.4128 .50108 .41965 .51521 .43173 .50913 .42483 .4973 Mtetra
.617 .625 .836 r
.42483 .4973 .43173 .50913 .44385 .50344 .43688 .49471 Mtetra
.601 .685 .901 r
.43688 .49471 .44385 .50344 .45598 .49892 .44899 .49256 Mtetra
.59 .752 .955 r
.44899 .49256 .45598 .49892 .46814 .49544 .46117 .49028 Mtetra
.587 .793 .978 r
.46117 .49028 .46814 .49544 .48036 .49246 .47341 .48766 Mtetra
.596 .81 .982 r
.47341 .48766 .48036 .49246 .49263 .48954 .48573 .48472 Mtetra
.609 .814 .979 r
.48573 .48472 .49263 .48954 .50497 .48647 .49811 .48151 Mtetra
.621 .814 .975 r
.49811 .48151 .50497 .48647 .51737 .48317 .51055 .47808 Mtetra
.63 .814 .971 r
.51055 .47808 .51737 .48317 .52983 .47964 .52306 .47446 Mtetra
.638 .814 .967 r
.52306 .47446 .52983 .47964 .54234 .4759 .53562 .47066 Mtetra
.645 .815 .965 r
.53562 .47066 .54234 .4759 .55492 .47195 .54824 .46669 Mtetra
.651 .817 .963 r
.54824 .46669 .55492 .47195 .56755 .4678 .56092 .46254 Mtetra
.657 .82 .961 r
.56092 .46254 .56755 .4678 .58024 .46344 .57365 .45821 Mtetra
.664 .824 .96 r
.57365 .45821 .58024 .46344 .59297 .45885 .58644 .45368 Mtetra
.672 .829 .959 r
.58644 .45368 .59297 .45885 .60576 .45404 .59928 .44892 Mtetra
.68 .835 .957 r
.59928 .44892 .60576 .45404 .61859 .44906 .61216 .44388 Mtetra
.692 .837 .953 r
.61216 .44388 .61859 .44906 .63148 .44414 .62509 .43852 Mtetra
.703 .826 .941 r
.62509 .43852 .63148 .44414 .64444 .43972 .63805 .43284 Mtetra
.706 .788 .915 r
.63805 .43284 .64444 .43972 .6575 .43636 .65107 .42703 Mtetra
.687 .717 .873 r
.65107 .42703 .6575 .43636 .67068 .43421 .66414 .42165 Mtetra
.647 .638 .827 r
.66414 .42165 .67068 .43421 .68396 .43248 .67733 .41749 Mtetra
.616 .588 .799 r
.67733 .41749 .68396 .43248 .69727 .4297 .69064 .41451 Mtetra
.62 .588 .796 r
.69064 .41451 .69727 .4297 .71055 .42507 .70401 .41132 Mtetra
.626 .611 .816 r
.70401 .41132 .71055 .42507 .72386 .41997 .71745 .40796 Mtetra
.465 .557 .864 r
.71745 .40796 .72386 .41997 .73757 .42003 .73131 .41018 Mtetra
0 .094 .644 r
.73131 .41018 .73757 .42003 .75226 .43286 .74623 .42602 Mtetra
.689 .22 0 r
.74623 .42602 .75226 .43286 .76775 .45342 .76192 .44929 Mtetra
0 .378 .778 r
.76192 .44929 .76775 .45342 .78235 .45912 .77662 .45571 Mtetra
.935 .908 .77 r
.77662 .45571 .78235 .45912 .79513 .44108 .7894 .4364 Mtetra
.957 .858 .701 r
.7894 .4364 .79513 .44108 .80736 .41722 .80157 .41076 Mtetra
.888 .847 .797 r
.80157 .41076 .80736 .41722 .82027 .4019 .81445 .39431 Mtetra
.756 .801 .889 r
.81445 .39431 .82027 .4019 .83387 .39409 .82807 .38607 Mtetra
.677 .763 .916 r
.82807 .38607 .83387 .39409 .84779 .38905 .84203 .3809 Mtetra
.658 .753 .92 r
.84203 .3809 .84779 .38905 .86182 .38456 .85611 .37636 Mtetra
.656 .752 .92 r
.85611 .37636 .86182 .38456 .87594 .38012 .87028 .37188 Mtetra
.656 .751 .92 r
.24096 .56157 .24857 .56821 .25993 .56463 .25235 .55796 Mtetra
.652 .751 .922 r
.25235 .55796 .25993 .56463 .27134 .56111 .26379 .55443 Mtetra
.626 .744 .932 r
.26379 .55443 .27134 .56111 .28275 .55819 .27522 .55157 Mtetra
.45 .682 .964 r
.27522 .55157 .28275 .55819 .29401 .55821 .28649 .55192 Mtetra
0 .098 .568 r
.28649 .55192 .29401 .55821 .30485 .56604 .29726 .5606 Mtetra
.837 .368 .014 r
.29726 .5606 .30485 .56604 .31527 .58261 .3076 .57832 Mtetra
.685 .144 0 r
.3076 .57832 .31527 .58261 .32624 .59302 .31853 .58952 Mtetra
.872 .846 .816 r
.31853 .58952 .32624 .59302 .33871 .57873 .33106 .57517 Mtetra
.929 .785 .68 r
.33106 .57517 .33871 .57873 .35198 .54831 .34453 .54303 Mtetra
.909 .776 .702 r
.34453 .54303 .35198 .54831 .36478 .52514 .35761 .51588 Mtetra
.816 .729 .769 r
.35761 .51588 .36478 .52514 .3769 .51522 .36997 .50164 Mtetra
.685 .627 .785 r
.36997 .50164 .3769 .51522 .38881 .5107 .38197 .49545 Mtetra
.615 .574 .784 r
.38197 .49545 .38881 .5107 .40078 .50601 .39386 .4927 Mtetra
.58 .582 .82 r
.39386 .4927 .40078 .50601 .4128 .50108 .40576 .49151 Mtetra
.556 .646 .894 r
.40576 .49151 .4128 .50108 .42483 .4973 .41772 .49067 Mtetra
.542 .726 .959 r
.41772 .49067 .42483 .4973 .43688 .49471 .42977 .48942 Mtetra
.548 .775 .982 r
.42977 .48942 .43688 .49471 .44899 .49256 .4419 .48756 Mtetra
.573 .795 .983 r
.4419 .48756 .44899 .49256 .46117 .49028 .45412 .48512 Mtetra
.598 .799 .976 r
.45412 .48512 .46117 .49028 .47341 .48766 .46641 .48224 Mtetra
.617 .797 .968 r
.46641 .48224 .47341 .48766 .48573 .48472 .47877 .47903 Mtetra
.63 .792 .96 r
.47877 .47903 .48573 .48472 .49811 .48151 .4912 .47558 Mtetra
.638 .788 .954 r
.4912 .47558 .49811 .48151 .51055 .47808 .50368 .47195 Mtetra
.644 .784 .949 r
.50368 .47195 .51055 .47808 .52306 .47446 .51623 .46818 Mtetra
.649 .782 .945 r
.51623 .46818 .52306 .47446 .53562 .47066 .52883 .46429 Mtetra
.653 .781 .942 r
.52883 .46429 .53562 .47066 .54824 .46669 .5415 .46028 Mtetra
.656 .782 .941 r
.5415 .46028 .54824 .46669 .56092 .46254 .55422 .45616 Mtetra
.659 .785 .941 r
.55422 .45616 .56092 .46254 .57365 .45821 .567 .45191 Mtetra
.663 .79 .942 r
.567 .45191 .57365 .45821 .58644 .45368 .57983 .44754 Mtetra
.668 .798 .944 r
.57983 .44754 .58644 .45368 .59928 .44892 .59272 .443 Mtetra
.675 .808 .946 r
.59272 .443 .59928 .44892 .61216 .44388 .60566 .43819 Mtetra
.685 .82 .947 r
.60566 .43819 .61216 .44388 .62509 .43852 .61864 .43304 Mtetra
.7 .832 .946 r
.61864 .43304 .62509 .43852 .63805 .43284 .63166 .42741 Mtetra
.718 .839 .939 r
.63166 .42741 .63805 .43284 .65107 .42703 .64471 .42119 Mtetra
.735 .831 .924 r
.64471 .42119 .65107 .42703 .66414 .42165 .65779 .41436 Mtetra
.739 .789 .893 r
.65779 .41436 .66414 .42165 .67733 .41749 .67088 .40714 Mtetra
.712 .708 .845 r
.67088 .40714 .67733 .41749 .69064 .41451 .68403 .40028 Mtetra
.661 .622 .8 r
.68403 .40028 .69064 .41451 .70401 .41132 .69731 .39503 Mtetra
.588 .559 .789 r
.69731 .39503 .70401 .41132 .71745 .40796 .71085 .39333 Mtetra
.348 .442 .816 r
.71085 .39333 .71745 .40796 .73131 .41018 .72499 .39993 Mtetra
0 0 .525 r
.72499 .39993 .73131 .41018 .74623 .42602 .74018 .41981 Mtetra
.74 .27 0 r
.74018 .41981 .74623 .42602 .76192 .44929 .756 .4448 Mtetra
0 .393 .799 r
.756 .4448 .76192 .44929 .77662 .45571 .77074 .45119 Mtetra
.933 .881 .76 r
.77074 .45119 .77662 .45571 .7894 .4364 .78354 .43097 Mtetra
.956 .843 .692 r
.78354 .43097 .7894 .4364 .80157 .41076 .7957 .40405 Mtetra
.894 .841 .786 r
.7957 .40405 .80157 .41076 .81445 .39431 .80858 .38664 Mtetra
.764 .803 .884 r
.80858 .38664 .81445 .39431 .82807 .38607 .82222 .37798 Mtetra
.68 .764 .915 r
.82222 .37798 .82807 .38607 .84203 .3809 .83622 .37268 Mtetra
.659 .753 .92 r
.83622 .37268 .84203 .3809 .85611 .37636 .85035 .36809 Mtetra
.656 .752 .92 r
.85035 .36809 .85611 .37636 .87028 .37188 .86456 .36357 Mtetra
.655 .751 .92 r
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Mtetra
.652 .75 .922 r
.24472 .55124 .25235 .55796 .26379 .55443 .25618 .5477 Mtetra
.622 .743 .933 r
.25618 .5477 .26379 .55443 .27522 .55157 .26763 .54491 Mtetra
.422 .67 .965 r
.26763 .54491 .27522 .55157 .28649 .55192 .27889 .54561 Mtetra
.493 0 0 r
.27889 .54561 .28649 .55192 .29726 .5606 .28962 .55504 Mtetra
.845 .382 .031 r
.28962 .55504 .29726 .5606 .3076 .57832 .29989 .57341 Mtetra
.656 .115 0 r
.29989 .57341 .3076 .57832 .31853 .58952 .31083 .58446 Mtetra
.86 .81 .799 r
.31083 .58446 .31853 .58952 .33106 .57517 .32346 .56959 Mtetra
.916 .762 .675 r
.32346 .56959 .33106 .57517 .34453 .54303 .33709 .53637 Mtetra
.904 .756 .686 r
.33709 .53637 .34453 .54303 .35761 .51588 .35041 .50634 Mtetra
.833 .727 .747 r
.35041 .50634 .35761 .51588 .36997 .50164 .36295 .48929 Mtetra
.683 .644 .805 r
.36295 .48929 .36997 .50164 .38197 .49545 .37494 .4836 Mtetra
.534 .586 .853 r
.37494 .4836 .38197 .49545 .39386 .4927 .38673 .4837 Mtetra
.457 .616 .918 r
.38673 .4837 .39386 .4927 .40576 .49151 .39856 .48482 Mtetra
.463 .692 .966 r
.39856 .48482 .40576 .49151 .41772 .49067 .41052 .48491 Mtetra
.52 .748 .979 r
.41052 .48491 .41772 .49067 .42977 .48942 .42259 .48369 Mtetra
.573 .77 .972 r
.42259 .48369 .42977 .48942 .4419 .48756 .43477 .4815 Mtetra
.605 .771 .96 r
.43477 .4815 .4419 .48756 .45412 .48512 .44704 .47871 Mtetra
.623 .766 .948 r
.44704 .47871 .45412 .48512 .46641 .48224 .45937 .47557 Mtetra
.633 .762 .941 r
.45937 .47557 .46641 .48224 .47877 .47903 .47177 .47221 Mtetra
.639 .76 .936 r
.47177 .47221 .47877 .47903 .4912 .47558 .48423 .46868 Mtetra
.643 .76 .934 r
.48423 .46868 .4912 .47558 .50368 .47195 .49675 .46502 Mtetra
.647 .762 .933 r
.49675 .46502 .50368 .47195 .51623 .46818 .50934 .46124 Mtetra
.65 .763 .932 r
.50934 .46124 .51623 .46818 .52883 .46429 .52198 .45735 Mtetra
.654 .765 .931 r
.52198 .45735 .52883 .46429 .5415 .46028 .53468 .45333 Mtetra
.657 .767 .931 r
.53468 .45333 .5415 .46028 .55422 .45616 .54745 .44918 Mtetra
.661 .769 .929 r
.54745 .44918 .55422 .45616 .567 .45191 .56027 .44489 Mtetra
.666 .77 .927 r
.56027 .44489 .567 .45191 .57983 .44754 .57314 .44045 Mtetra
.67 .77 .925 r
.57314 .44045 .57983 .44754 .59272 .443 .58607 .43585 Mtetra
.675 .771 .923 r
.58607 .43585 .59272 .443 .60566 .43819 .59906 .4311 Mtetra
.68 .776 .923 r
.59906 .4311 .60566 .43819 .61864 .43304 .61209 .42613 Mtetra
.69 .785 .924 r
.61209 .42613 .61864 .43304 .63166 .42741 .62517 .42084 Mtetra
.707 .802 .924 r
.62517 .42084 .63166 .42741 .64471 .42119 .63829 .41496 Mtetra
.735 .82 .917 r
.63829 .41496 .64471 .42119 .65779 .41436 .65141 .40805 Mtetra
.768 .826 .898 r
.65141 .40805 .65779 .41436 .67088 .40714 .66452 .39977 Mtetra
.781 .8 .868 r
.66452 .39977 .67088 .40714 .68403 .40028 .6776 .39044 Mtetra
.741 .731 .842 r
.6776 .39044 .68403 .40028 .69731 .39503 .69076 .3822 Mtetra
.6 .615 .838 r
.69076 .3822 .69731 .39503 .71085 .39333 .70429 .37993 Mtetra
.199 .371 .81 r
.70429 .37993 .71085 .39333 .72499 .39993 .71861 .38934 Mtetra
0 0 .447 r
.71861 .38934 .72499 .39993 .74018 .41981 .73397 .41213 Mtetra
.713 .259 0 r
.73397 .41213 .74018 .41981 .756 .4448 .74986 .43815 Mtetra
.012 .426 .862 r
.74986 .43815 .756 .4448 .77074 .45119 .76469 .44502 Mtetra
.917 .847 .76 r
.76469 .44502 .77074 .45119 .78354 .43097 .77757 .42488 Mtetra
.952 .832 .687 r
.77757 .42488 .78354 .43097 .7957 .40405 .78977 .3972 Mtetra
.9 .839 .776 r
.78977 .3972 .7957 .40405 .80858 .38664 .80265 .37894 Mtetra
.772 .806 .88 r
.80265 .37894 .80858 .38664 .82222 .37798 .81631 .36984 Mtetra
.683 .766 .914 r
.81631 .36984 .82222 .37798 .83622 .37268 .83035 .36439 Mtetra
.659 .753 .92 r
.83035 .36439 .83622 .37268 .85035 .36809 .84454 .35974 Mtetra
.656 .752 .92 r
.84454 .35974 .85035 .36809 .86456 .36357 .8588 .35518 Mtetra
.655 .751 .92 r
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54447 Mtetra
.651 .75 .922 r
.23702 .54447 .24472 .55124 .25618 .5477 .24851 .54091 Mtetra
.617 .742 .935 r
.24851 .54091 .25618 .5477 .26763 .54491 .25998 .53821 Mtetra
.39 .655 .964 r
.25998 .53821 .26763 .54491 .27889 .54561 .27123 .5393 Mtetra
.55 .019 0 r
.27123 .5393 .27889 .54561 .28962 .55504 .2819 .54943 Mtetra
.846 .384 .033 r
.2819 .54943 .28962 .55504 .29989 .57341 .29215 .56791 Mtetra
.532 0 0 r
.29215 .56791 .29989 .57341 .31083 .58446 .30319 .57734 Mtetra
.854 .767 .765 r
.30319 .57734 .31083 .58446 .32346 .56959 .31602 .5603 Mtetra
.891 .726 .671 r
.31602 .5603 .32346 .56959 .33709 .53637 .32975 .52686 Mtetra
.879 .727 .689 r
.32975 .52686 .33709 .53637 .35041 .50634 .34306 .49856 Mtetra
.84 .758 .773 r
.34306 .49856 .35041 .50634 .36295 .48929 .35558 .48317 Mtetra
.708 .791 .916 r
.35558 .48317 .36295 .48929 .37494 .4836 .36759 .4777 Mtetra
.481 .727 .979 r
.36759 .4777 .37494 .4836 .38673 .4837 .37944 .47714 Mtetra
.422 .678 .969 r
.37944 .47714 .38673 .4837 .39856 .48482 .39131 .47774 Mtetra
.484 .69 .958 r
.39131 .47774 .39856 .48482 .41052 .48491 .4033 .4776 Mtetra
.548 .71 .947 r
.4033 .4776 .41052 .48491 .42259 .48369 .41541 .47634 Mtetra
.588 .725 .938 r
.41541 .47634 .42259 .48369 .43477 .4815 .42762 .4742 Mtetra
.611 .736 .934 r
.42762 .4742 .43477 .4815 .44704 .47871 .43991 .47146 Mtetra
.625 .743 .932 r
.43991 .47146 .44704 .47871 .45937 .47557 .45227 .46835 Mtetra
.634 .748 .93 r
.45227 .46835 .45937 .47557 .47177 .47221 .46471 .46498 Mtetra
.64 .75 .929 r
.46471 .46498 .47177 .47221 .48423 .46868 .4772 .46143 Mtetra
.644 .752 .928 r
.4772 .46143 .48423 .46868 .49675 .46502 .48976 .45773 Mtetra
.648 .753 .926 r
.48976 .45773 .49675 .46502 .50934 .46124 .50239 .4539 Mtetra
.652 .754 .924 r
.50239 .4539 .50934 .46124 .52198 .45735 .51507 .44994 Mtetra
.655 .754 .923 r
.51507 .44994 .52198 .45735 .53468 .45333 .52781 .44587 Mtetra
.658 .754 .921 r
.52781 .44587 .53468 .45333 .54745 .44918 .54061 .44169 Mtetra
.66 .755 .92 r
.54061 .44169 .54745 .44918 .56027 .44489 .55347 .43742 Mtetra
.663 .758 .921 r
.55347 .43742 .56027 .44489 .57314 .44045 .56639 .43305 Mtetra
.666 .762 .922 r
.56639 .43305 .57314 .44045 .58607 .43585 .57937 .42855 Mtetra
.673 .768 .922 r
.57937 .42855 .58607 .43585 .59906 .4311 .5924 .42382 Mtetra
.682 .773 .92 r
.5924 .42382 .59906 .4311 .61209 .42613 .60548 .41876 Mtetra
.695 .775 .913 r
.60548 .41876 .61209 .42613 .62517 .42084 .6186 .41323 Mtetra
.711 .774 .902 r
.6186 .41323 .62517 .42084 .63829 .41496 .63175 .40707 Mtetra
.73 .773 .887 r
.63175 .40707 .63829 .41496 .65141 .40805 .64492 .40007 Mtetra
.752 .778 .874 r
.64492 .40007 .65141 .40805 .66452 .39977 .65808 .39199 Mtetra
.768 .788 .869 r
.65808 .39199 .66452 .39977 .6776 .39044 .67124 .38316 Mtetra
.748 .798 .893 r
.67124 .38316 .6776 .39044 .69076 .3822 .68449 .3755 Mtetra
.585 .761 .963 r
.68449 .3755 .69076 .3822 .70429 .37993 .69805 .3729 Mtetra
0 .378 .835 r
.69805 .3729 .70429 .37993 .71861 .38934 .71229 .38052 Mtetra
0 0 .424 r
.71229 .38052 .71861 .38934 .73397 .41213 .72753 .40143 Mtetra
0 0 .371 r
.72753 .40143 .73397 .41213 .74986 .43815 .74341 .42761 Mtetra
.106 .379 .839 r
.74341 .42761 .74986 .43815 .76469 .44502 .75841 .43667 Mtetra
.883 .805 .768 r
.75841 .43667 .76469 .44502 .77757 .42488 .7715 .41816 Mtetra
.948 .823 .687 r
.7715 .41816 .77757 .42488 .78977 .3972 .78379 .39029 Mtetra
.905 .838 .768 r
.78379 .39029 .78977 .3972 .80265 .37894 .79668 .37122 Mtetra
.781 .81 .876 r
.79668 .37122 .80265 .37894 .81631 .36984 .81036 .36164 Mtetra
.686 .768 .913 r
.81036 .36164 .81631 .36984 .83035 .36439 .82444 .35603 Mtetra
.66 .754 .92 r
.82444 .35603 .83035 .36439 .84454 .35974 .83867 .35132 Mtetra
.656 .752 .92 r
.83867 .35132 .84454 .35974 .8588 .35518 .85298 .34671 Mtetra
.655 .751 .92 r
.21778 .54134 .22557 .54814 .23702 .54447 .22926 .53764 Mtetra
.65 .75 .923 r
.22926 .53764 .23702 .54447 .24851 .54091 .24078 .53408 Mtetra
.611 .74 .937 r
.24078 .53408 .24851 .54091 .25998 .53821 .25227 .53148 Mtetra
.353 .638 .962 r
.25227 .53148 .25998 .53821 .27123 .5393 .26349 .53298 Mtetra
.591 .061 0 r
.26349 .53298 .27123 .5393 .2819 .54943 .27412 .54369 Mtetra
.836 .368 .009 r
.27412 .54369 .2819 .54943 .29215 .56791 .2844 .56155 Mtetra
0 .315 .766 r
.2844 .56155 .29215 .56791 .30319 .57734 .29565 .56784 Mtetra
.849 .729 .731 r
.29565 .56784 .30319 .57734 .31602 .5603 .30873 .54764 Mtetra
.867 .698 .671 r
.30873 .54764 .31602 .5603 .32975 .52686 .32247 .51558 Mtetra
.847 .708 .709 r
.32247 .51558 .32975 .52686 .34306 .49856 .33551 .49305 Mtetra
.815 .815 .849 r
.33551 .49305 .34306 .49856 .35558 .48317 .34784 .48247 Mtetra
.637 .941 .959 r
.34784 .48247 .35558 .48317 .36759 .4777 .35992 .47689 Mtetra
.515 .897 .956 r
.35992 .47689 .36759 .4777 .37944 .47714 .37197 .47296 Mtetra
.553 .817 .995 r
.37197 .47296 .37944 .47714 .39131 .47774 .38401 .4705 Mtetra
.557 .717 .947 r
.38401 .4705 .39131 .47774 .4033 .4776 .39607 .46902 Mtetra
.567 .682 .917 r
.39607 .46902 .4033 .4776 .41541 .47634 .40821 .46759 Mtetra
.586 .686 .91 r
.40821 .46759 .41541 .47634 .42762 .4742 .42043 .46569 Mtetra
.605 .701 .912 r
.42043 .46569 .42762 .4742 .43991 .47146 .43274 .46324 Mtetra
.62 .715 .914 r
.43274 .46324 .43991 .47146 .45227 .46835 .44513 .46034 Mtetra
.63 .725 .916 r
.44513 .46034 .45227 .46835 .46471 .46498 .4576 .45709 Mtetra
.638 .732 .916 r
.4576 .45709 .46471 .46498 .4772 .46143 .47013 .45358 Mtetra
.644 .736 .916 r
.47013 .45358 .4772 .46143 .48976 .45773 .48272 .4499 Mtetra
.648 .739 .916 r
.48272 .4499 .48976 .45773 .50239 .4539 .49538 .44606 Mtetra
.652 .741 .915 r
.49538 .44606 .50239 .4539 .51507 .44994 .5081 .44209 Mtetra
.656 .743 .914 r
.5081 .44209 .51507 .44994 .52781 .44587 .52088 .43797 Mtetra
.66 .745 .913 r
.52088 .43797 .52781 .44587 .54061 .44169 .53372 .4337 Mtetra
.665 .744 .91 r
.53372 .4337 .54061 .44169 .55347 .43742 .54662 .42925 Mtetra
.669 .742 .905 r
.54662 .42925 .55347 .43742 .56639 .43305 .55957 .42462 Mtetra
.674 .738 .899 r
.55957 .42462 .56639 .43305 .57937 .42855 .57258 .41981 Mtetra
.677 .732 .892 r
.57258 .41981 .57937 .42855 .5924 .42382 .58565 .41483 Mtetra
.681 .728 .886 r
.58565 .41483 .5924 .42382 .60548 .41876 .59876 .40964 Mtetra
.689 .729 .881 r
.59876 .40964 .60548 .41876 .6186 .41323 .61192 .4041 Mtetra
.703 .734 .875 r
.61192 .4041 .6186 .41323 .63175 .40707 .62511 .39796 Mtetra
.718 .741 .869 r
.62511 .39796 .63175 .40707 .64492 .40007 .63833 .39113 Mtetra
.721 .747 .872 r
.63833 .39113 .64492 .40007 .65808 .39199 .65159 .3842 Mtetra
.701 .771 .906 r
.65159 .3842 .65808 .39199 .67124 .38316 .66494 .37831 Mtetra
.632 .843 .981 r
.66494 .37831 .67124 .38316 .68449 .3755 .67841 .37401 Mtetra
.37 .823 .934 r
.67841 .37401 .68449 .3755 .69805 .3729 .69204 .37142 Mtetra
0 .488 .734 r
.69204 .37142 .69805 .3729 .71229 .38052 .70605 .37399 Mtetra
0 .012 .518 r
.70605 .37399 .71229 .38052 .72753 .40143 .72093 .38885 Mtetra
0 0 .472 r
.72093 .38885 .72753 .40143 .74341 .42761 .73669 .41352 Mtetra
.1 .301 .778 r
.73669 .41352 .74341 .42761 .75841 .43667 .75192 .42581 Mtetra
.828 .752 .78 r
.75192 .42581 .75841 .43667 .7715 .41816 .76531 .41051 Mtetra
.938 .811 .693 r
.76531 .41051 .7715 .41816 .78379 .39029 .77773 .38322 Mtetra
.908 .835 .761 r
.77773 .38322 .78379 .39029 .79668 .37122 .79065 .36347 Mtetra
.79 .813 .871 r
.79065 .36347 .79668 .37122 .81036 .36164 .80435 .35339 Mtetra
.69 .77 .912 r
.80435 .35339 .81036 .36164 .82444 .35603 .81847 .3476 Mtetra
.661 .754 .919 r
.81847 .3476 .82444 .35603 .83867 .35132 .83275 .34282 Mtetra
.656 .752 .92 r
.83275 .34282 .83867 .35132 .85298 .34671 .84711 .33817 Mtetra
.655 .751 .92 r
.20992 .53449 .21778 .54134 .22926 .53764 .22143 .53076 Mtetra
.649 .75 .923 r
.22143 .53076 .22926 .53764 .24078 .53408 .23298 .52719 Mtetra
.605 .738 .939 r
.23298 .52719 .24078 .53408 .25227 .53148 .24448 .52471 Mtetra
.317 .621 .958 r
.24448 .52471 .25227 .53148 .26349 .53298 .2557 .52659 Mtetra
.605 .076 0 r
.2557 .52659 .26349 .53298 .27412 .54369 .2663 .53754 Mtetra
.805 .321 0 r
.2663 .53754 .27412 .54369 .2844 .56155 .27667 .55388 Mtetra
.311 .591 .943 r
.27667 .55388 .2844 .56155 .29565 .56784 .2882 .55631 Mtetra
.843 .705 .711 r
.2882 .55631 .29565 .56784 .30873 .54764 .30147 .53393 Mtetra
.852 .688 .678 r
.30147 .53393 .30873 .54764 .32247 .51558 .31509 .50498 Mtetra
.822 .714 .745 r
.31509 .50498 .32247 .51558 .33551 .49305 .32786 .4882 Mtetra
.731 .836 .929 r
.32786 .4882 .33551 .49305 .34784 .48247 .34 .48195 Mtetra
.51 .899 .947 r
.34 .48195 .34784 .48247 .35992 .47689 .35206 .47787 Mtetra
.524 .919 .885 r
.35206 .47787 .35992 .47689 .37197 .47296 .36424 .47239 Mtetra
.645 .947 .953 r
.36424 .47239 .37197 .47296 .38401 .4705 .37649 .46647 Mtetra
.666 .857 .973 r
.37649 .46647 .38401 .4705 .39607 .46902 .38873 .46179 Mtetra
.627 .745 .932 r
.38873 .46179 .39607 .46902 .40821 .46759 .40096 .45861 Mtetra
.604 .689 .902 r
.40096 .45861 .40821 .46759 .42043 .46569 .41323 .45619 Mtetra
.604 .677 .893 r
.41323 .45619 .42043 .46569 .43274 .46324 .42556 .45382 Mtetra
.612 .683 .892 r
.42556 .45382 .43274 .46324 .44513 .46034 .43797 .45116 Mtetra
.622 .694 .895 r
.43797 .45116 .44513 .46034 .4576 .45709 .45045 .44817 Mtetra
.631 .704 .899 r
.45045 .44817 .4576 .45709 .47013 .45358 .46301 .44491 Mtetra
.637 .714 .902 r
.46301 .44491 .47013 .45358 .48272 .4499 .47563 .4414 Mtetra
.643 .721 .905 r
.47563 .4414 .48272 .4499 .49538 .44606 .48832 .43768 Mtetra
.649 .727 .906 r
.48832 .43768 .49538 .44606 .5081 .44209 .50108 .43378 Mtetra
.653 .732 .907 r
.50108 .43378 .5081 .44209 .52088 .43797 .51389 .42971 Mtetra
.657 .735 .907 r
.51389 .42971 .52088 .43797 .53372 .4337 .52677 .42548 Mtetra
.662 .739 .907 r
.52677 .42548 .53372 .4337 .54662 .42925 .5397 .42109 Mtetra
.667 .744 .907 r
.5397 .42109 .54662 .42925 .55957 .42462 .5527 .4165 Mtetra
.676 .749 .905 r
.5527 .4165 .55957 .42462 .57258 .41981 .56575 .41158 Mtetra
.689 .751 .899 r
.56575 .41158 .57258 .41981 .58565 .41483 .57885 .40615 Mtetra
.701 .744 .885 r
.57885 .40615 .58565 .41483 .59876 .40964 .59198 .40016 Mtetra
.706 .728 .868 r
.59198 .40016 .59876 .40964 .61192 .4041 .60516 .39382 Mtetra
.695 .707 .857 r
.60516 .39382 .61192 .4041 .62511 .39796 .6184 .38775 Mtetra
.668 .7 .87 r
.6184 .38775 .62511 .39796 .63833 .39113 .63172 .38284 Mtetra
.621 .729 .924 r
.63172 .38284 .63833 .39113 .65159 .3842 .64516 .37956 Mtetra
.518 .807 .998 r
.64516 .37956 .65159 .3842 .66494 .37831 .65872 .37732 Mtetra
.356 .822 .909 r
.65872 .37732 .66494 .37831 .67841 .37401 .67234 .37442 Mtetra
.353 .828 .827 r
.67234 .37442 .67841 .37401 .69204 .37142 .68596 .37011 Mtetra
.301 .785 .907 r
.68596 .37011 .69204 .37142 .70605 .37399 .69978 .3681 Mtetra
0 .281 .743 r
.69978 .3681 .70605 .37399 .72093 .38885 .71433 .37694 Mtetra
0 0 .534 r
.71433 .37694 .72093 .38885 .73669 .41352 .72986 .39831 Mtetra
.046 .247 .745 r
.72986 .39831 .73669 .41352 .75192 .42581 .74523 .4128 Mtetra
.761 .698 .792 r
.74523 .4128 .75192 .42581 .76531 .41051 .75896 .40147 Mtetra
.919 .792 .704 r
.75896 .40147 .76531 .41051 .77773 .38322 .77159 .3757 Mtetra
.906 .827 .757 r
.77159 .3757 .77773 .38322 .79065 .36347 .78456 .35563 Mtetra
.797 .814 .865 r
.78456 .35563 .79065 .36347 .80435 .35339 .79829 .34508 Mtetra
.694 .772 .911 r
.79829 .34508 .80435 .35339 .81847 .3476 .81245 .33909 Mtetra
.661 .755 .919 r
.81245 .33909 .81847 .3476 .83275 .34282 .82677 .33424 Mtetra
.656 .752 .92 r
.82677 .33424 .83275 .34282 .84711 .33817 .84119 .32955 Mtetra
.655 .751 .921 r
.202 .52757 .20992 .53449 .22143 .53076 .21354 .52382 Mtetra
.648 .75 .923 r
.21354 .52382 .22143 .53076 .23298 .52719 .22511 .52025 Mtetra
.599 .737 .941 r
.22511 .52025 .23298 .52719 .24448 .52471 .23664 .51788 Mtetra
.294 .608 .954 r
.23664 .51788 .24448 .52471 .2557 .52659 .24784 .51999 Mtetra
.578 .051 0 r
.24784 .51999 .2557 .52659 .2663 .53754 .25847 .53067 Mtetra
.726 .222 0 r
.25847 .53067 .2663 .53754 .27667 .55388 .26898 .54474 Mtetra
.551 .662 .91 r
.26898 .54474 .27667 .55388 .2882 .55631 .28077 .54376 Mtetra
.836 .694 .707 r
.28077 .54376 .2882 .55631 .30147 .53393 .2941 .52131 Mtetra
.846 .696 .696 r
.2941 .52131 .30147 .53393 .31509 .50498 .30753 .49637 Mtetra
.813 .745 .789 r
.30753 .49637 .31509 .50498 .32786 .4882 .32013 .48326 Mtetra
.673 .826 .957 r
.32013 .48326 .32786 .4882 .34 .48195 .33222 .47867 Mtetra
.541 .845 .999 r
.33222 .47867 .34 .48195 .35206 .47787 .34425 .4759 Mtetra
.571 .894 .986 r
.34425 .4759 .35206 .47787 .36424 .47239 .35642 .47197 Mtetra
.615 .941 .95 r
.35642 .47197 .36424 .47239 .37649 .46647 .36871 .46635 Mtetra
.662 .959 .938 r
.36871 .46635 .37649 .46647 .38873 .46179 .38109 .45975 Mtetra
.701 .927 .966 r
.38109 .45975 .38873 .46179 .40096 .45861 .3935 .45351 Mtetra
.685 .83 .952 r
.3935 .45351 .40096 .45861 .41323 .45619 .4059 .44847 Mtetra
.65 .741 .916 r
.4059 .44847 .41323 .45619 .42556 .45382 .41831 .44459 Mtetra
.63 .696 .893 r
.41831 .44459 .42556 .45382 .43797 .45116 .43076 .44134 Mtetra
.625 .681 .883 r
.43076 .44134 .43797 .45116 .45045 .44817 .44328 .43822 Mtetra
.629 .681 .88 r
.44328 .43822 .45045 .44817 .46301 .44491 .45586 .43496 Mtetra
.636 .684 .879 r
.45586 .43496 .46301 .44491 .47563 .4414 .46851 .43147 Mtetra
.642 .688 .878 r
.46851 .43147 .47563 .4414 .48832 .43768 .48123 .42772 Mtetra
.649 .691 .876 r
.48123 .42772 .48832 .43768 .50108 .43378 .49401 .42373 Mtetra
.655 .692 .872 r
.49401 .42373 .50108 .43378 .51389 .42971 .50686 .41947 Mtetra
.661 .691 .867 r
.50686 .41947 .51389 .42971 .52677 .42548 .51976 .41495 Mtetra
.665 .687 .861 r
.51976 .41495 .52677 .42548 .5397 .42109 .53273 .4102 Mtetra
.668 .682 .854 r
.53273 .4102 .5397 .42109 .5527 .4165 .54575 .40527 Mtetra
.666 .675 .849 r
.54575 .40527 .5527 .4165 .56575 .41158 .55883 .40032 Mtetra
.662 .674 .851 r
.55883 .40032 .56575 .41158 .57885 .40615 .57196 .39556 Mtetra
.656 .686 .866 r
.57196 .39556 .57885 .40615 .59198 .40016 .58517 .39109 Mtetra
.648 .718 .9 r
.58517 .39109 .59198 .40016 .60516 .39382 .59844 .38702 Mtetra
.622 .774 .954 r
.59844 .38702 .60516 .39382 .6184 .38775 .61179 .38349 Mtetra
.537 .828 .999 r
.61179 .38349 .6184 .38775 .63172 .38284 .62524 .38072 Mtetra
.383 .817 .959 r
.62524 .38072 .63172 .38284 .64516 .37956 .63879 .37855 Mtetra
.335 .809 .905 r
.63879 .37855 .64516 .37956 .65872 .37732 .65241 .37592 Mtetra
.49 .888 .95 r
.65241 .37592 .65872 .37732 .67234 .37442 .66604 .3717 Mtetra
.639 .918 .978 r
.66604 .3717 .67234 .37442 .68596 .37011 .67967 .36604 Mtetra
.585 .859 .995 r
.67967 .36604 .68596 .37011 .69978 .3681 .69345 .36215 Mtetra
.075 .5 .898 r
.69345 .36215 .69978 .3681 .71433 .37694 .70781 .36707 Mtetra
0 .038 .591 r
.70781 .36707 .71433 .37694 .72986 .39831 .72308 .3842 Mtetra
0 .23 .742 r
.72308 .3842 .72986 .39831 .74523 .4128 .73843 .39868 Mtetra
.702 .658 .803 r
.73843 .39868 .74523 .4128 .75896 .40147 .75245 .39084 Mtetra
.893 .769 .718 r
.75245 .39084 .75896 .40147 .77159 .3757 .76533 .36739 Mtetra
.896 .813 .757 r
.76533 .36739 .77159 .3757 .78456 .35563 .77841 .34756 Mtetra
.801 .811 .86 r
.77841 .34756 .78456 .35563 .79829 .34508 .79217 .33668 Mtetra
.698 .773 .91 r
.79217 .33668 .79829 .34508 .81245 .33909 .80637 .33051 Mtetra
.662 .755 .919 r
.80637 .33051 .81245 .33909 .82677 .33424 .82074 .32559 Mtetra
.656 .752 .92 r
.82074 .32559 .82677 .33424 .84119 .32955 .83521 .32085 Mtetra
.655 .751 .921 r
.19402 .52061 .202 .52757 .21354 .52382 .20559 .51683 Mtetra
.647 .749 .924 r
.20559 .51683 .21354 .52382 .22511 .52025 .21719 .51325 Mtetra
.596 .735 .942 r
.21719 .51325 .22511 .52025 .23664 .51788 .22873 .51093 Mtetra
.295 .607 .953 r
.22873 .51093 .23664 .51788 .24784 .51999 .23995 .51304 Mtetra
.498 0 0 r
.23995 .51304 .24784 .51999 .25847 .53067 .25063 .52286 Mtetra
.557 .055 0 r
.25063 .52286 .25847 .53067 .26898 .54474 .26133 .53441 Mtetra
.628 .666 .868 r
.26133 .53441 .26898 .54474 .28077 .54376 .27329 .53129 Mtetra
.829 .695 .716 r
.27329 .53129 .28077 .54376 .2941 .52131 .28656 .51053 Mtetra
.845 .715 .72 r
.28656 .51053 .2941 .52131 .30753 .49637 .2998 .48939 Mtetra
.807 .781 .829 r
.2998 .48939 .30753 .49637 .32013 .48326 .31232 .4783 Mtetra
.67 .826 .959 r
.31232 .4783 .32013 .48326 .33222 .47867 .32445 .47374 Mtetra
.596 .81 .982 r
.32445 .47374 .33222 .47867 .34425 .4759 .33654 .47074 Mtetra
.612 .807 .975 r
.33654 .47074 .34425 .4759 .35642 .47197 .3487 .46748 Mtetra
.625 .834 .981 r
.3487 .46748 .35642 .47197 .36871 .46635 .36095 .46374 Mtetra
.624 .895 .987 r
.36095 .46374 .36871 .46635 .38109 .45975 .3733 .45922 Mtetra
.609 .939 .95 r
.3733 .45922 .38109 .45975 .3935 .45351 .38574 .45364 Mtetra
.622 .952 .927 r
.38574 .45364 .3935 .45351 .4059 .44847 .39825 .44733 Mtetra
.673 .946 .959 r
.39825 .44733 .4059 .44847 .41831 .44459 .41081 .44102 Mtetra
.696 .885 .968 r
.41081 .44102 .41831 .44459 .43076 .44134 .42339 .4353 Mtetra
.682 .804 .94 r
.42339 .4353 .43076 .44134 .44328 .43822 .43599 .43031 Mtetra
.664 .746 .911 r
.43599 .43031 .44328 .43822 .45586 .43496 .44863 .42589 Mtetra
.654 .713 .891 r
.44863 .42589 .45586 .43496 .46851 .43147 .46133 .42175 Mtetra
.651 .698 .88 r
.46133 .42175 .46851 .43147 .48123 .42772 .47408 .41767 Mtetra
.653 .692 .874 r
.47408 .41767 .48123 .42772 .49401 .42373 .48689 .41349 Mtetra
.656 .69 .87 r
.48689 .41349 .49401 .42373 .50686 .41947 .49977 .40914 Mtetra
.659 .69 .868 r
.49977 .40914 .50686 .41947 .51976 .41495 .5127 .40465 Mtetra
.661 .692 .868 r
.5127 .40465 .51976 .41495 .53273 .4102 .5257 .40006 Mtetra
.661 .697 .872 r
.5257 .40006 .53273 .4102 .54575 .40527 .53876 .39547 Mtetra
.658 .704 .881 r
.53876 .39547 .54575 .40527 .55883 .40032 .55187 .39103 Mtetra
.645 .711 .896 r
.55187 .39103 .55883 .40032 .57196 .39556 .56506 .38706 Mtetra
.607 .719 .924 r
.56506 .38706 .57196 .39556 .58517 .39109 .57833 .38419 Mtetra
.529 .735 .969 r
.57833 .38419 .58517 .39109 .59844 .38702 .5917 .38275 Mtetra
.394 .76 .993 r
.5917 .38275 .59844 .38702 .61179 .38349 .60519 .38206 Mtetra
.286 .773 .909 r
.60519 .38206 .61179 .38349 .62524 .38072 .61874 .38039 Mtetra
.392 .849 .886 r
.61874 .38039 .62524 .38072 .63879 .37855 .63231 .37647 Mtetra
.604 .922 .972 r
.63231 .37647 .63879 .37855 .65241 .37592 .64589 .37106 Mtetra
.677 .863 .97 r
.64589 .37106 .65241 .37592 .66604 .3717 .65952 .3655 Mtetra
.681 .822 .951 r
.65952 .3655 .66604 .3717 .67967 .36604 .67322 .36008 Mtetra
.62 .81 .973 r
.67322 .36008 .67967 .36604 .69345 .36215 .68706 .35619 Mtetra
.233 .609 .953 r
.68706 .35619 .69345 .36215 .70781 .36707 .70133 .35891 Mtetra
0 .147 .669 r
.70133 .35891 .70781 .36707 .72308 .3842 .71637 .37197 Mtetra
0 .261 .767 r
.71637 .37197 .72308 .3842 .73843 .39868 .7316 .38461 Mtetra
.664 .642 .818 r
.7316 .38461 .73843 .39868 .75245 .39084 .7458 .37893 Mtetra
.865 .748 .732 r
.7458 .37893 .75245 .39084 .76533 .36739 .75895 .35807 Mtetra
.88 .794 .761 r
.75895 .35807 .76533 .36739 .77841 .34756 .77217 .33908 Mtetra
.798 .802 .855 r
.77217 .33908 .77841 .34756 .79217 .33668 .78599 .32815 Mtetra
.7 .772 .908 r
.78599 .32815 .79217 .33668 .80637 .33051 .80023 .32185 Mtetra
.663 .755 .919 r
.80023 .32185 .80637 .33051 .82074 .32559 .81466 .31685 Mtetra
.656 .752 .92 r
.81466 .31685 .82074 .32559 .83521 .32085 .82917 .31207 Mtetra
.655 .751 .921 r
.18597 .51358 .19402 .52061 .20559 .51683 .19757 .50977 Mtetra
.647 .749 .924 r
.19757 .50977 .20559 .51683 .21719 .51325 .20919 .50617 Mtetra
.596 .735 .941 r
.20919 .50617 .21719 .51325 .22873 .51093 .22076 .50381 Mtetra
.326 .62 .956 r
.22076 .50381 .22873 .51093 .23995 .51304 .23203 .50561 Mtetra
0 .143 .633 r
.23203 .50561 .23995 .51304 .25063 .52286 .24281 .51414 Mtetra
0 .142 .658 r
.24281 .51414 .25063 .52286 .26133 .53441 .25368 .52341 Mtetra
.646 .661 .85 r
.25368 .52341 .26133 .53441 .27329 .53129 .2657 .51956 Mtetra
.821 .702 .733 r
.2657 .51956 .27329 .53129 .28656 .51053 .27885 .50135 Mtetra
.843 .738 .748 r
.27885 .50135 .28656 .51053 .2998 .48939 .29194 .48327 Mtetra
.802 .804 .853 r
.29194 .48327 .2998 .48939 .31232 .4783 .30445 .47317 Mtetra
.684 .825 .951 r
.30445 .47317 .31232 .4783 .32445 .47374 .31664 .46823 Mtetra
.628 .801 .966 r
.31664 .46823 .32445 .47374 .33654 .47074 .3288 .46471 Mtetra
.632 .786 .956 r
.3288 .46471 .33654 .47074 .3487 .46748 .34101 .46116 Mtetra
.641 .781 .948 r
.34101 .46116 .3487 .46748 .36095 .46374 .3533 .45742 Mtetra
.642 .782 .948 r
.3533 .45742 .36095 .46374 .3733 .45922 .36565 .45362 Mtetra
.635 .804 .964 r
.36565 .45362 .3733 .45922 .38574 .45364 .37805 .44986 Mtetra
.62 .86 .988 r
.37805 .44986 .38574 .45364 .39825 .44733 .39053 .44583 Mtetra
.578 .912 .974 r
.39053 .44583 .39825 .44733 .41081 .44102 .40308 .44123 Mtetra
.524 .916 .911 r
.40308 .44123 .41081 .44102 .42339 .4353 .41571 .43602 Mtetra
.513 .914 .884 r
.41571 .43602 .42339 .4353 .43599 .43031 .4284 .43046 Mtetra
.552 .928 .915 r
.4284 .43046 .43599 .43031 .44863 .42589 .44114 .42486 Mtetra
.602 .932 .959 r
.44114 .42486 .44863 .42589 .46133 .42175 .45393 .41942 Mtetra
.633 .913 .981 r
.45393 .41942 .46133 .42175 .47408 .41767 .46676 .41425 Mtetra
.643 .885 .985 r
.46676 .41425 .47408 .41767 .48689 .41349 .47964 .4094 Mtetra
.637 .863 .984 r
.47964 .4094 .48689 .41349 .49977 .40914 .49257 .40492 Mtetra
.616 .854 .988 r
.49257 .40492 .49977 .40914 .5127 .40465 .50556 .40087 Mtetra
.574 .855 .996 r
.50556 .40087 .5127 .40465 .5257 .40006 .51861 .39735 Mtetra
.493 .855 .99 r
.51861 .39735 .5257 .40006 .53876 .39547 .53173 .39437 Mtetra
.355 .818 .919 r
.53173 .39437 .53876 .39547 .55187 .39103 .54493 .39177 Mtetra
.207 .733 .767 r
.54493 .39177 .55187 .39103 .56506 .38706 .5582 .38901 Mtetra
0 0 0 r
.5582 .38901 .56506 .38706 .57833 .38419 .57154 .38525 Mtetra
.381 .843 .808 r
.57154 .38525 .57833 .38419 .5917 .38275 .58493 .38024 Mtetra
.616 .913 .981 r
.58493 .38024 .5917 .38275 .60519 .38206 .59837 .37503 Mtetra
.635 .778 .949 r
.59837 .37503 .60519 .38206 .61874 .38039 .6119 .37107 Mtetra
.607 .703 .912 r
.6119 .37107 .61874 .38039 .63231 .37647 .62554 .36816 Mtetra
.632 .741 .927 r
.62554 .36816 .63231 .37647 .64589 .37106 .63923 .36438 Mtetra
.677 .807 .945 r
.63923 .36438 .64589 .37106 .65952 .3655 .65293 .35911 Mtetra
.681 .818 .949 r
.65293 .35911 .65952 .3655 .67322 .36008 .66668 .35365 Mtetra
.614 .795 .968 r
.66668 .35365 .67322 .36008 .68706 .35619 .68059 .34997 Mtetra
.317 .654 .971 r
.68059 .34997 .68706 .35619 .70133 .35891 .69485 .35161 Mtetra
0 .274 .76 r
.69485 .35161 .70133 .35891 .71637 .37197 .70972 .3614 Mtetra
.035 .337 .818 r
.70972 .3614 .71637 .37197 .7316 .38461 .72479 .37126 Mtetra
.652 .649 .834 r
.72479 .37126 .7316 .38461 .7458 .37893 .73907 .36628 Mtetra
.841 .734 .746 r
.73907 .36628 .7458 .37893 .75895 .35807 .75244 .34775 Mtetra
.859 .775 .768 r
.75244 .34775 .75895 .35807 .77217 .33908 .76583 .33008 Mtetra
.788 .789 .853 r
.76583 .33008 .77217 .33908 .78599 .32815 .77974 .31942 Mtetra
.699 .769 .906 r
.77974 .31942 .78599 .32815 .80023 .32185 .79404 .31308 Mtetra
.663 .755 .918 r
.79404 .31308 .80023 .32185 .81466 .31685 .80852 .30804 Mtetra
.656 .752 .92 r
.80852 .30804 .81466 .31685 .82917 .31207 .82308 .3032 Mtetra
.655 .751 .921 r
.17785 .5065 .18597 .51358 .19757 .50977 .18948 .50266 Mtetra
.647 .749 .924 r
.18948 .50266 .19757 .50977 .20919 .50617 .20114 .49901 Mtetra
.601 .736 .939 r
.20114 .49901 .20919 .50617 .22076 .50381 .21274 .49651 Mtetra
.38 .642 .959 r
.21274 .49651 .22076 .50381 .23203 .50561 .22407 .4977 Mtetra
0 .285 .766 r
.22407 .4977 .23203 .50561 .24281 .51414 .23499 .50468 Mtetra
0 .292 .788 r
.23499 .50468 .24281 .51414 .25368 .52341 .24599 .51219 Mtetra
.635 .654 .851 r
.24599 .51219 .25368 .52341 .2657 .51956 .258 .5087 Mtetra
.811 .712 .756 r
.258 .5087 .2657 .51956 .27885 .50135 .27099 .49327 Mtetra
.839 .758 .773 r
.27099 .49327 .27885 .50135 .29194 .48327 .28398 .47747 Mtetra
.798 .814 .865 r
.28398 .47747 .29194 .48327 .30445 .47317 .29651 .46779 Mtetra
.7 .822 .94 r
.29651 .46779 .30445 .47317 .31664 .46823 .30877 .46238 Mtetra
.65 .798 .954 r
.30877 .46238 .31664 .46823 .3288 .46471 .321 .45835 Mtetra
.643 .781 .947 r
.321 .45835 .3288 .46471 .34101 .46116 .33327 .45453 Mtetra
.643 .774 .943 r
.33327 .45453 .34101 .46116 .3533 .45742 .34559 .45072 Mtetra
.647 .774 .941 r
.34559 .45072 .3533 .45742 .36565 .45362 .35798 .44681 Mtetra
.653 .773 .937 r
.35798 .44681 .36565 .45362 .37805 .44986 .37044 .4427 Mtetra
.653 .764 .931 r
.37044 .4427 .37805 .44986 .39053 .44583 .38295 .4386 Mtetra
.648 .761 .932 r
.38295 .4386 .39053 .44583 .40308 .44123 .39552 .43463 Mtetra
.642 .779 .947 r
.39552 .43463 .40308 .44123 .41571 .43602 .40814 .43075 Mtetra
.633 .82 .972 r
.40814 .43075 .41571 .43602 .4284 .43046 .42083 .4268 Mtetra
.615 .868 .99 r
.42083 .4268 .4284 .43046 .44114 .42486 .43359 .42264 Mtetra
.58 .899 .985 r
.43359 .42264 .44114 .42486 .45393 .41942 .44641 .41827 Mtetra
.528 .903 .958 r
.44641 .41827 .45393 .41942 .46676 .41425 .45929 .41386 Mtetra
.466 .885 .92 r
.45929 .41386 .46676 .41425 .47964 .4094 .47223 .40958 Mtetra
.399 .854 .876 r
.47223 .40958 .47964 .4094 .49257 .40492 .48523 .40553 Mtetra
.341 .821 .833 r
.48523 .40553 .49257 .40492 .50556 .40087 .49829 .40166 Mtetra
.321 .809 .814 r
.49829 .40166 .50556 .40087 .51861 .39735 .51142 .39779 Mtetra
.369 .838 .848 r
.51142 .39779 .51861 .39735 .53173 .39437 .52461 .3937 Mtetra
.475 .888 .927 r
.52461 .3937 .53173 .39437 .54493 .39177 .53787 .38931 Mtetra
.573 .897 .985 r
.53787 .38931 .54493 .39177 .5582 .38901 .55119 .38487 Mtetra
.612 .862 .99 r
.55119 .38487 .5582 .38901 .57154 .38525 .56458 .38062 Mtetra
.638 .856 .982 r
.56458 .38062 .57154 .38525 .58493 .38024 .57804 .37599 Mtetra
.682 .882 .973 r
.57804 .37599 .58493 .38024 .59837 .37503 .59153 .37017 Mtetra
.707 .87 .959 r
.59153 .37017 .59837 .37503 .6119 .37107 .60506 .36381 Mtetra
.672 .787 .935 r
.60506 .36381 .6119 .37107 .62554 .36816 .61868 .35875 Mtetra
.622 .71 .909 r
.61868 .35875 .62554 .36816 .63923 .36438 .63242 .35533 Mtetra
.627 .722 .915 r
.63242 .35533 .63923 .36438 .65293 .35911 .64623 .35169 Mtetra
.653 .779 .941 r
.64623 .35169 .65293 .35911 .66668 .35365 .66008 .34712 Mtetra
.605 .79 .969 r
.66008 .34712 .66668 .35365 .68059 .34997 .67404 .34362 Mtetra
.36 .677 .977 r
.67404 .34362 .68059 .34997 .69485 .35161 .68832 .34463 Mtetra
0 .392 .84 r
.68832 .34463 .69485 .35161 .70972 .3614 .70308 .35193 Mtetra
.142 .443 .877 r
.70308 .35193 .70972 .3614 .72479 .37126 .71799 .35879 Mtetra
.665 .671 .847 r
.71799 .35879 .72479 .37126 .73907 .36628 .73227 .35334 Mtetra
.823 .726 .758 r
.73227 .35334 .73907 .36628 .75244 .34775 .74583 .33663 Mtetra
.836 .758 .777 r
.74583 .33663 .75244 .34775 .76583 .33008 .75941 .32054 Mtetra
.774 .775 .854 r
.75941 .32054 .76583 .33008 .77974 .31942 .77342 .31047 Mtetra
.696 .764 .904 r
.77342 .31047 .77974 .31942 .79404 .31308 .78779 .30421 Mtetra
.663 .754 .918 r
.78779 .30421 .79404 .31308 .80852 .30804 .80232 .29914 Mtetra
.656 .752 .92 r
.80232 .29914 .80852 .30804 .82308 .3032 .81694 .29426 Mtetra
.655 .751 .921 r
.16967 .49935 .17785 .5065 .18948 .50266 .18132 .49548 Mtetra
.649 .75 .923 r
.18132 .49548 .18948 .50266 .20114 .49901 .19302 .49177 Mtetra
.611 .738 .936 r
.19302 .49177 .20114 .49901 .21274 .49651 .20467 .48902 Mtetra
.443 .668 .958 r
.20467 .48902 .21274 .49651 .22407 .4977 .21609 .48938 Mtetra
.041 .416 .863 r
.21609 .48938 .22407 .4977 .23499 .50468 .22715 .49472 Mtetra
.065 .382 .845 r
.22715 .49472 .23499 .50468 .24599 .51219 .23825 .50094 Mtetra
.604 .642 .861 r
.23825 .50094 .24599 .51219 .258 .5087 .25019 .49852 Mtetra
.794 .72 .783 r
.25019 .49852 .258 .5087 .27099 .49327 .26301 .48582 Mtetra
.832 .772 .795 r
.26301 .48582 .27099 .49327 .28398 .47747 .27593 .47176 Mtetra
.796 .818 .869 r
.27593 .47176 .28398 .47747 .29651 .46779 .2885 .4622 Mtetra
.714 .819 .93 r
.2885 .4622 .29651 .46779 .30877 .46238 .30084 .45631 Mtetra
.665 .796 .945 r
.30084 .45631 .30877 .46238 .321 .45835 .31313 .45188 Mtetra
.653 .782 .942 r
.31313 .45188 .321 .45835 .33327 .45453 .32545 .44778 Mtetra
.652 .774 .938 r
.32545 .44778 .33327 .45453 .34559 .45072 .33783 .44371 Mtetra
.65 .767 .934 r
.33783 .44371 .34559 .45072 .35798 .44681 .35026 .43968 Mtetra
.646 .764 .934 r
.35026 .43968 .35798 .44681 .37044 .4427 .36274 .43576 Mtetra
.649 .771 .938 r
.36274 .43576 .37044 .4427 .38295 .4386 .37529 .43173 Mtetra
.656 .776 .937 r
.37529 .43173 .38295 .4386 .39552 .43463 .38791 .42748 Mtetra
.662 .771 .93 r
.38791 .42748 .39552 .43463 .40814 .43075 .40059 .42305 Mtetra
.666 .757 .918 r
.40059 .42305 .40814 .43075 .42083 .4268 .41334 .41848 Mtetra
.666 .741 .907 r
.41334 .41848 .42083 .4268 .43359 .42264 .42614 .41389 Mtetra
.658 .729 .902 r
.42614 .41389 .43359 .42264 .44641 .41827 .439 .4095 Mtetra
.651 .727 .904 r
.439 .4095 .44641 .41827 .45929 .41386 .45191 .40533 Mtetra
.647 .733 .912 r
.45191 .40533 .45929 .41386 .47223 .40958 .46488 .40129 Mtetra
.645 .74 .918 r
.46488 .40129 .47223 .40958 .48523 .40553 .47791 .39726 Mtetra
.647 .742 .918 r
.47791 .39726 .48523 .40553 .49829 .40166 .49102 .39316 Mtetra
.651 .738 .913 r
.49102 .39316 .49829 .40166 .51142 .39779 .50418 .38892 Mtetra
.653 .73 .906 r
.50418 .38892 .51142 .39779 .52461 .3937 .51742 .38458 Mtetra
.654 .725 .901 r
.51742 .38458 .52461 .3937 .53787 .38931 .53071 .38019 Mtetra
.651 .725 .903 r
.53071 .38019 .53787 .38931 .55119 .38487 .54408 .37589 Mtetra
.64 .726 .91 r
.54408 .37589 .55119 .38487 .56458 .38062 .55751 .3719 Mtetra
.622 .726 .922 r
.55751 .3719 .56458 .38062 .57804 .37599 .57102 .36847 Mtetra
.635 .766 .942 r
.57102 .36847 .57804 .37599 .59153 .37017 .58459 .36451 Mtetra
.691 .842 .956 r
.58459 .36451 .59153 .37017 .60506 .36381 .5982 .35869 Mtetra
.715 .867 .953 r
.5982 .35869 .60506 .36381 .61868 .35875 .61184 .35206 Mtetra
.669 .807 .949 r
.61184 .35206 .61868 .35875 .63242 .35533 .62558 .34695 Mtetra
.621 .74 .932 r
.62558 .34695 .63242 .35533 .64623 .35169 .63944 .34339 Mtetra
.618 .742 .935 r
.63944 .34339 .64623 .35169 .66008 .34712 .65338 .33988 Mtetra
.583 .76 .963 r
.65338 .33988 .66008 .34712 .67404 .34362 .66743 .33706 Mtetra
.383 .685 .978 r
.66743 .33706 .67404 .34362 .68832 .34463 .68174 .33777 Mtetra
.089 .489 .898 r
.68174 .33777 .68832 .34463 .70308 .35193 .69642 .34309 Mtetra
.282 .554 .927 r
.69642 .34309 .70308 .35193 .71799 .35879 .71118 .34696 Mtetra
.692 .697 .85 r
.71118 .34696 .71799 .35879 .73227 .35334 .72543 .34031 Mtetra
.81 .722 .768 r
.72543 .34031 .73227 .35334 .74583 .33663 .73914 .32492 Mtetra
.813 .744 .788 r
.73914 .32492 .74583 .33663 .75941 .32054 .7529 .31055 Mtetra
.755 .76 .857 r
.7529 .31055 .75941 .32054 .77342 .31047 .76704 .3013 Mtetra
.689 .758 .904 r
.76704 .3013 .77342 .31047 .78779 .30421 .78147 .29523 Mtetra
.662 .753 .918 r
.78147 .29523 .78779 .30421 .80232 .29914 .79606 .29015 Mtetra
.656 .752 .92 r
.79606 .29015 .80232 .29914 .81694 .29426 .81073 .28523 Mtetra
.655 .751 .92 r
.16141 .49215 .16967 .49935 .18132 .49548 .1731 .48823 Mtetra
.65 .75 .922 r
.1731 .48823 .18132 .49548 .19302 .49177 .18483 .48444 Mtetra
.622 .741 .932 r
.18483 .48444 .19302 .49177 .20467 .48902 .19654 .48138 Mtetra
.504 .691 .952 r
.19654 .48138 .20467 .48902 .21609 .48938 .20807 .48079 Mtetra
.217 .518 .915 r
.20807 .48079 .21609 .48938 .22715 .49472 .21928 .48444 Mtetra
.164 .438 .871 r
.21928 .48444 .22715 .49472 .23825 .50094 .23046 .48967 Mtetra
.555 .622 .874 r
.23046 .48967 .23825 .50094 .25019 .49852 .24229 .48866 Mtetra
.767 .722 .811 r
.24229 .48866 .25019 .49852 .26301 .48582 .25494 .47864 Mtetra
.821 .78 .814 r
.25494 .47864 .26301 .48582 .27593 .47176 .2678 .46604 Mtetra
.796 .82 .871 r
.2678 .46604 .27593 .47176 .2885 .4622 .28043 .45648 Mtetra
.727 .818 .922 r
.28043 .45648 .2885 .4622 .30084 .45631 .29284 .4501 Mtetra
.679 .797 .937 r
.29284 .4501 .30084 .45631 .31313 .45188 .3052 .44525 Mtetra
.661 .781 .938 r
.3052 .44525 .31313 .45188 .32545 .44778 .31757 .44092 Mtetra
.654 .774 .937 r
.31757 .44092 .32545 .44778 .33783 .44371 .32998 .43676 Mtetra
.654 .772 .936 r
.32998 .43676 .33783 .44371 .35026 .43968 .34246 .43259 Mtetra
.657 .77 .932 r
.34246 .43259 .35026 .43968 .36274 .43576 .355 .42831 Mtetra
.657 .76 .926 r
.355 .42831 .36274 .43576 .37529 .43173 .36759 .42404 Mtetra
.653 .754 .923 r
.36759 .42404 .37529 .43173 .38791 .42748 .38024 .41986 Mtetra
.654 .757 .925 r
.38024 .41986 .38791 .42748 .40059 .42305 .39296 .41565 Mtetra
.658 .765 .929 r
.39296 .41565 .40059 .42305 .41334 .41848 .40573 .41128 Mtetra
.652 .77 .935 r
.40573 .41128 .41334 .41848 .42614 .41389 .41857 .40704 Mtetra
.644 .779 .946 r
.41857 .40704 .42614 .41389 .439 .4095 .43145 .40298 Mtetra
.648 .792 .951 r
.43145 .40298 .439 .4095 .45191 .40533 .44441 .39875 Mtetra
.658 .794 .947 r
.44441 .39875 .45191 .40533 .46488 .40129 .45744 .39423 Mtetra
.664 .782 .937 r
.45744 .39423 .46488 .40129 .47791 .39726 .47052 .38957 Mtetra
.674 .768 .922 r
.47052 .38957 .47791 .39726 .49102 .39316 .48368 .38458 Mtetra
.687 .75 .899 r
.48368 .38458 .49102 .39316 .50418 .38892 .4969 .37907 Mtetra
.685 .72 .875 r
.4969 .37907 .50418 .38892 .51742 .38458 .51017 .3734 Mtetra
.665 .685 .859 r
.51017 .3734 .51742 .38458 .53071 .38019 .5235 .36834 Mtetra
.648 .666 .853 r
.5235 .36834 .53071 .38019 .54408 .37589 .53688 .36387 Mtetra
.636 .658 .855 r
.53688 .36387 .54408 .37589 .55751 .3719 .55034 .35987 Mtetra
.611 .648 .862 r
.55034 .35987 .55751 .3719 .57102 .36847 .56388 .35682 Mtetra
.582 .643 .876 r
.56388 .35682 .57102 .36847 .58459 .36451 .57752 .35475 Mtetra
.614 .7 .906 r
.57752 .35475 .58459 .36451 .5982 .35869 .59122 .35152 Mtetra
.691 .8 .932 r
.59122 .35152 .5982 .35869 .61184 .35206 .60494 .34574 Mtetra
.699 .829 .945 r
.60494 .34574 .61184 .35206 .62558 .34695 .61871 .33964 Mtetra
.639 .781 .949 r
.61871 .33964 .62558 .34695 .63944 .34339 .63259 .33538 Mtetra
.598 .745 .946 r
.63259 .33538 .63944 .34339 .65338 .33988 .6466 .33232 Mtetra
.553 .74 .963 r
.6466 .33232 .65338 .33988 .66743 .33706 .66073 .33022 Mtetra
.392 .682 .976 r
.66073 .33022 .66743 .33706 .68174 .33777 .67509 .33089 Mtetra
.205 .569 .938 r
.67509 .33089 .68174 .33777 .69642 .34309 .68972 .33449 Mtetra
.428 .649 .951 r
.68972 .33449 .69642 .34309 .71118 .34696 .70435 .33539 Mtetra
.723 .716 .843 r
.70435 .33539 .71118 .34696 .72543 .34031 .71855 .32719 Mtetra
.798 .718 .776 r
.71855 .32719 .72543 .34031 .73914 .32492 .73238 .31286 Mtetra
.788 .732 .8 r
.73238 .31286 .73914 .32492 .7529 .31055 .74632 .30025 Mtetra
.734 .748 .864 r
.74632 .30025 .7529 .31055 .76704 .3013 .76059 .29196 Mtetra
.681 .752 .905 r
.76059 .29196 .76704 .3013 .78147 .29523 .7751 .28615 Mtetra
.66 .752 .918 r
.7751 .28615 .78147 .29523 .79606 .29015 .78974 .28107 Mtetra
.656 .751 .92 r
.78974 .28107 .79606 .29015 .81073 .28523 .80447 .27611 Mtetra
.655 .751 .92 r
.15309 .48488 .16141 .49215 .1731 .48823 .16481 .48093 Mtetra
.652 .75 .922 r
.16481 .48093 .1731 .48823 .18483 .48444 .17657 .47705 Mtetra
.634 .744 .928 r
.17657 .47705 .18483 .48444 .19654 .48138 .18834 .47366 Mtetra
.556 .71 .943 r
.18834 .47366 .19654 .48138 .20807 .48079 .19998 .47208 Mtetra
.357 .594 .935 r
.19998 .47208 .20807 .48079 .21928 .48444 .21136 .47403 Mtetra
.245 .484 .888 r
.21136 .47403 .21928 .48444 .23046 .48967 .22263 .47827 Mtetra
.494 .593 .882 r
.22263 .47827 .23046 .48967 .24229 .48866 .23434 .47873 Mtetra
.724 .713 .84 r
.23434 .47873 .24229 .48866 .25494 .47864 .24679 .47143 Mtetra
.804 .782 .832 r
.24679 .47143 .25494 .47864 .2678 .46604 .25959 .4603 Mtetra
.796 .82 .871 r
.25959 .4603 .2678 .46604 .28043 .45648 .27227 .45071 Mtetra
.739 .82 .914 r
.27227 .45071 .28043 .45648 .29284 .4501 .28477 .44383 Mtetra
.69 .799 .932 r
.28477 .44383 .29284 .4501 .3052 .44525 .29719 .43859 Mtetra
.669 .784 .935 r
.29719 .43859 .3052 .44525 .31757 .44092 .30961 .43399 Mtetra
.662 .775 .933 r
.30961 .43399 .31757 .44092 .32998 .43676 .32208 .42958 Mtetra
.656 .767 .931 r
.32208 .42958 .32998 .43676 .34246 .43259 .3346 .42531 Mtetra
.652 .765 .932 r
.3346 .42531 .34246 .43259 .355 .42831 .34717 .42114 Mtetra
.655 .77 .934 r
.34717 .42114 .355 .42831 .36759 .42404 .3598 .41688 Mtetra
.66 .772 .932 r
.3598 .41688 .36759 .42404 .38024 .41986 .3725 .41244 Mtetra
.668 .768 .925 r
.3725 .41244 .38024 .41986 .39296 .41565 .38527 .40774 Mtetra
.664 .755 .918 r
.38527 .40774 .39296 .41565 .40573 .41128 .39809 .40316 Mtetra
.651 .746 .919 r
.39809 .40316 .40573 .41128 .41857 .40704 .41096 .39896 Mtetra
.658 .75 .918 r
.41096 .39896 .41857 .40704 .43145 .40298 .4239 .39451 Mtetra
.679 .748 .903 r
.4239 .39451 .43145 .40298 .44441 .39875 .43692 .38932 Mtetra
.678 .725 .885 r
.43692 .38932 .44441 .39875 .45744 .39423 .44999 .38406 Mtetra
.667 .705 .876 r
.44999 .38406 .45744 .39423 .47052 .38957 .46312 .37913 Mtetra
.674 .703 .869 r
.46312 .37913 .47052 .38957 .48368 .38458 .47631 .37383 Mtetra
.688 .702 .858 r
.47631 .37383 .48368 .38458 .4969 .37907 .48956 .36787 Mtetra
.685 .693 .852 r
.48956 .36787 .4969 .37907 .51017 .3734 .50287 .36192 Mtetra
.663 .68 .856 r
.50287 .36192 .51017 .3734 .5235 .36834 .51623 .35688 Mtetra
.625 .665 .869 r
.51623 .35688 .5235 .36834 .53688 .36387 .52965 .35331 Mtetra
.624 .685 .887 r
.52965 .35331 .53688 .36387 .55034 .35987 .54314 .34979 Mtetra
.62 .695 .898 r
.54314 .34979 .55034 .35987 .56388 .35682 .55671 .3464 Mtetra
.575 .668 .902 r
.55671 .3464 .56388 .35682 .57752 .35475 .57038 .34439 Mtetra
.572 .669 .905 r
.57038 .34439 .57752 .35475 .59122 .35152 .58414 .34245 Mtetra
.643 .733 .914 r
.58414 .34245 .59122 .35152 .60494 .34574 .59794 .33821 Mtetra
.688 .792 .929 r
.59794 .33821 .60494 .34574 .61871 .33964 .61177 .33245 Mtetra
.651 .791 .949 r
.61177 .33245 .61871 .33964 .63259 .33538 .6257 .32778 Mtetra
.589 .756 .957 r
.6257 .32778 .63259 .33538 .6466 .33232 .63976 .3248 Mtetra
.524 .73 .968 r
.63976 .3248 .6466 .33232 .66073 .33022 .65396 .32326 Mtetra
.393 .682 .976 r
.65396 .32326 .66073 .33022 .67509 .33089 .66837 .32391 Mtetra
.32 .64 .966 r
.66837 .32391 .67509 .33089 .68972 .33449 .68295 .32575 Mtetra
.562 .715 .944 r
.68295 .32575 .68972 .33449 .70435 .33539 .69746 .32363 Mtetra
.749 .724 .829 r
.69746 .32363 .70435 .33539 .71855 .32719 .71161 .3139 Mtetra
.784 .712 .784 r
.71161 .3139 .71855 .32719 .73238 .31286 .72556 .30066 Mtetra
.762 .722 .815 r
.72556 .30066 .73238 .31286 .74632 .30025 .73968 .28984 Mtetra
.712 .74 .873 r
.73968 .28984 .74632 .30025 .76059 .29196 .75408 .28252 Mtetra
.673 .749 .908 r
.75408 .28252 .76059 .29196 .7751 .28615 .76867 .27698 Mtetra
.659 .751 .918 r
.76867 .27698 .7751 .28615 .78974 .28107 .78336 .27191 Mtetra
.656 .751 .92 r
.78336 .27191 .78974 .28107 .80447 .27611 .79815 .26691 Mtetra
.14469 .47755 .15309 .48488 .16481 .48093 .15645 .47357 Mtetra
.654 .751 .921 r
.15645 .47357 .16481 .48093 .17657 .47705 .16824 .4696 Mtetra
.643 .747 .924 r
.16824 .4696 .17657 .47705 .18834 .47366 .18007 .46593 Mtetra
.596 .726 .935 r
.18007 .46593 .18834 .47366 .19998 .47208 .19182 .46344 Mtetra
.466 .65 .939 r
.19182 .46344 .19998 .47208 .21136 .47403 .20338 .46369 Mtetra
.328 .534 .903 r
.20338 .46369 .21136 .47403 .22263 .47827 .21475 .4667 Mtetra
.438 .563 .883 r
.21475 .4667 .22263 .47827 .23434 .47873 .22636 .46833 Mtetra
.66 .686 .863 r
.22636 .46833 .23434 .47873 .24679 .47143 .2386 .46384 Mtetra
.777 .774 .851 r
.2386 .46384 .24679 .47143 .25959 .4603 .2513 .45448 Mtetra
.793 .82 .873 r
.2513 .45448 .25959 .4603 .27227 .45071 .26402 .44499 Mtetra
.751 .824 .908 r
.26402 .44499 .27227 .45071 .28477 .44383 .27661 .43759 Mtetra
.704 .804 .927 r
.27661 .43759 .28477 .44383 .29719 .43859 .2891 .43187 Mtetra
.677 .786 .932 r
.2891 .43187 .29719 .43859 .30961 .43399 .30158 .427 Mtetra
.664 .776 .933 r
.30158 .427 .30961 .43399 .32208 .42958 .3141 .4225 Mtetra
.661 .774 .933 r
.3141 .4225 .32208 .42958 .3346 .42531 .32666 .41806 Mtetra
.662 .77 .93 r
.32666 .41806 .3346 .42531 .34717 .42114 .33928 .41356 Mtetra
.66 .761 .925 r
.33928 .41356 .34717 .42114 .3598 .41688 .35196 .40912 Mtetra
.658 .757 .923 r
.35196 .40912 .3598 .41688 .3725 .41244 .3647 .40472 Mtetra
.659 .759 .924 r
.3647 .40472 .3725 .41244 .38527 .40774 .37749 .40028 Mtetra
.653 .766 .932 r
.37749 .40028 .38527 .40774 .39809 .40316 .39034 .39598 Mtetra
.652 .775 .939 r
.39034 .39598 .39809 .40316 .41096 .39896 .40325 .39167 Mtetra
.68 .781 .927 r
.40325 .39167 .41096 .39896 .4239 .39451 .41626 .38651 Mtetra
.692 .766 .908 r
.41626 .38651 .4239 .39451 .43692 .38932 .42933 .38086 Mtetra
.659 .744 .913 r
.42933 .38086 .43692 .38932 .44999 .38406 .44243 .37631 Mtetra
.626 .754 .939 r
.44243 .37631 .44999 .38406 .46312 .37913 .45557 .37268 Mtetra
.669 .807 .949 r
.45557 .37268 .46312 .37913 .47631 .37383 .4688 .36771 Mtetra
.733 .833 .926 r
.4688 .36771 .47631 .37383 .48956 .36787 .48213 .36063 Mtetra
.7 .795 .923 r
.48213 .36063 .48956 .36787 .50287 .36192 .49548 .35465 Mtetra
.623 .771 .951 r
.49548 .35465 .50287 .36192 .51623 .35688 .50888 .35093 Mtetra
.67 .827 .959 r
.50888 .35093 .51623 .35688 .52965 .35331 .52235 .34576 Mtetra
.67 .781 .932 r
.52235 .34576 .52965 .35331 .54314 .34979 .53589 .3407 Mtetra
.626 .724 .917 r
.53589 .3407 .54314 .34979 .55671 .3464 .5495 .33702 Mtetra
.562 .69 .926 r
.5495 .33702 .55671 .3464 .57038 .34439 .5632 .33516 Mtetra
.548 .689 .932 r
.5632 .33516 .57038 .34439 .58414 .34245 .57701 .3336 Mtetra
.623 .733 .925 r
.57701 .3336 .58414 .34245 .59794 .33821 .59086 .32992 Mtetra
.67 .767 .923 r
.59086 .32992 .59794 .33821 .61177 .33245 .60476 .32473 Mtetra
.643 .774 .943 r
.60476 .32473 .61177 .33245 .6257 .32778 .61874 .32033 Mtetra
.576 .757 .964 r
.61874 .32033 .6257 .32778 .63976 .3248 .63286 .31758 Mtetra
.499 .73 .976 r
.63286 .31758 .63976 .3248 .65396 .32326 .64713 .31639 Mtetra
.405 .693 .979 r
.64713 .31639 .65396 .32326 .66837 .32391 .66157 .31672 Mtetra
.449 .707 .977 r
.66157 .31672 .66837 .32391 .68295 .32575 .6761 .31643 Mtetra
.664 .746 .911 r
.6761 .31643 .68295 .32575 .69746 .32363 .69049 .31124 Mtetra
.761 .718 .813 r
.69049 .31124 .69746 .32363 .71161 .3139 .70462 .3004 Mtetra
.765 .703 .793 r
.70462 .3004 .71161 .3139 .72556 .30066 .71871 .28856 Mtetra
.735 .715 .833 r
.71871 .28856 .72556 .30066 .73968 .28984 .733 .2795 Mtetra
.692 .736 .884 r
.733 .2795 .73968 .28984 .75408 .28252 .74751 .27306 Mtetra
.665 .747 .911 r
.74751 .27306 .75408 .28252 .76867 .27698 .76217 .26773 Mtetra
.657 .751 .919 r
.76217 .26773 .76867 .27698 .78336 .27191 .77693 .26266 Mtetra
.656 .751 .92 r
.77693 .26266 .78336 .27191 .79815 .26691 .79176 .25762 Mtetra
.13623 .47016 .14469 .47755 .15645 .47357 .14801 .46614 Mtetra
.655 .751 .921 r
.14801 .46614 .15645 .47357 .16824 .4696 .15984 .46212 Mtetra
.65 .749 .922 r
.15984 .46212 .16824 .4696 .18007 .46593 .17172 .45823 Mtetra
.625 .737 .928 r
.17172 .45823 .18007 .46593 .19182 .46344 .18357 .455 Mtetra
.547 .691 .934 r
.18357 .455 .19182 .46344 .20338 .46369 .1953 .45366 Mtetra
.421 .593 .914 r
.1953 .45366 .20338 .46369 .21475 .4667 .20683 .45506 Mtetra
.412 .549 .883 r
.20683 .45506 .21475 .4667 .22636 .46833 .2184 .45714 Mtetra
.576 .639 .876 r
.2184 .45714 .22636 .46833 .2386 .46384 .23041 .45539 Mtetra
.728 .749 .869 r
.23041 .45539 .2386 .46384 .2513 .45448 .24295 .44837 Mtetra
.781 .814 .878 r
.24295 .44837 .2513 .45448 .26402 .44499 .25568 .43938 Mtetra
.762 .829 .904 r
.25568 .43938 .26402 .44499 .27661 .43759 .26835 .4315 Mtetra
.718 .812 .923 r
.26835 .4315 .27661 .43759 .2891 .43187 .28093 .42527 Mtetra
.688 .793 .93 r
.28093 .42527 .2891 .43187 .30158 .427 .29348 .42002 Mtetra
.673 .78 .93 r
.29348 .42002 .30158 .427 .3141 .4225 .30605 .41522 Mtetra
.663 .77 .929 r
.30605 .41522 .3141 .4225 .32666 .41806 .31865 .41067 Mtetra
.657 .767 .93 r
.31865 .41067 .32666 .41806 .33928 .41356 .33131 .40629 Mtetra
.66 .772 .932 r
.33131 .40629 .33928 .41356 .35196 .40912 .34402 .40182 Mtetra
.664 .773 .931 r
.34402 .40182 .35196 .40912 .3647 .40472 .35681 .3972 Mtetra
.668 .769 .926 r
.35681 .3972 .3647 .40472 .37749 .40028 .36966 .39242 Mtetra
.662 .759 .922 r
.36966 .39242 .37749 .40028 .39034 .39598 .38256 .38781 Mtetra
.666 .753 .915 r
.38256 .38781 .39034 .39598 .40325 .39167 .39553 .38305 Mtetra
.678 .746 .902 r
.39553 .38305 .40325 .39167 .41626 .38651 .40857 .37785 Mtetra
.674 .745 .904 r
.40857 .37785 .41626 .38651 .42933 .38086 .42166 .37275 Mtetra
.623 .744 .933 r
.42166 .37275 .42933 .38086 .44243 .37631 .43477 .3692 Mtetra
.598 .765 .959 r
.43477 .3692 .44243 .37631 .45557 .37268 .44794 .36611 Mtetra
.67 .805 .947 r
.44794 .36611 .45557 .37268 .4688 .36771 .46123 .36106 Mtetra
.772 .825 .894 r
.46123 .36106 .4688 .36771 .48213 .36063 .47463 .35225 Mtetra
.694 .764 .905 r
.47463 .35225 .48213 .36063 .49548 .35465 .48803 .34636 Mtetra
.013 .402 .853 r
.48803 .34636 .49548 .35465 .50888 .35093 .5014 .35291 Mtetra
.717 .986 .819 r
.5014 .35291 .50888 .35093 .52235 .34576 .51498 .34192 Mtetra
.754 .911 .945 r
.51498 .34192 .52235 .34576 .53589 .3407 .52857 .33382 Mtetra
.61 .783 .964 r
.52857 .33382 .53589 .3407 .5495 .33702 .54223 .33023 Mtetra
.544 .76 .977 r
.54223 .33023 .5495 .33702 .5632 .33516 .55598 .32805 Mtetra
.559 .758 .971 r
.55598 .32805 .5632 .33516 .57701 .3336 .56982 .32564 Mtetra
.634 .764 .941 r
.56982 .32564 .57701 .3336 .59086 .32992 .58371 .32152 Mtetra
.652 .759 .928 r
.58371 .32152 .59086 .32992 .60476 .32473 .59767 .31685 Mtetra
.622 .764 .947 r
.59767 .31685 .60476 .32473 .61874 .32033 .61172 .31299 Mtetra
.553 .753 .97 r
.61172 .31299 .61874 .32033 .63286 .31758 .62591 .31066 Mtetra
.481 .733 .982 r
.62591 .31066 .63286 .31758 .64713 .31639 .64023 .30961 Mtetra
.454 .725 .984 r
.64023 .30961 .64713 .31639 .66157 .31672 .65468 .30897 Mtetra
.587 .759 .96 r
.65468 .30897 .66157 .31672 .6761 .31643 .66913 .30588 Mtetra
.724 .741 .865 r
.66913 .30588 .6761 .31643 .69049 .31124 .68342 .29794 Mtetra
.756 .703 .802 r
.68342 .29794 .69049 .31124 .70462 .3004 .69759 .2869 Mtetra
.74 .695 .808 r
.69759 .2869 .70462 .3004 .71871 .28856 .71184 .27686 Mtetra
.708 .714 .854 r
.71184 .27686 .71871 .28856 .733 .2795 .72628 .26939 Mtetra
.676 .736 .896 r
.72628 .26939 .733 .2795 .74751 .27306 .74089 .26361 Mtetra
.66 .748 .915 r
.74089 .26361 .74751 .27306 .76217 .26773 .75562 .25841 Mtetra
.656 .751 .919 r
.75562 .25841 .76217 .26773 .77693 .26266 .77043 .25333 Mtetra
.656 .751 .92 r
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Mtetra
.12769 .46272 .13623 .47016 .14801 .46614 .1395 .45865 Mtetra
.1395 .45865 .14801 .46614 .15984 .46212 .15137 .45458 Mtetra
.653 .75 .921 r
.15137 .45458 .15984 .46212 .17172 .45823 .16328 .45055 Mtetra
.642 .744 .923 r
.16328 .45055 .17172 .45823 .18357 .455 .17522 .44682 Mtetra
.601 .719 .927 r
.17522 .44682 .18357 .455 .1953 .45366 .1871 .44417 Mtetra
.512 .651 .92 r
.1871 .44417 .1953 .45366 .20683 .45506 .19883 .4437 Mtetra
.437 .57 .89 r
.19883 .4437 .20683 .45506 .2184 .45714 .21045 .44516 Mtetra
.498 .588 .875 r
.21045 .44516 .2184 .45714 .23041 .45539 .22228 .44549 Mtetra
.647 .696 .881 r
.22228 .44549 .23041 .45539 .24295 .44837 .23458 .44144 Mtetra
.75 .793 .888 r
.23458 .44144 .24295 .44837 .25568 .43938 .24725 .43379 Mtetra
.766 .831 .902 r
.24725 .43379 .25568 .43938 .26835 .4315 .25999 .4257 Mtetra
.736 .825 .919 r
.25999 .4257 .26835 .4315 .28093 .42527 .27266 .41881 Mtetra
.7 .802 .928 r
.27266 .41881 .28093 .42527 .29348 .42002 .28528 .41312 Mtetra
.677 .785 .931 r
.28528 .41312 .29348 .42002 .30605 .41522 .2979 .40814 Mtetra
.67 .78 .932 r
.2979 .40814 .30605 .41522 .31865 .41067 .31056 .40336 Mtetra
.668 .774 .929 r
.31056 .40336 .31865 .41067 .33131 .40629 .32328 .39862 Mtetra
.663 .763 .925 r
.32328 .39862 .33131 .40629 .34402 .40182 .33604 .39401 Mtetra
.659 .76 .924 r
.33604 .39401 .34402 .40182 .35681 .3972 .34885 .3895 Mtetra
.658 .764 .927 r
.34885 .3895 .35681 .3972 .36966 .39242 .36173 .38499 Mtetra
.661 .773 .932 r
.36173 .38499 .36966 .39242 .38256 .38781 .37467 .38036 Mtetra
.669 .776 .93 r
.37467 .38036 .38256 .38781 .39553 .38305 .38768 .37548 Mtetra
.67 .774 .928 r
.38768 .37548 .39553 .38305 .40857 .37785 .40076 .37056 Mtetra
.651 .777 .941 r
.40076 .37056 .40857 .37785 .42166 .37275 .41387 .36615 Mtetra
.631 .793 .96 r
.41387 .36615 .42166 .37275 .43477 .3692 .42704 .36215 Mtetra
.668 .792 .94 r
.42704 .36215 .43477 .3692 .44794 .36611 .4403 .35717 Mtetra
.717 .756 .883 r
.4403 .35717 .44794 .36611 .46123 .36106 .45367 .35026 Mtetra
.738 .723 .838 r
.45367 .35026 .46123 .36106 .47463 .35225 .46711 .34167 Mtetra
.715 .721 .855 r
.46711 .34167 .47463 .35225 .48803 .34636 .48057 .3344 Mtetra
.427 .561 .887 r
.48057 .3344 .48803 .34636 .5014 .35291 .49398 .33636 Mtetra
.509 .527 .811 r
.49398 .33636 .5014 .35291 .51498 .34192 .50752 .33705 Mtetra
.651 .86 .979 r
.50752 .33705 .51498 .34192 .52857 .33382 .52118 .33193 Mtetra
.536 .9 .968 r
.52118 .33193 .52857 .33382 .54223 .33023 .5349 .32732 Mtetra
.556 .886 .988 r
.5349 .32732 .54223 .33023 .55598 .32805 .5487 .32304 Mtetra
.627 .852 .985 r
.5487 .32304 .55598 .32805 .56982 .32564 .56257 .3184 Mtetra
.654 .794 .95 r
.56257 .3184 .56982 .32564 .58371 .32152 .5765 .31359 Mtetra
.638 .77 .943 r
.5765 .31359 .58371 .32152 .59767 .31685 .59052 .30925 Mtetra
.593 .763 .96 r
.59052 .30925 .59767 .31685 .61172 .31299 .60464 .30605 Mtetra
.528 .756 .98 r
.60464 .30605 .61172 .31299 .62591 .31066 .61889 .30405 Mtetra
.495 .752 .987 r
.61889 .30405 .62591 .31066 .64023 .30961 .63325 .30255 Mtetra
.564 .771 .975 r
.63325 .30255 .64023 .30961 .65468 .30897 .64766 .29977 Mtetra
.692 .762 .905 r
.64766 .29977 .65468 .30897 .66913 .30588 .66202 .29351 Mtetra
.741 .714 .826 r
.66202 .29351 .66913 .30588 .68342 .29794 .67628 .28392 Mtetra
.735 .686 .803 r
.67628 .28392 .68342 .29794 .69759 .2869 .69055 .27392 Mtetra
.711 .693 .831 r
.69055 .27392 .69759 .2869 .71184 .27686 .70495 .26581 Mtetra
.684 .719 .876 r
.70495 .26581 .71184 .27686 .72628 .26939 .71952 .25955 Mtetra
.664 .741 .907 r
.71952 .25955 .72628 .26939 .74089 .26361 .73421 .25417 Mtetra
.657 .749 .918 r
.73421 .25417 .74089 .26361 .75562 .25841 .749 .24903 Mtetra
.656 .751 .92 r
.749 .24903 .75562 .25841 .77043 .25333 .76387 .24391 Mtetra
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Mtetra
.13092 .4511 .1395 .45865 .15137 .45458 .14282 .44699 Mtetra
.655 .751 .92 r
.14282 .44699 .15137 .45458 .16328 .45055 .15477 .44287 Mtetra
.651 .749 .921 r
.15477 .44287 .16328 .45055 .17522 .44682 .16677 .43886 Mtetra
.633 .737 .923 r
.16677 .43886 .17522 .44682 .1871 .44417 .17876 .43532 Mtetra
.584 .698 .921 r
.17876 .43532 .1871 .44417 .19883 .4437 .19069 .43311 Mtetra
.505 .623 .902 r
.19069 .43311 .19883 .4437 .21045 .44516 .20247 .43295 Mtetra
.473 .572 .874 r
.20247 .43295 .21045 .44516 .22228 .44549 .21425 .43383 Mtetra
.551 .622 .876 r
.21425 .43383 .22228 .44549 .23458 .44144 .2263 .43271 Mtetra
.678 .736 .894 r
.2263 .43271 .23458 .44144 .24725 .43379 .23878 .42765 Mtetra
.749 .817 .905 r
.23878 .42765 .24725 .43379 .25999 .4257 .25151 .42018 Mtetra
.748 .835 .918 r
.25151 .42018 .25999 .4257 .27266 .41881 .26427 .41284 Mtetra
.72 .821 .928 r
.26427 .41284 .27266 .41881 .28528 .41312 .27699 .40647 Mtetra
.694 .798 .93 r
.27699 .40647 .28528 .41312 .2979 .40814 .28969 .40094 Mtetra
.674 .779 .929 r
.28969 .40094 .2979 .40814 .31056 .40336 .30239 .396 Mtetra
.663 .773 .931 r
.30239 .396 .31056 .40336 .32328 .39862 .31514 .39136 Mtetra
.663 .777 .934 r
.31514 .39136 .32328 .39862 .33604 .39401 .32795 .38669 Mtetra
.666 .777 .932 r
.32795 .38669 .33604 .39401 .34885 .3895 .34081 .38193 Mtetra
.667 .772 .928 r
.34081 .38193 .34885 .3895 .36173 .38499 .35375 .37712 Mtetra
.669 .765 .922 r
.35375 .37712 .36173 .38499 .37467 .38036 .36674 .3722 Mtetra
.675 .76 .915 r
.36674 .3722 .37467 .38036 .38768 .37548 .3798 .36706 Mtetra
.663 .751 .915 r
.3798 .36706 .38768 .37548 .40076 .37056 .39291 .36228 Mtetra
.631 .745 .93 r
.39291 .36228 .40076 .37056 .41387 .36615 .40604 .35846 Mtetra
.622 .759 .944 r
.40604 .35846 .41387 .36615 .42704 .36215 .41924 .35481 Mtetra
.662 .783 .939 r
.41924 .35481 .42704 .36215 .4403 .35717 .43254 .35 Mtetra
.667 .791 .941 r
.43254 .35 .4403 .35717 .45367 .35026 .44591 .34502 Mtetra
.558 .814 .993 r
.44591 .34502 .45367 .35026 .46711 .34167 .4593 .34203 Mtetra
.243 .758 .809 r
.4593 .34203 .46711 .34167 .48057 .3344 .47277 .33927 Mtetra
0 0 0 r
.47277 .33927 .48057 .3344 .49398 .33636 .48636 .3335 Mtetra
.621 .909 .983 r
.48636 .3335 .49398 .33636 .50752 .33705 .5 .32816 Mtetra
.548 .703 .942 r
.5 .32816 .50752 .33705 .52118 .33193 .51369 .3264 Mtetra
.552 .808 .993 r
.51369 .3264 .52118 .33193 .5349 .32732 .52748 .3235 Mtetra
.644 .894 .984 r
.52748 .3235 .5349 .32732 .5487 .32304 .54134 .31802 Mtetra
.692 .873 .966 r
.54134 .31802 .5487 .32304 .56257 .3184 .55525 .31174 Mtetra
.669 .818 .955 r
.55525 .31174 .56257 .3184 .5765 .31359 .56924 .30637 Mtetra
.617 .785 .962 r
.56924 .30637 .5765 .31359 .59052 .30925 .58332 .30246 Mtetra
.564 .778 .979 r
.58332 .30246 .59052 .30925 .60464 .30605 .5975 .29962 Mtetra
.537 .778 .987 r
.5975 .29962 .60464 .30605 .61889 .30405 .61179 .2972 Mtetra
.585 .787 .976 r
.61179 .2972 .61889 .30405 .63325 .30255 .62614 .29386 Mtetra
.681 .772 .92 r
.62614 .29386 .63325 .30255 .64766 .29977 .64049 .28802 Mtetra
.728 .721 .844 r
.64049 .28802 .64766 .29977 .66202 .29351 .6548 .27948 Mtetra
.725 .682 .808 r
.6548 .27948 .66202 .29351 .67628 .28392 .66911 .27012 Mtetra
.707 .678 .82 r
.66911 .27012 .67628 .28392 .69055 .27392 .68351 .26198 Mtetra
.685 .703 .861 r
.68351 .26198 .69055 .27392 .70495 .26581 .69805 .25547 Mtetra
.667 .731 .897 r
.69805 .25547 .70495 .26581 .71952 .25955 .71272 .24992 Mtetra
.659 .746 .914 r
.71272 .24992 .71952 .25955 .73421 .25417 .72748 .24471 Mtetra
.656 .75 .919 r
.72748 .24471 .73421 .25417 .749 .24903 .74232 .23956 Mtetra
.656 .751 .92 r
.74232 .23956 .749 .24903 .76387 .24391 .75724 .2344 Mtetra
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Mtetra
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Mtetra
.1342 .43934 .14282 .44699 .15477 .44287 .14618 .43517 Mtetra
.655 .751 .92 r
.14618 .43517 .15477 .44287 .16677 .43886 .15822 .43101 Mtetra
.649 .746 .921 r
.15822 .43101 .16677 .43886 .17876 .43532 .1703 .42701 Mtetra
.628 .729 .92 r
.1703 .42701 .17876 .43532 .19069 .43311 .18237 .42359 Mtetra
.579 .682 .911 r
.18237 .42359 .19069 .43311 .20247 .43295 .19436 .4215 Mtetra
.518 .612 .885 r
.19436 .4215 .20247 .43295 .21425 .43383 .20626 .42115 Mtetra
.502 .58 .865 r
.20626 .42115 .21425 .43383 .2263 .43271 .21819 .42136 Mtetra
.572 .64 .879 r
.21819 .42136 .2263 .43271 .23878 .42765 .23039 .41956 Mtetra
.681 .755 .907 r
.23039 .41956 .23878 .42765 .25151 .42018 .24297 .41438 Mtetra
.74 .828 .919 r
.24297 .41438 .25151 .42018 .26427 .41284 .25575 .40727 Mtetra
.734 .836 .927 r
.25575 .40727 .26427 .41284 .27699 .40647 .26856 .40037 Mtetra
.708 .818 .934 r
.26856 .40037 .27699 .40647 .28969 .40094 .28134 .39435 Mtetra
.69 .802 .934 r
.28134 .39435 .28969 .40094 .30239 .396 .29413 .38886 Mtetra
.679 .785 .93 r
.29413 .38886 .30239 .396 .31514 .39136 .30695 .38369 Mtetra
.667 .769 .926 r
.30695 .38369 .31514 .39136 .32795 .38669 .3198 .37887 Mtetra
.66 .763 .926 r
.3198 .37887 .32795 .38669 .34081 .38193 .3327 .37425 Mtetra
.656 .767 .931 r
.3327 .37425 .34081 .38193 .35375 .37712 .34566 .36973 Mtetra
.659 .778 .936 r
.34566 .36973 .35375 .37712 .36674 .3722 .35868 .36507 Mtetra
.674 .79 .936 r
.35868 .36507 .36674 .3722 .3798 .36706 .37179 .35996 Mtetra
.676 .792 .936 r
.37179 .35996 .3798 .36706 .39291 .36228 .38495 .35474 Mtetra
.647 .773 .94 r
.38495 .35474 .39291 .36228 .40604 .35846 .39815 .35037 Mtetra
.621 .75 .939 r
.39815 .35037 .40604 .35846 .41924 .35481 .41138 .34673 Mtetra
.625 .753 .939 r
.41138 .34673 .41924 .35481 .43254 .35 .42469 .34298 Mtetra
.613 .78 .961 r
.42469 .34298 .43254 .35 .44591 .34502 .43808 .33936 Mtetra
.542 .797 .992 r
.43808 .33936 .44591 .34502 .4593 .34203 .45151 .33677 Mtetra
.528 .805 .997 r
.45151 .33677 .4593 .34203 .47277 .33927 .46502 .33424 Mtetra
.628 .849 .984 r
.46502 .33424 .47277 .33927 .48636 .3335 .47865 .32967 Mtetra
.636 .888 .986 r
.47865 .32967 .48636 .3335 .5 .32816 .49236 .32443 Mtetra
.505 .843 .997 r
.49236 .32443 .5 .32816 .51369 .3264 .50612 .3214 Mtetra
.557 .828 .996 r
.50612 .3214 .51369 .3264 .52748 .3235 .51996 .31812 Mtetra
.675 .858 .969 r
.51996 .31812 .52748 .3235 .54134 .31802 .53388 .31235 Mtetra
.709 .86 .954 r
.53388 .31235 .54134 .31802 .55525 .31174 .54786 .30565 Mtetra
.667 .837 .965 r
.54786 .30565 .55525 .31174 .56924 .30637 .56191 .30017 Mtetra
.609 .815 .979 r
.56191 .30017 .56924 .30637 .58332 .30246 .57604 .29614 Mtetra
.592 .806 .982 r
.57604 .29614 .58332 .30246 .5975 .29962 .59027 .29248 Mtetra
.631 .797 .962 r
.59027 .29248 .5975 .29962 .61179 .2972 .60456 .28806 Mtetra
.69 .764 .908 r
.60456 .28806 .61179 .2972 .62614 .29386 .61887 .28186 Mtetra
.716 .712 .845 r
.61887 .28186 .62614 .29386 .64049 .28802 .63319 .27385 Mtetra
.711 .674 .813 r
.63319 .27385 .64049 .28802 .6548 .27948 .64753 .26532 Mtetra
.696 .669 .819 r
.64753 .26532 .6548 .27948 .66911 .27012 .66195 .25765 Mtetra
.68 .691 .854 r
.66195 .25765 .66911 .27012 .68351 .26198 .67648 .25122 Mtetra
.667 .722 .89 r
.67648 .25122 .68351 .26198 .69805 .25547 .69113 .24563 Mtetra
.659 .742 .911 r
.69113 .24563 .69805 .25547 .71272 .24992 .70586 .24038 Mtetra
.656 .749 .918 r
.70586 .24038 .71272 .24992 .72748 .24471 .72068 .2352 Mtetra
.656 .751 .92 r
.72068 .2352 .72748 .24471 .74232 .23956 .73558 .23001 Mtetra
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .2248 Mtetra
.75056 .2248 .75724 .2344 .77224 .22921 .76561 .21955 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Mtetra
.1255 .43162 .1342 .43934 .14618 .43517 .13752 .42741 Mtetra
.13752 .42741 .14618 .43517 .15822 .43101 .14959 .42319 Mtetra
.654 .75 .92 r
.14959 .42319 .15822 .43101 .1703 .42701 .16172 .41899 Mtetra
.648 .744 .92 r
.16172 .41899 .1703 .42701 .18237 .42359 .17388 .41496 Mtetra
.628 .723 .916 r
.17388 .41496 .18237 .42359 .19436 .4215 .18604 .41148 Mtetra
.587 .676 .901 r
.18604 .41148 .19436 .4215 .20626 .42115 .19815 .40917 Mtetra
.538 .612 .875 r
.19815 .40917 .20626 .42115 .21819 .42136 .21018 .40831 Mtetra
.523 .585 .859 r
.21018 .40831 .21819 .42136 .23039 .41956 .22225 .40798 Mtetra
.571 .637 .878 r
.22225 .40798 .23039 .41956 .24297 .41438 .23454 .40618 Mtetra
.662 .75 .915 r
.23454 .40618 .24297 .41438 .25575 .40727 .24715 .40157 Mtetra
.726 .833 .931 r
.24715 .40157 .25575 .40727 .26856 .40037 .25999 .39492 Mtetra
.73 .841 .933 r
.25999 .39492 .26856 .40037 .28134 .39435 .27288 .38812 Mtetra
.703 .817 .935 r
.27288 .38812 .28134 .39435 .29413 .38886 .28575 .38217 Mtetra
.682 .801 .938 r
.28575 .38217 .29413 .38886 .30695 .38369 .29862 .37686 Mtetra
.675 .796 .939 r
.29862 .37686 .30695 .38369 .3198 .37887 .31153 .37176 Mtetra
.673 .789 .936 r
.31153 .37176 .3198 .37887 .3327 .37425 .3245 .36669 Mtetra
.67 .777 .93 r
.3245 .36669 .3327 .37425 .34566 .36973 .33752 .3617 Mtetra
.662 .763 .925 r
.33752 .3617 .34566 .36973 .35868 .36507 .35059 .35693 Mtetra
.664 .761 .922 r
.35059 .35693 .35868 .36507 .37179 .35996 .36372 .35207 Mtetra
.672 .772 .925 r
.36372 .35207 .37179 .35996 .38495 .35474 .37693 .34696 Mtetra
.668 .774 .929 r
.37693 .34696 .38495 .35474 .39815 .35037 .39019 .34193 Mtetra
.651 .752 .924 r
.39019 .34193 .39815 .35037 .41138 .34673 .4035 .33743 Mtetra
.635 .726 .914 r
.4035 .33743 .41138 .34673 .42469 .34298 .41685 .33342 Mtetra
.617 .714 .915 r
.41685 .33342 .42469 .34298 .43808 .33936 .43026 .32993 Mtetra
.59 .708 .925 r
.43026 .32993 .43808 .33936 .45151 .33677 .44373 .32716 Mtetra
.579 .699 .924 r
.44373 .32716 .45151 .33677 .46502 .33424 .45728 .3247 Mtetra
.592 .708 .924 r
.45728 .3247 .46502 .33424 .47865 .32967 .47092 .32184 Mtetra
.581 .751 .958 r
.47092 .32184 .47865 .32967 .49236 .32443 .48465 .31897 Mtetra
.533 .805 .996 r
.48465 .31897 .49236 .32443 .50612 .3214 .49846 .31629 Mtetra
.594 .841 .991 r
.49846 .31629 .50612 .3214 .51996 .31812 .51236 .31228 Mtetra
.698 .852 .956 r
.51236 .31228 .51996 .31812 .53388 .31235 .52635 .3059 Mtetra
.722 .842 .938 r
.52635 .3059 .53388 .31235 .54786 .30565 .54038 .29876 Mtetra
.69 .822 .946 r
.54038 .29876 .54786 .30565 .56191 .30017 .55448 .29267 Mtetra
.666 .798 .946 r
.55448 .29267 .56191 .30017 .57604 .29614 .56865 .28734 Mtetra
.678 .768 .919 r
.56865 .28734 .57604 .29614 .59027 .29248 .58288 .28159 Mtetra
.696 .726 .874 r
.58288 .28159 .59027 .29248 .60456 .28806 .59716 .27485 Mtetra
.699 .685 .833 r
.59716 .27485 .60456 .28806 .61887 .28186 .61147 .26732 Mtetra
.692 .661 .815 r
.61147 .26732 .61887 .28186 .63319 .27385 .62584 .25974 Mtetra
.681 .664 .826 r
.62584 .25974 .63319 .27385 .64753 .26532 .64027 .25284 Mtetra
.672 .689 .857 r
.64027 .25284 .64753 .26532 .66195 .25765 .65481 .24678 Mtetra
.664 .719 .89 r
.65481 .24678 .66195 .25765 .67648 .25122 .66944 .24128 Mtetra
.659 .74 .91 r
.66944 .24128 .67648 .25122 .69113 .24563 .68415 .23601 Mtetra
.656 .748 .918 r
.68415 .23601 .69113 .24563 .70586 .24038 .69895 .23081 Mtetra
.656 .751 .92 r
.69895 .23081 .70586 .24038 .72068 .2352 .71382 .2256 Mtetra
.71382 .2256 .72068 .2352 .73558 .23001 .72877 .22036 Mtetra
.72877 .22036 .73558 .23001 .75056 .2248 .7438 .2151 Mtetra
.7438 .2151 .75056 .2248 .76561 .21955 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42383 Mtetra
.11673 .42383 .1255 .43162 .13752 .42741 .12878 .41959 Mtetra
.12878 .41959 .13752 .42741 .14959 .42319 .14088 .41533 Mtetra
.655 .751 .92 r
.14088 .41533 .14959 .42319 .16172 .41899 .15304 .41105 Mtetra
.654 .75 .92 r
.15304 .41105 .16172 .41899 .17388 .41496 .16526 .40679 Mtetra
.649 .743 .918 r
.16526 .40679 .17388 .41496 .18604 .41148 .17752 .40266 Mtetra
.634 .723 .912 r
.17752 .40266 .18604 .41148 .19815 .40917 .18979 .39897 Mtetra
.603 .68 .896 r
.18979 .39897 .19815 .40917 .21018 .40831 .20203 .39617 Mtetra
.564 .623 .87 r
.20203 .39617 .21018 .40831 .22225 .40798 .21423 .39456 Mtetra
.541 .589 .852 r
.21423 .39456 .22225 .40798 .23454 .40618 .22644 .39368 Mtetra
.559 .616 .865 r
.22644 .39368 .23454 .40618 .24715 .40157 .23879 .3922 Mtetra
.622 .711 .909 r
.23879 .3922 .24715 .40157 .25999 .39492 .25139 .38874 Mtetra
.693 .817 .942 r
.25139 .38874 .25999 .39492 .27288 .38812 .26423 .3831 Mtetra
.723 .856 .945 r
.26423 .3831 .27288 .38812 .28575 .38217 .2772 .37645 Mtetra
.715 .836 .939 r
.2772 .37645 .28575 .38217 .29862 .37686 .2902 .37006 Mtetra
.69 .802 .934 r
.2902 .37006 .29862 .37686 .31153 .37176 .30319 .36445 Mtetra
.67 .784 .935 r
.30319 .36445 .31153 .37176 .3245 .36669 .3162 .35942 Mtetra
.663 .785 .939 r
.3162 .35942 .3245 .36669 .33752 .3617 .32925 .3546 Mtetra
.66 .79 .944 r
.32925 .3546 .33752 .3617 .35059 .35693 .34236 .34981 Mtetra
.658 .79 .945 r
.34236 .34981 .35059 .35693 .36372 .35207 .35553 .34506 Mtetra
.661 .795 .946 r
.35553 .34506 .36372 .35207 .37693 .34696 .36877 .34019 Mtetra
.663 .804 .95 r
.36877 .34019 .37693 .34696 .39019 .34193 .38208 .33522 Mtetra
.66 .806 .953 r
.38208 .33522 .39019 .34193 .4035 .33743 .39545 .33029 Mtetra
.651 .792 .95 r
.39545 .33029 .4035 .33743 .41685 .33342 .40888 .32564 Mtetra
.637 .771 .944 r
.40888 .32564 .41685 .33342 .43026 .32993 .42235 .32139 Mtetra
.62 .745 .935 r
.42235 .32139 .43026 .32993 .44373 .32716 .43589 .31766 Mtetra
.601 .713 .923 r
.43589 .31766 .44373 .32716 .45728 .3247 .44948 .31451 Mtetra
.581 .689 .915 r
.44948 .31451 .45728 .3247 .47092 .32184 .46315 .31198 Mtetra
.566 .692 .925 r
.46315 .31198 .47092 .32184 .48465 .31897 .4769 .30978 Mtetra
.592 .721 .934 r
.4769 .30978 .48465 .31897 .49846 .31629 .49075 .30679 Mtetra
.666 .743 .907 r
.49075 .30679 .49846 .31629 .51236 .31228 .50471 .3015 Mtetra
.709 .73 .867 r
.50471 .3015 .51236 .31228 .52635 .3059 .51873 .29422 Mtetra
.707 .712 .852 r
.51873 .29422 .52635 .3059 .54038 .29876 .53281 .28681 Mtetra
.689 .701 .856 r
.53281 .28681 .54038 .29876 .55448 .29267 .54694 .28016 Mtetra
.681 .688 .85 r
.54694 .28016 .55448 .29267 .56865 .28734 .56113 .27373 Mtetra
.68 .67 .833 r
.56113 .27373 .56865 .28734 .58288 .28159 .57538 .26706 Mtetra
.676 .654 .821 r
.57538 .26706 .58288 .28159 .59716 .27485 .58969 .26037 Mtetra
.671 .653 .824 r
.58969 .26037 .59716 .27485 .61147 .26732 .60406 .25391 Mtetra
.668 .67 .843 r
.60406 .25391 .61147 .26732 .62584 .25974 .61851 .24785 Mtetra
.664 .698 .871 r
.61851 .24785 .62584 .25974 .64027 .25284 .63304 .24222 Mtetra
.66 .724 .897 r
.63304 .24222 .64027 .25284 .65481 .24678 .64765 .23687 Mtetra
.657 .741 .912 r
.64765 .23687 .65481 .24678 .66944 .24128 .66234 .23162 Mtetra
.656 .749 .918 r
.66234 .23162 .66944 .24128 .68415 .23601 .67711 .2264 Mtetra
.656 .751 .92 r
.67711 .2264 .68415 .23601 .69895 .23081 .69196 .22117 Mtetra
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Mtetra
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42383 .10788 .41598 Mtetra
.10788 .41598 .11673 .42383 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Mtetra
.1321 .4074 .14088 .41533 .15304 .41105 .14429 .40308 Mtetra
.14429 .40308 .15304 .41105 .16526 .40679 .15655 .39874 Mtetra
.655 .75 .92 r
.15655 .39874 .16526 .40679 .17752 .40266 .16885 .39441 Mtetra
.651 .744 .918 r
.16885 .39441 .17752 .40266 .18979 .39897 .18121 .39015 Mtetra
.642 .728 .912 r
.18121 .39015 .18979 .39897 .20203 .39617 .1936 .38617 Mtetra
.621 .694 .896 r
.1936 .38617 .20203 .39617 .21423 .39456 .20599 .38276 Mtetra
.593 .645 .871 r
.20599 .38276 .21423 .39456 .22644 .39368 .21837 .38021 Mtetra
.568 .603 .848 r
.21837 .38021 .22644 .39368 .23879 .3922 .23075 .37846 Mtetra
.561 .596 .846 r
.23075 .37846 .23879 .3922 .25139 .38874 .24318 .37694 Mtetra
.583 .644 .876 r
.24318 .37694 .25139 .38874 .26423 .3831 .25577 .37464 Mtetra
.632 .741 .927 r
.25577 .37464 .26423 .3831 .2772 .37645 .26856 .37079 Mtetra
.679 .833 .958 r
.26856 .37079 .2772 .37645 .2902 .37006 .28153 .36541 Mtetra
.703 .868 .96 r
.28153 .36541 .2902 .37006 .30319 .36445 .29462 .35921 Mtetra
.704 .853 .953 r
.29462 .35921 .30319 .36445 .3162 .35942 .30775 .35301 Mtetra
.692 .818 .942 r
.30775 .35301 .3162 .35942 .32925 .3546 .32091 .34722 Mtetra
.678 .789 .933 r
.32091 .34722 .32925 .3546 .34236 .34981 .3341 .34188 Mtetra
.666 .772 .928 r
.3341 .34188 .34236 .34981 .35553 .34506 .34732 .33687 Mtetra
.659 .764 .927 r
.34732 .33687 .35553 .34506 .36877 .34019 .3606 .33206 Mtetra
.657 .766 .93 r
.3606 .33206 .36877 .34019 .38208 .33522 .37394 .32731 Mtetra
.656 .773 .935 r
.37394 .32731 .38208 .33522 .39545 .33029 .38735 .32254 Mtetra
.654 .778 .939 r
.38735 .32254 .39545 .33029 .40888 .32564 .40082 .31779 Mtetra
.648 .774 .941 r
.40082 .31779 .40888 .32564 .42235 .32139 .41435 .31321 Mtetra
.634 .762 .94 r
.41435 .31321 .42235 .32139 .43589 .31766 .42794 .30902 Mtetra
.615 .743 .937 r
.42794 .30902 .43589 .31766 .44948 .31451 .44159 .30537 Mtetra
.604 .727 .932 r
.44159 .30537 .44948 .31451 .46315 .31198 .45531 .30203 Mtetra
.625 .716 .912 r
.45531 .30203 .46315 .31198 .4769 .30978 .46913 .29813 Mtetra
.665 .695 .868 r
.46913 .29813 .4769 .30978 .49075 .30679 .48304 .29262 Mtetra
.685 .66 .82 r
.48304 .29262 .49075 .30679 .50471 .3015 .49703 .28559 Mtetra
.68 .635 .797 r
.49703 .28559 .50471 .3015 .51873 .29422 .51108 .27826 Mtetra
.668 .629 .801 r
.51108 .27826 .51873 .29422 .53281 .28681 .52518 .2716 Mtetra
.66 .636 .815 r
.52518 .2716 .53281 .28681 .54694 .28016 .53934 .26554 Mtetra
.659 .645 .825 r
.53934 .26554 .54694 .28016 .56113 .27373 .55356 .25968 Mtetra
.658 .654 .835 r
.55356 .25968 .56113 .27373 .57538 .26706 .56786 .25398 Mtetra
.657 .671 .852 r
.56786 .25398 .57538 .26706 .58969 .26037 .58222 .24845 Mtetra
.659 .695 .872 r
.58222 .24845 .58969 .26037 .60406 .25391 .59666 .24302 Mtetra
.659 .718 .892 r
.59666 .24302 .60406 .25391 .61851 .24785 .61118 .23768 Mtetra
.657 .735 .907 r
.61118 .23768 .61851 .24785 .63304 .24222 .62577 .23244 Mtetra
.656 .745 .915 r
.62577 .23244 .63304 .24222 .64765 .23687 .64044 .22721 Mtetra
.656 .75 .919 r
.64044 .22721 .64765 .23687 .66234 .23162 .65518 .22198 Mtetra
.656 .751 .92 r
.65518 .22198 .66234 .23162 .67711 .2264 .67001 .21672 Mtetra
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Mtetra
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19003 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Mtetra
.13546 .39504 .14429 .40308 .15655 .39874 .14775 .39066 Mtetra
.14775 .39066 .15655 .39874 .16885 .39441 .16009 .38626 Mtetra
.655 .75 .92 r
.16009 .38626 .16885 .39441 .18121 .39015 .1725 .38185 Mtetra
.653 .747 .918 r
.1725 .38185 .18121 .39015 .1936 .38617 .18496 .37747 Mtetra
.649 .736 .913 r
.18496 .37747 .1936 .38617 .20599 .38276 .19746 .37321 Mtetra
.638 .713 .902 r
.19746 .37321 .20599 .38276 .21837 .38021 .21 .36924 Mtetra
.621 .676 .881 r
.21 .36924 .21837 .38021 .23075 .37846 .22255 .36576 Mtetra
.601 .634 .856 r
.22255 .36576 .23075 .37846 .24318 .37694 .23512 .36285 Mtetra
.585 .604 .838 r
.23512 .36285 .24318 .37694 .25577 .37464 .24772 .36044 Mtetra
.58 .601 .838 r
.24772 .36044 .25577 .37464 .26856 .37079 .26039 .3582 Mtetra
.591 .635 .863 r
.26039 .3582 .26856 .37079 .28153 .36541 .27316 .35559 Mtetra
.617 .706 .908 r
.27316 .35559 .28153 .36541 .29462 .35921 .28607 .35214 Mtetra
.645 .788 .951 r
.28607 .35214 .29462 .35921 .30775 .35301 .29913 .34773 Mtetra
.661 .846 .971 r
.29913 .34773 .30775 .35301 .32091 .34722 .3123 .34262 Mtetra
.667 .868 .975 r
.3123 .34262 .32091 .34722 .3341 .34188 .32555 .33717 Mtetra
.667 .866 .975 r
.32555 .33717 .3341 .34188 .34732 .33687 .33885 .33171 Mtetra
.664 .853 .972 r
.33885 .33171 .34732 .33687 .3606 .33206 .35221 .3264 Mtetra
.657 .838 .97 r
.35221 .3264 .3606 .33206 .37394 .32731 .36562 .32133 Mtetra
.649 .828 .969 r
.36562 .32133 .37394 .32731 .38735 .32254 .37908 .31647 Mtetra
.641 .824 .971 r
.37908 .31647 .38735 .32254 .40082 .31779 .3926 .31179 Mtetra
.636 .826 .974 r
.3926 .31179 .40082 .31779 .41435 .31321 .40619 .3072 Mtetra
.639 .828 .973 r
.40619 .3072 .41435 .31321 .42794 .30902 .41985 .30251 Mtetra
.657 .82 .962 r
.41985 .30251 .42794 .30902 .44159 .30537 .43359 .29743 Mtetra
.685 .789 .929 r
.43359 .29743 .44159 .30537 .45531 .30203 .44741 .29157 Mtetra
.7 .733 .877 r
.44741 .29157 .45531 .30203 .46913 .29813 .46132 .28483 Mtetra
.692 .678 .831 r
.46132 .28483 .46913 .29813 .48304 .29262 .47529 .27765 Mtetra
.677 .646 .812 r
.47529 .27765 .48304 .29262 .49703 .28559 .48931 .2708 Mtetra
.662 .643 .82 r
.48931 .2708 .49703 .28559 .51108 .27826 .50337 .26473 Mtetra
.655 .661 .843 r
.50337 .26473 .51108 .27826 .52518 .2716 .5175 .25927 Mtetra
.655 .683 .865 r
.5175 .25927 .52518 .2716 .53934 .26554 .5317 .254 Mtetra
.655 .7 .879 r
.5317 .254 .53934 .26554 .55356 .25968 .54597 .24879 Mtetra
.655 .715 .892 r
.54597 .24879 .55356 .25968 .56786 .25398 .56031 .24363 Mtetra
.656 .729 .903 r
.56031 .24363 .56786 .25398 .58222 .24845 .57473 .23845 Mtetra
.657 .739 .91 r
.57473 .23845 .58222 .24845 .59666 .24302 .58922 .23323 Mtetra
.656 .745 .915 r
.58922 .23323 .59666 .24302 .61118 .23768 .60379 .22801 Mtetra
.656 .749 .918 r
.60379 .22801 .61118 .23768 .62577 .23244 .61843 .22279 Mtetra
.656 .751 .92 r
.61843 .22279 .62577 .23244 .64044 .22721 .63316 .21753 Mtetra
.63316 .21753 .64044 .22721 .65518 .22198 .64796 .21225 Mtetra
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Mtetra
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19003 .73842 .17999 Mtetra
.06583 .40873 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Mtetra
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Mtetra
.13887 .38251 .14775 .39066 .16009 .38626 .15125 .37807 Mtetra
.15125 .37807 .16009 .38626 .1725 .38185 .16369 .37361 Mtetra
.16369 .37361 .1725 .38185 .18496 .37747 .17619 .36913 Mtetra
.655 .749 .919 r
.17619 .36913 .18496 .37747 .19746 .37321 .18875 .36464 Mtetra
.653 .744 .916 r
.18875 .36464 .19746 .37321 .21 .36924 .20137 .36018 Mtetra
.649 .732 .909 r
.20137 .36018 .21 .36924 .22255 .36576 .21403 .35582 Mtetra
.641 .709 .896 r
.21403 .35582 .22255 .36576 .23512 .36285 .22674 .35166 Mtetra
.63 .678 .877 r
.22674 .35166 .23512 .36285 .24772 .36044 .23949 .34778 Mtetra
.619 .646 .855 r
.23949 .34778 .24772 .36044 .26039 .3582 .25228 .34417 Mtetra
.61 .619 .836 r
.25228 .34417 .26039 .3582 .27316 .35559 .26512 .3408 Mtetra
.604 .605 .826 r
.26512 .3408 .27316 .35559 .28607 .35214 .27803 .33757 Mtetra
.604 .61 .83 r
.27803 .33757 .28607 .35214 .29913 .34773 .29101 .33433 Mtetra
.613 .634 .848 r
.29101 .33433 .29913 .34773 .3123 .34262 .30408 .33083 Mtetra
.626 .67 .873 r
.30408 .33083 .3123 .34262 .32555 .33717 .31725 .32695 Mtetra
.64 .71 .898 r
.31725 .32695 .32555 .33717 .33885 .33171 .33052 .32264 Mtetra
.651 .743 .917 r
.33052 .32264 .33885 .33171 .35221 .3264 .34388 .31799 Mtetra
.66 .764 .927 r
.34388 .31799 .35221 .3264 .36562 .32133 .35732 .31304 Mtetra
.666 .77 .927 r
.35732 .31304 .36562 .32133 .37908 .31647 .37084 .30787 Mtetra
.673 .765 .92 r
.37084 .30787 .37908 .31647 .3926 .31179 .38444 .30245 Mtetra
.68 .75 .904 r
.38444 .30245 .3926 .31179 .40619 .3072 .39811 .29672 Mtetra
.685 .726 .882 r
.39811 .29672 .40619 .3072 .41985 .30251 .41185 .29062 Mtetra
.685 .699 .857 r
.41185 .29062 .41985 .30251 .43359 .29743 .42567 .28418 Mtetra
.68 .674 .837 r
.42567 .28418 .43359 .29743 .44741 .29157 .43954 .27763 Mtetra
.672 .66 .829 r
.43954 .27763 .44741 .29157 .46132 .28483 .45347 .27129 Mtetra
.665 .664 .839 r
.45347 .27129 .46132 .28483 .47529 .27765 .46745 .26539 Mtetra
.66 .685 .863 r
.46745 .26539 .47529 .27765 .48931 .2708 .48148 .25993 Mtetra
.658 .714 .89 r
.48148 .25993 .48931 .2708 .50337 .26473 .49558 .25469 Mtetra
.659 .735 .906 r
.49558 .25469 .50337 .26473 .5175 .25927 .50975 .24946 Mtetra
.658 .741 .911 r
.50975 .24946 .5175 .25927 .5317 .254 .52399 .24427 Mtetra
.655 .743 .915 r
.52399 .24427 .5317 .254 .54597 .24879 .53831 .23916 Mtetra
.655 .747 .918 r
.53831 .23916 .54597 .24879 .56031 .24363 .5527 .23403 Mtetra
.656 .749 .918 r
.5527 .23403 .56031 .24363 .57473 .23845 .56717 .22882 Mtetra
.656 .75 .919 r
.56717 .22882 .57473 .23845 .58922 .23323 .58171 .22359 Mtetra
.656 .751 .92 r
.58171 .22359 .58922 .23323 .60379 .22801 .59633 .21834 Mtetra
.59633 .21834 .60379 .22801 .61843 .22279 .61103 .21307 Mtetra
.61103 .21307 .61843 .22279 .63316 .21753 .62581 .20776 Mtetra
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20244 Mtetra
.64066 .20244 .64796 .21225 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73842 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40873 .07786 .40441 .06874 .39639 Mtetra
.06874 .39639 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09303 .38761 Mtetra
.09303 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Mtetra
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37876 Mtetra
.11756 .37876 .12655 .38693 .13887 .38251 .12992 .37429 Mtetra
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Mtetra
.14233 .36981 .15125 .37807 .16369 .37361 .15481 .3653 Mtetra
.15481 .3653 .16369 .37361 .17619 .36913 .16734 .36078 Mtetra
.16734 .36078 .17619 .36913 .18875 .36464 .17994 .35623 Mtetra
.655 .75 .92 r
.17994 .35623 .18875 .36464 .20137 .36018 .19259 .35167 Mtetra
.655 .749 .919 r
.19259 .35167 .20137 .36018 .21403 .35582 .20531 .34709 Mtetra
.655 .744 .916 r
.20531 .34709 .21403 .35582 .22674 .35166 .21809 .34251 Mtetra
.652 .734 .909 r
.21809 .34251 .22674 .35166 .23949 .34778 .23093 .33796 Mtetra
.647 .717 .899 r
.23093 .33796 .23949 .34778 .25228 .34417 .24382 .33352 Mtetra
.642 .698 .887 r
.24382 .33352 .25228 .34417 .26512 .3408 .25677 .3292 Mtetra
.637 .678 .872 r
.25677 .3292 .26512 .3408 .27803 .33757 .26978 .32493 Mtetra
.634 .657 .855 r
.26978 .32493 .27803 .33757 .29101 .33433 .28285 .32066 Mtetra
.631 .639 .84 r
.28285 .32066 .29101 .33433 .30408 .33083 .29599 .31638 Mtetra
.63 .626 .828 r
.29599 .31638 .30408 .33083 .31725 .32695 .30921 .31204 Mtetra
.63 .62 .822 r
.30921 .31204 .31725 .32695 .33052 .32264 .3225 .3076 Mtetra
.633 .621 .82 r
.3225 .3076 .33052 .32264 .34388 .31799 .33587 .30297 Mtetra
.638 .624 .82 r
.33587 .30297 .34388 .31799 .35732 .31304 .34932 .29813 Mtetra
.643 .628 .821 r
.34932 .29813 .35732 .31304 .37084 .30787 .36285 .29305 Mtetra
.647 .633 .821 r
.36285 .29305 .37084 .30787 .38444 .30245 .37645 .28777 Mtetra
.651 .637 .823 r
.37645 .28777 .38444 .30245 .39811 .29672 .39013 .28233 Mtetra
.653 .643 .828 r
.39013 .28233 .39811 .29672 .41185 .29062 .40387 .27684 Mtetra
.654 .654 .838 r
.40387 .27684 .41185 .29062 .42567 .28418 .41768 .2714 Mtetra
.656 .673 .855 r
.41768 .2714 .42567 .28418 .43954 .27763 .43155 .26604 Mtetra
.658 .698 .876 r
.43155 .26604 .43954 .27763 .45347 .27129 .44548 .26075 Mtetra
.659 .722 .895 r
.44548 .26075 .45347 .27129 .46745 .26539 .45949 .25551 Mtetra
.66 .739 .908 r
.45949 .25551 .46745 .26539 .48148 .25993 .47356 .25025 Mtetra
.659 .745 .913 r
.47356 .25025 .48148 .25993 .49558 .25469 .48771 .24502 Mtetra
.655 .745 .916 r
.48771 .24502 .49558 .25469 .50975 .24946 .50193 .2399 Mtetra
.653 .748 .919 r
.50193 .2399 .50975 .24946 .52399 .24427 .51622 .23482 Mtetra
.655 .753 .922 r
.51622 .23482 .52399 .24427 .53831 .23916 .53058 .22967 Mtetra
.657 .753 .921 r
.53058 .22967 .53831 .23916 .5527 .23403 .54502 .22441 Mtetra
.656 .751 .92 r
.54502 .22441 .5527 .23403 .56717 .22882 .55954 .21914 Mtetra
.55954 .21914 .56717 .22882 .58171 .22359 .57414 .21388 Mtetra
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Mtetra
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20325 Mtetra
.60356 .20325 .61103 .21307 .62581 .20776 .61838 .1979 Mtetra
.61838 .1979 .62581 .20776 .64066 .20244 .63329 .19252 Mtetra
.63329 .19252 .64066 .20244 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39639 .05954 .38829 Mtetra
.05954 .38829 .06874 .39639 .08086 .39201 .07169 .38388 Mtetra
.656 .752 .92 r
.07169 .38388 .08086 .39201 .09303 .38761 .0839 .37944 Mtetra
.656 .751 .92 r
.0839 .37944 .09303 .38761 .10527 .38319 .09617 .37498 Mtetra
.656 .752 .92 r
.09617 .37498 .10527 .38319 .11756 .37876 .10849 .3705 Mtetra
.656 .751 .92 r
.10849 .3705 .11756 .37876 .12992 .37429 .12088 .366 Mtetra
.656 .752 .92 r
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36147 Mtetra
.656 .751 .92 r
.13333 .36147 .14233 .36981 .15481 .3653 .14584 .35693 Mtetra
.656 .752 .92 r
.14584 .35693 .15481 .3653 .16734 .36078 .15841 .35236 Mtetra
.656 .751 .92 r
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34778 Mtetra
.656 .752 .92 r
.17104 .34778 .17994 .35623 .19259 .35167 .18373 .34316 Mtetra
.656 .751 .92 r
.18373 .34316 .19259 .35167 .20531 .34709 .19649 .33852 Mtetra
.655 .75 .92 r
.19649 .33852 .20531 .34709 .21809 .34251 .20931 .33388 Mtetra
.20931 .33388 .21809 .34251 .23093 .33796 .22219 .32922 Mtetra
.656 .749 .918 r
.22219 .32922 .23093 .33796 .24382 .33352 .23514 .3245 Mtetra
.656 .743 .914 r
.23514 .3245 .24382 .33352 .25677 .3292 .24815 .31976 Mtetra
.654 .733 .907 r
.24815 .31976 .25677 .3292 .26978 .32493 .26123 .31504 Mtetra
.651 .722 .901 r
.26123 .31504 .26978 .32493 .28285 .32066 .27436 .31039 Mtetra
.649 .714 .895 r
.27436 .31039 .28285 .32066 .29599 .31638 .28756 .30575 Mtetra
.648 .706 .89 r
.28756 .30575 .29599 .31638 .30921 .31204 .30083 .30108 Mtetra
.649 .701 .884 r
.30083 .30108 .30921 .31204 .3225 .3076 .31417 .29635 Mtetra
.649 .696 .88 r
.31417 .29635 .3225 .3076 .33587 .30297 .32757 .29155 Mtetra
.65 .694 .877 r
.32757 .29155 .33587 .30297 .34932 .29813 .34106 .28667 Mtetra
.652 .694 .877 r
.34106 .28667 .34932 .29813 .36285 .29305 .35461 .28172 Mtetra
.653 .699 .879 r
.35461 .28172 .36285 .29305 .37645 .28777 .36823 .27671 Mtetra
.655 .706 .885 r
.36823 .27671 .37645 .28777 .39013 .28233 .38193 .27164 Mtetra
.657 .716 .892 r
.38193 .27164 .39013 .28233 .40387 .27684 .39569 .26651 Mtetra
.659 .725 .898 r
.39569 .26651 .40387 .27684 .41768 .2714 .40953 .26133 Mtetra
.659 .733 .904 r
.40953 .26133 .41768 .2714 .43155 .26604 .42343 .25613 Mtetra
.658 .738 .908 r
.42343 .25613 .43155 .26604 .44548 .26075 .43741 .25095 Mtetra
.657 .741 .912 r
.43741 .25095 .44548 .26075 .45949 .25551 .45145 .24579 Mtetra
.654 .743 .915 r
.45145 .24579 .45949 .25551 .47356 .25025 .46557 .24071 Mtetra
.653 .748 .92 r
.46557 .24071 .47356 .25025 .48771 .24502 .47976 .23565 Mtetra
.655 .754 .923 r
.47976 .23565 .48771 .24502 .50193 .2399 .49402 .23051 Mtetra
.658 .756 .923 r
.49402 .23051 .50193 .2399 .51622 .23482 .50836 .22524 Mtetra
.658 .752 .92 r
.50836 .22524 .51622 .23482 .53058 .22967 .52278 .21994 Mtetra
.656 .749 .919 r
.52278 .21994 .53058 .22967 .54502 .22441 .53727 .21467 Mtetra
.655 .75 .92 r
.53727 .21467 .54502 .22441 .55954 .21914 .55184 .2094 Mtetra
.656 .752 .921 r
.55184 .2094 .55954 .21914 .57414 .21388 .56648 .20408 Mtetra
.656 .752 .92 r
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19872 Mtetra
.656 .751 .92 r
.58121 .19872 .58881 .20858 .60356 .20325 .59601 .19335 Mtetra
.59601 .19335 .60356 .20325 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38455 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.656 .752 .92 r
.05026 .38012 .05954 .38829 .07169 .38388 .06244 .37567 Mtetra
.656 .751 .92 r
.06244 .37567 .07169 .38388 .0839 .37944 .07468 .37119 Mtetra
.656 .752 .92 r
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.656 .751 .92 r
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36218 Mtetra
.656 .752 .92 r
.09934 .36218 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.656 .751 .92 r
.11176 .35763 .12088 .366 .13333 .36147 .12424 .35307 Mtetra
.656 .752 .92 r
.12424 .35307 .13333 .36147 .14584 .35693 .13679 .34848 Mtetra
.656 .751 .92 r
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Mtetra
.656 .752 .92 r
.14939 .34387 .15841 .35236 .17104 .34778 .16206 .33924 Mtetra
.656 .751 .92 r
.16206 .33924 .17104 .34778 .18373 .34316 .17479 .33459 Mtetra
.656 .752 .92 r
.17479 .33459 .18373 .34316 .19649 .33852 .18758 .32991 Mtetra
.18758 .32991 .19649 .33852 .20931 .33388 .20044 .3252 Mtetra
.656 .751 .92 r
.20044 .3252 .20931 .33388 .22219 .32922 .21336 .32046 Mtetra
.655 .75 .92 r
.21336 .32046 .22219 .32922 .23514 .3245 .22635 .31574 Mtetra
.654 .751 .921 r
.22635 .31574 .23514 .3245 .24815 .31976 .23939 .31101 Mtetra
.655 .752 .921 r
.23939 .31101 .24815 .31976 .26123 .31504 .25251 .30623 Mtetra
.657 .752 .92 r
.25251 .30623 .26123 .31504 .27436 .31039 .2657 .30137 Mtetra
.657 .748 .917 r
.2657 .30137 .27436 .31039 .28756 .30575 .27895 .29647 Mtetra
.657 .743 .913 r
.27895 .29647 .28756 .30575 .30083 .30108 .29227 .29154 Mtetra
.656 .737 .91 r
.29227 .29154 .30083 .30108 .31417 .29635 .30566 .28663 Mtetra
.655 .734 .907 r
.30566 .28663 .31417 .29635 .32757 .29155 .31911 .2817 Mtetra
.655 .732 .906 r
.31911 .2817 .32757 .29155 .34106 .28667 .33263 .27676 Mtetra
.33263 .27676 .34106 .28667 .35461 .28172 .34622 .27178 Mtetra
.34622 .27178 .35461 .28172 .36823 .27671 .35988 .26679 Mtetra
.655 .734 .907 r
.35988 .26679 .36823 .27671 .38193 .27164 .37361 .26176 Mtetra
.655 .736 .909 r
.37361 .26176 .38193 .27164 .39569 .26651 .38741 .25673 Mtetra
.654 .739 .912 r
.38741 .25673 .39569 .26651 .40953 .26133 .40128 .2517 Mtetra
.654 .744 .916 r
.40128 .2517 .40953 .26133 .42343 .25613 .41522 .24666 Mtetra
.654 .749 .92 r
.41522 .24666 .42343 .25613 .43741 .25095 .42924 .2416 Mtetra
.654 .753 .923 r
.42924 .2416 .43741 .25095 .45145 .24579 .44333 .2365 Mtetra
.657 .757 .924 r
.44333 .2365 .45145 .24579 .46557 .24071 .45749 .2313 Mtetra
.658 .755 .922 r
.45749 .2313 .46557 .24071 .47976 .23565 .47173 .22601 Mtetra
.658 .751 .919 r
.47173 .22601 .47976 .23565 .49402 .23051 .48605 .22071 Mtetra
.655 .747 .918 r
.48605 .22071 .49402 .23051 .50836 .22524 .50043 .21547 Mtetra
.654 .749 .919 r
.50043 .21547 .50836 .22524 .52278 .21994 .5149 .21023 Mtetra
.656 .752 .921 r
.5149 .21023 .52278 .21994 .53727 .21467 .52944 .20492 Mtetra
.656 .753 .921 r
.52944 .20492 .53727 .21467 .55184 .2094 .54406 .19955 Mtetra
.656 .751 .92 r
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19417 Mtetra
.55875 .19417 .56648 .20408 .58121 .19872 .57353 .18877 Mtetra
.57353 .18877 .58121 .19872 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.656 .752 .92 r
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.656 .751 .92 r
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.656 .752 .92 r
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37636 .03814 .38455 .05026 .38012 .0409 .37188 Mtetra
.656 .751 .92 r
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.656 .752 .92 r
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.656 .751 .92 r
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.656 .752 .92 r
.07772 .35833 .08698 .36669 .09934 .36218 .09011 .35377 Mtetra
.656 .751 .92 r
.09011 .35377 .09934 .36218 .11176 .35763 .10256 .34919 Mtetra
.656 .752 .92 r
.10256 .34919 .11176 .35763 .12424 .35307 .11508 .34458 Mtetra
.656 .751 .92 r
.11508 .34458 .12424 .35307 .13679 .34848 .12766 .33996 Mtetra
.656 .752 .92 r
.12766 .33996 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.656 .751 .92 r
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Mtetra
.656 .752 .92 r
.153 .33063 .16206 .33924 .17479 .33459 .16577 .32593 Mtetra
.656 .751 .92 r
.16577 .32593 .17479 .33459 .18758 .32991 .17859 .32121 Mtetra
.17859 .32121 .18758 .32991 .20044 .3252 .19149 .31647 Mtetra
.655 .751 .921 r
.19149 .31647 .20044 .3252 .21336 .32046 .20444 .31172 Mtetra
.657 .753 .921 r
.20444 .31172 .21336 .32046 .22635 .31574 .21747 .3069 Mtetra
.657 .752 .92 r
.21747 .3069 .22635 .31574 .23939 .31101 .23056 .30205 Mtetra
.656 .749 .918 r
.23056 .30205 .23939 .31101 .25251 .30623 .24372 .29719 Mtetra
.654 .748 .918 r
.24372 .29719 .25251 .30623 .2657 .30137 .25694 .29236 Mtetra
.654 .75 .92 r
.25694 .29236 .2657 .30137 .27895 .29647 .27022 .28753 Mtetra
.654 .753 .922 r
.27022 .28753 .27895 .29647 .29227 .29154 .28358 .28267 Mtetra
.655 .756 .924 r
.28358 .28267 .29227 .29154 .30566 .28663 .297 .27776 Mtetra
.655 .757 .925 r
.297 .27776 .30566 .28663 .31911 .2817 .31049 .27281 Mtetra
.656 .758 .925 r
.31049 .27281 .31911 .2817 .33263 .27676 .32406 .26781 Mtetra
.32406 .26781 .33263 .27676 .34622 .27178 .33769 .2628 Mtetra
.33769 .2628 .34622 .27178 .35988 .26679 .35139 .25776 Mtetra
.35139 .25776 .35988 .26679 .37361 .26176 .36517 .25269 Mtetra
.36517 .25269 .37361 .26176 .38741 .25673 .37902 .24758 Mtetra
.657 .758 .924 r
.37902 .24758 .38741 .25673 .40128 .2517 .39294 .24242 Mtetra
.658 .756 .922 r
.39294 .24242 .40128 .2517 .41522 .24666 .40693 .23721 Mtetra
.658 .753 .92 r
.40693 .23721 .41522 .24666 .42924 .2416 .42099 .23197 Mtetra
.658 .75 .918 r
.42099 .23197 .42924 .2416 .44333 .2365 .43513 .22671 Mtetra
.656 .746 .917 r
.43513 .22671 .44333 .2365 .45749 .2313 .44934 .22148 Mtetra
.654 .746 .918 r
.44934 .22148 .45749 .2313 .47173 .22601 .46363 .21629 Mtetra
.654 .75 .92 r
.46363 .21629 .47173 .22601 .48605 .22071 .47799 .21107 Mtetra
.656 .754 .922 r
.47799 .21107 .48605 .22071 .50043 .21547 .49243 .20576 Mtetra
.657 .754 .921 r
.49243 .20576 .50043 .21547 .5149 .21023 .50694 .20038 Mtetra
.656 .751 .92 r
.50694 .20038 .5149 .21023 .52944 .20492 .52153 .195 Mtetra
.52153 .195 .52944 .20492 .54406 .19955 .5362 .18961 Mtetra
.5362 .18961 .54406 .19955 .55875 .19417 .55095 .18419 Mtetra
.656 .752 .92 r
.55095 .18419 .55875 .19417 .57353 .18877 .56578 .17872 Mtetra
.656 .751 .92 r
.56578 .17872 .57353 .18877 .58838 .18334 .58068 .17324 Mtetra
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.656 .752 .92 r
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.656 .751 .92 r
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .1397 Mtetra
.656 .752 .92 r
.67184 .1397 .6792 .15013 .69463 .14449 .68732 .13399 Mtetra
.656 .751 .92 r
.68732 .13399 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37636 .0409 .37188 .03145 .36357 Mtetra
.656 .752 .92 r
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.656 .751 .92 r
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35448 Mtetra
.656 .752 .92 r
.056 .35448 .06538 .36287 .07772 .35833 .06836 .34989 Mtetra
.656 .751 .92 r
.06836 .34989 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.656 .752 .92 r
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.656 .751 .92 r
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.656 .752 .92 r
.10583 .33602 .11508 .34458 .12766 .33996 .11844 .33135 Mtetra
.656 .751 .92 r
.11844 .33135 .12766 .33996 .1403 .3353 .13112 .32666 Mtetra
.656 .752 .92 r
.13112 .32666 .1403 .3353 .153 .33063 .14385 .32193 Mtetra
.656 .751 .92 r
.14385 .32193 .153 .33063 .16577 .32593 .15666 .3172 Mtetra
.656 .752 .92 r
.15666 .3172 .16577 .32593 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31647 .18245 .30764 Mtetra
.656 .751 .92 r
.18245 .30764 .19149 .31647 .20444 .31172 .19545 .30281 Mtetra
.655 .75 .92 r
.19545 .30281 .20444 .31172 .21747 .3069 .20851 .29799 Mtetra
.655 .751 .921 r
.20851 .29799 .21747 .3069 .23056 .30205 .22164 .29316 Mtetra
.655 .753 .922 r
.22164 .29316 .23056 .30205 .24372 .29719 .23483 .2883 Mtetra
.657 .755 .922 r
.23483 .2883 .24372 .29719 .25694 .29236 .24809 .28335 Mtetra
.658 .753 .92 r
.24809 .28335 .25694 .29236 .27022 .28753 .26143 .27836 Mtetra
.658 .75 .918 r
.26143 .27836 .27022 .28753 .28358 .28267 .27483 .27333 Mtetra
.656 .747 .916 r
.27483 .27333 .28358 .28267 .297 .27776 .2883 .26832 Mtetra
.656 .745 .916 r
.2883 .26832 .297 .27776 .31049 .27281 .30183 .26329 Mtetra
.655 .744 .915 r
.30183 .26329 .31049 .27281 .32406 .26781 .31544 .25826 Mtetra
.655 .745 .915 r
.31544 .25826 .32406 .26781 .33769 .2628 .32911 .25319 Mtetra
.32911 .25319 .33769 .2628 .35139 .25776 .34286 .2481 Mtetra
.656 .745 .915 r
.34286 .2481 .35139 .25776 .36517 .25269 .35668 .24298 Mtetra
.655 .744 .915 r
.35668 .24298 .36517 .25269 .37902 .24758 .37057 .23785 Mtetra
.655 .745 .916 r
.37057 .23785 .37902 .24758 .39294 .24242 .38453 .2327 Mtetra
.654 .746 .917 r
.38453 .2327 .39294 .24242 .40693 .23721 .39856 .22755 Mtetra
.654 .749 .919 r
.39856 .22755 .40693 .23721 .42099 .23197 .41267 .22237 Mtetra
.654 .751 .921 r
.41267 .22237 .42099 .23197 .43513 .22671 .42685 .21718 Mtetra
.655 .755 .923 r
.42685 .21718 .43513 .22671 .44934 .22148 .44111 .21191 Mtetra
.657 .756 .923 r
.44111 .21191 .44934 .22148 .46363 .21629 .45544 .20656 Mtetra
.657 .753 .921 r
.45544 .20656 .46363 .21629 .47799 .21107 .46985 .20118 Mtetra
.656 .75 .919 r
.46985 .20118 .47799 .21107 .49243 .20576 .48434 .19581 Mtetra
.655 .75 .919 r
.48434 .19581 .49243 .20576 .50694 .20038 .4989 .19044 Mtetra
.655 .751 .92 r
.4989 .19044 .50694 .20038 .52153 .195 .51355 .18503 Mtetra
.656 .752 .921 r
.51355 .18503 .52153 .195 .5362 .18961 .52827 .17957 Mtetra
.656 .752 .92 r
.52827 .17957 .5362 .18961 .55095 .18419 .54307 .17408 Mtetra
.656 .751 .92 r
.54307 .17408 .55095 .18419 .56578 .17872 .55795 .16857 Mtetra
.55795 .16857 .56578 .17872 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.656 .752 .92 r
.64894 .13488 .65644 .14536 .67184 .1397 .66439 .12915 Mtetra
.656 .751 .92 r
.66439 .12915 .67184 .1397 .68732 .13399 .67994 .1234 Mtetra
.656 .752 .92 r
.67994 .1234 .68732 .13399 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?oooc00Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000003oool0oooo0380oooo
001<0?ooo`@00000C03ooolb0:O0j`030000002W`>/0Yl3[00T0Yl3[403oool00`000000oooo0000
000c0?ooo`007@3oool2000000@0oooo0P0000030?ooo`@000007P3oool2000004d0oooo=@2W`>/0
0`000000Yl3[0:O0j`090:O0ja80oooo00<000000?ooo`3oool0<@3oool001`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`<00000C@3oool30:Nojc@0Yl3[00<00000
0:O0j`2W`>/02P2W`>/B0?ooo`030000003oool0oooo0300oooo000L0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool06@3oool2000004h0oooo1P2W_n/c0:O0j`030000002W`>/0
Yl3[00/0Yl3[4P3oool00`000000oooo0?ooo`0_0?ooo`005P3oool400000080oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0E0?ooo`<00000C03oool:0:Nojc<0Yl3[00<00000
0:O0j`2W`>/02`2W`>/B0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000004`3oool3000004d0oooo0`2X`>/50:Noj`D0Z<7[<P2W
`>/00`000000Yl3[0:O0j`0<0:O0ja80oooo00<000000?ooo`3oool0;P3oool001d0oooo0P00000:
0?ooo`8000004P3oool4000004`0oooo1P2X`>/20:Noj`<0Yl7/1@2X`N/a0:O0j`030000002W`>/0
Yl3[00d0Yl3[4P3oool00`000000oooo0?ooo`0]0?ooo`00>`3oool2000004`0oooo1@2X`N`50:S0
j`H0Yl7/102X`N/80:O0j`<0Yko[9P2W`>/00`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?oo
o`3oool0;@3oool003P0oooo0`00001<0?ooo`<0Yl7/1@2X`N`50:Noj`D0Yl7/1@2W_n/50:O0j`H0
Yko[9P2W`>/00`000000Yl3[0:O0j`0=0:O0ja40oooo0P00000^0?ooo`00=@3oool3000004d0oooo
1P2W`N`20:S1k0<0Ykk[6@2W_n/V0:O0j`030000002W`>/0Yl3[00h0Yl3[4@3oool00`000000oooo
0?ooo`0/0?ooo`00<`3oool2000004d0oooo1@2W`>/40:O1k0H0Ykk[0P2W_n/30:S0j`L0Yko[0`2X
`>/50:NojbX0Yl3[00<000000:O0j`2W`>/03`2W`>/A0?ooo`030000003oool0oooo02/0oooo000`
0?ooo`<00000B`3oool50:Noj`D0Yl3[102W_^X50:Nnj`H0Z<3[102W_n/60:S0j`80Yko[0`2X`>/7
0:O0j`<0Yko[1@2W`>/50:Noj`@0Yl3[1@2W_n/<0:O0j`030000002W`>/0Yl3[0100Yl3[4@3oool0
0`000000oooo0?ooo`0Z0?ooo`00;P3oool3000004/0oooo0`2W_^X50:Noj`D0Z;o[102W_^X50:S1
k0D0Z<3[1@2X`N`;0:S0j`@0Yl3[1P2W_n/20:O0j`<0YkkZ102W_n/20:O0j`<0YkkZ2P2W_n/60:O0
j`030000002W`>/0Yl3[0100Yl3[4@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool3000000<0
oooo00<000000?ooo`3oool0AP3oool60:NnjP80Yko[0`2X`>/50:Roj`80YkkZ1`2X`N`50:O1k0D0
Z<7/1@2W`>`50:S0j`X0Yko[1P2W_^X30:Noj`H0YkkZ0P2W_n/30:Rmj@D0Yko[0P2W`>/30:Noj`03
0000002W`>/0Yl3[0140Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool2000004/0oooo
2P2W_^X60:S0j`@0Z;o[202X`N`20:Noj`D0Yl7/0P2X`N`30:Noj`D0Yl3/2P2W_n/50:Rmj0D0YkkZ
102X_>P50:NnjPH0Z;gY2@2W_n/00`000000Yl3[0:O0j`030:Noj`h0Yl3[4P3oool00`000000oooo
0?ooo`0X0?ooo`009P3oool3000004X0oooo2@2W_^X50:S1k0D0Z<3[1@2W`>`50:S1k0D0Yko[102W
`N`60:Noj`80Yl3/0`2W_^X70:Noj`<0Yk[W1@2X_NP50:Rgi0@0Z;cX1@2X^ND50:Rmj@D0Z;gX102W
_n/00`000000Yko[0:Noj`040:Noj`h0Yl3[4@3oool00`000000oooo0?ooo`0X0?ooo`00903oool2
000004/0oooo2P2W_^X20:S2k0D0Z<7/1@2W_n/50:O0k0D0YkkZ1@2W_n/40:NnjPD0Yko[1P2W_^X4
0:Noj`H0Yk[W0P2X_NP30:Rag`D0Z;OT0P2X_>P20:VbgPD0Z;WU1@2Y^><50:Rmj080Z;gY0P000000
0`2X_NT0Yko[0:Noj`080:Noj`X0Yl3[403oool2000002T0oooo000Q0?ooo`<00000B`3oool:0:Nn
jPD0Z<;/0P2X`N`30:NnjPD0Yko[0P2W`>`30:Rmj@D0YkkZ1@2X_^T40:NnjPD0Z;gY1@2W_^X50:Ng
i0D0Yk[W1P2X/Ml40:Rgi0D0ZK;N0P2X^ND30:b`f`D0ZKSS0P2X_NP0102Z^><00000000000000002
0:Rmj@030000002X_NT0Z;kY00@0Z;kY102W_n/:0:O0ja80oooo00<000000?ooo`3oool09P3oool0
01l0oooo0`0000190?ooo`X0YkkZ1@2W`^`40:S2k0H0YkkZ102W_n/60:Rmj@80YkkZ0`2X_NP50:Rn
j@80YkkZ0P2X_>L50:Rmj@D0Yk?Q1@2W]n@50:R[fPD0Z;7O1@2[ZmL40:VbgPH0[;3K102Y^><30000
00<0Z[SS0P2X_NT00`000000Z[_U0:Zki@040:Rnj@D0Z;o[2P2W`>/A0?ooo`030000003oool0oooo
02H0oooo000M0?ooo`800000B`3oool70:NnjPX0Yl;/1@2W_NT40:NnjPD0Z;cX1@2X_NT60:Rmj0@0
Z;kY1@2X_>L30:Rmj@80YjkM1@2W/n420:Ngi0<0Z:OE1@2XZmX20:Rag`<0ZjOB102[ZmL20:VbgP<0
[ZWC1@2//=/01@2^/=X00000000000000000[[3J00D0Z[SS0`2Z^nD00`000000Z[_U0:Zki@020:Rn
j@80ZKgX1@2X_n/:0:O0ja40oooo00<000000?ooo`3oool0303oool2000000@0oooo0P0000030?oo
o`@000002P3oool001D0oooo1@0000030?ooo`800000B@3oool70:NnjPP0Yl;/1@2W_>P50:Nmj@@0
Z;_W1@2X_>P50:Rhi@D0Z;gX1@2X]^<50:Rli`D0YjkM102W/n450:RWe@D0Z:_J1@2[Ym840:^[e`H0
[ZWC0P2//=/3000000D0[[3J1@2_/m`30:Zki@030000002Z^nD0ZKgX00@0ZKgX102X_n/;0:O0ja40
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`0000140?ooo`T0YkkZ202W`^`30:Nkj0D0
YkcX0P2W_NT30:Rii@@0Z;_W0`2X_>P20:Rbh0D0Z;SU1@2X[m`50:Rfh`D0YjWG102W[]d50:RUd`D0
Z:OE0P2XZmX30:fWdPD0ZjOB0P2[ZmL20;6Yd0D0[ZWC0P0000030;:[d@@0[[3J0P2d[M450:ncg080
Z[_U00<0[kSP0000002_^>00102Y_NP50:RojP/0Yl3[403oool00`000000oooo0?ooo`0:0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`00000o0?ooo`X0YkkZ2@2W`^`60:Nkj0@0YkcX1P2X^ND40:Rk
i`D0Z;;P0P2X^>D30:ZYePD0Z:oL0P2X]^<30:VTd@D0YjWG0P2W[]d20:RRd0@0Z:GC1@2XYmD50:fW
dPD0ZjOB102aZM020:jYd`<0000000<0]Zc@0;:[d@2bZm400`2bZm420:j`fP<0]:gA1@2_/m`30:nh
h0030000002_^>00[KcU00@0[KcU1@2X_nX50:S0j`D0Yl3[4@3oool00`000000oooo0?ooo`030?oo
o`@000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00T0oooo000?0?oo
o`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>`3oool20:NojPD0YkkZ2P2W`^`50:Nki`@0Yk_X1@2X]n@50:Rii@D0YjcJ102X/^050:ZY
ePD0Z:oL1@2YY=450:NYe`@0Z:;@1@2XYM<20:RWe@<0[Z_E1@2]Ym820:^WdP<0/ZoE0P2aZM030000
00040:jYd`2f[=00]Zc@0;J/d0D0/Z_A1P2d[M420:ncg0<0][7D0P2_^>000`2e]]X000000;FffP05
0:fli@D0Z[oY1@2X`>/50:O0ja40oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`030000003oool0oooo03P0oooo1@2W_nX30:NnjP80Yl7/1@2W`^`:0:Nki`@0YkCR1@2X
]n@50:NWePD0YjcJ0P2X/^020:bXe0D0ZZWF0P2X[m`30:fUc`D0ZJCA0P2WZML30:^Qc@@0Z:;@102X
YM<50:j[e@D0[JOB102b[mD300000080/JW@1P2f[=020;:[d@<0^Jk>1@2d[M450;Jae0@0]KKJ00@0
00000;FffP2]_>D0[KcU0`2a_>850:Zoj@D0Z<3[102W`>/@0?ooo`8000002`3oool2000000X0oooo
0P00000;0?ooo`005P3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0c0?ooo`D0Z;o[1@2W_nX50:O1k080Yl;/2P2W^nL30:Nbh@@0YkCR0P2X]n@30:NTd`D0YjOF102W
[=X50:bXe0@0ZZWF1@2]YLl50:VTd@D0Zj7=102XX]050:j`f@D0[Z_E0P2]Ym830;:ig`<000000P2b
[mD20;6Yd080]kKH1@2f[=060;V^cP80]:gA0`2l[ld30;Jae080_K7>102e]]X00`000000/KcR0;6l
hP040;6lhP@0Z[oY1@2X`>/50:O0ja40oooo00<000000?ooo`3oool08@3oool001`0oooo00<00000
0?ooo`3oool01@3oool200000300oooo102X`>/50:Roj`T0Yl7/2P2W^nL60:Nbh@<0YkCR1@2WY=<5
0:NWePD0[ZcF1@2/Z=@20:ZYeP80/JgD1@2]YLl20:VTd@<0[Z;<1@2[XLd20:RRd080/;?K1@2^/=T4
0:j[e@80/[WO0`0000000`2b^Ml0/ZoE0;:_e@020;:_e@D0]kKH0P2f[=030;Zhf0D0^Jk>1P2l[ld0
102f/M@0_K7>0;facP2m/Lh40;FffP030000002l]mD0/KcR00@0/KcR1@2/_nP40:S0j`H0Yl3[4@3o
ool00`000000oooo0?ooo`0P0?ooo`00703oool2000000P0oooo00<000000?ooo`3oool0:`3oool3
0:S1k0@0Z<3[1@2W`>`50:O1k0D0Yk_X102W^nL50:Jah0D0Yk;Q102VXm850:NTd`80YjOF0`2_/]/5
0:j/eP@0[:SD102a[M@50:fUc`D0[Z;<1@2[XLd40;2cf`D0[[3I0`2]a>/3000000@0/[WO1@2``nP4
0;Nff0D0^[SH102i[/h20;ffd`D0_:o=1@2m/Lh20;FffP80_;OE00@000000;bge@2a_>80/KcR0`2f
_Ml40:boj0D0Z<3[1@2W`>/A0?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0:03oool60:S1k080Z<3[0P2W_n/50:O0k0D0YkcX1@2W^nP9
0:Jah080Yk;Q0`2UX]840:JSdP@0YjCC1@2_/]/50:j/ePD0/k_P102a[M@20:fUc`<0[jSA1@2^X/`2
0:^Qc@<0];KJ102`/m/20:j`f@80Z/cb0`0000030:g4j`80/[WO0`2Qc?H50;33j080]kKH0P2^aN/5
0;Zhf080^Jk>0`2m]]<40;b_c@80`K?=102m/Lh50;bge@030000002f_Ml0][gO00@0][gO0P2/_nP2
0:k0i`D0Z<3[1@2W`>/A0?ooo`030000003oool0oooo01l0oooo000K0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool08`3oool50:O0k0D0Z<7/1@2W_n/30:O0k080Z;kY1@2W_>P20:Nk
j0<0Y[;Q202V/N050:FRdPD0YZ?B0P2WY=<20:nih@D0[k;K0P2^[=H30:o9k@D0/k_P0`2a[M@50:nX
d@D0[Z;<1P2d]]X30;2cf`040:[<lP000000000000000080Z/cb102]a>/60:7<mP@0/<?X102^aN/5
0;Zhf0H0_KKC0P2l[ld30<6cc@<0_K7>0P33/l/40;bge@030<>hd0000000][gO00@0][gO1@2^`>L5
0:W0j`D0Yl3[4@3oool00`000000oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<000000?oo
o`3oool07`3oool50:O0j`@0Yl3/2P2W_n/50:Rnj@@0YkcX1P2V/^440:Jah0@0Y:3B1@2UX]840:JS
dPD0[kWQ102_/]/60:o9k@@0/k_P102Z/Mh50:nXd@80[Z;<0`2e^]d50;BffP80/=;b0P0000050:[<
lPD0Ulkk1@2Qc?H509G9n@@0[/G[0P2j^=P30;73i`D0_KKC1P31/ld00`2m/Lh0`k?;0<>cb`020<>c
b`80_;OE0P33^=0010000000`kS@0;Jmg`2f_Ml30;^og@80[/3W0`2``^L50:W0j`D0Yl3[403oool0
0`000000oooo0?ooo`0N0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01X0oooo1@2W_n/50:O0j`T0Yko[1@2X_nX50:Rnj@@0Y[?R1@2V/^450:>Od@<0Y:3B1@2UX]850:jo
i`@0[kWQ1@2XdOH50:o9k@D0WkOY102Z/Mh40:nXd@H0]K[M0P2d]]X0102heo000000000000000003
0;3BlPH0Vm3j102Gc_/508W7o0@0ULWi102^aN/60;73i`80_KKC0`2i_Md50<6cc@D0`k?;1@33^=00
0`000000^koM0;^og@030;^og@H0/<;W0P2Y`>/30:W1j`@0Yl3[4@3oool00`000000oooo0?ooo`0M
0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo0P2W`>/50:No
j`80Yl3[0`2X`>/50:Noj`D0Z<3[102X_nX50:Fdh`@0Y[?R0P2V/^430::Nd@@0XioA102TX=820:FR
dP<0[<?[1@2^_nL20:nih@<0Xm?i102XdOH509ZjkPD0WkOY0`2Z/Mh50:Znj0D0]K[M0`0000030;SG
l0D0Z]Kg1@2Mb?H50937nP@0RLOl101n`?`40935n@D0/L?W1@2i_Md40<6cc@80`[O@0`33/l/20<Rf
b0@0`kS@00@0bK_<0000002k_md0^koM0`31`]/50;32i`D0ZL7[102W`>/@0?ooo`8000007`3oool0
01/0oooo0P00000?0?ooo`030000003oool0oooo01D0oooo1@2W`>/40:Noj`H0Z<3[0P2W_n/30:O0
j`D0Z<3[102V]^D50:Fdh`<0Y[?R1@2RW]450:>Od@<0Y:3B1P2/`n/40:joi`H0Xm?i102M_^l509Zj
kP@0WkOY102G^>l50:Znj0050;Fjg@00000000000000002bf_@00`2heo030;GLm0<0Z]Kg0P2[dO@5
09g8mPD0Ul?e1027`OX407k0o0@0T<Gi1@2F`_D50;Vmg@80`K?=0`32]m020<>cb`@0b;K80P33^=02
0<Vkc00300000031`]/0`L;K00@0`L;K1@2b`nL40:W1j`D0Yl3[4@3oool00`000000oooo0?ooo`0L
0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo2@2W`>/90:S0
j`H0Yl3[0P2X`>/30:JhiP@0Y[KU102U]><40:6NdPD0XYkA102SWm450:[5k@@0[<?[1P2RdoT50:;3
l0@0WKk_102J^^h5092ak0@0UkS_0P2Z_^P3000000D0/][d1P2eg?@50:_Am0D0XlGa1@2G`oD408O1
nP@0Nk_k101d^O/509K2m@@0^KgM1@32]m060<Rfb0D0bK_<00<000000<72f`31`]/00P31`]/20<K6
fP@0//?W1@2Y`N/50:O0ja40oooo00<000000?ooo`3oool06`3oool000P0oooo0P0000040?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`h0
Yl3[1@2X`>/90:O0j`H0Y[SV0`2V]^D50:6Pd`@0XIkB102RW]450:S3k@D0Z/G]1@2Td_P50:G6l0D0
X/?`0`2M_^l509B`jPD0T;7/0P2G^>l3000000<0V=Om0`2bf_@40:cKn0D0/Mog0`2[dO@20:O;l`D0
XlGa1@2O`o8408g0n0@0Nk_k101d^O/409K2m@D0ZKkY0`32]m020;nie0@0b;K80P3<]lH30<Vkc080
d;k900<000000<72f`31`]/01036a]X20;;3i`80//CW1@2Y`N/50:O0ja00oooo00<000000?ooo`3o
ool06`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?oo
o`8000004`3oool00`000000oooo0?ooo`0:0?oooa00Yl3[1@2W_n/50:O0j`@0Yk_X1@2V^>H40:6S
e`@0XJ3C1@2QW]820::Nd@80Y[kZ1@2X`nd50:KCn0<0Y=;h0P2Wao050:G6l0D0W[k_0`2I]^`509B`
jP<0T;7/0`00000308S>oP@0V=Om102/foP30:CTn`D0/Mog1@2Wbo<50:K2k@D0Wl?b102C`OH407nj
n@@0Ik7j101b]?X50:Vnj@040<:gd02o^M@0_kWD0;nie0<0b;K8103<]lH00`39^l`0d;k90=2nb@02
0=2nb@0300000036a]X0a/KJ00<0a/KJ1@2ba>L50:W1j`@0Yl3[4@3oool00`000000oooo0?ooo`0J
0?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000005@3o
ool00`000000oooo0?ooo`070?oooa@0Yl3[102W_n/50:Nnj@@0Yk_X1@2RZ=X30:6Se`D0XJ3C102Q
W]850:JnjP80Z<?]0`2Xe_P50:KCn0D0YlO`0P2Ua_030:?5l@D0W[k_0`2I]^`409Nek0<000000`2D
`?D5087Go`@0S]?n1P2Ti?/50:3Jo0<0Yl_c0P2R`o050:K2k@D0Y<Ka102C`OH407njn@@0Ik7j101b
]?X40:Vnj@D0_kWD00<0b;K80<bgaP3<]lH00`3<]lH50=2nb@0300000036a]X0a/KJ0080a/KJ0P39
bMX20;;4i`<0/lGX1@2Y`N/40:O0ja40oooo00<000000?ooo`3oool06@3oool000030?ooo`000000
0000008000000P3oool010000000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0080oooo6@2W`>/40:Noj`D0YkkY102S[Ml40::XfP@0XJ?G102Q
X=<50:>ei@@0Y[kZ1P2Xe_P50:O5k`@0YlO`1P2SaO4409jnk`@0U;;/0`00000209Nek080U<3e102R
ho`4087Go`D0SLkn1P2>h_`40:3Jo0D0X/?`0P2V`^d30:_4k0@0Y<Ka1@2F`O@408Jjm`@0I:ki0`1A
XoL508ngl@@0_kWD1@3<]lH20<nha0<0d;k90P3F`/H00`000000a/KJ0<K6fP030<W9fPH0/lGX1@2Y
`N/40:O0ja00oooo00<000000?ooo`3oool06@3oool000L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`030?ooo`8000005P3oool00`000000Yl3[0:O0j`0H0:O0j`L0Yko[0P2W
_^T30:Bbh`@0XjgO102RZ=X30:6Se`D0X:_O1@2S]ND60:WJn0@0Z<C^1@2WaNl50:K:l`@0XlGa1@2G
]N`0102D/^`000000000002D/^`409Nek0@0X^?l0`2Nj?/508bcl@D0RNKg1@2;`_X408o2n0@0X/?`
1P2[a>`40:K:lPD0U/7d1026^_L406B^n@<0DJ?g102?]o420;nie0<0^KOG0`3<]lH40<nha0030=2n
b@3F`/H0e/;60080e/;600@000000<W9fP39bMX0bLWJ0P3<cMX50;?5j0D0ZL7[102W`>/@0?ooo`80
00006P3oool000P0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0B0?oooa`0Yl3[
2@2W_n/50:Bbh`D0XjgO0`2RZ=X409bRf@D0X:_O0P2S]ND30:[Mn@<0ZM[h0`2X`nd40:S4kPD0Z<kc
1@2Vb_<409ffjP80UkG/0`00000309Bbk0H0X=Wk1P2Nj?/208bcl@<0Y]cj1@2Lb?H508_2nP<0Sl;h
1@2O^n`30:_4k0<0/<[]102Vb_8509VnlP@0SKgf101T[_T303BAl0<0SkOa1P2i]mL00`3<]lH0ckS4
0<nha0030<nha0@0e/;60P3Ka/@00`000000bLWJ0<c=fP030<c=fPD0//GX102Y`N/50:O0ja40oooo
00<000000?ooo`3oool05`3oool001T0oooo00<000000?ooo`3oool04P3ooolJ0:O0j`T0Yko[1@2U
]nH40:Bbh`@0XjgO102JW=@409bRf@@0X:_O1P2ZgOT60:S3k@@0ZLgc1@2Xc_<50::ij@80WKKZ0`00
000408[<o@D0Qlko0`2g^=X306f?h`<0PXK?102Vg?X20<7Yl@D0W<Sf1@2?/>d308b`kPD0Wk_/1P2`
b^d40:?7lPD0VKkb102=_OH306B^n@@0=97`0`1]Y_<50;Vge`H0ckS400<0d[W20=K2aP3F`/H00`3K
a/@00`000000c<gJ0<c=fP020<c=fP80cLoL102baNP50:W1j`D0Yl3[403oool00`000000oooo0?oo
o`0G0?ooo`006@3oool200000140oooo7@2W`>/40:Noj`D0Y[_X1@2U]nH30:Bbh`D0VY[C102JW=@4
09bRf@H0Z]ki102ZaNd30:S3k@<0ZL_b102YcO<50:K0k0<0X[WY0`00000309c7mPD0R/cm0P0n`/l6
0;NhfP80KHoS1@22Q/l50<7Yl@D0X;WZ1@2?/>d308b`kPD0Y;_Y0`2`b^d30;;Dl@@0XlOb1@2N_Nl4
09G2mP<0HZoj0`0FOND406fVl`80^KOG0`2a/]T40<nha080d[W200<0e/;60=_6a03Ka/@00`3Ka/@0
0`000000c<gJ0<c=fP040<g?g080//GX0P2aaNT50:W1j`D0Yl3[403oool00`000000oooo0?ooo`0F
0?ooo`006@3oool00`000000oooo0?ooo`0=0?ooob40Yl3[1@2W_^X40:Jkj0D0WZGJ0`2LW]H409ZJ
d`@0VYcD1P2Yf?P50:g9kP@0Z/G]1P2Ybo850:_6k@<0Y/3/0`00000309o0l0@0W<Of102>d?h30;bi
ePD0]kSJ0`1]Sn<308:6c`<0]ocA102[anh50:2ijP@0Sk3]102BZnL50:Bkj@D0/]Ca1@2N_Nh509jm
k`@0V/[h0`1L[OX301Imi@<0B8g]1@2a/]T30<nha0<0d[W21@3Ka/@20>7;`P030000003=cm`0cLoL
00<0cLoL1@2aaNT50:W1j`@0Yl3[4@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`000000
oooo0?ooo`090?ooob80Yl3[102W_n/50:NnjP@0XJgP102NYMX309bNePD0VY[C0P2JW=@20:G9l`<0
ZMSh0`2adO450:g9kP@0Z<[a0`2Ybo830:c5k0@0ZlK]0`00000209jol0D0Wl3`1@2Zb_060;bieP80
]kSJ0`2a`nL01003I]X0KHoS08:6c`22Q/l50:_Cm@@0ZlO^1@2N/ND409>[iP@0TZ_W1@2`c>h30;;D
l@80Zlkb1@2N_Nh50:O7l0@0V/[h101L[OX201Imi@<0B8g]1@2a/]T00`3?^<@0d[W20=:i`P020=:i
`P040=Nk_P3Ka/@0flK40=_6a0<0hL_200<0iM310000003=cm`00P3=cm`20<c@g@80/LGY0`2`aNT4
0:W1j`D0Yl3[403oool00`000000oooo0?ooo`0E0?ooo`006@3oool2000000L0oooo8`2W`>/70:No
j`80YkkZ0`2T]ND30:6]h0D0WZGJ0`2LW]H409ZJd`D0YLWc1P2adO490:S:l@H0[<G/0`0000020:G5
l0@0W[o`1@2Yb?030:[:l080]l7R1@2l^MH60;73i`@0WlGc1@2[doD409n_h`D0W[7U102CZnH409fc
i`D0/<c^1@2[c_850:2hjP@0YlO`1@2MboL4056Wn0030016`P18SNd0B8g]0080B8g]102a/]T40=:i
`P<0ek^n00@0flK40>7;`P3Qbl80hL_20P3Ud<400`000000cLoL0<g?g0030<c@g@H0/<GY0P2Y`N/2
0:S1j`D0Yl3[403oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`030?oo
ob@0Yl3[2@2W_n/60:Bei@<0XJgP102NYMX309bNePH0WKCX1@2df_<30;7Al@80ZLS`1@2Xb_450:W2
k0050:c5k000000000000000002]b^l01@2UaO0409o2l@D0ZLS`1@2g`N820;bieP<0aM?T0`2a`nL3
0;?;k0@0WlGc1@2OZ]h409n_h`@0W[7U1@2DY>0409fci`H0]mgc102O]NP50:2hjP@0[]7b1@2MboL4
056Wn0040016`P0TLN00977P02Aah0D0ZZ_H0`3B^L830=Nk_P@0hL_20`3Ud<4010000000c=3M0<c@
g@3<d=d20<[@gPD0/<GY1@2X`N/50:O0ja00oooo00<000000?ooo`3oool04`3oool001P0oooo00<0
00000?ooo`3oool00`3ooolW0:O0j`@0Yko[1@2V^nP40:Bei@<0XJgP1@2DVMH309NRg0<0WKCX0`2c
g_D50;CJl`D0ZLS`1@2Y`n`20:W2k0<000001@2]b^l50:6nkP@0Wl;a1@2[b_040;O1hPH0aM?T1P2c
bn`40:V^f`D0Wj[N0`2O[n<509bUg0@0U:CP0P2M/nL30;3Gm0<0]mgc0`2/bNl409nej080X;SZ0`2]
c_440:kAlPH0W/oi0`0kVo<01000A/80977P02Aah00TLN050:Z[f0030=:i`P3G^kh0ek^n0080ek^n
00<0gKnk0>7;`P3Qbl80103Ud<400`3Wdl4000000<c@g@040<[@gPD0[lCY102X`N/50:O0j`l0oooo
0P00000E0?ooo`00603oool010000000oooo0000003ooolZ0:O0j`@0YkkZ1@2V^nP409VRf`<0UI[F
102DVMH409NRg0H0/mke1P2[b>l50:_6kP<0ZL?/0P0000040:c:k`<0[L[_0P2Y`>X50:6nkP@0XL_e
1@2[b_050:_>lP<0aM?T0P2keNd30;?;k0<0[k7J102Y[]/409nZgP@0XZSJ1@2LYM`309BTh0H0/=Od
1@2/bNl409nej0D0[Lka1P2^d_<509GKoP0601=oi@0kVo<002F[0016`P08E]40977P1@2ZZmP40=Nk
_P<0gKnk00@0hL_20>G@`@3Ud<40iM310P3Wdl400`000000b]3N0<[@gP020<[@gP80aloP102_a>T5
0:S0j`@0Yl3[4@3oool00`000000oooo0?ooo`060?ooo`8000002P3oool001P0oooo00<000000:O0
j`2W`>/09`2W`>/50:Noj`@0YkkZ1@2N[N4309VRf`@0UI[F102DVMH209NRg0@0[MGe102`cNl30:_8
k`<0[<W_102[a^h300000080Z<O_1@2/b^l50:W0jP80XKk^0`2Va_040:7;m@D0VL?e1@2[c_850;_E
k@H0[k7J0`2Y[]/50:FZfP@0XZSJ102LYM`50:;4l@D0]=ke102/bNl50:6mk@<0[Lka0P2]g?P30:kB
l`@0Xn_j0`2Efoh201=oi@8002F[00<004K200QFd@0TLN000P2ZZmP30:JVe@<0ek^n0`3M_k/30>G@
`@@0im?100<000000<[@gP3:d=h00`37cn050:k4j@@0Z<3[1@2W`>/A0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000002@3oool00140oooo0P0000050?ooo`030000003oool0Yl3[
02T0Yl3[102W_n/40:>fiP@0WZgQ102IX]/409FJeP<0U9WF102]eOD30;OFl0@0/<g_1P2/bNl30000
0080YlC^102Xanl50:c2jP@0ZL3Z1P2Va_0409nnkPD0VL?e1P2[c_840;2cf`D0[k7J102Z[m/50:FZ
fP<0XZSJ1@2O^N`30:;4l@80[^7i1@2dg_D409^cj@D0XKg]1@2]g?P40:?[nP<0F]?C101=b>P00`0C
OnD002F[000UZ`0200QFd@D0YZKE0P3G^kh40=fo^`030>C4]`3Ud<40im?100<0im?10P3XeL801000
0000aloP0<O?h037cn020<G>h@D0[/CY102X`>/50:O0ja00oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo02X0Yl3[102V_>T40:>fiP@0WZgQ0`2IX]/409FJePD0XKg]1P2ge_050:c;l0040:c9k`00
00000000000000H0YlC^102[`n`50:c2jPD0ZlK]1@2/_^L409nnkPD0X<7`0`2[c_830:bcgP@0/;?K
0P2_/MX30:nhg`@0ZZoK102UZ]X40:>ij0D0WkW/1@2^hOT50:;7lP@0Vk?Y1P2Jk?P507gSl`<0XMOk
1@2E`_H00`00H=D007bk0017_P02000UZ`030012a008E]40YZKE00@0YZKE00@0ek^n0=fo^`3M_k/0
gKnk0P3Ta;L40>OC`@<0j=G200<0imK400000037cn001035c^420:k4j@<0[/?Z102X`>/50:O0ja00
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000090?ooo`00403oool010000000
oooo0?ooo`0000040?ooo`8000000P3ooolW0:O0j`<0Yko[102V_>T40:>fiP<0WZgQ102?V=P409FT
h0<0XKg]0`2ifo430;OFl080[/g`0P2/bo03000000@0Z<?]0`2Wa>h30:[5k@@0Zl?/1@2[a^h30:_6
k@80[KkV1@2/_^L40:Rnj@D0X<7`1@2//mh40;2cf`H0[kSO0`2Z[m/50:Jii`@0XkWX1P2Sfo/409gY
n`D0X/Ob1@1TfN8205G?i`D0Q<ko102Qeo/20;o<i0@0UL;f0`00H=D01@00Akh002F[0012a000@/@0
25KA00@0YZKE0`3M_k/30>C4]`030>_:]03Wdl40im?100<0j=G20P3We/@00`000000aLkQ0<G>h@03
0<G>h@D0[/?Z1@2X`>/40:O0ja40oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo902W
`>/60:Noj`<0Y[cY1@2GYMh3096Jf@@0SiSH102EY>060;WKl@<0[/g`0`0000040:[4k@@0Z<?]1P2Z
aNd40:W5kPD0ZlK^1@2]_^H20:bni`<0/LCX102X_^T50:Zdh0@0[;?N1@2__nH50:nhg`@0YkWV1@2V
^NL509cLo@D0HMO>102MjO/204W5j0D0RM?o1@2N^^`60;?5i`D0_lcT102IWMH0100bG/l0063E001P
e@00Akh30012a0D0ZJCA0P3M_k/30>C4]`80jlZd103XeL830>OFa00300000035c^40aLkQ00<0`lgR
0`2^`nX20:g3jPD0Z<3[102W`>/@0?ooo`800000103oool2000000X0oooo000@0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool01@3ooolO0:O0j`T0Yko[102N/ND409NUgP@0TI[I
0`2?V=P60;7Al@@0/m7_0`0000030:g8kPD0Z/C]102Za^h30:[5k@<0Z<?]102YaNh50:[0jP@0[KkV
1P2aa>P20:Rnj@80[KWR1@2Z]>020:bcgP80[<C/1@2__nH50:Nji`@0YkWV0P2V^NL309;Uo0800000
1@2K^>`408Nln0D0WlKd1@2[/mh309jjk080^;oO0`2caNL30<C9gP80_lcT0`2m^mL309VMeP80<Uk?
00@0063E0000K0002IL003Zm0P00@/@40:VTd@040=fo^`3Ta;L0i<Bg0>C4]`<0jlZd00<0l<na0>SE
`P3XeL800`3We/@20>KFaP0300000033cN80`lgR00<0`lgR1@2]`nX50:S0j`@0Yl3[3P3oool30000
0100oooo000A0?ooo`800000103oool2000000L0oooo7`2W`>/50:Noj`@0Y;[Y102N/ND409NUgP<0
TI[I1@2O]^P30;7Al@80^]O^0`0000030;3=k`@0[LS^1@2Ya^l40:[6kPH0Z<?]1@2Y`^`40:[0jPD0
[/O]102aa>P50:fihP@0Z[CP1@2/a>`20:noiP<0Y[cY102W^^L40:NiiP80T^Gl0P0d^l@40:Ffi@D0
VkS/102U]nH309o6m080/KCK1@2[/mh50;Rog`D0a<WN1P2m^mL309VMeP80<Uk?00D0001/0003Q000
>[d003Zm0012a0040:VTd@@0i<Bg0`3[b[@20?3?/@<0imK40`3Ve/H0103TelT000000<?=hP33cN83
0<7=h`80[L?Z0`2/`nX40:S0j`D0Yl3[3`3oool00`000000oooo0?ooo`0>0?ooo`005`3oool00`00
0000oooo0?ooo`070?oooal0Yl3[1@2V_^/40:Bjj@<0W[7U102GYMh408nMg@D0WkKX00D0^]O^0000
0000000000000;[GkP060;3=k`D0ZLG^102Ya^l50:S2k0<0Z<?]0P2[a>d50:W2k0@0Y/K`1@2^and4
0:foi`@0[KWR1@2Yb>l40:c4k0H0Y[cY0`2W^^L207WSk@80F]7[1@2X]>440:Ffi@D0YjoM102U]nH5
0;6df`80Zk?N0`2g_Mh30;Rog`80`<OO0`34bMh20<O<gPD0_K_G0`2IWMH3039Nc`050000K00007P0
03Zm000j_@00@/@00P2YY=420;>Xc@80i<Bg0`3[b[@30?3?/@030?;B[`3We/@0i]K60080i]K60P3T
elT00`000000`LgS0<7=h`030<7=h`D0[<?Z1@2X`>/40:O0ja00oooo00<000000?ooo`3oool03@3o
ool001L0oooo00<000000?ooo`3oool0203ooolK0:O0j`D0Yko[102V_^/409Z^i@<0T9oN102:U]X4
08nMg@80WkKX0`0000000`2ieNh0]M7_0;GAk`030;GAk`<0/<g_0P2/and50:W5kP@0ZL?/1@2X`^`5
0:_4k@D0YlC^102Va_050:Roj`@0[KoW102Xbo850:W8k`@0YKg[1@2V_>T205kFf@80O][m102Y/]l5
0:Rdh@@0ZJcI102W[md50;BjgP@0/KCK1P2g_Mh50<37g`D0alcN1@2YWl`309J?b@<0FG7@00@0001/
000j_@00>[d003Zm1@2cZ<d0103Ta;L0jlZd0>_:]03[b[@20?3?/@80l]:_0`3Ve/H30>CGb@040>?H
c0000000`LgS0<7=h`<0_lcU102/`nX60:S0j`@0Yl3[403oool00`000000oooo0?ooo`0<0?ooo`00
5`3oool2000000T0oooo702W`>/50:Noj`@0X[WY0`2J[^D4092OgP@0RYKJ0`2?WMd2000000<0^MG^
0P2ke^d50;GAk`D0[<O]1@2[a^d40:W3k0D0ZLG^0`2[a>d20:S2k0D0YlC^102V_^/50:Roj`@0YL[c
102Xbo890:Fmj`80D/o@102Bf_h30:VagP@0ZK;O0P2X]>430:Z/f@@0ZJcI0P2W[md20;>nhPD0];[N
102c^ml30;NmgP<0^/GS0`30aml20<CCi@<0alcN0P2f]MP40:VOc0<0UXo90`1ILM000`0006`0001h
000j_@02000j_@@0/jS=0`3[b[@30?3?/@80l]:_0P3ce:l30>CGb@<0hmS<00<000000;o<i@2oc>D0
0`2oc>D40:c2j`D0Z<3[1@2W`>/?0?ooo`030000003oool0oooo00`0oooo000G0?ooo`030000003o
ool0oooo00X0oooo6`2W`>/50:Jnj`@0X[WY0`2J[^D4092OgP<0RYKJ0`0000030:VojPD0^mK]1@2a
c>h30:c7k@80ZlO^1@2[a^d40:S5kPD0ZLG^1@2X`^`50:W1j`@0Y[k[1@2Tao840:G:l`@0YK_Y1@2U
_N/205OBe@D0WM[l1P2Y/Mh30:Vbg`D0ZZcI102Y[=T50;>nhP80];[N0`2`^^440;>kg`D0^/GS0P30
aml40<CCi@@0][GH102YWl`409J?b@<0FG7@00@0001/00/o_P00>[d003Zm0`2cZ<d20<:bbP80jlZd
0P3`ck430?;B[`80lmB_00<0m=Na0>CGb@3Sf<`00`3Sf<`0103Qf/l000000;o<i@2oc>D30;c<iP@0
[<;[1@2X`>/40:O0ja00oooo00<000000?ooo`3oool02`3oool001H0oooo00<000000?ooo`3oool0
303ooolG0:O0j`D0Yko[102V_^/30::ij@<0VZkU102@Wmh30000000409:Sh02Y_nX0ZKoZ0:VojP<0
_M?[0`2ke^d20;SBk@D0/Lc^1@2[anh50:S4kP@0Z<G^1@2X`N`30:S2k080ZlC/1@2Y`N/40:K5k`D0
Y<Ob102V^^L40:Fkj@80I][P1P2Sg?/40:R`gPD0ZK7N102[[]X40:Z/f@D0/<3V102c_^860;2jh@80
/k_O0P2fa^H40;[5h`@0a=?U0`2mbN@40;Jef0<0ZIo<102FSlT405Uad0030000GP0;?kh003Zm0080
/jS=1032//X30?3?/@80l]:_0`3ce:l00`3dek40hmS<0>?Hc0020>?Hc080hM[?00<000000;c<iP2l
c>H00`2lc>H50:_2j`@0Z<3[1@2W`>/@0?ooo`030000003oool0oooo00X0oooo000F0?ooo`800000
3P3ooolG0:O0j`D0Yko[102P^NX309J]iP<0RIcO0`0000000`25UM/0TZ?P09:Sh00209:Sh0H0_M?[
1@2hd^d60:g8kPD0ZLG]102Xa>h40:S2k0D0Z<7/1@2[a>`20:W1j`<0Z<?]102VaNl50:RjiP@0Y[[W
0P1gh^/50:CRo0D0Yk3N102X/=h50:Z_g0@0ZjkJ0P2Z[=T20:foi`D0/<3V102^^^850;2jh@D0]/KV
1@2ldNX50;g9i0@0][GH102NU//40:2Ld0<0MhkM00<0001N00/o_P0;?kh01@32//X20=?0a`040?3?
/@3bdZl0l]:_0?;B[`80lmB_0P3dek400`3dfk<0hmS<0>?Hc0040>7Jc`040000002lc>H0_<cV0;c<
iP80^LcX102[`^/50:S0j`@0Yl3[3`3oool2000000`0oooo000F0?ooo`030000003oool0oooo00h0
oooo5`2W`>/50:Fnj`@0X;WZ0P2F[NH30000000308VLg`25UM/0QIGK0080QIGK0P2BXn020:k1j0<0
_M?[102oeN/50;?=k@<0[LS^0P2/anh50:W5k@@0ZLG^102X`^`50:S5kP@0ZlC/1P2X`nd40:Zmj0D0
Z;[V1027ioD30:;Yn`@0Yk7O1@2W/=h20:R`gP80ZK3M102Z[m`40:^^fPD0[KoW0P2``>H30:fki0@0
[[[R1@2aa^T20;K6iP<0]<g/0`2ldNX20;cDk0@0_LWT1@2MU/`309jFb`D0X9c@0`1gS]d00`0005h0
6Dg700/o_P030<:bbP<0dl370`3bdZl30??D[`80m=Na0P3dfk<40>7Jc`80g]cD00<000000;W<j02i
c>P00`2ic>P40:[2j`D0Z<3[102W`>/@0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000
003oool0oooo0100oooo502W`>/20:Noj`D0YKk[0P2P^NX30000000309J]iP29W=l0RIcO0080RIcO
0`25UM/50:k1j0D0_mG[0P2ldn/50;?=k@D0[<O^1@2Ya^h40:W5kP@0YlG_1@2XaNh40:O1k0<0Z<?]
0`2Z`N/40:Zmj0H0U>Kl0P2RjO/40:Jbh@@0Yk7O102W/=h50:V`g@<0ZZoL1@2Z_^P40:foi`H0[K_T
0P2^^^820:k5j`@0/LKY1P2dcN`50;cDk0@0YJ?C102MU/`409jFb`@0X9c@0`1gS]d01@006:@06Dg7
01U=a`0;?kh0`[;:00@0dl3700<0h/k40?;B[`3bdZl00`3ce:l01@3dek40m=^c0?CK/`3dfk<0m>2g
0080hM[?0`3Ng=@010000000fMgJ0;W<j02ic>P30;K:j@@0Z/;[1@2X`>/40:O0ja00oooo00<00000
0?ooo`3oool0203oool001H0oooo0P00000B0?oooa40Yl3[1@2W_n/30:Fnj`<000000P2D[^T308BL
hP@0P9CM0`2BXn430:k1j0@0_m7W1@2ldn/50;3;kP<0[<O^1`2Ya^h40:K3kP@0YlG_2@2W`N`60:[1
j`80Z[gX0`2Mg_d209[^m@D0YkKT102V/^480:Nag`@0ZK3M102Y_NP50:Znj0@0[;cV1@2]^n@50:k5
j`@0/<S/0`2dcN`30;OFl080_=C/0`2_]ml30:FSd`D0WIK<0`2NU//50:bag0<0QYkS00<003Vo01U=
a`0ICLL0103C`<L30>;>a0<0lmB_0P3dek420?CK/`<0m>2g0`3Ng=@20=WMfP030000002fb^T0]/[Y
00<0]/[Y1@2Y`^/40:S0j`D0Yl3[3`3oool00`000000oooo0?ooo`080?ooo`005P3oool00`000000
oooo0?ooo`0B0?oooa40Yl3[102W_n/300000080X;[[102D[^T308BLhP@0P9CM0`2BXn440;oAi`<0
a=CV0`2ldn/20;O?k0D0/<_^1@2Ya^h50:O4kP@0Y/?^1@2X`^d40:O1k0@0ZLG^1@2Z`N/409gNo@@0
ZKkY102W]^@40:Jbh@@0Y[3P1@2W/Ml40:Rlj0@0ZKgX1@2[_NL40:bliPD0[<C/0P2^aN/30:k6k0@0
/<S/1@2ge_050:ngg`@0YJ?C102MU/`40:V]fP@0[;7L1026W^<301U=a`<0dl370`3Rc/@0103Zf<80
lmB_0??D[`3dek430?CK/`<0m>2g00<0lnBl0=WMfP3IgMX00P3IgMX00`3CgN0000000;K:j@020;K:
j@80//S[102Y`^/90:O0j`l0oooo0P0000090?ooo`000`3oool2000000@0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`0D0?oooa40Yl3[0`0000020:Jnj`@0X;[[0`2D[^T308BLhP@0
P9CM1@2]_>@60<CDiPD0]lo/1P2]bNh40:W6kPD0YlC^102XaNh50:S2k@@0YlK_102YaNh60:;An0<0
[/g`102Y_^T30:Nfi0D0Y;3P102V/>050:Nkj0@0Z;cX102Z_^P50:^mi`@0Z/?/102/a>`60:k6k0D0
/mCb102dbNX40:ngg`@0YJ?C1@2MW]D40:V]fP<0[;7L1@28X^D0100KHMH06Dg701U=a`3C`<L30>;>
a0<0j]S20P3dek420?CK/`<0m>2g0P3ci;`00`3`j<<0fMgJ0=WMfP030=?Mh0030000002bb>/0//S[
00<0//S[102X`N/90:O0j`/0oooo0`0000000`3oool000000?ooo`080?ooo`000P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool>
0:O0j`8000000P2W`>/40:Jnj`@0UK;[0`21WnH307VBg`@0SIoP0`2]_>@30;o;h`<0a=CV0`33e>L5
0;C=k@<0[LW^0P2[b>l40:W6kPD0YlG_102XaNh50:K5l0@0YlK_1@2Tao8208?YhPH0[/g`0`2Y_^T4
0::_h@D0Y;3P102V^^L40:Nkj080Z;cX0`2X_^T40:Znj0D0ZL;[102Z`n`40:c5k0<0[/K/0`2_dO82
0;?DlP<0/m?`102dbNX30:ngg`D0Ui?>102MW]D40:V]fP@0[;KP1@28X^D201]QeP@0h/k40`3Zf<80
103^hL80m=^c0?CK/`3dfk<20?CP]`80lnBl0`3`j<<30=?Mh0030<_Ki@000000bm_U0080//S[0`2_
a^/40:S1j`T0Yl3[1P3oool4000000@0oooo00<000000?ooo`3oool01`3oool00080oooo00@00000
0?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000001L0oooo2P2W`>/3000000D0Yl3[
102R_>`409Fbj`<0PIoV0`1iT]l408fOh0H0_l_S1033e>L20<3Bj0D0]<g]1@2[b>l50:O6k`@0YlG_
102U`nl50:K5l0D0YL;^0P26j^T50;;Rm`@0[/g`102Q[^440::_h@D0Y;SW102V^^L30:Nkj0H0Z;kY
0P2Z_^P20:S1j`@0ZL;[1@2[aN`40:c5k0D0[m7b1@2cdo050:6Ld0<0VI?<1@2GTlh309fNe@D0[k[R
102/]^0408RRi@<06f7F0P3Rc/@30>[H`P80k^720P3_j<D20?CP]`<0lnBl0P3`j<<20>c[b`@0bm_U
00<000000:o6j`2_a^/00`2_a^/50:S1j`T0Yl3[0P3oool3000000P0oooo00<000000?ooo`3oool0
1`3oool00080oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0
603oool50:O0j`<000001@2W`>/40:Joj`@0X[c/0`2E/^/3086OiP@0NI;O0P2=Wn020:Fbh@<0_l_S
1037d>050<3Bj0H0/<c^102Yao050:O6k`@0Y/C_102U`nl50:O3kP<0YL;^0P2CjOT30:cbm@@0XK;T
102O[^840:6^h@@0XkKV1@2T^>L30:Jji`@0YkkY1@2X_^T50:S1j`@0Z/G]1@2[aN`50:c>lPD0/MKc
102XZmP40:6Ld0@0VI?<102GTlh40:^ih`@0[k[R1@2W]^<408FQiP<00fgL0`3Zf<820>kQ`P<0knS5
00@0kNg80??T_03ci;`0lnBl0P3`j<<30>c[b`030>G/d`3;fnD0bm_U0080`]OY00<000000:o6j`2_
a^/00`2/a>`40:S1j`T0Yl3[0P00000<0?ooo`030000003oool0oooo00H0oooo00020?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`04
0:O0j`0000000000000000T0Yl3[102V_n/409Vhk@<0PjK[0`1_TN<307nFg`D0YK;Q1@37d>020<_A
g`<0`=;X0P2mdNT30;3<kP<0[Lc_102Yao050:K6l0@0Y/C_102WaNl50:O3kP80TnWi0P2/l_D40:Jm
jP@0XK;T102O[^840:6diP@0XkKV102T^>L40:JmjP@0YkkY202X`N/20:W4k@@0Z/G]1@2[c?450:kE
m0<0/MKc0P2]^^830:R[f0D0XIc@0`2ITl`50:BahP@0ZkWS0P2_^^820:bki0D0YkKS0`25XNH01@0O
H=D006C<00=]g003KM`0j]S200<0k^720P3_j<D20>g]b080jno<0P3`j<<30>c[b`80iNcC1@32enT0
0`000000[<C/0:c4k0030:c4k0@0Z<3[2@2W`>/=0?ooo`030000003oool0oooo00H0oooo00030?oo
o`8000002P3oool3000000<0oooo0P00000H0?ooo`<000003@2W`>/40:Bnk0@0VKS]0`23Y^/306nA
h`<0OiKO0`2U/^420;ZogP<0am3P103;dMl50;gAj@H0[Lc_102Wb?450:K6l0@0YLK`102WaNl409kL
o080Wo?]0`2_e?<40:JmjP<0XK;T1@2O/ND40:6diP<0XkKV1@2U_NX40:JmjP@0Yl7/1@2X`N/50:W4
k@@0ZL[a0`2[c?420:cDm@D0[]Gd1@2]^^830:R[f0@0XIc@102LY=/40:BahP@0ZkWS1@2/^n@40:Nf
h`<0QJ7V0P0OH=D2001Tc0<0k^720P3_j<D20>g]b0<0jno<00@0jNo?0>c[b`3/jl/0k>_;0P3Uk=<3
0=g[g@<0^M7/00<000000;WAk02Y`^`0102Y`^`40:S0j`P0Yl3[3@3oool00`000000oooo0?ooo`06
0?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`<00000103oool90:O0j`@0Yko[102T_^`309Vh
k@<0PjK[101_TN<307nFg`D0^[oN1@3;dMl30<_AgPH0^]7/102Zbo440:O8l@D0Y<Ka102Ua_050:;=
mP80Wo?]1P2_e?<30:JmjP@0W:kT1@2O/ND30:6diP@0Y;cZ102U_NX50:K1k0@0Yl7/1@2Xa>h50:S8
l0@0ZL[a1@2/e?D50:o6j`@0[K[R0`2XZmP509RHdP@0W:CK0`2T/N850:^ki@@0[;_T1@2R/nD3082O
iP03031[fP0OH=D00637008006370P3_j<D30>g]b080jno<0P3Ykll20>O`d@80iNcC0`3Mjmd20=;W
i@80^M7/00<0//_]0000002bbnd0102Y`^`=0:O0j``0oooo00<000000?ooo`3oool01P3oool001@0
oooo00<000000?ooo`3oool04P3oool3000000P0oooo2@2W`>/40:Noj`@0Wkc]102</>l206^Gj@<0
JHcR102CXn030;ZogP<0a/KI0P3;dMl50<_AgP<0^]7/0`2fdNh40:[;l@@0Y<Ob1@2Ta_450:C8lP80
Vo3c1@2ckOL509Z`iP<0VZgT102L[^@409nai@@0Xk_Z102T_>X40:G0k@D0Y/7/102W`nh30:S4kP80
YlS`1@2Xb?050:WBm@@0[Lka102_a^/509bCbP<0V9;<102HV=8409bTf`@0ZK_V1@2[^nD40:Vji@@0
X[?U1020WnH2031[fP03000_]P00LML0077G00<0kNg80P3[kl`20>W_c`80io3A0P3Vl=<30=g[g@<0
d^OU102bbnd00`000000Z<7[0:S1j`030:S1j`d0Yl3[2`3oool00`000000oooo0?ooo`060?ooo`00
503oool200000100oooo0`00000<0?ooo`T0Yl3[102V_n`409nlk@@0S;3_0P1[UnT306V<hP@0Tj?P
1P36a]T70<_AgPH0]]7^102Vc?@:0:C7lP@0WnGl0`2YmO040:2nkPD0V[3V0`2J[N@309b^i0D0XKWZ
102S^nX40:C0k@@0YL3]1@2V`nh40:O3kPD0YlS`1@2XdOH50:_Bm0@0[Lka102OUl/409bCbP@0V9;<
0`2HV=850:Vmj0@0ZK_V1@2Y_>L40:Vji@@0W;7V0`1jVnH3031[fP0400AEd@00;kH08hk/02>>k080
jno<0P3Ykll20>O`d@<0i_3C00<0i?;F0=;Wi@3BinD00P3BinD20<KOj`<0//_]00<0[<K/0000002X
`N/00`2X`N/>0:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool0
303oool300000140oooo202W`>/40:Jok0@0V;W_101gY_0205>8i`<0JHcR0P2CXn020:R_g0<0a/KI
103=b=@60<_AgP<0]]7^0`2cd_040:K<m0D0XLWd1P2OeO/20:Wel0@0Z]_i102P_^h409Z`iP@0V[?Y
0`2N]nT40:6ijPD0Xko]102T`>d40:G3kPD0Y/?^1@2Wao440:KAmP<0Z=7f0P2XdoL40:_Bm0D0Xic>
0`2OUl/509bCbP<0V9;<102X_NT50:Vmj0@0ZKcX102Y_>L50:JhiP@0W;7V0`1jVnH01@0nMMh0<6_J
031[fP04EM4002nf0080F:ci0P3Ykll20>O`d@<0i_3C0P3Tl]H20>3cfPD0a]o[0`2/a^`00`000000
[<K/0:S0j`030:S0j`d0Yl3[2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo
0?ooo`0:0?ooo`8000005@3oool80:O0j`D0Y;o/0`2H^Nl407NVl080DhSW0P1`T>850:R_g0D0cLSD
0P3Bam060<_AgPH0/m;`1@2PcOL409c>n@<0WmGk0`2Ml?<30:Gbl`<0Z]_i102A[^X409J_j0@0V[?Y
0`2N]nT40::okPD0Xko]102T`^l40:G3kPD0Y/Sa1@2Ud?L40:KAmPD0Z=?g102UXM440:>LcP@0WiO;
102LTlX40:Bgi`@0Z;gY1@2W^nL40:Vlj0@0Yk[W102V^>H409baiP@0NY_V0P0nMMh200AEd@D0QL?k
0`3Vl=<20>CbeP80h??J0P3Il^450;[EkP80[<K/00<0ZL;/0000002Y`^`0102X`>/=0:O0j`X0oooo
00<000000?ooo`3oool01@3oool001@0oooo00<000000?ooo`3oool01`3oool3000001P0oooo202W
`>/50:Bok0<0V;W_0`1gY_0305>8i`80L93R0`2X[m`20;Vfe`<0cLSD103Bam040<_AgP@0c=3M1@2_
do<409S?n`@0W<ki0`2Ml?<20:Gbl`@0SM7n0`2>]o84096^jP@0UZoX102L_>l309nnkP@0X[o^1@2S
`^l40:C2k`D0Y<Sb102Sd?L50:G@m`D0Y]Ch102VYM@40:FQd@@0Xic>0`2OUl/509n]h@@0Y;OW102W
^^L90:Nki`@0Yk[W102R]^L409J]i`<0MYSV0`0nMMh303IhhPD0Ym?g0P3Tl]H20>3cfP80fO;Q0P3>
jnT40;[EkP@0ZL;/00<000000:O0j`2W`>/03`2W`>/:0?ooo`030000003oool0oooo00D0oooo000C
0?ooo`<000001@3oool3000001`0oooo202W`>/50::nk@<0S[Ga0`1KV>l203ikh`<0L93R1@2i]]L5
0=;7d0<0e<G;1@3<d=d30<g=fPD0Zm?e0`2Hco/209;To080Q^_R1P23iO@308gAoP<0S[Ob0`2A[^X5
09Jil0@0W;c_0`2O_^h40:;3l0@0Xl;_1P2SbO@40:7@n0@0Xm3g1@2TdoP50:JWe`@0YZGD0`2UXM44
0:>LcP@0WZ?I102O[N450:Rki`@0Yk[W102X_NP40:Nki`D0Y[[W102R]^L409J]i`<0MYSV0P1>On44
03IhhP80Ym?g0`2ngo00103PlmX0fO;Q0=Wbh@3Il^440<k[j@D0/<_]0`2X`N/00`000000Yl3[0:O0
j`0?0:O0j`T0oooo00<000000?ooo`3oool01@3oool001<0oooo00<000000?ooo`3oool00P3oool3
00000200oooo102W`>/50:Jok0@0X[k]0`2>]O4305^Hk`80?W_S0`1nUn430;Vfe`<0a;S?0P3Bam04
0=C5b`040=K2a@3<d=d0c=3M0<c@g@<0cLgJ0P3>am@30:_Cm@<0[=?d0P22i_840:?`m@80]L[Z101k
^_X306b]n0<0Nk3e0`2<]O8409Jil0D0V/Ge102Oa?830:;3l0D0XL[e1@2Nd?T40:7@n0D0X];h202V
YmL40:JUe0@0WYW>102MWM<409jSf@80WjgQ0P2Y_nT40:Rki`D0Z;oZ102X_NP40:Nkj0@0Y[[W102R
]^L409J]i`<0MYSV0`1>On4306:Gk@@0_]o`00@0cNSY0=G`i03El>@0eO3T0`3>jnT30<3Ok`80/<_]
0`2[a>`20:S1j`030000002X`N/0Yl3[0100Yl3[203oool00`000000oooo0?ooo`050?ooo`004`3o
ool00`000000oooo00000002000002@0oooo102W`>/50:Jok0@0Wkg^0`21/?<203N4jP<0?W_S0`1n
Un400`2i]]L0a;S?0<Bhc`030<Bhc`@0e<G;0`3F`/D40<g=fP@0c/OD102/do@20;_Fk@<0d=3I1@2e
b^X407^jnP<0K:gh0`1k/?D308belP@0T/Gh1@2JaOD409W<n@@0WLcg102Kd?X409k@n@H0X<oh102U
Y=D70:JWe`D0X9S<0`2NVLh409fMd`@0WZ?I1@2Y_nT20:Rki`80YkkZ102X_nX50:Jkj0@0Yk_X0`2V
^^L509jdi`@0T:WW0`1cU^D3062<i@@0HYO]0P3=j>T30=G`i080e_CT1@30gnl50:_4k0<0Yl3[00<0
00000:O0j`2W`>/0402W`>/70?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000009`3oool4
0:O0j`D0Y[o/102O_Nh3086`l`80=hCZ0P0YL=h307jGh@D0a;S?0P3;^<P20=C5b`@0e/;50P3G_;l5
0<k7e0<0d;k90`2ke^d40=3@f@80el;5102^Y<h408RFfP<0M9g[0`1f/OL408FonP<0T/Gh1@2Bbo/4
09W<n@D0V<ok0`2Kd?X509o:mPD0Y:7B102UY=D30:JWe`@0XYS:102PV<`409jIcP<0WIgC1@2Y`n`4
0:Voj@D0YkkZ102V^^L40:Jkj0@0Yk_X102T^>L509jdi`<0T:WW101cU^D3062<i@@0R;;a0`3El>@2
0=Kdi0<0co;Y1@2cd>l40:S1k0<0Yl3[00<000000:O0j`2W`>/03`2W`>/70?ooo`030000003oool0
oooo00D0oooo000D0?ooo`030000003oool0oooo02L0oooo1@2W`>/40:Jok0@0W;c_0`1aZoD0100:
J]`0=hCZ02U`gP0YL=h308jOg`<0a;S?103;^<P40=K2a@<0ekbo00@0f;Nh0<k7e03>am@0c/OD0`3@
_/T30=:f_P@0d=3I0`3G`/D00`3E^[l0[ZC>0:jTcP020:jTcP<0R9KJ101dWN/307Jam`@0R[We102<
a_/309;;n`H0U/_j102P]NL409o1l0@0Y9c>102TXM840:FTe@@0XiS:0`2RV<X50:2Hc0<0WYW>1@2X
aNh30:W3k0D0Y[_X0`2W_^X20:Nkj0@0Y[[W0`2V^nP50:Fji`@0Y;SW1@2J/>L308VTiP<0M9KT0`1P
S>D50:W<lP80e_CT0`3?l^T30<?Vk`80/m3_0`2/a^d40:S1k080Yl3[00<000000:O0j`2W`>/0402W
`>/70?ooo`030000003oool0oooo00@0oooo000;0?ooo`D000001@3oool2000002T0oooo102W`>/4
0:Jok0@0W;c_0`1aZoD0100:J]`0:G3N02U`gP0YL=h308jOg`030<Bhc`3;^<P0bkS80080bkS80P3?
]/420=K2a@<0ekbo0`3H]kP40=2nb@@0d[Jn00<0f;Fe0=3@f@3@d=T00`3G`/D20=Fj_`@0[ZC>102M
T/P409BDd@@0SZGT0`2:^OD409V_iP@0Ul3d1@2QYm/40:2ei`@0Y9W:102TW<h30:BQdPD0YI[:0`2S
V<X40::HbP@0X9S<1@2WaNl40:Jhi@<0Y[WW1@2V^nP50:Nkj0<0Y[[W102W_>P50:Fji`@0X[OX102J
/>L408VTiP<0M9KT0`1gW>P30:W<lP80`N?_0P3=l^X50<?Vk`D0[<K]1`2W`>/00`000000Yl3[0:O0
j`0@0:O0j`H0oooo00<000000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0W0?ooo`@0Yl3[102V_n`409Vll080HJCe0P0:J]`2011Qf0<0SYoO103;^<P4
0<nf`@@0ekbo0`3H]kP00`3H/[80d;k90=2nb@040=:f_P<0f;Fe103G`/D30=Fj_`80[ZC>0P2_X<P3
09fBb0D0U9CA102SVL/309fOeP@0VJoV102RWM040:6Wf`D0YYS70`2TVLX40:BLcP@0Yig<102UV/X4
0:>HbP<0XYS:1@2Va>l20:O5k`<0YkOU102V^>D30:Jii`D0Z;kY102W^nP40:NnjP@0YkcX1@2T^^P4
0::gj0<0V[3W1029Y>H307BFi0@0MicX0`31hnl20<gbjP<0c?KZ1@2edo040:S2k0L0Yl3[00<00000
0:O0j`2W`>/0402W`>/50?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool09`3oool40:O0j`@0YKo/102I_?02066Tm@8004S40P0@HMP309ZT
g080bkS81@3?]/400`3B/k/0ekbo0=Nl_`040=Rg^080f;:b103B][h40=Re]@030>6j/03G`/D0el;5
00@0eKZo102_X<P409fBb080U9CA0`2XVlP30:>Ib`@0WIoF102VV/T40::Md080XJOK0P2ZVlP40:JH
a`@0Y9W:0P2TW<h20:ZRc`<0Yig<1@2UV/X30:>HbP@0Y/C^102Va>l50:Ngi@@0Y[SU102X`N/40:Rn
j@D0Y[gZ102W_^X40:Fjj0@0Y;[X1@2N/nL309F/iP@0QIoT0`1lV^D409:ck@<0cO;Z0P3<m^X30<;Y
l@80]M?`0`2/a^d30:S2k0P0Yl3[00<000000:O0j`2W`>/03`2W`>/50?ooo`030000003oool0oooo
00@0oooo000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool40:O0j`@0
YKo/102H_?0205>Nm08004S400<004[9011Qf02JY=`00P2JY=`50<nf`@<0d[>k00@0ekbo0=Rg^03H
]kP0f;Nh0`3H/[80103J/:d0d[Jn0=:f_P3B][h30=Re]@<0hKZ`103E^[l20=2ja0@0[j380`2MT/P5
0:RKb0@0XiW;0P2MWmH20:bNb@@0YY[90`2RWM040:ZKb0@0YYS7102TVLX40:ZRc`@0Yig<102UV/X4
0:O4kP@0Y/C^102W^>D40:Ngi@D0Z<;]102X`N/40:Jkj0@0Y[gZ1@2U^NL40:Fjj0@0X[OW102N/nL4
09F/iP<0QIoT101lV^D50:oAlP030<cfjP32jO40`^Wa00<0`^Wa1@2/a^d;0:O0j`030000002W`>/0
Yl3[0100Yl3[103oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0:0?oo
o`800000:03oool40:O0j`@0YKo/102H_?0205>Nm003000TXP00B<@004[900@0XZOI0`3?]/440=:c
^`@0f;Nh0`3H/[820=Z`[@030=:f_P3H]KD0f;Fe0080f;Fe0`3Q^[000`3W`Jl0eKZo0=Fj_`040=2j
a0<0[j38102YX<h40:RKb0@0XiW;102/W/T40:JJb@@0[Z?<102ZVlP30:JHa`D0[J[D102ZX/l30:NM
c0T0YlC^202W^>D40:O3k@@0Z<;]1@2V^^L40:Jkj0@0Yk_X102U^NL50:Fjj0@0X[OW0`2N/nL5092U
i0<0QIkS102<ZNP20:oAlP80a>k`0`36mn`40;CDl@D0Z<7/2`2W`>/00`000000Yl3[0:O0j`0?0:O0
j`@0oooo00<000000?ooo`3oool0103oool000`0oooo0P00000>0?ooo`030000003oool0oooo02H0
oooo102W`>/40:Fok0@0V;ca0P1;Vo<00`009:8004[9001:b@040::Wf@030<nf`@3B/k/0d[>k00<0
d[>k00<0e;6g0=Rg^03H]kP00`3H/[830=Z`[@@0f;Fe0`3Q^[030>O1[`D0d;[4102ZZ=@30:VPcP@0
Z9_81@2aYlh40:bNb@80YY[90P2b[M<30:jSc0@0ZY_8102_/m/50:fZe0<0ZZ;?102WaNl40:O4kPT0
YkSU102W`^d40:O3k@@0YkWV102V^^L50:Rmj@@0Yk_X102V_>T40:Fjj0D0X;KW0`2J[nH4092Ui0@0
QIkS0`2<ZNP30<C^l080a_O/0`2ojO820;CDl@80ZlK]102X`N`<0:O0j`030000002W`>/0Yl3[00l0
Yl3[0`3oool00`000000oooo0?ooo`040?ooo`007@3oool00`000000oooo0?ooo`0V0?ooo`@0Yl3[
102U_n`409Rll@<0Bi_c00<002BX001:b@2RYmT00P2RYmT50=:c^`<0e;6g00@0f;Nh0=Rb/P3H/[80
f;:b0`3J/:d0103M/Z/0f;Fe0=Re]@3H]KD30>6j/0<0il6_00@0j<Jc0=2ja03@^/@0d;[40P36^/l4
0:ZXe0<0ZJ3>0P2XVlP20:j^e`@0/JO>102/W/T40;:]d`@0[Z?<0P2ZVlP20:nkhP@0[k?K102]Z]@4
0:K4k`@0YlG_202W^>D90:O2k@P0YkWV102X`>/40:Rmj@T0Y[cY102S]nL40:2fi`@0VZoV0`2@YN@4
08FNh`D0Y/Oa00<0a_O/0;oYlP2ojO800`2ojO850:_6kA00Yl3[00<000000:O0j`2W`>/03P2W`>/4
0?ooo`030000003oool0oooo00<0oooo000N0?ooo`030000003oool0oooo02H0oooo1@2W`>/30:Fo
k0D0VKc`0P1;Vo@00`009:P0YJWI0:FYf@020:FYf@<0d[>k103D/KL40=Rb/P<0f[2]0P3M/Z/0103H
]KD0hKZ`0>6j/03Q^[030>O1[`<0j<Jc00<0d;[40<Jjc`36^/l00P36^/l30:ZXe0<0ZJ3>1@2^[]L3
0;6WcPD0/KKL102b[M<30:jSc0D0[k_R0`2_/m/50:G2kP@0Y/C_102W]nD40:Nhi@P0Yl;]2@2W^NH4
0:O1k0@0Z<3[102U^^P40:Jlj@D0Y;SW102S]nL409f_i@@0UJSS0`2=XN8408jVi@@0_Ngc0`30mnh4
0;;Al0D0Z<7/3`2W`>/00`000000Yl3[0:O0j`0@0:O0j`80oooo00<000000?ooo`3oool00`3oool0
01l0oooo0P00000X0?ooo`@0Yl3[102U_n`409Vll080Bi_d00<002BX0:FYf@2UZMT00P2UZMT00`3B
/k/0e;6g0=Ba]`030=Ba]`030=Ja]03H/[80f;:b00<0f[2]0`3M/Z/40>6j/0<0il6_0`3Xa[<50<Jj
c`@0X:_O0`2S[Ml40:j^e`@0Z[SS102a]]`40;:]d`@0ZkkW102_^n840:Fnj`@0YL;^1@2W^>D40:Ng
i@P0Yl;]102W^^H40:NiiPT0Yl7/102V^NL40:Fjj0@0Y[WW102T^>L50::fi`@0WJoU0`2EZ><408fQ
hPD0Y<Ga0`30mnh30;[Um0@0Z/C]102X`N`@0:O0j`030000002W`>/0Yl3[0100Yl3[00<0oooo0000
003oool0103oool00240oooo00<000000?ooo`3oool09P3oool40:O0j`D0Y[o/0`2J_?02056Nm@04
000TZ02UZMT0YJWI0:FYf@D0e;6g0`3F/K@0103H/[80f[2]0=Z`[@3J/:d30=fbZ`030>BiZ`3Q^[00
hKZ`00<0il6_103Xa[<0103Ta[T0a[[?0<Jjc`36^/l20;ffd`@0X:_O0`2S[Ml40:>fi@@0Z[SS0`2a
]]`50:Nlj0@0ZkkW102U^^P40:Fnj`@0Z;WV102W^>D50:O3k@@0Yl;]202W^^H50:O1k0@0YkWV102V
^NH40:Jii`@0YkcY102V^NL40:Bjj0@0X[KW102M[nD309FXh`D0TZOT0P2TaO430;Sam0@0^^Gd0P2^
c>l40:[4kA@0Yl3[00<000000:O0j`2W`>/03`2W`>/00`3oool000000?ooo`040?ooo`008P3oool0
0`000000oooo0?ooo`0V0?ooo`@0Yl3[1@2V_n`309Zll080DIke102PZ]h30=Ba]`@0e[6d103J/:d3
0=fbZ`80i;V[00@0hKZ`0>O1[`3W`Jl0il6_0`3Xa[<30>C6^@D0_KKC0`2PZml409jai@@0XkKU0`2Z
^><40:Fjj0D0YkcX102V^NL40:Fjj0@0ZKcW102X^NH40:O2k@@0Yl?]1@2W^NH40:NjiPD0Yl7/202W
^NH30:JiiPD0Yko[102W_>T40:Bjj@@0Y;[X102M[n<409VYhP<0TZ?P102BYn@40;Sam0<0^oGa102^
c>l50:S1ja@0Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`008`3oool0
0`000000oooo0?ooo`0V0?ooo`@0Yl3[1@2V_n`409bmk`0405ZSmP2PZ]h0X:[N0:2ZgP<0e;6g103F
/K@00`3G];H0f[2]0=Z`[@030=fbZ`<0i;V[0`3W`Jl30>S6/`@0i<Ji00<0g/:l0;ffd`2m]]<00P2m
]]<40:6^h0@0W[7U0`2S]^D40:Fii`@0YK[X1@2X^nL40:Jii`@0ZKkY102Y_>L40:K0k0@0Yl;]202W
^NH50:O1k0D0Yk[V1`2W^NH50:O0j`<0Yko[1@2T^NL40:Bjj@@0XK;T102M[n<309VYhP@0TZ?P1@2V
c_D00`2kmO40]M_d0;GKm0030;GKm0@0ZL;/102X`N/D0:O0j`030000002W`>/0Yl3[00l0Yl3[00<0
00000?ooo`3oool00`3oool002@0oooo0P00000W0?ooo`D0Yl3[102V_n`409fmk`0506>WmP2PZ]h0
X:[N0:2ZgP3D/KL0103F/K@20=Nd]P80f[2]0`3M/Z/30>BiZ`030>[3[03W`Jl0il6_00<0j<Jc0`3T
a[T20=k2_080_KKC0`2k]=<40:6^h0@0X[?U0`2T]nL40:Fii`@0YkcX102X^nL50:RnjP@0ZKkY102V
_NX40:K0k0@0Z;WV102W^NH50:O1k0P0Yk[V102W^NH50:O0k0@0Y[OU0`2U]nH40:Bii`D0Y;KU102Q
/^@309f_h`<0VJWR1@2FZnD20:K>m@80/oK`0`2hk_D40:_6kP@0ZL;/602W`>/00`000000Yl3[0:O0
j`0;0:O0j`<0oooo00<000000?ooo`3oool00`3oool002H0oooo00<000000?ooo`3oool09@3oool5
0:O0j`@0Y[o/102M_Nl30:2ZgP@0e[6d103G];H0103J/:d0gK:[0=fbZ`3M/Z/30>BiZ`80j/>/0`3X
a[<30>C6^@<0g/:l1P2k]=<40:J`g`@0X[?U0`2T]nL40:Jjj0@0YkcX102V_>T40:RnjPD0Y[_X102V
_NX40:RjiP@0Z;WV1@2W`N`40:NiiPL0Yk[V1@2W_n/50:Nhi@@0Y[OU0`2U]nH40:Jji`@0Y;KU1@2O
[n<309^Xg`<0UJ;N102FZnD20;?fl0<0^>ke0`2_d?430:_6kQd0Yl3[00<000000:O0j`2W`>/01P2W
`>/80?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo02D0oooo1@2W`>/4
0:Jok0@0Wkk^0`2=ZNP30=Ja]0@0ekBf0`3M/Z/30>BiZ`<0j/>/0P3]b:h40>C6^@<0g/:l00@0f[no
0;^dd`2k]=<0^kCC0`2l]=840:J`g`@0YKGT0`2U^>H80:Jjj0@0Y[cY102W^^L40:Jkj0D0ZKcW102X
^^H50:O1k0P0YkWV202W_n/40:Nii@@0YkSU102V]nD40:Jmj@@0Y[[W102Q/nD409n_h`@0VjSO0`2E
X]h30:[SnP<0/?O_1@2_d?440:S1ja`0Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`030000003o
ool0oooo0080oooo000X0?ooo`030000003oool0oooo02H0oooo102W`>/40:Jok0@0Wkk^0`2=ZNP0
0`3F/K@0ekBf0=Nd]P030=Nd]P030=Vj^`3M/Z/0gK:[00<0i;V[0`3Z`j`20>g8[P030>g:/03Ta[T0
i<Ji00<0g/:l0`3J_kl50;bddP80Y[3O0`2//]d40:Fei0<0YKSV102W^^L40:Jjj0@0Z;_W102W^^L4
0:Vnj@@0ZKcW1@2W_n/50:RiiP<0YkWV1@2W`>/40:Noj`@0YkWV102W^ND30:Nhi@D0Y[k[0`2V_NT5
0::ci0@0XK?U0`2O[n<409^Xg`@0WKc^0P2`mnl50;?Nm@@0ZL;/102X`N/L0:O0j`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00000W0?ooo`@0Yl3[102V_n`30:2n
kP<0SJWX1@3G];H30=Vj^`040=fbZ`3T^J/0i;V[0>BiZ`80j/>/0`3]b:h20>g:/0@0g/:l0`3J_kl0
0`3G_L40_;CB0;bddP020;bddPD0[;;M102U]N@40:Nii@@0Yk[W102X_>L40:Rki`D0Z;kY0`2Y_^T5
0:Nmj@@0Z;[V102X^NH40:S0j`@0Yl3[2@2W^NH80:Jnj`@0YK?R0`2T/^<40::ci0D0WjKK0`2JXMT4
09NTg`@0Y??a0P2ck_L50:_7kP<0ZL;/7P2W`>/30?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool09@3oool40:O0j`D0Y/3/0P2P_^h304nG
l@<0ekBf103I^[/30>BiZ`<0j/>/0P3]b:h30>g:/0030>c:/`3N`[`0g/:l00<0f[no0`3G_L420;bd
dP80_[G@102//]d50:VfhP@0YkWU102X^^L40:Rli`D0Z;cX102X^^H40:Nki`@0ZKcW102X^^H80:S0
j`@0YkWU102W^NH50:NnjP@0Y[k[102V]><40:FchP<0Y;;S102S[n0409nVf`@0VZ7I0P2GY=l30:7S
o0030;?^m`2]c_40[Lka0080[Lka102[anhM0:O0j`P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?ooo`D0Yl3[102W`>`20:6nkP<0
CiOa00<0ekBf0=Vj^`3I^[/00`3I^[/00`3Ja<<0i;V[0>BiZ`030>[3[080kLR^0`3]b[020>c:/`@0
f[no0`3G_L450;jed0@0/;CK102Y]^850:Vhi0@0Z;[W102X^^H50:VkiP@0Z;[V102Y_NP40:Vli`@0
YkoZ102X`>/40:Rhi@@0YkWU202W_^X50:Nfh`<0Y[CS102U/n840:Ffi@@0XjoP0`2OY]/409ZQf@03
0:7So02Vm?00Y_C`0080Y_C`0P2_f?D40:g>l@D0Z<3[602W`>/;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool002d0oooo00<000000?ooo`3oool09P3oool40:O0j`@0Yl3/
0`2R_^h00`00D<@0fKZk0=Vj^`030=Vj^`<0f/C300<0i;V[0>[3[03Z`j`00`3]b:h20>g:/0<0k<Zc
00<0j<Zh0=Zo_`3J_kl0103G_L40103D_L<0_[G@0;jed02n]M020<6fc`@0/;CK102/]^440:Vhi0D0
ZK[U0P2X^^H20:ZkiP@0ZK_V2@2Y_NP40:Nlj0@0YkoZ102X^>@40:Rhi@@0Z;kZ102W_^X40:Nfi0@0
YkKS0`2V]><50:Fii`@0YKKU0`2S[n0409ZYh@<0W<7b0`2Dl>T40:oHm@D0Z<;/6@2W`>/?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool002h0oooo00<000000?ooo`3oool0
9P3oool80:O0j`<0X[k^00@005340=Vj^`3I^[/0fKZk103Ja<<30>[3[080kLR^0`3]b[020>c:/`<0
j<Zh103G_L430=Bm``D0`KK?102d]=P40:bfh@@0ZkWS102Y^^D50:ZkiP@0ZK_W102Y_NP50:RjiP<0
YkcX1@2Y^ND40:Rhi0@0Z;oZ102X_^X40:Nfh`@0YkKT102V^^L30:Fjj0@0YKWW1@2NW]<309^Oe`@0
VZWQ00<0U?3Y0:oSn02_hoP00`2_hoP50:W4kAP0Yl3[503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0040oooo000_0?ooo`8000009`3oool80:O0j`<0X[o]00<005340=Vj^`3Ja<<0
0`3Ja<<30=c?c0<0kLR^0P3]b[030>c:/`<0j<Zh00<0iL^m0=Nm`@3G_L40103D_L<0103C_/H0`KK?
0<6fc`31]/l20<>fcP@0];CH102_]]h40:^ih`D0Zk[T102Z^ND40:Vki`@0ZKWU102X^^H40:Zji@@0
ZKWU202X_nX50:Rfh`@0YkKS102W^^L40:Jji`<0YK[X102RXM@409jNd`@0VioG00<0S^_a0:W]n02Y
kOP00`2YkOP40:[8k`T0Yl3[102W_n/<0:O0jaP0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0U0?ooo`P0Yl3[0`2R_nd40=[4``<0g<o<
0`3Of=030>g:/080k<Zc0`3Xb[P30>G;_@@0e;g30`3C_/H00`31]/l0`kK>0<>fcP020<>fcP80];CH
0P2h]=H40:nfgP@0[KOQ0`2[^^@20:bhhP@0Z[WU102[^^@40:Vii@@0ZkcV102Z^^D40:Rmj@@0Z;oZ
102X]N840:Rfh`P0Yk[W1@2UYmL30:BTeP@0XZ7D0`2NW]<409GRo@80VO3a1@2[cO8=0:O0j`<0Yko[
202W`>/L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<0
00000?ooo`3oool09@3oool80:O0j`<0Xko]0P3Ja<<30=c?c0<0gmS@0`3Qg]830>c:/`<0j<Zh0`3U
bkd00`3QcLD0e;g30=Bm``040=>naPD0`kK>1@2h]=H40;:ef`@0[KOQ1@2/^>840:bjh`@0Zk[T202[
_>H40:RkiP@0Z;gY102X]>440:RehP@0Z;_W102W^^L40:JYf0@0YJOG102TY=H30::Qe0D0W<ki00<0
VO3a0:_Bm02[d_@00`2[d_@40:S1ja@0Yl3[803oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0040oooo000c0?ooo`030000003oool0oooo02D0oooo2@2W`>/20:>ok@<0g<o<0`3Of=03
0>7NdP<0hN?F0`3Xb[P30>G;_@<0hLg5103C_/H20=70bP<0`kK>0P34^<h30;RdeP80^kCC102b]M/4
0:nfgP<0[;SR0P2^]ml40:bjh`@0ZkWT102[_>H40:Vgh`@0Z;_V102Y]>440:Rdh@@0ZK_V102X^nL4
0:NYf0@0YZWH0`2UYmL40:BTeP@0W[c]0P23jN@50:[Gm`@0Z<?/102X`N/40:O1k0`0Yl3[903oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000d0?ooo`8000009P3oool90:O0
j`<0Y;o]0`3Of=030>7NdP<0hN?F0`3Lim`30>G;_@@0hLg500<0fm7>0=>naP3C_/H0103A`<X50<Bh
cPD0^kCC102e]=L40:nfgPD0[[OO102/]Ml40:^ii0@0ZkGQ102Y]n<40:^fh@@0ZKCQ102Y^^H40:Vk
iP@0YjSG102WZMP30:JYf0@0Xj_M102Q/N<206oOf@@0Z=_i1@2YaNh30:S3k0P0Yl7/1@2W_n/30:O0
jbT0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`010?ooo`00=P3oool00`000000
oooo0?ooo`0U0?ooo`P0Yl3[102U_n`30>7NdP<0hN?F0`3Lim`30=3Zi`@0hLg50`3KdLh40=70bP80
clG@0`34^<h20<Jkd0<0^kCC0P2m]]840;Fde`@0/[?J0P2^]ml30;2cfP<0[;GO1@2]]=h30:^eh@D0
[;OQ102[]^440:Zgh`@0ZK[V102WYM@40:NXe`<0YjWH102UZMX40:>[g@80XK7S102Tgo/40:S7l0@0
ZLG^102W`>/40:O1k0P0Yko[;03oool00`000000oooo0?ooo`070?ooo`4000000@3oool10?ooo`00
=`3oool00`000000oooo0?ooo`0U0?ooo`P0Yl3[102U_n`00`2N_^l0hN?F0>7SeP040=cWg0<0d>[W
0P2jjo@20>7=a@<0fm7>0P3Cf=`20=70bP@0clG@00<0a;S>0<Jkd036^m000P36^m040;ffdP80]KCG
0`2h/m@30;:cfPD0/;?J0P2/]Ml20;2bfPP0[KCN102/]n450:ZagP<0Z[OS1@2XXm830:NUe0@0YjSG
102WZ]T40:FYfP<0Xj_M0`2OhOd40:S9l@@0Z<O`102W_n/40:O0j`P0Yko[<03oool00`000000oooo
0?ooo`060?ooo`4000000@3oool10?ooo`00>03oool00`000000oooo0?ooo`0U0?ooo`L0Yl3[1@2V
_n`309jnk`80NKCh0P3@j^L50;[[m0<0fm7>103Cf=`50<o5d0@0a[_@0P36`]H30;ffdPD0^;?D102e
/]H40;2cfPD0/;;J0P2]]=h20:j_f@@0[KCN102ZZmL40:ZagP@0ZJ?@102XXm830:NUe0D0ZJkK0`2W
Z]T40:FYfP<0V^;m102WbO840:S9l@@0YkkZ102W_n/40:S0jcP0oooo00<000000?ooo`3oool01@3o
ool100000040oooo0@3oool003T0oooo0P00000V0?ooo`L0Yl3[102V_n`40::ok@@0SK[e1P2>h_d3
0=?Hg0<0`N7_0P3?aM030<_>g080a[_@0`36`]H20;ffdP80`;_E0`2h/m@20;^geP@0]K;F102b/=H4
0;2bfPD0[ZoI0P2]]=h20:fYd`@0ZZ_G0P2Z/Mh20:fWdP@0ZJ?@0`2XXm840:beg`@0ZJkK0`2WZ]T3
09KPoPD0Y/[b0`2WbO880:NnjPD0Z<7/>`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`00>`3oool00`000000oooo0?ooo`0T0?ooo`L0Yl3[1@2W`>`30::ok@D0V[ga0P1//_X304O1
k`D0`N7_1@3;c]`50<K2ePD0`;_E1@2k]mH20;FbeP80^;KG102b/=H40;6^e@@0[ZoI1@2]ZM<30:Z[
e`D0[JOB0`2YXm040:o1i`@0[;GO0P1Bcm<409?MoPP0Y/[b1@2X_^X40:O2k@@0Z<;/?`3oool00`00
0000oooo0?ooo`040?ooo`4000000@3oool10?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo``0
Yl3[102U_n`40:6okP@0S;_f00<0@jGg001//P2Ah?h0102Ah?h40;_Ml@<0a/;F0P31d^L30<2ke@80
_l_T102k]mH50;Rfe`80/[3F0P2g]mT40;6^e@@0/[3F102]ZM<40;:bf@@0[JOB102^d_<40:o1i`03
04S8c@2Cf_h0Tm[n00<0Tm[n1@2UbO840:NnjP@0Z;kZ202W`^e30?ooo`030000003oool0oooo00<0
oooo0@0000010?ooo`40oooo000m0?ooo`030000003oool0oooo02@0oooo302W`>/40:K0k0@0XKo^
102L__0407^inP0402FKk@0c]NH0<kGV03>eiP<0^mga1@31d^L50;o;i0@0_<[U102h]]L50;Ngf@80
/JkE0P2ha><40;:`eP@0]/SX102b/]T409oTo0@0[];c00<0?l;903k2c`2Ee_d00`2Ee_d50:G8lPL0
YkkZ202W`^e80?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40oooo000n0?ooo`800000
9@3oool<0:O0j`@0Y/3/102U_n`409bnl0@0U[kc101^^?`0100LW>L0O=[l07cJo01lf_`509SQo@@0
W>?m102lb^D40;WAk0@0]kOI1@2ha><20;:`eP80Z>?k0`2fb>P507COk`80B/SR1@2KcOT309SAo0@0
YLKa202W_^X80:O2kD/0oooo00<000000?ooo`3oool00`3oool100000040oooo00100?ooo`030000
003oool0oooo02<0oooo4@2W`>/30:Fok0D0Xko]0`2F__<509>nm0<0J[Wm00<08j?X02fbg`0]/]l0
0`0]/]l309cSo@D0S>;l0`2idN`40:_RnP@0^<CS102Xho/204?5eP0303Jkf@1id?l0NM3o0080NM3o
102NbOH50:G2kP<0YLC_202W_^X80:O2kDl0oooo00<000000?ooo`3oool00P3oool100000040oooo
00110?ooo`030000003oool0oooo02<0oooo4@2W`>/40:O0k0@0Y/3/202R_nh309Bom0<0LKgm1@1o
`O`304fjn0<0:K3M0`1Ndnd203:hf@0304:kl01fbOl0M/Wo0080M/Wo1@2GaoP308_<o@@0XLGb102V
`>`40:G2kP@0Z;oZ102W_^X80:O2kE<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3o
ool00`000000oooo0?ooo`0T0?oooa@0Yl3[1`2V`>`40::okP@0Xl3^102H`?<509k0l@<0Sl;h1@2L
`_<308k5nP@0W/?b1@2U`Nd30:?2k`@0Yko[102V`>`40:Roj`@0Z;oZ202W`^eG0?ooo`040000003o
ool0oooo00000040oooo00130?ooo`8000009@3ooolG0:O0j`T0Y/3/0`2S`>h50:C0k@@0Y/3/102S
`>h40:K0k0<0Xl7^102V`>`40:G1k@@0Yl3[102W_n/40:S1j`@0Z;o[102W`NaN0?ooo`040000003o
ool0oooo00000040oooo00150?ooo`030000003oool0oooo02<0oooo802W`>/40:O0k0@0Yl3[102V
`>`40:O0k0<0Y/3/102W`>/40:K0k0P0Yl3[1@2W`N`30:S1j`@0Yl3/HP3oool00`000000oooo0000
00010?ooo`00AP3oool00`000000oooo0?ooo`0S0?ooob`0Yl3[0`2W`>`@0:O0j`@0Yl3/202W_n]V
0?ooo`4000000@3oool100000000A`3oool00`000000oooo0?ooo`0S0?ooocl0Yl3[102X_n/40:No
jfX0oooo0P00000004P0oooo0P00000U0?ooocX0Yl3[102X`>/40:Rojfd0oooo0P00000004X0oooo
00<000000?ooo`3oool08`3ooolj0:O0j`@0Z<3[L03oool200000000B`3oool00`000000oooo0?oo
o`0R0?oooc/0Yl3[K`3oool400000080oooo001<0?ooo`030000003oool0oooo02<0oooo<`2W`>]a
0?ooo`@000001P3oool004d0oooo0P00000T0?ooobl0Yl3[L03oool4000000X0oooo001?0?ooo`03
0000003oool0oooo0280oooo:`2W`>]_0?ooo`@000003P3oool00500oooo00<000000?ooo`3oool0
8`3ooolV0:O0jfh0oooo1000000B0?ooo`00D@3oool00`000000oooo0?ooo`0S0?ooob80Yl3[KP3o
ool3000001H0oooo001B0?ooo`800000903ooolN0:O0jfd0oooo1000000I0?ooo`00E03oool00`00
0000oooo0?ooo`0R0?oooaL0Yl3[K`3oool4000001d0oooo001E0?ooo`030000003oool0oooo0240
oooo502W`>]^0?ooo`@000008@3oool005H0oooo00<000000?ooo`3oool08P3oool?0:O0jfd0oooo
1000000U0?ooo`00E`3oool2000002<0oooo2`2W`>]/0?ooo`@00000:@3oool005T0oooo00<00000
0?ooo`3oool08@3oool40:O0jfl0oooo0`00000]0?ooo`00FP3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo06X0oooo1000000`0?ooo`00F`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo06H0oooo1000000d0?ooo`00G03oool200000240oooo00<000000?ooo`3oool0
HP3oool4000003P0oooo001N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3o
ool4000003`0oooo001O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool4
00000400oooo001P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool30000
04@0oooo001Q0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`@00000A`3oool006<0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000B`3oool006@0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`@00000C`3oool006D0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`170?ooo`@00000D`3oool006H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`@00000E`3oool006L0oooo0P00000F0?ooo`03
0000003oool0oooo0400oooo0`00001K0?ooo`00J@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo03`0oooo1000001N0?ooo`00JP3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03P0oooo1000001R0?ooo`00J`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo03@0oooo1000001V0?ooo`00K03oool200000100oooo00<000000?ooo`3oool0<@3oool40000
06X0oooo001^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;@3oool4000006h0
oooo001_0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3oool300000780oooo
001`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool4000007D0oooo001a
0?ooo`8000002`3oool00`000000oooo0?ooo`0R0?ooo`@00000N@3oool007<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000O@3oool007@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000P@3oool007D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0F0?ooo`@00000Q@3oool007H0oooo0P0000060?ooo`030000003o
ool0oooo01<0oooo0`0000290?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00l0oooo1000002<0?ooo`00N@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo1000002@0?ooo`00NP3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002D0?oo
o`00N`3oool2000000030?ooo`000000oooo00@0oooo1000002H0?ooo`00O@3oool2000000030?oo
o`000000000000800000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69272 .42772 .68706 Mtetra
.656 .752 .92 r
.42772 .68706 .43406 .69272 .44494 .68966 .43863 .68396 Mtetra
.656 .751 .92 r
.43863 .68396 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.656 .752 .92 r
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.656 .751 .92 r
.46057 .67775 .46682 .68349 .47783 .68038 .47161 .67462 Mtetra
.656 .752 .92 r
.47161 .67462 .47783 .68038 .48889 .67727 .48269 .67148 Mtetra
.656 .751 .92 r
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.656 .752 .92 r
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.656 .751 .92 r
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.656 .752 .92 r
.51621 .66199 .52232 .66784 .53355 .66467 .52747 .6588 Mtetra
.52747 .6588 .53355 .66467 .54483 .66149 .53878 .65559 Mtetra
.53878 .65559 .54483 .66149 .55616 .65833 .55014 .65235 Mtetra
.656 .75 .919 r
.55014 .65235 .55616 .65833 .56753 .65511 .56155 .64913 Mtetra
.655 .75 .92 r
.56155 .64913 .56753 .65511 .57895 .65185 .573 .64592 Mtetra
.654 .752 .922 r
.573 .64592 .57895 .65185 .59042 .64857 .5845 .6427 Mtetra
.655 .756 .924 r
.5845 .6427 .59042 .64857 .60193 .64533 .59605 .63943 Mtetra
.657 .756 .923 r
.59605 .63943 .60193 .64533 .6135 .64211 .60764 .63611 Mtetra
.658 .754 .921 r
.60764 .63611 .6135 .64211 .62511 .63891 .61928 .63275 Mtetra
.658 .749 .918 r
.61928 .63275 .62511 .63891 .63677 .63567 .63097 .62939 Mtetra
.657 .746 .915 r
.63097 .62939 .63677 .63567 .64848 .63241 .64271 .62603 Mtetra
.657 .744 .914 r
.64271 .62603 .64848 .63241 .66024 .62911 .6545 .62268 Mtetra
.657 .743 .913 r
.6545 .62268 .66024 .62911 .67205 .62579 .66634 .61932 Mtetra
.656 .742 .913 r
.66634 .61932 .67205 .62579 .6839 .62244 .67823 .61596 Mtetra
.656 .743 .913 r
.67823 .61596 .6839 .62244 .69581 .61907 .69017 .61259 Mtetra
.656 .743 .914 r
.69017 .61259 .69581 .61907 .70776 .61567 .70216 .60921 Mtetra
.655 .745 .916 r
.70216 .60921 .70776 .61567 .71977 .61224 .71421 .60584 Mtetra
.655 .747 .918 r
.71421 .60584 .71977 .61224 .73182 .60878 .7263 .60246 Mtetra
.654 .751 .921 r
.7263 .60246 .73182 .60878 .74393 .60529 .73845 .59907 Mtetra
.654 .755 .924 r
.73845 .59907 .74393 .60529 .75608 .60182 .75065 .59565 Mtetra
.656 .758 .925 r
.75065 .59565 .75608 .60182 .7683 .59841 .76289 .59215 Mtetra
.657 .756 .923 r
.76289 .59215 .7683 .59841 .78057 .59503 .77519 .58861 Mtetra
.657 .752 .92 r
.77519 .58861 .78057 .59503 .79289 .59161 .78754 .58508 Mtetra
.656 .749 .918 r
.78754 .58508 .79289 .59161 .80525 .5881 .79995 .58157 Mtetra
.655 .749 .919 r
.79995 .58157 .80525 .5881 .81767 .58457 .81241 .57807 Mtetra
.655 .752 .921 r
.81241 .57807 .81767 .58457 .83015 .58104 .82493 .57453 Mtetra
.656 .752 .921 r
.82493 .57453 .83015 .58104 .84268 .57752 .8375 .57097 Mtetra
.656 .752 .92 r
.8375 .57097 .84268 .57752 .85526 .57398 .85012 .56738 Mtetra
.656 .751 .92 r
.85012 .56738 .85526 .57398 .8679 .57041 .8628 .56379 Mtetra
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56323 .88832 .55656 Mtetra
.88832 .55656 .89334 .56323 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68706 .42134 .68134 Mtetra
.42134 .68134 .42772 .68706 .43863 .68396 .43227 .67823 Mtetra
.43227 .67823 .43863 .68396 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66881 Mtetra
.46533 .66881 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66247 Mtetra
.4876 .66247 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Mtetra
.51005 .65608 .51621 .66199 .52747 .6588 .52135 .65286 Mtetra
.52135 .65286 .52747 .6588 .53878 .65559 .53269 .64964 Mtetra
.655 .751 .921 r
.53269 .64964 .53878 .65559 .55014 .65235 .54408 .64641 Mtetra
.655 .752 .921 r
.54408 .64641 .55014 .65235 .56155 .64913 .55551 .64316 Mtetra
.656 .753 .921 r
.55551 .64316 .56155 .64913 .573 .64592 .567 .63987 Mtetra
.657 .751 .92 r
.567 .63987 .573 .64592 .5845 .6427 .57853 .63657 Mtetra
.655 .748 .919 r
.57853 .63657 .5845 .6427 .59605 .63943 .59011 .63331 Mtetra
.652 .749 .92 r
.59011 .63331 .59605 .63943 .60764 .63611 .60174 .63011 Mtetra
.65 .753 .925 r
.60174 .63011 .60764 .63611 .61928 .63275 .61342 .62694 Mtetra
.649 .76 .93 r
.61342 .62694 .61928 .63275 .63097 .62939 .62515 .62376 Mtetra
.648 .767 .936 r
.62515 .62376 .63097 .62939 .64271 .62603 .63693 .62055 Mtetra
.649 .773 .94 r
.63693 .62055 .64271 .62603 .6545 .62268 .64876 .61729 Mtetra
.65 .778 .942 r
.64876 .61729 .6545 .62268 .66634 .61932 .66064 .61396 Mtetra
.651 .78 .942 r
.66064 .61396 .66634 .61932 .67823 .61596 .67256 .61057 Mtetra
.654 .781 .942 r
.67256 .61057 .67823 .61596 .69017 .61259 .68454 .6071 Mtetra
.656 .779 .939 r
.68454 .6071 .69017 .61259 .70216 .60921 .69656 .60357 Mtetra
.658 .775 .935 r
.69656 .60357 .70216 .60921 .71421 .60584 .70863 .59998 Mtetra
.66 .769 .93 r
.70863 .59998 .71421 .60584 .7263 .60246 .72075 .59637 Mtetra
.66 .762 .925 r
.72075 .59637 .7263 .60246 .73845 .59907 .73292 .59274 Mtetra
.659 .754 .92 r
.73292 .59274 .73845 .59907 .75065 .59565 .74515 .58915 Mtetra
.657 .749 .918 r
.74515 .58915 .75065 .59565 .76289 .59215 .75743 .58563 Mtetra
.655 .749 .919 r
.75743 .58563 .76289 .59215 .77519 .58861 .76977 .58214 Mtetra
.655 .751 .921 r
.76977 .58214 .77519 .58861 .78754 .58508 .78217 .57864 Mtetra
.656 .754 .922 r
.78217 .57864 .78754 .58508 .79995 .58157 .79461 .57509 Mtetra
.656 .753 .921 r
.79461 .57509 .79995 .58157 .81241 .57807 .80711 .57151 Mtetra
.656 .751 .92 r
.80711 .57151 .81241 .57807 .82493 .57453 .81966 .56794 Mtetra
.81966 .56794 .82493 .57453 .8375 .57097 .83227 .56435 Mtetra
.83227 .56435 .8375 .57097 .85012 .56738 .84493 .56074 Mtetra
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66881 .45901 .66296 Mtetra
.45901 .66296 .46533 .66881 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66247 .48134 .65658 Mtetra
.48134 .65658 .4876 .66247 .4988 .65929 .49257 .65336 Mtetra
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Mtetra
.50385 .65014 .51005 .65608 .52135 .65286 .51518 .6469 Mtetra
.655 .752 .921 r
.51518 .6469 .52135 .65286 .53269 .64964 .52655 .64366 Mtetra
.52655 .64366 .53269 .64964 .54408 .64641 .53797 .64041 Mtetra
.653 .751 .922 r
.53797 .64041 .54408 .64641 .55551 .64316 .54944 .63721 Mtetra
.648 .752 .925 r
.54944 .63721 .55551 .64316 .567 .63987 .56095 .63411 Mtetra
.643 .758 .932 r
.56095 .63411 .567 .63987 .57853 .63657 .57252 .63112 Mtetra
.637 .768 .943 r
.57252 .63112 .57853 .63657 .59011 .63331 .58414 .62821 Mtetra
.631 .78 .953 r
.58414 .62821 .59011 .63331 .60174 .63011 .59581 .62534 Mtetra
.625 .792 .962 r
.59581 .62534 .60174 .63011 .61342 .62694 .60754 .62249 Mtetra
.62 .804 .97 r
.60754 .62249 .61342 .62694 .62515 .62376 .61932 .61962 Mtetra
.616 .816 .977 r
.61932 .61962 .62515 .62376 .63693 .62055 .63115 .61669 Mtetra
.615 .828 .982 r
.63115 .61669 .63693 .62055 .64876 .61729 .64303 .61364 Mtetra
.617 .838 .984 r
.64303 .61364 .64876 .61729 .66064 .61396 .65496 .61042 Mtetra
.624 .846 .984 r
.65496 .61042 .66064 .61396 .67256 .61057 .66693 .60701 Mtetra
.633 .849 .982 r
.66693 .60701 .67256 .61057 .68454 .6071 .67894 .6034 Mtetra
.644 .847 .978 r
.67894 .6034 .68454 .6071 .69656 .60357 .691 .59962 Mtetra
.653 .84 .972 r
.691 .59962 .69656 .60357 .70863 .59998 .7031 .59571 Mtetra
.66 .83 .965 r
.7031 .59571 .70863 .59998 .72075 .59637 .71524 .59172 Mtetra
.663 .818 .958 r
.71524 .59172 .72075 .59637 .73292 .59274 .72744 .58773 Mtetra
.665 .805 .95 r
.72744 .58773 .73292 .59274 .74515 .58915 .73968 .58374 Mtetra
.666 .792 .942 r
.73968 .58374 .74515 .58915 .75743 .58563 .75198 .57979 Mtetra
.665 .777 .933 r
.75198 .57979 .75743 .58563 .76977 .58214 .76433 .57592 Mtetra
.661 .763 .926 r
.76433 .57592 .76977 .58214 .78217 .57864 .77675 .57217 Mtetra
.658 .755 .922 r
.77675 .57217 .78217 .57864 .79461 .57509 .78923 .56853 Mtetra
.656 .752 .921 r
.78923 .56853 .79461 .57509 .80711 .57151 .80176 .56492 Mtetra
.80176 .56492 .80711 .57151 .81966 .56794 .81436 .56131 Mtetra
.656 .752 .92 r
.81436 .56131 .81966 .56794 .83227 .56435 .827 .55768 Mtetra
.656 .751 .92 r
.827 .55768 .83227 .56435 .84493 .56074 .8397 .55404 Mtetra
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54672 Mtetra
.86527 .54672 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Mtetra
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .6474 Mtetra
.655 .751 .921 r
.48629 .6474 .49257 .65336 .50385 .65014 .4976 .64416 Mtetra
.654 .751 .921 r
.4976 .64416 .50385 .65014 .51518 .6469 .50896 .64095 Mtetra
.65 .752 .924 r
.50896 .64095 .51518 .6469 .52655 .64366 .52036 .63782 Mtetra
.642 .754 .93 r
.52036 .63782 .52655 .64366 .53797 .64041 .53181 .63487 Mtetra
.629 .761 .942 r
.53181 .63487 .53797 .64041 .54944 .63721 .54332 .63219 Mtetra
.609 .775 .96 r
.54332 .63219 .54944 .63721 .56095 .63411 .55487 .62979 Mtetra
.579 .794 .981 r
.55487 .62979 .56095 .63411 .57252 .63112 .56649 .62768 Mtetra
.535 .815 .997 r
.56649 .62768 .57252 .63112 .58414 .62821 .57817 .62579 Mtetra
.473 .83 .995 r
.57817 .62579 .58414 .62821 .59581 .62534 .58991 .62397 Mtetra
.398 .828 .959 r
.58991 .62397 .59581 .62534 .60754 .62249 .6017 .62201 Mtetra
.331 .809 .897 r
.6017 .62201 .60754 .62249 .61932 .61962 .61355 .61977 Mtetra
.293 .791 .843 r
.61355 .61977 .61932 .61962 .63115 .61669 .62544 .61717 Mtetra
.286 .787 .814 r
.62544 .61717 .63115 .61669 .64303 .61364 .63739 .61425 Mtetra
.297 .794 .808 r
.63739 .61425 .64303 .61364 .65496 .61042 .64937 .61105 Mtetra
.317 .806 .813 r
.64937 .61105 .65496 .61042 .66693 .60701 .6614 .60762 Mtetra
.342 .822 .822 r
.6614 .60762 .66693 .60701 .67894 .6034 .67348 .60394 Mtetra
.375 .841 .836 r
.67348 .60394 .67894 .6034 .691 .59962 .68559 .59999 Mtetra
.424 .869 .861 r
.68559 .59999 .691 .59962 .7031 .59571 .69773 .5957 Mtetra
.493 .903 .901 r
.69773 .5957 .7031 .59571 .71524 .59172 .7099 .59106 Mtetra
.571 .928 .943 r
.7099 .59106 .71524 .59172 .72744 .58773 .7221 .58612 Mtetra
.636 .928 .972 r
.7221 .58612 .72744 .58773 .73968 .58374 .73434 .58103 Mtetra
.671 .9 .977 r
.73434 .58103 .73968 .58374 .75198 .57979 .74662 .57601 Mtetra
.682 .862 .968 r
.74662 .57601 .75198 .57979 .76433 .57592 .75896 .5712 Mtetra
.68 .826 .954 r
.75896 .5712 .76433 .57592 .77675 .57217 .77136 .56667 Mtetra
.673 .796 .94 r
.77136 .56667 .77675 .57217 .78923 .56853 .78384 .56243 Mtetra
.666 .773 .93 r
.78384 .56243 .78923 .56853 .80176 .56492 .79639 .55846 Mtetra
.66 .76 .924 r
.79639 .55846 .80176 .56492 .81436 .56131 .80901 .55468 Mtetra
.657 .754 .921 r
.80901 .55468 .81436 .56131 .827 .55768 .82169 .55097 Mtetra
.656 .752 .92 r
.82169 .55097 .827 .55768 .8397 .55404 .83443 .54729 Mtetra
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Mtetra
.656 .751 .92 r
.84723 .54361 .85246 .55039 .86527 .54672 .86008 .53991 Mtetra
.86008 .53991 .86527 .54672 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Mtetra
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .6479 Mtetra
.655 .751 .92 r
.45743 .6479 .46381 .65386 .47503 .65063 .46867 .64466 Mtetra
.654 .751 .921 r
.46867 .64466 .47503 .65063 .48629 .6474 .47996 .64144 Mtetra
.65 .752 .924 r
.47996 .64144 .48629 .6474 .4976 .64416 .4913 .63832 Mtetra
.639 .753 .931 r
.4913 .63832 .4976 .64416 .50896 .64095 .50269 .63545 Mtetra
.617 .759 .947 r
.50269 .63545 .50896 .64095 .52036 .63782 .51412 .63303 Mtetra
.576 .774 .973 r
.51412 .63303 .52036 .63782 .53181 .63487 .52561 .63119 Mtetra
.502 .792 .997 r
.52561 .63119 .53181 .63487 .54332 .63219 .53715 .62991 Mtetra
.386 .793 .982 r
.53715 .62991 .54332 .63219 .55487 .62979 .54876 .62891 Mtetra
.267 .763 .899 r
.54876 .62891 .55487 .62979 .56649 .62768 .56044 .62768 Mtetra
.242 .757 .835 r
.56044 .62768 .56649 .62768 .57817 .62579 .57217 .62576 Mtetra
.348 .823 .878 r
.57217 .62576 .57817 .62579 .58991 .62397 .58394 .62295 Mtetra
.515 .892 .964 r
.58394 .62295 .58991 .62397 .6017 .62201 .59575 .61942 Mtetra
.627 .883 .988 r
.59575 .61942 .6017 .62201 .61355 .61977 .6076 .61548 Mtetra
.666 .827 .961 r
.6076 .61548 .61355 .61977 .62544 .61717 .6195 .61143 Mtetra
.671 .776 .929 r
.6195 .61143 .62544 .61717 .63739 .61425 .63145 .60749 Mtetra
.665 .742 .908 r
.63145 .60749 .63739 .61425 .64937 .61105 .64345 .60377 Mtetra
.656 .724 .899 r
.64345 .60377 .64937 .61105 .6614 .60762 .65551 .60032 Mtetra
.648 .722 .902 r
.65551 .60032 .6614 .60762 .67348 .60394 .66764 .59712 Mtetra
.639 .734 .917 r
.66764 .59712 .67348 .60394 .68559 .59999 .67983 .59415 Mtetra
.628 .764 .944 r
.67983 .59415 .68559 .59999 .69773 .5957 .69208 .59128 Mtetra
.612 .813 .977 r
.69208 .59128 .69773 .5957 .7099 .59106 .70439 .58831 Mtetra
.583 .871 .994 r
.70439 .58831 .7099 .59106 .7221 .58612 .71673 .58491 Mtetra
.544 .907 .964 r
.71673 .58491 .7221 .58612 .73434 .58103 .72908 .58078 Mtetra
.535 .92 .916 r
.72908 .58078 .73434 .58103 .74662 .57601 .74143 .57573 Mtetra
.587 .942 .918 r
.74143 .57573 .74662 .57601 .75896 .5712 .75377 .56997 Mtetra
.66 .949 .955 r
.75377 .56997 .75896 .5712 .77136 .56667 .76613 .56398 Mtetra
.696 .912 .97 r
.76613 .56398 .77136 .56667 .78384 .56243 .77856 .55825 Mtetra
.696 .855 .959 r
.77856 .55825 .78384 .56243 .79639 .55846 .79106 .55308 Mtetra
.681 .807 .942 r
.79106 .55308 .79639 .55846 .80901 .55468 .80366 .54851 Mtetra
.668 .775 .93 r
.80366 .54851 .80901 .55468 .82169 .55097 .81635 .5444 Mtetra
.66 .76 .923 r
.81635 .5444 .82169 .55097 .83443 .54729 .82912 .54054 Mtetra
.657 .754 .921 r
.82912 .54054 .83443 .54729 .84723 .54361 .84196 .53679 Mtetra
.656 .752 .92 r
.84196 .53679 .84723 .54361 .86008 .53991 .85485 .53305 Mtetra
.656 .751 .92 r
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Mtetra
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Mtetra
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Mtetra
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Mtetra
.655 .751 .921 r
.43976 .64515 .44623 .65113 .45743 .6479 .45099 .64191 Mtetra
.652 .751 .922 r
.45099 .64191 .45743 .6479 .46867 .64466 .46226 .63873 Mtetra
.643 .752 .928 r
.46226 .63873 .46867 .64466 .47996 .64144 .47358 .63578 Mtetra
.619 .755 .943 r
.47358 .63578 .47996 .64144 .4913 .63832 .48494 .63335 Mtetra
.568 .764 .971 r
.48494 .63335 .4913 .63832 .50269 .63545 .49635 .63173 Mtetra
.464 .774 .997 r
.49635 .63173 .50269 .63545 .51412 .63303 .50781 .63096 Mtetra
.303 .755 .957 r
.50781 .63096 .51412 .63303 .52561 .63119 .51934 .63053 Mtetra
.218 .734 .867 r
.51934 .63053 .52561 .63119 .53715 .62991 .53093 .6295 Mtetra
.359 .825 .907 r
.53093 .6295 .53715 .62991 .54876 .62891 .54258 .62704 Mtetra
.606 .9 .987 r
.54258 .62704 .54876 .62891 .56044 .62768 .55428 .62307 Mtetra
.702 .82 .938 r
.55428 .62307 .56044 .62768 .57217 .62576 .56601 .6182 Mtetra
.7 .727 .871 r
.56601 .6182 .57217 .62576 .58394 .62295 .57777 .61316 Mtetra
.682 .672 .833 r
.57777 .61316 .58394 .62295 .59575 .61942 .58959 .60843 Mtetra
.668 .645 .818 r
.58959 .60843 .59575 .61942 .6076 .61548 .60145 .60412 Mtetra
.659 .635 .815 r
.60145 .60412 .6076 .61548 .6195 .61143 .61337 .60017 Mtetra
.655 .635 .819 r
.61337 .60017 .6195 .61143 .63145 .60749 .62534 .59645 Mtetra
.652 .638 .824 r
.62534 .59645 .63145 .60749 .64345 .60377 .63737 .59287 Mtetra
.65 .641 .827 r
.63737 .59287 .64345 .60377 .65551 .60032 .64945 .58938 Mtetra
.648 .64 .828 r
.64945 .58938 .65551 .60032 .66764 .59712 .66159 .58598 Mtetra
.644 .635 .826 r
.66159 .58598 .66764 .59712 .67983 .59415 .67378 .58272 Mtetra
.638 .628 .824 r
.67378 .58272 .67983 .59415 .69208 .59128 .68605 .5797 Mtetra
.63 .622 .824 r
.68605 .5797 .69208 .59128 .70439 .58831 .69839 .57704 Mtetra
.62 .623 .832 r
.69839 .57704 .70439 .58831 .71673 .58491 .71082 .57481 Mtetra
.611 .642 .857 r
.71082 .57481 .71673 .58491 .72908 .58078 .72332 .57288 Mtetra
.609 .696 .905 r
.72332 .57288 .72908 .58078 .74143 .57573 .73589 .5708 Mtetra
.617 .8 .969 r
.73589 .5708 .74143 .57573 .75377 .56997 .74846 .56778 Mtetra
.62 .908 .983 r
.74846 .56778 .75377 .56997 .76613 .56398 .76099 .56321 Mtetra
.63 .951 .938 r
.76099 .56321 .76613 .56398 .77856 .55825 .77345 .55717 Mtetra
.681 .96 .943 r
.77345 .55717 .77856 .55825 .79106 .55308 .78591 .5505 Mtetra
.714 .924 .963 r
.78591 .5505 .79106 .55308 .80366 .54851 .79843 .54418 Mtetra
.704 .856 .955 r
.79843 .54418 .80366 .54851 .81635 .5444 .81106 .53872 Mtetra
.682 .8 .938 r
.81106 .53872 .81635 .5444 .82912 .54054 .8238 .5341 Mtetra
.666 .769 .927 r
.8238 .5341 .82912 .54054 .84196 .53679 .83665 .53001 Mtetra
.659 .756 .922 r
.83665 .53001 .84196 .53679 .85485 .53305 .84958 .52615 Mtetra
.656 .752 .921 r
.84958 .52615 .85485 .53305 .86781 .5293 .86257 .52235 Mtetra
.656 .752 .92 r
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Mtetra
.656 .751 .92 r
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Mtetra
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Mtetra
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Mtetra
.655 .751 .921 r
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63915 Mtetra
.65 .751 .924 r
.43325 .63915 .43976 .64515 .45099 .64191 .4445 .63603 Mtetra
.634 .751 .933 r
.4445 .63603 .45099 .64191 .46226 .63873 .4558 .63329 Mtetra
.592 .754 .956 r
.4558 .63329 .46226 .63873 .47358 .63578 .46713 .63138 Mtetra
.494 .759 .99 r
.46713 .63138 .47358 .63578 .48494 .63335 .4785 .63062 Mtetra
.314 .739 .973 r
.4785 .63062 .48494 .63335 .49635 .63173 .48993 .63064 Mtetra
.195 .713 .88 r
.48993 .63064 .49635 .63173 .50781 .63096 .50143 .63019 Mtetra
.381 .831 .932 r
.50143 .63019 .50781 .63096 .51934 .63053 .51301 .6279 Mtetra
.659 .885 .98 r
.51301 .6279 .51934 .63053 .53093 .6295 .52464 .62352 Mtetra
.718 .776 .898 r
.52464 .62352 .53093 .6295 .54258 .62704 .53632 .61806 Mtetra
.699 .693 .841 r
.53632 .61806 .54258 .62704 .55428 .62307 .54803 .61276 Mtetra
.677 .66 .825 r
.54803 .61276 .55428 .62307 .56601 .6182 .55978 .60814 Mtetra
.666 .661 .835 r
.55978 .60814 .56601 .6182 .57777 .61316 .57158 .60412 Mtetra
.662 .681 .857 r
.57158 .60412 .57777 .61316 .58959 .60843 .58344 .60039 Mtetra
.661 .705 .88 r
.58344 .60039 .58959 .60843 .60145 .60412 .59535 .59674 Mtetra
.661 .724 .896 r
.59535 .59674 .60145 .60412 .61337 .60017 .6073 .59311 Mtetra
.66 .734 .904 r
.6073 .59311 .61337 .60017 .62534 .59645 .61931 .5895 Mtetra
.658 .737 .908 r
.61931 .5895 .62534 .59645 .63737 .59287 .63137 .58593 Mtetra
.656 .738 .91 r
.63137 .58593 .63737 .59287 .64945 .58938 .64349 .58242 Mtetra
.654 .737 .911 r
.64349 .58242 .64945 .58938 .66159 .58598 .65566 .57896 Mtetra
.652 .735 .911 r
.65566 .57896 .66159 .58598 .67378 .58272 .66789 .57555 Mtetra
.651 .731 .908 r
.66789 .57555 .67378 .58272 .68605 .5797 .68017 .57215 Mtetra
.651 .721 .9 r
.68017 .57215 .68605 .5797 .69839 .57704 .69251 .56876 Mtetra
.648 .701 .885 r
.69251 .56876 .69839 .57704 .71082 .57481 .70491 .56546 Mtetra
.639 .672 .866 r
.70491 .56546 .71082 .57481 .72332 .57288 .71738 .56245 Mtetra
.623 .643 .849 r
.71738 .56245 .72332 .57288 .73589 .5708 .72995 .56004 Mtetra
.605 .628 .848 r
.72995 .56004 .73589 .5708 .74846 .56778 .74263 .55833 Mtetra
.597 .653 .876 r
.74263 .55833 .74846 .56778 .76099 .56321 .75539 .55677 Mtetra
.617 .748 .939 r
.75539 .55677 .76099 .56321 .77345 .55717 .76815 .5541 Mtetra
.657 .891 .981 r
.76815 .5541 .77345 .55717 .78591 .5505 .7808 .54929 Mtetra
.684 .959 .945 r
.7808 .54929 .78591 .5505 .79843 .54418 .79336 .54257 Mtetra
.721 .959 .945 r
.79336 .54257 .79843 .54418 .81106 .53872 .80591 .53536 Mtetra
.726 .901 .957 r
.80591 .53536 .81106 .53872 .8238 .5341 .81856 .52894 Mtetra
.698 .827 .944 r
.81856 .52894 .8238 .5341 .83665 .53001 .83135 .52372 Mtetra
.673 .779 .93 r
.83135 .52372 .83665 .53001 .84958 .52615 .84428 .51936 Mtetra
.661 .759 .923 r
.84428 .51936 .84958 .52615 .86257 .52235 .8573 .51538 Mtetra
.657 .753 .921 r
.8573 .51538 .86257 .52235 .87562 .51856 .87039 .51152 Mtetra
.656 .752 .92 r
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Mtetra
.656 .751 .92 r
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Mtetra
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Mtetra
.654 .751 .921 r
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63638 Mtetra
.648 .751 .924 r
.41544 .63638 .42204 .64239 .43325 .63915 .42668 .63329 Mtetra
.626 .75 .936 r
.42668 .63329 .43325 .63915 .4445 .63603 .43795 .63072 Mtetra
.564 .751 .965 r
.43795 .63072 .4445 .63603 .4558 .63329 .44924 .62927 Mtetra
.416 .742 .993 r
.44924 .62927 .4558 .63329 .46713 .63138 .46057 .62921 Mtetra
.201 .691 .923 r
.46057 .62921 .46713 .63138 .4785 .63062 .47197 .62967 Mtetra
.242 .746 .893 r
.47197 .62967 .4785 .63062 .48993 .63064 .48345 .62872 Mtetra
.59 .891 .99 r
.48345 .62872 .48993 .63064 .50143 .63019 .49502 .62509 Mtetra
.723 .804 .915 r
.49502 .62509 .50143 .63019 .51301 .6279 .50665 .61955 Mtetra
.71 .71 .848 r
.50665 .61955 .51301 .6279 .52464 .62352 .51831 .61386 Mtetra
.687 .676 .834 r
.51831 .61386 .52464 .62352 .53632 .61806 .53001 .60894 Mtetra
.676 .683 .85 r
.53001 .60894 .53632 .61806 .54803 .61276 .54175 .60462 Mtetra
.674 .706 .872 r
.54175 .60462 .54803 .61276 .55978 .60814 .55354 .60052 Mtetra
.673 .72 .884 r
.55354 .60052 .55978 .60814 .57158 .60412 .56537 .59647 Mtetra
.67 .719 .886 r
.56537 .59647 .57158 .60412 .58344 .60039 .57725 .59251 Mtetra
.666 .713 .883 r
.57725 .59251 .58344 .60039 .59535 .59674 .58919 .58868 Mtetra
.662 .707 .881 r
.58919 .58868 .59535 .59674 .6073 .59311 .60117 .58498 Mtetra
.659 .705 .881 r
.60117 .58498 .6073 .59311 .61931 .5895 .61321 .58136 Mtetra
.657 .705 .882 r
.61321 .58136 .61931 .5895 .63137 .58593 .6253 .57778 Mtetra
.656 .705 .883 r
.6253 .57778 .63137 .58593 .64349 .58242 .63745 .57424 Mtetra
.655 .705 .884 r
.63745 .57424 .64349 .58242 .65566 .57896 .64965 .57073 Mtetra
.653 .703 .884 r
.64965 .57073 .65566 .57896 .66789 .57555 .6619 .56726 Mtetra
.65 .702 .884 r
.6619 .56726 .66789 .57555 .68017 .57215 .67422 .56388 Mtetra
.646 .701 .886 r
.67422 .56388 .68017 .57215 .69251 .56876 .68659 .56063 Mtetra
.642 .704 .892 r
.68659 .56063 .69251 .56876 .70491 .56546 .69904 .55751 Mtetra
.639 .708 .897 r
.69904 .55751 .70491 .56546 .71738 .56245 .71154 .55447 Mtetra
.636 .707 .898 r
.71154 .55447 .71738 .56245 .72995 .56004 .72411 .55149 Mtetra
.63 .691 .888 r
.72411 .55149 .72995 .56004 .74263 .55833 .73675 .54872 Mtetra
.614 .659 .87 r
.73675 .54872 .74263 .55833 .75539 .55677 .7495 .54656 Mtetra
.593 .636 .864 r
.7495 .54656 .75539 .55677 .76815 .5541 .76238 .54518 Mtetra
.592 .667 .891 r
.76238 .54518 .76815 .5541 .7808 .54929 .77531 .54364 Mtetra
.64 .789 .953 r
.77531 .54364 .7808 .54929 .79336 .54257 .78817 .54013 Mtetra
.702 .929 .965 r
.78817 .54013 .79336 .54257 .80591 .53536 .80086 .53386 Mtetra
.736 .966 .936 r
.80086 .53386 .80591 .53536 .81856 .52894 .81346 .52612 Mtetra
.745 .927 .95 r
.81346 .52612 .81856 .52894 .83135 .52372 .82614 .51891 Mtetra
.712 .847 .946 r
.82614 .51891 .83135 .52372 .84428 .51936 .83899 .51314 Mtetra
.678 .787 .932 r
.83899 .51314 .84428 .51936 .8573 .51538 .852 .50854 Mtetra
.662 .761 .923 r
.852 .50854 .8573 .51538 .87039 .51152 .86512 .50446 Mtetra
.657 .753 .921 r
.86512 .50446 .87039 .51152 .88354 .50768 .87831 .50055 Mtetra
.656 .752 .92 r
.87831 .50055 .88354 .50768 .89676 .50382 .89156 .49665 Mtetra
.656 .751 .92 r
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Mtetra
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63685 Mtetra
.654 .751 .921 r
.3864 .63685 .3931 .64289 .40425 .63962 .39757 .63359 Mtetra
.648 .751 .924 r
.39757 .63359 .40425 .63962 .41544 .63638 .40879 .63049 Mtetra
.623 .749 .937 r
.40879 .63049 .41544 .63638 .42668 .63329 .42003 .62798 Mtetra
.548 .746 .968 r
.42003 .62798 .42668 .63329 .43795 .63072 .4313 .62679 Mtetra
.36 .72 .987 r
.4313 .62679 .43795 .63072 .44924 .62927 .44258 .62723 Mtetra
.138 .654 .891 r
.44258 .62723 .44924 .62927 .46057 .62921 .45393 .62804 Mtetra
.308 .782 .927 r
.45393 .62804 .46057 .62921 .47197 .62967 .4654 .62675 Mtetra
.67 .875 .976 r
.4654 .62675 .47197 .62967 .48345 .62872 .47696 .62231 Mtetra
.731 .765 .88 r
.47696 .62231 .48345 .62872 .49502 .62509 .48859 .61623 Mtetra
.709 .7 .839 r
.48859 .61623 .49502 .62509 .50665 .61955 .50025 .61044 Mtetra
.691 .689 .843 r
.50025 .61044 .50665 .61955 .51831 .61386 .51194 .60543 Mtetra
.684 .703 .861 r
.51194 .60543 .51831 .61386 .53001 .60894 .52366 .60089 Mtetra
.677 .71 .873 r
.52366 .60089 .53001 .60894 .54175 .60462 .53543 .59666 Mtetra
.669 .71 .879 r
.53543 .59666 .54175 .60462 .55354 .60052 .54725 .59275 Mtetra
.662 .714 .887 r
.54725 .59275 .55354 .60052 .56537 .59647 .55912 .58907 Mtetra
.658 .724 .897 r
.55912 .58907 .56537 .59647 .57725 .59251 .57104 .58551 Mtetra
.657 .736 .907 r
.57104 .58551 .57725 .59251 .58919 .58868 .58301 .58196 Mtetra
.657 .745 .915 r
.58301 .58196 .58919 .58868 .60117 .58498 .59503 .57838 Mtetra
.657 .75 .918 r
.59503 .57838 .60117 .58498 .61321 .58136 .60711 .57479 Mtetra
.656 .751 .92 r
.60711 .57479 .61321 .58136 .6253 .57778 .61923 .57121 Mtetra
.655 .752 .921 r
.61923 .57121 .6253 .57778 .63745 .57424 .63141 .56764 Mtetra
.654 .751 .921 r
.63141 .56764 .63745 .57424 .64965 .57073 .64365 .56409 Mtetra
.653 .751 .921 r
.64365 .56409 .64965 .57073 .6619 .56726 .65594 .56054 Mtetra
.653 .749 .92 r
.65594 .56054 .6619 .56726 .67422 .56388 .66828 .55698 Mtetra
.654 .745 .916 r
.66828 .55698 .67422 .56388 .68659 .56063 .68068 .55338 Mtetra
.654 .735 .909 r
.68068 .55338 .68659 .56063 .69904 .55751 .69314 .5498 Mtetra
.65 .721 .9 r
.69314 .5498 .69904 .55751 .71154 .55447 .70565 .54633 Mtetra
.643 .707 .894 r
.70565 .54633 .71154 .55447 .72411 .55149 .71824 .5431 Mtetra
.633 .698 .892 r
.71824 .5431 .72411 .55149 .73675 .54872 .73091 .54019 Mtetra
.623 .691 .892 r
.73091 .54019 .73675 .54872 .7495 .54656 .74366 .5376 Mtetra
.61 .674 .887 r
.74366 .5376 .7495 .54656 .76238 .54518 .75651 .53548 Mtetra
.588 .647 .876 r
.75651 .53548 .76238 .54518 .77531 .54364 .76949 .53414 Mtetra
.578 .648 .883 r
.76949 .53414 .77531 .54364 .78817 .54013 .78257 .53309 Mtetra
.62 .736 .93 r
.78257 .53309 .78817 .54013 .80086 .53386 .79559 .53035 Mtetra
.709 .895 .964 r
.79559 .53035 .80086 .53386 .81346 .52612 .80841 .52434 Mtetra
.757 .964 .933 r
.80841 .52434 .81346 .52612 .82614 .51891 .82107 .51616 Mtetra
.761 .935 .942 r
.82107 .51616 .82614 .51891 .83899 .51314 .8338 .50836 Mtetra
.721 .853 .944 r
.8338 .50836 .83899 .51314 .852 .50854 .84672 .50225 Mtetra
.681 .788 .931 r
.84672 .50225 .852 .50854 .86512 .50446 .85981 .49752 Mtetra
.662 .761 .923 r
.85981 .49752 .86512 .50446 .87831 .50055 .87303 .49339 Mtetra
.657 .753 .921 r
.87303 .49339 .87831 .50055 .89156 .49665 .88633 .48943 Mtetra
.656 .752 .92 r
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Mtetra
.656 .751 .92 r
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63406 Mtetra
.655 .751 .921 r
.36848 .63406 .37527 .64012 .3864 .63685 .37964 .63077 Mtetra
.65 .751 .923 r
.37964 .63077 .3864 .63685 .39757 .63359 .39084 .62762 Mtetra
.627 .749 .935 r
.39084 .62762 .39757 .63359 .40879 .63049 .40207 .62502 Mtetra
.55 .742 .965 r
.40207 .62502 .40879 .63049 .42003 .62798 .4133 .62382 Mtetra
.344 .704 .984 r
.4133 .62382 .42003 .62798 .4313 .62679 .42454 .62455 Mtetra
.091 .617 .874 r
.42454 .62455 .4313 .62679 .44258 .62723 .43584 .62587 Mtetra
.301 .774 .933 r
.43584 .62587 .44258 .62723 .45393 .62804 .44727 .6248 Mtetra
.688 .866 .966 r
.44727 .6248 .45393 .62804 .4654 .62675 .45883 .62006 Mtetra
.739 .759 .869 r
.45883 .62006 .4654 .62675 .47696 .62231 .47047 .61351 Mtetra
.717 .704 .837 r
.47047 .61351 .47696 .62231 .48859 .61623 .48212 .60733 Mtetra
.698 .696 .845 r
.48212 .60733 .48859 .61623 .50025 .61044 .4938 .60203 Mtetra
.684 .704 .862 r
.4938 .60203 .50025 .61044 .51194 .60543 .50552 .59746 Mtetra
.672 .711 .877 r
.50552 .59746 .51194 .60543 .52366 .60089 .51727 .59342 Mtetra
.666 .723 .892 r
.51727 .59342 .52366 .60089 .53543 .59666 .52907 .58962 Mtetra
.665 .736 .903 r
.52907 .58962 .53543 .59666 .54725 .59275 .54092 .58583 Mtetra
.666 .741 .906 r
.54092 .58583 .54725 .59275 .55912 .58907 .55282 .582 Mtetra
.665 .737 .903 r
.55282 .582 .55912 .58907 .57104 .58551 .56477 .57818 Mtetra
.663 .729 .899 r
.56477 .57818 .57104 .58551 .58301 .58196 .57677 .57441 Mtetra
.66 .723 .896 r
.57677 .57441 .58301 .58196 .59503 .57838 .58882 .57072 Mtetra
.658 .72 .895 r
.58882 .57072 .59503 .57838 .60711 .57479 .60093 .56708 Mtetra
.657 .719 .895 r
.60093 .56708 .60711 .57479 .61923 .57121 .61309 .56347 Mtetra
.656 .719 .895 r
.61309 .56347 .61923 .57121 .63141 .56764 .6253 .55987 Mtetra
.655 .719 .895 r
.6253 .55987 .63141 .56764 .64365 .56409 .63756 .55629 Mtetra
.654 .718 .896 r
.63756 .55629 .64365 .56409 .65594 .56054 .64989 .55273 Mtetra
.652 .718 .897 r
.64989 .55273 .65594 .56054 .66828 .55698 .66227 .54922 Mtetra
.649 .72 .9 r
.66227 .54922 .66828 .55698 .68068 .55338 .67471 .54579 Mtetra
.647 .724 .905 r
.67471 .54579 .68068 .55338 .69314 .5498 .68721 .54242 Mtetra
.646 .731 .911 r
.68721 .54242 .69314 .5498 .70565 .54633 .69977 .53906 Mtetra
.646 .735 .914 r
.69977 .53906 .70565 .54633 .71824 .5431 .71238 .53564 Mtetra
.646 .73 .91 r
.71238 .53564 .71824 .5431 .73091 .54019 .72506 .53224 Mtetra
.639 .714 .902 r
.72506 .53224 .73091 .54019 .74366 .5376 .73781 .52908 Mtetra
.623 .693 .895 r
.73781 .52908 .74366 .5376 .75651 .53548 .75066 .52646 Mtetra
.601 .672 .89 r
.75066 .52646 .75651 .53548 .76949 .53414 .76363 .52457 Mtetra
.575 .646 .884 r
.76363 .52457 .76949 .53414 .78257 .53309 .77675 .52359 Mtetra
.563 .643 .888 r
.77675 .52359 .78257 .53309 .79559 .53035 .78997 .52296 Mtetra
.612 .724 .925 r
.78997 .52296 .79559 .53035 .80841 .52434 .80312 .52045 Mtetra
.722 .886 .956 r
.80312 .52045 .80841 .52434 .82107 .51616 .81601 .51413 Mtetra
.78 .961 .925 r
.81601 .51413 .82107 .51616 .8338 .50836 .82872 .50535 Mtetra
.773 .931 .936 r
.82872 .50535 .8338 .50836 .84672 .50225 .8415 .49717 Mtetra
.722 .846 .94 r
.8415 .49717 .84672 .50225 .85981 .49752 .85452 .49101 Mtetra
.678 .783 .929 r
.85452 .49101 .85981 .49752 .87303 .49339 .86773 .4863 Mtetra
.661 .759 .922 r
.86773 .4863 .87303 .49339 .88633 .48943 .88105 .48217 Mtetra
.657 .752 .921 r
.88105 .48217 .88633 .48943 .89969 .48549 .89445 .47817 Mtetra
.656 .752 .92 r
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Mtetra
.656 .751 .92 r
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Mtetra
.655 .751 .92 r
.3505 .63126 .35737 .63735 .36848 .63406 .36165 .62795 Mtetra
.652 .751 .922 r
.36165 .62795 .36848 .63406 .37964 .63077 .37283 .62472 Mtetra
.635 .749 .93 r
.37283 .62472 .37964 .63077 .39084 .62762 .38404 .62192 Mtetra
.57 .742 .957 r
.38404 .62192 .39084 .62762 .40207 .62502 .39526 .62042 Mtetra
.373 .702 .984 r
.39526 .62042 .40207 .62502 .4133 .62382 .40645 .62111 Mtetra
.056 .58 .87 r
.40645 .62111 .4133 .62382 .42454 .62455 .41769 .62306 Mtetra
.196 .706 .897 r
.41769 .62306 .42454 .62455 .43584 .62587 .42906 .62292 Mtetra
.67 .874 .975 r
.42906 .62292 .43584 .62587 .44727 .6248 .44061 .61847 Mtetra
.752 .771 .869 r
.44061 .61847 .44727 .6248 .45883 .62006 .45226 .61144 Mtetra
.73 .712 .833 r
.45226 .61144 .45883 .62006 .47047 .61351 .46393 .6046 Mtetra
.705 .699 .841 r
.46393 .6046 .47047 .61351 .48212 .60733 .4756 .59896 Mtetra
.686 .706 .863 r
.4756 .59896 .48212 .60733 .4938 .60203 .48731 .59431 Mtetra
.675 .719 .882 r
.48731 .59431 .4938 .60203 .50552 .59746 .49905 .59017 Mtetra
.672 .731 .894 r
.49905 .59017 .50552 .59746 .51727 .59342 .51083 .58615 Mtetra
.669 .731 .896 r
.51083 .58615 .51727 .59342 .52907 .58962 .52266 .58221 Mtetra
.664 .727 .896 r
.52266 .58221 .52907 .58962 .54092 .58583 .53454 .57844 Mtetra
.659 .726 .899 r
.53454 .57844 .54092 .58583 .55282 .582 .54648 .57483 Mtetra
.656 .733 .906 r
.54648 .57483 .55282 .582 .56477 .57818 .55846 .57129 Mtetra
.655 .742 .913 r
.55846 .57129 .56477 .57818 .57677 .57441 .5705 .56774 Mtetra
.655 .749 .919 r
.5705 .56774 .57677 .57441 .58882 .57072 .58259 .56415 Mtetra
.656 .753 .922 r
.58259 .56415 .58882 .57072 .60093 .56708 .59473 .56054 Mtetra
.655 .755 .923 r
.59473 .56054 .60093 .56708 .61309 .56347 .60692 .55691 Mtetra
.655 .755 .924 r
.60692 .55691 .61309 .56347 .6253 .55987 .61917 .55328 Mtetra
.654 .755 .924 r
.61917 .55328 .6253 .55987 .63756 .55629 .63147 .54966 Mtetra
.63147 .54966 .63756 .55629 .64989 .55273 .64383 .54602 Mtetra
.655 .753 .922 r
.64383 .54602 .64989 .55273 .66227 .54922 .65625 .54235 Mtetra
.656 .75 .919 r
.65625 .54235 .66227 .54922 .67471 .54579 .66871 .53865 Mtetra
.656 .742 .913 r
.66871 .53865 .67471 .54579 .68721 .54242 .68123 .53493 Mtetra
.653 .732 .907 r
.68123 .53493 .68721 .54242 .69977 .53906 .69382 .53129 Mtetra
.648 .723 .903 r
.69382 .53129 .69977 .53906 .71238 .53564 .70647 .5278 Mtetra
.643 .72 .904 r
.70647 .5278 .71238 .53564 .72506 .53224 .71918 .52448 Mtetra
.64 .722 .908 r
.71918 .52448 .72506 .53224 .73781 .52908 .73197 .52125 Mtetra
.635 .719 .908 r
.73197 .52125 .73781 .52908 .75066 .52646 .74482 .51813 Mtetra
.62 .7 .902 r
.74482 .51813 .75066 .52646 .76363 .52457 .75778 .51553 Mtetra
.59 .668 .894 r
.75778 .51553 .76363 .52457 .77675 .52359 .77088 .51394 Mtetra
.554 .637 .887 r
.77088 .51394 .77675 .52359 .78997 .52296 .78415 .51356 Mtetra
.545 .639 .894 r
.78415 .51356 .78997 .52296 .80312 .52045 .79752 .51337 Mtetra
.621 .741 .932 r
.79752 .51337 .80312 .52045 .81601 .51413 .81076 .51048 Mtetra
.752 .904 .945 r
.81076 .51048 .81601 .51413 .82872 .50535 .82366 .50313 Mtetra
.802 .959 .914 r
.82366 .50313 .82872 .50535 .8415 .49717 .83639 .4936 Mtetra
.776 .914 .933 r
.83639 .4936 .8415 .49717 .85452 .49101 .84927 .48539 Mtetra
.713 .827 .936 r
.84927 .48539 .85452 .49101 .86773 .4863 .86241 .47948 Mtetra
.672 .773 .926 r
.86241 .47948 .86773 .4863 .88105 .48217 .87574 .47492 Mtetra
.659 .756 .921 r
.87574 .47492 .88105 .48217 .89445 .47817 .88917 .4708 Mtetra
.656 .752 .92 r
.88917 .4708 .89445 .47817 .90792 .47418 .90269 .46676 Mtetra
.656 .751 .92 r
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Mtetra
.654 .751 .921 r
.34359 .62512 .3505 .63126 .36165 .62795 .35475 .62183 Mtetra
.644 .75 .926 r
.35475 .62183 .36165 .62795 .37283 .62472 .36596 .61878 Mtetra
.6 .744 .945 r
.36596 .61878 .37283 .62472 .38404 .62192 .37716 .61674 Mtetra
.443 .713 .981 r
.37716 .61674 .38404 .62192 .39526 .62042 .38834 .61693 Mtetra
.078 .572 .895 r
.38834 .61693 .39526 .62042 .40645 .62111 .39951 .61933 Mtetra
.014 .572 .814 r
.39951 .61933 .40645 .62111 .41769 .62306 .41079 .62077 Mtetra
.579 .874 .994 r
.41079 .62077 .41769 .62306 .42906 .62292 .42229 .61751 Mtetra
.763 .8 .883 r
.42229 .61751 .42906 .62292 .44061 .61847 .43395 .61024 Mtetra
.749 .725 .83 r
.43395 .61024 .44061 .61847 .45226 .61144 .44565 .60249 Mtetra
.718 .703 .835 r
.44565 .60249 .45226 .61144 .46393 .6046 .45733 .59618 Mtetra
.694 .708 .858 r
.45733 .59618 .46393 .6046 .4756 .59896 .46903 .59118 Mtetra
.68 .72 .879 r
.46903 .59118 .4756 .59896 .48731 .59431 .48076 .58682 Mtetra
.672 .726 .89 r
.48076 .58682 .48731 .59431 .49905 .59017 .49253 .58278 Mtetra
.664 .727 .896 r
.49253 .58278 .49905 .59017 .51083 .58615 .50434 .57899 Mtetra
.66 .733 .904 r
.50434 .57899 .51083 .58615 .52266 .58221 .5162 .57533 Mtetra
.661 .742 .911 r
.5162 .57533 .52266 .58221 .53454 .57844 .52812 .57163 Mtetra
.663 .746 .912 r
.52812 .57163 .53454 .57844 .54648 .57483 .54008 .56785 Mtetra
.663 .742 .909 r
.54008 .56785 .54648 .57483 .55846 .57129 .5521 .56405 Mtetra
.661 .735 .904 r
.5521 .56405 .55846 .57129 .5705 .56774 .56417 .56028 Mtetra
.659 .729 .901 r
.56417 .56028 .5705 .56774 .58259 .56415 .57628 .55656 Mtetra
.658 .725 .899 r
.57628 .55656 .58259 .56415 .59473 .56054 .58846 .55289 Mtetra
.657 .724 .899 r
.58846 .55289 .59473 .56054 .60692 .55691 .60068 .54923 Mtetra
.656 .724 .899 r
.60068 .54923 .60692 .55691 .61917 .55328 .61297 .54557 Mtetra
.655 .724 .899 r
.61297 .54557 .61917 .55328 .63147 .54966 .6253 .54192 Mtetra
.654 .723 .9 r
.6253 .54192 .63147 .54966 .64383 .54602 .6377 .53829 Mtetra
.653 .724 .901 r
.6377 .53829 .64383 .54602 .65625 .54235 .65015 .53469 Mtetra
.651 .726 .904 r
.65015 .53469 .65625 .54235 .66871 .53865 .66265 .53115 Mtetra
.649 .731 .909 r
.66265 .53115 .66871 .53865 .68123 .53493 .67522 .52764 Mtetra
.649 .738 .914 r
.67522 .52764 .68123 .53493 .69382 .53129 .68785 .5241 Mtetra
.65 .743 .917 r
.68785 .5241 .69382 .53129 .70647 .5278 .70053 .52049 Mtetra
.651 .74 .914 r
.70053 .52049 .70647 .5278 .71918 .52448 .71327 .51683 Mtetra
.647 .73 .909 r
.71327 .51683 .71918 .52448 .73197 .52125 .72607 .5133 Mtetra
.639 .719 .906 r
.72607 .5133 .73197 .52125 .74482 .51813 .73896 .51004 Mtetra
.629 .711 .906 r
.73896 .51004 .74482 .51813 .75778 .51553 .75192 .50708 Mtetra
.609 .694 .903 r
.75192 .50708 .75778 .51553 .77088 .51394 .76501 .50478 Mtetra
.568 .657 .897 r
.76501 .50478 .77088 .51394 .78415 .51356 .77826 .50382 Mtetra
.522 .621 .891 r
.77826 .50382 .78415 .51356 .79752 .51337 .79172 .50431 Mtetra
.533 .644 .905 r
.79172 .50431 .79752 .51337 .81076 .51048 .80523 .50429 Mtetra
.66 .788 .943 r
.80523 .50429 .81076 .51048 .82366 .50313 .81847 .50009 Mtetra
.796 .934 .922 r
.81847 .50009 .82366 .50313 .83639 .4936 .83131 .49101 Mtetra
.819 .951 .906 r
.83131 .49101 .83639 .4936 .84927 .48539 .84408 .48093 Mtetra
.764 .883 .931 r
.84408 .48093 .84927 .48539 .86241 .47948 .8571 .47319 Mtetra
.697 .802 .93 r
.8571 .47319 .86241 .47948 .87574 .47492 .87039 .46777 Mtetra
.666 .764 .923 r
.87039 .46777 .87574 .47492 .88917 .4708 .88385 .4634 Mtetra
.657 .753 .921 r
.88385 .4634 .88917 .4708 .90269 .46676 .89741 .45928 Mtetra
.656 .752 .92 r
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Mtetra
.656 .751 .92 r
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Mtetra
.655 .751 .921 r
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61895 Mtetra
.651 .751 .923 r
.33661 .61895 .34359 .62512 .35475 .62183 .34781 .61572 Mtetra
.626 .747 .934 r
.34781 .61572 .35475 .62183 .36596 .61878 .35902 .61308 Mtetra
.526 .729 .966 r
.35902 .61308 .36596 .61878 .37716 .61674 .37019 .61229 Mtetra
.201 .617 .949 r
.37019 .61229 .37716 .61674 .38834 .61693 .38132 .61442 Mtetra
0 .438 .743 r
.38132 .61442 .38834 .61693 .39951 .61933 .39248 .61758 Mtetra
.301 .765 .945 r
.39248 .61758 .39951 .61933 .41079 .62077 .40388 .6168 Mtetra
.754 .847 .921 r
.40388 .6168 .41079 .62077 .42229 .61751 .41553 .6102 Mtetra
.774 .75 .832 r
.41553 .6102 .42229 .61751 .43395 .61024 .42727 .60135 Mtetra
.74 .71 .824 r
.42727 .60135 .43395 .61024 .44565 .60249 .43899 .59383 Mtetra
.707 .707 .847 r
.43899 .59383 .44565 .60249 .45733 .59618 .45069 .58816 Mtetra
.685 .716 .873 r
.45069 .58816 .45733 .59618 .46903 .59118 .46241 .58359 Mtetra
.672 .724 .889 r
.46241 .58359 .46903 .59118 .48076 .58682 .47416 .57954 Mtetra
.666 .731 .899 r
.47416 .57954 .48076 .58682 .49253 .58278 .48596 .57569 Mtetra
.665 .738 .904 r
.48596 .57569 .49253 .58278 .50434 .57899 .4978 .57184 Mtetra
.665 .737 .904 r
.4978 .57184 .50434 .57899 .5162 .57533 .5097 .56801 Mtetra
.661 .731 .902 r
.5097 .56801 .5162 .57533 .52812 .57163 .52164 .56428 Mtetra
.656 .73 .904 r
.52164 .56428 .52812 .57163 .54008 .56785 .53364 .56069 Mtetra
.654 .736 .91 r
.53364 .56069 .54008 .56785 .5521 .56405 .54569 .55715 Mtetra
.653 .744 .916 r
.54569 .55715 .5521 .56405 .56417 .56028 .55779 .55359 Mtetra
.654 .752 .921 r
.55779 .55359 .56417 .56028 .57628 .55656 .56995 .54999 Mtetra
.654 .756 .924 r
.56995 .54999 .57628 .55656 .58846 .55289 .58216 .54634 Mtetra
.655 .758 .926 r
.58216 .54634 .58846 .55289 .60068 .54923 .59442 .54267 Mtetra
.654 .759 .926 r
.59442 .54267 .60068 .54923 .61297 .54557 .60674 .53899 Mtetra
.60674 .53899 .61297 .54557 .6253 .54192 .61912 .53529 Mtetra
.655 .758 .926 r
.61912 .53529 .6253 .54192 .6377 .53829 .63155 .53156 Mtetra
.656 .757 .924 r
.63155 .53156 .6377 .53829 .65015 .53469 .64403 .5278 Mtetra
.657 .753 .921 r
.64403 .5278 .65015 .53469 .66265 .53115 .65657 .52399 Mtetra
.658 .746 .915 r
.65657 .52399 .66265 .53115 .67522 .52764 .66916 .52016 Mtetra
.656 .736 .909 r
.66916 .52016 .67522 .52764 .68785 .5241 .68181 .51638 Mtetra
.651 .729 .906 r
.68181 .51638 .68785 .5241 .70053 .52049 .69453 .51273 Mtetra
.647 .727 .907 r
.69453 .51273 .70053 .52049 .71327 .51683 .70731 .50919 Mtetra
.646 .731 .911 r
.70731 .50919 .71327 .51683 .72607 .5133 .72015 .50566 Mtetra
.646 .732 .912 r
.72015 .50566 .72607 .5133 .73896 .51004 .73306 .50213 Mtetra
.639 .723 .908 r
.73306 .50213 .73896 .51004 .75192 .50708 .74604 .49881 Mtetra
.623 .707 .906 r
.74604 .49881 .75192 .50708 .76501 .50478 .75913 .49602 Mtetra
.588 .679 .903 r
.75913 .49602 .76501 .50478 .77826 .50382 .77236 .49434 Mtetra
.527 .632 .897 r
.77236 .49434 .77826 .50382 .79172 .50431 .78583 .49456 Mtetra
.481 .601 .895 r
.78583 .49456 .79172 .50431 .80523 .50429 .7995 .49612 Mtetra
.55 .68 .924 r
.7995 .49612 .80523 .50429 .81847 .50009 .81307 .49532 Mtetra
.739 .865 .94 r
.81307 .49532 .81847 .50009 .83131 .49101 .82619 .48846 Mtetra
.837 .953 .891 r
.82619 .48846 .83131 .49101 .84408 .48093 .83895 .47751 Mtetra
.816 .927 .908 r
.83895 .47751 .84408 .48093 .8571 .47319 .85183 .46765 Mtetra
.736 .842 .93 r
.85183 .46765 .8571 .47319 .87039 .46777 .86504 .46086 Mtetra
.679 .778 .925 r
.86504 .46086 .87039 .46777 .88385 .4634 .8785 .45599 Mtetra
.66 .756 .921 r
.8785 .45599 .88385 .4634 .89741 .45928 .89208 .45175 Mtetra
.656 .752 .92 r
.89208 .45175 .89741 .45928 .91103 .4552 .90575 .44762 Mtetra
.656 .751 .92 r
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Mtetra
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Mtetra
.654 .751 .921 r
.31841 .61608 .32546 .62229 .33661 .61895 .32959 .61274 Mtetra
.644 .749 .926 r
.32959 .61274 .33661 .61895 .34781 .61572 .3408 .60966 Mtetra
.593 .74 .946 r
.3408 .60966 .34781 .61572 .35902 .61308 .352 .60773 Mtetra
.388 .684 .977 r
.352 .60773 .35902 .61308 .37019 .61229 .36312 .60859 Mtetra
0 .433 .795 r
.36312 .60859 .37019 .61229 .38132 .61442 .37419 .6125 Mtetra
0 .45 .72 r
.37419 .6125 .38132 .61442 .39248 .61758 .38541 .61513 Mtetra
.628 .884 .988 r
.38541 .61513 .39248 .61758 .40388 .6168 .39696 .61117 Mtetra
.797 .795 .85 r
.39696 .61117 .40388 .6168 .41553 .6102 .40874 .60181 Mtetra
.772 .728 .812 r
.40874 .60181 .41553 .6102 .42727 .60135 .42054 .59241 Mtetra
.729 .708 .83 r
.42054 .59241 .42727 .60135 .43899 .59383 .43227 .58547 Mtetra
.695 .711 .861 r
.43227 .58547 .43899 .59383 .45069 .58816 .44399 .5804 Mtetra
.676 .721 .884 r
.44399 .5804 .45069 .58816 .46241 .58359 .45573 .57618 Mtetra
.668 .73 .895 r
.45573 .57618 .46241 .58359 .47416 .57954 .46751 .57223 Mtetra
.664 .732 .9 r
.46751 .57223 .47416 .57954 .48596 .57569 .47934 .5684 Mtetra
.659 .732 .903 r
.47934 .5684 .48596 .57569 .4978 .57184 .49121 .56473 Mtetra
.656 .737 .909 r
.49121 .56473 .4978 .57184 .5097 .56801 .50314 .56114 Mtetra
.657 .745 .915 r
.50314 .56114 .5097 .56801 .52164 .56428 .51512 .55747 Mtetra
.66 .749 .916 r
.51512 .55747 .52164 .56428 .53364 .56069 .52715 .5537 Mtetra
.662 .745 .912 r
.52715 .5537 .53364 .56069 .54569 .55715 .53923 .54988 Mtetra
.661 .737 .906 r
.53923 .54988 .54569 .55715 .55779 .55359 .55136 .54607 Mtetra
.659 .73 .902 r
.55136 .54607 .55779 .55359 .56995 .54999 .56355 .54231 Mtetra
.657 .726 .9 r
.56355 .54231 .56995 .54999 .58216 .54634 .57579 .53858 Mtetra
.656 .724 .899 r
.57579 .53858 .58216 .54634 .59442 .54267 .58809 .53486 Mtetra
.58809 .53486 .59442 .54267 .60674 .53899 .60044 .53115 Mtetra
.655 .724 .899 r
.60044 .53115 .60674 .53899 .61912 .53529 .61285 .52743 Mtetra
.654 .724 .9 r
.61285 .52743 .61912 .53529 .63155 .53156 .62531 .52374 Mtetra
.653 .725 .902 r
.62531 .52374 .63155 .53156 .64403 .5278 .63783 .52007 Mtetra
.651 .728 .905 r
.63783 .52007 .64403 .5278 .65657 .52399 .65042 .51645 Mtetra
.65 .734 .911 r
.65042 .51645 .65657 .52399 .66916 .52016 .66306 .51285 Mtetra
.65 .742 .916 r
.66306 .51285 .66916 .52016 .68181 .51638 .67575 .50919 Mtetra
.653 .747 .919 r
.67575 .50919 .68181 .51638 .69453 .51273 .6885 .50542 Mtetra
.655 .745 .916 r
.6885 .50542 .69453 .51273 .70731 .50919 .70131 .50158 Mtetra
.653 .736 .911 r
.70131 .50158 .70731 .50919 .72015 .50566 .71418 .49781 Mtetra
.647 .728 .908 r
.71418 .49781 .72015 .50566 .73306 .50213 .72712 .49421 Mtetra
.643 .725 .908 r
.72712 .49421 .73306 .50213 .74604 .49881 .74013 .49072 Mtetra
.634 .718 .908 r
.74013 .49072 .74604 .49881 .75913 .49602 .75322 .48751 Mtetra
.608 .696 .906 r
.75322 .48751 .75913 .49602 .77236 .49434 .76645 .48516 Mtetra
.546 .65 .903 r
.76645 .48516 .77236 .49434 .78583 .49456 .77989 .48474 Mtetra
.459 .589 .896 r
.77989 .48474 .78583 .49456 .7995 .49612 .79364 .48682 Mtetra
.452 .6 .907 r
.79364 .48682 .7995 .49612 .81307 .49532 .80748 .48883 Mtetra
.637 .775 .946 r
.80748 .48883 .81307 .49532 .82619 .48846 .82094 .48519 Mtetra
.829 .932 .899 r
.82094 .48519 .82619 .48846 .83895 .47751 .83382 .4747 Mtetra
.855 .947 .877 r
.83382 .4747 .83895 .47751 .85183 .46765 .84658 .4629 Mtetra
.784 .881 .917 r
.84658 .4629 .85183 .46765 .86504 .46086 .85967 .4543 Mtetra
.701 .8 .926 r
.85967 .4543 .86504 .46086 .8785 .45599 .8731 .44864 Mtetra
.666 .762 .922 r
.8731 .44864 .8785 .45599 .89208 .45175 .88672 .44417 Mtetra
.657 .753 .921 r
.88672 .44417 .89208 .45175 .90575 .44762 .90042 .43998 Mtetra
.656 .752 .92 r
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Mtetra
.655 .751 .92 r
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60983 Mtetra
.652 .751 .922 r
.3113 .60983 .31841 .61608 .32959 .61274 .3225 .60652 Mtetra
.633 .747 .93 r
.3225 .60652 .32959 .61274 .3408 .60966 .33372 .6037 Mtetra
.538 .726 .961 r
.33372 .6037 .3408 .60966 .352 .60773 .3449 .60275 Mtetra
.16 .576 .934 r
.3449 .60275 .352 .60773 .36312 .60859 .35596 .60553 Mtetra
.332 0 0 r
.35596 .60553 .36312 .60859 .37419 .6125 .36699 .61074 Mtetra
.062 .609 .838 r
.36699 .61074 .37419 .6125 .38541 .61513 .37831 .61175 Mtetra
.776 .868 .916 r
.37831 .61175 .38541 .61513 .39696 .61117 .39004 .60431 Mtetra
.81 .765 .81 r
.39004 .60431 .39696 .61117 .40874 .60181 .40193 .59293 Mtetra
.766 .718 .808 r
.40193 .59293 .40874 .60181 .42054 .59241 .41376 .58358 Mtetra
.717 .708 .84 r
.41376 .58358 .42054 .59241 .43227 .58547 .4255 .57733 Mtetra
.684 .715 .872 r
.4255 .57733 .43227 .58547 .44399 .5804 .43723 .57275 Mtetra
.669 .724 .89 r
.43723 .57275 .44399 .5804 .45573 .57618 .449 .56877 Mtetra
.662 .729 .899 r
.449 .56877 .45573 .57618 .46751 .57223 .46081 .56502 Mtetra
.659 .735 .905 r
.46081 .56502 .46751 .57223 .47934 .5684 .47266 .56133 Mtetra
.661 .74 .909 r
.47266 .56133 .47934 .5684 .49121 .56473 .48457 .55756 Mtetra
.662 .738 .907 r
.48457 .55756 .49121 .56473 .50314 .56114 .49653 .55376 Mtetra
.658 .732 .904 r
.49653 .55376 .50314 .56114 .51512 .55747 .50854 .55005 Mtetra
.654 .73 .905 r
.50854 .55005 .51512 .55747 .52715 .5537 .5206 .54647 Mtetra
.651 .736 .911 r
.5206 .54647 .52715 .5537 .53923 .54988 .53272 .54295 Mtetra
.651 .746 .919 r
.53272 .54295 .53923 .54988 .55136 .54607 .54489 .53939 Mtetra
.652 .755 .925 r
.54489 .53939 .55136 .54607 .56355 .54231 .55712 .53578 Mtetra
.653 .761 .929 r
.55712 .53578 .56355 .54231 .57579 .53858 .5694 .5321 Mtetra
.653 .764 .93 r
.5694 .5321 .57579 .53858 .58809 .53486 .58173 .52839 Mtetra
.654 .765 .931 r
.58173 .52839 .58809 .53486 .60044 .53115 .59412 .52464 Mtetra
.59412 .52464 .60044 .53115 .61285 .52743 .60657 .52087 Mtetra
.655 .764 .93 r
.60657 .52087 .61285 .52743 .62531 .52374 .61907 .51706 Mtetra
.657 .762 .927 r
.61907 .51706 .62531 .52374 .63783 .52007 .63162 .51319 Mtetra
.659 .757 .923 r
.63162 .51319 .63783 .52007 .65042 .51645 .64423 .50925 Mtetra
.66 .749 .916 r
.64423 .50925 .65042 .51645 .66306 .51285 .65689 .50528 Mtetra
.658 .738 .909 r
.65689 .50528 .66306 .51285 .67575 .50919 .66962 .50137 Mtetra
.653 .73 .906 r
.66962 .50137 .67575 .50919 .6885 .50542 .68241 .49759 Mtetra
.65 .73 .907 r
.68241 .49759 .6885 .50542 .70131 .50158 .69526 .4939 Mtetra
.65 .735 .911 r
.69526 .4939 .70131 .50158 .71418 .49781 .70817 .49017 Mtetra
.652 .738 .912 r
.70817 .49017 .71418 .49781 .72712 .49421 .72114 .48636 Mtetra
.65 .732 .909 r
.72114 .48636 .72712 .49421 .74013 .49072 .73418 .48262 Mtetra
.642 .723 .907 r
.73418 .48262 .74013 .49072 .75322 .48751 .74729 .47911 Mtetra
.624 .708 .906 r
.74729 .47911 .75322 .48751 .76645 .48516 .76051 .4762 Mtetra
.569 .669 .906 r
.76051 .4762 .76645 .48516 .77989 .48474 .77393 .47501 Mtetra
.458 .593 .899 r
.77393 .47501 .77989 .48474 .79364 .48682 .78769 .477 Mtetra
.372 .543 .894 r
.78769 .477 .79364 .48682 .80748 .48883 .80174 .48105 Mtetra
.51 .677 .94 r
.80174 .48105 .80748 .48883 .82094 .48519 .81555 .48096 Mtetra
.791 .899 .919 r
.81555 .48096 .82094 .48519 .83382 .4747 .82865 .47206 Mtetra
.879 .949 .852 r
.82865 .47206 .83382 .4747 .84658 .4629 .84135 .45881 Mtetra
.831 .91 .892 r
.84135 .45881 .84658 .4629 .85967 .4543 .8543 .44813 Mtetra
.732 .824 .922 r
.8543 .44813 .85967 .4543 .8731 .44864 .86768 .44136 Mtetra
.675 .77 .922 r
.86768 .44136 .8731 .44864 .88672 .44417 .8813 .43656 Mtetra
.659 .754 .921 r
.8813 .43656 .88672 .44417 .90042 .43998 .89505 .43227 Mtetra
.656 .752 .92 r
.89505 .43227 .90042 .43998 .9142 .43581 .90888 .42806 Mtetra
.655 .751 .921 r
.29294 .60694 .30014 .61322 .3113 .60983 .30413 .60354 Mtetra
.65 .75 .923 r
.30413 .60354 .3113 .60983 .3225 .60652 .31536 .60027 Mtetra
.616 .743 .937 r
.31536 .60027 .3225 .60652 .33372 .6037 .32659 .59782 Mtetra
.451 .696 .972 r
.32659 .59782 .33372 .6037 .3449 .60275 .33772 .59811 Mtetra
0 .388 .79 r
.33772 .59811 .3449 .60275 .35596 .60553 .34869 .60291 Mtetra
.447 0 0 r
.34869 .60291 .35596 .60553 .36699 .61074 .35971 .6089 Mtetra
.37 .802 .966 r
.35971 .6089 .36699 .61074 .37831 .61175 .37117 .60754 Mtetra
.831 .833 .848 r
.37117 .60754 .37831 .61175 .39004 .60431 .38309 .59665 Mtetra
.816 .749 .789 r
.38309 .59665 .39004 .60431 .40193 .59293 .39508 .58384 Mtetra
.76 .714 .81 r
.39508 .58384 .40193 .59293 .41376 .58358 .40693 .57486 Mtetra
.703 .708 .851 r
.40693 .57486 .41376 .58358 .4255 .57733 .41868 .5693 Mtetra
.671 .715 .881 r
.41868 .5693 .4255 .57733 .43723 .57275 .43043 .56517 Mtetra
.661 .725 .896 r
.43043 .56517 .43723 .57275 .449 .56877 .44221 .56142 Mtetra
.66 .732 .903 r
.44221 .56142 .449 .56877 .46081 .56502 .45405 .55769 Mtetra
.658 .733 .904 r
.45405 .55769 .46081 .56502 .47266 .56133 .46594 .55399 Mtetra
.654 .732 .907 r
.46594 .55399 .47266 .56133 .48457 .55756 .47787 .55042 Mtetra
.652 .738 .913 r
.47787 .55042 .48457 .55756 .49653 .55376 .48986 .54689 Mtetra
.655 .748 .918 r
.48986 .54689 .49653 .55376 .50854 .55005 .50191 .54325 Mtetra
.659 .752 .919 r
.50191 .54325 .50854 .55005 .5206 .54647 .514 .53945 Mtetra
.662 .747 .913 r
.514 .53945 .5206 .54647 .53272 .54295 .52615 .53555 Mtetra
.661 .737 .906 r
.52615 .53555 .53272 .54295 .54489 .53939 .53836 .53166 Mtetra
.659 .728 .9 r
.53836 .53166 .54489 .53939 .55712 .53578 .55061 .52781 Mtetra
.658 .722 .896 r
.55061 .52781 .55712 .53578 .5694 .5321 .56293 .52401 Mtetra
.656 .719 .894 r
.56293 .52401 .5694 .5321 .58173 .52839 .57529 .52023 Mtetra
.656 .718 .894 r
.57529 .52023 .58173 .52839 .59412 .52464 .58771 .51646 Mtetra
.655 .717 .894 r
.58771 .51646 .59412 .52464 .60657 .52087 .60019 .51269 Mtetra
.654 .718 .895 r
.60019 .51269 .60657 .52087 .61907 .51706 .61273 .50895 Mtetra
.652 .72 .898 r
.61273 .50895 .61907 .51706 .63162 .51319 .62532 .50524 Mtetra
.65 .725 .903 r
.62532 .50524 .63162 .51319 .64423 .50925 .63798 .50158 Mtetra
.649 .733 .911 r
.63798 .50158 .64423 .50925 .65689 .50528 .65069 .49793 Mtetra
.651 .744 .918 r
.65069 .49793 .65689 .50528 .66962 .50137 .66347 .49418 Mtetra
.656 .752 .921 r
.66347 .49418 .66962 .50137 .68241 .49759 .67629 .49027 Mtetra
.659 .75 .917 r
.67629 .49027 .68241 .49759 .69526 .4939 .68917 .48624 Mtetra
.657 .74 .911 r
.68917 .48624 .69526 .4939 .70817 .49017 .70211 .48226 Mtetra
.653 .732 .907 r
.70211 .48226 .70817 .49017 .72114 .48636 .71511 .4784 Mtetra
.652 .731 .908 r
.71511 .4784 .72114 .48636 .73418 .48262 .72818 .47457 Mtetra
.65 .729 .907 r
.72818 .47457 .73418 .48262 .74729 .47911 .74132 .47076 Mtetra
.639 .717 .905 r
.74132 .47076 .74729 .47911 .76051 .4762 .75454 .46734 Mtetra
.593 .684 .905 r
.75454 .46734 .76051 .4762 .77393 .47501 .76794 .46539 Mtetra
.471 .604 .902 r
.76794 .46539 .77393 .47501 .78769 .477 .78169 .46695 Mtetra
.309 .501 .883 r
.78169 .46695 .78769 .477 .80174 .48105 .79588 .47242 Mtetra
.363 .573 .92 r
.79588 .47242 .80174 .48105 .81555 .48096 .81004 .47585 Mtetra
.724 .857 .944 r
.81004 .47585 .81555 .48096 .82865 .47206 .82342 .46934 Mtetra
.892 .944 .838 r
.82342 .46934 .82865 .47206 .84135 .45881 .83612 .45518 Mtetra
.871 .924 .859 r
.83612 .45518 .84135 .45881 .8543 .44813 .84893 .4423 Mtetra
.767 .846 .911 r
.84893 .4423 .8543 .44813 .86768 .44136 .86222 .43417 Mtetra
.687 .779 .921 r
.86222 .43417 .86768 .44136 .8813 .43656 .87585 .42891 Mtetra
.661 .756 .921 r
.87585 .42891 .8813 .43656 .89505 .43227 .88964 .42451 Mtetra
.656 .752 .92 r
.88964 .42451 .89505 .43227 .90888 .42806 .90351 .42025 Mtetra
.655 .751 .921 r
.28569 .60062 .29294 .60694 .30413 .60354 .29691 .59719 Mtetra
.646 .749 .925 r
.29691 .59719 .30413 .60354 .31536 .60027 .30816 .594 Mtetra
.593 .737 .944 r
.30816 .594 .31536 .60027 .32659 .59782 .31938 .59202 Mtetra
.326 .641 .966 r
.31938 .59202 .32659 .59782 .33772 .59811 .33046 .59371 Mtetra
.392 0 0 r
.33046 .59371 .33772 .59811 .34869 .60291 .34134 .60057 Mtetra
.496 0 0 r
.34134 .60057 .34869 .60291 .35971 .6089 .35236 .60693 Mtetra
.623 .899 .986 r
.35236 .60693 .35971 .6089 .37117 .60754 .36399 .60273 Mtetra
.858 .809 .8 r
.36399 .60273 .37117 .60754 .38309 .59665 .37611 .58851 Mtetra
.821 .741 .776 r
.37611 .58851 .38309 .59665 .39508 .58384 .38819 .57463 Mtetra
.751 .711 .814 r
.38819 .57463 .39508 .58384 .40693 .57486 .40005 .56619 Mtetra
.688 .705 .861 r
.40005 .56619 .40693 .57486 .41868 .5693 .4118 .56132 Mtetra
.66 .714 .888 r
.4118 .56132 .41868 .5693 .43043 .56517 .42357 .55756 Mtetra
.655 .724 .9 r
.42357 .55756 .43043 .56517 .44221 .56142 .43538 .55399 Mtetra
.653 .729 .905 r
.43538 .55399 .44221 .56142 .45405 .55769 .44724 .55046 Mtetra
.653 .735 .91 r
.44724 .55046 .45405 .55769 .46594 .55399 .45916 .54688 Mtetra
.658 .741 .911 r
.45916 .54688 .46594 .55399 .47787 .55042 .47113 .54314 Mtetra
.66 .738 .907 r
.47113 .54314 .47787 .55042 .48986 .54689 .48315 .53931 Mtetra
.656 .729 .903 r
.48315 .53931 .48986 .54689 .50191 .54325 .49523 .5356 Mtetra
.651 .726 .904 r
.49523 .5356 .50191 .54325 .514 .53945 .50736 .53206 Mtetra
.647 .733 .912 r
.50736 .53206 .514 .53945 .52615 .53555 .51954 .5286 Mtetra
.647 .747 .922 r
.51954 .5286 .52615 .53555 .53836 .53166 .53178 .5251 Mtetra
.648 .761 .931 r
.53178 .5251 .53836 .53166 .55061 .52781 .54407 .52151 Mtetra
.65 .77 .937 r
.54407 .52151 .55061 .52781 .56293 .52401 .55643 .51781 Mtetra
.651 .775 .939 r
.55643 .51781 .56293 .52401 .57529 .52023 .56883 .51405 Mtetra
.652 .777 .94 r
.56883 .51405 .57529 .52023 .58771 .51646 .58129 .51025 Mtetra
.653 .777 .94 r
.58129 .51025 .58771 .51646 .60019 .51269 .59381 .5064 Mtetra
.655 .776 .938 r
.59381 .5064 .60019 .51269 .61273 .50895 .60639 .50248 Mtetra
.659 .773 .934 r
.60639 .50248 .61273 .50895 .62532 .50524 .61901 .49846 Mtetra
.662 .765 .926 r
.61901 .49846 .62532 .50524 .63798 .50158 .63169 .49435 Mtetra
.663 .752 .916 r
.63169 .49435 .63798 .50158 .65069 .49793 .64443 .49019 Mtetra
.66 .738 .907 r
.64443 .49019 .65069 .49793 .66347 .49418 .65723 .48612 Mtetra
.655 .728 .903 r
.65723 .48612 .66347 .49418 .67629 .49027 .67009 .48223 Mtetra
.651 .728 .905 r
.67009 .48223 .67629 .49027 .68917 .48624 .68302 .47844 Mtetra
.653 .736 .911 r
.68302 .47844 .68917 .48624 .70211 .48226 .696 .47456 Mtetra
.657 .742 .912 r
.696 .47456 .70211 .48226 .71511 .4784 .70904 .47052 Mtetra
.658 .738 .909 r
.70904 .47052 .71511 .4784 .72818 .47457 .72214 .46643 Mtetra
.656 .731 .904 r
.72214 .46643 .72818 .47457 .74132 .47076 .7353 .46238 Mtetra
.651 .723 .902 r
.7353 .46238 .74132 .47076 .75454 .46734 .74853 .45852 Mtetra
.616 .698 .902 r
.74853 .45852 .75454 .46734 .76794 .46539 .76191 .4558 Mtetra
.492 .618 .904 r
.76191 .4558 .76794 .46539 .78169 .46695 .77565 .45676 Mtetra
.258 .467 .872 r
.77565 .45676 .78169 .46695 .79588 .47242 .78994 .46329 Mtetra
.2 .459 .88 r
.78994 .46329 .79588 .47242 .81004 .47585 .80441 .47013 Mtetra
.624 .803 .968 r
.80441 .47013 .81004 .47585 .82342 .46934 .81811 .46648 Mtetra
.897 .939 .831 r
.81811 .46648 .82342 .46934 .83612 .45518 .83085 .45182 Mtetra
.902 .926 .824 r
.83085 .45182 .83612 .45518 .84893 .4423 .84352 .43671 Mtetra
.802 .863 .894 r
.84352 .43671 .84893 .4423 .86222 .43417 .85672 .42703 Mtetra
.702 .789 .918 r
.85672 .42703 .86222 .43417 .87585 .42891 .87035 .42121 Mtetra
.664 .758 .92 r
.87035 .42121 .87585 .42891 .88964 .42451 .88417 .41667 Mtetra
.657 .752 .92 r
.88417 .41667 .88964 .42451 .90351 .42025 .89809 .41237 Mtetra
.654 .751 .921 r
.27838 .59424 .28569 .60062 .29691 .59719 .28963 .5908 Mtetra
.642 .748 .926 r
.28963 .5908 .29691 .59719 .30816 .594 .3009 .58769 Mtetra
.566 .729 .951 r
.3009 .58769 .30816 .594 .31938 .59202 .31212 .58623 Mtetra
.165 .553 .93 r
.31212 .58623 .31938 .59202 .33046 .59371 .32312 .58942 Mtetra
.574 .014 0 r
.32312 .58942 .33046 .59371 .34134 .60057 .3339 .59834 Mtetra
.516 0 0 r
.3339 .59834 .34134 .60057 .35236 .60693 .34493 .60489 Mtetra
.765 .915 .939 r
.34493 .60489 .35236 .60693 .36399 .60273 .35676 .59765 Mtetra
.876 .794 .766 r
.35676 .59765 .36399 .60273 .37611 .58851 .36908 .58013 Mtetra
.826 .738 .767 r
.36908 .58013 .37611 .58851 .38819 .57463 .38125 .56534 Mtetra
.741 .708 .82 r
.38125 .56534 .38819 .57463 .40005 .56619 .39312 .55748 Mtetra
.67 .701 .869 r
.39312 .55748 .40005 .56619 .4118 .56132 .40488 .55329 Mtetra
.647 .711 .894 r
.40488 .55329 .4118 .56132 .42357 .55756 .41666 .54995 Mtetra
.648 .723 .903 r
.41666 .54995 .42357 .55756 .43538 .55399 .42849 .54656 Mtetra
.653 .73 .906 r
.42849 .54656 .43538 .55399 .44724 .55046 .44038 .543 Mtetra
.654 .731 .906 r
.44038 .543 .44724 .55046 .45916 .54688 .45233 .53939 Mtetra
.65 .729 .907 r
.45233 .53939 .45916 .54688 .47113 .54314 .46433 .53589 Mtetra
.65 .737 .913 r
.46433 .53589 .47113 .54314 .48315 .53931 .47638 .53234 Mtetra
.661 .75 .916 r
.47638 .53234 .48315 .53931 .49523 .5356 .48849 .52846 Mtetra
.674 .75 .907 r
.48849 .52846 .49523 .5356 .50736 .53206 .50066 .52412 Mtetra
.682 .731 .887 r
.50066 .52412 .50736 .53206 .51954 .5286 .51288 .51945 Mtetra
.68 .701 .863 r
.51288 .51945 .51954 .5286 .53178 .5251 .52514 .51468 Mtetra
.672 .673 .842 r
.52514 .51468 .53178 .5251 .54407 .52151 .53746 .51003 Mtetra
.662 .65 .828 r
.53746 .51003 .54407 .52151 .55643 .51781 .54982 .50561 Mtetra
.653 .634 .819 r
.54982 .50561 .55643 .51781 .56883 .51405 .56224 .50147 Mtetra
.645 .626 .816 r
.56224 .50147 .56883 .51405 .58129 .51025 .57472 .49763 Mtetra
.639 .623 .818 r
.57472 .49763 .58129 .51025 .59381 .5064 .58726 .49409 Mtetra
.633 .625 .825 r
.58726 .49409 .59381 .5064 .60639 .50248 .59987 .49083 Mtetra
.628 .635 .838 r
.59987 .49083 .60639 .50248 .61901 .49846 .61255 .48781 Mtetra
.626 .654 .858 r
.61255 .48781 .61901 .49846 .63169 .49435 .62529 .4849 Mtetra
.628 .682 .882 r
.62529 .4849 .63169 .49435 .64443 .49019 .6381 .48191 Mtetra
.637 .716 .904 r
.6381 .48191 .64443 .49019 .65723 .48612 .65096 .47858 Mtetra
.65 .743 .917 r
.65096 .47858 .65723 .48612 .67009 .48223 .66387 .47478 Mtetra
.66 .75 .917 r
.66387 .47478 .67009 .48223 .68302 .47844 .67682 .47064 Mtetra
.661 .741 .91 r
.67682 .47064 .68302 .47844 .696 .47456 .68983 .46647 Mtetra
.657 .732 .905 r
.68983 .46647 .696 .47456 .70904 .47052 .70291 .4624 Mtetra
.658 .733 .905 r
.70291 .4624 .70904 .47052 .72214 .46643 .71605 .45828 Mtetra
.663 .735 .904 r
.71605 .45828 .72214 .46643 .7353 .46238 .72923 .45398 Mtetra
.663 .729 .899 r
.72923 .45398 .7353 .46238 .74853 .45852 .74247 .44964 Mtetra
.638 .707 .897 r
.74247 .44964 .74853 .45852 .76191 .4558 .75584 .44616 Mtetra
.516 .631 .903 r
.75584 .44616 .76191 .4558 .77565 .45676 .76956 .44646 Mtetra
.212 .437 .861 r
.76956 .44646 .77565 .45676 .78994 .46329 .78394 .45391 Mtetra
.022 .333 .816 r
.78394 .45391 .78994 .46329 .80441 .47013 .79872 .4641 Mtetra
.483 .731 .98 r
.79872 .4641 .80441 .47013 .81811 .46648 .81274 .46353 Mtetra
.9 .937 .828 r
.81274 .46353 .81811 .46648 .83085 .45182 .82554 .44859 Mtetra
.925 .921 .79 r
.82554 .44859 .83085 .45182 .84352 .43671 .83808 .43122 Mtetra
.833 .871 .872 r
.83808 .43122 .84352 .43671 .85672 .42703 .85118 .4199 Mtetra
.717 .796 .913 r
.85118 .4199 .85672 .42703 .87035 .42121 .8648 .41347 Mtetra
.668 .76 .92 r
.8648 .41347 .87035 .42121 .88417 .41667 .87866 .40877 Mtetra
.657 .752 .92 r
.87866 .40877 .88417 .41667 .89809 .41237 .89263 .40442 Mtetra
.654 .751 .921 r
.27102 .58781 .27838 .59424 .28963 .5908 .28229 .58436 Mtetra
.637 .747 .928 r
.28229 .58436 .28963 .5908 .3009 .58769 .29358 .58134 Mtetra
.536 .718 .957 r
.29358 .58134 .3009 .58769 .31212 .58623 .30479 .5804 Mtetra
0 .437 .857 r
.30479 .5804 .31212 .58623 .32312 .58942 .31572 .5851 Mtetra
.687 .148 0 r
.31572 .5851 .32312 .58942 .3339 .59834 .32638 .59611 Mtetra
.53 0 0 r
.32638 .59611 .3339 .59834 .34493 .60489 .33742 .60287 Mtetra
.837 .903 .884 r
.33742 .60287 .34493 .60489 .35676 .59765 .34946 .5926 Mtetra
.891 .787 .74 r
.34946 .5926 .35676 .59765 .36908 .58013 .36201 .57175 Mtetra
.833 .739 .76 r
.36201 .57175 .36908 .58013 .38125 .56534 .37427 .55596 Mtetra
.731 .705 .826 r
.37427 .55596 .38125 .56534 .39312 .55748 .38614 .54867 Mtetra
.65 .693 .876 r
.38614 .54867 .39312 .55748 .40488 .55329 .3979 .54517 Mtetra
.635 .706 .897 r
.3979 .54517 .40488 .55329 .41666 .54995 .4097 .54218 Mtetra
.643 .719 .903 r
.4097 .54218 .41666 .54995 .42849 .54656 .42155 .53891 Mtetra
.651 .725 .903 r
.42155 .53891 .42849 .54656 .44038 .543 .43348 .53537 Mtetra
.667 .731 .898 r
.43348 .53537 .44038 .543 .45233 .53939 .44546 .53131 Mtetra
.688 .727 .88 r
.44546 .53131 .45233 .53939 .46433 .53589 .45752 .5264 Mtetra
.698 .698 .847 r
.45752 .5264 .46433 .53589 .47638 .53234 .46963 .52078 Mtetra
.689 .658 .814 r
.46963 .52078 .47638 .53234 .48849 .52846 .48178 .51501 Mtetra
.673 .623 .792 r
.48178 .51501 .48849 .52846 .50066 .52412 .49397 .50959 Mtetra
.658 .604 .782 r
.49397 .50959 .50066 .52412 .51288 .51945 .5062 .50472 Mtetra
.649 .597 .783 r
.5062 .50472 .51288 .51945 .52514 .51468 .51847 .50034 Mtetra
.644 .6 .79 r
.51847 .50034 .52514 .51468 .53746 .51003 .5308 .49628 Mtetra
.643 .607 .799 r
.5308 .49628 .53746 .51003 .54982 .50561 .54318 .49237 Mtetra
.643 .615 .807 r
.54318 .49237 .54982 .50561 .56224 .50147 .55562 .48851 Mtetra
.644 .62 .811 r
.55562 .48851 .56224 .50147 .57472 .49763 .56811 .48463 Mtetra
.56811 .48463 .57472 .49763 .58726 .49409 .58066 .48073 Mtetra
.642 .615 .807 r
.58066 .48073 .58726 .49409 .59987 .49083 .59327 .47687 Mtetra
.637 .604 .8 r
.59327 .47687 .59987 .49083 .61255 .48781 .60594 .47317 Mtetra
.629 .592 .793 r
.60594 .47317 .61255 .48781 .62529 .4849 .61868 .4698 Mtetra
.618 .581 .79 r
.61868 .4698 .62529 .4849 .6381 .48191 .6315 .46692 Mtetra
.606 .577 .795 r
.6315 .46692 .6381 .48191 .65096 .47858 .64441 .46462 Mtetra
.599 .587 .811 r
.64441 .46462 .65096 .47858 .66387 .47478 .65741 .46268 Mtetra
.603 .619 .841 r
.65741 .46268 .66387 .47478 .67682 .47064 .67048 .46059 Mtetra
.621 .669 .875 r
.67048 .46059 .67682 .47064 .68983 .46647 .68359 .45778 Mtetra
.645 .713 .897 r
.68359 .45778 .68983 .46647 .70291 .4624 .69672 .4541 Mtetra
.659 .73 .902 r
.69672 .4541 .70291 .4624 .71605 .45828 .7099 .4499 Mtetra
.667 .732 .898 r
.7099 .4499 .71605 .45828 .72923 .45398 .72311 .44541 Mtetra
.674 .731 .893 r
.72311 .44541 .72923 .45398 .74247 .44964 .73637 .44066 Mtetra
.658 .715 .89 r
.73637 .44066 .74247 .44964 .75584 .44616 .74972 .43641 Mtetra
.538 .641 .9 r
.74972 .43641 .75584 .44616 .76956 .44646 .76342 .43608 Mtetra
.161 .404 .847 r
.76342 .43608 .76956 .44646 .78394 .45391 .7779 .4445 Mtetra
0 .194 .723 r
.7779 .4445 .78394 .45391 .79872 .4641 .79297 .45809 Mtetra
.295 .628 .962 r
.79297 .45809 .79872 .4641 .81274 .46353 .80731 .46059 Mtetra
.902 .937 .824 r
.80731 .46059 .81274 .46353 .82554 .44859 .82017 .44533 Mtetra
.942 .91 .76 r
.82017 .44533 .82554 .44859 .83808 .43122 .83258 .42569 Mtetra
.858 .872 .848 r
.83258 .42569 .83808 .43122 .85118 .4199 .84559 .41271 Mtetra
.732 .801 .907 r
.84559 .41271 .85118 .4199 .8648 .41347 .85921 .40566 Mtetra
.671 .762 .919 r
.85921 .40566 .8648 .41347 .87866 .40877 .8731 .40081 Mtetra
.657 .753 .92 r
.8731 .40081 .87866 .40877 .89263 .40442 .88711 .39639 Mtetra
.653 .751 .921 r
.26359 .58134 .27102 .58781 .28229 .58436 .27489 .57787 Mtetra
.633 .746 .929 r
.27489 .57787 .28229 .58436 .29358 .58134 .2862 .57493 Mtetra
.505 .706 .961 r
.2862 .57493 .29358 .58134 .30479 .5804 .2974 .57449 Mtetra
0 .309 .758 r
.2974 .57449 .30479 .5804 .31572 .5851 .30825 .58063 Mtetra
.757 .244 0 r
.30825 .58063 .31572 .5851 .32638 .59611 .31879 .59371 Mtetra
.55 0 0 r
.31879 .59371 .32638 .59611 .33742 .60287 .32983 .60089 Mtetra
.874 .888 .841 r
.32983 .60089 .33742 .60287 .34946 .5926 .34207 .58788 Mtetra
.905 .785 .719 r
.34207 .58788 .34946 .5926 .36201 .57175 .35487 .56363 Mtetra
.844 .744 .753 r
.35487 .56363 .36201 .57175 .37427 .55596 .36724 .54656 Mtetra
.725 .704 .83 r
.36724 .54656 .37427 .55596 .38614 .54867 .37913 .53965 Mtetra
.632 .683 .88 r
.37913 .53965 .38614 .54867 .3979 .54517 .39089 .53672 Mtetra
.632 .698 .892 r
.39089 .53672 .3979 .54517 .4097 .54218 .4027 .53379 Mtetra
.666 .711 .882 r
.4027 .53379 .4097 .54218 .42155 .53891 .41461 .52972 Mtetra
.695 .703 .853 r
.41461 .52972 .42155 .53891 .43348 .53537 .42661 .52433 Mtetra
.7 .67 .817 r
.42661 .52433 .43348 .53537 .44546 .53131 .43867 .51815 Mtetra
.683 .631 .791 r
.43867 .51815 .44546 .53131 .45752 .5264 .45076 .51225 Mtetra
.66 .609 .786 r
.45076 .51225 .45752 .5264 .46963 .52078 .46287 .50736 Mtetra
.644 .611 .801 r
.46287 .50736 .46963 .52078 .48178 .51501 .47501 .50346 Mtetra
.637 .637 .834 r
.47501 .50346 .48178 .51501 .49397 .50959 .4872 .50014 Mtetra
.635 .68 .876 r
.4872 .50014 .49397 .50959 .5062 .50472 .49944 .49702 Mtetra
.635 .725 .913 r
.49944 .49702 .5062 .50472 .51847 .50034 .51175 .49384 Mtetra
.635 .763 .94 r
.51175 .49384 .51847 .50034 .5308 .49628 .52411 .4905 Mtetra
.637 .788 .955 r
.52411 .4905 .5308 .49628 .54318 .49237 .53654 .48698 Mtetra
.64 .803 .961 r
.53654 .48698 .54318 .49237 .55562 .48851 .54902 .48325 Mtetra
.646 .811 .963 r
.54902 .48325 .55562 .48851 .56811 .48463 .56156 .47934 Mtetra
.653 .813 .96 r
.56156 .47934 .56811 .48463 .58066 .48073 .57415 .47524 Mtetra
.661 .81 .954 r
.57415 .47524 .58066 .48073 .59327 .47687 .5868 .47094 Mtetra
.67 .799 .944 r
.5868 .47094 .59327 .47687 .60594 .47317 .59949 .46645 Mtetra
.676 .776 .925 r
.59949 .46645 .60594 .47317 .61868 .4698 .61224 .4618 Mtetra
.677 .74 .898 r
.61224 .4618 .61868 .4698 .6315 .46692 .62504 .4571 Mtetra
.667 .692 .865 r
.62504 .4571 .6315 .46692 .64441 .46462 .6379 .45257 Mtetra
.646 .641 .831 r
.6379 .45257 .64441 .46462 .65741 .46268 .65084 .44865 Mtetra
.619 .598 .808 r
.65084 .44865 .65741 .46268 .67048 .46059 .66389 .44574 Mtetra
.596 .576 .801 r
.66389 .44574 .67048 .46059 .68359 .45778 .67705 .44387 Mtetra
.589 .586 .817 r
.67705 .44387 .68359 .45778 .69672 .4541 .69031 .44231 Mtetra
.608 .631 .848 r
.69031 .44231 .69672 .4541 .7099 .4499 .70361 .43993 Mtetra
.643 .685 .874 r
.70361 .43993 .7099 .4499 .72311 .44541 .71691 .4362 Mtetra
.674 .717 .88 r
.71691 .4362 .72311 .44541 .73637 .44066 .7302 .43132 Mtetra
.674 .714 .879 r
.7302 .43132 .73637 .44066 .74972 .43641 .74355 .42643 Mtetra
.553 .645 .895 r
.74355 .42643 .74972 .43641 .76342 .43608 .75725 .42566 Mtetra
.09 .357 .825 r
.75725 .42566 .76342 .43608 .7779 .4445 .77184 .43536 Mtetra
0 .05 .602 r
.77184 .43536 .7779 .4445 .79297 .45809 .7872 .45241 Mtetra
.077 .497 .897 r
.7872 .45241 .79297 .45809 .80731 .46059 .80182 .45769 Mtetra
.908 .937 .817 r
.80182 .45769 .80731 .46059 .82017 .44533 .81472 .44187 Mtetra
.953 .897 .733 r
.81472 .44187 .82017 .44533 .83258 .42569 .82702 .41997 Mtetra
.877 .868 .826 r
.82702 .41997 .83258 .42569 .84559 .41271 .83995 .40542 Mtetra
.745 .804 .899 r
.83995 .40542 .84559 .41271 .85921 .40566 .85356 .39778 Mtetra
.675 .763 .917 r
.85356 .39778 .85921 .40566 .8731 .40081 .86749 .39277 Mtetra
.658 .753 .92 r
.86749 .39277 .8731 .40081 .88711 .39639 .88155 .3883 Mtetra
.653 .751 .922 r
.25611 .57481 .26359 .58134 .27489 .57787 .26744 .57133 Mtetra
.629 .745 .931 r
.26744 .57133 .27489 .57787 .2862 .57493 .27877 .56846 Mtetra
.475 .694 .963 r
.27877 .56846 .2862 .57493 .2974 .57449 .28996 .56847 Mtetra
0 .193 .655 r
.28996 .56847 .2974 .57449 .30825 .58063 .30072 .5759 Mtetra
.801 .309 0 r
.30072 .5759 .30825 .58063 .31879 .59371 .31114 .59093 Mtetra
.579 .004 0 r
.31114 .59093 .31879 .59371 .32983 .60089 .32215 .59884 Mtetra
.891 .873 .812 r
.32215 .59884 .32983 .60089 .34207 .58788 .33458 .58371 Mtetra
.916 .785 .701 r
.33458 .58371 .34207 .58788 .35487 .56363 .34764 .55616 Mtetra
.861 .754 .743 r
.34764 .55616 .35487 .56363 .36724 .54656 .36016 .53721 Mtetra
.731 .708 .829 r
.36016 .53721 .36724 .54656 .37913 .53965 .37209 .52992 Mtetra
.643 .672 .863 r
.37209 .52992 .37913 .53965 .39089 .53672 .38389 .52657 Mtetra
.667 .673 .846 r
.38389 .52657 .39089 .53672 .4027 .53379 .39578 .52219 Mtetra
.69 .657 .812 r
.39578 .52219 .4027 .53379 .41461 .52972 .40777 .51635 Mtetra
.679 .626 .79 r
.40777 .51635 .41461 .52972 .42661 .52433 .41979 .51062 Mtetra
.652 .61 .794 r
.41979 .51062 .42661 .52433 .43867 .51815 .43182 .50625 Mtetra
.63 .628 .83 r
.43182 .50625 .43867 .51815 .45076 .51225 .44386 .50317 Mtetra
.616 .681 .888 r
.44386 .50317 .45076 .51225 .46287 .50736 .45595 .50065 Mtetra
.606 .745 .943 r
.45595 .50065 .46287 .50736 .47501 .50346 .4681 .49812 Mtetra
.6 .79 .971 r
.4681 .49812 .47501 .50346 .4872 .50014 .48032 .49534 Mtetra
.603 .811 .98 r
.48032 .49534 .4872 .50014 .49944 .49702 .4926 .4923 Mtetra
.612 .817 .979 r
.4926 .4923 .49944 .49702 .51175 .49384 .50495 .48903 Mtetra
.622 .818 .976 r
.50495 .48903 .51175 .49384 .52411 .4905 .51736 .48557 Mtetra
.63 .817 .972 r
.51736 .48557 .52411 .4905 .53654 .48698 .52983 .48195 Mtetra
.637 .817 .969 r
.52983 .48195 .53654 .48698 .54902 .48325 .54236 .47816 Mtetra
.644 .818 .967 r
.54236 .47816 .54902 .48325 .56156 .47934 .55494 .47422 Mtetra
.65 .82 .965 r
.55494 .47422 .56156 .47934 .57415 .47524 .56758 .47012 Mtetra
.655 .822 .964 r
.56758 .47012 .57415 .47524 .5868 .47094 .58028 .46585 Mtetra
.661 .826 .963 r
.58028 .46585 .5868 .47094 .59949 .46645 .59302 .46142 Mtetra
.667 .831 .962 r
.59302 .46142 .59949 .46645 .61224 .4618 .60582 .45679 Mtetra
.675 .835 .96 r
.60582 .45679 .61224 .4618 .62504 .4571 .61867 .45192 Mtetra
.685 .833 .955 r
.61867 .45192 .62504 .4571 .6379 .45257 .63156 .44679 Mtetra
.694 .817 .941 r
.63156 .44679 .6379 .45257 .65084 .44865 .6445 .44143 Mtetra
.694 .773 .912 r
.6445 .44143 .65084 .44865 .66389 .44574 .65749 .43606 Mtetra
.672 .702 .869 r
.65749 .43606 .66389 .44574 .67705 .44387 .67055 .43124 Mtetra
.633 .629 .828 r
.67055 .43124 .67705 .44387 .69031 .44231 .68373 .42773 Mtetra
.599 .583 .807 r
.68373 .42773 .69031 .44231 .70361 .43993 .69706 .42564 Mtetra
.596 .586 .812 r
.69706 .42564 .70361 .43993 .71691 .4362 .71047 .42368 Mtetra
.631 .632 .833 r
.71047 .42368 .71691 .4362 .7302 .43132 .72388 .42022 Mtetra
.658 .671 .851 r
.72388 .42022 .7302 .43132 .74355 .42643 .73728 .41571 Mtetra
.545 .626 .883 r
.73728 .41571 .74355 .42643 .75725 .42566 .75104 .41528 Mtetra
0 .283 .784 r
.75104 .41528 .75725 .42566 .77184 .43536 .76578 .42687 Mtetra
0 0 .461 r
.76578 .42687 .77184 .43536 .7872 .45241 .78142 .44729 Mtetra
0 .365 .798 r
.78142 .44729 .7872 .45241 .80182 .45769 .79626 .45468 Mtetra
.916 .931 .805 r
.79626 .45468 .80182 .45769 .81472 .44187 .80917 .43801 Mtetra
.959 .88 .712 r
.80917 .43801 .81472 .44187 .82702 .41997 .82138 .41398 Mtetra
.89 .86 .806 r
.82138 .41398 .82702 .41997 .83995 .40542 .83424 .39799 Mtetra
.756 .805 .892 r
.83424 .39799 .83995 .40542 .85356 .39778 .84786 .38981 Mtetra
.678 .764 .916 r
.84786 .38981 .85356 .39778 .86749 .39277 .86183 .38465 Mtetra
.658 .753 .92 r
.86183 .38465 .86749 .39277 .88155 .3883 .87594 .38014 Mtetra
.652 .751 .922 r
.24857 .56823 .25611 .57481 .26744 .57133 .25992 .56473 Mtetra
.625 .744 .932 r
.25992 .56473 .26744 .57133 .27877 .56846 .27127 .56193 Mtetra
.445 .681 .965 r
.27127 .56193 .27877 .56846 .28996 .56847 .28245 .56235 Mtetra
0 .097 .563 r
.28245 .56235 .28996 .56847 .30072 .5759 .29315 .57089 Mtetra
.828 .353 .008 r
.29315 .57089 .30072 .5759 .31114 .59093 .30345 .58758 Mtetra
.607 .04 0 r
.30345 .58758 .31114 .59093 .32215 .59884 .31442 .59637 Mtetra
.895 .857 .796 r
.31442 .59637 .32215 .59884 .33458 .58371 .32699 .58003 Mtetra
.925 .785 .688 r
.32699 .58003 .33458 .58371 .34764 .55616 .3403 .54955 Mtetra
.882 .764 .727 r
.3403 .54955 .34764 .55616 .36016 .53721 .35305 .52753 Mtetra
.764 .711 .803 r
.35305 .52753 .36016 .53721 .37209 .52992 .36512 .51788 Mtetra
.674 .643 .811 r
.36512 .51788 .37209 .52992 .38389 .52657 .37701 .51281 Mtetra
.659 .612 .791 r
.37701 .51281 .38389 .52657 .39578 .52219 .38892 .50809 Mtetra
.641 .6 .792 r
.38892 .50809 .39578 .52219 .40777 .51635 .40085 .50422 Mtetra
.614 .617 .83 r
.40085 .50422 .40777 .51635 .41979 .51062 .41278 .50176 Mtetra
.59 .676 .9 r
.41278 .50176 .41979 .51062 .43182 .50625 .42475 .49997 Mtetra
.571 .746 .96 r
.42475 .49997 .43182 .50625 .44386 .50317 .43679 .49808 Mtetra
.569 .788 .982 r
.43679 .49808 .44386 .50317 .45595 .50065 .44892 .49582 Mtetra
.584 .803 .983 r
.44892 .49582 .45595 .50065 .4681 .49812 .46111 .49316 Mtetra
.602 .806 .978 r
.46111 .49316 .4681 .49812 .48032 .49534 .47337 .49017 Mtetra
.618 .804 .971 r
.47337 .49017 .48032 .49534 .4926 .4923 .4857 .48692 Mtetra
.629 .801 .965 r
.4857 .48692 .4926 .4923 .50495 .48903 .49809 .48346 Mtetra
.636 .798 .96 r
.49809 .48346 .50495 .48903 .51736 .48557 .51055 .47983 Mtetra
.642 .795 .956 r
.51055 .47983 .51736 .48557 .52983 .48195 .52306 .47608 Mtetra
.647 .793 .952 r
.52306 .47608 .52983 .48195 .54236 .47816 .53563 .47221 Mtetra
.65 .792 .95 r
.53563 .47221 .54236 .47816 .55494 .47422 .54825 .46824 Mtetra
.654 .793 .949 r
.54825 .46824 .55494 .47422 .56758 .47012 .56094 .46416 Mtetra
.657 .796 .949 r
.56094 .46416 .56758 .47012 .58028 .46585 .57368 .45998 Mtetra
.66 .801 .95 r
.57368 .45998 .58028 .46585 .59302 .46142 .58648 .45566 Mtetra
.665 .807 .951 r
.58648 .45566 .59302 .46142 .60582 .45679 .59933 .45117 Mtetra
.671 .815 .953 r
.59933 .45117 .60582 .45679 .61867 .45192 .61223 .44648 Mtetra
.68 .825 .953 r
.61223 .44648 .61867 .45192 .63156 .44679 .62518 .44149 Mtetra
.691 .834 .952 r
.62518 .44149 .63156 .44679 .6445 .44143 .63817 .43615 Mtetra
.703 .839 .947 r
.63817 .43615 .6445 .44143 .65749 .43606 .6512 .43041 Mtetra
.715 .831 .936 r
.6512 .43041 .65749 .43606 .67055 .43124 .66426 .4243 Mtetra
.715 .791 .911 r
.66426 .4243 .67055 .43124 .68373 .42773 .67736 .41811 Mtetra
.687 .713 .868 r
.67736 .41811 .68373 .42773 .69706 .42564 .69054 .41261 Mtetra
.643 .63 .822 r
.69054 .41261 .69706 .42564 .71047 .42368 .70386 .40855 Mtetra
.619 .589 .797 r
.70386 .40855 .71047 .42368 .72388 .42022 .7173 .40538 Mtetra
.612 .589 .804 r
.7173 .40538 .72388 .42022 .73728 .41571 .73083 .4026 Mtetra
.486 .548 .845 r
.73083 .4026 .73728 .41571 .75104 .41528 .74476 .40454 Mtetra
0 .169 .707 r
.74476 .40454 .75104 .41528 .76578 .42687 .75974 .41925 Mtetra
.651 .193 0 r
.75974 .41925 .76578 .42687 .78142 .44729 .77562 .44264 Mtetra
0 .278 .717 r
.77562 .44264 .78142 .44729 .79626 .45468 .7906 .45121 Mtetra
.923 .917 .792 r
.7906 .45121 .79626 .45468 .80917 .43801 .80352 .43352 Mtetra
.961 .864 .697 r
.80352 .43352 .80917 .43801 .82138 .41398 .81565 .40768 Mtetra
.898 .852 .789 r
.81565 .40768 .82138 .41398 .83424 .39799 .82848 .39045 Mtetra
.766 .807 .886 r
.82848 .39045 .83424 .39799 .84786 .38981 .84211 .38177 Mtetra
.681 .765 .915 r
.84211 .38177 .84786 .38981 .86183 .38465 .85612 .37647 Mtetra
.659 .753 .92 r
.85612 .37647 .86183 .38465 .87594 .38014 .87028 .3719 Mtetra
.652 .751 .922 r
.24096 .56159 .24857 .56823 .25992 .56473 .25234 .55808 Mtetra
.621 .743 .934 r
.25234 .55808 .25992 .56473 .27127 .56193 .26372 .55536 Mtetra
.414 .667 .965 r
.26372 .55536 .27127 .56193 .28245 .56235 .27488 .55617 Mtetra
.511 0 0 r
.27488 .55617 .28245 .56235 .29315 .57089 .28551 .56566 Mtetra
.844 .379 .038 r
.28551 .56566 .29315 .57089 .30345 .58758 .29572 .58354 Mtetra
.612 .053 0 r
.29572 .58354 .30345 .58758 .31442 .59637 .30666 .59295 Mtetra
.889 .834 .786 r
.30666 .59295 .31442 .59637 .32699 .58003 .31934 .57604 Mtetra
.926 .777 .677 r
.31934 .57604 .32699 .58003 .3403 .54955 .33289 .5431 Mtetra
.897 .761 .704 r
.33289 .5431 .3403 .54955 .35305 .52753 .34594 .51678 Mtetra
.792 .701 .764 r
.34594 .51678 .35305 .52753 .36512 .51788 .35823 .50361 Mtetra
.662 .607 .783 r
.35823 .50361 .36512 .51788 .37701 .51281 .37012 .49858 Mtetra
.588 .572 .803 r
.37012 .49858 .37701 .51281 .38892 .50809 .3819 .49711 Mtetra
.546 .608 .866 r
.3819 .49711 .38892 .50809 .40085 .50422 .3937 .49678 Mtetra
.521 .69 .944 r
.3937 .49678 .40085 .50422 .41278 .50176 .40559 .49621 Mtetra
.523 .755 .981 r
.40559 .49621 .41278 .50176 .42475 .49997 .41758 .49491 Mtetra
.555 .785 .985 r
.41758 .49491 .42475 .49997 .43679 .49808 .42967 .49286 Mtetra
.589 .792 .976 r
.42967 .49286 .43679 .49808 .44892 .49582 .44184 .49022 Mtetra
.614 .788 .965 r
.44184 .49022 .44892 .49582 .46111 .49316 .45408 .48717 Mtetra
.628 .78 .954 r
.45408 .48717 .46111 .49316 .47337 .49017 .46638 .48385 Mtetra
.637 .773 .945 r
.46638 .48385 .47337 .49017 .4857 .48692 .47875 .48037 Mtetra
.642 .768 .94 r
.47875 .48037 .4857 .48692 .49809 .48346 .49118 .47676 Mtetra
.645 .766 .936 r
.49118 .47676 .49809 .48346 .51055 .47983 .50367 .47305 Mtetra
.648 .765 .934 r
.50367 .47305 .51055 .47983 .52306 .47608 .51622 .46925 Mtetra
.651 .765 .933 r
.51622 .46925 .52306 .47608 .53563 .47221 .52883 .46536 Mtetra
.654 .767 .932 r
.52883 .46536 .53563 .47221 .54825 .46824 .5415 .46136 Mtetra
.657 .768 .931 r
.5415 .46136 .54825 .46824 .56094 .46416 .55423 .45725 Mtetra
.66 .769 .93 r
.55423 .45725 .56094 .46416 .57368 .45998 .56701 .45303 Mtetra
.663 .77 .929 r
.56701 .45303 .57368 .45998 .58648 .45566 .57985 .44871 Mtetra
.666 .772 .929 r
.57985 .44871 .58648 .45566 .59933 .45117 .59274 .44428 Mtetra
.669 .775 .929 r
.59274 .44428 .59933 .45117 .61223 .44648 .60569 .43973 Mtetra
.673 .782 .931 r
.60569 .43973 .61223 .44648 .62518 .44149 .6187 .43503 Mtetra
.68 .794 .936 r
.6187 .43503 .62518 .44149 .63817 .43615 .63175 .43009 Mtetra
.692 .812 .939 r
.63175 .43009 .63817 .43615 .6512 .43041 .64484 .42471 Mtetra
.711 .83 .938 r
.64484 .42471 .6512 .43041 .66426 .4243 .65796 .41869 Mtetra
.734 .84 .93 r
.65796 .41869 .66426 .4243 .67736 .41811 .67109 .41189 Mtetra
.751 .825 .91 r
.67109 .41189 .67736 .41811 .69054 .41261 .68423 .40436 Mtetra
.744 .768 .872 r
.68423 .40436 .69054 .41261 .70386 .40855 .69739 .3966 Mtetra
.696 .674 .824 r
.69739 .3966 .70386 .40855 .7173 .40538 .71066 .39004 Mtetra
.612 .584 .798 r
.71066 .39004 .7173 .40538 .73083 .4026 .7242 .38715 Mtetra
.398 .461 .809 r
.7242 .38715 .73083 .4026 .74476 .40454 .73837 .39267 Mtetra
0 .042 .609 r
.73837 .39267 .74476 .40454 .75974 .41925 .75366 .41177 Mtetra
.706 .251 0 r
.75366 .41177 .75974 .41925 .77562 .44264 .76973 .43764 Mtetra
0 .264 .713 r
.76973 .43764 .77562 .44264 .7906 .45121 .78479 .44671 Mtetra
.921 .891 .783 r
.78479 .44671 .7906 .45121 .80352 .43352 .79774 .4283 Mtetra
.959 .848 .688 r
.79774 .4283 .80352 .43352 .81565 .40768 .80986 .40112 Mtetra
.904 .846 .777 r
.80986 .40112 .81565 .40768 .82848 .39045 .82267 .38283 Mtetra
.774 .809 .88 r
.82267 .38283 .82848 .39045 .84211 .38177 .83631 .37367 Mtetra
.684 .766 .914 r
.83631 .37367 .84211 .38177 .85612 .37647 .85036 .36822 Mtetra
.659 .753 .92 r
.85036 .36822 .85612 .37647 .87028 .3719 .86457 .36359 Mtetra
.651 .75 .922 r
.23329 .55491 .24096 .56159 .25234 .55808 .24471 .55139 Mtetra
.616 .741 .936 r
.24471 .55139 .25234 .55808 .26372 .55536 .2561 .54876 Mtetra
.379 .651 .964 r
.2561 .54876 .26372 .55536 .27488 .55617 .26725 .54997 Mtetra
.574 .042 0 r
.26725 .54997 .27488 .55617 .28551 .56566 .27782 .56029 Mtetra
.851 .392 .052 r
.27782 .56029 .28551 .56566 .29572 .58354 .28796 .5788 Mtetra
.557 0 0 r
.28796 .5788 .29572 .58354 .30666 .59295 .29893 .58787 Mtetra
.878 .799 .769 r
.29893 .58787 .30666 .59295 .31934 .57604 .31174 .57 Mtetra
.913 .754 .67 r
.31174 .57 .31934 .57604 .33289 .5431 .32549 .53539 Mtetra
.893 .743 .688 r
.32549 .53539 .33289 .5431 .34594 .51678 .33878 .50629 Mtetra
.807 .709 .757 r
.33878 .50629 .34594 .51678 .35823 .50361 .35118 .49166 Mtetra
.636 .63 .828 r
.35118 .49166 .35823 .50361 .37012 .49858 .363 .48831 Mtetra
.474 .59 .889 r
.363 .48831 .37012 .49858 .3819 .49711 .37467 .48952 Mtetra
.419 .639 .948 r
.37467 .48952 .3819 .49711 .3937 .49678 .38644 .4907 Mtetra
.469 .715 .976 r
.38644 .4907 .3937 .49678 .40559 .49621 .39835 .49044 Mtetra
.543 .756 .976 r
.39835 .49044 .40559 .49621 .41758 .49491 .41038 .48885 Mtetra
.59 .764 .962 r
.41038 .48885 .41758 .49491 .42967 .49286 .42251 .48642 Mtetra
.614 .761 .949 r
.42251 .48642 .42967 .49286 .44184 .49022 .43472 .48354 Mtetra
.626 .758 .941 r
.43472 .48354 .44184 .49022 .45408 .48717 .447 .48038 Mtetra
.633 .758 .938 r
.447 .48038 .45408 .48717 .46638 .48385 .45934 .47704 Mtetra
.638 .759 .936 r
.45934 .47704 .46638 .48385 .47875 .48037 .47175 .47353 Mtetra
.642 .761 .935 r
.47175 .47353 .47875 .48037 .49118 .47676 .48421 .46991 Mtetra
.646 .763 .934 r
.48421 .46991 .49118 .47676 .50367 .47305 .49674 .46617 Mtetra
.649 .764 .933 r
.49674 .46617 .50367 .47305 .51622 .46925 .50933 .46233 Mtetra
.651 .764 .932 r
.50933 .46233 .51622 .46925 .52883 .46536 .52198 .45839 Mtetra
.654 .765 .931 r
.52198 .45839 .52883 .46536 .5415 .46136 .53469 .45437 Mtetra
.656 .766 .93 r
.53469 .45437 .5415 .46136 .55423 .45725 .54745 .45027 Mtetra
.658 .768 .931 r
.54745 .45027 .55423 .45725 .56701 .45303 .56028 .44608 Mtetra
.66 .77 .931 r
.56028 .44608 .56701 .45303 .57985 .44871 .57316 .44179 Mtetra
.664 .774 .931 r
.57316 .44179 .57985 .44871 .59274 .44428 .5861 .43739 Mtetra
.668 .777 .931 r
.5861 .43739 .59274 .44428 .60569 .43973 .5991 .43283 Mtetra
.675 .78 .929 r
.5991 .43283 .60569 .43973 .6187 .43503 .61214 .42804 Mtetra
.682 .781 .925 r
.61214 .42804 .6187 .43503 .63175 .43009 .62524 .423 Mtetra
.69 .781 .921 r
.62524 .423 .63175 .43009 .64484 .42471 .63838 .41768 Mtetra
.701 .787 .918 r
.63838 .41768 .64484 .42471 .65796 .41869 .65157 .41197 Mtetra
.723 .804 .915 r
.65157 .41197 .65796 .41869 .67109 .41189 .66476 .40545 Mtetra
.758 .822 .902 r
.66476 .40545 .67109 .41189 .68423 .40436 .67794 .39756 Mtetra
.787 .818 .877 r
.67794 .39756 .68423 .40436 .69739 .3966 .69107 .38816 Mtetra
.774 .774 .853 r
.69107 .38816 .69739 .3966 .71066 .39004 .70423 .37876 Mtetra
.66 .672 .851 r
.70423 .37876 .71066 .39004 .7242 .38715 .71769 .37408 Mtetra
.298 .439 .835 r
.71769 .37408 .7242 .38715 .73837 .39267 .73196 .38103 Mtetra
0 0 .521 r
.73196 .38103 .73837 .39267 .75366 .41177 .74743 .40292 Mtetra
.688 .253 0 r
.74743 .40292 .75366 .41177 .76973 .43764 .76362 .43045 Mtetra
0 .288 .773 r
.76362 .43045 .76973 .43764 .78479 .44671 .77879 .44046 Mtetra
.903 .852 .783 r
.77879 .44046 .78479 .44671 .79774 .4283 .79184 .42232 Mtetra
.956 .835 .685 r
.79184 .42232 .79774 .4283 .80986 .40112 .80399 .3944 Mtetra
.909 .843 .767 r
.80399 .3944 .80986 .40112 .82267 .38283 .8168 .37517 Mtetra
.784 .812 .875 r
.8168 .37517 .82267 .38283 .83631 .37367 .83046 .36551 Mtetra
.687 .768 .913 r
.83046 .36551 .83631 .37367 .85036 .36822 .84455 .35989 Mtetra
.66 .754 .92 r
.84455 .35989 .85036 .36822 .86457 .36359 .8588 .3552 Mtetra
.65 .75 .923 r
.22557 .54817 .23329 .55491 .24471 .55139 .237 .54464 Mtetra
.61 .74 .938 r
.237 .54464 .24471 .55139 .2561 .54876 .24841 .54212 Mtetra
.338 .632 .96 r
.24841 .54212 .2561 .54876 .26725 .54997 .25954 .54378 Mtetra
.623 .094 0 r
.25954 .54378 .26725 .54997 .27782 .56029 .27006 .55483 Mtetra
.85 .389 .048 r
.27006 .55483 .27782 .56029 .28796 .5788 .28018 .57329 Mtetra
0 .2 .638 r
.28018 .57329 .28796 .5788 .29893 .58787 .29129 .58042 Mtetra
.865 .756 .74 r
.29129 .58042 .29893 .58787 .31174 .57 .3043 .56038 Mtetra
.889 .722 .668 r
.3043 .56038 .31174 .57 .32549 .53539 .31813 .52599 Mtetra
.876 .727 .694 r
.31813 .52599 .32549 .53539 .33878 .50629 .33138 .49899 Mtetra
.826 .767 .797 r
.33138 .49899 .33878 .50629 .35118 .49166 .34375 .48584 Mtetra
.639 .783 .951 r
.34375 .48584 .35118 .49166 .363 .48831 .35562 .48234 Mtetra
.411 .692 .978 r
.35562 .48234 .363 .48831 .37467 .48952 .36735 .48281 Mtetra
.418 .67 .966 r
.36735 .48281 .37467 .48952 .38644 .4907 .37916 .48354 Mtetra
.502 .694 .955 r
.37916 .48354 .38644 .4907 .39835 .49044 .39109 .48314 Mtetra
.562 .715 .944 r
.39109 .48314 .39835 .49044 .41038 .48885 .40315 .48159 Mtetra
.597 .73 .937 r
.40315 .48159 .41038 .48885 .42251 .48642 .41531 .47923 Mtetra
.617 .74 .934 r
.41531 .47923 .42251 .48642 .43472 .48354 .42755 .47636 Mtetra
.628 .745 .931 r
.42755 .47636 .43472 .48354 .447 .48038 .43986 .47317 Mtetra
.636 .747 .929 r
.43986 .47317 .447 .48038 .45934 .47704 .45224 .46977 Mtetra
.641 .748 .927 r
.45224 .46977 .45934 .47704 .47175 .47353 .46468 .4662 Mtetra
.645 .749 .925 r
.46468 .4662 .47175 .47353 .48421 .46991 .47719 .46251 Mtetra
.648 .749 .923 r
.47719 .46251 .48421 .46991 .49674 .46617 .48975 .45871 Mtetra
.651 .749 .922 r
.48975 .45871 .49674 .46617 .50933 .46233 .50238 .45481 Mtetra
.653 .749 .92 r
.50238 .45481 .50933 .46233 .52198 .45839 .51507 .45082 Mtetra
.656 .749 .919 r
.51507 .45082 .52198 .45839 .53469 .45437 .52781 .44671 Mtetra
.659 .749 .917 r
.52781 .44671 .53469 .45437 .54745 .45027 .54062 .4425 Mtetra
.662 .748 .914 r
.54062 .4425 .54745 .45027 .56028 .44608 .55348 .43818 Mtetra
.664 .746 .911 r
.55348 .43818 .56028 .44608 .57316 .44179 .5664 .43377 Mtetra
.665 .744 .909 r
.5664 .43377 .57316 .44179 .5861 .43739 .57938 .42929 Mtetra
.667 .744 .908 r
.57938 .42929 .5861 .43739 .5991 .43283 .59242 .42475 Mtetra
.668 .745 .908 r
.59242 .42475 .5991 .43283 .61214 .42804 .60551 .42016 Mtetra
.672 .753 .912 r
.60551 .42016 .61214 .42804 .62524 .423 .61866 .4154 Mtetra
.684 .766 .914 r
.61866 .4154 .62524 .423 .63838 .41768 .63185 .41022 Mtetra
.703 .777 .909 r
.63185 .41022 .63838 .41768 .65157 .41197 .64508 .40434 Mtetra
.726 .78 .896 r
.64508 .40434 .65157 .41197 .66476 .40545 .65831 .39754 Mtetra
.749 .78 .878 r
.65831 .39754 .66476 .40545 .67794 .39756 .67154 .38963 Mtetra
.77 .786 .866 r
.67154 .38963 .67794 .39756 .69107 .38816 .68475 .38063 Mtetra
.768 .797 .877 r
.68475 .38063 .69107 .38816 .70423 .37876 .698 .37192 Mtetra
.662 .788 .941 r
.698 .37192 .70423 .37876 .71769 .37408 .71151 .3673 Mtetra
.115 .492 .903 r
.71151 .3673 .71769 .37408 .73196 .38103 .72572 .37264 Mtetra
0 0 .456 r
.72572 .37264 .73196 .38103 .74743 .40292 .74104 .39227 Mtetra
.614 .206 0 r
.74104 .39227 .74743 .40292 .76362 .43045 .75718 .41949 Mtetra
0 .273 .778 r
.75718 .41949 .76362 .43045 .77879 .44046 .77253 .43169 Mtetra
.859 .798 .789 r
.77253 .43169 .77879 .44046 .79184 .42232 .78582 .41552 Mtetra
.949 .824 .686 r
.78582 .41552 .79184 .42232 .80399 .3944 .79807 .38758 Mtetra
.914 .841 .758 r
.79807 .38758 .80399 .3944 .8168 .37517 .81088 .36751 Mtetra
.793 .816 .87 r
.81088 .36751 .8168 .37517 .83046 .36551 .82456 .35731 Mtetra
.691 .771 .912 r
.82456 .35731 .83046 .36551 .84455 .35989 .83869 .35149 Mtetra
.66 .754 .92 r
.83869 .35149 .84455 .35989 .8588 .3552 .85298 .34674 Mtetra
.649 .75 .923 r
.21777 .54137 .22557 .54817 .237 .54464 .22924 .53784 Mtetra
.603 .738 .94 r
.22924 .53784 .237 .54464 .24841 .54212 .24066 .53546 Mtetra
.293 .609 .954 r
.24066 .53546 .24841 .54212 .25954 .54378 .25177 .53758 Mtetra
.654 .129 0 r
.25177 .53758 .25954 .54378 .27006 .55483 .26223 .54917 Mtetra
.836 .366 .011 r
.26223 .54917 .27006 .55483 .28018 .57329 .27241 .56671 Mtetra
.132 .522 .915 r
.27241 .56671 .28018 .57329 .29129 .58042 .28377 .5704 Mtetra
.854 .721 .715 r
.28377 .5704 .29129 .58042 .3043 .56038 .29701 .54776 Mtetra
.865 .697 .672 r
.29701 .54776 .3043 .56038 .31813 .52599 .31076 .51599 Mtetra
.85 .722 .722 r
.31076 .51599 .31813 .52599 .33138 .49899 .32372 .49496 Mtetra
.815 .856 .879 r
.32372 .49496 .33138 .49899 .34375 .48584 .33596 .48517 Mtetra
.605 .932 .96 r
.33596 .48517 .34375 .48584 .35562 .48234 .34797 .48009 Mtetra
.52 .866 .991 r
.34797 .48009 .35562 .48234 .36735 .48281 .35991 .4771 Mtetra
.533 .757 .979 r
.35991 .4771 .36735 .48281 .37916 .48354 .37185 .4756 Mtetra
.544 .69 .934 r
.37185 .4756 .37916 .48354 .39109 .48314 .38383 .47458 Mtetra
.566 .682 .918 r
.38383 .47458 .39109 .48314 .40315 .48159 .39591 .47317 Mtetra
.591 .696 .916 r
.39591 .47317 .40315 .48159 .41531 .47923 .40808 .47111 Mtetra
.61 .713 .918 r
.40808 .47111 .41531 .47923 .42755 .47636 .42034 .46849 Mtetra
.624 .726 .92 r
.42034 .46849 .42755 .47636 .43986 .47317 .43268 .46544 Mtetra
.633 .734 .92 r
.43268 .46544 .43986 .47317 .45224 .46977 .44509 .46211 Mtetra
.639 .739 .921 r
.44509 .46211 .45224 .46977 .46468 .4662 .45757 .4586 Mtetra
.642 .742 .921 r
.45757 .4586 .46468 .4662 .47719 .46251 .47011 .45495 Mtetra
.645 .745 .922 r
.47011 .45495 .47719 .46251 .48975 .45871 .48271 .4512 Mtetra
.648 .749 .923 r
.48271 .4512 .48975 .45871 .50238 .45481 .49537 .44736 Mtetra
.65 .752 .924 r
.49537 .44736 .50238 .45481 .51507 .45082 .50809 .44342 Mtetra
.652 .755 .925 r
.50809 .44342 .51507 .45082 .52781 .44671 .52088 .43938 Mtetra
.655 .759 .926 r
.52088 .43938 .52781 .44671 .54062 .4425 .53372 .43525 Mtetra
.658 .763 .928 r
.53372 .43525 .54062 .4425 .55348 .43818 .54663 .43102 Mtetra
.662 .768 .929 r
.54663 .43102 .55348 .43818 .5664 .43377 .55959 .42663 Mtetra
.668 .772 .928 r
.55959 .42663 .5664 .43377 .57938 .42929 .57261 .42202 Mtetra
.676 .772 .923 r
.57261 .42202 .57938 .42929 .59242 .42475 .58569 .41716 Mtetra
.685 .766 .913 r
.58569 .41716 .59242 .42475 .60551 .42016 .59881 .41196 Mtetra
.69 .753 .899 r
.59881 .41196 .60551 .42016 .61866 .4154 .61198 .40651 Mtetra
.692 .737 .885 r
.61198 .40651 .61866 .4154 .63185 .41022 .6252 .40087 Mtetra
.697 .728 .874 r
.6252 .40087 .63185 .41022 .64508 .40434 .63847 .39493 Mtetra
.711 .732 .868 r
.63847 .39493 .64508 .40434 .65831 .39754 .65175 .38834 Mtetra
.725 .743 .866 r
.65175 .38834 .65831 .39754 .67154 .38963 .66506 .38113 Mtetra
.722 .761 .883 r
.66506 .38113 .67154 .38963 .68475 .38063 .67842 .37424 Mtetra
.684 .81 .943 r
.67842 .37424 .68475 .38063 .698 .37192 .69191 .36891 Mtetra
.505 .856 .992 r
.69191 .36891 .698 .37192 .71151 .3673 .70558 .3658 Mtetra
0 .549 .779 r
.70558 .3658 .71151 .3673 .72572 .37264 .71963 .36757 Mtetra
.496 0 0 r
.71963 .36757 .72572 .37264 .74104 .39227 .73456 .38092 Mtetra
0 0 .446 r
.73456 .38092 .74104 .39227 .75718 .41949 .75049 .40535 Mtetra
0 .231 .741 r
.75049 .40535 .75718 .41949 .77253 .43169 .76603 .42021 Mtetra
.792 .733 .798 r
.76603 .42021 .77253 .43169 .78582 .41552 .77965 .40757 Mtetra
.936 .809 .695 r
.77965 .40757 .78582 .41552 .79807 .38758 .79207 .38053 Mtetra
.916 .836 .752 r
.79207 .38053 .79807 .38758 .81088 .36751 .80492 .35981 Mtetra
.803 .819 .864 r
.80492 .35981 .81088 .36751 .82456 .35731 .8186 .34905 Mtetra
.696 .773 .911 r
.8186 .34905 .82456 .35731 .83869 .35149 .83277 .34303 Mtetra
.661 .755 .919 r
.83277 .34303 .83869 .35149 .85298 .34674 .84711 .3382 Mtetra
.648 .75 .923 r
.20992 .53453 .21777 .54137 .22924 .53784 .22141 .531 Mtetra
.595 .736 .942 r
.22141 .531 .22924 .53784 .24066 .53546 .23284 .52875 Mtetra
.25 .586 .946 r
.23284 .52875 .24066 .53546 .25177 .53758 .24393 .53129 Mtetra
.66 .135 0 r
.24393 .53129 .25177 .53758 .26223 .54917 .25438 .54302 Mtetra
.795 .306 0 r
.25438 .54302 .26223 .54917 .27241 .56671 .26468 .5587 Mtetra
.503 .672 .94 r
.26468 .5587 .27241 .56671 .28377 .5704 .27633 .55847 Mtetra
.845 .701 .702 r
.27633 .55847 .28377 .5704 .29701 .54776 .28973 .53448 Mtetra
.85 .69 .683 r
.28973 .53448 .29701 .54776 .31076 .51599 .30328 .50673 Mtetra
.823 .732 .765 r
.30328 .50673 .31076 .51599 .32372 .49496 .31594 .49153 Mtetra
.728 .88 .951 r
.31594 .49153 .32372 .49496 .33596 .48517 .32803 .48532 Mtetra
.545 .922 .928 r
.32803 .48532 .33596 .48517 .34797 .48009 .34009 .48037 Mtetra
.601 .945 .928 r
.34009 .48037 .34797 .48009 .35991 .4771 .35223 .47457 Mtetra
.663 .902 .98 r
.35223 .47457 .35991 .4771 .37185 .4756 .36439 .4695 Mtetra
.629 .778 .952 r
.36439 .4695 .37185 .4756 .38383 .47458 .37651 .46614 Mtetra
.596 .699 .915 r
.37651 .46614 .38383 .47458 .39591 .47317 .38864 .46393 Mtetra
.591 .677 .9 r
.38864 .46393 .39591 .47317 .40808 .47111 .40083 .46192 Mtetra
.601 .683 .899 r
.40083 .46192 .40808 .47111 .42034 .46849 .41311 .4596 Mtetra
.613 .696 .903 r
.41311 .4596 .42034 .46849 .43268 .46544 .42546 .4569 Mtetra
.624 .71 .907 r
.42546 .4569 .43268 .46544 .44509 .46211 .4379 .45384 Mtetra
.633 .721 .911 r
.4379 .45384 .44509 .46211 .45757 .4586 .4504 .45049 Mtetra
.64 .729 .913 r
.4504 .45049 .45757 .4586 .47011 .45495 .46297 .4469 Mtetra
.645 .733 .913 r
.46297 .4469 .47011 .45495 .48271 .4512 .47561 .44313 Mtetra
.65 .735 .912 r
.47561 .44313 .48271 .4512 .49537 .44736 .48831 .4392 Mtetra
.653 .735 .91 r
.48831 .4392 .49537 .44736 .50809 .44342 .50107 .43514 Mtetra
.657 .734 .907 r
.50107 .43514 .50809 .44342 .52088 .43938 .51389 .43095 Mtetra
.66 .732 .903 r
.51389 .43095 .52088 .43938 .53372 .43525 .52677 .42664 Mtetra
.662 .729 .899 r
.52677 .42664 .53372 .43525 .54663 .43102 .53971 .42224 Mtetra
.662 .726 .896 r
.53971 .42224 .54663 .43102 .55959 .42663 .55271 .41779 Mtetra
.662 .725 .896 r
.55271 .41779 .55959 .42663 .57261 .42202 .56577 .41335 Mtetra
.664 .731 .899 r
.56577 .41335 .57261 .42202 .58569 .41716 .57889 .4088 Mtetra
.672 .743 .904 r
.57889 .4088 .58569 .41716 .59881 .41196 .59206 .40398 Mtetra
.69 .76 .905 r
.59206 .40398 .59881 .41196 .61198 .40651 .60528 .39852 Mtetra
.713 .768 .896 r
.60528 .39852 .61198 .40651 .6252 .40087 .61853 .39216 Mtetra
.723 .754 .877 r
.61853 .39216 .6252 .40087 .63847 .39493 .6318 .38521 Mtetra
.706 .726 .865 r
.6318 .38521 .63847 .39493 .65175 .38834 .64513 .37874 Mtetra
.666 .714 .884 r
.64513 .37874 .65175 .38834 .66506 .38113 .65858 .37394 Mtetra
.6 .755 .952 r
.65858 .37394 .66506 .38113 .67842 .37424 .67218 .37101 Mtetra
.467 .832 .993 r
.67218 .37101 .67842 .37424 .69191 .36891 .68589 .36859 Mtetra
.338 .818 .866 r
.68589 .36859 .69191 .36891 .70558 .3658 .69962 .36517 Mtetra
.245 .757 .854 r
.69962 .36517 .70558 .3658 .71963 .36757 .71351 .36309 Mtetra
0 .328 .745 r
.71351 .36309 .71963 .36757 .73456 .38092 .72808 .37031 Mtetra
0 0 .534 r
.72808 .37031 .73456 .38092 .75049 .40535 .74371 .39049 Mtetra
0 .198 .719 r
.74371 .39049 .75049 .40535 .76603 .42021 .75934 .40669 Mtetra
.718 .674 .806 r
.75934 .40669 .76603 .42021 .77965 .40757 .77332 .39808 Mtetra
.914 .788 .708 r
.77332 .39808 .77965 .40757 .79207 .38053 .78598 .37293 Mtetra
.912 .827 .749 r
.78598 .37293 .79207 .38053 .80492 .35981 .79889 .352 Mtetra
.81 .82 .858 r
.79889 .352 .80492 .35981 .8186 .34905 .8126 .34074 Mtetra
.7 .775 .91 r
.8126 .34074 .8186 .34905 .83277 .34303 .8268 .33449 Mtetra
.662 .755 .919 r
.8268 .33449 .83277 .34303 .84711 .3382 .84119 .32959 Mtetra
.647 .75 .924 r
.202 .52762 .20992 .53453 .22141 .531 .21352 .52409 Mtetra
.588 .733 .944 r
.21352 .52409 .22141 .531 .23284 .52875 .22496 .52198 Mtetra
.224 .572 .94 r
.22496 .52198 .23284 .52875 .24393 .53129 .23604 .52476 Mtetra
.628 .103 0 r
.23604 .52476 .24393 .53129 .25438 .54302 .24651 .53606 Mtetra
.694 .185 0 r
.24651 .53606 .25438 .54302 .26468 .5587 .25699 .54924 Mtetra
.639 .687 .879 r
.25699 .54924 .26468 .5587 .27633 .55847 .2689 .54584 Mtetra
.838 .693 .703 r
.2689 .54584 .27633 .55847 .28973 .53448 .28231 .52245 Mtetra
.844 .7 .703 r
.28231 .52245 .28973 .53448 .30328 .50673 .29565 .49892 Mtetra
.806 .76 .81 r
.29565 .49892 .30328 .50673 .31594 .49153 .30813 .48721 Mtetra
.661 .843 .97 r
.30813 .48721 .31594 .49153 .32803 .48532 .32016 .48282 Mtetra
.564 .875 .994 r
.32016 .48282 .32803 .48532 .34009 .48037 .33218 .47935 Mtetra
.613 .928 .967 r
.33218 .47935 .34009 .48037 .35223 .47457 .34434 .47426 Mtetra
.67 .957 .945 r
.34434 .47426 .35223 .47457 .36439 .4695 .35663 .46777 Mtetra
.706 .934 .963 r
.35663 .46777 .36439 .4695 .37651 .46614 .36895 .46136 Mtetra
.685 .838 .956 r
.36895 .46136 .37651 .46614 .38864 .46393 .38124 .45632 Mtetra
.641 .74 .921 r
.38124 .45632 .38864 .46393 .40083 .46192 .39353 .45275 Mtetra
.617 .691 .897 r
.39353 .45275 .40083 .46192 .41311 .4596 .40585 .44994 Mtetra
.614 .679 .888 r
.40585 .44994 .41311 .4596 .42546 .4569 .41822 .44723 Mtetra
.62 .682 .887 r
.41822 .44723 .42546 .4569 .4379 .45384 .43068 .44431 Mtetra
.628 .689 .888 r
.43068 .44431 .4379 .45384 .4504 .45049 .4432 .44112 Mtetra
.634 .696 .89 r
.4432 .44112 .4504 .45049 .46297 .4469 .4558 .43769 Mtetra
.641 .703 .892 r
.4558 .43769 .46297 .4469 .47561 .44313 .46846 .43404 Mtetra
.646 .709 .893 r
.46846 .43404 .47561 .44313 .48831 .4392 .48119 .43019 Mtetra
.652 .714 .893 r
.48119 .43019 .48831 .4392 .50107 .43514 .49399 .42611 Mtetra
.658 .717 .892 r
.49399 .42611 .50107 .43514 .51389 .43095 .50684 .42182 Mtetra
.663 .717 .889 r
.50684 .42182 .51389 .43095 .52677 .42664 .51976 .41731 Mtetra
.669 .715 .883 r
.51976 .41731 .52677 .42664 .53971 .42224 .53273 .41255 Mtetra
.675 .71 .875 r
.53273 .41255 .53971 .42224 .55271 .41779 .54576 .40751 Mtetra
.679 .7 .862 r
.54576 .40751 .55271 .41779 .56577 .41335 .55884 .40218 Mtetra
.678 .682 .847 r
.55884 .40218 .56577 .41335 .57889 .4088 .57198 .3967 Mtetra
.672 .663 .833 r
.57198 .3967 .57889 .4088 .59206 .40398 .58517 .3913 Mtetra
.66 .649 .828 r
.58517 .3913 .59206 .40398 .60528 .39852 .59842 .38632 Mtetra
.65 .653 .84 r
.59842 .38632 .60528 .39852 .61853 .39216 .61175 .3819 Mtetra
.642 .69 .879 r
.61175 .3819 .61853 .39216 .6318 .38521 .62516 .37797 Mtetra
.619 .762 .947 r
.62516 .37797 .6318 .38521 .64513 .37874 .63865 .37455 Mtetra
.521 .825 1 r
.63865 .37455 .64513 .37874 .65858 .37394 .65225 .37195 Mtetra
.37 .813 .951 r
.65225 .37195 .65858 .37394 .67218 .37101 .66596 .36978 Mtetra
.391 .84 .927 r
.66596 .36978 .67218 .37101 .68589 .36859 .6797 .36662 Mtetra
.558 .908 .969 r
.6797 .36662 .68589 .36859 .69962 .36517 .69343 .36178 Mtetra
.57 .876 .994 r
.69343 .36178 .69962 .36517 .71351 .36309 .70727 .35772 Mtetra
.146 .57 .929 r
.70727 .35772 .71351 .36309 .72808 .37031 .72165 .3612 Mtetra
0 .077 .62 r
.72165 .3612 .72808 .37031 .74371 .39049 .73699 .3769 Mtetra
0 .196 .723 r
.73699 .3769 .74371 .39049 .75934 .40669 .75256 .39239 Mtetra
.657 .635 .816 r
.75256 .39239 .75934 .40669 .77332 .39808 .76681 .38705 Mtetra
.885 .764 .723 r
.76681 .38705 .77332 .39808 .78598 .37293 .77976 .36446 Mtetra
.901 .811 .75 r
.77976 .36446 .78598 .37293 .79889 .352 .79278 .34392 Mtetra
.812 .815 .852 r
.79278 .34392 .79889 .352 .8126 .34074 .80653 .33233 Mtetra
.705 .776 .908 r
.80653 .33233 .8126 .34074 .8268 .33449 .82077 .32587 Mtetra
.663 .756 .919 r
.82077 .32587 .8268 .33449 .84119 .32959 .83521 .3209 Mtetra
.646 .749 .924 r
.19401 .52066 .202 .52762 .21352 .52409 .20556 .51713 Mtetra
.583 .732 .945 r
.20556 .51713 .21352 .52409 .22496 .52198 .21702 .51508 Mtetra
.23 .572 .941 r
.21702 .51508 .22496 .52198 .23604 .52476 .22811 .51783 Mtetra
.546 .023 0 r
.22811 .51783 .23604 .52476 .24651 .53606 .23866 .52815 Mtetra
0 .008 .509 r
.23866 .52815 .24651 .53606 .25699 .54924 .24933 .53874 Mtetra
.681 .681 .843 r
.24933 .53874 .25699 .54924 .2689 .54584 .2614 .53354 Mtetra
.832 .696 .713 r
.2614 .53354 .2689 .54584 .28231 .52245 .27472 .51223 Mtetra
.843 .721 .729 r
.27472 .51223 .28231 .52245 .29565 .49892 .28786 .49234 Mtetra
.796 .789 .846 r
.28786 .49234 .29565 .49892 .30813 .48721 .30028 .48231 Mtetra
.66 .825 .963 r
.30028 .48231 .30813 .48721 .32016 .48282 .31234 .47802 Mtetra
.602 .815 .982 r
.31234 .47802 .32016 .48282 .33218 .47935 .32438 .47489 Mtetra
.621 .832 .981 r
.32438 .47489 .33218 .47935 .34434 .47426 .33651 .47127 Mtetra
.641 .886 .985 r
.33651 .47127 .34434 .47426 .35663 .46777 .34875 .46671 Mtetra
.652 .94 .964 r
.34875 .46671 .35663 .46777 .36895 .46136 .36109 .46091 Mtetra
.674 .957 .946 r
.36109 .46091 .36895 .46136 .38124 .45632 .37352 .45429 Mtetra
.706 .929 .964 r
.37352 .45429 .38124 .45632 .39353 .45275 .38598 .44789 Mtetra
.696 .841 .952 r
.38598 .44789 .39353 .45275 .40585 .44994 .39844 .44247 Mtetra
.664 .755 .918 r
.39844 .44247 .40585 .44994 .41822 .44723 .41091 .43814 Mtetra
.642 .706 .893 r
.41091 .43814 .41822 .44723 .43068 .44431 .42341 .43448 Mtetra
.634 .686 .881 r
.42341 .43448 .43068 .44431 .4432 .44112 .43597 .43104 Mtetra
.636 .682 .877 r
.43597 .43104 .4432 .44112 .4558 .43769 .44859 .42752 Mtetra
.641 .683 .874 r
.44859 .42752 .4558 .43769 .46846 .43404 .46129 .42377 Mtetra
.648 .684 .871 r
.46129 .42377 .46846 .43404 .48119 .43019 .47404 .41976 Mtetra
.653 .684 .866 r
.47404 .41976 .48119 .43019 .49399 .42611 .48687 .41551 Mtetra
.657 .683 .862 r
.48687 .41551 .49399 .42611 .50684 .42182 .49975 .41107 Mtetra
.659 .681 .86 r
.49975 .41107 .50684 .42182 .51976 .41731 .5127 .4065 Mtetra
.661 .681 .859 r
.5127 .4065 .51976 .41731 .53273 .41255 .5257 .40187 Mtetra
.662 .685 .862 r
.5257 .40187 .53273 .41255 .54576 .40751 .53876 .3972 Mtetra
.665 .695 .868 r
.53876 .3972 .54576 .40751 .55884 .40218 .55188 .39242 Mtetra
.674 .712 .877 r
.55188 .39242 .55884 .40218 .57198 .3967 .56506 .38735 Mtetra
.68 .724 .883 r
.56506 .38735 .57198 .3967 .58517 .3913 .57829 .38206 Mtetra
.671 .725 .89 r
.57829 .38206 .58517 .3913 .59842 .38632 .59159 .37711 Mtetra
.628 .71 .905 r
.59159 .37711 .59842 .38632 .61175 .3819 .60498 .37363 Mtetra
.539 .698 .942 r
.60498 .37363 .61175 .3819 .62516 .37797 .61851 .37241 Mtetra
.409 .724 .989 r
.61851 .37241 .62516 .37797 .63865 .37455 .63217 .37232 Mtetra
.331 .785 .95 r
.63217 .37232 .63865 .37455 .65225 .37195 .64588 .3708 Mtetra
.459 .877 .936 r
.64588 .3708 .65225 .37195 .66596 .36978 .65957 .36672 Mtetra
.632 .908 .983 r
.65957 .36672 .66596 .36978 .6797 .36662 .67328 .36134 Mtetra
.676 .852 .967 r
.67328 .36134 .6797 .36662 .69343 .36178 .68704 .35587 Mtetra
.629 .816 .972 r
.68704 .35587 .69343 .36178 .70727 .35772 .70094 .35171 Mtetra
.311 .656 .971 r
.70094 .35171 .70727 .35772 .72165 .3612 .71525 .35336 Mtetra
0 .201 .71 r
.71525 .35336 .72165 .3612 .73699 .3769 .73035 .36517 Mtetra
0 .237 .754 r
.73035 .36517 .73699 .3769 .75256 .39239 .74577 .37841 Mtetra
.62 .622 .832 r
.74577 .37841 .75256 .39239 .76681 .38705 .76019 .37487 Mtetra
.857 .744 .738 r
.76019 .37487 .76681 .38705 .77976 .36446 .77341 .35495 Mtetra
.883 .793 .755 r
.77341 .35495 .77976 .36446 .79278 .34392 .78659 .33539 Mtetra
.808 .805 .848 r
.78659 .33539 .79278 .34392 .80653 .33233 .8004 .32377 Mtetra
.707 .775 .905 r
.8004 .32377 .80653 .33233 .82077 .32587 .81469 .31717 Mtetra
.664 .756 .919 r
.81469 .31717 .82077 .32587 .83521 .3209 .82918 .31213 Mtetra
.646 .749 .924 r
.18596 .51364 .19401 .52066 .20556 .51713 .19753 .51009 Mtetra
.584 .731 .945 r
.19753 .51009 .20556 .51713 .21702 .51508 .20902 .508 Mtetra
.269 .59 .947 r
.20902 .508 .21702 .51508 .22811 .51783 .22016 .5104 Mtetra
0 .101 .591 r
.22016 .5104 .22811 .51783 .23866 .52815 .23082 .51935 Mtetra
0 .208 .716 r
.23082 .51935 .23866 .52815 .24933 .53874 .24166 .52774 Mtetra
.687 .675 .833 r
.24166 .52774 .24933 .53874 .2614 .53354 .25378 .52212 Mtetra
.826 .705 .732 r
.25378 .52212 .2614 .53354 .27472 .51223 .26695 .50349 Mtetra
.841 .744 .756 r
.26695 .50349 .27472 .51223 .28786 .49234 .27996 .48638 Mtetra
.79 .807 .866 r
.27996 .48638 .28786 .49234 .30028 .48231 .29237 .47709 Mtetra
.676 .82 .952 r
.29237 .47709 .30028 .48231 .31234 .47802 .3045 .47241 Mtetra
.63 .798 .963 r
.3045 .47241 .31234 .47802 .32438 .47489 .3166 .46887 Mtetra
.635 .787 .954 r
.3166 .46887 .32438 .47489 .33651 .47127 .32876 .46527 Mtetra
.64 .79 .954 r
.32876 .46527 .33651 .47127 .34875 .46671 .34099 .46152 Mtetra
.64 .816 .968 r
.34099 .46152 .34875 .46671 .36109 .46091 .35329 .45759 Mtetra
.635 .877 .986 r
.35329 .45759 .36109 .46091 .37352 .45429 .36567 .45317 Mtetra
.616 .931 .966 r
.36567 .45317 .37352 .45429 .38598 .44789 .37814 .44785 Mtetra
.612 .947 .933 r
.37814 .44785 .38598 .44789 .39844 .44247 .39069 .44179 Mtetra
.653 .951 .951 r
.39069 .44179 .39844 .44247 .41091 .43814 .4033 .4355 Mtetra
.692 .914 .971 r
.4033 .4355 .41091 .43814 .42341 .43448 .41593 .4295 Mtetra
.695 .843 .954 r
.41593 .4295 .42341 .43448 .43597 .43104 .42859 .42402 Mtetra
.682 .778 .923 r
.42859 .42402 .43597 .43104 .44859 .42752 .44129 .41901 Mtetra
.67 .734 .899 r
.44129 .41901 .44859 .42752 .46129 .42377 .45404 .41434 Mtetra
.66 .709 .884 r
.45404 .41434 .46129 .42377 .47404 .41976 .46684 .4099 Mtetra
.654 .698 .879 r
.46684 .4099 .47404 .41976 .48687 .41551 .47969 .40564 Mtetra
.649 .697 .881 r
.47969 .40564 .48687 .41551 .49975 .41107 .4926 .40154 Mtetra
.646 .705 .89 r
.4926 .40154 .49975 .41107 .5127 .4065 .50558 .39755 Mtetra
.644 .719 .903 r
.50558 .39755 .5127 .4065 .5257 .40187 .51862 .39364 Mtetra
.64 .738 .919 r
.51862 .39364 .5257 .40187 .53876 .3972 .53172 .3898 Mtetra
.626 .758 .941 r
.53172 .3898 .53876 .3972 .55188 .39242 .54489 .38628 Mtetra
.583 .782 .974 r
.54489 .38628 .55188 .39242 .56506 .38735 .55815 .38347 Mtetra
.481 .816 .999 r
.55815 .38347 .56506 .38735 .57829 .38206 .57148 .38134 Mtetra
.278 .777 .876 r
.57148 .38134 .57829 .38206 .59159 .37711 .58491 .37914 Mtetra
0 0 0 r
.58491 .37914 .59159 .37711 .60498 .37363 .59838 .3757 Mtetra
.264 .76 .696 r
.59838 .3757 .60498 .37363 .61851 .37241 .6119 .37087 Mtetra
.535 .905 .959 r
.6119 .37087 .61851 .37241 .63217 .37232 .62547 .36615 Mtetra
.604 .796 .973 r
.62547 .36615 .63217 .37232 .64588 .3708 .63917 .36271 Mtetra
.614 .741 .936 r
.63917 .36271 .64588 .3708 .65957 .36672 .65294 .35942 Mtetra
.657 .782 .941 r
.65294 .35942 .65957 .36672 .67328 .36134 .66673 .35477 Mtetra
.678 .813 .948 r
.66673 .35477 .67328 .36134 .68704 .35587 .68056 .34939 Mtetra
.628 .8 .965 r
.68056 .34939 .68704 .35587 .70094 .35171 .69452 .34535 Mtetra
.378 .685 .979 r
.69452 .34535 .70094 .35171 .71525 .35336 .70883 .34614 Mtetra
0 .326 .798 r
.70883 .34614 .71525 .35336 .73035 .36517 .72377 .35496 Mtetra
0 .318 .807 r
.72377 .35496 .73035 .36517 .74577 .37841 .739 .3653 Mtetra
.612 .634 .849 r
.739 .3653 .74577 .37841 .76019 .37487 .75348 .36212 Mtetra
.834 .732 .752 r
.75348 .36212 .76019 .37487 .77341 .35495 .76693 .34447 Mtetra
.862 .774 .763 r
.76693 .34447 .77341 .35495 .78659 .33539 .7803 .32631 Mtetra
.798 .791 .846 r
.7803 .32631 .78659 .33539 .8004 .32377 .7942 .315 Mtetra
.706 .772 .903 r
.7942 .315 .8004 .32377 .81469 .31717 .80855 .30837 Mtetra
.664 .755 .918 r
.80855 .30837 .81469 .31717 .82918 .31213 .82309 .30327 Mtetra
.646 .749 .924 r
.17784 .50656 .18596 .51364 .19753 .51009 .18945 .50296 Mtetra
.59 .732 .942 r
.18945 .50296 .19753 .51009 .20902 .508 .20097 .50071 Mtetra
.333 .619 .955 r
.20097 .50071 .20902 .508 .22016 .5104 .21218 .50247 Mtetra
0 .247 .736 r
.21218 .50247 .22016 .5104 .23082 .51935 .22297 .50986 Mtetra
0 .341 .82 r
.22297 .50986 .23082 .51935 .24166 .52774 .23395 .51662 Mtetra
.673 .669 .838 r
.23395 .51662 .24166 .52774 .25378 .52212 .24604 .51161 Mtetra
.817 .716 .755 r
.24604 .51161 .25378 .52212 .26695 .50349 .25904 .49572 Mtetra
.837 .762 .781 r
.25904 .49572 .26695 .50349 .27996 .48638 .27196 .48062 Mtetra
.787 .814 .874 r
.27196 .48062 .27996 .48638 .29237 .47709 .2844 .47162 Mtetra
.692 .816 .941 r
.2844 .47162 .29237 .47709 .3045 .47241 .2966 .46646 Mtetra
.649 .793 .951 r
.2966 .46646 .3045 .47241 .3166 .46887 .30877 .46248 Mtetra
.644 .779 .946 r
.30877 .46248 .3166 .46887 .32876 .46527 .32098 .45867 Mtetra
.646 .775 .942 r
.32098 .45867 .32876 .46527 .34099 .46152 .33325 .45481 Mtetra
.651 .773 .938 r
.33325 .45481 .34099 .46152 .35329 .45759 .34559 .45082 Mtetra
.65 .772 .938 r
.34559 .45082 .35329 .45759 .36567 .45317 .35798 .44683 Mtetra
.643 .785 .95 r
.35798 .44683 .36567 .45317 .37814 .44785 .37042 .44297 Mtetra
.634 .83 .976 r
.37042 .44297 .37814 .44785 .39069 .44179 .38293 .43899 Mtetra
.61 .889 .989 r
.38293 .43899 .39069 .44179 .4033 .4355 .39552 .43462 Mtetra
.564 .919 .956 r
.39552 .43462 .4033 .4355 .41593 .4295 .40818 .42972 Mtetra
.528 .918 .91 r
.40818 .42972 .41593 .4295 .42859 .42402 .42091 .42438 Mtetra
.524 .918 .902 r
.42091 .42438 .42859 .42402 .44129 .41901 .43369 .41892 Mtetra
.531 .917 .921 r
.43369 .41892 .44129 .41901 .45404 .41434 .44652 .4137 Mtetra
.527 .91 .94 r
.44652 .4137 .45404 .41434 .46684 .4099 .45939 .40892 Mtetra
.508 .897 .949 r
.45939 .40892 .46684 .4099 .47969 .40564 .47231 .40461 Mtetra
.475 .882 .946 r
.47231 .40461 .47969 .40564 .4926 .40154 .48529 .4007 Mtetra
.434 .864 .93 r
.48529 .4007 .4926 .40154 .50558 .39755 .49833 .39708 Mtetra
.384 .842 .901 r
.49833 .39708 .50558 .39755 .51862 .39364 .51143 .39367 Mtetra
.325 .81 .857 r
.51143 .39367 .51862 .39364 .53172 .3898 .52461 .39041 Mtetra
.271 .777 .803 r
.52461 .39041 .53172 .3898 .54489 .38628 .53786 .38716 Mtetra
.273 .777 .786 r
.53786 .38716 .54489 .38628 .55815 .38347 .55118 .38359 Mtetra
.353 .828 .857 r
.55118 .38359 .55815 .38347 .57148 .38134 .56457 .37984 Mtetra
.466 .873 .954 r
.56457 .37984 .57148 .38134 .58491 .37914 .57804 .37612 Mtetra
.56 .879 .992 r
.57804 .37612 .58491 .37914 .59838 .3757 .59157 .37213 Mtetra
.643 .893 .985 r
.59157 .37213 .59838 .3757 .6119 .37087 .60514 .36689 Mtetra
.7 .897 .968 r
.60514 .36689 .6119 .37087 .62547 .36615 .61873 .36044 Mtetra
.693 .842 .955 r
.61873 .36044 .62547 .36615 .63917 .36271 .63239 .35457 Mtetra
.64 .752 .93 r
.63239 .35457 .63917 .36271 .65294 .35942 .64618 .35046 Mtetra
.625 .725 .919 r
.64618 .35046 .65294 .35942 .66673 .35477 .66007 .34686 Mtetra
.646 .763 .934 r
.66007 .34686 .66673 .35477 .68056 .34939 .67399 .34252 Mtetra
.615 .784 .962 r
.67399 .34252 .68056 .34939 .69452 .34535 .68802 .33884 Mtetra
.409 .699 .981 r
.68802 .33884 .69452 .34535 .70883 .34614 .70236 .33915 Mtetra
.02 .432 .866 r
.70236 .33915 .70883 .34614 .72377 .35496 .71719 .34573 Mtetra
.105 .424 .869 r
.71719 .34573 .72377 .35496 .739 .3653 .73226 .35309 Mtetra
.629 .661 .862 r
.73226 .35309 .739 .3653 .75348 .36212 .74671 .3492 Mtetra
.817 .726 .764 r
.74671 .3492 .75348 .36212 .76693 .34447 .76035 .33321 Mtetra
.84 .758 .773 r
.76035 .33321 .76693 .34447 .7803 .32631 .77392 .31666 Mtetra
.783 .777 .847 r
.77392 .31666 .7803 .32631 .7942 .315 .78794 .30598 Mtetra
.702 .766 .902 r
.78794 .30598 .7942 .315 .80855 .30837 .80234 .29945 Mtetra
.664 .754 .918 r
.80234 .29945 .80855 .30837 .82309 .30327 .81694 .29432 Mtetra
.648 .749 .923 r
.16966 .49941 .17784 .50656 .18945 .50296 .1813 .49574 Mtetra
.601 .735 .939 r
.1813 .49574 .18945 .50296 .20097 .50071 .19287 .49323 Mtetra
.406 .65 .957 r
.19287 .49323 .20097 .50071 .21218 .50247 .20418 .49412 Mtetra
0 .383 .842 r
.20418 .49412 .21218 .50247 .22297 .50986 .21511 .49989 Mtetra
.112 .412 .861 r
.21511 .49989 .22297 .50986 .23395 .51662 .22618 .50555 Mtetra
.643 .66 .852 r
.22618 .50555 .23395 .51662 .24604 .51161 .23818 .50178 Mtetra
.802 .726 .78 r
.23818 .50178 .24604 .51161 .25904 .49572 .25102 .48849 Mtetra
.83 .775 .801 r
.25102 .48849 .25904 .49572 .27196 .48062 .26388 .4749 Mtetra
.786 .817 .877 r
.26388 .4749 .27196 .48062 .2844 .47162 .27637 .46592 Mtetra
.706 .813 .932 r
.27637 .46592 .2844 .47162 .2966 .46646 .28864 .46031 Mtetra
.664 .792 .943 r
.28864 .46031 .2966 .46646 .30877 .46248 .30087 .45595 Mtetra
.654 .779 .94 r
.30087 .45595 .30877 .46248 .32098 .45867 .31313 .45186 Mtetra
.651 .771 .937 r
.31313 .45186 .32098 .45867 .33325 .45481 .32545 .44785 Mtetra
.648 .767 .936 r
.32545 .44785 .33325 .45481 .34559 .45082 .33782 .4439 Mtetra
.65 .77 .936 r
.33782 .4439 .34559 .45082 .35798 .44683 .35025 .43986 Mtetra
.657 .771 .933 r
.35025 .43986 .35798 .44683 .37042 .44297 .36275 .43562 Mtetra
.66 .762 .926 r
.36275 .43562 .37042 .44297 .38293 .43899 .37531 .43129 Mtetra
.657 .753 .92 r
.37531 .43129 .38293 .43899 .39552 .43462 .38793 .42703 Mtetra
.656 .756 .924 r
.38793 .42703 .39552 .43462 .40818 .42972 .4006 .4228 Mtetra
.651 .775 .939 r
.4006 .4228 .40818 .42972 .42091 .42438 .41333 .41864 Mtetra
.635 .808 .966 r
.41333 .41864 .42091 .42438 .43369 .41892 .42612 .41468 Mtetra
.61 .85 .989 r
.42612 .41468 .43369 .41892 .44652 .4137 .43896 .41078 Mtetra
.58 .881 .992 r
.43896 .41078 .44652 .4137 .45939 .40892 .45187 .40675 Mtetra
.562 .896 .983 r
.45187 .40675 .45939 .40892 .47231 .40461 .46486 .40251 Mtetra
.575 .903 .981 r
.46486 .40251 .47231 .40461 .48529 .4007 .4779 .39798 Mtetra
.621 .904 .985 r
.4779 .39798 .48529 .4007 .49833 .39708 .49102 .39302 Mtetra
.669 .878 .977 r
.49102 .39302 .49833 .39708 .51143 .39367 .50419 .38764 Mtetra
.688 .822 .947 r
.50419 .38764 .51143 .39367 .52461 .39041 .51742 .38214 Mtetra
.676 .755 .91 r
.51742 .38214 .52461 .39041 .53786 .38716 .53071 .37702 Mtetra
.652 .701 .883 r
.53071 .37702 .53786 .38716 .55118 .38359 .54406 .37265 Mtetra
.64 .68 .872 r
.54406 .37265 .55118 .38359 .56457 .37984 .55747 .36862 Mtetra
.628 .67 .871 r
.55747 .36862 .56457 .37984 .57804 .37612 .57097 .36501 Mtetra
.606 .663 .879 r
.57097 .36501 .57804 .37612 .59157 .37213 .58455 .36218 Mtetra
.605 .69 .903 r
.58455 .36218 .59157 .37213 .60514 .36689 .59821 .35931 Mtetra
.662 .776 .934 r
.59821 .35931 .60514 .36689 .61873 .36044 .61191 .3545 Mtetra
.711 .842 .945 r
.61191 .3545 .61873 .36044 .63239 .35457 .62561 .34805 Mtetra
.684 .818 .947 r
.62561 .34805 .63239 .35457 .64618 .35046 .6394 .34246 Mtetra
.63 .756 .937 r
.6394 .34246 .64618 .35046 .66007 .34686 .65332 .33856 Mtetra
.618 .743 .936 r
.65332 .33856 .66007 .34686 .67399 .34252 .66733 .33503 Mtetra
.591 .757 .958 r
.66733 .33503 .67399 .34252 .68802 .33884 .68145 .33204 Mtetra
.424 .7 .979 r
.68145 .33204 .68802 .33884 .70236 .33915 .69583 .3322 Mtetra
.129 .514 .912 r
.69583 .3322 .70236 .33915 .71719 .34573 .7106 .33706 Mtetra
.241 .533 .921 r
.7106 .33706 .71719 .34573 .73226 .35309 .72551 .34155 Mtetra
.663 .691 .866 r
.72551 .34155 .73226 .35309 .74671 .3492 .73991 .33627 Mtetra
.806 .723 .774 r
.73991 .33627 .74671 .3492 .76035 .33321 .75369 .32141 Mtetra
.818 .745 .784 r
.75369 .32141 .76035 .33321 .77392 .31666 .76745 .30655 Mtetra
.764 .762 .851 r
.76745 .30655 .77392 .31666 .78794 .30598 .7816 .29674 Mtetra
.695 .759 .901 r
.7816 .29674 .78794 .30598 .80234 .29945 .79608 .29042 Mtetra
.663 .753 .917 r
.79608 .29042 .80234 .29945 .81694 .29432 .81074 .28529 Mtetra
.65 .749 .922 r
.16141 .49219 .16966 .49941 .1813 .49574 .17308 .48844 Mtetra
.615 .738 .934 r
.17308 .48844 .1813 .49574 .19287 .49323 .18471 .48558 Mtetra
.475 .678 .954 r
.18471 .48558 .19287 .49323 .20418 .49412 .19613 .48548 Mtetra
.172 .49 .903 r
.19613 .48548 .20418 .49412 .21511 .49989 .20722 .48962 Mtetra
.189 .453 .878 r
.20722 .48962 .21511 .49989 .22618 .50555 .21835 .49451 Mtetra
.596 .644 .868 r
.21835 .49451 .22618 .50555 .23818 .50178 .23023 .4923 Mtetra
.779 .73 .807 r
.23023 .4923 .23818 .50178 .25102 .48849 .2429 .48152 Mtetra
.82 .783 .818 r
.2429 .48152 .25102 .48849 .26388 .4749 .25572 .46915 Mtetra
.787 .817 .877 r
.25572 .46915 .26388 .4749 .27637 .46592 .26826 .46009 Mtetra
.719 .813 .923 r
.26826 .46009 .27637 .46592 .28864 .46031 .28061 .45402 Mtetra
.675 .792 .937 r
.28061 .45402 .28864 .46031 .30087 .45595 .2929 .44929 Mtetra
.66 .779 .937 r
.2929 .44929 .30087 .45595 .31313 .45186 .30521 .44501 Mtetra
.656 .773 .935 r
.30521 .44501 .31313 .45186 .32545 .44785 .31757 .44083 Mtetra
.656 .769 .933 r
.31757 .44083 .32545 .44785 .33782 .4439 .32999 .43662 Mtetra
.654 .763 .929 r
.32999 .43662 .33782 .4439 .35025 .43986 .34247 .43246 Mtetra
.651 .759 .928 r
.34247 .43246 .35025 .43986 .36275 .43562 .35499 .42838 Mtetra
.651 .765 .932 r
.35499 .42838 .36275 .43562 .37531 .43129 .36758 .42426 Mtetra
.66 .774 .934 r
.36758 .42426 .37531 .43129 .38793 .42703 .38024 .41986 Mtetra
.667 .773 .929 r
.38024 .41986 .38793 .42703 .4006 .4228 .39297 .41525 Mtetra
.659 .761 .926 r
.39297 .41525 .4006 .4228 .41333 .41864 .40575 .41087 Mtetra
.654 .755 .924 r
.40575 .41087 .41333 .41864 .42612 .41468 .41858 .4066 Mtetra
.665 .751 .914 r
.41858 .4066 .42612 .41468 .43896 .41078 .43148 .40198 Mtetra
.673 .735 .897 r
.43148 .40198 .43896 .41078 .45187 .40675 .44445 .39704 Mtetra
.67 .714 .881 r
.44445 .39704 .45187 .40675 .46486 .40251 .45748 .39208 Mtetra
.671 .699 .868 r
.45748 .39208 .46486 .40251 .4779 .39798 .47057 .38697 Mtetra
.676 .69 .856 r
.47057 .38697 .4779 .39798 .49102 .39302 .48372 .38154 Mtetra
.674 .681 .848 r
.48372 .38154 .49102 .39302 .50419 .38764 .49692 .37607 Mtetra
.663 .675 .852 r
.49692 .37607 .50419 .38764 .51742 .38214 .51018 .37107 Mtetra
.651 .681 .866 r
.51018 .37107 .51742 .38214 .53071 .37702 .5235 .36661 Mtetra
.644 .693 .881 r
.5235 .36661 .53071 .37702 .54406 .37265 .53688 .36246 Mtetra
.634 .695 .889 r
.53688 .36246 .54406 .37265 .55747 .36862 .55033 .35866 Mtetra
.635 .702 .894 r
.55033 .35866 .55747 .36862 .57097 .36501 .56386 .35479 Mtetra
.622 .692 .894 r
.56386 .35479 .57097 .36501 .58455 .36218 .57747 .35136 Mtetra
.587 .663 .891 r
.57747 .35136 .58455 .36218 .59821 .35931 .59117 .34907 Mtetra
.598 .683 .901 r
.59117 .34907 .59821 .35931 .61191 .3545 .60496 .34635 Mtetra
.669 .766 .923 r
.60496 .34635 .61191 .3545 .62561 .34805 .61876 .34126 Mtetra
.698 .816 .938 r
.61876 .34126 .62561 .34805 .6394 .34246 .63259 .33518 Mtetra
.651 .787 .947 r
.63259 .33518 .6394 .34246 .65332 .33856 .64653 .33056 Mtetra
.605 .749 .946 r
.64653 .33056 .65332 .33856 .66733 .33503 .6606 .32729 Mtetra
.564 .74 .959 r
.6606 .32729 .66733 .33503 .68145 .33204 .67481 .32497 Mtetra
.425 .693 .976 r
.67481 .32497 .68145 .33204 .69583 .3322 .68923 .32519 Mtetra
.225 .578 .943 r
.68923 .32519 .69583 .3322 .7106 .33706 .70396 .3286 Mtetra
.384 .629 .95 r
.70396 .3286 .7106 .33706 .72551 .34155 .71874 .3303 Mtetra
.702 .715 .859 r
.71874 .3303 .72551 .34155 .73991 .33627 .73307 .32331 Mtetra
.797 .721 .781 r
.73307 .32331 .73991 .33627 .75369 .32141 .74696 .30926 Mtetra
.795 .734 .796 r
.74696 .30926 .75369 .32141 .76745 .30655 .7609 .29611 Mtetra
.743 .75 .858 r
.7609 .29611 .76745 .30655 .7816 .29674 .77519 .2873 Mtetra
.686 .753 .903 r
.77519 .2873 .7816 .29674 .79608 .29042 .78976 .28128 Mtetra
.661 .752 .917 r
.78976 .28128 .79608 .29042 .81074 .28529 .80447 .27615 Mtetra
.652 .75 .922 r
.15309 .48491 .16141 .49219 .17308 .48844 .16479 .48106 Mtetra
.628 .742 .929 r
.16479 .48106 .17308 .48844 .18471 .48558 .17649 .47785 Mtetra
.535 .701 .947 r
.17649 .47785 .18471 .48558 .19613 .48548 .18803 .4767 Mtetra
.317 .57 .93 r
.18803 .4767 .19613 .48548 .20722 .48962 .19928 .4792 Mtetra
.248 .486 .888 r
.19928 .4792 .20722 .48962 .21835 .49451 .21047 .48337 Mtetra
.536 .617 .88 r
.21047 .48337 .21835 .49451 .23023 .4923 .22221 .4828 Mtetra
.744 .725 .834 r
.22221 .4828 .23023 .4923 .2429 .48152 .23471 .47455 Mtetra
.807 .786 .833 r
.23471 .47455 .2429 .48152 .25572 .46915 .24747 .46338 Mtetra
.788 .818 .876 r
.24747 .46338 .25572 .46915 .26826 .46009 .26008 .4542 Mtetra
.731 .814 .916 r
.26008 .4542 .26826 .46009 .28061 .45402 .2725 .44766 Mtetra
.687 .795 .932 r
.2725 .44766 .28061 .45402 .2929 .44929 .28486 .44257 Mtetra
.668 .781 .934 r
.28486 .44257 .2929 .44929 .30521 .44501 .29723 .43802 Mtetra
.66 .772 .932 r
.29723 .43802 .30521 .44501 .31757 .44083 .30963 .43369 Mtetra
.655 .767 .932 r
.30963 .43369 .31757 .44083 .32999 .43662 .32209 .4295 Mtetra
.656 .769 .932 r
.32209 .4295 .32999 .43662 .34247 .43246 .3346 .42523 Mtetra
.661 .769 .929 r
.3346 .42523 .34247 .43246 .35499 .42838 .34718 .42082 Mtetra
.663 .761 .923 r
.34718 .42082 .35499 .42838 .36758 .42426 .35983 .41634 Mtetra
.663 .752 .916 r
.35983 .41634 .36758 .42426 .38024 .41986 .37253 .41183 Mtetra
.654 .747 .918 r
.37253 .41183 .38024 .41986 .39297 .41525 .38528 .40758 Mtetra
.644 .755 .93 r
.38528 .40758 .39297 .41525 .40575 .41087 .39808 .40359 Mtetra
.662 .773 .932 r
.39808 .40359 .40575 .41087 .41858 .4066 .41096 .39904 Mtetra
.684 .772 .918 r
.41096 .39904 .41858 .4066 .43148 .40198 .42392 .39377 Mtetra
.673 .752 .91 r
.42392 .39377 .43148 .40198 .44445 .39704 .43693 .38881 Mtetra
.655 .747 .918 r
.43693 .38881 .44445 .39704 .45748 .39208 .44998 .38443 Mtetra
.666 .768 .926 r
.44998 .38443 .45748 .39208 .47057 .38697 .46311 .37968 Mtetra
.692 .787 .923 r
.46311 .37968 .47057 .38697 .48372 .38154 .47631 .37405 Mtetra
.695 .783 .919 r
.47631 .37405 .48372 .38154 .49692 .37607 .48956 .36828 Mtetra
.673 .769 .923 r
.48956 .36828 .49692 .37607 .51018 .37107 .50286 .36324 Mtetra
.66 .765 .928 r
.50286 .36324 .51018 .37107 .5235 .36661 .51622 .35858 Mtetra
.661 .761 .924 r
.51622 .35858 .5235 .36661 .53688 .36246 .52965 .35388 Mtetra
.649 .743 .918 r
.52965 .35388 .53688 .36246 .55033 .35866 .54314 .34953 Mtetra
.64 .727 .911 r
.54314 .34953 .55033 .35866 .56386 .35479 .5567 .34546 Mtetra
.63 .718 .911 r
.5567 .34546 .56386 .35479 .57747 .35136 .57034 .3417 Mtetra
.587 .693 .915 r
.57034 .3417 .57747 .35136 .59117 .34907 .58408 .33923 Mtetra
.571 .683 .916 r
.58408 .33923 .59117 .34907 .60496 .34635 .59792 .33722 Mtetra
.632 .728 .917 r
.59792 .33722 .60496 .34635 .61876 .34126 .6118 .33332 Mtetra
.682 .779 .924 r
.6118 .33332 .61876 .34126 .63259 .33518 .6257 .32774 Mtetra
.658 .787 .943 r
.6257 .32774 .63259 .33518 .64653 .33056 .63969 .3229 Mtetra
.6 .759 .955 r
.63969 .3229 .64653 .33056 .6606 .32729 .65381 .31964 Mtetra
.54 .734 .965 r
.65381 .31964 .6606 .32729 .67481 .32497 .66809 .31779 Mtetra
.42 .689 .975 r
.66809 .31779 .67481 .32497 .68923 .32519 .68257 .31809 Mtetra
.318 .635 .964 r
.68257 .31809 .68923 .32519 .70396 .3286 .69726 .32006 Mtetra
.518 .7 .953 r
.69726 .32006 .70396 .3286 .71874 .3303 .71191 .31894 Mtetra
.735 .727 .844 r
.71191 .31894 .71874 .3303 .73307 .32331 .72618 .31019 Mtetra
.786 .717 .786 r
.72618 .31019 .73307 .32331 .74696 .30926 .74017 .29695 Mtetra
.77 .724 .81 r
.74017 .29695 .74696 .30926 .7609 .29611 .7543 .28553 Mtetra
.721 .741 .867 r
.7543 .28553 .7609 .29611 .77519 .2873 .76873 .27777 Mtetra
.676 .749 .905 r
.76873 .27777 .77519 .2873 .78976 .28128 .78338 .27204 Mtetra
.659 .751 .918 r
.78338 .27204 .78976 .28128 .80447 .27615 .79815 .26694 Mtetra
.653 .75 .921 r
.14469 .47757 .15309 .48491 .16479 .48106 .15644 .47364 Mtetra
.639 .745 .926 r
.15644 .47364 .16479 .48106 .17649 .47785 .16819 .47009 Mtetra
.581 .719 .938 r
.16819 .47009 .17649 .47785 .18803 .4767 .17985 .46797 Mtetra
.432 .631 .938 r
.17985 .46797 .18803 .4767 .19928 .4792 .19128 .4688 Mtetra
.313 .524 .9 r
.19128 .4688 .19928 .4792 .21047 .48337 .20256 .47203 Mtetra
.472 .584 .885 r
.20256 .47203 .21047 .48337 .22221 .4828 .21417 .4729 Mtetra
.689 .705 .859 r
.21417 .4729 .22221 .4828 .23471 .47455 .22646 .46731 Mtetra
.785 .781 .849 r
.22646 .46731 .23471 .47455 .24747 .46338 .23915 .45756 Mtetra
.788 .818 .876 r
.23915 .45756 .24747 .46338 .26008 .4542 .25181 .44835 Mtetra
.743 .818 .91 r
.25181 .44835 .26008 .4542 .2725 .44766 .26432 .4413 Mtetra
.698 .798 .927 r
.26432 .4413 .2725 .44766 .28486 .44257 .27674 .4358 Mtetra
.674 .783 .931 r
.27674 .4358 .28486 .44257 .29723 .43802 .28916 .43104 Mtetra
.665 .775 .932 r
.28916 .43104 .29723 .43802 .30963 .43369 .30162 .42654 Mtetra
.662 .771 .93 r
.30162 .42654 .30963 .43369 .32209 .4295 .31412 .42208 Mtetra
.659 .763 .927 r
.31412 .42208 .32209 .4295 .3346 .42523 .32668 .41771 Mtetra
.655 .761 .927 r
.32668 .41771 .3346 .42523 .34718 .42082 .33929 .41343 Mtetra
.658 .766 .93 r
.33929 .41343 .34718 .42082 .35983 .41634 .35197 .40905 Mtetra
.663 .771 .93 r
.35197 .40905 .35983 .41634 .37253 .41183 .36471 .40449 Mtetra
.66 .77 .931 r
.36471 .40449 .37253 .41183 .38528 .40758 .3775 .40001 Mtetra
.663 .765 .926 r
.3775 .40001 .38528 .40758 .39808 .40359 .39037 .39541 Mtetra
.684 .757 .906 r
.39037 .39541 .39808 .40359 .41096 .39904 .40331 .39007 Mtetra
.681 .737 .893 r
.40331 .39007 .41096 .39904 .42392 .39377 .41632 .38476 Mtetra
.641 .723 .908 r
.41632 .38476 .42392 .39377 .43693 .38881 .42933 .3808 Mtetra
.617 .742 .936 r
.42933 .3808 .43693 .38881 .44998 .38443 .4424 .37747 Mtetra
.664 .789 .941 r
.4424 .37747 .44998 .38443 .46311 .37968 .45557 .37271 Mtetra
.71 .802 .922 r
.45557 .37271 .46311 .37968 .47631 .37405 .46883 .36643 Mtetra
.688 .78 .921 r
.46883 .36643 .47631 .37405 .48956 .36828 .48212 .36087 Mtetra
.593 .754 .955 r
.48212 .36087 .48956 .36828 .50286 .36324 .49545 .35796 Mtetra
.534 .8 .995 r
.49545 .35796 .50286 .36324 .51622 .35858 .50886 .35552 Mtetra
.666 .914 .977 r
.50886 .35552 .51622 .35858 .52965 .35388 .52235 .34953 Mtetra
.705 .887 .964 r
.52235 .34953 .52965 .35388 .54314 .34953 .5359 .34305 Mtetra
.68 .816 .948 r
.5359 .34305 .54314 .34953 .5567 .34546 .5495 .33759 Mtetra
.648 .767 .935 r
.5495 .33759 .5567 .34546 .57034 .3417 .56318 .33315 Mtetra
.59 .726 .938 r
.56318 .33315 .57034 .3417 .58408 .33923 .57695 .3304 Mtetra
.561 .707 .938 r
.57695 .3304 .58408 .33923 .59792 .33722 .59083 .32841 Mtetra
.615 .732 .929 r
.59083 .32841 .59792 .33722 .6118 .33332 .60476 .32494 Mtetra
.666 .764 .923 r
.60476 .32494 .6118 .33332 .6257 .32774 .61873 .31984 Mtetra
.649 .772 .938 r
.61873 .31984 .6257 .32774 .63969 .3229 .63278 .31523 Mtetra
.59 .757 .958 r
.63278 .31523 .63969 .3229 .65381 .31964 .64696 .31219 Mtetra
.517 .732 .971 r
.64696 .31219 .65381 .31964 .66809 .31779 .6613 .31069 Mtetra
.421 .695 .977 r
.6613 .31069 .66809 .31779 .68257 .31809 .67583 .31085 Mtetra
.421 .692 .976 r
.67583 .31085 .68257 .31809 .69726 .32006 .69048 .31108 Mtetra
.629 .742 .928 r
.69048 .31108 .69726 .32006 .71191 .31894 .705 .30702 Mtetra
.755 .726 .826 r
.705 .30702 .71191 .31894 .72618 .31019 .71923 .29683 Mtetra
.771 .709 .794 r
.71923 .29683 .72618 .31019 .74017 .29695 .73335 .28468 Mtetra
.744 .717 .827 r
.73335 .28468 .74017 .29695 .7543 .28553 .74765 .27501 Mtetra
.7 .736 .879 r
.74765 .27501 .7543 .28553 .76873 .27777 .76221 .2682 Mtetra
.668 .747 .909 r
.76221 .2682 .76873 .27777 .78338 .27204 .77693 .26274 Mtetra
.658 .75 .918 r
.77693 .26274 .78338 .27204 .79815 .26694 .79176 .25763 Mtetra
.655 .751 .921 r
.13623 .47017 .14469 .47757 .15644 .47364 .14801 .46618 Mtetra
.647 .748 .923 r
.14801 .46618 .15644 .47364 .16819 .47009 .15982 .46237 Mtetra
.615 .733 .93 r
.15982 .46237 .16819 .47009 .17985 .46797 .17159 .45942 Mtetra
.521 .677 .936 r
.17159 .45942 .17985 .46797 .19128 .4688 .18319 .45863 Mtetra
.393 .575 .911 r
.18319 .45863 .19128 .4688 .20256 .47203 .19461 .46051 Mtetra
.427 .56 .885 r
.19461 .46051 .20256 .47203 .21417 .4729 .20613 .46227 Mtetra
.613 .665 .876 r
.20613 .46227 .21417 .4729 .22646 .46731 .21819 .4594 Mtetra
.747 .764 .866 r
.21819 .4594 .22646 .46731 .23915 .45756 .23075 .45158 Mtetra
.783 .816 .879 r
.23075 .45158 .23915 .45756 .25181 .44835 .24345 .44259 Mtetra
.754 .823 .906 r
.24345 .44259 .25181 .44835 .26432 .4413 .25604 .43506 Mtetra
.712 .806 .924 r
.25604 .43506 .26432 .4413 .27674 .4358 .26854 .42908 Mtetra
.684 .788 .929 r
.26854 .42908 .27674 .4358 .28916 .43104 .28103 .42398 Mtetra
.669 .776 .93 r
.28103 .42398 .28916 .43104 .30162 .42654 .29353 .41929 Mtetra
.661 .77 .93 r
.29353 .41929 .30162 .42654 .31412 .42208 .30607 .41484 Mtetra
.662 .771 .931 r
.30607 .41484 .31412 .42208 .32668 .41771 .31867 .41035 Mtetra
.664 .769 .928 r
.31867 .41035 .32668 .41771 .33929 .41343 .33134 .40576 Mtetra
.665 .762 .922 r
.33134 .40576 .33929 .41343 .35197 .40905 .34406 .40113 Mtetra
.662 .756 .919 r
.34406 .40113 .35197 .40905 .36471 .40449 .35684 .39656 Mtetra
.656 .755 .922 r
.35684 .39656 .36471 .40449 .3775 .40001 .36967 .39216 Mtetra
.662 .76 .922 r
.36967 .39216 .3775 .40001 .39037 .39541 .38257 .38755 Mtetra
.677 .765 .917 r
.38257 .38755 .39037 .39541 .40331 .39007 .39555 .38244 Mtetra
.664 .768 .928 r
.39555 .38244 .40331 .39007 .41632 .38476 .40857 .37774 Mtetra
.616 .772 .955 r
.40857 .37774 .41632 .38476 .42933 .3808 .42162 .37426 Mtetra
.621 .789 .962 r
.42162 .37426 .42933 .3808 .4424 .37747 .43474 .37055 Mtetra
.701 .802 .928 r
.43474 .37055 .4424 .37747 .45557 .37271 .44798 .36459 Mtetra
.751 .782 .878 r
.44798 .36459 .45557 .37271 .46883 .36643 .46132 .35634 Mtetra
.705 .725 .866 r
.46132 .35634 .46883 .36643 .48212 .36087 .47467 .34972 Mtetra
.436 .582 .9 r
.47467 .34972 .48212 .36087 .49545 .35796 .48798 .35129 Mtetra
.172 .561 .933 r
.48798 .35129 .49545 .35796 .50886 .35552 .50138 .35464 Mtetra
.629 .949 .941 r
.50138 .35464 .50886 .35552 .52235 .34953 .51496 .34795 Mtetra
.758 .967 .929 r
.51496 .34795 .52235 .34953 .5359 .34305 .52858 .33885 Mtetra
.729 .899 .955 r
.52858 .33885 .5359 .34305 .5495 .33759 .54224 .33153 Mtetra
.657 .826 .964 r
.54224 .33153 .5495 .33759 .56318 .33315 .55597 .32656 Mtetra
.585 .785 .975 r
.55597 .32656 .56318 .33315 .57695 .3304 .56979 .32342 Mtetra
.574 .769 .971 r
.56979 .32342 .57695 .3304 .59083 .32841 .5837 .3206 Mtetra
.629 .767 .946 r
.5837 .3206 .59083 .32841 .60476 .32494 .59766 .31657 Mtetra
.657 .763 .928 r
.59766 .31657 .60476 .32494 .61873 .31984 .61169 .31173 Mtetra
.631 .762 .941 r
.61169 .31173 .61873 .31984 .63278 .31523 .62581 .30763 Mtetra
.571 .753 .964 r
.62581 .30763 .63278 .31523 .64696 .31219 .64006 .30497 Mtetra
.498 .732 .977 r
.64006 .30497 .64696 .31219 .6613 .31069 .65446 .30371 Mtetra
.448 .716 .981 r
.65446 .30371 .6613 .31069 .67583 .31085 .66901 .30326 Mtetra
.544 .745 .969 r
.66901 .30326 .67583 .31085 .69048 .31108 .68358 .30112 Mtetra
.705 .749 .886 r
.68358 .30112 .69048 .31108 .705 .30702 .698 .2942 Mtetra
.758 .713 .81 r
.698 .2942 .705 .30702 .71923 .29683 .71223 .28334 Mtetra
.749 .7 .805 r
.71223 .28334 .71923 .29683 .73335 .28468 .72649 .27272 Mtetra
.716 .714 .846 r
.72649 .27272 .73335 .28468 .74765 .27501 .74097 .26469 Mtetra
.681 .735 .891 r
.74097 .26469 .74765 .27501 .76221 .2682 .75563 .25865 Mtetra
.662 .747 .913 r
.75563 .25865 .76221 .2682 .77693 .26274 .77043 .25336 Mtetra
.657 .751 .919 r
.77043 .25336 .77693 .26274 .79176 .25763 .78532 .24824 Mtetra
.656 .751 .92 r
.12769 .46272 .13623 .47017 .14801 .46618 .1395 .45866 Mtetra
.652 .75 .921 r
.1395 .45866 .14801 .46618 .15982 .46237 .15136 .45469 Mtetra
.636 .742 .925 r
.15136 .45469 .15982 .46237 .17159 .45942 .16322 .45114 Mtetra
.584 .71 .93 r
.16322 .45114 .17159 .45942 .18319 .45863 .17499 .44893 Mtetra
.482 .632 .919 r
.17499 .44893 .18319 .45863 .19461 .46051 .18659 .44909 Mtetra
.427 .564 .889 r
.18659 .44909 .19461 .46051 .20613 .46227 .19813 .45075 Mtetra
.528 .611 .879 r
.19813 .45075 .20613 .46227 .21819 .4594 .20996 .45026 Mtetra
.682 .723 .881 r
.20996 .45026 .21819 .4594 .23075 .45158 .22232 .44506 Mtetra
.762 .803 .886 r
.22232 .44506 .23075 .45158 .24345 .44259 .23498 .43694 Mtetra
.762 .828 .903 r
.23498 .43694 .24345 .44259 .25604 .43506 .24766 .42903 Mtetra
.727 .816 .92 r
.24766 .42903 .25604 .43506 .26854 .42908 .26025 .42249 Mtetra
.694 .796 .928 r
.26025 .42249 .26854 .42908 .28103 .42398 .2728 .41702 Mtetra
.676 .783 .93 r
.2728 .41702 .28103 .42398 .29353 .41929 .28536 .41209 Mtetra
.67 .775 .928 r
.28536 .41209 .29353 .41929 .30607 .41484 .29796 .40732 Mtetra
.663 .765 .926 r
.29796 .40732 .30607 .41484 .31867 .41035 .3106 .40277 Mtetra
.659 .764 .927 r
.3106 .40277 .31867 .41035 .33134 .40576 .3233 .3983 Mtetra
.659 .768 .93 r
.3233 .3983 .33134 .40576 .34406 .40113 .33605 .39382 Mtetra
.665 .775 .931 r
.33605 .39382 .34406 .40113 .35684 .39656 .34887 .38912 Mtetra
.668 .773 .929 r
.34887 .38912 .35684 .39656 .36967 .39216 .36176 .38433 Mtetra
.675 .765 .919 r
.36176 .38433 .36967 .39216 .38257 .38755 .37472 .37928 Mtetra
.669 .753 .914 r
.37472 .37928 .38257 .38755 .39555 .38244 .38773 .37439 Mtetra
.653 .756 .925 r
.38773 .37439 .39555 .38244 .40857 .37774 .40078 .36997 Mtetra
.634 .758 .937 r
.40078 .36997 .40857 .37774 .42162 .37426 .41388 .36607 Mtetra
.663 .757 .92 r
.41388 .36607 .42162 .37426 .43474 .37055 .42707 .3613 Mtetra
.681 .737 .893 r
.42707 .3613 .43474 .37055 .44798 .36459 .44034 .35581 Mtetra
.704 .756 .893 r
.44034 .35581 .44798 .36459 .46132 .35634 .45369 .3495 Mtetra
.698 .808 .933 r
.45369 .3495 .46132 .35634 .47467 .34972 .46708 .34356 Mtetra
.685 .826 .951 r
.46708 .34356 .47467 .34972 .48798 .35129 .48052 .33796 Mtetra
.8 .704 .758 r
.48052 .33796 .48798 .35129 .50138 .35464 .49411 .32274 Mtetra
.363 .314 .669 r
.49411 .32274 .50138 .35464 .51496 .34795 .50754 .33334 Mtetra
.586 .597 .83 r
.50754 .33334 .51496 .34795 .52858 .33885 .52118 .33102 Mtetra
.662 .776 .934 r
.52118 .33102 .52858 .33885 .54224 .33153 .5349 .32608 Mtetra
.598 .827 .987 r
.5349 .32608 .54224 .33153 .55597 .32656 .5487 .32226 Mtetra
.599 .864 .993 r
.5487 .32226 .55597 .32656 .56979 .32342 .56256 .31792 Mtetra
.626 .838 .981 r
.56256 .31792 .56979 .32342 .5837 .3206 .5765 .31343 Mtetra
.66 .799 .95 r
.5765 .31343 .5837 .3206 .59766 .31657 .5905 .3084 Mtetra
.645 .767 .937 r
.5905 .3084 .59766 .31657 .61169 .31173 .60459 .30387 Mtetra
.609 .763 .953 r
.60459 .30387 .61169 .31173 .62581 .30763 .61877 .30027 Mtetra
.544 .751 .972 r
.61877 .30027 .62581 .30763 .64006 .30497 .63309 .29806 Mtetra
.496 .744 .983 r
.63309 .29806 .64006 .30497 .65446 .30371 .64754 .29666 Mtetra
.525 .754 .98 r
.64754 .29666 .65446 .30371 .66901 .30326 .66207 .29469 Mtetra
.66 .768 .929 r
.66207 .29469 .66901 .30326 .68358 .30112 .67655 .28955 Mtetra
.738 .728 .843 r
.67655 .28955 .68358 .30112 .698 .2942 .6909 .28052 Mtetra
.744 .695 .805 r
.6909 .28052 .698 .2942 .71223 .28334 .7052 .27012 Mtetra
.721 .694 .824 r
.7052 .27012 .71223 .28334 .72649 .27272 .71963 .26135 Mtetra
.692 .717 .869 r
.71963 .26135 .72649 .27272 .74097 .26469 .73425 .25466 Mtetra
.668 .739 .903 r
.73425 .25466 .74097 .26469 .75563 .25865 .74901 .24912 Mtetra
.658 .749 .917 r
.74901 .24912 .75563 .25865 .77043 .25336 .76387 .24392 Mtetra
.656 .751 .92 r
.76387 .24392 .77043 .25336 .78532 .24824 .77881 .23877 Mtetra
.11908 .4552 .12769 .46272 .1395 .45866 .13092 .45111 Mtetra
.655 .751 .921 r
.13092 .45111 .1395 .45866 .15136 .45469 .14282 .44702 Mtetra
.648 .747 .922 r
.14282 .44702 .15136 .45469 .16322 .45114 .15475 .44311 Mtetra
.623 .731 .924 r
.15475 .44311 .16322 .45114 .17499 .44893 .16666 .43986 Mtetra
.56 .683 .921 r
.16666 .43986 .17499 .44893 .18659 .44909 .17846 .43824 Mtetra
.479 .604 .899 r
.17846 .43824 .18659 .44909 .19813 .45075 .19012 .43868 Mtetra
.477 .577 .876 r
.19012 .43868 .19813 .45075 .20996 .45026 .20183 .43943 Mtetra
.588 .655 .883 r
.20183 .43943 .20996 .45026 .22232 .44506 .21393 .43721 Mtetra
.71 .764 .894 r
.21393 .43721 .22232 .44506 .23498 .43694 .22645 .43107 Mtetra
.756 .823 .904 r
.22645 .43107 .23498 .43694 .24766 .42903 .23916 .42334 Mtetra
.742 .828 .918 r
.23916 .42334 .24766 .42903 .26025 .42249 .25185 .41622 Mtetra
.712 .81 .926 r
.25185 .41622 .26025 .42249 .2728 .41702 .26449 .41014 Mtetra
.685 .789 .929 r
.26449 .41014 .2728 .41702 .28536 .41209 .27711 .4049 Mtetra
.67 .777 .93 r
.27711 .4049 .28536 .41209 .29796 .40732 .28975 .4001 Mtetra
.668 .777 .931 r
.28975 .4001 .29796 .40732 .3106 .40277 .30244 .39535 Mtetra
.668 .773 .928 r
.30244 .39535 .3106 .40277 .3233 .3983 .31519 .39057 Mtetra
.665 .764 .924 r
.31519 .39057 .3233 .3983 .33605 .39382 .328 .38585 Mtetra
.662 .758 .922 r
.328 .38585 .33605 .39382 .34887 .38912 .34086 .38122 Mtetra
.664 .762 .923 r
.34086 .38122 .34887 .38912 .36176 .38433 .35378 .3765 Mtetra
.67 .766 .923 r
.35378 .3765 .36176 .38433 .37472 .37928 .36677 .37158 Mtetra
.658 .767 .93 r
.36677 .37158 .37472 .37928 .38773 .37439 .37981 .367 Mtetra
.633 .77 .945 r
.37981 .367 .38773 .37439 .40078 .36997 .39288 .36307 Mtetra
.639 .787 .953 r
.39288 .36307 .40078 .36997 .41388 .36607 .40603 .35891 Mtetra
.674 .791 .936 r
.40603 .35891 .41388 .36607 .42707 .3613 .41927 .35374 Mtetra
.673 .78 .93 r
.41927 .35374 .42707 .3613 .44034 .35581 .43258 .34859 Mtetra
.634 .779 .951 r
.43258 .34859 .44034 .35581 .45369 .3495 .44592 .34452 Mtetra
.61 .841 .987 r
.44592 .34452 .45369 .3495 .46708 .34356 .45933 .34044 Mtetra
.659 .911 .979 r
.45933 .34044 .46708 .34356 .48052 .33796 .47285 .33457 Mtetra
.651 .902 .982 r
.47285 .33457 .48052 .33796 .49411 .32274 .48641 .32894 Mtetra
.081 0 0 r
.48641 .32894 .49411 .32274 .50754 .33334 .50002 .32513 Mtetra
.605 .746 .944 r
.50002 .32513 .50754 .33334 .52118 .33102 .51371 .32183 Mtetra
.565 .703 .934 r
.51371 .32183 .52118 .33102 .5349 .32608 .52748 .3197 Mtetra
.552 .781 .984 r
.52748 .3197 .5349 .32608 .5487 .32226 .54133 .31709 Mtetra
.63 .85 .984 r
.54133 .31709 .5487 .32226 .56256 .31792 .55526 .3124 Mtetra
.684 .857 .965 r
.55526 .3124 .56256 .31792 .5765 .31343 .56924 .30641 Mtetra
.678 .811 .947 r
.56924 .30641 .5765 .31343 .5905 .3084 .58328 .30078 Mtetra
.633 .78 .952 r
.58328 .30078 .5905 .3084 .60459 .30387 .59743 .29648 Mtetra
.58 .767 .968 r
.59743 .29648 .60459 .30387 .61877 .30027 .61168 .29345 Mtetra
.533 .765 .983 r
.61168 .29345 .61877 .30027 .63309 .29806 .62606 .29123 Mtetra
.547 .772 .982 r
.62606 .29123 .63309 .29806 .64754 .29666 .64052 .28869 Mtetra
.643 .779 .946 r
.64052 .28869 .64754 .29666 .66207 .29469 .65499 .28403 Mtetra
.721 .741 .868 r
.65499 .28403 .66207 .29469 .67655 .28955 .66939 .27618 Mtetra
.734 .697 .816 r
.66939 .27618 .67655 .28955 .6909 .28052 .68375 .26659 Mtetra
.717 .682 .815 r
.68375 .26659 .6909 .28052 .7052 .27012 .69818 .25774 Mtetra
.694 .699 .851 r
.69818 .25774 .7052 .27012 .71963 .26135 .71277 .25068 Mtetra
.672 .727 .89 r
.71277 .25068 .71963 .26135 .73425 .25466 .72749 .24489 Mtetra
.66 .744 .912 r
.72749 .24489 .73425 .25466 .74901 .24912 .74233 .23959 Mtetra
.657 .75 .919 r
.74233 .23959 .74901 .24912 .76387 .24392 .75725 .2344 Mtetra
.656 .751 .92 r
.75725 .2344 .76387 .24392 .77881 .23877 .77224 .22921 Mtetra
.1104 .44762 .11908 .4552 .13092 .45111 .12227 .44349 Mtetra
.655 .751 .92 r
.12227 .44349 .13092 .45111 .14282 .44702 .1342 .43935 Mtetra
.654 .75 .921 r
.1342 .43935 .14282 .44702 .15475 .44311 .14618 .43524 Mtetra
.644 .744 .921 r
.14618 .43524 .15475 .44311 .16666 .43986 .15818 .43138 Mtetra
.614 .719 .92 r
.15818 .43138 .16666 .43986 .17846 .43824 .17015 .42835 Mtetra
.553 .662 .909 r
.17015 .42835 .17846 .43824 .19012 .43868 .18201 .42694 Mtetra
.496 .595 .882 r
.18201 .42694 .19012 .43868 .20183 .43943 .19379 .42715 Mtetra
.513 .593 .871 r
.19379 .42715 .20183 .43943 .21393 .43721 .20568 .42703 Mtetra
.615 .682 .89 r
.20568 .42703 .21393 .43721 .22645 .43107 .21794 .42397 Mtetra
.715 .787 .908 r
.21794 .42397 .22645 .43107 .23916 .42334 .23056 .41769 Mtetra
.746 .832 .917 r
.23056 .41769 .23916 .42334 .25185 .41622 .24331 .4104 Mtetra
.727 .826 .927 r
.24331 .4104 .25185 .41622 .26449 .41014 .25604 .40378 Mtetra
.703 .809 .931 r
.25604 .40378 .26449 .41014 .27711 .4049 .26875 .39794 Mtetra
.685 .789 .929 r
.26875 .39794 .27711 .4049 .28975 .4001 .28147 .39263 Mtetra
.67 .773 .927 r
.28147 .39263 .28975 .4001 .30244 .39535 .29421 .38778 Mtetra
.662 .769 .929 r
.29421 .38778 .30244 .39535 .31519 .39057 .30699 .38315 Mtetra
.661 .774 .933 r
.30699 .38315 .31519 .39057 .328 .38585 .31983 .37851 Mtetra
.663 .778 .934 r
.31983 .37851 .328 .38585 .34086 .38122 .33273 .37378 Mtetra
.67 .778 .93 r
.33273 .37378 .34086 .38122 .35378 .3765 .34571 .36884 Mtetra
.68 .775 .923 r
.34571 .36884 .35378 .3765 .36677 .37158 .35876 .36355 Mtetra
.671 .764 .92 r
.35876 .36355 .36677 .37158 .37981 .367 .37185 .35852 Mtetra
.64 .744 .924 r
.37185 .35852 .37981 .367 .39288 .36307 .38497 .35443 Mtetra
.626 .736 .926 r
.38497 .35443 .39288 .36307 .40603 .35891 .39814 .35073 Mtetra
.64 .754 .931 r
.39814 .35073 .40603 .35891 .41927 .35374 .41139 .34658 Mtetra
.633 .782 .953 r
.41139 .34658 .41927 .35374 .43258 .34859 .42471 .3425 Mtetra
.58 .797 .982 r
.42471 .3425 .43258 .34859 .44592 .34452 .43808 .33936 Mtetra
.565 .821 .994 r
.43808 .33936 .44592 .34452 .45933 .34044 .45152 .33616 Mtetra
.622 .869 .989 r
.45152 .33616 .45933 .34044 .47285 .33457 .46507 .3315 Mtetra
.633 .907 .983 r
.46507 .3315 .47285 .33457 .48641 .32894 .47871 .32602 Mtetra
.643 .915 .98 r
.47871 .32602 .48641 .32894 .50002 .32513 .4924 .32023 Mtetra
.615 .851 .988 r
.4924 .32023 .50002 .32513 .51371 .32183 .50615 .31582 Mtetra
.533 .786 .991 r
.50615 .31582 .51371 .32183 .52748 .3197 .51997 .3134 Mtetra
.549 .785 .986 r
.51997 .3134 .52748 .3197 .54133 .31709 .53388 .31075 Mtetra
.651 .823 .966 r
.53388 .31075 .54133 .31709 .55526 .3124 .54786 .3058 Mtetra
.701 .832 .945 r
.54786 .3058 .55526 .3124 .56924 .30641 .5619 .2994 Mtetra
.674 .813 .95 r
.5619 .2994 .56924 .30641 .58328 .30078 .576 .29383 Mtetra
.614 .795 .968 r
.576 .29383 .58328 .30078 .59743 .29648 .59021 .28984 Mtetra
.574 .79 .981 r
.59021 .28984 .59743 .29648 .61168 .29345 .60452 .28668 Mtetra
.587 .792 .978 r
.60452 .28668 .61168 .29345 .62606 .29123 .61891 .28322 Mtetra
.655 .784 .942 r
.61891 .28322 .62606 .29123 .64052 .28869 .63334 .27817 Mtetra
.712 .742 .875 r
.63334 .27817 .64052 .28869 .65499 .28403 .64774 .27077 Mtetra
.721 .694 .824 r
.64774 .27077 .65499 .28403 .66939 .27618 .66214 .26196 Mtetra
.708 .674 .815 r
.66214 .26196 .66939 .27618 .68375 .26659 .6766 .25356 Mtetra
.69 .686 .842 r
.6766 .25356 .68375 .26659 .69818 .25774 .69117 .24652 Mtetra
.673 .715 .881 r
.69117 .24652 .69818 .25774 .71277 .25068 .70588 .24062 Mtetra
.661 .738 .907 r
.70588 .24062 .71277 .25068 .72749 .24489 .72069 .23524 Mtetra
.657 .748 .917 r
.72069 .23524 .72749 .24489 .74233 .23959 .73558 .23001 Mtetra
.656 .751 .92 r
.73558 .23001 .74233 .23959 .75725 .2344 .75056 .2248 Mtetra
.75056 .2248 .75725 .2344 .77224 .22921 .76561 .21956 Mtetra
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Mtetra
.11354 .43581 .12227 .44349 .1342 .43935 .1255 .43162 Mtetra
.655 .751 .92 r
.1255 .43162 .1342 .43935 .14618 .43524 .13752 .42743 Mtetra
.653 .749 .92 r
.13752 .42743 .14618 .43524 .15818 .43138 .14958 .42329 Mtetra
.642 .74 .92 r
.14958 .42329 .15818 .43138 .17015 .42835 .16167 .41944 Mtetra
.613 .71 .915 r
.16167 .41944 .17015 .42835 .18201 .42694 .17372 .41641 Mtetra
.561 .652 .897 r
.17372 .41641 .18201 .42694 .19379 .42715 .18569 .41485 Mtetra
.517 .595 .871 r
.18569 .41485 .19379 .42715 .20568 .42703 .1976 .41458 Mtetra
.532 .6 .868 r
.1976 .41458 .20568 .42703 .21794 .42397 .20963 .41395 Mtetra
.615 .688 .896 r
.20963 .41395 .21794 .42397 .23056 .41769 .22199 .41082 Mtetra
.705 .794 .92 r
.22199 .41082 .23056 .41769 .24331 .4104 .23466 .40487 Mtetra
.736 .837 .927 r
.23466 .40487 .24331 .4104 .25604 .40378 .24747 .39789 Mtetra
.719 .826 .932 r
.24747 .39789 .25604 .40378 .26875 .39794 .26027 .39149 Mtetra
.695 .807 .935 r
.26027 .39149 .26875 .39794 .28147 .39263 .27306 .38585 Mtetra
.684 .797 .935 r
.27306 .38585 .28147 .39263 .29421 .38778 .28587 .38052 Mtetra
.676 .783 .93 r
.28587 .38052 .29421 .38778 .30699 .38315 .29872 .3754 Mtetra
.669 .769 .925 r
.29872 .3754 .30699 .38315 .31983 .37851 .31162 .37049 Mtetra
.661 .76 .924 r
.31162 .37049 .31983 .37851 .33273 .37378 .32456 .36581 Mtetra
.656 .761 .927 r
.32456 .36581 .33273 .37378 .34571 .36884 .33755 .36125 Mtetra
.665 .775 .932 r
.33755 .36125 .34571 .36884 .35876 .36355 .35062 .35639 Mtetra
.674 .791 .937 r
.35062 .35639 .35876 .36355 .37185 .35852 .36377 .35123 Mtetra
.662 .785 .94 r
.36377 .35123 .37185 .35852 .38497 .35443 .37696 .3464 Mtetra
.64 .759 .935 r
.37696 .3464 .38497 .35443 .39814 .35073 .39018 .34223 Mtetra
.627 .743 .93 r
.39018 .34223 .39814 .35073 .41139 .34658 .40346 .33841 Mtetra
.616 .749 .941 r
.40346 .33841 .41139 .34658 .42471 .3425 .4168 .33485 Mtetra
.596 .758 .956 r
.4168 .33485 .42471 .3425 .43808 .33936 .43021 .33168 Mtetra
.592 .757 .957 r
.43021 .33168 .43808 .33936 .45152 .33616 .4437 .32859 Mtetra
.616 .77 .954 r
.4437 .32859 .45152 .33616 .46507 .3315 .45728 .32487 Mtetra
.645 .808 .961 r
.45728 .32487 .46507 .3315 .47871 .32602 .47095 .32022 Mtetra
.646 .835 .973 r
.47095 .32022 .47871 .32602 .4924 .32023 .48469 .31535 Mtetra
.603 .85 .991 r
.48469 .31535 .4924 .32023 .50615 .31582 .4985 .31113 Mtetra
.533 .829 .999 r
.4985 .31113 .50615 .31582 .51997 .3134 .51238 .30808 Mtetra
.568 .825 .994 r
.51238 .30808 .51997 .3134 .53388 .31075 .52635 .30464 Mtetra
.665 .836 .965 r
.52635 .30464 .53388 .31075 .54786 .3058 .54038 .2992 Mtetra
.702 .834 .946 r
.54038 .2992 .54786 .3058 .5619 .2994 .55448 .29273 Mtetra
.672 .825 .957 r
.55448 .29273 .5619 .2994 .576 .29383 .56865 .28711 Mtetra
.634 .812 .968 r
.56865 .28711 .576 .29383 .59021 .28984 .5829 .28253 Mtetra
.643 .798 .957 r
.5829 .28253 .59021 .28984 .60452 .28668 .59723 .27778 Mtetra
.682 .77 .918 r
.59723 .27778 .60452 .28668 .61891 .28322 .6116 .27185 Mtetra
.706 .723 .863 r
.6116 .27185 .61891 .28322 .63334 .27817 .62599 .2645 Mtetra
.706 .682 .824 r
.62599 .2645 .63334 .27817 .64774 .27077 .64041 .25641 Mtetra
.694 .667 .819 r
.64041 .25641 .64774 .27077 .66214 .26196 .65489 .24874 Mtetra
.681 .68 .843 r
.65489 .24874 .66214 .26196 .6766 .25356 .66947 .24207 Mtetra
.669 .709 .878 r
.66947 .24207 .6766 .25356 .69117 .24652 .68416 .23625 Mtetra
.661 .734 .904 r
.68416 .23625 .69117 .24652 .70588 .24062 .69895 .23086 Mtetra
.657 .747 .916 r
.69895 .23086 .70588 .24062 .72069 .23524 .71382 .22561 Mtetra
.656 .75 .919 r
.71382 .22561 .72069 .23524 .73558 .23001 .72877 .22036 Mtetra
.656 .751 .92 r
.72877 .22036 .73558 .23001 .75056 .2248 .7438 .2151 Mtetra
.7438 .2151 .75056 .2248 .76561 .21956 .75891 .20981 Mtetra
.0928 .43227 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Mtetra
.11673 .42384 .1255 .43162 .13752 .42743 .12878 .41959 Mtetra
.655 .751 .92 r
.12878 .41959 .13752 .42743 .14958 .42329 .14088 .41535 Mtetra
.653 .748 .92 r
.14088 .41535 .14958 .42329 .16167 .41944 .15303 .41115 Mtetra
.643 .738 .918 r
.15303 .41115 .16167 .41944 .17372 .41641 .16521 .40722 Mtetra
.619 .708 .909 r
.16521 .40722 .17372 .41641 .18569 .41485 .17738 .40399 Mtetra
.577 .654 .889 r
.17738 .40399 .18569 .41485 .1976 .41458 .18948 .40195 Mtetra
.54 .602 .864 r
.18948 .40195 .1976 .41458 .20963 .41395 .20154 .40107 Mtetra
.54 .598 .861 r
.20154 .40107 .20963 .41395 .22199 .41082 .21369 .4002 Mtetra
.595 .67 .892 r
.21369 .4002 .22199 .41082 .23466 .40487 .22608 .39759 Mtetra
.678 .78 .928 r
.22608 .39759 .23466 .40487 .24747 .39789 .23876 .39247 Mtetra
.725 .842 .937 r
.23876 .39247 .24747 .39789 .26027 .39149 .25163 .38583 Mtetra
.721 .836 .936 r
.25163 .38583 .26027 .39149 .27306 .38585 .26454 .37929 Mtetra
.695 .807 .935 r
.26454 .37929 .27306 .38585 .28587 .38052 .27743 .37356 Mtetra
.676 .793 .937 r
.27743 .37356 .28587 .38052 .29872 .3754 .29032 .3684 Mtetra
.67 .792 .939 r
.29032 .3684 .29872 .3754 .31162 .37049 .30327 .3634 Mtetra
.671 .791 .938 r
.30327 .3634 .31162 .37049 .32456 .36581 .31627 .35836 Mtetra
.668 .781 .934 r
.31627 .35836 .32456 .36581 .33755 .36125 .32933 .35339 Mtetra
.665 .77 .928 r
.32933 .35339 .33755 .36125 .35062 .35639 .34244 .34849 Mtetra
.669 .771 .927 r
.34244 .34849 .35062 .35639 .36377 .35123 .35562 .34346 Mtetra
.67 .776 .929 r
.35562 .34346 .36377 .35123 .37696 .3464 .36887 .33834 Mtetra
.663 .767 .927 r
.36887 .33834 .37696 .3464 .39018 .34223 .38216 .33342 Mtetra
.649 .745 .919 r
.38216 .33342 .39018 .34223 .40346 .33841 .39551 .32893 Mtetra
.632 .723 .913 r
.39551 .32893 .40346 .33841 .4168 .33485 .4089 .32493 Mtetra
.613 .706 .911 r
.4089 .32493 .4168 .33485 .43021 .33168 .42235 .32152 Mtetra
.596 .694 .911 r
.42235 .32152 .43021 .33168 .4437 .32859 .43586 .3186 Mtetra
.592 .697 .916 r
.43586 .3186 .4437 .32859 .45728 .32487 .44945 .31574 Mtetra
.602 .725 .931 r
.44945 .31574 .45728 .32487 .47095 .32022 .46314 .31251 Mtetra
.61 .768 .955 r
.46314 .31251 .47095 .32022 .48469 .31535 .47692 .30886 Mtetra
.579 .793 .981 r
.47692 .30886 .48469 .31535 .4985 .31113 .49077 .30562 Mtetra
.559 .817 .994 r
.49077 .30562 .4985 .31113 .51238 .30808 .5047 .3024 Mtetra
.632 .84 .98 r
.5047 .3024 .51238 .30808 .52635 .30464 .51873 .29767 Mtetra
.708 .825 .938 r
.51873 .29767 .52635 .30464 .54038 .2992 .53282 .29099 Mtetra
.717 .795 .913 r
.53282 .29099 .54038 .2992 .55448 .29273 .54697 .28385 Mtetra
.695 .773 .911 r
.54697 .28385 .55448 .29273 .56865 .28711 .56118 .27747 Mtetra
.686 .752 .902 r
.56118 .27747 .56865 .28711 .5829 .28253 .57545 .27134 Mtetra
.692 .721 .871 r
.57545 .27134 .5829 .28253 .59723 .27778 .58978 .26468 Mtetra
.692 .685 .839 r
.58978 .26468 .59723 .27778 .6116 .27185 .60415 .25751 Mtetra
.686 .663 .822 r
.60415 .25751 .6116 .27185 .62599 .2645 .61858 .2503 Mtetra
.678 .663 .828 r
.61858 .2503 .62599 .2645 .64041 .25641 .63308 .24352 Mtetra
.671 .682 .853 r
.63308 .24352 .64041 .25641 .65489 .24874 .64767 .2374 Mtetra
.664 .711 .883 r
.64767 .2374 .65489 .24874 .66947 .24207 .66235 .2318 Mtetra
.659 .735 .905 r
.66235 .2318 .66947 .24207 .68416 .23625 .67712 .22644 Mtetra
.657 .746 .916 r
.67712 .22644 .68416 .23625 .69895 .23086 .69196 .22118 Mtetra
.656 .75 .919 r
.69196 .22118 .69895 .23086 .71382 .22561 .70689 .21591 Mtetra
.656 .751 .92 r
.70689 .21591 .71382 .22561 .72877 .22036 .7219 .21062 Mtetra
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19997 Mtetra
.08389 .42449 .0928 .43227 .10474 .42806 .09586 .42025 Mtetra
.09586 .42025 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Mtetra
.11996 .4117 .12878 .41959 .14088 .41535 .1321 .4074 Mtetra
.655 .751 .92 r
.1321 .4074 .14088 .41535 .15303 .41115 .14429 .40309 Mtetra
.653 .748 .919 r
.14429 .40309 .15303 .41115 .16521 .40722 .15654 .39882 Mtetra
.646 .738 .916 r
.15654 .39882 .16521 .40722 .17738 .40399 .16882 .39474 Mtetra
.629 .713 .907 r
.16882 .39474 .17738 .40399 .18948 .40195 .18111 .39115 Mtetra
.599 .667 .887 r
.18111 .39115 .18948 .40195 .20154 .40107 .19337 .38844 Mtetra
.566 .616 .862 r
.19337 .38844 .20154 .40107 .21369 .4002 .2056 .38673 Mtetra
.551 .595 .851 r
.2056 .38673 .21369 .4002 .22608 .39759 .21786 .38551 Mtetra
.572 .632 .872 r
.21786 .38551 .22608 .39759 .23876 .39247 .23027 .38359 Mtetra
.629 .728 .918 r
.23027 .38359 .23876 .39247 .25163 .38583 .24293 .37987 Mtetra
.69 .824 .947 r
.24293 .37987 .25163 .38583 .26454 .37929 .2558 .37428 Mtetra
.716 .857 .949 r
.2558 .37428 .26454 .37929 .27743 .37356 .2688 .36779 Mtetra
.711 .836 .942 r
.2688 .36779 .27743 .37356 .29032 .3684 .28183 .36149 Mtetra
.689 .801 .934 r
.28183 .36149 .29032 .3684 .30327 .3634 .29486 .35585 Mtetra
.671 .78 .931 r
.29486 .35585 .30327 .3634 .31627 .35836 .3079 .35077 Mtetra
.662 .777 .935 r
.3079 .35077 .31627 .35836 .32933 .35339 .32099 .34593 Mtetra
.658 .781 .939 r
.32099 .34593 .32933 .35339 .34244 .34849 .33414 .34118 Mtetra
.657 .786 .943 r
.33414 .34118 .34244 .34849 .35562 .34346 .34735 .33643 Mtetra
.659 .796 .948 r
.34735 .33643 .35562 .34346 .36887 .33834 .36063 .33157 Mtetra
.66 .805 .952 r
.36063 .33157 .36887 .33834 .38216 .33342 .37397 .32663 Mtetra
.658 .805 .953 r
.37397 .32663 .38216 .33342 .39551 .32893 .38738 .32173 Mtetra
.651 .792 .95 r
.38738 .32173 .39551 .32893 .4089 .32493 .40085 .31704 Mtetra
.64 .77 .942 r
.40085 .31704 .4089 .32493 .42235 .32152 .41437 .31268 Mtetra
.628 .742 .929 r
.41437 .31268 .42235 .32152 .43586 .3186 .42795 .30871 Mtetra
.616 .712 .914 r
.42795 .30871 .43586 .3186 .44945 .31574 .4416 .30511 Mtetra
.603 .69 .904 r
.4416 .30511 .44945 .31574 .46314 .31251 .45531 .30192 Mtetra
.587 .685 .909 r
.45531 .30192 .46314 .31251 .47692 .30886 .46911 .29918 Mtetra
.596 .712 .925 r
.46911 .29918 .47692 .30886 .49077 .30562 .48299 .29609 Mtetra
.644 .736 .916 r
.48299 .29609 .49077 .30562 .5047 .3024 .49698 .29151 Mtetra
.693 .724 .874 r
.49698 .29151 .5047 .3024 .51873 .29767 .51105 .28494 Mtetra
.703 .693 .838 r
.51105 .28494 .51873 .29767 .53282 .29099 .52518 .27734 Mtetra
.692 .674 .828 r
.52518 .27734 .53282 .29099 .54697 .28385 .53936 .27008 Mtetra
.679 .667 .832 r
.53936 .27008 .54697 .28385 .56118 .27747 .5536 .2634 Mtetra
.675 .662 .829 r
.5536 .2634 .56118 .27747 .57545 .27134 .5679 .25687 Mtetra
.671 .654 .825 r
.5679 .25687 .57545 .27134 .58978 .26468 .58226 .25041 Mtetra
.666 .656 .83 r
.58226 .25041 .58978 .26468 .60415 .25751 .59669 .24422 Mtetra
.664 .672 .848 r
.59669 .24422 .60415 .25751 .61858 .2503 .61119 .23832 Mtetra
.662 .697 .872 r
.61119 .23832 .61858 .2503 .63308 .24352 .62578 .2327 Mtetra
.66 .722 .895 r
.62578 .2327 .63308 .24352 .64767 .2374 .64044 .2273 Mtetra
.657 .739 .91 r
.64044 .2273 .64767 .2374 .66235 .2318 .65519 .222 Mtetra
.656 .747 .917 r
.65519 .222 .66235 .2318 .67712 .22644 .67001 .21673 Mtetra
.656 .75 .92 r
.67001 .21673 .67712 .22644 .69196 .22118 .68491 .21144 Mtetra
.656 .751 .92 r
.68491 .21144 .69196 .22118 .70689 .21591 .6999 .20613 Mtetra
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Mtetra
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19997 .74532 .19002 Mtetra
.0749 .41664 .08389 .42449 .09586 .42025 .0869 .41236 Mtetra
.0869 .41236 .09586 .42025 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Mtetra
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Mtetra
.12323 .3994 .1321 .4074 .14429 .40309 .13546 .39504 Mtetra
.655 .751 .92 r
.13546 .39504 .14429 .40309 .15654 .39882 .14775 .39067 Mtetra
.654 .749 .919 r
.14775 .39067 .15654 .39882 .16882 .39474 .16009 .38631 Mtetra
.65 .742 .916 r
.16009 .38631 .16882 .39474 .18111 .39115 .17248 .38205 Mtetra
.64 .723 .908 r
.17248 .38205 .18111 .39115 .19337 .38844 .18489 .37806 Mtetra
.621 .687 .891 r
.18489 .37806 .19337 .38844 .2056 .38673 .19732 .37463 Mtetra
.596 .642 .867 r
.19732 .37463 .2056 .38673 .21786 .38551 .20974 .37192 Mtetra
.575 .606 .846 r
.20974 .37192 .21786 .38551 .23027 .38359 .22216 .36988 Mtetra
.57 .602 .846 r
.22216 .36988 .23027 .38359 .24293 .37987 .23466 .36801 Mtetra
.587 .646 .876 r
.23466 .36801 .24293 .37987 .2558 .37428 .24728 .36555 Mtetra
.627 .735 .925 r
.24728 .36555 .2558 .37428 .2688 .36779 .26009 .36181 Mtetra
.668 .823 .958 r
.26009 .36181 .2688 .36779 .28183 .36149 .27307 .35673 Mtetra
.691 .864 .964 r
.27307 .35673 .28183 .36149 .29486 .35585 .28617 .35082 Mtetra
.697 .859 .959 r
.28617 .35082 .29486 .35585 .3079 .35077 .29934 .34475 Mtetra
.692 .831 .95 r
.29934 .34475 .3079 .35077 .32099 .34593 .31255 .33892 Mtetra
.68 .801 .94 r
.31255 .33892 .32099 .34593 .33414 .34118 .32578 .33344 Mtetra
.67 .78 .932 r
.32578 .33344 .33414 .34118 .34735 .33643 .33906 .32828 Mtetra
.662 .768 .928 r
.33906 .32828 .34735 .33643 .36063 .33157 .35238 .32334 Mtetra
.658 .766 .929 r
.35238 .32334 .36063 .33157 .37397 .32663 .36576 .3185 Mtetra
.656 .769 .932 r
.36576 .3185 .37397 .32663 .38738 .32173 .37921 .3137 Mtetra
.653 .771 .936 r
.37921 .3137 .38738 .32173 .40085 .31704 .39272 .30897 Mtetra
.646 .769 .938 r
.39272 .30897 .40085 .31704 .41437 .31268 .40629 .30441 Mtetra
.635 .761 .939 r
.40629 .30441 .41437 .31268 .42795 .30871 .41993 .30015 Mtetra
.621 .75 .939 r
.41993 .30015 .42795 .30871 .4416 .30511 .43362 .29628 Mtetra
.616 .742 .936 r
.43362 .29628 .4416 .30511 .45531 .30192 .44739 .29253 Mtetra
.636 .736 .921 r
.44739 .29253 .45531 .30192 .46911 .29918 .46125 .2882 Mtetra
.666 .712 .882 r
.46125 .2882 .46911 .29918 .48299 .29609 .47521 .2827 Mtetra
.684 .674 .834 r
.47521 .2827 .48299 .29609 .49698 .29151 .48925 .27594 Mtetra
.681 .641 .803 r
.48925 .27594 .49698 .29151 .51105 .28494 .50335 .26863 Mtetra
.67 .626 .797 r
.50335 .26863 .51105 .28494 .52518 .27734 .5175 .26176 Mtetra
.66 .632 .811 r
.5175 .26176 .52518 .27734 .53936 .27008 .5317 .2556 Mtetra
.657 .647 .829 r
.5317 .2556 .53936 .27008 .5536 .2634 .54597 .24983 Mtetra
.657 .663 .845 r
.54597 .24983 .5536 .2634 .5679 .25687 .56032 .24423 Mtetra
.656 .681 .861 r
.56032 .24423 .5679 .25687 .58226 .25041 .57473 .23879 Mtetra
.657 .702 .88 r
.57473 .23879 .58226 .25041 .59669 .24422 .58923 .23344 Mtetra
.658 .722 .896 r
.58923 .23344 .59669 .24422 .61119 .23832 .60379 .2281 Mtetra
.657 .736 .908 r
.60379 .2281 .61119 .23832 .62578 .2327 .61844 .22281 Mtetra
.656 .745 .915 r
.61844 .22281 .62578 .2327 .64044 .2273 .63316 .21754 Mtetra
.656 .749 .919 r
.63316 .21754 .64044 .2273 .65519 .222 .64796 .21226 Mtetra
.656 .751 .92 r
.64796 .21226 .65519 .222 .67001 .21673 .66284 .20695 Mtetra
.66284 .20695 .67001 .21673 .68491 .21144 .67779 .20161 Mtetra
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.656 .752 .92 r
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.656 .751 .92 r
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.656 .752 .92 r
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Mtetra
.656 .751 .92 r
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38694 Mtetra
.12655 .38694 .13546 .39504 .14775 .39067 .13887 .38251 Mtetra
.655 .751 .92 r
.13887 .38251 .14775 .39067 .16009 .38631 .15125 .37808 Mtetra
.655 .75 .92 r
.15125 .37808 .16009 .38631 .17248 .38205 .16369 .37363 Mtetra
.653 .746 .918 r
.16369 .37363 .17248 .38205 .18489 .37806 .17618 .36922 Mtetra
.649 .735 .912 r
.17618 .36922 .18489 .37806 .19732 .37463 .18872 .36491 Mtetra
.639 .711 .9 r
.18872 .36491 .19732 .37463 .20974 .37192 .2013 .36086 Mtetra
.624 .677 .88 r
.2013 .36086 .20974 .37192 .22216 .36988 .2139 .35722 Mtetra
.608 .64 .857 r
.2139 .35722 .22216 .36988 .23466 .36801 .22652 .35404 Mtetra
.595 .612 .839 r
.22652 .35404 .23466 .36801 .24728 .36555 .23918 .35125 Mtetra
.588 .604 .836 r
.23918 .35125 .24728 .36555 .26009 .36181 .2519 .34867 Mtetra
.594 .628 .855 r
.2519 .34867 .26009 .36181 .27307 .35673 .26471 .3459 Mtetra
.612 .683 .892 r
.26471 .3459 .27307 .35673 .28617 .35082 .27764 .34255 Mtetra
.635 .754 .934 r
.27764 .34255 .28617 .35082 .29934 .34475 .2907 .33844 Mtetra
.651 .815 .962 r
.2907 .33844 .29934 .34475 .31255 .33892 .30388 .33369 Mtetra
.658 .849 .973 r
.30388 .33369 .31255 .33892 .32578 .33344 .31715 .32854 Mtetra
.659 .86 .976 r
.31715 .32854 .32578 .33344 .33906 .32828 .33048 .32327 Mtetra
.657 .857 .976 r
.33048 .32327 .33906 .32828 .35238 .32334 .34388 .31803 Mtetra
.653 .849 .975 r
.34388 .31803 .35238 .32334 .36576 .3185 .35733 .31292 Mtetra
.648 .841 .974 r
.35733 .31292 .36576 .3185 .37921 .3137 .37084 .30796 Mtetra
.644 .836 .974 r
.37084 .30796 .37921 .3137 .39272 .30897 .38441 .3031 Mtetra
.644 .834 .973 r
.38441 .3031 .39272 .30897 .40629 .30441 .39805 .29823 Mtetra
.652 .829 .968 r
.39805 .29823 .40629 .30441 .41993 .30015 .41176 .2932 Mtetra
.67 .813 .952 r
.41176 .2932 .41993 .30015 .43362 .29628 .42555 .28776 Mtetra
.689 .777 .919 r
.42555 .28776 .43362 .29628 .44739 .29253 .43943 .28171 Mtetra
.694 .726 .874 r
.43943 .28171 .44739 .29253 .46125 .2882 .45338 .27509 Mtetra
.689 .681 .838 r
.45338 .27509 .46125 .2882 .47521 .2827 .46739 .26815 Mtetra
.676 .653 .82 r
.46739 .26815 .47521 .2827 .48925 .27594 .48146 .26143 Mtetra
.663 .649 .826 r
.48146 .26143 .48925 .27594 .50335 .26863 .49557 .25534 Mtetra
.656 .667 .849 r
.49557 .25534 .50335 .26863 .5175 .26176 .50975 .24983 Mtetra
.656 .693 .873 r
.50975 .24983 .5175 .26176 .5317 .2556 .52399 .24453 Mtetra
.657 .713 .889 r
.52399 .24453 .5317 .2556 .54597 .24983 .53831 .23926 Mtetra
.656 .725 .9 r
.53831 .23926 .54597 .24983 .56032 .24423 .5527 .23405 Mtetra
.655 .735 .908 r
.5527 .23405 .56032 .24423 .57473 .23879 .56717 .22886 Mtetra
.656 .743 .913 r
.56717 .22886 .57473 .23879 .58923 .23344 .58172 .22362 Mtetra
.656 .746 .916 r
.58172 .22362 .58923 .23344 .60379 .2281 .59633 .21835 Mtetra
.656 .749 .919 r
.59633 .21835 .60379 .2281 .61844 .22281 .61103 .21307 Mtetra
.656 .751 .92 r
.61103 .21307 .61844 .22281 .63316 .21754 .62581 .20777 Mtetra
.62581 .20777 .63316 .21754 .64796 .21226 .64066 .20243 Mtetra
.64066 .20243 .64796 .21226 .66284 .20695 .65559 .19708 Mtetra
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.656 .752 .92 r
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.656 .751 .92 r
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.656 .752 .92 r
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Mtetra
.656 .751 .92 r
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .3832 Mtetra
.656 .752 .92 r
.10527 .3832 .11429 .39133 .12655 .38694 .11756 .37875 Mtetra
.656 .751 .92 r
.11756 .37875 .12655 .38694 .13887 .38251 .12992 .3743 Mtetra
.656 .752 .92 r
.12992 .3743 .13887 .38251 .15125 .37808 .14233 .36981 Mtetra
.656 .751 .92 r
.14233 .36981 .15125 .37808 .16369 .37363 .1548 .36531 Mtetra
.1548 .36531 .16369 .37363 .17618 .36922 .16734 .36078 Mtetra
.655 .749 .919 r
.16734 .36078 .17618 .36922 .18872 .36491 .17993 .35627 Mtetra
.654 .744 .916 r
.17993 .35627 .18872 .36491 .2013 .36086 .19259 .35175 Mtetra
.65 .732 .909 r
.19259 .35175 .2013 .36086 .2139 .35722 .20529 .34731 Mtetra
.643 .712 .897 r
.20529 .34731 .2139 .35722 .22652 .35404 .21804 .34303 Mtetra
.634 .686 .881 r
.21804 .34303 .22652 .35404 .23918 .35125 .23084 .33898 Mtetra
.626 .658 .862 r
.23084 .33898 .23918 .35125 .2519 .34867 .24368 .3351 Mtetra
.618 .632 .843 r
.24368 .3351 .2519 .34867 .26471 .3459 .25658 .33137 Mtetra
.613 .615 .83 r
.25658 .33137 .26471 .3459 .27764 .34255 .26955 .32777 Mtetra
.611 .611 .827 r
.26955 .32777 .27764 .34255 .2907 .33844 .28258 .3242 Mtetra
.615 .622 .835 r
.28258 .3242 .2907 .33844 .30388 .33369 .29569 .32049 Mtetra
.624 .645 .851 r
.29569 .32049 .30388 .33369 .31715 .32854 .3089 .31653 Mtetra
.635 .672 .868 r
.3089 .31653 .31715 .32854 .33048 .32327 .3222 .31223 Mtetra
.646 .698 .883 r
.3222 .31223 .33048 .32327 .34388 .31803 .33559 .30761 Mtetra
.655 .715 .893 r
.33559 .30761 .34388 .31803 .35733 .31292 .34906 .30268 Mtetra
.662 .723 .894 r
.34906 .30268 .35733 .31292 .37084 .30796 .36262 .29749 Mtetra
.669 .721 .888 r
.36262 .29749 .37084 .30796 .38441 .3031 .37625 .29203 Mtetra
.673 .711 .876 r
.37625 .29203 .38441 .3031 .39805 .29823 .38996 .28629 Mtetra
.675 .695 .861 r
.38996 .28629 .39805 .29823 .41176 .2932 .40374 .28028 Mtetra
.674 .677 .845 r
.40374 .28028 .41176 .2932 .42555 .28776 .41759 .27408 Mtetra
.671 .664 .835 r
.41759 .27408 .42555 .28776 .43943 .28171 .43149 .26785 Mtetra
.667 .66 .834 r
.43149 .26785 .43943 .28171 .45338 .27509 .44546 .26176 Mtetra
.662 .668 .845 r
.44546 .26176 .45338 .27509 .46739 .26815 .45948 .25601 Mtetra
.658 .689 .868 r
.45948 .25601 .46739 .26815 .48146 .26143 .47356 .25059 Mtetra
.658 .717 .892 r
.47356 .25059 .48146 .26143 .49557 .25534 .48771 .24531 Mtetra
.659 .737 .907 r
.48771 .24531 .49557 .25534 .50975 .24983 .50192 .24002 Mtetra
.659 .744 .913 r
.50192 .24002 .50975 .24983 .52399 .24453 .51622 .23476 Mtetra
.655 .744 .916 r
.51622 .23476 .52399 .24453 .53831 .23926 .53058 .22958 Mtetra
.654 .748 .919 r
.53058 .22958 .53831 .23926 .5527 .23405 .54502 .22443 Mtetra
.656 .751 .92 r
.54502 .22443 .5527 .23405 .56717 .22886 .55954 .21918 Mtetra
.657 .751 .92 r
.55954 .21918 .56717 .22886 .58172 .22362 .57414 .21388 Mtetra
.656 .751 .92 r
.57414 .21388 .58172 .22362 .59633 .21835 .58881 .20858 Mtetra
.58881 .20858 .59633 .21835 .61103 .21307 .60356 .20326 Mtetra
.60356 .20326 .61103 .21307 .62581 .20777 .61838 .1979 Mtetra
.61838 .1979 .62581 .20777 .64066 .20243 .63329 .19252 Mtetra
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Mtetra
.656 .752 .92 r
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.656 .751 .92 r
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.656 .752 .92 r
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.656 .751 .92 r
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.656 .752 .92 r
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.656 .751 .92 r
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.656 .752 .92 r
.0839 .37944 .09304 .38761 .10527 .3832 .09617 .37498 Mtetra
.656 .751 .92 r
.09617 .37498 .10527 .3832 .11756 .37875 .10849 .3705 Mtetra
.656 .752 .92 r
.10849 .3705 .11756 .37875 .12992 .3743 .12088 .366 Mtetra
.656 .751 .92 r
.12088 .366 .12992 .3743 .14233 .36981 .13333 .36148 Mtetra
.656 .752 .92 r
.13333 .36148 .14233 .36981 .1548 .36531 .14584 .35693 Mtetra
.656 .751 .92 r
.14584 .35693 .1548 .36531 .16734 .36078 .15841 .35237 Mtetra
.15841 .35237 .16734 .36078 .17993 .35627 .17104 .34777 Mtetra
.655 .75 .92 r
.17104 .34777 .17993 .35627 .19259 .35175 .18373 .34317 Mtetra
.655 .749 .919 r
.18373 .34317 .19259 .35175 .20529 .34731 .19649 .33855 Mtetra
.655 .746 .917 r
.19649 .33855 .20529 .34731 .21804 .34303 .20931 .33391 Mtetra
.654 .738 .911 r
.20931 .33391 .21804 .34303 .23084 .33898 .22219 .32927 Mtetra
.649 .723 .902 r
.22219 .32927 .23084 .33898 .24368 .3351 .23512 .32473 Mtetra
.645 .707 .892 r
.23512 .32473 .24368 .3351 .25658 .33137 .24811 .32027 Mtetra
.642 .691 .881 r
.24811 .32027 .25658 .33137 .26955 .32777 .26116 .31586 Mtetra
.64 .675 .868 r
.26116 .31586 .26955 .32777 .28258 .3242 .27428 .31142 Mtetra
.638 .659 .854 r
.27428 .31142 .28258 .3242 .29569 .32049 .28747 .30694 Mtetra
.636 .645 .842 r
.28747 .30694 .29569 .32049 .3089 .31653 .30073 .30239 Mtetra
.636 .636 .834 r
.30073 .30239 .3089 .31653 .3222 .31223 .31407 .29776 Mtetra
.637 .633 .829 r
.31407 .29776 .3222 .31223 .33559 .30761 .32748 .293 Mtetra
.64 .632 .827 r
.32748 .293 .33559 .30761 .34906 .30268 .34097 .28811 Mtetra
.643 .635 .827 r
.34097 .28811 .34906 .30268 .36262 .29749 .35454 .28304 Mtetra
.646 .639 .829 r
.35454 .28304 .36262 .29749 .37625 .29203 .36817 .27785 Mtetra
.649 .646 .833 r
.36817 .27785 .37625 .29203 .38996 .28629 .38188 .27255 Mtetra
.651 .655 .84 r
.38188 .27255 .38996 .28629 .40374 .28028 .39566 .26722 Mtetra
.654 .668 .852 r
.39566 .26722 .40374 .28028 .41759 .27408 .40951 .26188 Mtetra
.656 .686 .867 r
.40951 .26188 .41759 .27408 .43149 .26785 .42342 .25659 Mtetra
.657 .706 .884 r
.42342 .25659 .43149 .26785 .44546 .26176 .4374 .25134 Mtetra
.659 .727 .9 r
.4374 .25134 .44546 .26176 .45948 .25601 .45145 .24608 Mtetra
.66 .74 .909 r
.45145 .24608 .45948 .25601 .47356 .25059 .46557 .24078 Mtetra
.659 .743 .913 r
.46557 .24078 .47356 .25059 .48771 .24531 .47976 .23551 Mtetra
.655 .744 .915 r
.47976 .23551 .48771 .24531 .50192 .24002 .49402 .23034 Mtetra
.653 .747 .919 r
.49402 .23034 .50192 .24002 .51622 .23476 .50836 .22523 Mtetra
.654 .753 .922 r
.50836 .22523 .51622 .23476 .53058 .22958 .52278 .22004 Mtetra
.657 .755 .922 r
.52278 .22004 .53058 .22958 .54502 .22443 .53727 .21472 Mtetra
.657 .752 .92 r
.53727 .21472 .54502 .22443 .55954 .21918 .55184 .20939 Mtetra
.656 .75 .92 r
.55184 .20939 .55954 .21918 .57414 .21388 .56648 .20407 Mtetra
.655 .751 .92 r
.56648 .20407 .57414 .21388 .58881 .20858 .58121 .19873 Mtetra
.656 .752 .92 r
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Mtetra
.656 .751 .92 r
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Mtetra
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .1825 Mtetra
.62585 .1825 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.656 .752 .92 r
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17154 Mtetra
.656 .751 .92 r
.65601 .17154 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.656 .752 .92 r
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16046 Mtetra
.656 .751 .92 r
.6865 .16046 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.656 .752 .92 r
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14926 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.656 .751 .92 r
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.656 .752 .92 r
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.656 .751 .92 r
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .3667 Mtetra
.656 .752 .92 r
.08698 .3667 .09617 .37498 .10849 .3705 .09934 .36217 Mtetra
.656 .751 .92 r
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35764 Mtetra
.656 .752 .92 r
.11176 .35764 .12088 .366 .13333 .36148 .12425 .35306 Mtetra
.656 .751 .92 r
.12425 .35306 .13333 .36148 .14584 .35693 .13679 .34849 Mtetra
.656 .752 .92 r
.13679 .34849 .14584 .35693 .15841 .35237 .14939 .34387 Mtetra
.655 .751 .92 r
.14939 .34387 .15841 .35237 .17104 .34777 .16206 .33925 Mtetra
.656 .752 .92 r
.16206 .33925 .17104 .34777 .18373 .34317 .17479 .33458 Mtetra
.656 .751 .92 r
.17479 .33458 .18373 .34317 .19649 .33855 .18758 .3299 Mtetra
.655 .75 .92 r
.18758 .3299 .19649 .33855 .20931 .33391 .20044 .32521 Mtetra
.20044 .32521 .20931 .33391 .22219 .32927 .21336 .32052 Mtetra
.656 .75 .919 r
.21336 .32052 .22219 .32927 .23512 .32473 .22634 .31576 Mtetra
.657 .746 .916 r
.22634 .31576 .23512 .32473 .24811 .32027 .2394 .31095 Mtetra
.656 .738 .91 r
.2394 .31095 .24811 .32027 .26116 .31586 .25252 .30614 Mtetra
.653 .729 .905 r
.25252 .30614 .26116 .31586 .27428 .31142 .26569 .30138 Mtetra
.651 .722 .9 r
.26569 .30138 .27428 .31142 .28747 .30694 .27894 .29664 Mtetra
.65 .717 .897 r
.27894 .29664 .28747 .30694 .30073 .30239 .29224 .2919 Mtetra
.65 .714 .894 r
.29224 .2919 .30073 .30239 .31407 .29776 .30562 .28711 Mtetra
.651 .711 .892 r
.30562 .28711 .31407 .29776 .32748 .293 .31907 .28227 Mtetra
.652 .711 .891 r
.31907 .28227 .32748 .293 .34097 .28811 .33259 .27735 Mtetra
.653 .712 .891 r
.33259 .27735 .34097 .28811 .35454 .28304 .34618 .27237 Mtetra
.655 .715 .893 r
.34618 .27237 .35454 .28304 .36817 .27785 .35985 .26733 Mtetra
.656 .72 .896 r
.35985 .26733 .36817 .27785 .38188 .27255 .37359 .26223 Mtetra
.657 .726 .9 r
.37359 .26223 .38188 .27255 .39566 .26722 .38739 .25708 Mtetra
.658 .732 .904 r
.38739 .25708 .39566 .26722 .40951 .26188 .40127 .25189 Mtetra
.658 .737 .908 r
.40127 .25189 .40951 .26188 .42342 .25659 .41522 .24669 Mtetra
.658 .74 .91 r
.41522 .24669 .42342 .25659 .4374 .25134 .42924 .24147 Mtetra
.656 .741 .912 r
.42924 .24147 .4374 .25134 .45145 .24608 .44333 .2363 Mtetra
.653 .743 .916 r
.44333 .2363 .45145 .24608 .46557 .24078 .45749 .23119 Mtetra
.653 .749 .92 r
.45749 .23119 .46557 .24078 .47976 .23551 .47173 .22608 Mtetra
.655 .755 .923 r
.47173 .22608 .47976 .23551 .49402 .23034 .48604 .22087 Mtetra
.658 .757 .923 r
.48604 .22087 .49402 .23034 .50836 .22523 .50043 .21554 Mtetra
.658 .752 .92 r
.50043 .21554 .50836 .22523 .52278 .22004 .5149 .21018 Mtetra
.655 .748 .918 r
.5149 .21018 .52278 .22004 .53727 .21472 .52944 .20487 Mtetra
.655 .75 .92 r
.52944 .20487 .53727 .21472 .55184 .20939 .54406 .19956 Mtetra
.656 .752 .921 r
.54406 .19956 .55184 .20939 .56648 .20407 .55875 .19419 Mtetra
.656 .752 .92 r
.55875 .19419 .56648 .20407 .58121 .19873 .57353 .18877 Mtetra
.656 .751 .92 r
.57353 .18877 .58121 .19873 .59601 .19335 .58838 .18334 Mtetra
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .1825 .61833 .17239 Mtetra
.656 .752 .92 r
.61833 .17239 .62585 .1825 .64089 .17704 .63343 .16687 Mtetra
.656 .751 .92 r
.63343 .16687 .64089 .17704 .65601 .17154 .6486 .16133 Mtetra
.656 .752 .92 r
.6486 .16133 .65601 .17154 .67121 .16602 .66386 .15574 Mtetra
.656 .751 .92 r
.66386 .15574 .67121 .16602 .6865 .16046 .6792 .15014 Mtetra
.656 .752 .92 r
.6792 .15014 .6865 .16046 .70187 .15488 .69463 .14449 Mtetra
.656 .751 .92 r
.69463 .14449 .70187 .15488 .71732 .14926 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.656 .752 .92 r
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36738 Mtetra
.656 .751 .92 r
.05311 .36738 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.656 .752 .92 r
.06538 .36287 .07468 .37119 .08698 .3667 .07772 .35833 Mtetra
.656 .751 .92 r
.07772 .35833 .08698 .3667 .09934 .36217 .09011 .35378 Mtetra
.656 .752 .92 r
.09011 .35378 .09934 .36217 .11176 .35764 .10256 .34918 Mtetra
.656 .751 .92 r
.10256 .34918 .11176 .35764 .12425 .35306 .11508 .34459 Mtetra
.656 .752 .92 r
.11508 .34459 .12425 .35306 .13679 .34849 .12766 .33995 Mtetra
.656 .751 .92 r
.12766 .33995 .13679 .34849 .14939 .34387 .1403 .33531 Mtetra
.656 .752 .92 r
.1403 .33531 .14939 .34387 .16206 .33925 .153 .33062 Mtetra
.655 .751 .92 r
.153 .33062 .16206 .33925 .17479 .33458 .16576 .32594 Mtetra
.656 .752 .92 r
.16576 .32594 .17479 .33458 .18758 .3299 .17859 .32121 Mtetra
.17859 .32121 .18758 .3299 .20044 .32521 .19149 .31646 Mtetra
.657 .752 .92 r
.19149 .31646 .20044 .32521 .21336 .32052 .20445 .31166 Mtetra
.655 .749 .919 r
.20445 .31166 .21336 .32052 .22634 .31576 .21747 .30689 Mtetra
.654 .75 .92 r
.21747 .30689 .22634 .31576 .2394 .31095 .23056 .30212 Mtetra
.654 .752 .922 r
.23056 .30212 .2394 .31095 .25252 .30614 .24371 .29733 Mtetra
.656 .754 .922 r
.24371 .29733 .25252 .30614 .26569 .30138 .25693 .29245 Mtetra
.657 .753 .92 r
.25693 .29245 .26569 .30138 .27894 .29664 .27022 .28752 Mtetra
.658 .749 .917 r
.27022 .28752 .27894 .29664 .29224 .2919 .28359 .28253 Mtetra
.657 .744 .914 r
.28359 .28253 .29224 .2919 .30562 .28711 .29702 .27754 Mtetra
.656 .74 .911 r
.29702 .27754 .30562 .28711 .31907 .28227 .31051 .27253 Mtetra
.655 .737 .91 r
.31051 .27253 .31907 .28227 .33259 .27735 .32408 .26753 Mtetra
.655 .736 .909 r
.32408 .26753 .33259 .27735 .34618 .27237 .33771 .26251 Mtetra
.33771 .26251 .34618 .27237 .35985 .26733 .35141 .25748 Mtetra
.655 .737 .91 r
.35141 .25748 .35985 .26733 .37359 .26223 .36518 .25242 Mtetra
.654 .739 .912 r
.36518 .25242 .37359 .26223 .38739 .25708 .37903 .24737 Mtetra
.654 .743 .915 r
.37903 .24737 .38739 .25708 .40127 .25189 .39294 .24229 Mtetra
.654 .747 .918 r
.39294 .24229 .40127 .25189 .41522 .24669 .40693 .23721 Mtetra
.654 .751 .921 r
.40693 .23721 .41522 .24669 .42924 .24147 .42099 .2321 Mtetra
.655 .755 .924 r
.42099 .2321 .42924 .24147 .44333 .2363 .43513 .22692 Mtetra
.658 .757 .923 r
.43513 .22692 .44333 .2363 .45749 .23119 .44934 .22163 Mtetra
.659 .754 .921 r
.44934 .22163 .45749 .23119 .47173 .22608 .46363 .21629 Mtetra
.657 .749 .918 r
.46363 .21629 .47173 .22608 .48604 .22087 .47799 .21095 Mtetra
.654 .746 .917 r
.47799 .21095 .48604 .22087 .50043 .21554 .49243 .20568 Mtetra
.654 .749 .92 r
.49243 .20568 .50043 .21554 .5149 .21018 .50694 .2004 Mtetra
.656 .753 .921 r
.50694 .2004 .5149 .21018 .52944 .20487 .52153 .19503 Mtetra
.52153 .19503 .52944 .20487 .54406 .19956 .5362 .18961 Mtetra
.656 .751 .92 r
.5362 .18961 .54406 .19956 .55875 .19419 .55095 .18418 Mtetra
.55095 .18418 .55875 .19419 .57353 .18877 .56578 .17873 Mtetra
.656 .752 .92 r
.56578 .17873 .57353 .18877 .58838 .18334 .58068 .17324 Mtetra
.656 .751 .92 r
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Mtetra
.656 .752 .92 r
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.656 .751 .92 r
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .15661 Mtetra
.656 .752 .92 r
.62589 .15661 .63343 .16687 .6486 .16133 .64112 .151 Mtetra
.656 .751 .92 r
.64112 .151 .6486 .16133 .66386 .15574 .65644 .14536 Mtetra
.656 .752 .92 r
.65644 .14536 .66386 .15574 .6792 .15014 .67184 .13969 Mtetra
.656 .751 .92 r
.67184 .13969 .6792 .15014 .69463 .14449 .68732 .134 Mtetra
.656 .752 .92 r
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12826 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36356 Mtetra
.656 .751 .92 r
.03145 .36356 .0409 .37188 .05311 .36738 .04369 .35903 Mtetra
.656 .752 .92 r
.04369 .35903 .05311 .36738 .06538 .36287 .056 .35447 Mtetra
.656 .751 .92 r
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.656 .752 .92 r
.06836 .3499 .07772 .35833 .09011 .35378 .08079 .34529 Mtetra
.656 .751 .92 r
.08079 .34529 .09011 .35378 .10256 .34918 .09328 .34067 Mtetra
.656 .752 .92 r
.09328 .34067 .10256 .34918 .11508 .34459 .10583 .33602 Mtetra
.656 .751 .92 r
.10583 .33602 .11508 .34459 .12766 .33995 .11844 .33135 Mtetra
.656 .752 .92 r
.11844 .33135 .12766 .33995 .1403 .33531 .13112 .32665 Mtetra
.656 .751 .92 r
.13112 .32665 .1403 .33531 .153 .33062 .14385 .32194 Mtetra
.656 .752 .92 r
.14385 .32194 .153 .33062 .16576 .32594 .15666 .31719 Mtetra
.656 .751 .92 r
.15666 .31719 .16576 .32594 .17859 .32121 .16952 .31243 Mtetra
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Mtetra
.655 .751 .921 r
.18245 .30764 .19149 .31646 .20445 .31166 .19545 .30286 Mtetra
.656 .753 .921 r
.19545 .30286 .20445 .31166 .21747 .30689 .20851 .29801 Mtetra
.657 .753 .92 r
.20851 .29801 .21747 .30689 .23056 .30212 .22164 .2931 Mtetra
.657 .75 .919 r
.22164 .2931 .23056 .30212 .24371 .29733 .23484 .28816 Mtetra
.655 .747 .917 r
.23484 .28816 .24371 .29733 .25693 .29245 .2481 .28326 Mtetra
.654 .747 .918 r
.2481 .28326 .25693 .29245 .27022 .28752 .26143 .27837 Mtetra
.653 .749 .92 r
.26143 .27837 .27022 .28752 .28359 .28253 .27482 .27348 Mtetra
.654 .753 .923 r
.27482 .27348 .28359 .28253 .29702 .27754 .28828 .26855 Mtetra
.654 .756 .924 r
.28828 .26855 .29702 .27754 .31051 .27253 .30181 .26358 Mtetra
.655 .758 .925 r
.30181 .26358 .31051 .27253 .32408 .26753 .31542 .25856 Mtetra
.656 .759 .926 r
.31542 .25856 .32408 .26753 .33771 .26251 .32909 .2535 Mtetra
.656 .76 .926 r
.32909 .2535 .33771 .26251 .35141 .25748 .34284 .2484 Mtetra
.656 .759 .926 r
.34284 .2484 .35141 .25748 .36518 .25242 .35666 .24327 Mtetra
.657 .759 .925 r
.35666 .24327 .36518 .25242 .37903 .24737 .37055 .23809 Mtetra
.657 .757 .923 r
.37055 .23809 .37903 .24737 .39294 .24229 .38452 .23288 Mtetra
.658 .755 .922 r
.38452 .23288 .39294 .24229 .40693 .23721 .39856 .22761 Mtetra
.658 .752 .919 r
.39856 .22761 .40693 .23721 .42099 .2321 .41267 .2223 Mtetra
.657 .747 .917 r
.41267 .2223 .42099 .2321 .43513 .22692 .42685 .217 Mtetra
.654 .745 .916 r
.42685 .217 .43513 .22692 .44934 .22163 .44111 .21176 Mtetra
.653 .747 .918 r
.44111 .21176 .44934 .22163 .46363 .21629 .45544 .20653 Mtetra
.654 .751 .921 r
.45544 .20653 .46363 .21629 .47799 .21095 .46985 .20125 Mtetra
.656 .755 .922 r
.46985 .20125 .47799 .21095 .49243 .20568 .48434 .19587 Mtetra
.657 .754 .921 r
.48434 .19587 .49243 .20568 .50694 .2004 .4989 .19044 Mtetra
.656 .751 .92 r
.4989 .19044 .50694 .2004 .52153 .19503 .51355 .18501 Mtetra
.655 .75 .92 r
.51355 .18501 .52153 .19503 .5362 .18961 .52827 .17957 Mtetra
.656 .751 .92 r
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Mtetra
.656 .752 .92 r
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16858 Mtetra
.656 .751 .92 r
.55795 .16858 .56578 .17873 .58068 .17324 .57291 .16303 Mtetra
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.656 .752 .92 r
.60307 .15186 .61074 .16218 .62589 .15661 .61828 .14623 Mtetra
.656 .751 .92 r
.61828 .14623 .62589 .15661 .64112 .151 .63356 .14057 Mtetra
.656 .752 .92 r
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13487 Mtetra
.656 .751 .92 r
.64894 .13487 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.656 .752 .92 r
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.656 .751 .92 r
.67994 .12339 .68732 .134 .70289 .12826 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?ooo`<0Yko[;@2W`>/00`000000Yl3[0:O0j`080:O0ja80oooo00<000000?ooo`3oool0
<P3oool004`0oooo1000001<0?ooo`H0Yko[;02W`>/00`000000Yl3[0:O0j`090:O0ja00oooo00<0
00000?ooo`000000<`3oool001d0oooo0P0000040?ooo`8000000`3oool4000001h0oooo0P00001=
0?ooo`@0Yl3[1P2W_n/[0:O0j`030000002W`>/0Yl3[00T0Yl3[4P3oool00`000000oooo0?ooo`0a
0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01`0oooo0`00001=
0?ooo`<0Z<7[102W`>/30:Nojbd0Yl3[00<000000:O0j`2W`>/02P2W`>/B0?ooo`030000003oool0
oooo0300oooo000L0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool06@3oool2
000004h0oooo1P2X`N/c0:O0j`030000002W`>/0Yl3[00/0Yl3[4P3oool00`000000oooo0?ooo`0_
0?ooo`005P3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0E
0?ooo`<00000C03oool50:O1k0D0Z<7[<`2W`>/00`000000Yl3[0:O0j`0;0:O0ja80oooo00<00000
0?ooo`3oool0;`3oool001`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
000C0?ooo`<00000C@3oool30:O0j`D0Yl7/1@2W_n/50:O0j`D0Yko[:02W`>/00`000000Yl3[0:O0
j`0<0:O0ja80oooo00<000000?ooo`3oool0;P3oool001d0oooo0P00000:0?ooo`8000004P3oool4
000004`0oooo1P2W`>/20:O1k0<0YkkZ1@2W_n/20:O0j`d0Yko[8P2W`>/00`000000Yl3[0:O0j`0=
0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?ooo`D0Yko[1@2W`>/60:Nn
jP`0Yko[0`2X`>/50:Nojb40Yl3[00<000000:O0j`2W`>/03@2W`>/B0?ooo`030000003oool0oooo
02d0oooo000h0?ooo`<00000BP3oool50:NnjPD0Yko[1@2X_n/50:NnjPD0Z<3[1@2W_n/60:S0j`@0
Yko[202W`>/30:Noj`H0Yl3[0`2W_n/50:O0j`D0Yko[102W`>/00`000000Yl3[0:O0j`0=0:O0ja40
oooo0P00000^0?ooo`00=@3oool3000004`0oooo0P2X_nX50:NnjP80Yko[0`2X`N/50:Roj`80YkkZ
0`2X`N`50:S0j`D0Z<7/2P2X`>/50:O0j`H0Yko[0`2W`>/60:Noj`80Yl3[0`2W_nX50:Noj`80Yl3[
00<0Yko[0000002W_n/03`2W`>/A0?ooo`030000003oool0oooo02`0oooo000c0?ooo`800000C@3o
ool50:RojP@0YkkZ1P2X`N/40:Roj`H0Z<7/0P2X`>/30:O0k0D0Z<7/1@2W`>/50:S0j`D0YkkZ1@2W
_n/40:NnjPD0Yko[1P2W_nX70:Noj`030000002W_n/0Yko[0080Yl3[0`2W_n/:0:O0ja40oooo00<0
00000?ooo`3oool0:`3oool00300oooo0`00001;0?ooo`D0Z<3[1@2X_nX40:S1k0D0Z<7[1@2W`N`5
0:S1k0H0Yl3/0P2X`N`30:Noj`D0Yl3[0P2X`>/30:Nnj@D0YkkZ1@2X_>P40:NnjPD0Z;gX1@2W_nX5
0:RnjP80Yko[00<000000:Noj`2W_n/01P2W_n/:0:O0ja40oooo00<000000?ooo`3oool0:P3oool0
02h0oooo0`00001;0?ooo`<0Z<7/1@2X`>/20:RojP<0Yl7/102X`N`50:Noj`D0Yl7/1@2W_n/50:O0
k0H0Yko[102W`>/60:Nnj@80YkkZ0`2X^>D40:Rlj080YkkZ0`2X^>D50:Rmj0D0Z;cW1@2X_^X00`2X
_nX000000:RojP020:RojPD0Yko[2P2W`>/A0?ooo`030000003oool0oooo02X0oooo000[0?ooo`<0
00000`3oool00`000000oooo0?ooo`160?ooo`H0Z<7/102X`>/60:O1k080Z<7/0P2W_^X50:Noj`D0
YkkZ1@2W_n/50:NnjPD0Yko[1@2W_>P50:Nnj@H0Z;SU0`2X_>P60:Rhi@80Z;gX0`2Y]^850:Rli`80
Z;kZ0`2Y^nL00`000000Z;oZ0:RojP070:RojPX0Yl3[4@3oool00`000000oooo0?ooo`0Y0?ooo`00
:@3oool2000004/0oooo2P2X`N`50:O0j`D0Yl7/1@2W_^X30:Noj`80Z;kY1@2W_^X20:Noj`<0Z;kY
1@2W_^X50:NiiPD0YkcX1@2X/n450:Rhi@@0ZK;O1@2X^>D60:VfhP@0Z;cW1@2Y^nL00`000000Z;oZ
0:RojP030:Vlj0D0Z;oZ0P2W`>/30:Roj`@0Yl3[4P3oool00`000000oooo0?ooo`0X0?ooo`009P3o
ool3000004X0oooo102X`^`50:S1k0D0Yko[1@2W`>/50:Nmj@D0YkkZ1@2X_^T40:NnjPH0Z;kY0P2W
_^X30:Rfh`D0YkWV0P2W_>P30:N^g0D0Z;?Q0P2X^>D30:V/f@@0ZK;O0P2X^>D30:^^fPD0ZKKR1@2[
]N040:Vki`030000002Y_>P0ZKcX00@0ZKcX102X_nX50:Roj`D0Yl3[4@3oool00`000000oooo0?oo
o`0X0?ooo`00903oool2000004/0oooo0`2W`^d40:S2k0<0Z<7/0P2W_^X50:Noj`D0Z;gX1@2W_NT5
0:Rmj0D0Z;kY102X_>P50:Rnj@H0Z;KS102W^NH60:N^g0@0Z;?Q1P2Y[=T30:Vbg`H0ZjkJ0P2Y]^83
0:j^e`D0ZkGP0P2/]n42000000030:bgh@2Y_>P0ZKcX00<0ZKcX1@2X_^T40:Roj`H0Yl3[403oool2
000002T0oooo000Q0?ooo`<00000B`3oool60:O2k@@0Z<;/1@2W_^X20:Noj`<0Z;cX1@2X_NP20:Nm
j@<0Z;[V1@2X_NP50:Rgi0@0Z;cX1@2W/Ml50:Rfh`D0Z:WH1@2W[]`50:ZWe0D0ZJcI102]ZM<50:^^
fPH0[ZkG0P2[]N00102`[mL000000000000000020:bgh@030000002/]n40[;[S00@0[;[S102X_^T5
0:RojPD0Yl3[4P3oool00`000000oooo0?ooo`0V0?ooo`007`3oool3000004T0oooo2P2W`^d50:Nm
j@@0YkkZ1P2X_>P40:Rmj0H0Z;[V0P2X_NP30:R`gPD0Z;OT0P2X_>P20:NZf@D0Yk7O0P2X]^<30:RU
e0D0Z:WH0P2W[]`30:^Wd`D0ZZOD0P2Y[=T30:nYdP@0[JWC0P2[[]X30;6Zd@D0[ZkG0`0000030;2_
e`80[;OQ00<000000;6bf@2a/]T0102/^^<20:Rnj@<0ZkgW1@2X_nX50:S0ja40oooo00<000000?oo
o`3oool09P3oool001d0oooo0P00001;0?ooo`L0Yl;]1@2W_>P50:Nmj@D0Z;_W102X_>P50:RdhPD0
Z;[V1P2X/=h40:Rgi0D0Yj[I102W/Ml50:RUe0D0Z:WH1@2[Ym<50:ZWe0D0[jWB102]ZM<60;6Zd@05
0:j^e`00000000000000002e[=001@2`[mL30;6bf@030000002a/]T0/K;I00<0[;[S1P2[_NL20:Ro
jP<0ZKoY1@2X`>/A0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`8000000`3oool40000
00X0oooo000E0?ooo`D000000`3oool2000004T0oooo1`2W`^d80:Nlj080YkgY0`2X^NH50:Rki`@0
YjoM1@2X]>850:V[f0D0Z;3N1@2YY]<50:NZf@@0Z:7?1@2XYM@20:RYf0<0[:WD1@2[Ym<20:ZWe0<0
/JoF1@2_ZM820:fYd`80]:kB0`2aZ]43000000@0]Jc@102`[mL20;N^d0<0/K;I00<000000;6bf@2a
]mh00`2a]mh50:^mi`H0ZKoY0P2X`>/30:Roja40oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0
oooo0`0000140?ooo`D0Yl;/102W`^d:0:Nlj0H0Z;WV0P2X^nL30:N[fP@0YjoM0`2X]>820:ZXe@D0
ZJ_H0P2X/=h30:fWd@D0ZJKC0P2WZ]T30:^Pc0<0Z:7?1@2XYM@50:bYe0D0ZjOC1@2a[mH50:nYdP@0
]:kB00@0/J[A000000000000/J[A0P2h/M850;F/d080/:oG0`2g[]040;6bf@030000002h/M80/KON
00<0/KON1@2^_>@50:Voj@H0Z;o[403oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00000o0?ooo`D0Yl7/1@2W`^`90:Nlj0D0YkSU1@2X^NH50:N[fPD0YjoM102ZZ=D5
0:V[f0D0[JOA1@2YY]<50:^Pc0@0Z:7?0P2XYM@30:fZe0D0[:WD0P2[Ym<30;6hgPD0/JoF0P2_ZM83
0;Big0040;B^dP000000000000000080/J[A0`2h/M850;F/d0H0]jk@0P2a/]T00`2h/M8000000;Ra
dP020;6ggP<0]kKH1@2^_>@50:^oj0D0Z;o[4@3oool00`000000oooo0?ooo`030?ooo`@000000P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00T0oooo000?0?ooo`@00000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3o
ool20:O0k0D0Yl7/2P2W_>P40:Ngi0D0YkSU1@2VYmL50:N[fP80YjoM0`2[ZMD40:ZXe@80ZJ_H0`2`
[]H50:fWd@80ZJKC0`2^Y<d50:^Pc0<0Z:7?1@2]Z]@50:bYe0D0/KSN1@2a[mH30;Big0<000000`2d
[]860;RadP80]Jc@0`2k/]050;N^d0@0^;7B00<000000;Nff02g]]P0102g]]P20:jli0<0/kcQ1@2[
_nP50:S0ja40oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000
003oool0oooo03P0oooo1@2W`>`30:O1k080YkgY1`2W_>P30:Nfi0@0YkOT0`2W^>D20:JUe@D0YZOG
102WZmX50:^Ye@@0ZZSE1@2`[]H50:fWd@D0[ZC=1@2[X<`20:RQc`80/JcC1@2]Z]@20:bYe0<0[l3V
1@2a^=h20;6_eP80[/G[0`0000020;Big080]:kB0`2f_Ml50;RadPH0^k;@0P2g[]030;jacP<0^;7B
00<0_k?>0000002g]]P0102g]]P60;>lh@80ZkoX0`2]_nL40:S0ja00oooo0P00000;0?ooo`800000
2P3oool2000000/0oooo000F0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03<0oooo1@2W_n/50:O0k0D0YkgY102W_>P60:Nfi0@0YkOT102VYMD50:JWe`D0[:gH1@2[
ZMD20:ZXe@80/KWO1@2`[]H20:fWd@<0[jcE1@2^Y<d40:^Pc0D0/JcC102]Z]@60:o0iP@0/KSN00@0
[/G[00000000000000000P2^aN/30;Big0H0][gO0P2h/M830;RmgPD0^k;@1P2n/Lh01@2h/M80_k?>
0;nccP2o/lh0000000<0]kKH0P2n]m<50;>lh@D0[KoW0P2X`>/30:W0jQ40oooo00<000000?ooo`3o
ool08@3oool001`0oooo00<000000?ooo`3oool01@3oool200000300oooo2@2W_n/50:Rnj@@0YkgY
1@2V]^@50:Nfi0D0YJ?D102VYMD20:JWe`<0[;7L1@2/[MP40:^Ye@@0/KWO1@2`[]H50:n/e@D0[ZC=
0P2[X<`30;>aeP@0/JcC1@2aaNT50:o0iP80Y<cd0`0000050:k5j`@0YlSa1@2f_Ml50;RmgP@0^k;@
0P2l^]L50;jacP@0_k?>00<000000;Nff02g]]P0102n]m<20;>lh@<0^;gM102]_nL60:W0jQ40oooo
00<000000?ooo`3oool0803oool001`0oooo0P0000080?ooo`030000003oool0oooo02T0oooo1@2W
_nX40:Noj`D0Z;oZ1@2X_^T90:Jfi0D0Y:;C102UXm@40:JUe@D0[;7L1@2/[MP50;36j`@0/KWO0P2`
[]H30:Zfh@D0[jcE102^Y<d60;>aeP80/JcC0P2gbnT50;75j@<0X/og0`0000040:C<m0D0U/[j102W
b?420;Jmg`<0Y<Ob1@2h_Mh20;^bd0<0_;[G102n/Lh20<:fc`@0_k?>00<000000;jgd`2n]m<00`2n
]m<50;Rmg@D0[l3W1@2Y`>XA0?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool09P3oool30:Roj`D0YkoZ0P2W_n/20:S0j`D0Z;oZ302V]^@2
0:>Qd`@0Y:;C1@2UXm@20:JUe@80[;KP1@2//M`20:b]f0<0Zm3c1@2`a^/30;6ig`D0Z[KQ1@2_[=D5
0;6ig`D0/k7F1@2gbnT20;75j@80[=?d0`0000030:;?m`D0T/[k1@2Fb_X30:O8l@H0Y<Ob102h_Mh6
0;bje`80_[7>0`32]/l30;nccP80aKG;00@000000;jgd`2n]m<0_[OC0P35^Ll30;Rmg@80_[oK1@2_
`>L50:W0jQ40oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0S0?ooo`H0Z;o[102W_nX50:S0j`<0Z;oZ0P2V]nD90:Jfi0D0Xj7C102TX]<4
0:FSe0D0[;KP102//M`60:_@l`@0/<K[1@2R_>/40:Zfh@80[jcE0`2T_>X50;6ig`80/k7F0`2edo04
0;O;j@040:cCm0000000000000000080[=?d1@2MboL509;:n`D0R<?k0`2<aO/50:C7lPD0Z<C]1@2l
^]L50<:fc`80_k?>1035]L/00`000000_[OC0<Fic`030<Fic`030;Rmg@2n_m/0_[oK0080_[oK0P2_
`>L30;72iPD0ZL3Z4@3oool00`000000oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<00000
0?ooo`3oool07`3oool50:S0j`@0Z;o[1@2W`N`50:S0j`D0Y[OU102V]^@50:>Re0D0Xj7C0`2TX]<5
0:^hh`D0[;KP102Ve?L50:_@l`D0WKg_1@2R_>/30:Zfh@H0Y;cZ102a^Ml60;GCl080/mGb0P000000
0`2ceO80[=3c0:c@l`030:c@l`D0WL_g1@2Da?L408S3n`@0S<Gk1@26`OX50:S4k@80_;[G0`2d_n84
0<:fc`H0aKG;00<000000<Fic`35^Ll00`35^Ll50;jof`H0/L;V0P2Y`>X30:W1ja00oooo00<00000
0?ooo`3oool07P3oool001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?oo
o`D0Yl3[1@2X`>/50:O0k0@0Yl7/1@2V^>H50:Jgi@@0XZ;E102SX]@50:>Qd`@0ZKWT1@2[^><50:CE
n@@0Y]Cg1@2N_o0509fmk`D0UZoX0`2H]^`50:BljPD0XMOj0`2edo00102Ze_L00000000000000002
0;?ElP80/mCa1@2/d?<50:;7l`D0U<Cg102;`?P407jnn`D0Q/7j102Xa>d50;BohP<0`[K?0P31^M<4
0<Feb`80bKO900@000000<Fic`35^Ll0aKW?0P3;^l/20;jof`<0`l?I1@2a`^H50:W1ja40oooo00<0
00000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H
0?ooo`L0Yl3[1@2W_n/50:O0k0@0Yk[W1@2V^>H20:Jgi@<0XZGG0`2RX]D50:>Re080Xj7C0`2W]n@4
0:Vii080ZkSS0`2Te_T50:CEn@D0X/;`102N_o0509Z`i`D0UZoX0`2H]^`508oAoPD0XMOj0`000003
0:[Fm`D0/mCa1@2]co850:;7l`D0Vl?c102;`?P407jnn`@0Q/7j1@2;__P50;BohP030<:fc`31^M<0
`KWC0080`KWC0P35]L/40<Vgb@0300000035^Ll0bk_;0080bk_;1P33`mT50;?4iP@0ZL7[403oool2
000001l0oooo000K0?ooo`8000003`3oool00`000000oooo0?ooo`0E0?ooo`P0Yl3[1`2W_n/20:O0
k0<0YkcX102W^^L40:JhiPD0XZGG102RX]D40:>Re0H0YkOT0`2Y^N@60:CFn@D0YLC`1@2R`_0409ff
j@D0V[3W102F[nP409C;n`D0Sm7n00D0TM?n0000000000000000097CoP030:[Fm`<0Y];g0`2ce?42
0:oKm`D0[Lob1@2Ua>l409_3l`D0T/3f101o^oX407:gn`D0Rkkh102d_n850<6id`H0bKO900<00000
0<^kb`3;^l/00P3;^l/00`3A_/P0`l?I0<?3f@020<?3f@80b<KH102ca>H50:W1ja40oooo00<00000
0?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?oo
o`T0Yl3[2@2W_n/60:Nlj0@0Yk[W102SZ=X50::Ue`<0XZ;E1@2U/^850:Ngi0H0YMOi102WaNl50:G4
l0D0X;g]102M]^T409Z`i`D0W<Cd102Dbo/208SDo`<0000000<0R=Co097CoP2Adoh00P2Adoh60:KB
m`D0[m_g1@2Xc?<50:G4k`@0XL?`1@2B`?H407nknP@0L[Ok102;__P50:6mk@<0`KWC0P2l^]P40<Vg
b@80c;S700<000000<^kb`3;^l/00`3A_/P20<?3f@<0b<KH0P2ca>H30;C5i`D0ZL7[4@3oool00`00
0000oooo0?ooo`0K0?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo2@2W`>/50:S0j`D0Yko[1@2X_^X40:Nlj0D0
XjcN102SZ=X40::Ue`@0XZcN1@2U/^850:OIn@<0YMOi0`2Wa>h40:O5k`D0XlGa1@2P_Nd309ffj@D0
V[W^1@2La?@209[Io@<000001@28bOd508c8o0H0XMWk102Pe_/50:S<l`D0Z<?]102Q`o0509O1m@D0
Q;_h101[/OX306^an@@0XKg]0P31^M<30;bjf0<0bKO9103<^<L00`000000dKk80=6nb0020=6nb0D0
b<KH1P2daNL50:W1ja00oooo00<000000?ooo`3oool06`3oool000L0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`8000004`3oool00`000000oooo0?ooo`0:0?oo
o``0Yl3[102X`>/50:Noj`D0Z;kZ102T/>450:>/gP<0XjSJ1@2OYMT40::/gP<0YK;R0P2XfoT50:OI
n@H0YlC^102Vb_<50:?5l@@0X;g]102G/^X509ZikP<0YMGi0`00000609gIo0<0R<Wm1@2=ao/30:7I
n`<0VMgn102Pe_/50:74lPD0Z<?]102VaO0509O1m@D0R[_g101[/?T3056RmP<0XKg]1P2l^]P00`39
]lT0c;S70<bha`030<bha`030=6nb0000000dKk80080dKk800@0el;50<S6f038a]P0b<KH0P3<b]P3
0;C5i`<0]<KW102Y`N/A0?ooo`030000003oool0oooo01X0oooo00070?ooo`040000003oool0oooo
000000/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo00L0oooo3`2W
`>/90:Noj`D0YKCT102T/>440:>/gP@0WIoE1@2OYMT40::/gPD0Z=_i1@2Xa>d30:O4kP<0Z<kc102V
b_<509bdj@@0V;7Y102G/^X40:G>mP<0000000<0YMGi0:CZnP2Tj_X00P2Tj_X509Znl@<0T;?_1@2=
ao/609WMoP@0T/Ch1@2Qa?850:[3k0@0Y/G`1@2I`_@508Zkm`<0Jk3i101AX_H308Bcl`D0_;[H1@3<
^<L20<jiaP030000003A_/P0dKk800<0el;500<0b<KH0<c:f03<b]P00P3<b]P60;C6i`@0ZL7[4@3o
ool00`000000oooo0?ooo`0I0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0
oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3o
oolA0:O0j`P0Yko[102V^NH50:Fdi0<0Y;3Q1@2LW=<309fOe@D0WjGI1P2Xg?T50:W4k@@0Z<C]1P2X
c_<40:6ij@D0W;CY102H/NT409g5m0<000000P2Uc_H20:CZnP80Y^Kk00<0c;C205a@Z`0D00001@2J
__43092ck`H0VM?l1@2Eb?T409;4n0D0WK_]102Z`n`50:S9l@D0VL;d1@2@_OD306ban@<0>I?a1024
/o<20;bjf0<0/kOK0`3<^<L30<jiaP030=6nb0000000el;500<0el;5103<b]P20<k>f@D0]<KW1@2Y
`N/@0?ooo`030000003oool0oooo01T0oooo00070?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool00`3oool2000001H0oooo00<000000:O0j`2W`>/0402W`>/80:Noj`<0YkcY102V
^NH40:Fdi0@0W9gD102LW=<409fOe@80WjGI0`2XfOT30:SLn@<0ZlO^1@2Ya>d70:S>l`<0Y[k[102Q
^NT409bdj@D0Ul7d00<0WLGd0000000000000P2MaO@40:;Xn`80Y^Kk0P3<]<8205a@Z`0301@0002J
__40V[ka0080V[ka1@2Ya^l50:SCmP@0ULSi1@2?]?0509fkk@80Z/?/0P2^an`50:S9l@D0V[ob102@
_OD406ban@<0>I?a0`1RXO<60;>gf`030<bha`3>^LH0c[W60080c[W600<0dKk80=O2a@0000000`3G
`/D00`3La/<0c<[H0<c:f0040<k>f@D0]<KX102Y`N/@0?ooo`8000006P3oool000P0oooo0P00000:
0?ooo`<000000`3oool00`000000oooo0?ooo`0B0?oooaP0Yl3[102W_n/60:Nlj@<0Y[WV1@2NXML3
09bMe0D0W9cC0`2MWmD60:SIn@H0ZlO^1@2Xbo840:S>l`H0Y[k[102Q^NT409S2m080Ul7d0`000006
09oNo@<0Y^Kk0`3<]<8305a@Z`D0UYSD0P2Ya^l30;[Vm0D0Z=?f102G^O0508ndl0@0WK_]1@2^an`5
0:K9lPD0V[ob102G`OD406bcnP030263j@0iTo40>I?a00<0HZ7c1@2c]m/50<jiaP<0el;500@00000
0=O2a@3La/<0g<K31@3>c]T20<o@fP@0]<KX1@2Y`N/A0?ooo`030000003oool0oooo01L0oooo000I
0?ooo`030000003oool0oooo0180oooo6P2W`>/40:NnjPD0YkcY102PZ=`409jQe`@0W9gD102LW=<6
0:K@mPD0[/g`0`2[anh20:S9l@D0Z<_b102Ya>d50:Jnj`D0WKo`0P2H`_@3000000D0T=;n1P2XjOX4
0<bd`P@0G52[102FV=@60;[Vm0D0YLC_102G^O0408ndl0D0XK[Z0`2^an`20;;@l0D0Y/Wb1@2N_^l4
09O1m@@0K;?j0P0QPnT406:Ql`80/kOK0`2Y/=d40<jiaP040=6i``3G`/D0el;5000000<0g<K300@0
h/_10<k>f@3>c]T0c/kI0`3?d=X20;C6j0<0/lKX1@2Y`N/@0?ooo`030000003oool0oooo01L0oooo
000I0?ooo`8000004@3ooolH0:O0j`D0Yko[102W_^X50::_h@@0X:SL102NXML309bMe0D0X/7_0`2V
d?H30;7Dl`D0[/g`1@2XbO450:_6k@@0ZLC]1@2P_^h309fol0<000000`2Dc?/3093BoP@0W=Ol1@2_
do<40<bd`P@0G52[0P2FV=@30<;gk@D0[]3b1@2Ua>l409JajP@0TZkZ1@2Q^^X50;;@l0D0XL7_102N
_^l509g8mP@0J;;k00<01FkM0263j@0mR>/00P0mR>/50:V`g@<0c[W60`3A^L<0103G`/D0g<K30000
003La/<30>;;`@D0cm3J1P2ca^P50:W1ja00oooo00<000000?ooo`3oool05P3oool001T0oooo00<0
00000?ooo`3oool03@3ooolH0:O0j`T0Yko[102T]^D50::_h@@0X:SL0`2NXML509b^i0@0X/7_1P2a
e?<50:S7l0<0Z<Wa0P2[aNd50:_6k@D0Xl;_0`2P_^h3000000<0X/Sc102Dc?/409cGo0<0//k^1@2_
do<30<bd`P@0G52[1032mnd20;CSmPD0[]3b1@2Q]nT409JajP@0TZkZ1@2[a>`20;;@l0<0[m7b1@2Q
`Nl40:G3k`D0WLSf101X/_/200E^g@<0?HS[1@2Y/=d00`3>^LH0dKW30=6i``020=6i``<0g<K300D0
00000>;;`@3Rbl40h/_10>K?_`030<o@fP80cm7K0`2ca^P30;;5j@@0ZL7[4@3oool00`000000oooo
0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`090?oooad0Yl3[1@2W_n/40:Jkj0@0Y;KU102R
[n440:2Xg0@0V:3J1@2L[^@50;;Km@D0ZLK_1@2Xao050:_5k@D0ZLS`102S`^l300000080Xl7^1@2R
b?<50:;7l`H0//k^102_do<30<bd`P80G52[102Ql_050;CSmPD0Xk[Y1@2Q]nT309JajPD0VJkV102[
a>`60:oAlPD0WkW[102U`nl60:3<m`<0H:oj00<005?<00E^g@0JK=h00P0mR>/40:V`g@D0dKW300H0
eK_00=c6``3La/<0h/_10000003Rbl430>K?_`030<o@fP3?dM/0cm7K0080cm7K1@2baNT50:S1ja00
oooo00<000000?ooo`3oool05@3oool001T0oooo0P0000070?ooob40Yl3[0P2W_n/30:NnjP@0Y[_X
102T]^D409RLeP@0UY[F102HX=X209b^i0<0/=gf0`2bfoD30:_7kP@0ZLK_1@2ZaNd30:_5k@<0[<[_
102Yb?0300000080X;c]102S`Nh50:c7kP<0X/Oc0`2d`N@30;;>kP80];WM101_U>H202b?kP80XO;`
1P2ZjOX40:Jnj`D0Xk[Y1@2O/N@309JYi0D0VJkV1@2feo450:?0kP@0WkW[1@2]d?830:3<m`<0XM3h
0P1?YoP3001Cc0806VcN1@2QZM`30=6i``<0eK_00P3Rbl400`000000h/_10>K?_`020>K?_`@0cm7K
0P3=dMd30;;5j@80/<GY1@2X`N/@0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003o
ool0oooo00<0oooo902W`>/60:NnjP<0Y[_X1@2KXm/309RLePD0UY[F0`2HX=X60;3MmPH0ZlO^102[
anl50:[5k@H0[<[_0`0000000`2S_^`0X;c]0:2lk@030:2lk@@0[<[_1@2/anh60;C1i0D0];WM101_
U>H508S<oPD0ZL;/102V_^/50::ci0@0Wk7T102FZN@209V^iP<0ZLK_0`2feo420;7Gm0D0Xl3^0P2O
^N/20:S8l0D0[M3b1@2Qd?P304nWn005000c]@00Dl`005?<001AcP0JK=h01@2QZM`00`3A^L<0eK_0
0=Fk`0020=Fk`0040=^n_03Rbl40h/_1000000<0i/no00<0jM>o0<oAf`3?dM/0103=dMd50;35j@D0
Z<7[403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`030?ooob80Yl3[
1@2W_n/40:NnjP@0WjgQ102KXm/409RLeP@0UY[F1P2[d_D40;3=k`<0ZlO^0`2[b_040:_7k`D0Z/K^
0P2/b^l3000000030:_3j`2S_^`0Xkk/0080Xkk/0P2P_>d30:?9l`@0[<[_1@2^_>@30;C1i0<0`<SP
102d^Md509O1m0<0R<cn0P2X`nd50:W2k0@0X[7S1@2R/n@309nai0@0UZWT1P2Ya^l50;7Gm0@0Xl3^
1@2Xb?060:gJm`@0TN3n0`0UTNd01@00<kD005?<001AcP00DLh06VcN00@0XJWL103E^l030=^n_004
0>;;`@3Vckl000000>K?_`80jM>o1@3=dMd20<_@gP@0/<GY1@2X`N/?0?ooo`8000005@3oool001P0
oooo00@000000?ooo`000000oooo9@2W`>/50:Noj`@0XkKV102O[N4409^Sf`<0V9cF1@2P_>`30:_B
m@<0]]Ka102`cNl60:_:l0D0Yl;]0`2Za^h2000000D0Zl?[0`2S_^`60:?9l`@0ZL7[1@2^_>@60<38
h0@0/<O[1@2G`O@50:S3k@D0Y;7Q102R/N<40::ci0@0VjWQ102J/>L30:W6k`<0/nGg1@2JboT509fm
k`D0XNSk1@2>j?P4097PoP<09I7]00@003>e001AcP00DLh0057>1@2LX]T20=Fk`0@0fkjl0P3Vckl0
1@000000jM>o0>WC_`3Ydkl0j]K000<0cM7M0`3;d=h50:o4j@@0Z<7[4@3oool00`000000oooo0?oo
o`060?ooo`8000002P3oool001P0oooo00<000000:O0j`2W`>/09`2W`>/50:Jlj@@0XkKV102O[N43
09^Sf`@0UZGP1@2P_>`60;KFl@L0Zl[`0`2Y`^`40:O2k@<000000P2^a^`50:_3j`D0X/Ga1@2R`^l4
0:W1j`80[[cT0`2ccNd30<38h0<0]Lg/102`an/50:c4k0<0Z<?]0P2V[]d50:Bah@<0X[7S1@2PZmh4
09^Yh@@0V[3W102ciOL208SWm@D0V/_i0P2M_Nl307GPk`H0I=O]00<0E]7M087Ko@21fod00`21fod3
002<a`8005>n00@003>e000l`@00DLh0057>102LX]T20=Fk`0@0fkjl00D0h/>i0>K?_`3Ydkl00000
0>WC_`030>[F`0@0bm3N0P38cml50:o4j@@0Z<3[4@3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo000000T0oooo000A0?ooo`8000001@3oool00`000000oooo0:O0j`0T0:O0j`@0Ykk[
1@2V_>T30:>fiPD0Ti_H0`2AV]P409JUh0<0X;c/0`2gfo850:g;k`@0Zl[`1P2Y`^`300000080ZlO^
102^a^`50:S4kP<0X/Ga0P2W`N`50:;2k`<0ZL7[1P2ccNd60;G=k0@0/LS[1@2/a>`50:J^g@@0Y;7Q
102S[]l50:2[gP<0VjWQ1P2Ti?`508SWm@@0V/_i0P1eh>l505k@l`@0MmCn0`2_co450:W9l0807GgW
00D0OP00001C_P00<kD003c1001AcP0409bRf@030=Fk`03K_[`0fkjl0080fkjl0P3R`kT30>WC_`05
0000003Ze/00j]K00>[F`03Yel800P3;d=h40<S?g`D0[lCY102X`>/@0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0S0:O0j`80Yko[102W_^/40:Jlj@@0V:CM102CVmP4096Jf0@0UZGP102gfo83
0;7>k`@0[L__1@2[a>`01@2Y`^`00000000000000000ZLO_00D0ZlO^102[a>`50:S4kPD0Yl7/102R
`^l509k9mPD0ZLW`0`2ecN`30;79k0@0/LS[1@2Y[=X40:J^g@D0Y[?R102S[]l40:2[gPD0Sn7m0`2P
]NL408Vbl@@0J;Wm1025dol20:ZfhPD0VL7c0`2_co430<C<h080ZLW`0`2X[=T0101<L=D07GgW07h0
0000Dkh2000l`@04001AcP2LX]T0W:;I09bRf@@0fkjl0`3R`kT01P3YbKD0jM>o0>WC_`3Ze/000000
0>[F`0<0jMO21038cml20<K?h@@0[lCY1@2X`>/@0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool200000080oooo802W
`>/50:Noj`@0Ykk[102N[n@309RTg@D0Ti_H0`2AV]P60;3BlPH0/Lk_102]b>h20:_4k0<000001@2Y
anl50:W3k0@0ZlC/1@2[`>T30:O1k080ZLC]1@2MaO@409fmk`D0ZLW`1@2abN`50:b^f@D0ZJcJ0P2V
[]d20:g1j0D0Y[?R0`2S[]l607OOm080ZkWS1@2P]NL208Vbl@80Y;3Q1@2N`o850:ZfhPD0^<;R1@34
c>050:R/f@<0C73E00@0OP00000CWP00?<4003c1102NWm@30=^n_0<0h/>i0P3YbKD20>[F`0030000
003Ze/00jMO20080jMO200<0j=O40<S?g`38cml00`36cn420:o4j@<0[/?Z102X`>/A0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooob00Yl3[102W_n/50:>ij0@0WZoT0`2HY=d409>Kf0@0
XK[[0`2`d_830;SFk`<0/Lk_0`2_c>l20:g8kP<00000102Ya^h30:W7k`80ZL;/1@2Y`n`40:c3j`D0
Zl3Y1@2Ya>d50:Bij0@0WKg_1@2Za>d30;79k080[K3K1@2/[]T40:V/fPD0[L7X102V/n800`1Jdm/0
Nm3o07_@o`0407_@o`D0ZkWS102P]NL50:B`h@D0];WM0P2Z]^830;Vng@<0^<;R0P35bMd30<C<h080
a/KJ1@2X[=T304a`e@0407h00000<[T003c1000l`@@0WYoD00@0fkjl0>;3^@3R`kT0h/>i0`3YbKD0
103_ck40j]K00>[F`00000020>WG`P80j=O41@36cn460:k3jP@0Z<3[403oool2000000@0oooo0P00
000:0?ooo`00403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo7`2W
`>/50:JmjP@0XkWX0`2N[n@309RTg@D0TZ7O102Q^^/60;SFk`@0[lc_0`0000030:W4k@D0ZLK^1@2Y
`^`50:_5k@@0[<?[1@2]`nX30:W4k@80[[cT1@2T^NP40:Noj`D0Z/C]102]/=/50:b^f@D0/=;b102]
`NP204G6b@D0ULSi1@2^^N840:^ih`D0YZOG0`2T/>420;W1h0@0];WM1P2i_]d00`2h`^80aLWM0<G9
g@020<G9g@D0a/KJ102X[=T404a`e@030000LP00<[T003c100@0WYoD103R`kT30>W9]@80klna0P3Y
el801@000000j=O40>SGa03Xel@0imS600<0a/oQ0P34c^830:k3jP<0[L?Z102X`>/>0?ooo`<00000
403oool00140oooo0P0000040?ooo`8000001`3ooolK0:O0j`@0Yko[1@2V_NX409VZh`<0T9gL0`2=
V=T509:Qg`H0^MO_102ac^l3000000<0ZlG]102Ya>d50:[3k0<0ZL;/0`2Za^h40:_5k@D0ZL;/102]
`nX50:jli0<0Y;WX0P2/`>P40:Noj`D0Zk;N102]/=/20:b^f@<0Zn3j102`d_8204G6c@H0X<;`102/
]^050:jihP@0Z:KC1@2VYmL50;W1h080];WM0P2f^mh50;Vng@@0aLWM0P39dN040<K6fPD0W9G<0`1U
M/l00`00078003:i000b^@050:RRd080h/>i0`3YbKD30>o?/@050?;B[`3Yel80j=O40000003Xel@0
0`3Wf<H50<C>hPD0[L?Z1@2X`>/?0?ooo`030000003oool0oooo00h0oooo000G0?ooo`030000003o
ool0oooo00L0oooo6`2W`>/40:Noj`D0XKKX0`2IZ^<4092Mg0<0SISI0`2BXMl20:g7k@<0^MO_0`2h
dnh3000000<0[lW]2@2[aNd40:[3k0H0Z/K^102W`N`50:W2k0@0[l7W1@2^_>@50:c0j080Yko[0P2[
]^450:^bgP<0[K3K1P2[h?X205??f`@0Xkc[0`2P`_030:ZagP@0[;KP0P2^^N830:bYe@@0Z:KC0P2V
YmL30;K4i@@0^L7P1@2f^mh20;Vng@<0_lOP0P35bMd40<WAh0@0/ZcB102LUL`406Efc`030000LP00
<[T003:i00D0Z:;@00@0h/>i0>W9]@3YbKD0jLVe0P3_ck420?;B[`80j=O400@000000>SGa03Wf<H0
imS60P3Uf/T20<C>hP<0`LkT0P2]`nX30:c3jP@0Z<3[403oool00`000000oooo0?ooo`0=0?ooo`00
5`3oool00`000000oooo0?ooo`080?oooa/0Yl3[1@2U_>X40:6fj0<0VJ[S0`2@WM`408fHf@D0[LO]
0P2hdnh3000000030;SCkP2_bNd0[lW]00@0[lW]102[a^h50:_5k@@0Z<C^0`2Za^h30:W1j`@0Yl7/
1@2Y`nd40:o1i`D0[lG[102/`>P50:^fh@@0Zk;N1@2Nio`206;GiPD0Y;SW102S_>/60:ZagP<0[;KP
1@2/ZMD40:RVd`D0]/CU0P2i`N030;:jg`@0][_N1@2oan050<WAh080_/CO0`2b[=8509bEc0<0IGK?
00<000ZK000b^000<[T01@2XX]030>W9]@<0klna0P3bdZl01@3deJl0j=O40>SGa0000000imS600<0
iM[91@31c^@60:c3jP@0Z<3[403oool00`000000oooo0?ooo`0<0?ooo`005`3oool2000000T0oooo
602W`>/40:Noj`D0YKcZ0`2Q]^P309VZh`@0RYWL102HZn@30:g7k@040;cFk@00000000000;cFk@@0
/lo^0`2_bNd70:_6kPD0Z<?]102Xa>h60:W1j`80Yl7/0P2XaNh50:W3k@@0ZLG^1@2_aN/40:bli@@0
ZkKQ1P2Cio/206oMkP@0YKCS1@2T^>L40:V_g0D0Z[7N102][]P40:bYe@D0/<;W102fa>D60;:jg`80
][_N0P2ianD30;o7h080`];V0`39dN030;k4g`@0/ZcB102LUL`306Efc`04000:V`00078003:h000b
^@80Z:;@0`2g[<h20>W9]@80klna0`3bdZl20?CE[`80imS600D000000>GJb@3Uf/T0iM[90>?LcP03
0<7>i080_/gV1@2/`nX50:S0j`l0oooo00<000000?ooo`3oool0303oool001L0oooo00<000000?oo
o`3oool02P3ooolG0:O0j`@0Yko[1@2N]NP309>Wh`<0RY[M102:VM`409R[i0<0000000@0_=K]0;[C
k@2jdnd0^]?]102ccnh60:_6kP@0ZL?]1@2X`nd40:[3k0D0ZL7[1@2XaNh50:C1kP@0ZLG^1@2Z`>T4
0:bli@D0SnGk0P1ihO850:Jbh@@0YKCS1@2Y[]/40:V_g0D0[K?L102][]P20:bYe@80[;kW1@2``^L4
0;6lhPD0/[[O1@2ianD50<;BiPD0_/CO102b[=8509bFc@80O8cH0P002Y/2000b^0H0]jc>0`3_ck42
0?;B[`<0m=F_00D0mMV`0>GJb@3Uf/T000000>GJb@030>?LcPD0_/gV1@2[`n/40:S0ja00oooo00<0
00000?ooo`3oool02`3oool001H0oooo00<000000?ooo`3oool0303ooolG0:O0j`@0Y;c[1@2N]NP3
09>Wh`<0RY[M102:VM`300000080]<_[1P2jdnd40:o9k@<0ZlK^0`2[a^d40:W3k@D0ZLC]102Z`n`5
0:W5kP<0Z<G^0P2W_n/50:C1kP@0Yl7/1@2Z`>T509CQo@80P^Gb102W/^450:Jbh@@0Z:kL1@2Y[]/2
0:V_g080[;GO102]/m`40:f^f0D0[;kW0P2``^L30;30iP@0/KcR1@2ca^P20;W7i@<0^LgZ0`32d^H2
0<3Cj0@0_/CO1@2NU/`409bFc@<0O8cH00@000ZK09dd0000<[P003:h102g[<h20<Zkc0040>o?/@3b
dZl0l]:_0?;B[`80m=F_0P3efK000`3fgK80iM[9000000030>?LcP80h=kC0P2ncNH30;_=j0@0Zl?[
1@2X`>/@0?ooo`030000003oool0oooo00X0oooo000F0?ooo`8000003P3ooolC0:O0j`@0Yko[102T
_>/409jej0<0TjOS0`2:V]d01@2M/>D00000000000000000WK3U00<0]<_[0`2ne>X30;[Ck@80]/o]
102_bNd60:_6k@D0ZLG^102Ya>d40:S4kPD0ZLG^1@2W_n/50:S2k@@0Yl7/1P2LfOd208KXl0@0Z;GR
102W/^420:Jbh@L0Z:kL102Y[]/50:beg`<0[K?L1@2Y^nH40:bni`H0/<3V0P2a_>820:o4j@@0/lKX
1P2icNX50<3Cj0@0Y:7B102NU/`409bFc@@0O8cH00<000ZK000k_@00<[P00`2g[<h30<Zkc0030>o?
/@3bdZl0l]:_00<0m=F_0P3efK020?KM/P030>?LcP000000hmc>00<0h=kC1@2kcNP50:_2j`@0Z<3[
3`3oool2000000`0oooo000F0?ooo`030000003oool0oooo00h0oooo4`2W`>/40:Noj`@0Y;c[102?
Y^D308BHgP<000001@2M/>D60;kDjPD0]/o]1@2]b>h30:_6k@L0ZLG^102W`^d40:S4kPD0ZL3Z0`2W
_n/20:[5k@D0Z<;]1@2Rc_L208OZj`D0Zk_V102X]N830:Nbh@T0Z:kL1@2[]n840:beg`@0ZKWU1@2Y
^nH40:o4j@D0/<3V1@2_a>T50;?9j`D0^mO^1@2_]]h30:BQdPD0WYK<0`2LU/d508^PhP0409dd0000
>kd003:h0;N/cP@0b[_<0`3bdZl20?CE[`80mMV`0`3fgK800`3ehKH0hmc>000000020>3Nd`80fmoI
0`2kcNP20;O;j@D0Zl;[102X`>/@0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000003o
ool0oooo0100oooo4P2W`>/30:Noj`D0W;GZ0`2?Y^D3000000@0R9WN0P2M/>D30;O9j0<0_]CZ102m
dn/40;7;k@D0[LS^1@2YaNh50:S3k@@0Yl;]102Y`^`50:W0jPD0Z/G]1@2Va_030:;>m`80Q^_V0P2^
an`50:^kiP<0Z;GR102W[md50:R^g0@0ZKOS102[]n890:Vii@D0[LG/102_a>T50:c0j@80[lCY0`2`
an/30;?9j`80]]C`0`2kenh20;O:j@D0[kKN0`2TXM8409jFc0@0Z:_I1@2;X>82000k_@D0b[_<0P3K
c<T30?CE[`80mMV`0P3fgK820?GQ]P030>3Nd`000000h=kC00@0fmoI1@2gbnT50:W2j`@0Z<3[403o
ool00`000000oooo0?ooo`080?ooo`005P3oool200000180oooo4@2W`>/50:Bmj`<0W;GZ0`000000
102?Y^D0Q9SN08BHgP24V=h308RIgPH0]lWX102mdn/30;[@j`@0/L_]1P2[a^h40:W5kPD0Z<?]102Y
a>d40:W2k0D0Z<K_0`2ZaNd20:O1k0D0Y/K`0P26jnH50:k7k0@0Zk_V102U[mh40:N_g@D0Z;OT102Y
]n<20:^ghP80ZK[V1`2Y^ND20:_5k@D0[LG/102[_^P40:c0j@H0/<O[1@2fe?050;O:j@@0[kKN0`2T
XM850:6Qe@@0Z:_I102;X>800`2M=00004G7000k_@030<Zkc0<0flc900@0im[80?CE[`3efK00mMV`
0`3fgK820?GQ]P80lnFk00@000000=_Of@3KgmT0fmoI0P3Eg]l20;O;j@<0/lW[102Y`^/50:O0j`l0
oooo00<000000?ooo`3oool0203oool001H0oooo00<000000?ooo`3oool04P3oool=0:O0j`@0Yko[
102T_N/30000000409bejP2?Y^D0SjKU08nVi@<0Q9SN1@2M[^<30;O9j0<0`M;W1P2jd>/40:o9k@<0
ZlK^0`2Za^h40:W5kPD0YlC^102Ya>d50:K3kP@0Z<K_1@2W`N`208O[j0D0/MOd102^an`50:B^g`@0
YJoN102V]^@50:Rgi0<0ZKOS1@2Y^^H40:Vii@D0ZlG]1@2Z_^P40:^nj0D0[/O/1@2aco020;KDl0<0
]mC_102gb^T509VEcP<0V9K?102QXMD20:R[f@<0[;KQ102=YND20015a`03000k_@3:^l`0flc90080
flc90P3Wf/P30?GI/080m]fb0P3ehKH30??U^`030?7X`P000000fmoI00<0eMkO1@2cbN/50:W1j`@0
Yl3[3`3oool2000000T0oooo00030?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo01@0oooo3@2W`>/40:Noj`<000000P2M^>/308fYj0<0OYSQ0`23Umh509f^h`@0`M;W
0`33dnL30;[@j`80]/k/102_bNd60:[6kPT0YlC^102V`^d50:K3kP@0Z<3[0`2W`N`2093[m080/NWh
1@2aeo@40::^h0@0Y:kO1@2U]N@40:Jfi0@0Z;OT102X^nL40:VjiPH0ZLC]202Z_^P50:c7k@<0[/O/
0P2^bnl40;7?l0D0]mC_1@2RXM<409VEcP@0V9K?0`2QXMD60:bfh@<0SJGU0`00ALL30=_<b@<0im[8
0P3[i<P30?KM/P80mN6f0P3ciK/20?7X`P040=GNg`000000eMkO0=GNg`80cMcT0`2cbN/20:o7j`@0
ZL7[1@2W`>/;0?ooo`<0000000<0oooo0000003oool0203oool00080oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo3@2W`>/00`2T
_^/00000000000020:Bnj`@0WKS[0`2=ZNP307jHh@<0PiON1P2e`n@60<?Ci`D0]/k/1@2/b>h30:[6
kP80Z<G^102Wa>h50:O3k@@0Y/;]1@2X`nd40:S0j`80T>_d1@2ajOP50::_h@@0XZkP102T/n@50:Fe
i0<0Y[KT1@2X^nP40:Rki`@0Z<?]0`2Ya>d30:Vnj@@0Z[kX102[a^h50:c7k@D0[/__1@2ce_840:bc
gP@0XZ7C102IULh409RFc`@0[;OQ1@2/]^4308fUi@805e_C0P00ALL0103Kc<T0im[80>OJb03Wf/P3
0>_Tb0040>cZbP3fgK80mN6f0?GQ]P80lnFk0`3aj<800`3/jlX000000<gLi0040<gLi0D0[lO[102X
`N/50:O0j`H0oooo100000040?ooo`030000003oool0oooo00L0oooo00020?ooo`040000003oool0
oooo000000/0oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`T0Yl3[00D0Yko[000000000000
00000:Noj`040:Bnj`<0WKS[0`2=ZNP307jHh@D0UZOR0`2e`n@20<?=hP<0`m?W1031d^L40;;<k@D0
[<S^1@2XaNh40:O4kPD0Yl?]102XaNh50:S3k@@0W>?m0`2Wlo<40:Bdi0D0XZoQ102R/^<40:Bci0@0
YKGT102W_>P40:Rkj0D0Yl;]102X`nd50:Vnj@80Z[kX0`2Ya^h40:_6kPD0[<S^1@2`eO<50;75j@@0
[;?N102RXM<309VEcPD0Y:oO102/]n450:Rgh`<0RJCV00<0:FOH01MKd`00@kH0103Wf/P20>_Tb080
k>[:0`3ehKH20??U^`80lNS20P3/jlX0103VkM8000000<gLi03=g>@30<CHj@D0[<G/102X`N/50:O0
j`80oooo0`0000080?ooo`030000003oool0oooo00L0oooo00020?ooo`040000003oool0oooo0000
00T0oooo0P0000040?ooo`030000003oool0oooo01P0oooo1@2W`>/3000000D0Yko[102O^n`308n^
j`<0NY[V0`1jTn0509JWhPD0`lgR1@31d^L20;kAj0@0//c]1P2[anl40:O5k`@0YlC^1@2VaNl40:S5
kPH0X]Ci0P2Wlo<40:W1j`@0Y;CT1@2P/><40::bh`<0Y;?T1@2V_>T40:Nlj0@0Y/7/1@2W`^d40:Vo
j@@0ZKkY1P2Ya^h40:_6k@<0[<S^0P2^do<30;3El`80/M7`1@2aaNT30:bcgP@0XZ7C102KXMT40:B_
g`80[;OQ0`2/^n@40:Rgh`@0RJCV0P0YImP00`00@kH0im[80>OJb0030>_Tb080k>[:0P3Zk/h20??U
^`80lNS20P3/jlX30>K]dP0400000034f>T0a=SY0<CHj@80^m;/102/aN`50:S0j`@0Yl3[0P00000<
0?ooo`030000003oool0oooo00H0oooo00020?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`040:O0j`0000000000000000@0Yl3[1@2U
_n`409nkk0<0Sjk[0`1jV^H307ZCh080UZOR0`2^^N430<?=hP@0b=3Q1@2ndNP40:o;kP<0ZlO_0`2X
anl40:O5k`D0YLC_102VaNl50:C8l`80W?;^1@2beo<40:W1j`@0WZkS1@2P/><30::bh`@0YK_Y1@2V
_>T40:K0k0@0Y/7/1@2X_nX40:Voj@D0Z<G^1@2ZaNd40:_6k@D0[]?c1@2adO040;75j@@0V9?=102F
U]4409^Qf@<0Y:oO1P2/^n@30:Rgh`@0RJCV0`0YImP01000AkL0jnC80>_Tb03[i<P20>cZbP<0j^k>
00<0j>oA0?7X`P3aj<800P3/jlX30>K]dP80g^cK00<000000;_Bk02kd^`00`2kd^`40:[3k0@0Z<3[
1@2W`>/=0?ooo`030000003oool0oooo00H0oooo00030?ooo`8000002P3oool3000000<0oooo0P00
000H0?ooo`<000002@2W`>/40:Fok0@0UKG^0P1kXN/307ZJiP<0NY?P1P2^^N450<S@h@80bM7P0`2n
dNP20;_@jP@0[l_^1P2Xanl40:K5k`D0YLC_102VaO030:C8l`80WNkg0`2dkOH40;;Gl`@0WJgS102N
[^<40:2`h`@0Xk[Y102U^nT50:Fok0@0Y/3/102W_n/50:RojP@0Z<C^0`2XaNh20:W5k@@0Z/G]1P2[
d?<50:oEm0@0YJCD102NVLh309RCc@@0UYKA102KXMT40:Zki@D0[;_T102S]>D408BQi`0503I_g00Y
ImP0:FOH000<VP00AkL00P3/j/X30>[^cP80j>oA00<0i^oB0>K_d`3Vkm<00`3VkM830=k/f`040000
003Dj>@0^m;/0;_Bk0<0/lc]102Z`n`80:O0j`d0oooo00<000000?ooo`3oool01P3oool001@0oooo
00<000000?ooo`3oool05@3oool3000000@0oooo2@2W`>/40::mk0@0UKG^0P1kXN/306f@h`@0QicQ
0`2^^N420;o3g@<0b=3Q1039dN050;_@jPH0[<[_102Wao040:K5k`T0Y/G`0P2Mk_L20;C]mP@0Y;g[
102M/>D409f]h`<0WZkS1@2R^>T40:>jj@@0YKk/102U_n`90:Noj`D0YlC^102Xa>h50:W5k@@0Z/kc
0`2[d?<30:cEm@80[mGd0`2Z/Md30:FTe0@0WYW>102HTld309JFd@D0Z;[V102Z^nD50:VjiP@0XkCU
1024XNL203I_g003000a^@0039X04goU00<0j^k>0P3Xkm40103Vkm80i^oC0>K_d`3Vkm<20>G`e0<0
g^cK0P3Dj>@00`000000/lc]0;?<k@030;?<k@D0Z<7[202W`>/<0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`030000003oool0oooo0180oooo0`0000080?ooo`@0Yl3[1@2V_n/40::mk0<0UKG^
0`1kXN/306f@h`@0QicQ1@2o`md80<WAh0@0^=3/0`2/b^l30:W:l@@0YlO`102Ua_450:K5l0@0X^3l
0P2/m?820:oFm0@0Y;g[102M/>D309f]h`@0WkGX1@2R^>T40:Bmj`@0YKk/102V_n`50:Noj`@0Yl?^
102Wa>h60:S4kP@0Z<gc102Zc_<50:cEm@D0Z[7M102UY=@309jIcP@0V9?=102U]^D50:RjiP@0ZKcW
102Y^^H509fbiP<0OIkW0`0fKm`01005EM004goU01=oi@0COnD20>S_d@040>K_dP3Vkm<0i^oC0>K_
d`80iO3D0P3TlMH30=CXi080b>7Z00<000000;?<k@2cc>d00`2]an`40:S1j`T0Yl3[2`3oool00`00
0000oooo0?ooo`060?ooo`00503oool200000100oooo0`00000<0?ooo`D0Yl3[102V_n/409fkkP<0
QJg_0P1TTnT306f@h`D0W:[P0`2o`md30<S7f@L0bM7P102hd>`60:W:l@@0Y<Ob102Ua_460:?@m`80
[?Cb1@2_e_@30:Bmj`D0VJkV0`2L/^L409nej0D0Xkg[102T_N/40:Fok0@0Y[o/1@2V`nh40:O3kPL0
Z<C^0`2Xbo840:S=l`D0Z]Cf102]_ND40:Zag@@0YJCD0`2NVLh509j[g`@0YKKU1@2X^nL40:Vli`@0
Y[WV102M/^H407fNi`80@WOO0P05EM0304^PmP040>K_dP3Vkm<0i^oC0>K_d`80iO3D0`3TlMH00`3Q
l]X0b>7Z0<SQjP030<SQjP030000002]an`0[LO/0080[LO/1@2X`>/90:O0j`X0oooo00<000000?oo
o`3oool01P3oool001@0oooo00<000000?ooo`3oool0303oool300000140oooo102W`>/40:Fok0@0
WK_^0`25[Nl206BCj@<0KHoR1@2LZ^040<S7f@<0c/WE1P39dN050;C@kPD0Y/_c102Tao850:?:m0D0
Y_3f0`2dkoH409RbjP<0UjgV1@2I[^H309bbi`@0X[_[102S_N/90:Fok0T0Y/?^102Wa>h40:S4kPD0
Z<_b1@2YdoH50:g6k0@0[KgU0`2Z/Md509VFc`<0VYkG1@2NZml80:Rki`D0Yk_W102V^NH309fbiP@0
OIkW0`12Mml00`0cMN401EG@07^knP0407^knP80iO3D0`3TlMH0103Ql]X0f_;P0=[bh03Jl^030;cG
kP040000002]an`0[LO/0:g7k080Z/?/102X`>/90:O0j`X0oooo00<000000?ooo`3oool01P3oool0
01@0oooo00<000000?ooo`3oool02P3oool2000001D0oooo102W`>/40:Fok0<0WK_^0`25[Nl306BC
j@<0KHoR0P2LZ^030;2df`80b<OI1@3>bMD60<WAh0<0]=3^0`2ad?040:K;l`D0X/Wd1P2Th_`20;C_
mP@0XLOc102H/^X309N]iP@0VJkV102O^N/40::kj`@0Y;o]1@2U_n`40:G3k`T0Y/?^102Wa>h50:O;
lPD0Ym;f102[c?450:g6k0@0WYC:0`2KTl/509VFc`<0VYkG1@2Y_NP40:Rki`@0Z;cX102W^nL50:>g
i`<0UjoW101hV^H00`1?P>80@WOO049gg`0203=eh@D0Wlgg0`3TlMH0103Ql]X0f_;P0=[bh03Jl^02
0=3]j0<0_=O^00<000000:[3k02Z`n`00`2Z`n`=0:O0j`X0oooo00<000000?ooo`3oool01@3oool0
01@0oooo00<000000?ooo`3oool01`3oool3000001P0oooo102W`>/40:>nk@<0U;S`0`1^XO020526
iP<0KHoR1P2`]=/50<k9e@<0dLSA1@39dN060;7@l0D0XLcf1@2Ne?/20:_dl@D0ZNKj102Qao<309Rb
jP@0Uk;Z102L]^/409nij`@0X[o]102T_nd50:C2k`P0YL?_102V`nh60:K:l`@0Y]7g0`2Wd_H20:W?
m0@0Zlca1@2QUl/309jDbP@0Vi?;102IU/l40:RojP@0ZKgX1@2X_NT40:Rlj0@0Y[[X102S]nL409N_
i`@0N9[V0P1?P>8303=eh@<0Wlgg0`2ifo40103Ql]X0f_;P0=[bh03Jl^030=3]j0@0//g^00<00000
0:S1j`2X`N/00`2X`N/<0:O0j`X0oooo00<000000?ooo`3oool01@3oool001<0oooo0`0000050?oo
o`<00000703oool40:Noj`@0Xkk]0`2D^?0306jQl080D8KV0`1hUN840;2df`80_[WE0`3>bMD30=78
d@80e<K=0`39dN030<W@g`H0[M7c102Jd?/309kDn`80W>gg0`2IlNd40:WVnP@0Rk3_0`2@[^/409Nb
jP<0W;K[1@2P_^h40::ok@@0Xl;_102T`^l50:G4k`@0YL?_1@2Ubo<50:CAm`@0Y]7g1@2Yco@40:>J
c0@0XIO;102NU<X309^Cb`D0Y[kZ102X_nX40:Nlj@@0Z;gY1@2V^nP40:Jjj0<0XkOW1@2AZnL307FG
iP<0Ch3R0`1LT^/30;WKl@80b^K[0P3Dk^H40=3]j080`n;^0`2bcNh00`2/aNd000000:S1j`030:S1
j`d0Yl3[2@3oool00`000000oooo0?ooo`050?ooo`004`3oool00`000000oooo0?ooo`020?ooo`<0
0000803oool40:Noj`D0X;g]0`28/o80101ATNh0D8KV0526iP1@Q^H307REhP80/;CK102n^MD40=78
d@@0e<K=1039d=l30<[>g@D0Z=?f102Jd?/209c]m`80VO7]1025gOd408S1nP@0Rk3_0`2@[^/309Nb
jP@0WKg_1@2P_^h40:;2l0@0Xl;_102Ta?050:G4k`D0Y<_d102SdOP40:CAm`D0Ym3e1@2TWLh30:>J
c0@0XIO;102NU<X40:>gi`@0Y[kZ1@2V^^L40:Nlj@@0Yk_X102V^nP40:Jjj0@0WkGW1@2AZnL307FG
iP<0Gh_T0`1LT^/30<[Vj`80e>kV0`3Fln@50<?RkP<0[<G]00<000000:c5k@2X`>/00`2X`>/=0:O0
j`P0oooo00<000000?ooo`3oool01@3oool001<0oooo00<000000?ooo`0000000P00000T0?ooo`@0
Y[o/1@2P_Nd308RclP80DI7^00<0?gcS07REhP1hUN800P1hUN840;jie@80ak[>0P3Ab=440=C6c@<0
e/?7103:c]d30<_9f0@0Z=?f0P2@goh208_/k@80V^ke102Sb?<206VanP@0R<7j0`2;/>l408ngl@@0
V;[_0`2M_Nl50:32l0@0X/;`102SaO440:C4l0D0X/ce1@2QdOP40:?An0D0YLof102TW/l40:BMcP@0
Xi[<0`2QUl/50:2^h@@0XkOW102W^^L40:Jji`D0Z;gY102W^nP40:Jkj0@0Y;WX102O]NL4096[i`<0
MIOV101ORn@408:]l080e>kV0`3Fln@20=7ci`D0]]?_0`2Y`^`00`000000ZL;/0:S0j`030:S0j`d0
Yl3[1`3oool00`000000oooo0?ooo`050?ooo`004`3oool3000002L0oooo102V_n`509flk`<0NJgd
0P0/ONL00`0oO><0RIgQ08VMh@0208VMh@80_[WE1037^/h40=C6c@@0e/?700<0ekk10<[>g@3:c]d0
1@3;bMP40:WGn080^^7c0`3@fn400`3Ca<`0XlSc0:?8l`020:?8l`<0JK7j0`1[ZoL3082am0@0SkOa
102G`oH309g2lPD0X<;`1@2Pao@30:?5l@D0XLgg102OdOT50:7An0D0Xlgf1`2TW/l50:BMcP<0Xi[<
102PYm/40:2^h@D0Z;cX102W^^L20:Jji`80Z;oZ102X_NT50:Jlj@@0Y[_X102T^NP409^bi`@0RjKW
0P1eU^D405n;i0D0XlKb0`3Fln@20=7ci`80a^W^0`2fdnl20:g8k@<0ZL;/00<000000:O0j`2W`>/0
3`2W`>/70?ooo`030000003oool0oooo00D0oooo000D0?ooo`030000003oool0oooo02L0oooo1@2V
_n`409flk`<0NJgd0P0/ONL00`0`Ln00RIgQ08VMh@0208VMh@D0ak[>00<0cKW70=C6c@3Da/d0103F
`lL30=Nn`@D0blWH0`3>`/l30;[Ql`<0d=_Q0`3Ca<`40::Qd`<0NIOS0P1[Xo84082am0@0Rl7i102G
`oH309g2lPD0WLWg1@2Jc_X409k=n0D0W=7j0`2OdOT50:?9m0D0Y9g>1`2TW/l40:BMcP@0X:;F102P
Ym/20:2^h@80ZL3Z1@2X_>P30:Nji`D0Z;oZ2@2V_>T30:Jkj0D0X[OX102K/^L308^Vi`<0MIKU101c
VNP30:?6lP80_Mg`0P3AlnL50<KYkPD0[LS]0P2X`>/00`000000Z<3[0:O0j`0@0:O0j`L0oooo00<0
00000?ooo`3oool0103oool000/0oooo1@0000050?ooo`800000:@3oool40:Jok0@0VKc`0P1WY_@3
02ami`03031ch02HY=h0V:CN0080V:CN0`37^/h30<fia`D0e/?70`3G_/40103G^;X0blWH0<_9f03;
bMP30<k2c`<0d[_30`3@fn440=?4c0030<je`@2RXM<0XZ7C0080XZ7C0`1iUn<306^SlP@0N;Oi0`2;
`OT408k8o0@0U/[i102EcO/509[>nPD0V/oj102R^NT40:;3l0@0Y9_<102TWLh70:BNc`D0XYoC102P
X]H30:2Wf`D0ZL3Z102X_>P50:O0j`@0Y[[X202V_>T40:Bij0@0X[OX102K/^L308^Vi`@0MIKU101c
VNP30;gMl080bno/0P3=mNT50;SHl0D0ZL;/0P2X`>/00`000000Z<3[0:O0j`0@0:O0j`H0oooo00<0
00000?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W
0?ooo`@0YKo/102I_?0206NVm08006;G0P0`Ln0409RTgP030<NjcP3=^LL0cKW70080cKW70P3A]l42
0=K3a`<0ekk10`3G^;X40<k2c`@0d[_30P3I^;P40=?4c0<0c[G10`2RXM<409JBc@<0Ri_M1025/?44
08G1n`<0S/Sl1@2AbO/309G=n`D0VL[h1@2R[^040::ij@@0Y9W:0`2TVl`40:BMcP80Y9k?0`2UX=03
0:>Od@@0XYoC102PX]H40:W3k@@0ZL3Z1@2V_^/50:Nji`@0Y[[X0`2V_>T50:Fjj0@0Y;WX102O]>L4
09J]i`<0QZ7U101kVND408b^k0<0bno/0P3=mNT20<G^k`<0^=S`0P2^bNh40:W2k0<0Yl3[00<00000
0:O0j`2W`>/0402W`>/50?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool09`3oool40:Fok0@0Uk_a0P1EW_@2001Re`0301aYg00`Ln00V:CN
0080V:CN103=^LL40=6g`@@0ekk10`3G^;X00`3H/k<0c/;?0<k2c`040=:k``<0fKRh00<0h;Za0=?4
c03Ca<`0103>]L440:VKb0@0UY;=0`2;Vmd408F`l@@0UjgV102B__D409f^h`@0Vkka102SXmD50::^
h0@0YYS80`2TVLX40:BKc0<0Y9g>1@2UX=040:>Od@<0XYoC1@2XaNl40:W3k@@0Y[_Y0`2V_^/20:Rl
j0@0Yk[W102V^^P40:Nlj@@0YK[X1@2S^NP409ndi`<0UZgW1026XND307^Ii@D0Z<Wa0`3=mNT40<G^
k`@0[/W^1@2X`>/30:O0j`030000002W`>/0Yl3[00l0Yl3[1@3oool00`000000oooo0?ooo`040?oo
o`003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo102U_n`409Nkl@80
EIkd00<003nl001Re`0LJM`0102TZ=X20<fia`D0dKO100<0dkBk0=Nn`@3G_/400`3G^;X30=Rc/`@0
d[_30`3I^;P30>2j/@D0c[G100@0b[?30:VKb02YVlP0ZI_8102FT/d40:BIbP@0WIgD102G[NH40:6P
e0@0WJkS102TW<d40:>Se@80XZkP0`2XV/P30:JHb0@0Y9W:0`2TVl`40:NRd@D0YJ3@0`2SWm440:O6
l0@0Z<G_1@2V^NL40:Jkj@D0Z;cX0`2W^^L50:NnjP@0YkcY102U^nT40:>ij0D0Vk7W0`2AZ>D408FN
i0<0R:CW0`2XbO430<3Wl@030<G^k`2hf_40^=[a00<0^=[a102Y`^`40:S0j`<0Yl3[00<000000:O0
j`2W`>/0402W`>/40?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00X0
oooo0P00000X0?ooo`@0YKo/102E^o4204BGlP03000o_00LJM`076WL00@0Y:SJ1@3A]l430=>d^`@0
ekRj0`3H/k<00`3I/:h0d[_30=:k``040=Vh^0<0h;Za00@0i;j`0<je`@3>]L40c[G10P3:/l<40:VK
b080UY;=0P2XW<X40:BIbP<0WIgD1@2VW</40:6Pe0@0Z9_9102TW<d30:>Se@D0Z9[8102VV<P30:BI
bP@0ZJKC102WX]440:FPd0P0YlK`102V^>D40:Jii`D0Z;oZ102X_>P40:Noj`@0YkkZ2@2U^nT40:6f
i`@0Vk7W102AZ>D308FNi0@0R:CW0`30io420<Ofk080`^oa0P2hf_430:g9kP@0ZL;/1`2W`>/00`00
0000Yl3[0:O0j`0?0:O0j`@0oooo00<000000?ooo`3oool0103oool000`0oooo0P00000>0?ooo`03
0000003oool0oooo02H0oooo102U_n`409Fkl@80A9Ob00<001VG001Gd@0LJM`00P2TZ=X20:b[eP<0
dKO1103C];/00`3D/[H0ekRj0=Nh^P040=Rc/`80fK2^103I^;P30>2j/@<0i;j`00<0c[G10<Zc``3:
/l<00P3:/l<30:VKb0@0Z9c:102TVLX40:fPbP@0YYc;0P2QX=@30:jQbP<0Z9_9102TW<d40:bObP@0
Z9[8102VV<P40:b/e`@0ZJKC0`2WX]450:K6l0@0YlK`102W]nD40:Jhi@@0Z<7/102X_nX50:JmjP@0
Yko[102U^^P40:Fkj@D0XkSW102Q]^L309^ai`@0TJSU0`25W^@509jmkP80aoK/1032ko450:g9kPD0
Z<3[1`2W`>/00`000000Yl3[0:O0j`0?0:O0j`<0oooo00<000000?ooo`3oool0103oool001d0oooo
00<000000?ooo`3oool09P3oool40:Fok0@0UK_a0P0jT_000`006IL005OA0:b[eP040:b[eP030=6g
`@3C];/0dkBk0080dkBk0`3D/[H0103G^;X0f;>c0=Rc/`3H/k<30=V`[P040=fb[03I^;P0fKRh0=Vh
^0<0h;Za0`3T_[050<Zc``@0[:C?102XW<X20:BIbP80/:S?0`2]X<X40:JLb`D0[Z7:102XVlT20:BL
c@80/:S@0`2/WlX40:RJb0D0[[?L102/[=L30:VVd`P0Y/K`1@2W]n@40:Ngi@D0Z<?]0`2X`N`40:Jk
j@<0Y[gZ0P2W_>P40:Jji`P0YK[X102S^>L509jciP<0Uj_T102=Xn<308^Si0<0W[g^0P2hh_@20<7f
kPD0]]Sb102Y`^`40:S0j`P0Yl3[00<000000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo
00<0oooo000N0?ooo`030000003oool0oooo02H0oooo102U_n`409Fkl@80>Y;`00<001VG001Gd@2/
ZmH00`2/ZmH40=>d^`@0e;:f103H/k<30=V`[P80gK:/00@0fKRh0>2j/@3P^[40h;Za103T_[00103U
`[@0b[?30<Zc``3:/l<20<>fc@@0[:C?0`2XW<X40;2Xc`@0[J3:0P2VW</20;>[d@@0[Z7:102XVlT4
0;2Xd0@0[9o:0P2XV/P20:jkh`@0[[?L102/[=L40:K5k`@0Y/K`202W]n@50:O3kPD0YkWV0`2V^^L4
0:Jkj@D0YkcX0`2V^^L50:Jmj@@0YK[X102R^>P409jciP@0Uj_T0`2=Xn<408^Si0<0^>;d0P31m^h2
0;k]l`D0[<O^102Y`^`;0:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`03
0?ooo`007`3oool2000002L0oooo102U_n`409Jkl@80>I;`00@001VG001Gd@2/ZmH0[:_F0P2_[=D3
0=>d^`@0e;:f00<0e[6c0=Rc/`3H/k<00`3I/:h30=fb[0@0h;Za0`3T_[030>G2]0D0`kK=0`2/Y<l4
0:Z/f0@0/:S?0`2]X<X50;>[d@<0[Z7:1@2b/]P40;2Xd0<0[9o:1@2^^n<30:jcg0D0YL;^102VaNl4
0:Nhi0@0YkOT1@2W`nh80:NiiP@0Y[[W102X_^X40:Nlj0@0Y[kZ102V_NT50:>hj0@0X[SX0`2N/nH5
09>UhP<0T:CS102L^N`20<7fkP<0_^gc0P2bdo440:c7kQ00Yl3[00<000000:O0j`2W`>/0402W`>/0
0`3oool000000?ooo`040?ooo`008@3oool00`000000oooo0?ooo`0U0?ooo`D0YKo/0`2F^o4203VB
l003000e]`2_[=D0[jcE00<0[jcE00<0dkBk0=Bb]P3D/[H00P3D/[H30=Ja/`040=Rc/`3I/:h0fK2^
0=V`[P<0gK:/00<0hkR[0>2j/@3P^[40103T_[030>G2]0030>73^P33]/d0`kK=0080`kK=102T[=`4
0:Z/f0<0/:S?102a/mX40;>[d@@0/;[Q1@2b/]P30;2Xd0@0[;oX102^^n<40:Fok0@0YL;^1@2X^>D4
0:Nhi0D0Yl?^2`2W^NH50:S0j`@0Z;kZ1@2V_>T30:JnjP@0Y;SW102S^>P509nai@<0VJcS102CYN84
092Th`<0]NGf0`2lmnl50;;Cl@@0Z<7/402W`>/00`000000Yl3[0:O0j`0?0:O0j`030?ooo`000000
oooo00@0oooo000R0?ooo`030000003oool0oooo02H0oooo102U_n`409Rll@0303nFlP000X80[jcE
00<0[jcE103D/[H40=Ja/`@0fK2^0`3M/Z`20>>hZ`040>2j/@3T_[00i;j`0>Bn/0<0iL:d0P3Q`kX2
0<>fc@<0^kGD102T[=`30:Z/f0@0Z[KQ102a/mX20;>[d@80Z[_U102`^^440;:bf0@0ZKoZ102/_nP4
0:Fkj@@0YKo/102X^^H40:Rhi@D0Yl?^302W^NH50:O1k0@0Y[WW102V^nP50:Nkj0<0YKWW102T^>L4
0:>fiP@0Wk7U102I[><309>UhPD0W[c^102lmnl20;WVm0D0Z/C]102X`N`@0:O0j`030000002W`>/0
Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002<0oooo00<000000?ooo`3oool09P3oool40:Fo
k0@0V;ca00<0?iKb0002PP2^[]L00`2^[]L30=Bb]P@0e[6c00<0f;>c0=V`[P3I/:h00`3M/Z`30>>h
Z`@0i;j`0P3U`[@30>73^PH0^kGD0`2T[=`40:6bi0@0Z[KQ0`2a/mX50:Zki@<0/;[Q1@2V_>T40:Vo
jP@0Y[WW102U^nT40:Vli`@0Z;[V1@2W`^d<0:NiiPD0Yl;]102W^NH40:Jii`@0YkgY102W^nP40:Fi
i`@0YK[X102S]^H309nai@D0UZGP0`2CYN8309jlkP<0/ngg00<0^NKd0:k<l02^c?000P2^c?040:[4
kA@0Yl3[00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2000002L0
oooo1@2V_n`409Zll0030002PP2^[]L0[ZkG0080[ZkG00<0e;:f0=Ja/`3F/K<00P3F/K<20=Rc/`80
fK2^0`3M/Z`30>>hZ`030>W1Z`3T_[00i;j`00<0iL:d0`3Q`kX00`3L`Kh0^kGD0;^ee0030;^ee0@0
XJkQ102Q/^@30:Zfh@@0Y[WW102Z^nD40:Jjj0@0Y[cY1@2W^^L40:Jii`@0ZKoY102Y_>L50:K1k0@0
Z;WV1`2W^NH50:O2k@T0YkWV102W_n/40:Nmj@<0Yk_X1@2U_>T40:Fjj0@0Wk3T0`2L[><409JUh0@0
TjGR00<0/ngg0;Sel@2hmO400P2hmO420;CKm0@0[/c`102X`N/D0:O0j`030000002W`>/0Yl3[00/0
Yl3[0`3oool00`000000oooo0?ooo`030?ooo`009P3oool00`000000oooo0?ooo`0U0?ooo`D0Y[o/
102L_O0010000X80[ZkG0:j^e`2^[]L50=Ja/`<0f;>c00@0fK2^0=fb[03M/Z`0gK:/0`3S^:/20>W1
Z`<0iL:d0`3Q`kX30=c1_P80^kGD0`2i]=@40:6^h@@0X[CU0`2T^>L40:Jii`@0Yk_W102V^^P40:Rl
j0@0Yk[W1@2X`>/40:Voj@D0Y[k[102X^^H40:RiiP<0YkWV1@2W`^d80:NiiPD0Yl3/102W_n/40:Fi
i`<0YK_Y102U_>T50::bi0@0Wk3T0`2L[><309JUh0@0XlWc0`2_mO440;CKm0D0Z<;/102X`N/D0:O0
j`030000002W`>/0Yl3[00H0Yl3[203oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000
oooo0?ooo`0U0?ooo`D0Y[o/102L_O040:>_h@<0e[6c103H/k<30=fb[0<0hkR[0`3Y`J/20>g6[@@0
hL>j0`3L`Kh50;Vde0D0Y[7P102R]>D30:Bhi`@0Yk[W102W^nL40:Rmj@@0Z;cX1@2W_n/30:S0j`D0
Y[cY1@2Y_>L40:RjiP<0Z;WV1@2W`^d80:NiiP@0Yl7/102W`>`50:JhiP<0YKWW102U^nT40:Bdi0@0
X[;T102O/>@409NRg@@0Uj[T0`2_mO430;K/mP@0ZlK^102X`^`H0:O0j`030000002W`>/0Yl3[00<0
Yl3[2`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`0V0?ooo`@0Y[o/
102M_Nl30:>_h@<0e[6c103H/k<00`3J^;L0gK:/0=fb[0030>>hZ`<0jL6[0P3]aZd00`3/b;00hL>j
0>73^P040=c1_P040=Rn`02i]=@0^KCD0;Vde080^kCC102V/N050:Ffi0<0YKWW102W^^L40:Nlj0@0
Z;gY1@2V_>T40:Rki`@0Yk[W102Y_^T40:Vli`D0Yl3[0`2W`N`50:RiiP@0YkWV202W`N`40:Jgi@@0
Y[SV102W_>P40:JhiP@0Y;CT102Q/><409fXgP@0Uj;M0P2GZ^@20:STn`80]^cf102^c_440:_6kQ`0
Yl3[00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00:@3oool2000002L0oooo
102V_n`409fmk`<0XjoQ00<0e[6c0=Rc/`3H/k<00P3H/k<30=Zh]`040=fb[03S^:/0hkR[0>>hZ`80
jL6[0`3]aZd20>c8/0@0g<6n0`3H_/050;^dd`@0Zk?N102U]^@40:Fii`@0Yk[W102W_>P40:Nkj0<0
Y[cY0P2Y_>P40:Rki`@0Z;oZ102Y_^T40:NnjP@0Yl3[202X^NH90:O1k0@0YkOU102V]nD40:NnjP@0
YkcX0`2V^>H50::di@@0XK3S0`2MZ=h409NRg@040:STn`2^mO40[_Ga0:kel@<0/][e0`2^c_450:S1
jaT0Yl3[0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000[0?ooo`03
0000003oool0oooo02D0oooo102V_n`309jnk`<0XjoQ103H/k<40=Zh]`<0hkR[0`3Y`J/20>g6[@<0
k<R`00<0j/Rc0=c1_P3L`Kh0103H_/00103E_L80^kCC0;^dd`2k]=<20;fed@@0Zk?N0`2U]^@50:Ni
iP@0Yk[W102X^nL40:Nkj0D0ZKcX102X_^X40:RojP@0YkcX102W_^X40:RjiP@0Z;WV202W`N`50:Nh
i@@0YkOU102W_n/40:NnjP@0Y;CT0`2S]ND40::di@@0XK3S102HYn0309fol080XO?`1@2bf_D40:S2
k0@0Z<7[5@2W`>/80?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002`0
oooo00<000000?ooo`3oool09@3oool50:K0k080W[k_0`20[?030=Rc/`@0f[Rg00<0gL6m0>>hZ`3S
^:/00`3Y`J/20>g6[@<0k<R`0P3Zb;<40=Rn`0<0eKg200<0^kCC0;fed@2m]M400P2m]M430:^cgP@0
Z;KS102W^NH90:Rki`@0ZKgX1@2W_>P40:RnjP@0Yk[W102W_>P40:Vli`@0Z;[V102W`>`40:O1k0P0
YkSU1@2W`>/30:Noj`D0YK?R102T]>@30:>ei@@0WjCI102JX=T409RWh0030:7cl02bjOP0/^Wh00<0
/^Wh1@2ZaNh30:S2k1D0Yl3[2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo000]0?ooo`030000003oool0oooo02H0oooo102V`>`209nnkP<0P:c`00<0f;>c0=Zh]`3J^;L0
0P3J^;L30=g1_@030>>hZ`3Y`J/0jL6[00<0kLJ]0P3/b;030>[8/`030>O8^03H_/00f;k000@0eKg2
1@2m]M440;2dg0@0Z;KS102Y^ND30:Rki`80ZK[V102X_>L40:Rki`@0YkcX1@2Y^nH40:Nji`@0ZKgX
102Y_>L40:Noj`@0Yl3/102X^>D40:Nhi@P0Yl3[102V/n840:FchP@0Y;CT102S[=d409nTf@<0VZ3I
102Nj?/20:Sbm0D0[<_`6@2W`>/?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0@3oool002h0oooo00<000000?ooo`3oool09P3oool40:K0k080XKk^0P0QQNX40=Zh]`@0gL6m0`3Y
`J/20>g6[@<0k<R`0`3Zb;<20>O8^0D0eKg200@0dkc40;fed@2m]M40_KGA0P30]]040;2dg0@0ZkOQ
102Y^ND50:VjiP@0ZK_V102X^nL40:Zli`@0ZK_V1@2Y_^T30:Vmj0D0YkgY102W_n/80:Rhi@P0Yl3[
102W/n840:JchP@0Y[SV102U/n840:>/g@<0WjCI1@2Mc?P00`2Xl_@0[]?d0:kCm0030:kCm0@0Z<7/
502W`>/D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool002l0oooo0P00
000W0?ooo`@0Yl3/0P2Q_^h20265jP<0f[Rg103M`Kd20>3<a0<0kLJ]0P3/b;030>[8/`<0ilRh00@0
i<Vm0=Fm`P3E_L80eKg20`3C_<@50<2fd0@0/kGI102[]n450:^ih`@0Zk[U102Y^nH80:Zli`@0ZKgY
102Y_^T40:Nki`@0YkgY1@2X^ND30:Rhi@T0Yl3[102W]>840:NchP@0Y[_X102V^>H30:FchP@0XjcM
102K/^L209Kaj`D0[]cg102Y`nd40:S1k100Yl3[603oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo02D0oooo102W`>`30::nk@030265jP3J
^;L0gL6m00<0gL6m0`3Pc<@00`3SeLT0kLJ]0>g6[@020>c8/0<0j/Rc0P3Wb;P30>C9_@030=Fm`P3C
_<@0dkc40080dkc400@0d[g60<2fd030]]00`;K@0P32]/l40;>ef@@0[kOO0`2[^N<20:fhhP@0Zk[U
102Z^nH40:Zli`@0Z;_W102Y_NT40:RiiP@0Yk_W102Y^^H40:Rii@@0Z;o[102W`>/80:NdhPD0Y[cY
102V^nP30:JhiP@0WYoD102LY=/209^bi`0408S[jP2[i_X0ZnKj0:_VnPD0Z/K^0`2Y`nd50:O1k0/0
Yl3[703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000b0?ooo`030000
003oool0oooo02D0oooo102W`>/30::nk@@0gL6m0`3Pc<@30>?Eb@80k<R`0`3Zb;<30>O8^0<0i<Vm
103C_<@30=:maP030<2fd032]/l0`[K?0080`[K?102g]ML40:ngg`D0[KSR102/^N<40:ZkiP@0ZK[U
102X^nL40:Vji@@0Z;WV102Z_>L40:VjiP@0Z;kZ102X_n/40:Rdh@@0YkCR102W_>T40:Jlj@D0Xj3B
0`2QWm8409jOe0<0W:CK00<0R>_Z0:_VnP2[i_X00P2[i_X20:[:l@@0Z/K^102W`>/40:O1k0@0Yko[
102W`>/P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool003<0oooo00<0
00000?ooo`3oool09@3oool40:O0j`<0Xko]0P3M`Kd30>3<a0<0hmG90`3Ufl/00`3Tgll0j/Rc0>[8
/`020>O8^0@0i<Vm00<0h<_40=>la03C_<@0103B_LH40<:fc`80a;O>102g]ML40;6fg0<0[KSR0P2_
]ml80:bih`@0ZK[U102[^nD40:Vji@@0Z[gW102Z_>L40:Rlj0@0Z;kZ202X]>440:Nlj0@0YkcY102T
X]<40:>PdP<0XIoB102NWm@00`2;j?H0X^gh0:;]n0030:;]n0D0Z/[a102W_n/40:O0j`P0Yko[903o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000d0?ooo`8000009P3oool5
0:O0j`80Xko]0`3Pc<@30>?Eb@<0iM_;0`3Tgll30>O8^0<0i<Vm0`3Pbl@40=:maP80d;o90P32]/l4
0<BgcP80]kGG0P2j]M@40;6fg0D0[kOO102^^>440:bih`@0[;_T102[^nD40:Zli`@0Z[gW102X^ND4
0:Rlj0@0ZKCQ102X]>440:Rlj0@0YkcX102UXm<40:BRd`<0Xj3B0`2QWm8209GNoPD0T^ga102Zc_<5
0:Roj`<0Yko[1@2X`>/30:NojbT0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`01
0?ooo`00=P3oool00`000000oooo0?ooo`0U0?ooo`@0Yl3[0`2T_nd30>?Eb@<0iM_;0`3Tgll30=oS
e`<0i<Vm0`3Pbl@20=_?c080d[g6103@_lT50<BgcPD0^[GD102d]=P20:ngg`<0/KGK0`2^^>450:bh
h@<0[;_T1@2Z^N@30:Zli`D0ZKKS0`2X^ND50:ZfhP@0ZKCQ102X^nL40:Rlj0@0YZCC102UXm<30:BR
d`<0Xj3B102Ld?X207kWiPD0ZM7e102X`N/40:Roj`@0Z<7/102X`>//0?ooo`030000003oool0oooo
00L0oooo0@0000010?ooo`40oooo000g0?ooo`030000003oool0oooo02D0oooo102W`>/40:Fok0<0
iM_;0`3Tgll30=oSe`<0e^OR0`3Pbl@40=_?c0@0d;o90P3?`ll20<BgcP<0aK[?0P2j]M@30;fedP<0
];CH1@2a]M/20:jhh@80[kCL102/^>440:bfh0@0Z[WT102[]N440:Vfh`@0ZkSR102Z]^850:Vii@<0
Z;_W1@2VXm830:JTd`@0YJ?C102S^nX40:33l@0307kWiP2Xe?L0Z=Cg00<0Z=Cg102X`n`40:S1j`D0
Yl;/0`2X`N``0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo000h0?ooo`030000
003oool0oooo02D0oooo102W`>/30:Fok080WKk_0P3Tgll40=oSe`80e^OR0`33j_000`3Pbl@0flo<
0=_?c0020=_?c080e=GI0P3@_lT30<o3c`D0aK[?1@2m]M820;Bdf080]k?E102a]M/90:ndg0@0[;KP
102]]Ml40:^eh@@0[;SR102[^>840:Vdh@@0ZKWU102WX]440:JSdP<0YZCC1@2U^>H30:>kjP80K=kL
1@2WeoP40:S4kP@0Z<?/102W`N`h0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
000i0?ooo`8000009P3oool30:O0j`@0Y[o/102M_^l00`1c/_P0e^OR0=KWhP050<?Zl0@0flo<0`3D
eMT40<o3c`80c<_I0`35^/l20<Joe0@0_KGB1@2g/mD40;Bbe`<0[kCL0P2b/]P40:ndg0@0[k?L102]
]Ml40:bdg`@0[;SR102Y[]/40:Vdh@@0Z:;@102WX]430:JSdP@0YkWV102U^>H205oGeP@0Y=Sj1@2X
a^l30:S4kPD0Yl3[>`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>`3oool0
0`000000oooo0?ooo`0T0?ooo`@0Yl3[0`2V_n`50::okP<0RKWf1@2Oi_`40=CEf@80a]kZ0P3?`ll4
0<c;f@030<Fjc`36_m@0a[oD0080a[oD0P2m]M820;nie0<0]k?E0P2j]]D40;Bbe`D0/[;H0P2_]=`2
0;2`e`@0[k?L102][]T40:bdg`@0ZZWE102Y[]/40:^Ud@@0Z:;@0`2WX]440:Zmj0@0YkWV00<0Em;B
0:;In`2RfO/00`2RfO/50:O7l0@0YkkZ102W_n/o0?ooo`030000003oool0oooo00@0oooo0@000001
0?ooo`40oooo000l0?ooo`030000003oool0oooo02@0oooo102W`>/40:K0k0@0Y;o]102G_O8206>_
nP<0G/gg1@36g^X50<c;f@D0a[oD1@2o^M@50;Zfe@@0]kCF102b/]P50;2`e`80[k?L0P2_[MD40:f^
f@@0[JSC102ZZMD40:j/e@@0ZjGA0`2XX]040:_6k@@0Z[gX00<0DLk@09oHn`2Of?/00`2Of?/50:O7
l@@0YkkY102W_^Y30?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`40oooo000m0?ooo`03
0000003oool0oooo02@0oooo202W`>/40:Bok@@0X;o_1026^_L00`0cWO8007>h0:3Ro0040:3Ro0@0
`MS[0`36_m@20<?<hP<0_kWD0P30aMh30;Zfe@80_L;N102g]=H40;FceP@0/;3G1@2_[MD20:f^f@80
/[7G0`2]Z=<20:ZYe@<0/k[N0`2^[=D40:^Ud@@0Z]?f102[a^d309gCn`<0WMKk102Vao480:NnjDP0
oooo00<000000?ooo`3oool00P3oool100000040oooo0@3oool003h0oooo0P00000U0?ooo`P0Yl3[
102V`>`40:2ok`@0VKka0`1a]_/504g3l@<0`MS[1@33c>850<35gPD0_L;N0P2g]=H20;_3h@@0]K?F
102e]MT40:n]e@@0/[7G0`2]Z=<50;>jgP<0[ZcE1@2Ph_`204_:e`@0WM3j1@2VaO030:K7l@@0YkgY
102W_^U;0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00@03oool00`000000oooo0?oo
o`0S0?ooo`P0Yl3[102V`>`50:Bok@<0VKka102A_O@405ncn`0400jDgP2Dgoh0U=on09COoPD0Zmoi
102`gOL40;g2gPD0^l?Q0P2e/mH20;W=jP<0]KGI1@2ga^D30;:ae`@0/m7`102c^]h508?TmP80E<oU
102NcOP40:G4k`@0Y/G`102X_^T40:NmjDl0oooo00<000000?ooo`3oool00P3oool100000040oooo
00110?ooo`030000003oool0oooo02<0oooo3@2W`>/40:K0k0@0X[o^0`2A_O@408bmm`<0F;Ck0P0G
WMl504g6kP<0/=gg102[goT40;_3h@@0^LgZ102Xh_X40;O6i@D0VnKl0`2cdO0205WBh00403g1e@1i
e?h0NMCn07WDoPD0Wl[f102V`^h40:G4k`P0Z;kYD`3oool01@000000oooo0?ooo`3oool000000040
oooo00120?ooo`030000003oool0oooo02@0oooo302W`>/80:K0k0<0X;o_102O_nl408bnm`<0G;Sl
0`0SYn@304k8k@<0Zmoi1@2Gi?d5067DkP<0Z>;j1@1KdnP204C3iP0406;;n`2Dbo/0U<_k09C;n`@0
XlCa102Qao<40:K0k0@0Y/;^102X_^X40:RnjEL0oooo00@000000?ooo`3oool000000@3oool004<0
oooo0P00000U0?oooa00Yl3[0`2V`>`40:G0k0@0Wko_1@2P_nl30930m`D0Ul7d0`1n`_d50973n0<0
M/Ko102Ca_T40:72l@@0VlKe102T`^h40:?4l@@0Y[o[102V`>`40:Roj`@0Z;kZFP3oool010000000
oooo0?ooo`0000010?ooo`00A@3oool00`000000oooo0?ooo`0S0?oooa@0Yl3[202U`>`40:K0k0@0
X/3^102T`>d409k1l@@0Xl3^0`2M`_840:C1kP@0XL;a102U`>`40:C2kPD0Yko[0`2V_n/40:S1jf80
oooo00<000000?ooo`0000000@3oool004H0oooo00<000000?ooo`3oool08`3ooolL0:O0j`P0Y/3/
0`2T`>d50:K0k0<0Xl3^102V`>`40:C1kPD0Yl3/0`2U`>`40:S0j`D0Yl7/0`2X`NaV0?ooo`400000
0@3oool100000000A`3oool00`000000oooo0?ooo`0S0?ooob00Yl3[0`2V`>`40:O0j`@0Y/3/1@2W
`>/30:K0k0`0Yl3[102W`>`40:O1k6X0oooo0P00000004P0oooo0P00000U0?ooocX0Yl3[102W_n/4
0:O0k6d0oooo0P00000004X0oooo00<000000?ooo`3oool08`3ooolf0:O0j`P0Yko[L03oool20000
0000B`3oool00`000000oooo0?ooo`0R0?ooocP0Yl3[0`2W_n]_0?ooo`@000000P3oool004`0oooo
00<000000?ooo`3oool08`3ooolc0:O0jg40oooo100000060?ooo`00C@3oool2000002@0oooo;`2W
`>]`0?ooo`@000002P3oool004l0oooo00<000000?ooo`3oool08P3oool[0:O0jfl0oooo1000000>
0?ooo`00D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo001A0?ooo`03
0000003oool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580oooo0P00000T0?oooah0Yl3[
K@3oool4000001T0oooo001D0?ooo`030000003oool0oooo0280oooo5`2W`>]_0?ooo`@000007@3o
ool005D0oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00EP3oool00`00
0000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?ooo`8000008`3oool;0:O0jf`0
oooo1000000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool3000002d0oooo
001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool400000300oooo001K
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0oooo001L0?oo
o`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool005h0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00000L0?ooo`030000003oool0
oooo05<0oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0
oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04L0oooo
1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0oooo1000
001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03oool3000005/0oooo001Y0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4000005h0oooo001Z0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?ooo`800000403o
ool00`000000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`030000003oool0oooo0280oooo
1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo1000
001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000021
0?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo100000250?oo
o`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`050000003oool0
oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003oool0103oool4
000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3oool200000:00
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.49382 .66833 .49998 .67414 .51113 .67099 .50499 .66517 Mtetra
.656 .752 .92 r
.50499 .66517 .51113 .67099 .52232 .66785 .51621 .66198 Mtetra
.656 .751 .92 r
.51621 .66198 .52232 .66785 .53355 .66468 .52747 .65879 Mtetra
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Mtetra
.655 .751 .92 r
.53878 .65559 .54483 .6615 .55616 .65827 .55014 .65239 Mtetra
.655 .753 .922 r
.55014 .65239 .55616 .65827 .56753 .65506 .56155 .64918 Mtetra
.656 .754 .922 r
.56155 .64918 .56753 .65506 .57895 .65188 .573 .64591 Mtetra
.657 .752 .92 r
.573 .64591 .57895 .65188 .59042 .64872 .5845 .6426 Mtetra
.657 .748 .917 r
.5845 .6426 .59042 .64872 .60194 .6455 .59604 .63931 Mtetra
.655 .746 .917 r
.59604 .63931 .60194 .6455 .6135 .64223 .60764 .63608 Mtetra
.653 .747 .919 r
.60764 .63608 .6135 .64223 .62511 .63891 .61929 .63288 Mtetra
.651 .752 .923 r
.61929 .63288 .62511 .63891 .63677 .63557 .63098 .62969 Mtetra
.651 .757 .927 r
.63098 .62969 .63677 .63557 .64848 .63222 .64273 .62647 Mtetra
.651 .763 .931 r
.64273 .62647 .64848 .63222 .66023 .62888 .65452 .62321 Mtetra
.652 .767 .933 r
.65452 .62321 .66023 .62888 .67204 .62555 .66637 .6199 Mtetra
.654 .769 .934 r
.66637 .6199 .67204 .62555 .68389 .62221 .67826 .61652 Mtetra
.655 .769 .933 r
.67826 .61652 .68389 .62221 .6958 .61888 .6902 .61309 Mtetra
.657 .767 .93 r
.6902 .61309 .6958 .61888 .70776 .61556 .70218 .6096 Mtetra
.659 .763 .926 r
.70218 .6096 .70776 .61556 .71977 .61223 .71422 .60607 Mtetra
.66 .757 .922 r
.71422 .60607 .71977 .61223 .73183 .6089 .7263 .60251 Mtetra
.659 .75 .917 r
.7263 .60251 .73183 .6089 .74394 .6055 .73844 .59898 Mtetra
.657 .746 .915 r
.73844 .59898 .74394 .6055 .7561 .60204 .75064 .5955 Mtetra
.655 .746 .916 r
.75064 .5955 .7561 .60204 .7683 .59851 .76289 .59207 Mtetra
.654 .749 .92 r
.76289 .59207 .7683 .59851 .78056 .59497 .77519 .58865 Mtetra
.655 .754 .923 r
.77519 .58865 .78056 .59497 .79288 .59147 .78755 .58516 Mtetra
.656 .756 .923 r
.78755 .58516 .79288 .59147 .80525 .58804 .79995 .58162 Mtetra
.657 .754 .921 r
.79995 .58162 .80525 .58804 .81768 .5846 .81241 .57805 Mtetra
.656 .75 .919 r
.81241 .57805 .81768 .5846 .83015 .58108 .82493 .57451 Mtetra
.655 .75 .919 r
.82493 .57451 .83015 .58108 .84268 .57752 .8375 .57096 Mtetra
.656 .751 .92 r
.8375 .57096 .84268 .57752 .85526 .57397 .85012 .56739 Mtetra
.656 .752 .921 r
.85012 .56739 .85526 .57397 .8679 .57041 .8628 .56379 Mtetra
.656 .751 .92 r
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Mtetra
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Mtetra
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66517 .4988 .65928 Mtetra
.4988 .65928 .50499 .66517 .51621 .66198 .51005 .65608 Mtetra
.51005 .65608 .51621 .66198 .52747 .65879 .52135 .65288 Mtetra
.656 .752 .921 r
.52135 .65288 .52747 .65879 .53878 .65559 .53269 .64965 Mtetra
.53269 .64965 .53878 .65559 .55014 .65239 .54408 .64641 Mtetra
.654 .751 .921 r
.54408 .64641 .55014 .65239 .56155 .64918 .55551 .6432 Mtetra
.651 .751 .923 r
.55551 .6432 .56155 .64918 .573 .64591 .567 .64006 Mtetra
.646 .755 .928 r
.567 .64006 .573 .64591 .5845 .6426 .57853 .63703 Mtetra
.642 .764 .937 r
.57853 .63703 .5845 .6426 .59604 .63931 .59012 .63405 Mtetra
.638 .774 .946 r
.59012 .63405 .59604 .63931 .60764 .63608 .60176 .63108 Mtetra
.635 .784 .953 r
.60176 .63108 .60764 .63608 .61929 .63288 .61345 .62809 Mtetra
.633 .793 .959 r
.61345 .62809 .61929 .63288 .63098 .62969 .62519 .62509 Mtetra
.632 .801 .964 r
.62519 .62509 .63098 .62969 .64273 .62647 .63698 .62204 Mtetra
.632 .808 .967 r
.63698 .62204 .64273 .62647 .65452 .62321 .64882 .6189 Mtetra
.635 .815 .969 r
.64882 .6189 .65452 .62321 .66637 .6199 .6607 .61565 Mtetra
.639 .82 .97 r
.6607 .61565 .66637 .6199 .67826 .61652 .67264 .61226 Mtetra
.644 .822 .968 r
.67264 .61226 .67826 .61652 .6902 .61309 .68462 .60874 Mtetra
.649 .821 .966 r
.68462 .60874 .6902 .61309 .70218 .6096 .69664 .6051 Mtetra
.654 .817 .962 r
.69664 .6051 .70218 .6096 .71422 .60607 .70871 .60138 Mtetra
.658 .812 .957 r
.70871 .60138 .71422 .60607 .7263 .60251 .72082 .5976 Mtetra
.661 .805 .952 r
.72082 .5976 .7263 .60251 .73844 .59898 .73299 .59377 Mtetra
.663 .795 .945 r
.73299 .59377 .73844 .59898 .75064 .5955 .7452 .58992 Mtetra
.664 .783 .937 r
.7452 .58992 .75064 .5955 .76289 .59207 .75747 .58608 Mtetra
.663 .769 .929 r
.75747 .58608 .76289 .59207 .77519 .58865 .76979 .58231 Mtetra
.66 .757 .922 r
.76979 .58231 .77519 .58865 .78755 .58516 .78217 .57865 Mtetra
.657 .751 .92 r
.78217 .57865 .78755 .58516 .79995 .58162 .79461 .57508 Mtetra
.656 .751 .92 r
.79461 .57508 .79995 .58162 .81241 .57805 .80711 .57153 Mtetra
.656 .752 .921 r
.80711 .57153 .81241 .57805 .82493 .57451 .81966 .56795 Mtetra
.81966 .56795 .82493 .57451 .8375 .57096 .83227 .56435 Mtetra
.656 .752 .92 r
.83227 .56435 .8375 .57096 .85012 .56739 .84493 .56074 Mtetra
.656 .751 .92 r
.84493 .56074 .85012 .56739 .8628 .56379 .85765 .55712 Mtetra
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Mtetra
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54248 Mtetra
.90908 .54248 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94825 .53132 Mtetra
.94825 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Mtetra
.48134 .65658 .4876 .66248 .4988 .65928 .49257 .65337 Mtetra
.655 .751 .921 r
.49257 .65337 .4988 .65928 .51005 .65608 .50385 .65015 Mtetra
.654 .751 .921 r
.50385 .65015 .51005 .65608 .52135 .65288 .51518 .64695 Mtetra
.652 .752 .923 r
.51518 .64695 .52135 .65288 .53269 .64965 .52655 .64381 Mtetra
.645 .753 .928 r
.52655 .64381 .53269 .64965 .54408 .64641 .53797 .64081 Mtetra
.635 .76 .938 r
.53797 .64081 .54408 .64641 .55551 .6432 .54944 .63802 Mtetra
.622 .772 .952 r
.54944 .63802 .55551 .6432 .567 .64006 .56097 .63543 Mtetra
.603 .788 .969 r
.56097 .63543 .567 .64006 .57853 .63703 .57255 .63304 Mtetra
.577 .806 .986 r
.57255 .63304 .57853 .63703 .59012 .63405 .58419 .63084 Mtetra
.54 .826 .998 r
.58419 .63084 .59012 .63405 .60176 .63108 .59588 .62874 Mtetra
.494 .842 .996 r
.59588 .62874 .60176 .63108 .61345 .62809 .60764 .62661 Mtetra
.442 .847 .971 r
.60764 .62661 .61345 .62809 .62519 .62509 .61945 .62431 Mtetra
.398 .842 .933 r
.61945 .62431 .62519 .62509 .63698 .62204 .63131 .62175 Mtetra
.372 .835 .897 r
.63131 .62175 .63698 .62204 .64882 .6189 .64321 .6189 Mtetra
.366 .834 .876 r
.64321 .6189 .64882 .6189 .6607 .61565 .65516 .61577 Mtetra
.378 .842 .871 r
.65516 .61577 .6607 .61565 .67264 .61226 .66715 .61235 Mtetra
.406 .858 .879 r
.66715 .61235 .67264 .61226 .68462 .60874 .67918 .60867 Mtetra
.449 .88 .899 r
.67918 .60867 .68462 .60874 .69664 .6051 .69124 .60468 Mtetra
.506 .904 .928 r
.69124 .60468 .69664 .6051 .70871 .60138 .70334 .60041 Mtetra
.57 .92 .958 r
.70334 .60041 .70871 .60138 .72082 .5976 .71547 .59586 Mtetra
.624 .919 .978 r
.71547 .59586 .72082 .5976 .73299 .59377 .72764 .59115 Mtetra
.658 .899 .981 r
.72764 .59115 .73299 .59377 .7452 .58992 .73985 .58641 Mtetra
.673 .868 .973 r
.73985 .58641 .7452 .58992 .75747 .58608 .75211 .58176 Mtetra
.676 .838 .961 r
.75211 .58176 .75747 .58608 .76979 .58231 .76443 .57728 Mtetra
.674 .811 .948 r
.76443 .57728 .76979 .58231 .78217 .57865 .77681 .57301 Mtetra
.669 .787 .937 r
.77681 .57301 .78217 .57865 .79461 .57508 .78926 .56893 Mtetra
.664 .769 .928 r
.78926 .56893 .79461 .57508 .80711 .57153 .80178 .56507 Mtetra
.659 .758 .923 r
.80178 .56507 .80711 .57153 .81966 .56795 .81436 .56135 Mtetra
.657 .753 .921 r
.81436 .56135 .81966 .56795 .83227 .56435 .827 .5577 Mtetra
.656 .752 .92 r
.827 .5577 .83227 .56435 .84493 .56074 .8397 .55405 Mtetra
.8397 .55405 .84493 .56074 .85765 .55712 .85246 .55039 Mtetra
.656 .751 .92 r
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54672 Mtetra
.86527 .54672 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54248 .90406 .53563 Mtetra
.90406 .53563 .90908 .54248 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94825 .53132 .94336 .52438 Mtetra
.94336 .52438 .94825 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Mtetra
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Mtetra
.655 .751 .92 r
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65065 Mtetra
.654 .751 .921 r
.47503 .65065 .48134 .65658 .49257 .65337 .48629 .64745 Mtetra
.651 .752 .924 r
.48629 .64745 .49257 .65337 .50385 .65015 .4976 .64434 Mtetra
.642 .753 .93 r
.4976 .64434 .50385 .65015 .51518 .64695 .50895 .64144 Mtetra
.624 .759 .944 r
.50895 .64144 .51518 .64695 .52655 .64381 .52036 .6389 Mtetra
.592 .773 .966 r
.52036 .6389 .52655 .64381 .53797 .64081 .53182 .63684 Mtetra
.539 .792 .991 r
.53182 .63684 .53797 .64081 .54944 .63802 .54333 .63526 Mtetra
.451 .806 .997 r
.54333 .63526 .54944 .63802 .56097 .63543 .55491 .63399 Mtetra
.339 .793 .948 r
.55491 .63399 .56097 .63543 .57255 .63304 .56655 .63269 Mtetra
.264 .768 .867 r
.56655 .63269 .57255 .63304 .58419 .63084 .57825 .63096 Mtetra
.283 .784 .844 r
.57825 .63096 .58419 .63084 .59588 .62874 .58999 .62856 Mtetra
.39 .846 .9 r
.58999 .62856 .59588 .62874 .60764 .62661 .60178 .62551 Mtetra
.517 .892 .967 r
.60178 .62551 .60764 .62661 .61945 .62431 .61361 .62202 Mtetra
.601 .886 .991 r
.61361 .62202 .61945 .62431 .63131 .62175 .62548 .61833 Mtetra
.637 .853 .982 r
.62548 .61833 .63131 .62175 .64321 .6189 .6374 .61462 Mtetra
.646 .823 .968 r
.6374 .61462 .64321 .6189 .65516 .61577 .64937 .61103 Mtetra
.644 .805 .96 r
.64937 .61103 .65516 .61577 .66715 .61235 .6614 .6076 Mtetra
.636 .803 .963 r
.6614 .6076 .66715 .61235 .67918 .60867 .67349 .60434 Mtetra
.623 .817 .975 r
.67349 .60434 .67918 .60867 .69124 .60468 .68564 .60119 Mtetra
.602 .845 .99 r
.68564 .60119 .69124 .60468 .70334 .60041 .69785 .59803 Mtetra
.569 .878 .993 r
.69785 .59803 .70334 .60041 .71547 .59586 .7101 .59465 Mtetra
.528 .898 .965 r
.7101 .59465 .71547 .59586 .72764 .59115 .72237 .5908 Mtetra
.506 .906 .92 r
.72237 .5908 .72764 .59115 .73985 .58641 .73466 .5863 Mtetra
.535 .922 .907 r
.73466 .5863 .73985 .58641 .75211 .58176 .74695 .58111 Mtetra
.608 .944 .938 r
.74695 .58111 .75211 .58176 .76443 .57728 .75925 .57548 Mtetra
.67 .935 .968 r
.75925 .57548 .76443 .57728 .77681 .57301 .77159 .56981 Mtetra
.692 .891 .97 r
.77159 .56981 .77681 .57301 .78926 .56893 .784 .56446 Mtetra
.689 .84 .956 r
.784 .56446 .78926 .56893 .80178 .56507 .79648 .55958 Mtetra
.677 .8 .94 r
.79648 .55958 .80178 .56507 .81436 .56135 .80905 .55519 Mtetra
.667 .773 .929 r
.80905 .55519 .81436 .56135 .827 .5577 .82171 .55116 Mtetra
.66 .759 .923 r
.82171 .55116 .827 .5577 .8397 .55405 .83444 .54735 Mtetra
.657 .753 .921 r
.83444 .54735 .8397 .55405 .85246 .55039 .84723 .54362 Mtetra
.656 .752 .92 r
.84723 .54362 .85246 .55039 .86527 .54672 .86008 .53992 Mtetra
.656 .751 .92 r
.86008 .53992 .86527 .54672 .87815 .54304 .873 .5362 Mtetra
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Mtetra
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65114 Mtetra
.655 .751 .921 r
.44623 .65114 .45265 .65707 .46381 .65386 .45743 .64792 Mtetra
.652 .751 .923 r
.45743 .64792 .46381 .65386 .47503 .65065 .46867 .64478 Mtetra
.643 .752 .928 r
.46867 .64478 .47503 .65065 .48629 .64745 .47996 .64185 Mtetra
.621 .756 .942 r
.47996 .64185 .48629 .64745 .4976 .64434 .49129 .63939 Mtetra
.576 .766 .969 r
.49129 .63939 .4976 .64434 .50895 .64144 .50267 .63764 Mtetra
.49 .781 .996 r
.50267 .63764 .50895 .64144 .52036 .6389 .51411 .63663 Mtetra
.351 .774 .975 r
.51411 .63663 .52036 .6389 .53182 .63684 .52561 .63597 Mtetra
.246 .749 .89 r
.52561 .63597 .53182 .63684 .54333 .63526 .53717 .63493 Mtetra
.316 .8 .887 r
.53717 .63493 .54333 .63526 .55491 .63399 .54879 .63277 Mtetra
.534 .894 .975 r
.54879 .63277 .55491 .63399 .56655 .63269 .56046 .62929 Mtetra
.676 .86 .969 r
.56046 .62929 .56655 .63269 .57825 .63096 .57215 .62486 Mtetra
.699 .768 .905 r
.57215 .62486 .57825 .63096 .58999 .62856 .58389 .62007 Mtetra
.688 .7 .856 r
.58389 .62007 .58999 .62856 .60178 .62551 .59567 .61539 Mtetra
.674 .661 .83 r
.59567 .61539 .60178 .62551 .61361 .62202 .6075 .61102 Mtetra
.663 .642 .818 r
.6075 .61102 .61361 .62202 .62548 .61833 .61938 .60697 Mtetra
.656 .633 .815 r
.61938 .60697 .62548 .61833 .6374 .61462 .63131 .60317 Mtetra
.652 .631 .816 r
.63131 .60317 .6374 .61462 .64937 .61103 .6433 .59957 Mtetra
.649 .629 .817 r
.6433 .59957 .64937 .61103 .6614 .6076 .65535 .5961 Mtetra
.645 .628 .818 r
.65535 .5961 .6614 .6076 .67349 .60434 .66746 .59279 Mtetra
.641 .625 .819 r
.66746 .59279 .67349 .60434 .68564 .60119 .67963 .58966 Mtetra
.635 .624 .821 r
.67963 .58966 .68564 .60119 .69785 .59803 .69186 .58678 Mtetra
.628 .626 .829 r
.69186 .58678 .69785 .59803 .7101 .59465 .70418 .58424 Mtetra
.621 .638 .846 r
.70418 .58424 .7101 .59465 .72237 .5908 .71657 .58201 Mtetra
.615 .672 .881 r
.71657 .58201 .72237 .5908 .73466 .5863 .72903 .5799 Mtetra
.615 .743 .937 r
.72903 .5799 .73466 .5863 .74695 .58111 .74154 .57742 Mtetra
.614 .847 .987 r
.74154 .57742 .74695 .58111 .75925 .57548 .75404 .57396 Mtetra
.603 .923 .97 r
.75404 .57396 .75925 .57548 .77159 .56981 .7665 .56914 Mtetra
.622 .95 .935 r
.7665 .56914 .77159 .56981 .784 .56446 .77893 .56317 Mtetra
.677 .954 .951 r
.77893 .56317 .784 .56446 .79648 .55958 .79136 .5568 Mtetra
.708 .914 .966 r
.79136 .5568 .79648 .55958 .80905 .55519 .80385 .55078 Mtetra
.699 .85 .955 r
.80385 .55078 .80905 .55519 .82171 .55116 .81645 .54551 Mtetra
.68 .798 .938 r
.81645 .54551 .82171 .55116 .83444 .54735 .82916 .54097 Mtetra
.666 .769 .927 r
.82916 .54097 .83444 .54735 .84723 .54362 .84197 .53691 Mtetra
.659 .757 .922 r
.84197 .53691 .84723 .54362 .86008 .53992 .85486 .53308 Mtetra
.657 .753 .921 r
.85486 .53308 .86008 .53992 .873 .5362 .86781 .52931 Mtetra
.656 .752 .92 r
.86781 .52931 .873 .5362 .88597 .53247 .88082 .52555 Mtetra
.656 .751 .92 r
.88082 .52555 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Mtetra
.655 .751 .92 r
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .6484 Mtetra
.654 .751 .921 r
.42858 .6484 .43508 .65435 .44623 .65114 .43976 .6452 Mtetra
.648 .751 .924 r
.43976 .6452 .44623 .65114 .45743 .64792 .45099 .64213 Mtetra
.632 .752 .934 r
.45099 .64213 .45743 .64792 .46867 .64478 .46225 .63947 Mtetra
.59 .757 .958 r
.46225 .63947 .46867 .64478 .47996 .64185 .47356 .63759 Mtetra
.497 .765 .991 r
.47356 .63759 .47996 .64185 .49129 .63939 .4849 .63674 Mtetra
.335 .753 .977 r
.4849 .63674 .49129 .63939 .50267 .63764 .49631 .63654 Mtetra
.224 .731 .893 r
.49631 .63654 .50267 .63764 .51411 .63663 .50779 .63589 Mtetra
.374 .828 .929 r
.50779 .63589 .51411 .63663 .52561 .63597 .51933 .63365 Mtetra
.637 .89 .986 r
.51933 .63365 .52561 .63597 .53717 .63493 .53093 .62954 Mtetra
.713 .792 .913 r
.53093 .62954 .53717 .63493 .54879 .63277 .54257 .62435 Mtetra
.7 .704 .851 r
.54257 .62435 .54879 .63277 .56046 .62929 .55425 .61915 Mtetra
.679 .662 .827 r
.55425 .61915 .56046 .62929 .57215 .62486 .56596 .6145 Mtetra
.666 .654 .828 r
.56596 .6145 .57215 .62486 .58389 .62007 .57773 .61043 Mtetra
.66 .666 .844 r
.57773 .61043 .58389 .62007 .59567 .61539 .58955 .60671 Mtetra
.659 .687 .865 r
.58955 .60671 .59567 .61539 .6075 .61102 .60143 .60314 Mtetra
.659 .708 .884 r
.60143 .60314 .6075 .61102 .61938 .60697 .61335 .5996 Mtetra
.658 .722 .896 r
.61335 .5996 .61938 .60697 .63131 .60317 .62533 .59608 Mtetra
.657 .731 .904 r
.62533 .59608 .63131 .60317 .6433 .59957 .63736 .59257 Mtetra
.656 .734 .907 r
.63736 .59257 .6433 .59957 .65535 .5961 .64944 .58909 Mtetra
.655 .734 .908 r
.64944 .58909 .65535 .5961 .66746 .59279 .66157 .58562 Mtetra
.654 .73 .905 r
.66157 .58562 .66746 .59279 .67963 .58966 .67376 .58218 Mtetra
.654 .722 .899 r
.67376 .58218 .67963 .58966 .69186 .58678 .686 .57874 Mtetra
.652 .706 .887 r
.686 .57874 .69186 .58678 .70418 .58424 .6983 .57534 Mtetra
.647 .684 .87 r
.6983 .57534 .70418 .58424 .71657 .58201 .71067 .57207 Mtetra
.637 .657 .853 r
.71067 .57207 .71657 .58201 .72903 .5799 .72311 .56916 Mtetra
.622 .635 .842 r
.72311 .56916 .72903 .5799 .74154 .57742 .73564 .56683 Mtetra
.607 .631 .849 r
.73564 .56683 .74154 .57742 .75404 .57396 .74828 .56508 Mtetra
.603 .668 .885 r
.74828 .56508 .75404 .57396 .7665 .56914 .76099 .56331 Mtetra
.621 .769 .951 r
.76099 .56331 .7665 .56914 .77893 .56317 .77369 .56043 Mtetra
.649 .9 .983 r
.77369 .56043 .77893 .56317 .79136 .5568 .7863 .55562 Mtetra
.671 .956 .947 r
.7863 .55562 .79136 .5568 .80385 .55078 .79883 .54916 Mtetra
.711 .956 .949 r
.79883 .54916 .80385 .55078 .81645 .54551 .81135 .54223 Mtetra
.721 .902 .96 r
.81135 .54223 .81645 .54551 .82916 .54097 .82397 .53597 Mtetra
.697 .831 .947 r
.82397 .53597 .82916 .54097 .84197 .53691 .83672 .53077 Mtetra
.674 .783 .932 r
.83672 .53077 .84197 .53691 .85486 .53308 .8496 .52638 Mtetra
.662 .761 .924 r
.8496 .52638 .85486 .53308 .86781 .52931 .86258 .52241 Mtetra
.657 .754 .921 r
.86258 .52241 .86781 .52931 .88082 .52555 .87563 .51857 Mtetra
.656 .752 .92 r
.87563 .51857 .88082 .52555 .89388 .52177 .88874 .51475 Mtetra
.656 .751 .92 r
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Mtetra
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Mtetra
.655 .751 .92 r
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64566 Mtetra
.653 .751 .921 r
.41087 .64566 .41745 .65163 .42858 .6484 .42203 .64246 Mtetra
.645 .751 .926 r
.42203 .64246 .42858 .6484 .43976 .6452 .43324 .63947 Mtetra
.619 .751 .94 r
.43324 .63947 .43976 .6452 .45099 .64213 .44448 .63707 Mtetra
.552 .754 .971 r
.44448 .63707 .45099 .64213 .46225 .63947 .45575 .63577 Mtetra
.402 .747 .993 r
.45575 .63577 .46225 .63947 .47356 .63759 .46706 .63568 Mtetra
.217 .708 .922 r
.46706 .63568 .47356 .63759 .4849 .63674 .47843 .63581 Mtetra
.291 .776 .911 r
.47843 .63581 .4849 .63674 .49631 .63654 .48989 .63447 Mtetra
.608 .89 .989 r
.48989 .63447 .49631 .63654 .50779 .63589 .50143 .6307 Mtetra
.719 .8 .914 r
.50143 .6307 .50779 .63589 .51933 .63365 .51302 .62532 Mtetra
.706 .708 .85 r
.51302 .62532 .51933 .63365 .53093 .62954 .52464 .61985 Mtetra
.684 .673 .833 r
.52464 .61985 .53093 .62954 .54257 .62435 .53631 .6151 Mtetra
.672 .678 .847 r
.53631 .6151 .54257 .62435 .55425 .61915 .54801 .61094 Mtetra
.67 .702 .871 r
.54801 .61094 .55425 .61915 .56596 .6145 .55977 .607 Mtetra
.671 .721 .887 r
.55977 .607 .56596 .6145 .57773 .61043 .57157 .60309 Mtetra
.67 .726 .892 r
.57157 .60309 .57773 .61043 .58955 .60671 .58342 .5992 Mtetra
.667 .721 .889 r
.58342 .5992 .58955 .60671 .60143 .60314 .59532 .59538 Mtetra
.664 .714 .886 r
.59532 .59538 .60143 .60314 .61335 .5996 .60727 .59166 Mtetra
.661 .709 .883 r
.60727 .59166 .61335 .5996 .62533 .59608 .61927 .58802 Mtetra
.658 .706 .882 r
.61927 .58802 .62533 .59608 .63736 .59257 .63133 .58445 Mtetra
.656 .704 .882 r
.63133 .58445 .63736 .59257 .64944 .58909 .64344 .58094 Mtetra
.654 .703 .883 r
.64344 .58094 .64944 .58909 .66157 .58562 .6556 .57747 Mtetra
.652 .703 .885 r
.6556 .57747 .66157 .58562 .67376 .58218 .66783 .57408 Mtetra
.649 .704 .887 r
.66783 .57408 .67376 .58218 .686 .57874 .68011 .57077 Mtetra
.646 .707 .892 r
.68011 .57077 .686 .57874 .6983 .57534 .69245 .56756 Mtetra
.643 .712 .898 r
.69245 .56756 .6983 .57534 .71067 .57207 .70485 .56443 Mtetra
.641 .716 .902 r
.70485 .56443 .71067 .57207 .72311 .56916 .71732 .56132 Mtetra
.64 .711 .898 r
.71732 .56132 .72311 .56916 .73564 .56683 .72984 .55823 Mtetra
.635 .689 .884 r
.72984 .55823 .73564 .56683 .74828 .56508 .74244 .55535 Mtetra
.618 .657 .865 r
.74244 .55535 .74828 .56508 .76099 .56331 .75514 .55308 Mtetra
.599 .637 .86 r
.75514 .55308 .76099 .56331 .77369 .56043 .76796 .55153 Mtetra
.597 .668 .889 r
.76796 .55153 .77369 .56043 .7863 .55562 .78085 .54989 Mtetra
.635 .782 .952 r
.78085 .54989 .7863 .55562 .79883 .54916 .79368 .54657 Mtetra
.687 .92 .971 r
.79368 .54657 .79883 .54916 .81135 .54223 .80636 .54076 Mtetra
.719 .963 .941 r
.80636 .54076 .81135 .54223 .82397 .53597 .81895 .53342 Mtetra
.738 .935 .952 r
.81895 .53342 .82397 .53597 .83672 .53077 .83159 .52631 Mtetra
.715 .859 .95 r
.83159 .52631 .83672 .53077 .8496 .52638 .84438 .52044 Mtetra
.683 .796 .935 r
.84438 .52044 .8496 .52638 .86258 .52241 .85733 .51571 Mtetra
.664 .765 .925 r
.85733 .51571 .86258 .52241 .87563 .51857 .8704 .5116 Mtetra
.658 .754 .921 r
.8704 .5116 .87563 .51857 .88874 .51475 .88354 .50769 Mtetra
.656 .752 .92 r
.88354 .50769 .88874 .51475 .90191 .51093 .89676 .50382 Mtetra
.656 .751 .92 r
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Mtetra
.655 .751 .92 r
.382 .64615 .38868 .65212 .39975 .64889 .3931 .6429 Mtetra
.653 .751 .922 r
.3931 .6429 .39975 .64889 .41087 .64566 .40425 .6397 Mtetra
.643 .75 .927 r
.40425 .6397 .41087 .64566 .42203 .64246 .41543 .63674 Mtetra
.61 .75 .944 r
.41543 .63674 .42203 .64246 .43324 .63947 .42664 .63452 Mtetra
.52 .748 .978 r
.42664 .63452 .43324 .63947 .44448 .63707 .43787 .63366 Mtetra
.321 .719 .98 r
.43787 .63366 .44448 .63707 .45575 .63577 .44914 .63413 Mtetra
.168 .683 .892 r
.44914 .63413 .45575 .63577 .46706 .63568 .46048 .63438 Mtetra
.411 .835 .962 r
.46048 .63438 .46706 .63568 .47843 .63581 .47193 .63233 Mtetra
.694 .857 .96 r
.47193 .63233 .47843 .63581 .48989 .63447 .48346 .62756 Mtetra
.723 .748 .872 r
.48346 .62756 .48989 .63447 .50143 .6307 .49505 .62169 Mtetra
.7 .692 .839 r
.49505 .62169 .50143 .6307 .51302 .62532 .50667 .6163 Mtetra
.685 .688 .846 r
.50667 .6163 .51302 .62532 .52464 .61985 .51832 .61162 Mtetra
.68 .705 .866 r
.51832 .61162 .52464 .61985 .53631 .6151 .53001 .60727 Mtetra
.676 .714 .877 r
.53001 .60727 .53631 .6151 .54801 .61094 .54174 .60311 Mtetra
.67 .713 .88 r
.54174 .60311 .54801 .61094 .55977 .607 .55353 .59919 Mtetra
.663 .712 .884 r
.55353 .59919 .55977 .607 .57157 .60309 .56536 .59549 Mtetra
.659 .717 .891 r
.56536 .59549 .57157 .60309 .58342 .5992 .57725 .59194 Mtetra
.657 .726 .9 r
.57725 .59194 .58342 .5992 .59532 .59538 .58918 .58844 Mtetra
.656 .736 .909 r
.58918 .58844 .59532 .59538 .60727 .59166 .60117 .58494 Mtetra
.656 .744 .915 r
.60117 .58494 .60727 .59166 .61927 .58802 .61321 .58141 Mtetra
.656 .748 .918 r
.61321 .58141 .61927 .58802 .63133 .58445 .6253 .57788 Mtetra
.655 .75 .92 r
.6253 .57788 .63133 .58445 .64344 .58094 .63745 .57434 Mtetra
.63745 .57434 .64344 .58094 .6556 .57747 .64965 .57079 Mtetra
.655 .748 .919 r
.64965 .57079 .6556 .57747 .66783 .57408 .6619 .56723 Mtetra
.655 .744 .915 r
.6619 .56723 .66783 .57408 .68011 .57077 .67421 .56365 Mtetra
.655 .737 .91 r
.67421 .56365 .68011 .57077 .69245 .56756 .68657 .56007 Mtetra
.654 .726 .902 r
.68657 .56007 .69245 .56756 .70485 .56443 .69898 .55653 Mtetra
.649 .714 .895 r
.69898 .55653 .70485 .56443 .71732 .56132 .71147 .55313 Mtetra
.642 .704 .892 r
.71147 .55313 .71732 .56132 .72984 .55823 .72402 .54997 Mtetra
.635 .7 .893 r
.72402 .54997 .72984 .55823 .74244 .55535 .73665 .54704 Mtetra
.628 .697 .894 r
.73665 .54704 .74244 .55535 .75514 .55308 .74935 .54431 Mtetra
.619 .682 .887 r
.74935 .54431 .75514 .55308 .76796 .55153 .76214 .54191 Mtetra
.6 .653 .874 r
.76214 .54191 .76796 .55153 .78085 .54989 .77506 .54023 Mtetra
.585 .646 .877 r
.77506 .54023 .78085 .54989 .79368 .54657 .78808 .53903 Mtetra
.61 .714 .919 r
.78808 .53903 .79368 .54657 .80636 .54076 .80109 .53669 Mtetra
.685 .865 .967 r
.80109 .53669 .80636 .54076 .81895 .53342 .81393 .53153 Mtetra
.737 .957 .944 r
.81393 .53153 .81895 .53342 .83159 .52631 .8266 .52398 Mtetra
.754 .947 .942 r
.8266 .52398 .83159 .52631 .84438 .52044 .83928 .51621 Mtetra
.729 .875 .949 r
.83928 .51621 .84438 .52044 .85733 .51571 .85212 .50981 Mtetra
.688 .803 .936 r
.85212 .50981 .85733 .51571 .8704 .5116 .86515 .50484 Mtetra
.666 .766 .925 r
.86515 .50484 .8704 .5116 .88354 .50769 .87832 .50063 Mtetra
.658 .755 .921 r
.87832 .50063 .88354 .50769 .89676 .50382 .89157 .49667 Mtetra
.656 .752 .92 r
.89157 .49667 .89676 .50382 .91003 .49995 .90488 .49275 Mtetra
.656 .751 .92 r
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Mtetra
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64013 Mtetra
.654 .751 .921 r
.37527 .64013 .382 .64615 .3931 .6429 .38639 .63691 Mtetra
.644 .75 .926 r
.38639 .63691 .3931 .6429 .40425 .6397 .39756 .63392 Mtetra
.609 .748 .943 r
.39756 .63392 .40425 .6397 .41543 .63674 .40875 .63171 Mtetra
.506 .741 .979 r
.40875 .63171 .41543 .63674 .42664 .63452 .41994 .63106 Mtetra
.274 .692 .969 r
.41994 .63106 .42664 .63452 .43787 .63366 .43116 .63196 Mtetra
.136 .66 .878 r
.43116 .63196 .43787 .63366 .44914 .63413 .44246 .63249 Mtetra
.466 .851 .981 r
.44246 .63249 .44914 .63413 .46048 .63438 .45389 .63018 Mtetra
.718 .833 .936 r
.45389 .63018 .46048 .63438 .47193 .63233 .46543 .62487 Mtetra
.727 .735 .857 r
.46543 .62487 .47193 .63233 .48346 .62756 .47702 .61864 Mtetra
.705 .696 .839 r
.47702 .61864 .48346 .62756 .49505 .62169 .48863 .61303 Mtetra
.692 .698 .851 r
.48863 .61303 .49505 .62169 .50667 .6163 .50027 .60813 Mtetra
.681 .707 .867 r
.50027 .60813 .50667 .6163 .51832 .61162 .51194 .60375 Mtetra
.671 .712 .879 r
.51194 .60375 .51832 .61162 .53001 .60727 .52366 .5998 Mtetra
.664 .721 .892 r
.52366 .5998 .53001 .60727 .54174 .60311 .53543 .59609 Mtetra
.662 .734 .903 r
.53543 .59609 .54174 .60311 .55353 .59919 .54725 .59242 Mtetra
.664 .743 .909 r
.54725 .59242 .55353 .59919 .56536 .59549 .55911 .5887 Mtetra
.55911 .5887 .56536 .59549 .57725 .59194 .57103 .58494 Mtetra
.663 .738 .905 r
.57103 .58494 .57725 .59194 .58918 .58844 .583 .5812 Mtetra
.661 .731 .901 r
.583 .5812 .58918 .58844 .60117 .58494 .59501 .57751 Mtetra
.659 .726 .898 r
.59501 .57751 .60117 .58494 .61321 .58141 .60708 .57387 Mtetra
.658 .723 .897 r
.60708 .57387 .61321 .58141 .6253 .57788 .61921 .57027 Mtetra
.656 .721 .896 r
.61921 .57027 .6253 .57788 .63745 .57434 .63138 .56669 Mtetra
.655 .72 .897 r
.63138 .56669 .63745 .57434 .64965 .57079 .64362 .56316 Mtetra
.653 .721 .898 r
.64362 .56316 .64965 .57079 .6619 .56723 .6559 .55966 Mtetra
.651 .723 .901 r
.6559 .55966 .6619 .56723 .67421 .56365 .66825 .55621 Mtetra
.649 .727 .906 r
.66825 .55621 .67421 .56365 .68657 .56007 .68065 .55281 Mtetra
.648 .732 .911 r
.68065 .55281 .68657 .56007 .69898 .55653 .69312 .54943 Mtetra
.648 .738 .915 r
.69312 .54943 .69898 .55653 .71147 .55313 .70564 .54601 Mtetra
.649 .739 .915 r
.70564 .54601 .71147 .55313 .72402 .54997 .71821 .54254 Mtetra
.648 .73 .909 r
.71821 .54254 .72402 .54997 .73665 .54704 .73084 .5391 Mtetra
.641 .713 .9 r
.73084 .5391 .73665 .54704 .74935 .54431 .74355 .5359 Mtetra
.628 .697 .894 r
.74355 .5359 .74935 .54431 .76214 .54191 .75635 .53315 Mtetra
.612 .681 .891 r
.75635 .53315 .76214 .54191 .77506 .54023 .76926 .53091 Mtetra
.592 .659 .884 r
.76926 .53091 .77506 .54023 .78808 .53903 .78229 .5294 Mtetra
.574 .644 .882 r
.78229 .5294 .78808 .53903 .80109 .53669 .79545 .5285 Mtetra
.596 .692 .91 r
.79545 .5285 .80109 .53669 .81393 .53153 .8086 .52665 Mtetra
.684 .837 .957 r
.8086 .52665 .81393 .53153 .8266 .52398 .82156 .52169 Mtetra
.757 .95 .941 r
.82156 .52169 .8266 .52398 .83928 .51621 .8343 .51377 Mtetra
.771 .948 .935 r
.8343 .51377 .83928 .51621 .85212 .50981 .84703 .50548 Mtetra
.736 .876 .945 r
.84703 .50548 .85212 .50981 .86515 .50484 .85994 .4988 Mtetra
.69 .801 .934 r
.85994 .4988 .86515 .50484 .87832 .50063 .87307 .49374 Mtetra
.665 .765 .924 r
.87307 .49374 .87832 .50063 .89157 .49667 .88634 .4895 Mtetra
.658 .754 .921 r
.88634 .4895 .89157 .49667 .90488 .49275 .89969 .4855 Mtetra
.656 .752 .92 r
.89969 .4855 .90488 .49275 .91826 .48882 .91311 .48153 Mtetra
.656 .751 .92 r
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Mtetra
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Mtetra
.654 .751 .921 r
.35737 .63735 .36418 .64339 .37527 .64013 .36848 .6341 Mtetra
.647 .75 .925 r
.36848 .6341 .37527 .64013 .38639 .63691 .37963 .63102 Mtetra
.617 .748 .939 r
.37963 .63102 .38639 .63691 .39756 .63392 .3908 .62866 Mtetra
.517 .737 .974 r
.3908 .62866 .39756 .63392 .40875 .63171 .40196 .62793 Mtetra
.267 .677 .968 r
.40196 .62793 .40875 .63171 .41994 .63106 .41313 .6291 Mtetra
.082 .617 .86 r
.41313 .6291 .41994 .63106 .43116 .63196 .42437 .63023 Mtetra
.435 .835 .979 r
.42437 .63023 .43116 .63196 .44246 .63249 .43577 .62829 Mtetra
.724 .834 .933 r
.43577 .62829 .44246 .63249 .45389 .63018 .44731 .62277 Mtetra
.737 .739 .853 r
.44731 .62277 .45389 .63018 .46543 .62487 .45891 .61606 Mtetra
.714 .702 .837 r
.45891 .61606 .46543 .62487 .47702 .61864 .47052 .61001 Mtetra
.695 .701 .851 r
.47052 .61001 .47702 .61864 .48863 .61303 .48215 .60494 Mtetra
.68 .709 .87 r
.48215 .60494 .48863 .61303 .50027 .60813 .49382 .6006 Mtetra
.671 .722 .887 r
.49382 .6006 .50027 .60813 .51194 .60375 .50552 .59663 Mtetra
.67 .734 .898 r
.50552 .59663 .51194 .60375 .52366 .5998 .51727 .59272 Mtetra
.669 .735 .9 r
.51727 .59272 .52366 .5998 .53543 .59609 .52907 .58883 Mtetra
.665 .73 .898 r
.52907 .58883 .53543 .59609 .54725 .59242 .54092 .58504 Mtetra
.66 .726 .898 r
.54092 .58504 .54725 .59242 .55911 .5887 .55282 .5814 Mtetra
.657 .728 .901 r
.55282 .5814 .55911 .5887 .57103 .58494 .56477 .57786 Mtetra
.655 .734 .908 r
.56477 .57786 .57103 .58494 .583 .5812 .57677 .57435 Mtetra
.655 .742 .914 r
.57677 .57435 .583 .5812 .59501 .57751 .58882 .57082 Mtetra
.655 .748 .918 r
.58882 .57082 .59501 .57751 .60708 .57387 .60093 .56727 Mtetra
.655 .751 .921 r
.60093 .56727 .60708 .57387 .61921 .57027 .61309 .56369 Mtetra
.655 .753 .922 r
.61309 .56369 .61921 .57027 .63138 .56669 .6253 .56009 Mtetra
.6253 .56009 .63138 .56669 .64362 .56316 .63757 .55648 Mtetra
.655 .752 .921 r
.63757 .55648 .64362 .56316 .6559 .55966 .64989 .55284 Mtetra
.656 .749 .918 r
.64989 .55284 .6559 .55966 .66825 .55621 .66227 .54917 Mtetra
.656 .743 .913 r
.66227 .54917 .66825 .55621 .68065 .55281 .67469 .54548 Mtetra
.655 .735 .908 r
.67469 .54548 .68065 .55281 .69312 .54943 .68718 .54182 Mtetra
.652 .726 .903 r
.68718 .54182 .69312 .54943 .70564 .54601 .69973 .53826 Mtetra
.647 .721 .902 r
.69973 .53826 .70564 .54601 .71821 .54254 .71234 .53485 Mtetra
.643 .723 .906 r
.71234 .53485 .71821 .54254 .73084 .5391 .72502 .53154 Mtetra
.642 .727 .91 r
.72502 .53154 .73084 .5391 .74355 .5359 .73776 .52825 Mtetra
.64 .724 .909 r
.73776 .52825 .74355 .5359 .75635 .53315 .75057 .52502 Mtetra
.629 .707 .902 r
.75057 .52502 .75635 .53315 .76926 .53091 .76346 .52216 Mtetra
.607 .681 .894 r
.76346 .52216 .76926 .53091 .78229 .5294 .77648 .52004 Mtetra
.578 .654 .888 r
.77648 .52004 .78229 .5294 .79545 .5285 .78965 .51892 Mtetra
.557 .639 .887 r
.78965 .51892 .79545 .5285 .8086 .52665 .80296 .51847 Mtetra
.589 .691 .913 r
.80296 .51847 .8086 .52665 .82156 .52169 .81624 .51676 Mtetra
.698 .842 .952 r
.81624 .51676 .82156 .52169 .8343 .51377 .82926 .51134 Mtetra
.78 .951 .93 r
.82926 .51134 .8343 .51377 .84703 .50548 .84203 .50271 Mtetra
.784 .942 .929 r
.84203 .50271 .84703 .50548 .85994 .4988 .85482 .49405 Mtetra
.735 .863 .941 r
.85482 .49405 .85994 .4988 .87307 .49374 .86784 .48739 Mtetra
.685 .792 .931 r
.86784 .48739 .87307 .49374 .88634 .4895 .88108 .48243 Mtetra
.663 .761 .923 r
.88108 .48243 .88634 .4895 .89969 .4855 .89446 .47821 Mtetra
.657 .753 .921 r
.89446 .47821 .89969 .4855 .91311 .48153 .90792 .47418 Mtetra
.656 .752 .92 r
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Mtetra
.656 .751 .92 r
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Mtetra
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Mtetra
.655 .751 .921 r
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63128 Mtetra
.651 .751 .923 r
.3505 .63128 .35737 .63735 .36848 .6341 .36164 .6281 Mtetra
.629 .748 .933 r
.36164 .6281 .36848 .6341 .37963 .63102 .3728 .62545 Mtetra
.548 .738 .964 r
.3728 .62545 .37963 .63102 .3908 .62866 .38394 .62431 Mtetra
.31 .68 .977 r
.38394 .62431 .3908 .62866 .40196 .62793 .39507 .62546 Mtetra
.022 .562 .844 r
.39507 .62546 .40196 .62793 .41313 .6291 .40624 .62744 Mtetra
.303 .768 .944 r
.40624 .62744 .41313 .6291 .42437 .63023 .41758 .62661 Mtetra
.712 .854 .95 r
.41758 .62661 .42437 .63023 .43577 .62829 .4291 .62137 Mtetra
.752 .754 .854 r
.4291 .62137 .43577 .62829 .44731 .62277 .44072 .61408 Mtetra
.727 .709 .833 r
.44072 .61408 .44731 .62277 .45891 .61606 .45234 .60739 Mtetra
.702 .703 .847 r
.45234 .60739 .45891 .61606 .47052 .61001 .46397 .60197 Mtetra
.685 .713 .87 r
.46397 .60197 .47052 .61001 .48215 .60494 .47563 .59745 Mtetra
.676 .725 .886 r
.47563 .59745 .48215 .60494 .49382 .6006 .48732 .5933 Mtetra
.671 .729 .894 r
.48732 .5933 .49382 .6006 .50552 .59663 .49905 .58933 Mtetra
.664 .728 .897 r
.49905 .58933 .50552 .59663 .51727 .59272 .51083 .58558 Mtetra
.659 .732 .903 r
.51083 .58558 .51727 .59272 .52907 .58883 .52266 .58197 Mtetra
.659 .741 .911 r
.52266 .58197 .52907 .58883 .54092 .58504 .53454 .57837 Mtetra
.66 .748 .915 r
.53454 .57837 .54092 .58504 .55282 .5814 .54648 .57469 Mtetra
.662 .748 .914 r
.54648 .57469 .55282 .5814 .56477 .57786 .55846 .57095 Mtetra
.661 .743 .911 r
.55846 .57095 .56477 .57786 .57677 .57435 .57049 .56721 Mtetra
.66 .737 .906 r
.57049 .56721 .57677 .57435 .58882 .57082 .58257 .5635 Mtetra
.659 .732 .903 r
.58257 .5635 .58882 .57082 .60093 .56727 .59471 .55982 Mtetra
.657 .728 .902 r
.59471 .55982 .60093 .56727 .61309 .56369 .6069 .55617 Mtetra
.656 .727 .901 r
.6069 .55617 .61309 .56369 .6253 .56009 .61915 .55254 Mtetra
.655 .726 .902 r
.61915 .55254 .6253 .56009 .63757 .55648 .63145 .54894 Mtetra
.653 .727 .903 r
.63145 .54894 .63757 .55648 .64989 .55284 .64381 .54536 Mtetra
.652 .729 .906 r
.64381 .54536 .64989 .55284 .66227 .54917 .65622 .54183 Mtetra
.65 .733 .91 r
.65622 .54183 .66227 .54917 .67469 .54548 .6687 .53831 Mtetra
.65 .739 .915 r
.6687 .53831 .67469 .54548 .68718 .54182 .68123 .5348 Mtetra
.651 .745 .919 r
.68123 .5348 .68718 .54182 .69973 .53826 .69381 .53122 Mtetra
.653 .746 .918 r
.69381 .53122 .69973 .53826 .71234 .53485 .70645 .52757 Mtetra
.652 .74 .914 r
.70645 .52757 .71234 .53485 .72502 .53154 .71915 .52391 Mtetra
.648 .729 .908 r
.71915 .52391 .72502 .53154 .73776 .52825 .73192 .5204 Mtetra
.641 .721 .906 r
.73192 .5204 .73776 .52825 .75057 .52502 .74476 .51712 Mtetra
.635 .717 .907 r
.74476 .51712 .75057 .52502 .76346 .52216 .75767 .51401 Mtetra
.623 .707 .905 r
.75767 .51401 .76346 .52216 .77648 .52004 .77068 .51128 Mtetra
.596 .679 .899 r
.77068 .51128 .77648 .52004 .78965 .51892 .78383 .50946 Mtetra
.557 .643 .891 r
.78383 .50946 .78965 .51892 .80296 .51847 .79716 .50894 Mtetra
.537 .632 .893 r
.79716 .50894 .80296 .51847 .81624 .51676 .81063 .50901 Mtetra
.596 .71 .923 r
.81063 .50901 .81624 .51676 .82926 .51134 .824 .50694 Mtetra
.734 .875 .946 r
.824 .50694 .82926 .51134 .84203 .50271 .83702 .50027 Mtetra
.805 .955 .914 r
.83702 .50027 .84203 .50271 .85482 .49405 .84979 .49069 Mtetra
.788 .925 .927 r
.84979 .49069 .85482 .49405 .86784 .48739 .86266 .48199 Mtetra
.724 .84 .936 r
.86266 .48199 .86784 .48739 .88108 .48243 .87582 .47568 Mtetra
.677 .779 .927 r
.87582 .47568 .88108 .48243 .89446 .47821 .88919 .47095 Mtetra
.66 .757 .922 r
.88919 .47095 .89446 .47821 .90792 .47418 .90269 .46678 Mtetra
.656 .752 .92 r
.90269 .46678 .90792 .47418 .92145 .47017 .91626 .46272 Mtetra
.656 .751 .92 r
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Mtetra
.32139 .63177 .32836 .63785 .33941 .63456 .33246 .62845 Mtetra
.653 .751 .921 r
.33246 .62845 .33941 .63456 .3505 .63128 .34358 .62519 Mtetra
.641 .749 .927 r
.34358 .62519 .3505 .63128 .36164 .6281 .35473 .62223 Mtetra
.587 .742 .95 r
.35473 .62223 .36164 .6281 .3728 .62545 .36588 .62044 Mtetra
.4 .7 .982 r
.36588 .62044 .3728 .62545 .38394 .62431 .37698 .62105 Mtetra
.019 .538 .862 r
.37698 .62105 .38394 .62431 .39507 .62546 .38807 .62369 Mtetra
.069 .613 .845 r
.38807 .62369 .39507 .62546 .40624 .62744 .39931 .62471 Mtetra
.645 .876 .984 r
.39931 .62471 .40624 .62744 .41758 .62661 .41079 .62068 Mtetra
.767 .783 .866 r
.41079 .62068 .41758 .62661 .4291 .62137 .42243 .61299 Mtetra
.746 .72 .828 r
.42243 .61299 .4291 .62137 .44072 .61408 .43408 .60531 Mtetra
.716 .705 .839 r
.43408 .60531 .44072 .61408 .45234 .60739 .44572 .5992 Mtetra
.692 .712 .863 r
.44572 .5992 .45234 .60739 .46397 .60197 .45737 .59433 Mtetra
.679 .722 .882 r
.45737 .59433 .46397 .60197 .47563 .59745 .46905 .59007 Mtetra
.669 .727 .893 r
.46905 .59007 .47563 .59745 .48732 .5933 .48077 .58615 Mtetra
.664 .733 .901 r
.48077 .58615 .48732 .5933 .49905 .58933 .49253 .58239 Mtetra
.664 .74 .907 r
.49253 .58239 .49905 .58933 .51083 .58558 .50434 .57861 Mtetra
.665 .74 .906 r
.50434 .57861 .51083 .58558 .52266 .58197 .51621 .5748 Mtetra
.662 .735 .903 r
.51621 .5748 .52266 .58197 .53454 .57837 .52812 .57105 Mtetra
.658 .73 .902 r
.52812 .57105 .53454 .57837 .54648 .57469 .54008 .56742 Mtetra
.655 .731 .905 r
.54008 .56742 .54648 .57469 .55846 .57095 .5521 .56387 Mtetra
.654 .737 .911 r
.5521 .56387 .55846 .57095 .57049 .56721 .56417 .56033 Mtetra
.654 .744 .916 r
.56417 .56033 .57049 .56721 .58257 .5635 .57629 .55678 Mtetra
.654 .75 .92 r
.57629 .55678 .58257 .5635 .59471 .55982 .58846 .55319 Mtetra
.654 .754 .923 r
.58846 .55319 .59471 .55982 .6069 .55617 .60069 .54957 Mtetra
.655 .756 .924 r
.60069 .54957 .6069 .55617 .61915 .55254 .61298 .54591 Mtetra
.61298 .54591 .61915 .55254 .63145 .54894 .62531 .54223 Mtetra
.656 .754 .922 r
.62531 .54223 .63145 .54894 .64381 .54536 .6377 .53851 Mtetra
.657 .751 .919 r
.6377 .53851 .64381 .54536 .65622 .54183 .65015 .53475 Mtetra
.657 .746 .915 r
.65015 .53475 .65622 .54183 .6687 .53831 .66265 .53097 Mtetra
.656 .738 .91 r
.66265 .53097 .6687 .53831 .68123 .5348 .6752 .52721 Mtetra
.654 .731 .906 r
.6752 .52721 .68123 .5348 .69381 .53122 .68782 .52353 Mtetra
.65 .727 .906 r
.68782 .52353 .69381 .53122 .70645 .52757 .7005 .51996 Mtetra
.647 .73 .909 r
.7005 .51996 .70645 .52757 .71915 .52391 .71325 .51646 Mtetra
.647 .735 .913 r
.71325 .51646 .71915 .52391 .73192 .5204 .72605 .51293 Mtetra
.648 .736 .913 r
.72605 .51293 .73192 .5204 .74476 .51712 .73891 .50936 Mtetra
.643 .726 .909 r
.73891 .50936 .74476 .51712 .75767 .51401 .75185 .50596 Mtetra
.632 .714 .907 r
.75185 .50596 .75767 .51401 .77068 .51128 .76487 .5029 Mtetra
.612 .698 .905 r
.76487 .5029 .77068 .51128 .78383 .50946 .77801 .50048 Mtetra
.573 .665 .9 r
.77801 .50048 .78383 .50946 .79716 .50894 .79132 .49931 Mtetra
.523 .624 .894 r
.79132 .49931 .79716 .50894 .81063 .50901 .80485 .49974 Mtetra
.52 .632 .902 r
.80485 .49974 .81063 .50901 .824 .50694 .81847 .50015 Mtetra
.634 .76 .938 r
.81847 .50015 .824 .50694 .83702 .50027 .83184 .49674 Mtetra
.787 .918 .927 r
.83184 .49674 .83702 .50027 .84979 .49069 .84477 .48807 Mtetra
.824 .952 .901 r
.84477 .48807 .84979 .49069 .86266 .48199 .85756 .47772 Mtetra
.776 .894 .928 r
.85756 .47772 .86266 .48199 .87582 .47568 .87058 .46951 Mtetra
.704 .81 .931 r
.87058 .46951 .87582 .47568 .88919 .47095 .8839 .46382 Mtetra
.668 .766 .924 r
.8839 .46382 .88919 .47095 .90269 .46678 .89741 .45935 Mtetra
.658 .754 .921 r
.89741 .45935 .90269 .46678 .91626 .46272 .91103 .45521 Mtetra
.656 .752 .92 r
.91103 .45521 .91626 .46272 .9299 .45865 .92471 .4511 Mtetra
.655 .751 .921 r
.31436 .62563 .32139 .63177 .33246 .62845 .32546 .62231 Mtetra
.65 .75 .923 r
.32546 .62231 .33246 .62845 .34358 .62519 .3366 .61912 Mtetra
.621 .746 .936 r
.3366 .61912 .34358 .62519 .35473 .62223 .34776 .61663 Mtetra
.503 .723 .971 r
.34776 .61663 .35473 .62223 .36588 .62044 .35887 .61616 Mtetra
.138 .585 .927 r
.35887 .61616 .36588 .62044 .37698 .62105 .36991 .61867 Mtetra
0 .435 .733 r
.36991 .61867 .37698 .62105 .38807 .62369 .38101 .62174 Mtetra
.395 .81 .976 r
.38101 .62174 .38807 .62369 .39931 .62471 .39238 .62031 Mtetra
.768 .831 .901 r
.39238 .62031 .39931 .62471 .41079 .62068 .40401 .61311 Mtetra
.773 .743 .826 r
.40401 .61311 .41079 .62068 .42243 .61299 .41572 .60418 Mtetra
.737 .71 .826 r
.41572 .60418 .42243 .61299 .43408 .60531 .4274 .59684 Mtetra
.705 .709 .852 r
.4274 .59684 .43408 .60531 .44572 .5992 .43905 .59135 Mtetra
.683 .719 .876 r
.43905 .59135 .44572 .5992 .45737 .59433 .45072 .5869 Mtetra
.671 .727 .892 r
.45072 .5869 .45737 .59433 .46905 .59007 .46242 .58289 Mtetra
.667 .734 .9 r
.46242 .58289 .46905 .59007 .48077 .58615 .47417 .579 Mtetra
.665 .735 .902 r
.47417 .579 .48077 .58615 .49253 .58239 .48596 .57519 Mtetra
.66 .733 .903 r
.48596 .57519 .49253 .58239 .50434 .57861 .4978 .57152 Mtetra
.656 .736 .908 r
.4978 .57152 .50434 .57861 .51621 .5748 .5097 .56796 Mtetra
.656 .744 .915 r
.5097 .56796 .51621 .5748 .52812 .57105 .52164 .56438 Mtetra
.658 .751 .918 r
.52164 .56438 .52812 .57105 .54008 .56742 .53364 .56071 Mtetra
.66 .751 .917 r
.53364 .56071 .54008 .56742 .5521 .56387 .54569 .55695 Mtetra
.661 .746 .913 r
.54569 .55695 .5521 .56387 .56417 .56033 .55779 .55317 Mtetra
.66 .739 .909 r
.55779 .55317 .56417 .56033 .57629 .55678 .56994 .54941 Mtetra
.658 .734 .905 r
.56994 .54941 .57629 .55678 .58846 .55319 .58215 .54568 Mtetra
.657 .73 .903 r
.58215 .54568 .58846 .55319 .60069 .54957 .59441 .54197 Mtetra
.656 .728 .902 r
.59441 .54197 .60069 .54957 .61298 .54591 .60673 .53829 Mtetra
.655 .728 .903 r
.60673 .53829 .61298 .54591 .62531 .54223 .6191 .53463 Mtetra
.653 .729 .904 r
.6191 .53463 .62531 .54223 .6377 .53851 .63153 .53099 Mtetra
.652 .731 .908 r
.63153 .53099 .6377 .53851 .65015 .53475 .64401 .52739 Mtetra
.651 .736 .912 r
.64401 .52739 .65015 .53475 .66265 .53097 .65656 .5238 Mtetra
.651 .743 .917 r
.65656 .5238 .66265 .53097 .6752 .52721 .66916 .52018 Mtetra
.652 .749 .921 r
.66916 .52018 .6752 .52721 .68782 .52353 .68182 .51648 Mtetra
.655 .75 .92 r
.68182 .51648 .68782 .52353 .7005 .51996 .69453 .51269 Mtetra
.655 .744 .915 r
.69453 .51269 .7005 .51996 .71325 .51646 .70729 .50887 Mtetra
.652 .735 .91 r
.70729 .50887 .71325 .51646 .72605 .51293 .72013 .50516 Mtetra
.647 .729 .908 r
.72013 .50516 .72605 .51293 .73891 .50936 .73303 .5016 Mtetra
.644 .729 .91 r
.73303 .5016 .73891 .50936 .75185 .50596 .746 .49811 Mtetra
.64 .725 .91 r
.746 .49811 .75185 .50596 .76487 .5029 .75904 .49474 Mtetra
.626 .712 .908 r
.75904 .49474 .76487 .5029 .77801 .50048 .77217 .49182 Mtetra
.593 .684 .905 r
.77217 .49182 .77801 .50048 .79132 .49931 .78547 .48996 Mtetra
.532 .638 .9 r
.78547 .48996 .79132 .49931 .80485 .49974 .79899 .49 Mtetra
.477 .6 .896 r
.79899 .49 .80485 .49974 .81847 .50015 .81276 .49165 Mtetra
.53 .661 .92 r
.81276 .49165 .81847 .50015 .83184 .49674 .82646 .49147 Mtetra
.719 .844 .941 r
.82646 .49147 .83184 .49674 .84477 .48807 .83969 .48527 Mtetra
.837 .948 .892 r
.83969 .48527 .84477 .48807 .85756 .47772 .8525 .47438 Mtetra
.824 .932 .902 r
.8525 .47438 .85756 .47772 .87058 .46951 .86537 .46411 Mtetra
.745 .85 .928 r
.86537 .46411 .87058 .46951 .8839 .46382 .8786 .45696 Mtetra
.683 .782 .926 r
.8786 .45696 .8839 .46382 .89741 .45935 .8921 .45194 Mtetra
.661 .757 .922 r
.8921 .45194 .89741 .45935 .91103 .45521 .90575 .44764 Mtetra
.656 .752 .92 r
.90575 .44764 .91103 .45521 .92471 .4511 .91948 .44349 Mtetra
.654 .751 .921 r
.30727 .61946 .31436 .62563 .32546 .62231 .3184 .61614 Mtetra
.642 .749 .927 r
.3184 .61614 .32546 .62231 .3366 .61912 .32956 .61312 Mtetra
.584 .738 .949 r
.32956 .61312 .3366 .61912 .34776 .61663 .3407 .61138 Mtetra
.349 .669 .975 r
.3407 .61138 .34776 .61663 .35887 .61616 .35175 .61261 Mtetra
0 .397 .758 r
.35175 .61261 .35887 .61616 .36991 .61867 .36274 .61675 Mtetra
0 .487 .75 r
.36274 .61675 .36991 .61867 .38101 .62174 .37391 .61903 Mtetra
.675 .883 .975 r
.37391 .61903 .38101 .62174 .39238 .62031 .38544 .61437 Mtetra
.799 .785 .84 r
.38544 .61437 .39238 .62031 .40401 .61311 .39721 .60466 Mtetra
.769 .725 .812 r
.39721 .60466 .40401 .61311 .41572 .60418 .40896 .59537 Mtetra
.727 .709 .833 r
.40896 .59537 .41572 .60418 .4274 .59684 .42065 .58864 Mtetra
.693 .714 .865 r
.42065 .58864 .4274 .59684 .43905 .59135 .43232 .58371 Mtetra
.675 .724 .886 r
.43232 .58371 .43905 .59135 .45072 .5869 .44401 .57954 Mtetra
.667 .73 .896 r
.44401 .57954 .45072 .5869 .46242 .58289 .45574 .57564 Mtetra
.662 .732 .902 r
.45574 .57564 .46242 .58289 .47417 .579 .46751 .57192 Mtetra
.659 .737 .907 r
.46751 .57192 .47417 .579 .48596 .57519 .47934 .56827 Mtetra
.661 .743 .911 r
.47934 .56827 .48596 .57519 .4978 .57152 .49121 .56454 Mtetra
.662 .743 .91 r
.49121 .56454 .4978 .57152 .5097 .56796 .50314 .56074 Mtetra
.661 .736 .905 r
.50314 .56074 .5097 .56796 .52164 .56438 .51512 .55699 Mtetra
.657 .73 .904 r
.51512 .55699 .52164 .56438 .53364 .56071 .52715 .55334 Mtetra
.654 .731 .906 r
.52715 .55334 .53364 .56071 .54569 .55695 .53923 .54978 Mtetra
.652 .737 .912 r
.53923 .54978 .54569 .55695 .55779 .55317 .55136 .54624 Mtetra
.652 .745 .918 r
.55136 .54624 .55779 .55317 .56994 .54941 .56356 .54268 Mtetra
.653 .752 .923 r
.56356 .54268 .56994 .54941 .58215 .54568 .5758 .53906 Mtetra
.653 .757 .926 r
.5758 .53906 .58215 .54568 .59441 .54197 .5881 .53539 Mtetra
.654 .759 .927 r
.5881 .53539 .59441 .54197 .60673 .53829 .60045 .53168 Mtetra
.655 .76 .927 r
.60045 .53168 .60673 .53829 .6191 .53463 .61286 .52792 Mtetra
.657 .758 .925 r
.61286 .52792 .6191 .53463 .63153 .53099 .62532 .52411 Mtetra
.658 .754 .921 r
.62532 .52411 .63153 .53099 .64401 .52739 .63784 .52024 Mtetra
.659 .748 .916 r
.63784 .52024 .64401 .52739 .65656 .5238 .65041 .51635 Mtetra
.658 .739 .91 r
.65041 .51635 .65656 .5238 .66916 .52018 .66304 .51248 Mtetra
.655 .732 .906 r
.66304 .51248 .66916 .52018 .68182 .51648 .67573 .5087 Mtetra
.651 .729 .906 r
.67573 .5087 .68182 .51648 .69453 .51269 .68848 .50503 Mtetra
.649 .732 .91 r
.68848 .50503 .69453 .51269 .70729 .50887 .7013 .50139 Mtetra
.651 .739 .914 r
.7013 .50139 .70729 .50887 .72013 .50516 .71417 .49769 Mtetra
.653 .741 .915 r
.71417 .49769 .72013 .50516 .73303 .5016 .7271 .49389 Mtetra
.65 .734 .911 r
.7271 .49389 .73303 .5016 .746 .49811 .7401 .49018 Mtetra
.644 .727 .909 r
.7401 .49018 .746 .49811 .75904 .49474 .75316 .48664 Mtetra
.635 .719 .908 r
.75316 .48664 .75904 .49474 .77217 .49182 .76632 .48338 Mtetra
.611 .7 .907 r
.76632 .48338 .77217 .49182 .78547 .48996 .7796 .48089 Mtetra
.552 .657 .905 r
.7796 .48089 .78547 .48996 .79899 .49 .7931 .48025 Mtetra
.462 .593 .897 r
.7931 .48025 .79899 .49 .81276 .49165 .80692 .48223 Mtetra
.44 .59 .905 r
.80692 .48223 .81276 .49165 .82646 .49147 .82089 .4846 Mtetra
.613 .753 .945 r
.82089 .4846 .82646 .49147 .83969 .48527 .83447 .48168 Mtetra
.821 .923 .903 r
.83447 .48168 .83969 .48527 .8525 .47438 .84743 .47152 Mtetra
.859 .947 .873 r
.84743 .47152 .8525 .47438 .86537 .46411 .8602 .45946 Mtetra
.793 .888 .913 r
.8602 .45946 .86537 .46411 .8786 .45696 .87329 .45045 Mtetra
.707 .805 .926 r
.87329 .45045 .8786 .45696 .8921 .45194 .88676 .44457 Mtetra
.667 .764 .922 r
.88676 .44457 .8921 .45194 .90575 .44764 .90043 .44004 Mtetra
.657 .753 .921 r
.90043 .44004 .90575 .44764 .91948 .44349 .9142 .43582 Mtetra
.652 .751 .922 r
.30014 .61324 .30727 .61946 .3184 .61614 .31129 .60994 Mtetra
.629 .747 .932 r
.31129 .60994 .3184 .61614 .32956 .61312 .32246 .60722 Mtetra
.522 .722 .964 r
.32246 .60722 .32956 .61312 .3407 .61138 .33357 .60652 Mtetra
.104 .545 .913 r
.33357 .60652 .3407 .61138 .35175 .61261 .34454 .60966 Mtetra
.352 0 0 r
.34454 .60966 .35175 .61261 .36274 .61675 .35549 .61491 Mtetra
.146 .667 .884 r
.35549 .61491 .36274 .61675 .37391 .61903 .36678 .61537 Mtetra
.79 .856 .9 r
.36678 .61537 .37391 .61903 .38544 .61437 .3785 .6073 Mtetra
.809 .759 .806 r
.3785 .6073 .38544 .61437 .39721 .60466 .39037 .59582 Mtetra
.764 .718 .809 r
.39037 .59582 .39721 .60466 .40896 .59537 .40216 .58669 Mtetra
.714 .709 .844 r
.40216 .58669 .40896 .59537 .42065 .58864 .41385 .58063 Mtetra
.682 .717 .875 r
.41385 .58063 .42065 .58864 .43232 .58371 .42554 .57616 Mtetra
.667 .725 .893 r
.42554 .57616 .43232 .58371 .44401 .57954 .43725 .57225 Mtetra
.662 .731 .901 r
.43725 .57225 .44401 .57954 .45574 .57564 .449 .5685 Mtetra
.661 .736 .905 r
.449 .5685 .45574 .57564 .46751 .57192 .46081 .56476 Mtetra
.661 .736 .906 r
.46081 .56476 .46751 .57192 .47934 .56827 .47267 .56102 Mtetra
.656 .733 .906 r
.47267 .56102 .47934 .56827 .49121 .56454 .48457 .55741 Mtetra
.652 .736 .911 r
.48457 .55741 .49121 .56454 .50314 .56074 .49653 .5539 Mtetra
.653 .746 .918 r
.49653 .5539 .50314 .56074 .51512 .55699 .50854 .55035 Mtetra
.656 .754 .922 r
.50854 .55035 .51512 .55699 .52715 .55334 .5206 .54666 Mtetra
.66 .755 .921 r
.5206 .54666 .52715 .55334 .53923 .54978 .53272 .54286 Mtetra
.661 .749 .915 r
.53272 .54286 .53923 .54978 .55136 .54624 .54489 .539 Mtetra
.66 .74 .909 r
.54489 .539 .55136 .54624 .56356 .54268 .55711 .53516 Mtetra
.659 .733 .904 r
.55711 .53516 .56356 .54268 .5758 .53906 .56939 .53135 Mtetra
.657 .728 .901 r
.56939 .53135 .5758 .53906 .5881 .53539 .58172 .52757 Mtetra
.656 .725 .9 r
.58172 .52757 .5881 .53539 .60045 .53168 .5941 .52383 Mtetra
.654 .725 .901 r
.5941 .52383 .60045 .53168 .61286 .52792 .60655 .52012 Mtetra
.653 .726 .903 r
.60655 .52012 .61286 .52792 .62532 .52411 .61905 .51644 Mtetra
.651 .73 .907 r
.61905 .51644 .62532 .52411 .63784 .52024 .63161 .5128 Mtetra
.65 .737 .913 r
.63161 .5128 .63784 .52024 .65041 .51635 .64423 .50917 Mtetra
.651 .746 .919 r
.64423 .50917 .65041 .51635 .66304 .51248 .6569 .50548 Mtetra
.653 .754 .923 r
.6569 .50548 .66304 .51248 .67573 .5087 .66963 .50167 Mtetra
.657 .755 .922 r
.66963 .50167 .67573 .5087 .68848 .50503 .68241 .49773 Mtetra
.659 .748 .916 r
.68241 .49773 .68848 .50503 .7013 .50139 .69525 .49374 Mtetra
.655 .738 .91 r
.69525 .49374 .7013 .50139 .71417 .49769 .70816 .48986 Mtetra
.651 .732 .909 r
.70816 .48986 .71417 .49769 .7271 .49389 .72113 .4861 Mtetra
.65 .734 .91 r
.72113 .4861 .7271 .49389 .7401 .49018 .73416 .48235 Mtetra
.65 .733 .91 r
.73416 .48235 .7401 .49018 .75316 .48664 .74725 .47859 Mtetra
.644 .726 .908 r
.74725 .47859 .75316 .48664 .76632 .48338 .76042 .47501 Mtetra
.627 .711 .907 r
.76042 .47501 .76632 .48338 .7796 .48089 .7737 .47199 Mtetra
.575 .674 .907 r
.7737 .47199 .7796 .48089 .7931 .48025 .78718 .47061 Mtetra
.466 .599 .901 r
.78718 .47061 .7931 .48025 .80692 .48223 .80101 .47238 Mtetra
.369 .54 .893 r
.80101 .47238 .80692 .48223 .82089 .4846 .81516 .47655 Mtetra
.487 .657 .936 r
.81516 .47655 .82089 .4846 .83447 .48168 .82912 .47711 Mtetra
.776 .887 .925 r
.82912 .47711 .83447 .48168 .84743 .47152 .84231 .46876 Mtetra
.88 .947 .851 r
.84231 .46876 .84743 .47152 .8602 .45946 .85504 .45542 Mtetra
.839 .914 .887 r
.85504 .45542 .8602 .45946 .87329 .45045 .86799 .44434 Mtetra
.739 .83 .921 r
.86799 .44434 .87329 .45045 .88676 .44457 .88139 .4373 Mtetra
.677 .772 .922 r
.88139 .4373 .88676 .44457 .90043 .44004 .89507 .43239 Mtetra
.659 .755 .921 r
.89507 .43239 .90043 .44004 .9142 .43582 .90888 .42808 Mtetra
.649 .751 .923 r
.29294 .60698 .30014 .61324 .31129 .60994 .30412 .60373 Mtetra
.611 .742 .939 r
.30412 .60373 .31129 .60994 .32246 .60722 .31529 .60141 Mtetra
.426 .687 .973 r
.31529 .60141 .32246 .60722 .33357 .60652 .32634 .60199 Mtetra
0 .346 .751 r
.32634 .60199 .33357 .60652 .34454 .60966 .33723 .60712 Mtetra
.444 0 0 r
.33723 .60712 .34454 .60966 .35549 .61491 .34818 .61296 Mtetra
.455 .839 .985 r
.34818 .61296 .35549 .61491 .36678 .61537 .35961 .61089 Mtetra
.834 .823 .837 r
.35961 .61089 .36678 .61537 .3785 .6073 .37153 .59951 Mtetra
.814 .745 .787 r
.37153 .59951 .3785 .6073 .39037 .59582 .3835 .5868 Mtetra
.756 .714 .812 r
.3835 .5868 .39037 .59582 .40216 .58669 .3953 .5781 Mtetra
.701 .709 .855 r
.3953 .5781 .40216 .58669 .41385 .58063 .407 .57272 Mtetra
.67 .717 .884 r
.407 .57272 .41385 .58063 .42554 .57616 .4187 .56866 Mtetra
.661 .726 .897 r
.4187 .56866 .42554 .57616 .43725 .57225 .43043 .56492 Mtetra
.659 .731 .903 r
.43043 .56492 .43725 .57225 .449 .5685 .44222 .56124 Mtetra
.655 .733 .906 r
.44222 .56124 .449 .5685 .46081 .56476 .45405 .55766 Mtetra
.654 .738 .911 r
.45405 .55766 .46081 .56476 .47267 .56102 .46594 .55409 Mtetra
.658 .745 .914 r
.46594 .55409 .47267 .56102 .48457 .55741 .47788 .55037 Mtetra
.662 .744 .911 r
.47788 .55037 .48457 .55741 .49653 .5539 .48987 .54653 Mtetra
.66 .734 .905 r
.48987 .54653 .49653 .5539 .50854 .55035 .50191 .54271 Mtetra
.655 .727 .901 r
.50191 .54271 .50854 .55035 .5206 .54666 .51401 .53905 Mtetra
.651 .727 .904 r
.51401 .53905 .5206 .54666 .53272 .54286 .52615 .53551 Mtetra
.649 .734 .911 r
.52615 .53551 .53272 .54286 .54489 .539 .53836 .532 Mtetra
.649 .746 .92 r
.53836 .532 .54489 .539 .55711 .53516 .55062 .52846 Mtetra
.65 .756 .927 r
.55062 .52846 .55711 .53516 .56939 .53135 .56293 .52484 Mtetra
.652 .764 .931 r
.56293 .52484 .56939 .53135 .58172 .52757 .57531 .52115 Mtetra
.653 .768 .933 r
.57531 .52115 .58172 .52757 .5941 .52383 .58773 .51737 Mtetra
.656 .768 .932 r
.58773 .51737 .5941 .52383 .60655 .52012 .60021 .51352 Mtetra
.658 .766 .929 r
.60021 .51352 .60655 .52012 .61905 .51644 .61275 .50959 Mtetra
.661 .759 .923 r
.61275 .50959 .61905 .51644 .63161 .5128 .62533 .50558 Mtetra
.662 .75 .915 r
.62533 .50558 .63161 .5128 .64423 .50917 .63798 .50153 Mtetra
.66 .738 .907 r
.63798 .50153 .64423 .50917 .6569 .50548 .65068 .49752 Mtetra
.656 .728 .903 r
.65068 .49752 .6569 .50548 .66963 .50167 .66344 .49364 Mtetra
.651 .725 .903 r
.66344 .49364 .66963 .50167 .68241 .49773 .67627 .4899 Mtetra
.649 .731 .909 r
.67627 .4899 .68241 .49773 .69525 .49374 .68916 .48619 Mtetra
.653 .742 .915 r
.68916 .48619 .69525 .49374 .70816 .48986 .70211 .48235 Mtetra
.657 .745 .915 r
.70211 .48235 .70816 .48986 .72113 .4861 .71511 .47836 Mtetra
.656 .739 .911 r
.71511 .47836 .72113 .4861 .73416 .48235 .72817 .47439 Mtetra
.653 .733 .908 r
.72817 .47439 .73416 .48235 .74725 .47859 .7413 .4705 Mtetra
.65 .729 .907 r
.7413 .4705 .74725 .47859 .76042 .47501 .75449 .46669 Mtetra
.64 .72 .905 r
.75449 .46669 .76042 .47501 .7737 .47199 .76778 .46319 Mtetra
.598 .689 .906 r
.76778 .46319 .7737 .47199 .78718 .47061 .78123 .46105 Mtetra
.481 .612 .904 r
.78123 .46105 .78718 .47061 .80101 .47238 .79505 .46233 Mtetra
.315 .504 .884 r
.79505 .46233 .80101 .47238 .81516 .47655 .80933 .46773 Mtetra
.345 .557 .914 r
.80933 .46773 .81516 .47655 .82912 .47711 .82363 .47168 Mtetra
.701 .84 .949 r
.82363 .47168 .82912 .47711 .84231 .46876 .83713 .46587 Mtetra
.889 .942 .841 r
.83713 .46587 .84231 .46876 .85504 .45542 .84987 .45182 Mtetra
.877 .926 .853 r
.84987 .45182 .85504 .45542 .86799 .44434 .86267 .43857 Mtetra
.775 .852 .909 r
.86267 .43857 .86799 .44434 .88139 .4373 .87598 .43011 Mtetra
.69 .782 .921 r
.87598 .43011 .88139 .4373 .89507 .43239 .88966 .42471 Mtetra
.661 .757 .921 r
.88966 .42471 .89507 .43239 .90888 .42808 .90351 .42029 Mtetra
.646 .75 .925 r
.28569 .60068 .29294 .60698 .30412 .60373 .29689 .5975 Mtetra
.586 .736 .946 r
.29689 .5975 .30412 .60373 .31529 .60141 .30805 .59568 Mtetra
.288 .624 .961 r
.30805 .59568 .31529 .60141 .32634 .60199 .31904 .59771 Mtetra
.435 0 0 r
.31904 .59771 .32634 .60199 .33723 .60712 .32983 .60483 Mtetra
.476 0 0 r
.32983 .60483 .33723 .60712 .34818 .61296 .34079 .61084 Mtetra
.676 .905 .976 r
.34079 .61084 .34818 .61296 .35961 .61089 .35241 .60584 Mtetra
.857 .8 .794 r
.35241 .60584 .35961 .61089 .37153 .59951 .36453 .59128 Mtetra
.817 .738 .776 r
.36453 .59128 .37153 .59951 .3835 .5868 .37658 .57768 Mtetra
.747 .711 .818 r
.37658 .57768 .3835 .5868 .3953 .5781 .38839 .56956 Mtetra
.685 .707 .864 r
.38839 .56956 .3953 .5781 .407 .57272 .4001 .56483 Mtetra
.659 .716 .89 r
.4001 .56483 .407 .57272 .4187 .56866 .41181 .56114 Mtetra
.654 .725 .901 r
.41181 .56114 .4187 .56866 .43043 .56492 .42357 .5576 Mtetra
.654 .732 .906 r
.42357 .5576 .43043 .56492 .44222 .56124 .43538 .55405 Mtetra
.657 .737 .909 r
.43538 .55405 .44222 .56124 .45405 .55766 .44724 .55038 Mtetra
.658 .736 .907 r
.44724 .55038 .45405 .55766 .46594 .55409 .45916 .54668 Mtetra
.653 .731 .907 r
.45916 .54668 .46594 .55409 .47788 .55037 .47113 .54312 Mtetra
.649 .735 .912 r
.47113 .54312 .47788 .55037 .48987 .54653 .48315 .53965 Mtetra
.653 .748 .92 r
.48315 .53965 .48987 .54653 .50191 .54271 .49522 .53604 Mtetra
.662 .758 .921 r
.49522 .53604 .50191 .54271 .51401 .53905 .50736 .5321 Mtetra
.672 .754 .912 r
.50736 .5321 .51401 .53905 .52615 .53551 .51954 .52786 Mtetra
.675 .736 .896 r
.51954 .52786 .52615 .53551 .53836 .532 .53178 .52346 Mtetra
.673 .713 .878 r
.53178 .52346 .53836 .532 .55062 .52846 .54406 .51906 Mtetra
.666 .691 .864 r
.54406 .51906 .55062 .52846 .56293 .52484 .5564 .5148 Mtetra
.659 .675 .854 r
.5564 .5148 .56293 .52484 .57531 .52115 .56879 .51075 Mtetra
.652 .666 .851 r
.56879 .51075 .57531 .52115 .58773 .51737 .58124 .50695 Mtetra
.645 .663 .853 r
.58124 .50695 .58773 .51737 .60021 .51352 .59375 .50338 Mtetra
.64 .668 .861 r
.59375 .50338 .60021 .51352 .61275 .50959 .60633 .50003 Mtetra
.636 .68 .874 r
.60633 .50003 .61275 .50959 .62533 .50558 .61897 .49682 Mtetra
.636 .699 .892 r
.61897 .49682 .62533 .50558 .63798 .50153 .63167 .49362 Mtetra
.64 .724 .91 r
.63167 .49362 .63798 .50153 .65068 .49752 .64443 .49024 Mtetra
.648 .747 .922 r
.64443 .49024 .65068 .49752 .66344 .49364 .65725 .48656 Mtetra
.657 .757 .924 r
.65725 .48656 .66344 .49364 .67627 .4899 .6701 .48255 Mtetra
.662 .752 .917 r
.6701 .48255 .67627 .4899 .68916 .48619 .68302 .4784 Mtetra
.658 .738 .909 r
.68302 .4784 .68916 .48619 .70211 .48235 .69599 .47435 Mtetra
.653 .732 .907 r
.69599 .47435 .70211 .48235 .71511 .47836 .70904 .47044 Mtetra
.654 .735 .909 r
.70904 .47044 .71511 .47836 .72817 .47439 .72214 .46649 Mtetra
.657 .738 .909 r
.72214 .46649 .72817 .47439 .7413 .4705 .7353 .46242 Mtetra
.657 .734 .906 r
.7353 .46242 .7413 .4705 .75449 .46669 .74852 .45832 Mtetra
.652 .725 .902 r
.74852 .45832 .75449 .46669 .76778 .46319 .76181 .4544 Mtetra
.62 .701 .903 r
.76181 .4544 .76778 .46319 .78123 .46105 .77525 .45153 Mtetra
.504 .626 .905 r
.77525 .45153 .78123 .46105 .79505 .46233 .78904 .45217 Mtetra
.273 .477 .876 r
.78904 .45217 .79505 .46233 .80933 .46773 .80342 .45844 Mtetra
.192 .449 .874 r
.80342 .45844 .80933 .46773 .82363 .47168 .81804 .46563 Mtetra
.593 .78 .97 r
.81804 .46563 .82363 .47168 .83713 .46587 .83188 .4628 Mtetra
.892 .938 .837 r
.83188 .4628 .83713 .46587 .84987 .45182 .84467 .44847 Mtetra
.906 .928 .819 r
.84467 .44847 .84987 .45182 .86267 .43857 .85733 .43304 Mtetra
.81 .868 .891 r
.85733 .43304 .86267 .43857 .87598 .43011 .87054 .42299 Mtetra
.706 .792 .918 r
.87054 .42299 .87598 .43011 .88966 .42471 .88421 .417 Mtetra
.664 .759 .921 r
.88421 .417 .88966 .42471 .90351 .42029 .8981 .41244 Mtetra
.642 .749 .927 r
.27838 .59434 .28569 .60068 .29689 .5975 .2896 .59124 Mtetra
.556 .726 .954 r
.2896 .59124 .29689 .5975 .30805 .59568 .30075 .58998 Mtetra
.111 .523 .912 r
.30075 .58998 .30805 .59568 .31904 .59771 .31166 .59355 Mtetra
.6 .041 0 r
.31166 .59355 .31904 .59771 .32983 .60483 .32234 .60267 Mtetra
.48 0 0 r
.32234 .60267 .32983 .60483 .34079 .61084 .33332 .60863 Mtetra
.793 .905 .92 r
.33332 .60863 .34079 .61084 .35241 .60584 .34516 .60049 Mtetra
.873 .787 .763 r
.34516 .60049 .35241 .60584 .36453 .59128 .35749 .58282 Mtetra
.821 .735 .769 r
.35749 .58282 .36453 .59128 .37658 .57768 .36962 .56849 Mtetra
.736 .708 .824 r
.36962 .56849 .37658 .57768 .38839 .56956 .38143 .56099 Mtetra
.668 .702 .873 r
.38143 .56099 .38839 .56956 .4001 .56483 .39314 .55692 Mtetra
.647 .713 .896 r
.39314 .55692 .4001 .56483 .41181 .56114 .40487 .55359 Mtetra
.649 .724 .904 r
.40487 .55359 .41181 .56114 .42357 .5576 .41665 .55017 Mtetra
.652 .729 .906 r
.41665 .55017 .42357 .5576 .43538 .55405 .42849 .54663 Mtetra
.654 .731 .906 r
.42849 .54663 .43538 .55405 .44724 .55038 .44038 .54304 Mtetra
.662 .737 .905 r
.44038 .54304 .44724 .55038 .45916 .54668 .45233 .53917 Mtetra
.681 .739 .894 r
.45233 .53917 .45916 .54668 .47113 .54312 .46435 .53465 Mtetra
.695 .719 .868 r
.46435 .53465 .47113 .54312 .48315 .53965 .47642 .52943 Mtetra
.692 .681 .835 r
.47642 .52943 .48315 .53965 .49522 .53604 .48854 .52389 Mtetra
.679 .644 .807 r
.48854 .52389 .49522 .53604 .50736 .5321 .5007 .51847 Mtetra
.665 .617 .791 r
.5007 .51847 .50736 .5321 .51954 .52786 .5129 .51343 Mtetra
.655 .602 .784 r
.5129 .51343 .51954 .52786 .53178 .52346 .52514 .50882 Mtetra
.648 .597 .784 r
.52514 .50882 .53178 .52346 .54406 .51906 .53744 .50454 Mtetra
.644 .597 .787 r
.53744 .50454 .54406 .51906 .5564 .5148 .54978 .50049 Mtetra
.642 .599 .791 r
.54978 .50049 .5564 .5148 .56879 .51075 .56219 .49656 Mtetra
.641 .6 .793 r
.56219 .49656 .56879 .51075 .58124 .50695 .57465 .49271 Mtetra
.639 .599 .794 r
.57465 .49271 .58124 .50695 .59375 .50338 .58717 .48894 Mtetra
.635 .596 .792 r
.58717 .48894 .59375 .50338 .60633 .50003 .59975 .48529 Mtetra
.63 .59 .79 r
.59975 .48529 .60633 .50003 .61897 .49682 .61239 .48188 Mtetra
.623 .584 .79 r
.61239 .48188 .61897 .49682 .63167 .49362 .62511 .4788 Mtetra
.614 .582 .794 r
.62511 .4788 .63167 .49362 .64443 .49024 .6379 .47617 Mtetra
.607 .588 .806 r
.6379 .47617 .64443 .49024 .65725 .48656 .65079 .47394 Mtetra
.604 .609 .83 r
.65079 .47394 .65725 .48656 .6701 .48255 .66375 .47183 Mtetra
.612 .649 .862 r
.66375 .47183 .6701 .48255 .68302 .4784 .67676 .46939 Mtetra
.631 .697 .893 r
.67676 .46939 .68302 .4784 .69599 .47435 .68982 .46625 Mtetra
.65 .729 .907 r
.68982 .46625 .69599 .47435 .70904 .47044 .70291 .46243 Mtetra
.657 .736 .908 r
.70291 .46243 .70904 .47044 .72214 .46649 .71605 .45834 Mtetra
.658 .733 .905 r
.71605 .45834 .72214 .46649 .7353 .46242 .72924 .4542 Mtetra
.661 .734 .903 r
.72924 .4542 .7353 .46242 .74852 .45832 .74249 .44993 Mtetra
.663 .73 .9 r
.74249 .44993 .74852 .45832 .76181 .4544 .7558 .44557 Mtetra
.641 .711 .898 r
.7558 .44557 .76181 .4544 .77525 .45153 .76922 .44197 Mtetra
.528 .64 .904 r
.76922 .44197 .77525 .45153 .78904 .45217 .78299 .44191 Mtetra
.237 .454 .868 r
.78299 .44191 .78904 .45217 .80342 .45844 .79745 .44889 Mtetra
.028 .332 .815 r
.79745 .44889 .80342 .45844 .81804 .46563 .81237 .45927 Mtetra
.443 .698 .974 r
.81237 .45927 .81804 .46563 .83188 .4628 .82655 .45963 Mtetra
.892 .936 .838 r
.82655 .45963 .83188 .4628 .84467 .44847 .83943 .44525 Mtetra
.927 .923 .786 r
.83943 .44525 .84467 .44847 .85733 .43304 .85196 .42763 Mtetra
.841 .876 .868 r
.85196 .42763 .85733 .43304 .87054 .42299 .86506 .41588 Mtetra
.723 .8 .912 r
.86506 .41588 .87054 .42299 .88421 .417 .87871 .40924 Mtetra
.667 .761 .92 r
.87871 .40924 .88421 .417 .8981 .41244 .89264 .40452 Mtetra
.637 .748 .928 r
.27101 .58795 .27838 .59434 .2896 .59124 .28225 .58494 Mtetra
.522 .714 .96 r
.28225 .58494 .2896 .59124 .30075 .58998 .29338 .58424 Mtetra
0 .392 .821 r
.29338 .58424 .30075 .58998 .31166 .59355 .30421 .58938 Mtetra
.702 .167 0 r
.30421 .58938 .31166 .59355 .32234 .60267 .31477 .60051 Mtetra
.476 0 0 r
.31477 .60051 .32234 .60267 .33332 .60863 .32578 .60643 Mtetra
.852 .889 .864 r
.32578 .60643 .33332 .60863 .34516 .60049 .33785 .59512 Mtetra
.887 .781 .739 r
.33785 .59512 .34516 .60049 .35749 .58282 .3504 .57431 Mtetra
.827 .735 .764 r
.3504 .57431 .35749 .58282 .36962 .56849 .36261 .55921 Mtetra
.725 .704 .83 r
.36261 .55921 .36962 .56849 .38143 .56099 .37443 .55232 Mtetra
.649 .695 .879 r
.37443 .55232 .38143 .56099 .39314 .55692 .38613 .54889 Mtetra
.638 .708 .898 r
.38613 .54889 .39314 .55692 .40487 .55359 .39788 .54582 Mtetra
.651 .72 .899 r
.39788 .54582 .40487 .55359 .41665 .55017 .40969 .54231 Mtetra
.672 .725 .889 r
.40969 .54231 .41665 .55017 .42849 .54663 .42158 .53808 Mtetra
.696 .716 .864 r
.42158 .53808 .42849 .54663 .44038 .54304 .43354 .53282 Mtetra
.702 .684 .829 r
.43354 .53282 .44038 .54304 .45233 .53917 .44557 .52678 Mtetra
.688 .643 .8 r
.44557 .52678 .45233 .53917 .46435 .53465 .45763 .52082 Mtetra
.667 .615 .787 r
.45763 .52082 .46435 .53465 .47642 .52943 .46971 .51563 Mtetra
.651 .608 .793 r
.46971 .51563 .47642 .52943 .48854 .52389 .48183 .51134 Mtetra
.642 .622 .815 r
.48183 .51134 .48854 .52389 .5007 .51847 .49399 .50769 Mtetra
.64 .652 .846 r
.49399 .50769 .5007 .51847 .5129 .51343 .5062 .50434 Mtetra
.64 .69 .88 r
.5062 .50434 .5129 .51343 .52514 .50882 .51847 .50104 Mtetra
.642 .725 .908 r
.51847 .50104 .52514 .50882 .53744 .50454 .5308 .49765 Mtetra
.645 .753 .928 r
.5308 .49765 .53744 .50454 .54978 .50049 .54319 .49411 Mtetra
.648 .771 .938 r
.54319 .49411 .54978 .50049 .56219 .49656 .55564 .4904 Mtetra
.653 .781 .942 r
.55564 .4904 .56219 .49656 .57465 .49271 .56814 .48652 Mtetra
.658 .783 .94 r
.56814 .48652 .57465 .49271 .58717 .48894 .58069 .48247 Mtetra
.664 .776 .933 r
.58069 .48247 .58717 .48894 .59975 .48529 .5933 .47825 Mtetra
.669 .761 .919 r
.5933 .47825 .59975 .48529 .61239 .48188 .60596 .47388 Mtetra
.671 .735 .898 r
.60596 .47388 .61239 .48188 .62511 .4788 .61867 .46942 Mtetra
.667 .7 .871 r
.61867 .46942 .62511 .4788 .6379 .47617 .63144 .465 Mtetra
.654 .658 .842 r
.63144 .465 .6379 .47617 .65079 .47394 .64428 .46087 Mtetra
.634 .618 .817 r
.64428 .46087 .65079 .47394 .66375 .47183 .6572 .45741 Mtetra
.611 .588 .802 r
.6572 .45741 .66375 .47183 .67676 .46939 .67023 .45487 Mtetra
.594 .578 .805 r
.67023 .45487 .67676 .46939 .68982 .46625 .68336 .45313 Mtetra
.592 .598 .827 r
.68336 .45313 .68982 .46625 .70291 .46243 .69659 .45148 Mtetra
.61 .647 .862 r
.69659 .45148 .70291 .46243 .71605 .45834 .70985 .44903 Mtetra
.639 .697 .888 r
.70985 .44903 .71605 .45834 .72924 .4542 .72312 .44553 Mtetra
.659 .723 .896 r
.72312 .44553 .72924 .4542 .74249 .44993 .73641 .44129 Mtetra
.671 .729 .893 r
.73641 .44129 .74249 .44993 .7558 .44557 .74973 .43661 Mtetra
.66 .717 .891 r
.74973 .43661 .7558 .44557 .76922 .44197 .76315 .4323 Mtetra
.552 .651 .9 r
.76315 .4323 .76922 .44197 .78299 .44191 .7769 .43155 Mtetra
.198 .428 .858 r
.7769 .43155 .78299 .44191 .79745 .44889 .79144 .43929 Mtetra
0 .206 .732 r
.79144 .43929 .79745 .44889 .81237 .45927 .80665 .45288 Mtetra
.248 .584 .946 r
.80665 .45288 .81237 .45927 .82655 .45963 .82117 .45646 Mtetra
.891 .937 .838 r
.82117 .45646 .82655 .45963 .83943 .44525 .83413 .44202 Mtetra
.944 .913 .757 r
.83413 .44202 .83943 .44525 .85196 .42763 .84653 .4222 Mtetra
.866 .878 .843 r
.84653 .4222 .85196 .42763 .86506 .41588 .85952 .40873 Mtetra
.739 .806 .905 r
.85952 .40873 .86506 .41588 .87871 .40924 .87317 .40141 Mtetra
.671 .762 .919 r
.87317 .40141 .87871 .40924 .89264 .40452 .88713 .39654 Mtetra
.633 .747 .93 r
.26358 .58151 .27101 .58795 .28225 .58494 .27484 .57858 Mtetra
.485 .7 .964 r
.27484 .57858 .28225 .58494 .29338 .58424 .28596 .57843 Mtetra
0 .251 .704 r
.28596 .57843 .29338 .58424 .30421 .58938 .29669 .58508 Mtetra
.767 .256 0 r
.29669 .58508 .30421 .58938 .31477 .60051 .30713 .59823 Mtetra
.478 0 0 r
.30713 .59823 .31477 .60051 .32578 .60643 .31815 .60427 Mtetra
.883 .873 .822 r
.31815 .60427 .32578 .60643 .33785 .59512 .33045 .59003 Mtetra
.899 .778 .719 r
.33045 .59003 .33785 .59512 .3504 .57431 .34325 .56601 Mtetra
.836 .74 .758 r
.34325 .56601 .3504 .57431 .36261 .55921 .35556 .54986 Mtetra
.717 .702 .835 r
.35556 .54986 .36261 .55921 .37443 .55232 .36739 .54337 Mtetra
.639 .686 .878 r
.36739 .54337 .37443 .55232 .38613 .54889 .3791 .54024 Mtetra
.654 .699 .88 r
.3791 .54024 .38613 .54889 .39788 .54582 .39089 .5366 Mtetra
.69 .699 .853 r
.39089 .5366 .39788 .54582 .40969 .54231 .40279 .53144 Mtetra
.702 .672 .817 r
.40279 .53144 .40969 .54231 .42158 .53808 .41476 .52522 Mtetra
.686 .635 .793 r
.41476 .52522 .42158 .53808 .43354 .53282 .42676 .51926 Mtetra
.659 .615 .793 r
.42676 .51926 .43354 .53282 .44557 .52678 .43876 .51457 Mtetra
.639 .625 .821 r
.43876 .51457 .44557 .52678 .45763 .52082 .45079 .51113 Mtetra
.626 .669 .871 r
.45079 .51113 .45763 .52082 .46971 .51563 .46285 .50832 Mtetra
.618 .729 .925 r
.46285 .50832 .46971 .51563 .48183 .51134 .47498 .50561 Mtetra
.612 .778 .961 r
.47498 .50561 .48183 .51134 .49399 .50769 .48717 .50273 Mtetra
.611 .806 .975 r
.48717 .50273 .49399 .50769 .5062 .50434 .49942 .49964 Mtetra
.615 .817 .978 r
.49942 .49964 .5062 .50434 .51847 .50104 .51174 .49634 Mtetra
.623 .821 .977 r
.51174 .49634 .51847 .50104 .5308 .49765 .52411 .49286 Mtetra
.63 .821 .974 r
.52411 .49286 .5308 .49765 .54319 .49411 .53654 .48923 Mtetra
.636 .821 .971 r
.53654 .48923 .54319 .49411 .55564 .4904 .54904 .48546 Mtetra
.642 .821 .969 r
.54904 .48546 .55564 .4904 .56814 .48652 .56158 .48155 Mtetra
.648 .823 .967 r
.56158 .48155 .56814 .48652 .58069 .48247 .57418 .47749 Mtetra
.653 .825 .966 r
.57418 .47749 .58069 .48247 .5933 .47825 .58684 .47329 Mtetra
.658 .829 .965 r
.58684 .47329 .5933 .47825 .60596 .47388 .59955 .46893 Mtetra
.664 .832 .964 r
.59955 .46893 .60596 .47388 .61867 .46942 .61231 .46439 Mtetra
.671 .832 .961 r
.61231 .46439 .61867 .46942 .63144 .465 .62512 .45966 Mtetra
.681 .825 .953 r
.62512 .45966 .63144 .465 .64428 .46087 .63798 .45471 Mtetra
.688 .801 .935 r
.63798 .45471 .64428 .46087 .6572 .45741 .65088 .4496 Mtetra
.684 .751 .902 r
.65088 .4496 .6572 .45741 .67023 .45487 .66384 .44457 Mtetra
.661 .682 .86 r
.66384 .44457 .67023 .45487 .68336 .45313 .67688 .44018 Mtetra
.625 .618 .824 r
.67688 .44018 .68336 .45313 .69659 .45148 .69005 .43707 Mtetra
.594 .582 .809 r
.69005 .43707 .69659 .45148 .70985 .44903 .70336 .43528 Mtetra
.587 .588 .82 r
.70336 .43528 .70985 .44903 .72312 .44553 .71676 .43375 Mtetra
.613 .635 .849 r
.71676 .43375 .72312 .44553 .73641 .44129 .73019 .43115 Mtetra
.653 .687 .87 r
.73019 .43115 .73641 .44129 .74973 .43661 .74358 .427 Mtetra
.667 .706 .876 r
.74358 .427 .74973 .43661 .76315 .4323 .75701 .42232 Mtetra
.567 .653 .893 r
.75701 .42232 .76315 .4323 .7769 .43155 .77076 .42111 Mtetra
.144 .393 .842 r
.77076 .42111 .7769 .43155 .79144 .43929 .7854 .42989 Mtetra
0 .073 .625 r
.7854 .42989 .79144 .43929 .80665 .45288 .8009 .44675 Mtetra
.025 .442 .87 r
.8009 .44675 .80665 .45288 .82117 .45646 .81573 .45331 Mtetra
.893 .938 .836 r
.81573 .45331 .82117 .45646 .83413 .44202 .82876 .43864 Mtetra
.955 .9 .731 r
.82876 .43864 .83413 .44202 .84653 .4222 .84104 .41661 Mtetra
.885 .873 .819 r
.84104 .41661 .84653 .4222 .85952 .40873 .85394 .40147 Mtetra
.753 .809 .897 r
.85394 .40147 .85952 .40873 .87317 .40141 .86757 .39351 Mtetra
.674 .764 .918 r
.86757 .39351 .87317 .40141 .88713 .39654 .88157 .38848 Mtetra
.629 .746 .931 r
.25609 .57501 .26358 .58151 .27484 .57858 .26737 .57216 Mtetra
.449 .684 .965 r
.26737 .57216 .27484 .57858 .28596 .57843 .27847 .57252 Mtetra
0 .126 .586 r
.27847 .57252 .28596 .57843 .29669 .58508 .28912 .58056 Mtetra
.807 .319 0 r
.28912 .58056 .29669 .58508 .30713 .59823 .29942 .59562 Mtetra
.492 0 0 r
.29942 .59562 .30713 .59823 .31815 .60427 .31044 .60208 Mtetra
.899 .858 .792 r
.31044 .60208 .31815 .60427 .33045 .59003 .32295 .58542 Mtetra
.911 .779 .702 r
.32295 .58542 .33045 .59003 .34325 .56601 .33601 .55817 Mtetra
.851 .748 .749 r
.33601 .55817 .34325 .56601 .35556 .54986 .34847 .5403 Mtetra
.727 .702 .827 r
.34847 .5403 .35556 .54986 .36739 .54337 .36036 .5332 Mtetra
.663 .67 .846 r
.36036 .5332 .36739 .54337 .3791 .54024 .37213 .52905 Mtetra
.682 .658 .821 r
.37213 .52905 .3791 .54024 .39089 .5366 .38401 .52379 Mtetra
.683 .635 .795 r
.38401 .52379 .39089 .5366 .40279 .53144 .39594 .51802 Mtetra
.658 .616 .796 r
.39594 .51802 .40279 .53144 .41476 .52522 .40787 .51346 Mtetra
.629 .628 .831 r
.40787 .51346 .41476 .52522 .42676 .51926 .4198 .51047 Mtetra
.606 .683 .896 r
.4198 .51047 .42676 .51926 .43876 .51457 .43176 .50825 Mtetra
.589 .75 .954 r
.43176 .50825 .43876 .51457 .45079 .51113 .44379 .50604 Mtetra
.583 .791 .978 r
.44379 .50604 .45079 .51113 .46285 .50832 .45588 .50355 Mtetra
.592 .806 .982 r
.45588 .50355 .46285 .50832 .47498 .50561 .46805 .50076 Mtetra
.606 .809 .978 r
.46805 .50076 .47498 .50561 .48717 .50273 .48029 .49771 Mtetra
.618 .808 .973 r
.48029 .49771 .48717 .50273 .49942 .49964 .49258 .49444 Mtetra
.627 .805 .968 r
.49258 .49444 .49942 .49964 .51174 .49634 .50494 .49099 Mtetra
.635 .803 .964 r
.50494 .49099 .51174 .49634 .52411 .49286 .51736 .4874 Mtetra
.64 .802 .961 r
.51736 .4874 .52411 .49286 .53654 .48923 .52983 .48367 Mtetra
.645 .801 .958 r
.52983 .48367 .53654 .48923 .54904 .48546 .54237 .47984 Mtetra
.648 .801 .956 r
.54237 .47984 .54904 .48546 .56158 .48155 .55496 .4759 Mtetra
.652 .802 .955 r
.55496 .4759 .56158 .48155 .57418 .47749 .5676 .47186 Mtetra
.655 .805 .955 r
.5676 .47186 .57418 .47749 .58684 .47329 .58031 .46771 Mtetra
.658 .809 .955 r
.58031 .46771 .58684 .47329 .59955 .46893 .59307 .46343 Mtetra
.663 .814 .956 r
.59307 .46343 .59955 .46893 .61231 .46439 .60588 .459 Mtetra
.669 .821 .956 r
.60588 .459 .61231 .46439 .62512 .45966 .61874 .45437 Mtetra
.676 .827 .956 r
.61874 .45437 .62512 .45966 .63798 .45471 .63165 .44949 Mtetra
.684 .833 .955 r
.63165 .44949 .63798 .45471 .65088 .4496 .64461 .44435 Mtetra
.694 .836 .951 r
.64461 .44435 .65088 .4496 .66384 .44457 .6576 .43891 Mtetra
.704 .826 .941 r
.6576 .43891 .66384 .44457 .67688 .44018 .67064 .43321 Mtetra
.702 .785 .915 r
.67064 .43321 .67688 .44018 .69005 .43707 .68372 .42753 Mtetra
.674 .708 .873 r
.68372 .42753 .69005 .43707 .70336 .43528 .6969 .42262 Mtetra
.628 .627 .831 r
.6969 .42262 .70336 .43528 .71676 .43375 .71022 .41933 Mtetra
.598 .586 .81 r
.71022 .41933 .71676 .43375 .73019 .43115 .7237 .41729 Mtetra
.609 .6 .817 r
.7237 .41729 .73019 .43115 .74358 .427 .73722 .41474 Mtetra
.636 .64 .837 r
.73722 .41474 .74358 .427 .75701 .42232 .75074 .41107 Mtetra
.554 .619 .872 r
.75074 .41107 .75701 .42232 .77076 .42111 .76456 .41045 Mtetra
.06 .332 .811 r
.76456 .41045 .77076 .42111 .7854 .42989 .77935 .42096 Mtetra
0 0 .5 r
.77935 .42096 .7854 .42989 .8009 .44675 .79514 .44112 Mtetra
0 .3 .762 r
.79514 .44112 .8009 .44675 .81573 .45331 .81023 .45011 Mtetra
.899 .936 .828 r
.81023 .45011 .81573 .45331 .82876 .43864 .82329 .43489 Mtetra
.961 .885 .71 r
.82329 .43489 .82876 .43864 .84104 .41661 .83547 .41077 Mtetra
.898 .866 .798 r
.83547 .41077 .84104 .41661 .85394 .40147 .84829 .3941 Mtetra
.765 .811 .89 r
.84829 .3941 .85394 .40147 .86757 .39351 .86193 .38553 Mtetra
.677 .765 .917 r
.86193 .38553 .86757 .39351 .88157 .38848 .87596 .38036 Mtetra
.625 .745 .933 r
.24855 .56847 .25609 .57501 .26737 .57216 .25985 .56569 Mtetra
.412 .667 .966 r
.25985 .56569 .26737 .57216 .27847 .57252 .27093 .56652 Mtetra
.51 0 0 r
.27093 .56652 .27847 .57252 .28912 .58056 .28149 .57577 Mtetra
.833 .361 .028 r
.28149 .57577 .28912 .58056 .29942 .59562 .29167 .59248 Mtetra
.509 0 0 r
.29167 .59248 .29942 .59562 .31044 .60208 .30267 .59954 Mtetra
.903 .843 .774 r
.30267 .59954 .31044 .60208 .32295 .58542 .31535 .58125 Mtetra
.92 .778 .688 r
.31535 .58125 .32295 .58542 .33601 .55817 .32869 .5508 Mtetra
.871 .753 .73 r
.32869 .5508 .33601 .55817 .34847 .5403 .34139 .52974 Mtetra
.754 .693 .793 r
.34139 .52974 .34847 .5403 .36036 .5332 .35342 .52024 Mtetra
.673 .628 .796 r
.35342 .52024 .36036 .5332 .37213 .52905 .36526 .51499 Mtetra
.646 .602 .79 r
.36526 .51499 .37213 .52905 .38401 .52379 .37709 .51091 Mtetra
.618 .605 .816 r
.37709 .51091 .38401 .52379 .39594 .51802 .38891 .50828 Mtetra
.586 .652 .882 r
.38891 .50828 .39594 .51802 .40787 .51346 .40075 .50673 Mtetra
.558 .725 .952 r
.40075 .50673 .40787 .51346 .4198 .51047 .41266 .50526 Mtetra
.551 .776 .982 r
.41266 .50526 .4198 .51047 .43176 .50825 .42465 .50339 Mtetra
.571 .796 .984 r
.42465 .50339 .43176 .50825 .44379 .50604 .43672 .50102 Mtetra
.596 .8 .977 r
.43672 .50102 .44379 .50604 .45588 .50355 .44886 .49822 Mtetra
.617 .796 .968 r
.44886 .49822 .45588 .50355 .46805 .50076 .46107 .49508 Mtetra
.63 .789 .958 r
.46107 .49508 .46805 .50076 .48029 .49771 .47335 .4917 Mtetra
.638 .782 .95 r
.47335 .4917 .48029 .49771 .49258 .49444 .48569 .48816 Mtetra
.643 .775 .944 r
.48569 .48816 .49258 .49444 .50494 .49099 .49809 .48451 Mtetra
.647 .771 .939 r
.49809 .48451 .50494 .49099 .51736 .4874 .51054 .48078 Mtetra
.649 .769 .936 r
.51054 .48078 .51736 .4874 .52983 .48367 .52306 .47698 Mtetra
.652 .768 .934 r
.52306 .47698 .52983 .48367 .54237 .47984 .53563 .47309 Mtetra
.654 .768 .933 r
.53563 .47309 .54237 .47984 .55496 .4759 .54826 .46911 Mtetra
.657 .768 .932 r
.54826 .46911 .55496 .4759 .5676 .47186 .56095 .46504 Mtetra
.659 .769 .931 r
.56095 .46504 .5676 .47186 .58031 .46771 .57369 .46089 Mtetra
.661 .771 .931 r
.57369 .46089 .58031 .46771 .59307 .46343 .5865 .45666 Mtetra
.663 .774 .932 r
.5865 .45666 .59307 .46343 .60588 .459 .59936 .45234 Mtetra
.665 .779 .934 r
.59936 .45234 .60588 .459 .61874 .45437 .61227 .44793 Mtetra
.668 .789 .938 r
.61227 .44793 .61874 .45437 .63165 .44949 .62524 .44338 Mtetra
.675 .802 .943 r
.62524 .44338 .63165 .44949 .64461 .44435 .63825 .4386 Mtetra
.685 .818 .947 r
.63825 .4386 .64461 .44435 .6576 .43891 .65131 .43344 Mtetra
.7 .833 .946 r
.65131 .43344 .6576 .43891 .67064 .43321 .66441 .4278 Mtetra
.715 .84 .941 r
.66441 .4278 .67064 .43321 .68372 .42753 .67753 .42164 Mtetra
.727 .828 .928 r
.67753 .42164 .68372 .42753 .6969 .42262 .69067 .41509 Mtetra
.719 .778 .899 r
.69067 .41509 .6969 .42262 .71022 .41933 .70387 .40866 Mtetra
.678 .689 .853 r
.70387 .40866 .71022 .41933 .7237 .41729 .71717 .40333 Mtetra
.635 .613 .811 r
.71717 .40333 .7237 .41729 .73722 .41474 .73063 .3995 Mtetra
.607 .582 .799 r
.73063 .3995 .73722 .41474 .75074 .41107 .74424 .39691 Mtetra
.499 .538 .828 r
.74424 .39691 .75074 .41107 .76456 .41045 .75825 .39872 Mtetra
0 .23 .748 r
.75825 .39872 .76456 .41045 .77935 .42096 .7733 .41249 Mtetra
.602 .161 0 r
.7733 .41249 .77935 .42096 .79514 .44112 .78936 .4359 Mtetra
0 .199 .667 r
.78936 .4359 .79514 .44112 .81023 .45011 .80463 .44652 Mtetra
.906 .924 .818 r
.80463 .44652 .81023 .45011 .82329 .43489 .81772 .43058 Mtetra
.964 .869 .695 r
.81772 .43058 .82329 .43489 .83547 .41077 .82982 .40463 Mtetra
.907 .858 .781 r
.82982 .40463 .83547 .41077 .84829 .3941 .84259 .38661 Mtetra
.775 .813 .883 r
.84259 .38661 .84829 .3941 .86193 .38553 .85623 .37748 Mtetra
.68 .766 .916 r
.85623 .37748 .86193 .38553 .87596 .38036 .87031 .37216 Mtetra
.62 .744 .935 r
.24094 .56188 .24855 .56847 .25985 .56569 .25226 .55917 Mtetra
.373 .649 .964 r
.25226 .55917 .25985 .56569 .27093 .56652 .26332 .56046 Mtetra
.586 .053 0 r
.26332 .56046 .27093 .56652 .28149 .57577 .2738 .57075 Mtetra
.848 .387 .057 r
.2738 .57075 .28149 .57577 .29167 .59248 .28389 .58867 Mtetra
.498 0 0 r
.28389 .58867 .29167 .59248 .30267 .59954 .29487 .59611 Mtetra
.899 .821 .761 r
.29487 .59611 .30267 .59954 .31535 .58125 .3077 .57667 Mtetra
.921 .768 .675 r
.3077 .57667 .31535 .58125 .32869 .5508 .32133 .54313 Mtetra
.883 .745 .705 r
.32133 .54313 .32869 .5508 .34139 .52974 .33434 .51779 Mtetra
.769 .678 .763 r
.33434 .51779 .34139 .52974 .35342 .52024 .34652 .50596 Mtetra
.636 .594 .79 r
.34652 .50596 .35342 .52024 .36526 .51499 .35829 .50233 Mtetra
.555 .579 .833 r
.35829 .50233 .36526 .51499 .37709 .51091 .36996 .50197 Mtetra
.508 .639 .913 r
.36996 .50197 .37709 .51091 .38891 .50828 .38168 .50212 Mtetra
.495 .721 .972 r
.38168 .50212 .38891 .50828 .40075 .50673 .39351 .50154 Mtetra
.527 .769 .986 r
.39351 .50154 .40075 .50673 .41266 .50526 .40545 .50004 Mtetra
.573 .785 .979 r
.40545 .50004 .41266 .50526 .42465 .50339 .41749 .49774 Mtetra
.606 .782 .965 r
.41749 .49774 .42465 .50339 .43672 .50102 .42961 .49492 Mtetra
.623 .773 .952 r
.42961 .49492 .43672 .50102 .44886 .49822 .4418 .49178 Mtetra
.632 .766 .943 r
.4418 .49178 .44886 .49822 .46107 .49508 .45405 .48847 Mtetra
.637 .763 .939 r
.45405 .48847 .46107 .49508 .47335 .4917 .46636 .48503 Mtetra
.641 .763 .937 r
.46636 .48503 .47335 .4917 .48569 .48816 .47874 .48149 Mtetra
.644 .765 .937 r
.47874 .48149 .48569 .48816 .49809 .48451 .49117 .47784 Mtetra
.646 .767 .936 r
.49117 .47784 .49809 .48451 .51054 .48078 .50367 .47411 Mtetra
.648 .768 .936 r
.50367 .47411 .51054 .48078 .52306 .47698 .51622 .47029 Mtetra
.651 .77 .936 r
.51622 .47029 .52306 .47698 .53563 .47309 .52883 .46639 Mtetra
.653 .771 .936 r
.52883 .46639 .53563 .47309 .54826 .46911 .54151 .46241 Mtetra
.655 .773 .936 r
.54151 .46241 .54826 .46911 .56095 .46504 .55424 .45835 Mtetra
.657 .774 .936 r
.55424 .45835 .56095 .46504 .57369 .46089 .56702 .4542 Mtetra
.659 .776 .936 r
.56702 .4542 .57369 .46089 .5865 .45666 .57987 .44997 Mtetra
.662 .779 .935 r
.57987 .44997 .5865 .45666 .59936 .45234 .59277 .44563 Mtetra
.667 .78 .934 r
.59277 .44563 .59936 .45234 .61227 .44793 .60573 .44113 Mtetra
.671 .78 .931 r
.60573 .44113 .61227 .44793 .62524 .44338 .61874 .43647 Mtetra
.676 .779 .928 r
.61874 .43647 .62524 .44338 .63825 .4386 .6318 .43167 Mtetra
.68 .781 .927 r
.6318 .43167 .63825 .4386 .65131 .43344 .64492 .42672 Mtetra
.687 .791 .929 r
.64492 .42672 .65131 .43344 .66441 .4278 .65808 .42151 Mtetra
.702 .81 .932 r
.65808 .42151 .66441 .4278 .67753 .42164 .67127 .41579 Mtetra
.726 .831 .93 r
.67127 .41579 .67753 .42164 .69067 .41509 .68447 .40922 Mtetra
.752 .838 .917 r
.68447 .40922 .69067 .41509 .70387 .40866 .69767 .40167 Mtetra
.763 .808 .889 r
.69767 .40167 .70387 .40866 .71717 .40333 .71085 .3934 Mtetra
.731 .727 .847 r
.71085 .3934 .71717 .40333 .73063 .3995 .72411 .38568 Mtetra
.644 .621 .812 r
.72411 .38568 .73063 .3995 .74424 .39691 .73762 .38136 Mtetra
.441 .486 .809 r
.73762 .38136 .74424 .39691 .75825 .39872 .7518 .38553 Mtetra
0 .114 .666 r
.7518 .38553 .75825 .39872 .7733 .41249 .76717 .40366 Mtetra
.658 .224 0 r
.76717 .40366 .7733 .41249 .78936 .4359 .78348 .43023 Mtetra
0 .161 .645 r
.78348 .43023 .78936 .4359 .80463 .44652 .79888 .44195 Mtetra
.904 .899 .811 r
.79888 .44195 .80463 .44652 .81772 .43058 .81202 .42554 Mtetra
.963 .853 .686 r
.81202 .42554 .81772 .43058 .82982 .40463 .8241 .39824 Mtetra
.913 .851 .768 r
.8241 .39824 .82982 .40463 .84259 .38661 .83684 .37905 Mtetra
.785 .815 .876 r
.83684 .37905 .84259 .38661 .85623 .37748 .85048 .36937 Mtetra
.684 .767 .915 r
.85048 .36937 .85623 .37748 .87031 .37216 .8646 .36389 Mtetra
.615 .742 .936 r
.23327 .55524 .24094 .56188 .25226 .55917 .2446 .55263 Mtetra
.329 .628 .96 r
.2446 .55263 .25226 .55917 .26332 .56046 .25565 .55439 Mtetra
.642 .114 0 r
.25565 .55439 .26332 .56046 .2738 .57075 .26606 .56558 Mtetra
.854 .398 .068 r
.26606 .56558 .2738 .57075 .28389 .58867 .27608 .58408 Mtetra
.389 0 0 r
.27608 .58408 .28389 .58867 .29487 .59611 .28712 .59089 Mtetra
.888 .787 .743 r
.28712 .59089 .29487 .59611 .3077 .57667 .30012 .57003 Mtetra
.909 .746 .667 r
.30012 .57003 .3077 .57667 .32133 .54313 .31397 .53445 Mtetra
.881 .733 .693 r
.31397 .53445 .32133 .54313 .33434 .51779 .32719 .50685 Mtetra
.78 .696 .771 r
.32719 .50685 .33434 .51779 .34652 .50596 .33942 .49483 Mtetra
.582 .621 .856 r
.33942 .49483 .34652 .50596 .35829 .50233 .35108 .49344 Mtetra
.414 .597 .92 r
.35108 .49344 .35829 .50233 .36996 .50197 .36266 .49525 Mtetra
.404 .661 .964 r
.36266 .49525 .36996 .50197 .38168 .50212 .37437 .49623 Mtetra
.491 .73 .978 r
.37437 .49623 .38168 .50212 .39351 .50154 .38623 .49557 Mtetra
.563 .756 .968 r
.38623 .49557 .39351 .50154 .40545 .50004 .39822 .49369 Mtetra
.6 .757 .954 r
.39822 .49369 .40545 .50004 .41749 .49774 .4103 .49114 Mtetra
.618 .756 .944 r
.4103 .49114 .41749 .49774 .42961 .49492 .42245 .4882 Mtetra
.628 .757 .939 r
.42245 .4882 .42961 .49492 .4418 .49178 .43468 .48501 Mtetra
.635 .758 .937 r
.43468 .48501 .4418 .49178 .45405 .48847 .44697 .48163 Mtetra
.64 .758 .934 r
.44697 .48163 .45405 .48847 .46636 .48503 .45932 .47809 Mtetra
.644 .758 .931 r
.45932 .47809 .46636 .48503 .47874 .48149 .47173 .47444 Mtetra
.647 .756 .929 r
.47173 .47444 .47874 .48149 .49117 .47784 .4842 .47069 Mtetra
.65 .755 .926 r
.4842 .47069 .49117 .47784 .50367 .47411 .49674 .46686 Mtetra
.652 .754 .924 r
.49674 .46686 .50367 .47411 .51622 .47029 .50933 .46295 Mtetra
.654 .753 .922 r
.50933 .46295 .51622 .47029 .52883 .46639 .52198 .45896 Mtetra
.656 .752 .92 r
.52198 .45896 .52883 .46639 .54151 .46241 .53469 .45488 Mtetra
.658 .751 .918 r
.53469 .45488 .54151 .46241 .55424 .45835 .54746 .45073 Mtetra
.66 .75 .916 r
.54746 .45073 .55424 .45835 .56702 .4542 .56028 .4465 Mtetra
.661 .749 .915 r
.56028 .4465 .56702 .4542 .57987 .44997 .57317 .44222 Mtetra
.662 .749 .915 r
.57317 .44222 .57987 .44997 .59277 .44563 .58611 .4379 Mtetra
.661 .75 .916 r
.58611 .4379 .59277 .44563 .60573 .44113 .59911 .43357 Mtetra
.663 .756 .92 r
.59911 .43357 .60573 .44113 .61874 .43647 .61218 .42918 Mtetra
.667 .767 .925 r
.61218 .42918 .61874 .43647 .6318 .43167 .62529 .42462 Mtetra
.676 .778 .927 r
.62529 .42462 .6318 .43167 .64492 .42672 .63846 .41976 Mtetra
.688 .785 .925 r
.63846 .41976 .64492 .42672 .65808 .42151 .65166 .41449 Mtetra
.7 .788 .92 r
.65166 .41449 .65808 .42151 .67127 .41579 .66491 .40878 Mtetra
.716 .795 .913 r
.66491 .40878 .67127 .41579 .68447 .40922 .67817 .40246 Mtetra
.747 .812 .904 r
.67817 .40246 .68447 .40922 .69767 .40167 .69142 .39497 Mtetra
.783 .822 .883 r
.69142 .39497 .69767 .40167 .71085 .3934 .70462 .38579 Mtetra
.792 .8 .859 r
.70462 .38579 .71085 .3934 .72411 .38568 .71779 .37575 Mtetra
.71 .722 .859 r
.71779 .37575 .72411 .38568 .73762 .38136 .73119 .36905 Mtetra
.389 .51 .859 r
.73119 .36905 .73762 .38136 .7518 .38553 .74539 .37333 Mtetra
0 .014 .586 r
.74539 .37333 .7518 .38553 .76717 .40366 .76092 .39374 Mtetra
.657 .239 0 r
.76092 .39374 .76717 .40366 .78348 .43023 .77738 .42235 Mtetra
0 .172 .691 r
.77738 .42235 .78348 .43023 .79888 .44195 .79292 .4355 Mtetra
.881 .853 .81 r
.79292 .4355 .79888 .44195 .81202 .42554 .80618 .41965 Mtetra
.958 .839 .683 r
.80618 .41965 .81202 .42554 .8241 .39824 .81831 .39166 Mtetra
.919 .847 .757 r
.81831 .39166 .8241 .39824 .83684 .37905 .83103 .37146 Mtetra
.795 .818 .87 r
.83103 .37146 .83684 .37905 .85048 .36937 .84468 .3612 Mtetra
.687 .769 .914 r
.84468 .3612 .85048 .36937 .8646 .36389 .85884 .35556 Mtetra
.609 .741 .939 r
.22553 .54857 .23327 .55524 .2446 .55263 .23688 .54606 Mtetra
.278 .602 .952 r
.23688 .54606 .2446 .55263 .25565 .55439 .2479 .54832 Mtetra
.683 .16 0 r
.2479 .54832 .25565 .55439 .26606 .56558 .25824 .56026 Mtetra
.85 .391 .056 r
.25824 .56026 .26606 .56558 .27608 .58408 .26827 .57851 Mtetra
0 .431 .839 r
.26827 .57851 .27608 .58408 .28712 .59089 .27948 .58308 Mtetra
.872 .747 .721 r
.27948 .58308 .28712 .59089 .30012 .57003 .29268 .56015 Mtetra
.887 .718 .666 r
.29268 .56015 .30012 .57003 .31397 .53445 .30659 .5253 Mtetra
.871 .729 .702 r
.30659 .5253 .31397 .53445 .32719 .50685 .31974 .50003 Mtetra
.806 .777 .826 r
.31974 .50003 .32719 .50685 .33942 .49483 .33195 .48919 Mtetra
.557 .763 .974 r
.33195 .48919 .33942 .49483 .35108 .49344 .34367 .48735 Mtetra
.368 .667 .972 r
.34367 .48735 .35108 .49344 .36266 .49525 .35531 .48841 Mtetra
.429 .671 .963 r
.35531 .48841 .36266 .49525 .37437 .49623 .36705 .48904 Mtetra
.519 .7 .952 r
.36705 .48904 .37437 .49623 .38623 .49557 .37894 .48834 Mtetra
.575 .721 .942 r
.37894 .48834 .38623 .49557 .39822 .49369 .39096 .48652 Mtetra
.605 .735 .937 r
.39096 .48652 .39822 .49369 .4103 .49114 .40306 .48398 Mtetra
.621 .742 .933 r
.40306 .48398 .4103 .49114 .42245 .4882 .41525 .48101 Mtetra
.631 .745 .93 r
.41525 .48101 .42245 .4882 .43468 .48501 .42751 .47778 Mtetra
.637 .746 .928 r
.42751 .47778 .43468 .48501 .44697 .48163 .43983 .47437 Mtetra
.641 .748 .926 r
.43983 .47437 .44697 .48163 .45932 .47809 .45222 .47082 Mtetra
.644 .749 .926 r
.45222 .47082 .45932 .47809 .47173 .47444 .46467 .46718 Mtetra
.646 .751 .926 r
.46467 .46718 .47173 .47444 .4842 .47069 .47718 .46345 Mtetra
.647 .754 .927 r
.47718 .46345 .4842 .47069 .49674 .46686 .48974 .45965 Mtetra
.649 .756 .928 r
.48974 .45965 .49674 .46686 .50933 .46295 .50237 .45579 Mtetra
.651 .759 .929 r
.50237 .45579 .50933 .46295 .52198 .45896 .51506 .45185 Mtetra
.653 .762 .93 r
.51506 .45185 .52198 .45896 .53469 .45488 .52781 .44783 Mtetra
.655 .766 .931 r
.52781 .44783 .53469 .45488 .54746 .45073 .54062 .44372 Mtetra
.657 .769 .932 r
.54062 .44372 .54746 .45073 .56028 .4465 .55349 .43951 Mtetra
.661 .771 .931 r
.55349 .43951 .56028 .4465 .57317 .44222 .56642 .43518 Mtetra
.666 .773 .929 r
.56642 .43518 .57317 .44222 .58611 .4379 .5794 .43068 Mtetra
.672 .77 .924 r
.5794 .43068 .58611 .4379 .59911 .43357 .59244 .42598 Mtetra
.675 .762 .916 r
.59244 .42598 .59911 .43357 .61218 .42918 .60553 .42114 Mtetra
.675 .75 .907 r
.60553 .42114 .61218 .42918 .62529 .42462 .61868 .41626 Mtetra
.673 .742 .902 r
.61868 .41626 .62529 .42462 .63846 .41976 .63189 .41142 Mtetra
.675 .744 .903 r
.63189 .41142 .63846 .41976 .65166 .41449 .64516 .4065 Mtetra
.689 .759 .905 r
.64516 .4065 .65166 .41449 .66491 .40878 .65846 .40108 Mtetra
.715 .777 .901 r
.65846 .40108 .66491 .40878 .67817 .40246 .67177 .3947 Mtetra
.744 .784 .885 r
.67177 .3947 .67817 .40246 .69142 .39497 .68507 .38704 Mtetra
.77 .788 .868 r
.68507 .38704 .69142 .39497 .70462 .38579 .69833 .37805 Mtetra
.778 .796 .867 r
.69833 .37805 .70462 .38579 .71779 .37575 .71159 .3687 Mtetra
.714 .799 .918 r
.71159 .3687 .71779 .37575 .73119 .36905 .72507 .36238 Mtetra
.273 .599 .951 r
.72507 .36238 .73119 .36905 .74539 .37333 .73923 .36536 Mtetra
0 0 .504 r
.73923 .36536 .74539 .37333 .76092 .39374 .75459 .38326 Mtetra
.622 .212 0 r
.75459 .38326 .76092 .39374 .77738 .42235 .77096 .41103 Mtetra
0 .177 .713 r
.77096 .41103 .77738 .42235 .79292 .4355 .78669 .42628 Mtetra
.826 .785 .813 r
.78669 .42628 .79292 .4355 .80618 .41965 .80021 .41272 Mtetra
.949 .824 .687 r
.80021 .41272 .80618 .41965 .81831 .39166 .81245 .38492 Mtetra
.923 .843 .748 r
.81245 .38492 .81831 .39166 .83103 .37146 .82518 .36385 Mtetra
.805 .822 .864 r
.82518 .36385 .83103 .37146 .84468 .3612 .83883 .353 Mtetra
.691 .772 .913 r
.83883 .353 .84468 .3612 .85884 .35556 .85303 .34716 Mtetra
.602 .739 .941 r
.21773 .54185 .22553 .54857 .23688 .54606 .2291 .53947 Mtetra
.222 .573 .941 r
.2291 .53947 .23688 .54606 .2479 .54832 .24008 .54224 Mtetra
.705 .186 0 r
.24008 .54224 .2479 .54832 .25824 .56026 .25038 .55467 Mtetra
.831 .358 .004 r
.25038 .55467 .25824 .56026 .26827 .57851 .26048 .57165 Mtetra
.4 .66 .964 r
.26048 .57165 .26827 .57851 .27948 .58308 .27197 .5726 Mtetra
.858 .715 .703 r
.27197 .5726 .27948 .58308 .29268 .56015 .28537 .5478 Mtetra
.864 .698 .674 r
.28537 .5478 .29268 .56015 .30659 .5253 .29912 .5166 Mtetra
.853 .738 .736 r
.29912 .5166 .30659 .5253 .31974 .50003 .31198 .49703 Mtetra
.806 .888 .904 r
.31198 .49703 .31974 .50003 .33195 .48919 .32413 .48806 Mtetra
.575 .912 .972 r
.32413 .48806 .33195 .48919 .34367 .48735 .33604 .48373 Mtetra
.508 .818 1 r
.33604 .48373 .34367 .48735 .35531 .48841 .34788 .4817 Mtetra
.517 .716 .962 r
.34788 .4817 .35531 .48841 .36705 .48904 .35972 .48085 Mtetra
.541 .68 .929 r
.35972 .48085 .36705 .48904 .37894 .48834 .37164 .47997 Mtetra
.571 .688 .92 r
.37164 .47997 .37894 .48834 .39096 .48652 .38367 .47842 Mtetra
.597 .707 .92 r
.38367 .47842 .39096 .48652 .40306 .48398 .39579 .47617 Mtetra
.616 .723 .922 r
.39579 .47617 .40306 .48398 .41525 .48101 .408 .47338 Mtetra
.628 .733 .923 r
.408 .47338 .41525 .48101 .42751 .47778 .42029 .47023 Mtetra
.634 .738 .923 r
.42029 .47023 .42751 .47778 .43983 .47437 .43264 .46687 Mtetra
.639 .742 .923 r
.43264 .46687 .43983 .47437 .45222 .47082 .44506 .46336 Mtetra
.643 .745 .924 r
.44506 .46336 .45222 .47082 .46467 .46718 .45754 .45972 Mtetra
.646 .748 .923 r
.45754 .45972 .46467 .46718 .47718 .46345 .47009 .45596 Mtetra
.649 .749 .922 r
.47009 .45596 .47718 .46345 .48974 .45965 .4827 .4521 Mtetra
.651 .749 .921 r
.4827 .4521 .48974 .45965 .50237 .45579 .49536 .44815 Mtetra
.654 .748 .919 r
.49536 .44815 .50237 .45579 .51506 .45185 .50809 .44411 Mtetra
.656 .747 .917 r
.50809 .44411 .51506 .45185 .52781 .44783 .52088 .43999 Mtetra
.657 .745 .915 r
.52088 .43999 .52781 .44783 .54062 .44372 .53373 .43581 Mtetra
.658 .744 .914 r
.53373 .43581 .54062 .44372 .55349 .43951 .54663 .43158 Mtetra
.658 .745 .914 r
.54663 .43158 .55349 .43951 .56642 .43518 .5596 .42735 Mtetra
.657 .748 .917 r
.5596 .42735 .56642 .43518 .5794 .43068 .57263 .42311 Mtetra
.657 .757 .924 r
.57263 .42311 .5794 .43068 .59244 .42598 .58572 .41885 Mtetra
.662 .773 .931 r
.58572 .41885 .59244 .42598 .60553 .42114 .59887 .41438 Mtetra
.676 .789 .935 r
.59887 .41438 .60553 .42114 .61868 .41626 .61206 .40945 Mtetra
.693 .794 .927 r
.61206 .40945 .61868 .41626 .63189 .41142 .6253 .40393 Mtetra
.705 .779 .909 r
.6253 .40393 .63189 .41142 .64516 .4065 .63857 .39794 Mtetra
.707 .752 .887 r
.63857 .39794 .64516 .4065 .65846 .40108 .65189 .39171 Mtetra
.71 .734 .87 r
.65189 .39171 .65846 .40108 .67177 .3947 .66524 .38518 Mtetra
.722 .736 .863 r
.66524 .38518 .67177 .3947 .68507 .38704 .6786 .37803 Mtetra
.731 .752 .869 r
.6786 .37803 .68507 .38704 .69833 .37805 .692 .37061 Mtetra
.712 .788 .911 r
.692 .37061 .69833 .37805 .71159 .3687 .70549 .36427 Mtetra
.6 .85 .991 r
.70549 .36427 .71159 .3687 .72507 .36238 .71919 .36036 Mtetra
.1 .635 .862 r
.71919 .36036 .72507 .36238 .73923 .36536 .73327 .3613 Mtetra
.483 0 0 r
.73327 .3613 .73923 .36536 .75459 .38326 .74824 .37318 Mtetra
0 0 .423 r
.74824 .37318 .75459 .38326 .77096 .41103 .76431 .39709 Mtetra
0 .166 .701 r
.76431 .39709 .77096 .41103 .78669 .42628 .78018 .41423 Mtetra
.748 .709 .815 r
.78018 .41423 .78669 .42628 .80021 .41272 .79406 .40441 Mtetra
.932 .806 .698 r
.79406 .40441 .80021 .41272 .81245 .38492 .8065 .37786 Mtetra
.923 .837 .742 r
.8065 .37786 .81245 .38492 .82518 .36385 .81927 .35621 Mtetra
.815 .825 .858 r
.81927 .35621 .82518 .36385 .83883 .353 .83294 .34475 Mtetra
.696 .775 .912 r
.83294 .34475 .83883 .353 .85303 .34716 .84717 .33871 Mtetra
.595 .738 .943 r
.20987 .53509 .21773 .54185 .2291 .53947 .22124 .53284 Mtetra
.173 .545 .928 r
.22124 .53284 .2291 .53947 .24008 .54224 .23221 .53605 Mtetra
.703 .185 0 r
.23221 .53605 .24008 .54224 .25038 .55467 .24249 .54848 Mtetra
.777 .28 0 r
.24249 .54848 .25038 .55467 .26048 .57165 .25275 .56328 Mtetra
.624 .707 .905 r
.25275 .56328 .26048 .57165 .27197 .5726 .26455 .56038 Mtetra
.847 .697 .696 r
.26455 .56038 .27197 .5726 .28537 .5478 .27805 .53511 Mtetra
.849 .693 .689 r
.27805 .53511 .28537 .5478 .29912 .5166 .29153 .50868 Mtetra
.825 .755 .785 r
.29153 .50868 .29912 .5166 .31198 .49703 .30408 .49475 Mtetra
.726 .914 .959 r
.30408 .49475 .31198 .49703 .32413 .48806 .31614 .48835 Mtetra
.587 .939 .929 r
.31614 .48835 .32413 .48806 .33604 .48373 .32818 .48282 Mtetra
.64 .937 .964 r
.32818 .48282 .33604 .48373 .34788 .4817 .34025 .47734 Mtetra
.64 .837 .976 r
.34025 .47734 .34788 .4817 .35972 .48085 .35229 .47341 Mtetra
.595 .725 .935 r
.35229 .47341 .35972 .48085 .37164 .47997 .36431 .4711 Mtetra
.58 .68 .909 r
.36431 .4711 .37164 .47997 .38367 .47842 .37636 .46937 Mtetra
.589 .68 .904 r
.37636 .46937 .38367 .47842 .39579 .47617 .3885 .46742 Mtetra
.604 .694 .907 r
.3885 .46742 .39579 .47617 .408 .47338 .40072 .46501 Mtetra
.618 .711 .912 r
.40072 .46501 .408 .47338 .42029 .47023 .41302 .46215 Mtetra
.629 .723 .915 r
.41302 .46215 .42029 .47023 .43264 .46687 .4254 .45893 Mtetra
.638 .731 .916 r
.4254 .45893 .43264 .46687 .44506 .46336 .43785 .45545 Mtetra
.643 .735 .915 r
.43785 .45545 .44506 .46336 .45754 .45972 .45037 .45178 Mtetra
.646 .736 .914 r
.45037 .45178 .45754 .45972 .47009 .45596 .46295 .448 Mtetra
.649 .737 .914 r
.46295 .448 .47009 .45596 .4827 .4521 .47559 .44411 Mtetra
.652 .738 .913 r
.47559 .44411 .4827 .4521 .49536 .44815 .48829 .44012 Mtetra
.655 .739 .912 r
.48829 .44012 .49536 .44815 .50809 .44411 .50106 .43602 Mtetra
.659 .739 .91 r
.50106 .43602 .50809 .44411 .52088 .43999 .51388 .43177 Mtetra
.662 .738 .906 r
.51388 .43177 .52088 .43999 .53373 .43581 .52677 .42738 Mtetra
.666 .735 .902 r
.52677 .42738 .53373 .43581 .54663 .43158 .53971 .42284 Mtetra
.669 .729 .895 r
.53971 .42284 .54663 .43158 .5596 .42735 .55271 .41817 Mtetra
.669 .719 .886 r
.55271 .41817 .5596 .42735 .57263 .42311 .56577 .4134 Mtetra
.668 .707 .877 r
.56577 .4134 .57263 .42311 .58572 .41885 .57889 .40862 Mtetra
.662 .694 .87 r
.57889 .40862 .58572 .41885 .59887 .41438 .59206 .40401 Mtetra
.656 .69 .87 r
.59206 .40401 .59887 .41438 .61206 .40945 .60531 .39962 Mtetra
.66 .704 .88 r
.60531 .39962 .61206 .40945 .6253 .40393 .61861 .39509 Mtetra
.683 .738 .892 r
.61861 .39509 .6253 .40393 .63857 .39794 .63195 .38974 Mtetra
.718 .767 .891 r
.63195 .38974 .63857 .39794 .65189 .39171 .6453 .38311 Mtetra
.731 .761 .877 r
.6453 .38311 .65189 .39171 .66524 .38518 .65866 .37581 Mtetra
.705 .735 .875 r
.65866 .37581 .66524 .38518 .6786 .37803 .67211 .36944 Mtetra
.65 .735 .912 r
.67211 .36944 .6786 .37803 .692 .37061 .68572 .36523 Mtetra
.555 .8 .99 r
.68572 .36523 .692 .37061 .70549 .36427 .69948 .36262 Mtetra
.389 .832 .942 r
.69948 .36262 .70549 .36427 .71919 .36036 .71332 .35985 Mtetra
.215 .738 .835 r
.71332 .35985 .71919 .36036 .73327 .3613 .72729 .35796 Mtetra
0 .364 .733 r
.72729 .35796 .73327 .3613 .74824 .37318 .7419 .36388 Mtetra
0 0 .535 r
.7419 .36388 .74824 .37318 .76431 .39709 .7576 .38274 Mtetra
0 .156 .694 r
.7576 .38274 .76431 .39709 .78018 .41423 .77349 .4003 Mtetra
.668 .645 .818 r
.77349 .4003 .78018 .41423 .79406 .40441 .78774 .39446 Mtetra
.906 .783 .713 r
.78774 .39446 .79406 .40441 .8065 .37786 .80045 .37016 Mtetra
.917 .826 .741 r
.80045 .37016 .8065 .37786 .81927 .35621 .8133 .34843 Mtetra
.822 .824 .851 r
.8133 .34843 .81927 .35621 .83294 .34475 .82698 .33644 Mtetra
.7 .777 .911 r
.82698 .33644 .83294 .34475 .84717 .33871 .84125 .33019 Mtetra
.589 .736 .945 r
.20194 .52828 .20987 .53509 .22124 .53284 .21333 .52613 Mtetra
.148 .529 .919 r
.21333 .52613 .22124 .53284 .23221 .53605 .22428 .52957 Mtetra
.667 .145 0 r
.22428 .52957 .23221 .53605 .24249 .54848 .2346 .54143 Mtetra
.645 .13 0 r
.2346 .54143 .24249 .54848 .25275 .56328 .24507 .55353 Mtetra
.698 .699 .847 r
.24507 .55353 .25275 .56328 .26455 .56038 .25711 .54774 Mtetra
.84 .693 .7 r
.25711 .54774 .26455 .56038 .27805 .53511 .27058 .52372 Mtetra
.842 .705 .712 r
.27058 .52372 .27805 .53511 .29153 .50868 .28382 .50166 Mtetra
.8 .776 .831 r
.28382 .50166 .29153 .50868 .30408 .49475 .29619 .4911 Mtetra
.658 .863 .977 r
.29619 .4911 .30408 .49475 .31614 .48835 .30817 .48661 Mtetra
.599 .907 .983 r
.30817 .48661 .31614 .48835 .32818 .48282 .32019 .48224 Mtetra
.659 .949 .955 r
.32019 .48224 .32818 .48282 .34025 .47734 .33236 .4762 Mtetra
.705 .947 .957 r
.33236 .4762 .34025 .47734 .35229 .47341 .3446 .4696 Mtetra
.695 .869 .964 r
.3446 .4696 .35229 .47341 .36431 .4711 .35681 .4642 Mtetra
.643 .759 .933 r
.35681 .4642 .36431 .4711 .37636 .46937 .36899 .46056 Mtetra
.609 .696 .905 r
.36899 .46056 .37636 .46937 .3885 .46742 .38117 .45797 Mtetra
.604 .679 .894 r
.38117 .45797 .3885 .46742 .40072 .46501 .39341 .45558 Mtetra
.611 .683 .893 r
.39341 .45558 .40072 .46501 .41302 .46215 .40574 .45296 Mtetra
.62 .693 .896 r
.40574 .45296 .41302 .46215 .4254 .45893 .41813 .45003 Mtetra
.628 .704 .9 r
.41813 .45003 .4254 .45893 .43785 .45545 .4306 .44682 Mtetra
.636 .715 .904 r
.4306 .44682 .43785 .45545 .45037 .45178 .44315 .44336 Mtetra
.643 .723 .907 r
.44315 .44336 .45037 .45178 .46295 .448 .45576 .43966 Mtetra
.649 .729 .907 r
.45576 .43966 .46295 .448 .47559 .44411 .46843 .43574 Mtetra
.655 .731 .905 r
.46843 .43574 .47559 .44411 .48829 .44012 .48117 .43162 Mtetra
.659 .73 .902 r
.48117 .43162 .48829 .44012 .50106 .43602 .49397 .42735 Mtetra
.661 .727 .898 r
.49397 .42735 .50106 .43602 .51388 .43177 .50684 .42297 Mtetra
.662 .725 .896 r
.50684 .42297 .51388 .43177 .52677 .42738 .51976 .41854 Mtetra
.51976 .41854 .52677 .42738 .53971 .42284 .53274 .41409 Mtetra
.663 .729 .898 r
.53274 .41409 .53971 .42284 .55271 .41817 .54578 .40957 Mtetra
.668 .735 .9 r
.54578 .40957 .55271 .41817 .56577 .4134 .55887 .40485 Mtetra
.678 .741 .898 r
.55887 .40485 .56577 .4134 .57889 .40862 .57202 .39978 Mtetra
.691 .739 .888 r
.57202 .39978 .57889 .40862 .59206 .40401 .58522 .39415 Mtetra
.697 .718 .865 r
.58522 .39415 .59206 .40401 .60531 .39962 .59846 .38806 Mtetra
.686 .68 .839 r
.59846 .38806 .60531 .39962 .61861 .39509 .61176 .38209 Mtetra
.663 .647 .823 r
.61176 .38209 .61861 .39509 .63195 .38974 .62512 .37688 Mtetra
.644 .641 .832 r
.62512 .37688 .63195 .38974 .6453 .38311 .63858 .37259 Mtetra
.635 .682 .877 r
.63858 .37259 .6453 .38311 .65866 .37581 .65213 .36886 Mtetra
.603 .767 .958 r
.65213 .36886 .65866 .37581 .67211 .36944 .66578 .36576 Mtetra
.476 .823 .998 r
.66578 .36576 .67211 .36944 .68572 .36523 .67955 .36347 Mtetra
.369 .818 .942 r
.67955 .36347 .68572 .36523 .69948 .36262 .69339 .36104 Mtetra
.468 .876 .951 r
.69339 .36104 .69948 .36262 .71332 .35985 .70724 .35713 Mtetra
.531 .88 .986 r
.70724 .35713 .71332 .35985 .72729 .35796 .72116 .35321 Mtetra
.196 .625 .947 r
.72116 .35321 .72729 .35796 .7419 .36388 .73557 .35551 Mtetra
0 .122 .651 r
.73557 .35551 .7419 .36388 .7576 .38274 .75095 .36972 Mtetra
0 .17 .707 r
.75095 .36972 .7576 .38274 .77349 .4003 .76673 .38591 Mtetra
.606 .608 .827 r
.76673 .38591 .77349 .4003 .78774 .39446 .78124 .38303 Mtetra
.876 .759 .73 r
.78124 .38303 .78774 .39446 .80045 .37016 .79427 .36151 Mtetra
.904 .81 .744 r
.79427 .36151 .80045 .37016 .8133 .34843 .80724 .34033 Mtetra
.823 .819 .845 r
.80724 .34033 .8133 .34843 .82698 .33644 .82097 .32803 Mtetra
.703 .777 .909 r
.82097 .32803 .82698 .33644 .84125 .33019 .83528 .32159 Mtetra
.586 .734 .946 r
.19394 .5214 .20194 .52828 .21333 .52613 .20535 .51929 Mtetra
.158 .532 .922 r
.20535 .51929 .21333 .52613 .22428 .52957 .21632 .52267 Mtetra
.584 .061 0 r
.21632 .52267 .22428 .52957 .2346 .54143 .22673 .53341 Mtetra
0 .09 .595 r
.22673 .53341 .2346 .54143 .24507 .55353 .2374 .54288 Mtetra
.719 .689 .821 r
.2374 .54288 .24507 .55353 .25711 .54774 .24958 .53567 Mtetra
.835 .698 .712 r
.24958 .53567 .25711 .54774 .27058 .52372 .26293 .51404 Mtetra
.84 .727 .739 r
.26293 .51404 .27058 .52372 .28382 .50166 .27598 .49541 Mtetra
.785 .796 .862 r
.27598 .49541 .28382 .50166 .29619 .4911 .28829 .48631 Mtetra
.653 .826 .967 r
.28829 .48631 .29619 .4911 .30817 .48661 .30029 .48219 Mtetra
.612 .829 .983 r
.30029 .48219 .30817 .48661 .32019 .48224 .31229 .47877 Mtetra
.641 .869 .984 r
.31229 .47877 .32019 .48224 .33236 .4762 .32441 .47446 Mtetra
.671 .926 .972 r
.32441 .47446 .33236 .4762 .3446 .4696 .33665 .4688 Mtetra
.697 .953 .952 r
.33665 .4688 .3446 .4696 .35681 .4642 .34899 .4621 Mtetra
.716 .926 .962 r
.34899 .4621 .35681 .4642 .36899 .46056 .36136 .45557 Mtetra
.694 .834 .95 r
.36136 .45557 .36899 .46056 .38117 .45797 .37371 .45029 Mtetra
.652 .743 .917 r
.37371 .45029 .38117 .45797 .39341 .45558 .38605 .44636 Mtetra
.627 .695 .894 r
.38605 .44636 .39341 .45558 .40574 .45296 .39841 .4432 Mtetra
.622 .681 .885 r
.39841 .4432 .40574 .45296 .41813 .45003 .41084 .44019 Mtetra
.627 .683 .883 r
.41084 .44019 .41813 .45003 .4306 .44682 .42333 .43701 Mtetra
.635 .687 .882 r
.42333 .43701 .4306 .44682 .44315 .44336 .4359 .43354 Mtetra
.642 .691 .88 r
.4359 .43354 .44315 .44336 .45576 .43966 .44854 .4298 Mtetra
.647 .693 .878 r
.44854 .4298 .45576 .43966 .46843 .43574 .46125 .42586 Mtetra
.65 .694 .877 r
.46125 .42586 .46843 .43574 .48117 .43162 .47401 .42178 Mtetra
.651 .696 .879 r
.47401 .42178 .48117 .43162 .49397 .42735 .48684 .41766 Mtetra
.652 .701 .882 r
.48684 .41766 .49397 .42735 .50684 .42297 .49973 .41351 Mtetra
.653 .707 .887 r
.49973 .41351 .50684 .42297 .51976 .41854 .51269 .40931 Mtetra
.657 .715 .891 r
.51269 .40931 .51976 .41854 .53274 .41409 .5257 .40498 Mtetra
.661 .721 .893 r
.5257 .40498 .53274 .41409 .54578 .40957 .53878 .40048 Mtetra
.665 .724 .893 r
.53878 .40048 .54578 .40957 .55887 .40485 .55191 .39583 Mtetra
.67 .728 .893 r
.55191 .39583 .55887 .40485 .57202 .39978 .56511 .39099 Mtetra
.675 .737 .896 r
.56511 .39099 .57202 .39978 .58522 .39415 .57836 .38593 Mtetra
.69 .758 .903 r
.57836 .38593 .58522 .39415 .59846 .38806 .59165 .38039 Mtetra
.707 .779 .908 r
.59165 .38039 .59846 .38806 .61176 .38209 .60499 .37423 Mtetra
.699 .772 .909 r
.60499 .37423 .61176 .38209 .62512 .37688 .61839 .36835 Mtetra
.635 .732 .918 r
.61839 .36835 .62512 .37688 .63858 .37259 .63191 .36458 Mtetra
.518 .697 .951 r
.63191 .36458 .63858 .37259 .65213 .36886 .64561 .36372 Mtetra
.39 .73 .99 r
.64561 .36372 .65213 .36886 .66578 .36576 .65944 .36364 Mtetra
.374 .814 .955 r
.65944 .36364 .66578 .36576 .67955 .36347 .67328 .36145 Mtetra
.537 .899 .97 r
.67328 .36145 .67955 .36347 .69339 .36104 .68709 .35693 Mtetra
.652 .884 .982 r
.68709 .35693 .69339 .36104 .70724 .35713 .70093 .35159 Mtetra
.632 .831 .977 r
.70093 .35159 .70724 .35713 .72116 .35321 .71488 .34722 Mtetra
.372 .692 .981 r
.71488 .34722 .72116 .35321 .73557 .35551 .72924 .34794 Mtetra
0 .259 .753 r
.72924 .34794 .73557 .35551 .75095 .36972 .74439 .35846 Mtetra
0 .221 .744 r
.74439 .35846 .75095 .36972 .76673 .38591 .75998 .37206 Mtetra
.57 .599 .843 r
.75998 .37206 .76673 .38591 .78124 .38303 .77463 .37061 Mtetra
.847 .74 .746 r
.77463 .37061 .78124 .38303 .79427 .36151 .78795 .3518 Mtetra
.886 .791 .751 r
.78795 .3518 .79427 .36151 .80724 .34033 .8011 .33175 Mtetra
.818 .808 .841 r
.8011 .33175 .80724 .34033 .82097 .32803 .8149 .31945 Mtetra
.705 .776 .907 r
.8149 .31945 .82097 .32803 .83528 .32159 .82926 .3129 Mtetra
.587 .733 .944 r
.18588 .51441 .19394 .5214 .20535 .51929 .19732 .51226 Mtetra
.207 .557 .934 r
.19732 .51226 .20535 .51929 .21632 .52267 .20833 .51524 Mtetra
0 .067 .556 r
.20833 .51524 .21632 .52267 .22673 .53341 .21887 .52453 Mtetra
0 .285 .778 r
.21887 .52453 .22673 .53341 .2374 .54288 .22971 .53188 Mtetra
.718 .684 .816 r
.22971 .53188 .2374 .54288 .24958 .53567 .24193 .52456 Mtetra
.829 .708 .731 r
.24193 .52456 .24958 .53567 .26293 .51404 .25511 .5057 Mtetra
.837 .749 .766 r
.25511 .5057 .26293 .51404 .27598 .49541 .26803 .48958 Mtetra
.778 .809 .877 r
.26803 .48958 .27598 .49541 .28829 .48631 .28035 .48103 Mtetra
.669 .815 .953 r
.28035 .48103 .28829 .48631 .30029 .48219 .29241 .47655 Mtetra
.633 .796 .961 r
.29241 .47655 .30029 .48219 .31229 .47877 .30446 .47298 Mtetra
.638 .794 .957 r
.30446 .47298 .31229 .47877 .32441 .47446 .31657 .4693 Mtetra
.645 .817 .966 r
.31657 .4693 .32441 .47446 .33665 .4688 .32876 .46531 Mtetra
.652 .874 .981 r
.32876 .46531 .33665 .4688 .34899 .4621 .34104 .46067 Mtetra
.656 .933 .969 r
.34104 .46067 .34899 .4621 .36136 .45557 .35343 .45498 Mtetra
.671 .954 .95 r
.35343 .45498 .36136 .45557 .37371 .45029 .3659 .44847 Mtetra
.704 .935 .963 r
.3659 .44847 .37371 .45029 .38605 .44636 .3784 .44198 Mtetra
.706 .86 .955 r
.3784 .44198 .38605 .44636 .39841 .4432 .39092 .4362 Mtetra
.68 .774 .922 r
.39092 .4362 .39841 .4432 .41084 .44019 .40345 .43133 Mtetra
.657 .718 .894 r
.40345 .43133 .41084 .44019 .42333 .43701 .41601 .42712 Mtetra
.646 .691 .878 r
.41601 .42712 .42333 .43701 .4359 .43354 .42862 .42321 Mtetra
.642 .681 .871 r
.42862 .42321 .4359 .43354 .44854 .4298 .44128 .41939 Mtetra
.641 .679 .871 r
.44128 .41939 .44854 .4298 .46125 .42586 .45401 .41562 Mtetra
.64 .684 .875 r
.45401 .41562 .46125 .42586 .47401 .42178 .4668 .41188 Mtetra
.64 .692 .883 r
.4668 .41188 .47401 .42178 .48684 .41766 .47965 .40813 Mtetra
.642 .702 .89 r
.47965 .40813 .48684 .41766 .49973 .41351 .49257 .40428 Mtetra
.648 .713 .895 r
.49257 .40428 .49973 .41351 .51269 .40931 .50556 .40023 Mtetra
.656 .72 .896 r
.50556 .40023 .51269 .40931 .5257 .40498 .51861 .3959 Mtetra
.664 .724 .894 r
.51861 .3959 .5257 .40498 .53878 .40048 .53172 .39125 Mtetra
.67 .724 .889 r
.53172 .39125 .53878 .40048 .55191 .39583 .54489 .38635 Mtetra
.669 .719 .886 r
.54489 .38635 .55191 .39583 .56511 .39099 .55813 .38146 Mtetra
.657 .714 .89 r
.55813 .38146 .56511 .39099 .57836 .38593 .57142 .377 Mtetra
.625 .717 .913 r
.57142 .377 .57836 .38593 .59165 .38039 .5848 .3736 Mtetra
.564 .756 .968 r
.5848 .3736 .59165 .38039 .60499 .37423 .59828 .37133 Mtetra
.435 .826 .985 r
.59828 .37133 .60499 .37423 .61839 .36835 .61185 .36908 Mtetra
.26 .769 .782 r
.61185 .36908 .61839 .36835 .63191 .36458 .62546 .3656 Mtetra
.308 .798 .779 r
.62546 .3656 .63191 .36458 .64561 .36372 .63911 .36125 Mtetra
.511 .876 .981 r
.63911 .36125 .64561 .36372 .65944 .36364 .65286 .35751 Mtetra
.59 .794 .977 r
.65286 .35751 .65944 .36364 .67328 .36145 .66671 .35433 Mtetra
.637 .782 .951 r
.66671 .35433 .67328 .36145 .68709 .35693 .6806 .35021 Mtetra
.67 .807 .948 r
.6806 .35021 .68709 .35693 .70093 .35159 .6945 .34505 Mtetra
.637 .802 .962 r
.6945 .34505 .70093 .35159 .71488 .34722 .70852 .34075 Mtetra
.428 .709 .982 r
.70852 .34075 .71488 .34722 .72924 .34794 .72288 .34077 Mtetra
0 .379 .834 r
.72288 .34077 .72924 .34794 .74439 .35846 .73788 .34858 Mtetra
0 .307 .8 r
.73788 .34858 .74439 .35846 .75998 .37206 .75326 .35919 Mtetra
.566 .616 .861 r
.75326 .35919 .75998 .37206 .77463 .37061 .76795 .35776 Mtetra
.824 .729 .76 r
.76795 .35776 .77463 .37061 .78795 .3518 .7815 .34114 Mtetra
.865 .774 .759 r
.7815 .34114 .78795 .3518 .8011 .33175 .79486 .32258 Mtetra
.807 .793 .839 r
.79486 .32258 .8011 .33175 .8149 .31945 .80875 .31064 Mtetra
.704 .771 .904 r
.80875 .31064 .8149 .31945 .82926 .3129 .82317 .30408 Mtetra
.594 .733 .941 r
.17777 .5073 .18588 .51441 .19732 .51226 .18924 .50499 Mtetra
.282 .593 .948 r
.18924 .50499 .19732 .51226 .20833 .51524 .20033 .50729 Mtetra
0 .216 .709 r
.20033 .50729 .20833 .51524 .21887 .52453 .211 .515 Mtetra
.069 .396 .853 r
.211 .515 .21887 .52453 .22971 .53188 .22197 .52088 Mtetra
.703 .681 .825 r
.22197 .52088 .22971 .53188 .24193 .52456 .23414 .51439 Mtetra
.821 .721 .754 r
.23414 .51439 .24193 .52456 .25511 .5057 .24716 .4982 Mtetra
.833 .767 .789 r
.24716 .4982 .25511 .5057 .26803 .48958 .25999 .48385 Mtetra
.776 .814 .883 r
.25999 .48385 .26803 .48958 .28035 .48103 .27235 .47546 Mtetra
.686 .811 .942 r
.27235 .47546 .28035 .48103 .29241 .47655 .28448 .47052 Mtetra
.649 .79 .949 r
.28448 .47052 .29241 .47655 .30446 .47298 .29659 .46659 Mtetra
.646 .779 .944 r
.29659 .46659 .30446 .47298 .31657 .4693 .30875 .46275 Mtetra
.648 .776 .941 r
.30875 .46275 .31657 .4693 .32876 .46531 .32097 .45885 Mtetra
.649 .78 .943 r
.32097 .45885 .32876 .46531 .34104 .46067 .33324 .4549 Mtetra
.645 .801 .958 r
.33324 .4549 .34104 .46067 .35343 .45498 .34558 .45093 Mtetra
.64 .856 .982 r
.34558 .45093 .35343 .45498 .3659 .44847 .35799 .44663 Mtetra
.625 .917 .979 r
.35799 .44663 .3659 .44847 .3784 .44198 .37049 .44157 Mtetra
.61 .942 .945 r
.37049 .44157 .3784 .44198 .39092 .4362 .38307 .43578 Mtetra
.635 .95 .944 r
.38307 .43578 .39092 .4362 .40345 .43133 .39572 .42956 Mtetra
.68 .935 .967 r
.39572 .42956 .40345 .43133 .41601 .42712 .40841 .42335 Mtetra
.695 .882 .968 r
.40841 .42335 .41601 .42712 .42862 .42321 .42113 .41759 Mtetra
.682 .822 .95 r
.42113 .41759 .42862 .42321 .44128 .41939 .43387 .41248 Mtetra
.666 .779 .934 r
.43387 .41248 .44128 .41939 .45401 .41562 .44666 .4079 Mtetra
.657 .755 .922 r
.44666 .4079 .45401 .41562 .4668 .41188 .4595 .4036 Mtetra
.655 .74 .912 r
.4595 .4036 .4668 .41188 .47965 .40813 .4724 .39933 Mtetra
.66 .729 .9 r
.4724 .39933 .47965 .40813 .49257 .40428 .48536 .39489 Mtetra
.665 .717 .887 r
.48536 .39489 .49257 .40428 .50556 .40023 .49838 .3902 Mtetra
.664 .703 .876 r
.49838 .3902 .50556 .40023 .51861 .3959 .51147 .38545 Mtetra
.653 .69 .872 r
.51147 .38545 .51861 .3959 .53172 .39125 .52461 .38106 Mtetra
.632 .688 .885 r
.52461 .38106 .53172 .39125 .54489 .38635 .53782 .37747 Mtetra
.602 .709 .919 r
.53782 .37747 .54489 .38635 .55813 .38146 .55111 .3747 Mtetra
.557 .755 .97 r
.55111 .3747 .55813 .38146 .57142 .377 .56448 .37256 Mtetra
.484 .801 1 r
.56448 .37256 .57142 .377 .5848 .3736 .57795 .37065 Mtetra
.409 .811 .982 r
.57795 .37065 .5848 .3736 .59828 .37133 .5915 .36875 Mtetra
.415 .825 .976 r
.5915 .36875 .59828 .37133 .61185 .36908 .60512 .36646 Mtetra
.529 .879 .986 r
.60512 .36646 .61185 .36908 .62546 .3656 .61879 .36259 Mtetra
.656 .916 .978 r
.61879 .36259 .62546 .3656 .63911 .36125 .63247 .3567 Mtetra
.696 .882 .967 r
.63247 .3567 .63911 .36125 .65286 .35751 .64618 .35047 Mtetra
.656 .792 .947 r
.64618 .35047 .65286 .35751 .66671 .35433 .66002 .34577 Mtetra
.627 .738 .927 r
.66002 .34577 .66671 .35433 .6806 .35021 .67397 .34205 Mtetra
.641 .755 .932 r
.67397 .34205 .6806 .35021 .6945 .34505 .68797 .33787 Mtetra
.622 .778 .956 r
.68797 .33787 .6945 .34505 .70852 .34075 .70208 .33406 Mtetra
.451 .716 .981 r
.70208 .33406 .70852 .34075 .72288 .34077 .71647 .33373 Mtetra
.078 .472 .89 r
.71647 .33373 .72288 .34077 .73788 .34858 .73137 .33956 Mtetra
.08 .412 .863 r
.73137 .33956 .73788 .34858 .75326 .35919 .74658 .34725 Mtetra
.589 .647 .876 r
.74658 .34725 .75326 .35919 .76795 .35776 .76122 .34488 Mtetra
.809 .725 .772 r
.76122 .34488 .76795 .35776 .7815 .34114 .77495 .32975 Mtetra
.843 .759 .77 r
.77495 .32975 .7815 .34114 .79486 .32258 .78851 .31283 Mtetra
.791 .778 .841 r
.78851 .31283 .79486 .32258 .80875 .31064 .80253 .30157 Mtetra
.699 .765 .902 r
.80253 .30157 .80875 .31064 .82317 .30408 .81702 .2951 Mtetra
.604 .734 .937 r
.16959 .50005 .17777 .5073 .18924 .50499 .18111 .4975 Mtetra
.366 .63 .955 r
.18111 .4975 .18924 .50499 .20033 .50729 .1923 .4989 Mtetra
0 .353 .822 r
.1923 .4989 .20033 .50729 .211 .515 .20312 .50503 Mtetra
.171 .449 .878 r
.20312 .50503 .211 .515 .22197 .52088 .21417 .51 Mtetra
.676 .675 .842 r
.21417 .51 .22197 .52088 .23414 .51439 .22624 .5049 Mtetra
.809 .731 .779 r
.22624 .5049 .23414 .51439 .24716 .4982 .23909 .49117 Mtetra
.826 .778 .807 r
.23909 .49117 .24716 .4982 .25999 .48385 .25188 .47811 Mtetra
.776 .815 .883 r
.25188 .47811 .25999 .48385 .27235 .47546 .26429 .46968 Mtetra
.699 .808 .933 r
.26429 .46968 .27235 .47546 .28448 .47052 .27649 .4643 Mtetra
.663 .789 .942 r
.27649 .4643 .28448 .47052 .29659 .46659 .28866 .46 Mtetra
.653 .776 .939 r
.28866 .46 .29659 .46659 .30875 .46275 .30087 .45595 Mtetra
.65 .77 .937 r
.30087 .45595 .30875 .46275 .32097 .45885 .31312 .45198 Mtetra
.651 .769 .935 r
.31312 .45198 .32097 .45885 .33324 .4549 .32544 .44796 Mtetra
.655 .77 .933 r
.32544 .44796 .33324 .4549 .34558 .45093 .33782 .44382 Mtetra
.656 .766 .93 r
.33782 .44382 .34558 .45093 .35799 .44663 .35026 .43964 Mtetra
.65 .769 .936 r
.35026 .43964 .35799 .44663 .37049 .44157 .36275 .4356 Mtetra
.645 .799 .957 r
.36275 .4356 .37049 .44157 .38307 .43578 .3753 .43155 Mtetra
.639 .855 .982 r
.3753 .43155 .38307 .43578 .39572 .42956 .38792 .42719 Mtetra
.605 .901 .986 r
.38792 .42719 .39572 .42956 .40841 .42335 .40061 .4226 Mtetra
.53 .908 .948 r
.40061 .4226 .40841 .42335 .42113 .41759 .41335 .41798 Mtetra
.464 .889 .888 r
.41335 .41798 .42113 .41759 .43387 .41248 .42616 .41319 Mtetra
.459 .887 .87 r
.42616 .41319 .43387 .41248 .44666 .4079 .43903 .40814 Mtetra
.496 .904 .899 r
.43903 .40814 .44666 .4079 .4595 .4036 .45196 .403 Mtetra
.545 .919 .939 r
.45196 .403 .4595 .4036 .4724 .39933 .46494 .39787 Mtetra
.588 .922 .967 r
.46494 .39787 .4724 .39933 .48536 .39489 .47798 .39272 Mtetra
.609 .914 .979 r
.47798 .39272 .48536 .39489 .49838 .3902 .49107 .38766 Mtetra
.6 .902 .985 r
.49107 .38766 .49838 .3902 .51147 .38545 .50422 .38293 Mtetra
.571 .894 .986 r
.50422 .38293 .51147 .38545 .52461 .38106 .51743 .37861 Mtetra
.549 .887 .986 r
.51743 .37861 .52461 .38106 .53782 .37747 .5307 .37455 Mtetra
.547 .875 .992 r
.5307 .37455 .53782 .37747 .55111 .3747 .54404 .37077 Mtetra
.574 .856 .996 r
.54404 .37077 .55111 .3747 .56448 .37256 .55746 .36709 Mtetra
.613 .822 .98 r
.55746 .36709 .56448 .37256 .57795 .37065 .57094 .36325 Mtetra
.631 .768 .945 r
.57094 .36325 .57795 .37065 .5915 .36875 .5845 .35938 Mtetra
.611 .707 .912 r
.5845 .35938 .5915 .36875 .60512 .36646 .59814 .35627 Mtetra
.592 .679 .901 r
.59814 .35627 .60512 .36646 .61879 .36259 .61189 .35379 Mtetra
.633 .733 .92 r
.61189 .35379 .61879 .36259 .63247 .3567 .62567 .34992 Mtetra
.697 .814 .937 r
.62567 .34992 .63247 .3567 .64618 .35047 .63945 .34391 Mtetra
.693 .821 .944 r
.63945 .34391 .64618 .35047 .66002 .34577 .6533 .338 Mtetra
.641 .768 .94 r
.6533 .338 .66002 .34577 .67397 .34205 .66728 .33375 Mtetra
.619 .745 .936 r
.66728 .33375 .67397 .34205 .68797 .33787 .68136 .33017 Mtetra
.598 .755 .953 r
.68136 .33017 .68797 .33787 .70208 .33406 .69555 .32705 Mtetra
.458 .711 .977 r
.69555 .32705 .70208 .33406 .71647 .33373 .70999 .32669 Mtetra
.173 .54 .926 r
.70999 .32669 .71647 .33373 .73137 .33956 .72484 .33102 Mtetra
.21 .517 .915 r
.72484 .33102 .73137 .33956 .74658 .34725 .73989 .33599 Mtetra
.629 .682 .881 r
.73989 .33599 .74658 .34725 .76122 .34488 .75446 .33206 Mtetra
.8 .725 .781 r
.75446 .33206 .76122 .34488 .77495 .32975 .76832 .31787 Mtetra
.822 .746 .781 r
.76832 .31787 .77495 .32975 .78851 .31283 .78208 .3026 Mtetra
.772 .764 .845 r
.78208 .3026 .78851 .31283 .80253 .30157 .79624 .29224 Mtetra
.693 .758 .901 r
.79624 .29224 .80253 .30157 .81702 .2951 .8108 .28596 Mtetra
.616 .736 .932 r
.16135 .49269 .16959 .50005 .18111 .4975 .17293 .48984 Mtetra
.444 .664 .955 r
.17293 .48984 .18111 .4975 .1923 .4989 .18423 .49021 Mtetra
.13 .463 .89 r
.18423 .49021 .1923 .4989 .20312 .50503 .1952 .49478 Mtetra
.225 .475 .886 r
.1952 .49478 .20312 .50503 .21417 .51 .2063 .4992 Mtetra
.634 .663 .861 r
.2063 .4992 .21417 .51 .22624 .5049 .21823 .49577 Mtetra
.789 .737 .804 r
.21823 .49577 .22624 .5049 .23909 .49117 .23093 .48437 Mtetra
.818 .786 .822 r
.23093 .48437 .23909 .49117 .25188 .47811 .24369 .47232 Mtetra
.778 .815 .882 r
.24369 .47232 .25188 .47811 .26429 .46968 .25616 .46375 Mtetra
.712 .808 .925 r
.25616 .46375 .26429 .46968 .27649 .4643 .26843 .45794 Mtetra
.673 .789 .936 r
.26843 .45794 .27649 .4643 .28866 .46 .28066 .45333 Mtetra
.66 .777 .936 r
.28066 .45333 .28866 .46 .30087 .45595 .29292 .44906 Mtetra
.657 .771 .934 r
.29292 .44906 .30087 .45595 .31312 .45198 .30522 .44488 Mtetra
.654 .766 .931 r
.30522 .44488 .31312 .45198 .32544 .44796 .31758 .44075 Mtetra
.651 .762 .931 r
.31758 .44075 .32544 .44796 .33782 .44382 .32999 .4367 Mtetra
.654 .767 .932 r
.32999 .4367 .33782 .44382 .35026 .43964 .34246 .43255 Mtetra
.66 .771 .931 r
.34246 .43255 .35026 .43964 .36275 .4356 .355 .42819 Mtetra
.668 .765 .922 r
.355 .42819 .36275 .4356 .3753 .43155 .36762 .42358 Mtetra
.664 .749 .913 r
.36762 .42358 .3753 .43155 .38792 .42719 .38028 .41906 Mtetra
.649 .741 .917 r
.38028 .41906 .38792 .42719 .40061 .4226 .39298 .415 Mtetra
.648 .756 .928 r
.39298 .415 .40061 .4226 .41335 .41798 .40575 .41093 Mtetra
.665 .778 .934 r
.40575 .41093 .41335 .41798 .42616 .41319 .41859 .40632 Mtetra
.672 .787 .935 r
.41859 .40632 .42616 .41319 .43903 .40814 .4315 .40146 Mtetra
.665 .791 .942 r
.4315 .40146 .43903 .40814 .45196 .403 .44446 .39678 Mtetra
.665 .807 .951 r
.44446 .39678 .45196 .403 .46494 .39787 .45748 .39201 Mtetra
.679 .823 .952 r
.45748 .39201 .46494 .39787 .47798 .39272 .47057 .38682 Mtetra
.686 .824 .949 r
.47057 .38682 .47798 .39272 .49107 .38766 .48372 .38139 Mtetra
.677 .812 .948 r
.48372 .38139 .49107 .38766 .50422 .38293 .49692 .37624 Mtetra
.658 .795 .948 r
.49692 .37624 .50422 .38293 .51743 .37861 .51018 .37163 Mtetra
.65 .785 .946 r
.51018 .37163 .51743 .37861 .5307 .37455 .5235 .36724 Mtetra
.662 .78 .936 r
.5235 .36724 .5307 .37455 .54404 .37077 .53688 .36252 Mtetra
.657 .753 .92 r
.53688 .36252 .54404 .37077 .55746 .36709 .55033 .35795 Mtetra
.64 .724 .909 r
.55033 .35795 .55746 .36709 .57094 .36325 .56385 .35394 Mtetra
.636 .719 .908 r
.56385 .35394 .57094 .36325 .5845 .35938 .57744 .35003 Mtetra
.628 .716 .91 r
.57744 .35003 .5845 .35938 .59814 .35627 .59112 .34637 Mtetra
.595 .689 .908 r
.59112 .34637 .59814 .35627 .61189 .35379 .60489 .34374 Mtetra
.592 .685 .906 r
.60489 .34374 .61189 .35379 .62567 .34992 .61875 .34118 Mtetra
.652 .745 .917 r
.61875 .34118 .62567 .34992 .63945 .34391 .63263 .33662 Mtetra
.693 .801 .932 r
.63263 .33662 .63945 .34391 .6533 .338 .64653 .33069 Mtetra
.66 .79 .944 r
.64653 .33069 .6533 .338 .66728 .33375 .66054 .32579 Mtetra
.612 .754 .946 r
.66054 .32579 .66728 .33375 .68136 .33017 .67468 .3223 Mtetra
.573 .741 .955 r
.67468 .3223 .68136 .33017 .69555 .32705 .68895 .31976 Mtetra
.454 .703 .974 r
.68895 .31976 .69555 .32705 .70999 .32669 .70345 .31955 Mtetra
.252 .59 .948 r
.70345 .31955 .70999 .32669 .72484 .33102 .71827 .32267 Mtetra
.346 .61 .948 r
.71827 .32267 .72484 .33102 .73989 .33599 .73318 .32503 Mtetra
.675 .712 .876 r
.73318 .32503 .73989 .33599 .75446 .33206 .74767 .31927 Mtetra
.794 .724 .787 r
.74767 .31927 .75446 .33206 .76832 .31787 .76162 .30565 Mtetra
.8 .736 .793 r
.76162 .30565 .76832 .31787 .78208 .3026 .77557 .29202 Mtetra
.751 .751 .852 r
.77557 .29202 .78208 .3026 .79624 .29224 .78988 .2827 Mtetra
.685 .751 .902 r
.78988 .2827 .79624 .29224 .8108 .28596 .80452 .27668 Mtetra
.627 .739 .928 r
.15305 .48525 .16135 .49269 .17293 .48984 .16468 .48207 Mtetra
.511 .691 .949 r
.16468 .48207 .17293 .48984 .18423 .49021 .17611 .48138 Mtetra
.277 .546 .923 r
.17611 .48138 .18423 .49021 .1952 .49478 .18724 .48438 Mtetra
.263 .494 .891 r
.18724 .48438 .1952 .49478 .2063 .4992 .19838 .48833 Mtetra
.576 .64 .877 r
.19838 .48833 .2063 .4992 .21823 .49577 .21016 .48667 Mtetra
.76 .735 .83 r
.21016 .48667 .21823 .49577 .23093 .48437 .22269 .4776 Mtetra
.808 .789 .835 r
.22269 .4776 .23093 .48437 .24369 .47232 .23541 .46651 Mtetra
.781 .816 .88 r
.23541 .46651 .24369 .47232 .25616 .46375 .24795 .45775 Mtetra
.723 .809 .918 r
.24795 .45775 .25616 .46375 .26843 .45794 .2603 .45151 Mtetra
.683 .791 .931 r
.2603 .45151 .26843 .45794 .28066 .45333 .27259 .44655 Mtetra
.666 .778 .933 r
.27259 .44655 .28066 .45333 .29292 .44906 .2849 .44208 Mtetra
.659 .771 .932 r
.2849 .44208 .29292 .44906 .30522 .44488 .29724 .43781 Mtetra
.657 .769 .932 r
.29724 .43781 .30522 .44488 .31758 .44075 .30964 .43357 Mtetra
.66 .767 .929 r
.30964 .43357 .31758 .44075 .32999 .4367 .3221 .42922 Mtetra
.659 .76 .925 r
.3221 .42922 .32999 .4367 .34246 .43255 .33462 .4249 Mtetra
.657 .756 .923 r
.33462 .4249 .34246 .43255 .355 .42819 .34719 .42063 Mtetra
.657 .759 .925 r
.34719 .42063 .355 .42819 .36762 .42358 .35983 .41631 Mtetra
.652 .767 .933 r
.35983 .41631 .36762 .42358 .38028 .41906 .37252 .4121 Mtetra
.653 .777 .94 r
.37252 .4121 .38028 .41906 .39298 .415 .38527 .40784 Mtetra
.677 .779 .927 r
.38527 .40784 .39298 .415 .40575 .41093 .3981 .40283 Mtetra
.688 .758 .905 r
.3981 .40283 .40575 .41093 .41859 .40632 .41101 .39742 Mtetra
.663 .731 .9 r
.41101 .39742 .41859 .40632 .4315 .40146 .42395 .39279 Mtetra
.641 .73 .913 r
.42395 .39279 .4315 .40146 .44446 .39678 .43693 .38888 Mtetra
.655 .756 .924 r
.43693 .38888 .44446 .39678 .45748 .39201 .44998 .38448 Mtetra
.68 .775 .923 r
.44998 .38448 .45748 .39201 .47057 .38682 .46312 .37927 Mtetra
.676 .775 .925 r
.46312 .37927 .47057 .38682 .48372 .38139 .4763 .37416 Mtetra
.647 .776 .942 r
.4763 .37416 .48372 .38139 .49692 .37624 .48954 .3699 Mtetra
.628 .798 .964 r
.48954 .3699 .49692 .37624 .51018 .37163 .50284 .36596 Mtetra
.641 .825 .971 r
.50284 .36596 .51018 .37163 .5235 .36724 .51622 .36154 Mtetra
.661 .831 .965 r
.51622 .36154 .5235 .36724 .53688 .36252 .52965 .35659 Mtetra
.681 .831 .955 r
.52965 .35659 .53688 .36252 .55033 .35795 .54315 .35111 Mtetra
.671 .801 .945 r
.54315 .35111 .55033 .35795 .56385 .35394 .55671 .346 Mtetra
.656 .765 .93 r
.55671 .346 .56385 .35394 .57744 .35003 .57034 .34138 Mtetra
.644 .743 .921 r
.57034 .34138 .57744 .35003 .59112 .34637 .58404 .33713 Mtetra
.602 .711 .921 r
.58404 .33713 .59112 .34637 .60489 .34374 .59785 .33417 Mtetra
.573 .691 .921 r
.59785 .33417 .60489 .34374 .61875 .34118 .61176 .33204 Mtetra
.622 .724 .92 r
.61176 .33204 .61875 .34118 .63263 .33662 .62572 .32843 Mtetra
.676 .772 .923 r
.62572 .32843 .63263 .33662 .64653 .33069 .63969 .32302 Mtetra
.663 .783 .938 r
.63969 .32302 .64653 .33069 .66054 .32579 .65375 .31802 Mtetra
.609 .761 .951 r
.65375 .31802 .66054 .32579 .67468 .3223 .66794 .31452 Mtetra
.553 .737 .961 r
.66794 .31452 .67468 .3223 .68895 .31976 .68228 .31238 Mtetra
.445 .697 .973 r
.68228 .31238 .68895 .31976 .70345 .31955 .69684 .31232 Mtetra
.324 .634 .963 r
.69684 .31232 .70345 .31955 .71827 .32267 .71163 .31428 Mtetra
.476 .684 .957 r
.71163 .31428 .71827 .32267 .73318 .32503 .72642 .31402 Mtetra
.716 .729 .86 r
.72642 .31402 .73318 .32503 .74767 .31927 .74082 .30635 Mtetra
.787 .721 .791 r
.74082 .30635 .74767 .31927 .76162 .30565 .75487 .29325 Mtetra
.777 .727 .806 r
.75487 .29325 .76162 .30565 .77557 .29202 .769 .28128 Mtetra
.729 .742 .862 r
.769 .28128 .77557 .29202 .78988 .2827 .78346 .27305 Mtetra
.676 .747 .904 r
.78346 .27305 .78988 .2827 .80452 .27668 .79818 .2673 Mtetra
.638 .743 .924 r
.14467 .47777 .15305 .48525 .16468 .48207 .15636 .47428 Mtetra
.564 .711 .941 r
.15636 .47428 .16468 .48207 .17611 .48138 .16792 .47255 Mtetra
.396 .611 .936 r
.16792 .47255 .17611 .48138 .18724 .48438 .17923 .47394 Mtetra
.308 .52 .898 r
.17923 .47394 .18724 .48438 .19838 .48833 .19042 .47725 Mtetra
.51 .608 .886 r
.19042 .47725 .19838 .48833 .21016 .48667 .20205 .47725 Mtetra
.714 .72 .854 r
.20205 .47725 .21016 .48667 .22269 .4776 .21438 .47064 Mtetra
.791 .787 .848 r
.21438 .47064 .22269 .4776 .23541 .46651 .22706 .46066 Mtetra
.782 .816 .879 r
.22706 .46066 .23541 .46651 .24795 .45775 .23965 .45177 Mtetra
.735 .812 .912 r
.23965 .45177 .24795 .45775 .2603 .45151 .25208 .44506 Mtetra
.693 .793 .927 r
.25208 .44506 .2603 .45151 .27259 .44655 .26444 .43975 Mtetra
.673 .78 .931 r
.26444 .43975 .27259 .44655 .2849 .44208 .2768 .43505 Mtetra
.665 .773 .93 r
.2768 .43505 .2849 .44208 .29724 .43781 .2892 .43057 Mtetra
.66 .767 .929 r
.2892 .43057 .29724 .43781 .30964 .43357 .30164 .4262 Mtetra
.656 .763 .929 r
.30164 .4262 .30964 .43357 .3221 .42922 .31413 .42194 Mtetra
.658 .767 .93 r
.31413 .42194 .3221 .42922 .33462 .4249 .32669 .41759 Mtetra
.665 .769 .927 r
.32669 .41759 .33462 .4249 .34719 .42063 .33931 .41302 Mtetra
.667 .763 .922 r
.33931 .41302 .34719 .42063 .35983 .41631 .352 .40837 Mtetra
.658 .752 .919 r
.352 .40837 .35983 .41631 .37252 .4121 .36473 .40397 Mtetra
.661 .749 .915 r
.36473 .40397 .37252 .4121 .38527 .40784 .37753 .39947 Mtetra
.678 .748 .904 r
.37753 .39947 .38527 .40784 .3981 .40283 .39041 .39435 Mtetra
.667 .743 .907 r
.39041 .39435 .3981 .40283 .41101 .39742 .40333 .38958 Mtetra
.624 .748 .936 r
.40333 .38958 .41101 .39742 .42395 .39279 .41627 .38608 Mtetra
.617 .78 .959 r
.41627 .38608 .42395 .39279 .43693 .38888 .42928 .38257 Mtetra
.682 .812 .945 r
.42928 .38257 .43693 .38888 .44998 .38448 .4424 .37725 Mtetra
.72 .796 .911 r
.4424 .37725 .44998 .38448 .46312 .37927 .45561 .37062 Mtetra
.694 .753 .897 r
.45561 .37062 .46312 .37927 .4763 .37416 .46886 .36478 Mtetra
.611 .706 .912 r
.46886 .36478 .4763 .37416 .48954 .3699 .48211 .36167 Mtetra
.521 .701 .952 r
.48211 .36167 .48954 .3699 .50284 .36596 .49543 .36056 Mtetra
.562 .807 .991 r
.49543 .36056 .50284 .36596 .51622 .36154 .50885 .35767 Mtetra
.604 .872 .992 r
.50885 .35767 .51622 .36154 .52965 .35659 .52235 .3533 Mtetra
.685 .914 .973 r
.52235 .3533 .52965 .35659 .54315 .35111 .53591 .34694 Mtetra
.708 .894 .964 r
.53591 .34694 .54315 .35111 .55671 .346 .54952 .34028 Mtetra
.691 .844 .956 r
.54952 .34028 .55671 .346 .57034 .34138 .56319 .33436 Mtetra
.667 .799 .946 r
.56319 .33436 .57034 .34138 .58404 .33713 .57693 .32928 Mtetra
.614 .757 .947 r
.57693 .32928 .58404 .33713 .59785 .33417 .59077 .32576 Mtetra
.574 .725 .945 r
.59077 .32576 .59785 .33417 .61176 .33204 .60472 .32333 Mtetra
.611 .734 .933 r
.60472 .32333 .61176 .33204 .62572 .32843 .61873 .31995 Mtetra
.662 .761 .924 r
.61873 .31995 .62572 .32843 .63969 .32302 .63277 .31497 Mtetra
.654 .771 .935 r
.63277 .31497 .63969 .32302 .65375 .31802 .64689 .3102 Mtetra
.601 .758 .954 r
.64689 .3102 .65375 .31802 .66794 .31452 .66114 .30687 Mtetra
.534 .735 .967 r
.66114 .30687 .66794 .31452 .68228 .31238 .67555 .30506 Mtetra
.44 .699 .975 r
.67555 .30506 .68228 .31238 .69684 .31232 .69016 .305 Mtetra
.405 .68 .973 r
.69016 .305 .69684 .31232 .71163 .31428 .70492 .30556 Mtetra
.591 .733 .942 r
.70492 .30556 .71163 .31428 .72642 .31402 .71958 .30255 Mtetra
.745 .732 .84 r
.71958 .30255 .72642 .31402 .74082 .30635 .73391 .29316 Mtetra
.775 .714 .795 r
.73391 .29316 .74082 .30635 .75487 .29325 .74807 .28084 Mtetra
.752 .719 .821 r
.74807 .28084 .75487 .29325 .769 .28128 .76239 .27057 Mtetra
.707 .736 .873 r
.76239 .27057 .769 .28128 .78346 .27305 .77698 .26336 Mtetra
.669 .745 .908 r
.77698 .26336 .78346 .27305 .79818 .2673 .79178 .25784 Mtetra
.646 .746 .922 r
.13622 .47027 .14467 .47777 .15636 .47428 .14797 .46653 Mtetra
.603 .727 .932 r
.14797 .46653 .15636 .47428 .16792 .47255 .15965 .46389 Mtetra
.492 .661 .937 r
.15965 .46389 .16792 .47255 .17923 .47394 .17113 .46367 Mtetra
.372 .56 .908 r
.17113 .46367 .17923 .47394 .19042 .47725 .18244 .46592 Mtetra
.451 .576 .888 r
.18244 .46592 .19042 .47725 .20205 .47725 .19394 .46715 Mtetra
.647 .688 .874 r
.19394 .46715 .20205 .47725 .21438 .47064 .20605 .46317 Mtetra
.762 .775 .864 r
.20605 .46317 .21438 .47064 .22706 .46066 .21862 .45474 Mtetra
.781 .816 .88 r
.21862 .45474 .22706 .46066 .23965 .45177 .23126 .44588 Mtetra
.746 .817 .908 r
.23126 .44588 .23965 .45177 .25208 .44506 .24378 .43868 Mtetra
.705 .8 .924 r
.24378 .43868 .25208 .44506 .26444 .43975 .25621 .43294 Mtetra
.68 .783 .928 r
.25621 .43294 .26444 .43975 .2768 .43505 .26863 .42798 Mtetra
.667 .774 .929 r
.26863 .42798 .2768 .43505 .2892 .43057 .28107 .42338 Mtetra
.663 .771 .93 r
.28107 .42338 .2892 .43057 .30164 .4262 .29356 .41889 Mtetra
.664 .769 .928 r
.29356 .41889 .30164 .4262 .31413 .42194 .3061 .41435 Mtetra
.661 .761 .924 r
.3061 .41435 .31413 .42194 .32669 .41759 .3187 .40987 Mtetra
.66 .758 .923 r
.3187 .40987 .32669 .41759 .33931 .41302 .33136 .40543 Mtetra
.658 .762 .927 r
.33136 .40543 .33931 .41302 .352 .40837 .34407 .40101 Mtetra
.659 .77 .932 r
.34407 .40101 .352 .40837 .36473 .40397 .35684 .39655 Mtetra
.67 .772 .927 r
.35684 .39655 .36473 .40397 .37753 .39947 .36969 .39173 Mtetra
.682 .768 .916 r
.36969 .39173 .37753 .39947 .39041 .39435 .38262 .38649 Mtetra
.659 .759 .924 r
.38262 .38649 .39041 .39435 .40333 .38958 .39557 .38196 Mtetra
.623 .756 .941 r
.39557 .38196 .40333 .38958 .41627 .38608 .40855 .3784 Mtetra
.643 .762 .935 r
.40855 .3784 .41627 .38608 .42928 .38257 .42161 .37429 Mtetra
.705 .765 .899 r
.42161 .37429 .42928 .38257 .4424 .37725 .43481 .36809 Mtetra
.721 .749 .874 r
.43481 .36809 .4424 .37725 .45561 .37062 .44807 .361 Mtetra
.697 .732 .877 r
.44807 .361 .45561 .37062 .46886 .36478 .46135 .35482 Mtetra
.584 .682 .908 r
.46135 .35482 .46886 .36478 .48211 .36167 .47463 .35249 Mtetra
.337 .581 .932 r
.47463 .35249 .48211 .36167 .49543 .36056 .48793 .35505 Mtetra
.62 .827 .98 r
.48793 .35505 .49543 .36056 .50885 .35767 .50141 .35096 Mtetra
.552 .764 .977 r
.50141 .35096 .50885 .35767 .52235 .3533 .51496 .34865 Mtetra
.693 .877 .967 r
.51496 .34865 .52235 .3533 .53591 .34694 .52858 .3425 Mtetra
.737 .893 .95 r
.52858 .3425 .53591 .34694 .54952 .34028 .54226 .335 Mtetra
.714 .865 .953 r
.54226 .335 .54952 .34028 .56319 .33436 .55598 .32829 Mtetra
.681 .834 .957 r
.55598 .32829 .56319 .33436 .57693 .32928 .56977 .32262 Mtetra
.618 .797 .968 r
.56977 .32262 .57693 .32928 .59077 .32576 .58366 .31871 Mtetra
.589 .774 .968 r
.58366 .31871 .59077 .32576 .60472 .32333 .59764 .31555 Mtetra
.624 .768 .948 r
.59764 .31555 .60472 .32333 .61873 .31995 .61169 .31162 Mtetra
.658 .766 .929 r
.61169 .31162 .61873 .31995 .63277 .31497 .62578 .30671 Mtetra
.639 .762 .937 r
.62578 .30671 .63277 .31497 .64689 .3102 .63996 .30237 Mtetra
.585 .753 .958 r
.63996 .30237 .64689 .3102 .66114 .30687 .65428 .29939 Mtetra
.515 .733 .973 r
.65428 .29939 .66114 .30687 .67555 .30506 .66876 .29788 Mtetra
.452 .712 .979 r
.66876 .29788 .67555 .30506 .69016 .305 .6834 .29746 Mtetra
.507 .73 .973 r
.6834 .29746 .69016 .305 .70492 .30556 .6981 .29608 Mtetra
.679 .752 .906 r
.6981 .29608 .70492 .30556 .71958 .30255 .71264 .29023 Mtetra
.756 .722 .821 r
.71264 .29023 .71958 .30255 .73391 .29316 .72695 .27974 Mtetra
.756 .705 .804 r
.72695 .27974 .73391 .29316 .74807 .28084 .74124 .26866 Mtetra
.726 .714 .84 r
.74124 .26866 .74807 .28084 .76239 .27057 .75574 .26004 Mtetra
.688 .734 .886 r
.75574 .26004 .76239 .27057 .77698 .26336 .77046 .25369 Mtetra
.663 .746 .912 r
.77046 .25369 .77698 .26336 .79178 .25784 .78533 .24835 Mtetra
.651 .749 .921 r
.12769 .46276 .13622 .47027 .14797 .46653 .13948 .45883 Mtetra
.629 .738 .926 r
.13948 .45883 .14797 .46653 .15965 .46389 .15127 .45549 Mtetra
.563 .699 .932 r
.15127 .45549 .15965 .46389 .17113 .46367 .16293 .45378 Mtetra
.453 .613 .917 r
.16293 .45378 .17113 .46367 .18244 .46592 .1744 .45452 Mtetra
.428 .564 .889 r
.1744 .45452 .18244 .46592 .19394 .46715 .18586 .45615 Mtetra
.564 .638 .882 r
.18586 .45615 .19394 .46715 .20605 .46317 .19773 .4547 Mtetra
.71 .745 .879 r
.19773 .4547 .20605 .46317 .21862 .45474 .21013 .44849 Mtetra
.769 .809 .885 r
.21013 .44849 .21862 .45474 .23126 .44588 .22278 .44012 Mtetra
.756 .823 .904 r
.22278 .44012 .23126 .44588 .24378 .43868 .23538 .43248 Mtetra
.719 .808 .92 r
.23538 .43248 .24378 .43868 .25621 .43294 .2479 .42623 Mtetra
.689 .79 .927 r
.2479 .42623 .25621 .43294 .26863 .42798 .26038 .42094 Mtetra
.675 .779 .928 r
.26038 .42094 .26863 .42798 .28107 .42338 .27287 .41606 Mtetra
.666 .77 .927 r
.27287 .41606 .28107 .42338 .29356 .41889 .28541 .41145 Mtetra
.661 .766 .928 r
.28541 .41145 .29356 .41889 .3061 .41435 .29798 .40697 Mtetra
.661 .769 .93 r
.29798 .40697 .3061 .41435 .3187 .40987 .31062 .40246 Mtetra
.667 .771 .927 r
.31062 .40246 .3187 .40987 .33136 .40543 .32333 .39777 Mtetra
.667 .765 .923 r
.32333 .39777 .33136 .40543 .34407 .40101 .33609 .39305 Mtetra
.667 .758 .918 r
.33609 .39305 .34407 .40101 .35684 .39655 .34892 .38828 Mtetra
.666 .75 .913 r
.34892 .38828 .35684 .39655 .36969 .39173 .3618 .38351 Mtetra
.665 .752 .915 r
.3618 .38351 .36969 .39173 .38262 .38649 .37475 .37877 Mtetra
.641 .76 .935 r
.37475 .37877 .38262 .38649 .39557 .38196 .38772 .37471 Mtetra
.638 .773 .945 r
.38772 .37471 .39557 .38196 .40855 .3784 .40075 .37067 Mtetra
.656 .766 .931 r
.40075 .37067 .40855 .3784 .42161 .37429 .41387 .36616 Mtetra
.688 .766 .911 r
.41387 .36616 .42161 .37429 .43481 .36809 .42709 .36054 Mtetra
.68 .781 .926 r
.42709 .36054 .43481 .36809 .44807 .361 .44035 .35522 Mtetra
.667 .83 .962 r
.44035 .35522 .44807 .361 .46135 .35482 .45367 .35012 Mtetra
.559 .83 .996 r
.45367 .35012 .46135 .35482 .47463 .35249 .46701 .34695 Mtetra
.671 .841 .965 r
.46701 .34695 .47463 .35249 .48793 .35505 .48047 .34163 Mtetra
.865 .718 .697 r
.48047 .34163 .48793 .35505 .50141 .35096 .49417 .31616 Mtetra
.355 .296 .653 r
.49417 .31616 .50141 .35096 .51496 .34865 .50757 .32812 Mtetra
.507 .481 .763 r
.50757 .32812 .51496 .34865 .52858 .3425 .52118 .32936 Mtetra
.637 .647 .843 r
.52118 .32936 .52858 .3425 .54226 .335 .5349 .32501 Mtetra
.633 .71 .902 r
.5349 .32501 .54226 .335 .55598 .32829 .54869 .321 Mtetra
.63 .783 .955 r
.54869 .321 .55598 .32829 .56977 .32262 .56255 .31686 Mtetra
.601 .821 .984 r
.56255 .31686 .56977 .32262 .58366 .31871 .5765 .31303 Mtetra
.634 .836 .978 r
.5765 .31303 .58366 .31871 .59764 .31555 .5905 .30837 Mtetra
.655 .799 .951 r
.5905 .30837 .59764 .31555 .61169 .31162 .60458 .30345 Mtetra
.656 .772 .934 r
.60458 .30345 .61169 .31162 .62578 .30671 .61872 .29855 Mtetra
.618 .759 .946 r
.61872 .29855 .62578 .30671 .63996 .30237 .63298 .29474 Mtetra
.564 .753 .966 r
.63298 .29474 .63996 .30237 .65428 .29939 .64736 .29215 Mtetra
.502 .737 .978 r
.64736 .29215 .65428 .29939 .66876 .29788 .6619 .29075 Mtetra
.503 .742 .98 r
.6619 .29075 .66876 .29788 .6834 .29746 .67654 .28925 Mtetra
.621 .764 .948 r
.67654 .28925 .6834 .29746 .6981 .29608 .69115 .28525 Mtetra
.729 .742 .862 r
.69115 .28525 .6981 .29608 .71264 .29023 .7056 .27694 Mtetra
.749 .705 .81 r
.7056 .27694 .71264 .29023 .72695 .27974 .71995 .2664 Mtetra
.731 .697 .818 r
.71995 .2664 .72695 .27974 .74124 .26866 .7344 .25697 Mtetra
.7 .715 .861 r
.7344 .25697 .74124 .26866 .75574 .26004 .74906 .24981 Mtetra
.672 .737 .899 r
.74906 .24981 .75574 .26004 .77046 .25369 .76388 .24406 Mtetra
.659 .747 .915 r
.76388 .24406 .77046 .25369 .78533 .24835 .77882 .23881 Mtetra
.654 .75 .92 r
.11908 .45521 .12769 .46276 .13948 .45883 .13092 .45117 Mtetra
.644 .746 .923 r
.13092 .45117 .13948 .45883 .15127 .45549 .14278 .44737 Mtetra
.611 .724 .926 r
.14278 .44737 .15127 .45549 .16293 .45378 .15459 .44448 Mtetra
.534 .666 .921 r
.15459 .44448 .16293 .45378 .1744 .45452 .16626 .44347 Mtetra
.458 .589 .896 r
.16626 .44347 .1744 .45452 .18586 .45615 .1778 .44437 Mtetra
.494 .591 .88 r
.1778 .44437 .18586 .45615 .19773 .4547 .1895 .44469 Mtetra
.627 .687 .887 r
.1895 .44469 .19773 .4547 .21013 .44849 .20165 .4413 Mtetra
.733 .783 .893 r
.20165 .4413 .21013 .44849 .22278 .44012 .2142 .43434 Mtetra
.758 .824 .904 r
.2142 .43434 .22278 .44012 .23538 .43248 .22686 .42657 Mtetra
.735 .82 .918 r
.22686 .42657 .23538 .43248 .2479 .42623 .23948 .41973 Mtetra
.703 .801 .926 r
.23948 .41973 .2479 .42623 .26038 .42094 .25204 .41397 Mtetra
.68 .783 .928 r
.25204 .41397 .26038 .42094 .27287 .41606 .26459 .4089 Mtetra
.671 .777 .929 r
.26459 .4089 .27287 .41606 .28541 .41145 .27717 .40408 Mtetra
.669 .772 .927 r
.27717 .40408 .28541 .41145 .29798 .40697 .2898 .39931 Mtetra
.664 .764 .924 r
.2898 .39931 .29798 .40697 .31062 .40246 .30249 .39469 Mtetra
.66 .761 .925 r
.30249 .39469 .31062 .40246 .32333 .39777 .31522 .39016 Mtetra
.659 .766 .929 r
.31522 .39016 .32333 .39777 .33609 .39305 .32801 .38562 Mtetra
.668 .775 .93 r
.32801 .38562 .33609 .39305 .34892 .38828 .34088 .38081 Mtetra
.673 .776 .927 r
.34088 .38081 .34892 .38828 .3618 .38351 .35382 .37579 Mtetra
.662 .767 .928 r
.35382 .37579 .3618 .38351 .37475 .37877 .36679 .37112 Mtetra
.642 .764 .937 r
.36679 .37112 .37475 .37877 .38772 .37471 .37981 .36698 Mtetra
.653 .766 .932 r
.37981 .36698 .38772 .37471 .40075 .37067 .3929 .36251 Mtetra
.67 .761 .918 r
.3929 .36251 .40075 .37067 .41387 .36616 .40608 .3575 Mtetra
.659 .745 .914 r
.40608 .3575 .41387 .36616 .42709 .36054 .4193 .35282 Mtetra
.63 .762 .942 r
.4193 .35282 .42709 .36054 .44035 .35522 .43257 .34894 Mtetra
.648 .812 .962 r
.43257 .34894 .44035 .35522 .45367 .35012 .44593 .34435 Mtetra
.704 .843 .949 r
.44593 .34435 .45367 .35012 .46701 .34695 .45938 .33812 Mtetra
.717 .763 .889 r
.45938 .33812 .46701 .34695 .48047 .34163 .4729 .33119 Mtetra
.687 .718 .873 r
.4729 .33119 .48047 .34163 .49417 .31616 .48646 .32519 Mtetra
.315 0 0 r
.48646 .32519 .49417 .31616 .50757 .32812 .50003 .32379 Mtetra
.559 .847 .998 r
.50003 .32379 .50757 .32812 .52118 .32936 .51371 .32027 Mtetra
.639 .736 .919 r
.51371 .32027 .52118 .32936 .5349 .32501 .52747 .31606 Mtetra
.584 .719 .936 r
.52747 .31606 .5349 .32501 .54869 .321 .54131 .31338 Mtetra
.563 .749 .964 r
.54131 .31338 .54869 .321 .56255 .31686 .55524 .3109 Mtetra
.608 .819 .981 r
.55524 .3109 .56255 .31686 .5765 .31303 .56924 .30691 Mtetra
.675 .838 .961 r
.56924 .30691 .5765 .31303 .5905 .30837 .58329 .30124 Mtetra
.681 .811 .945 r
.58329 .30124 .5905 .30837 .60458 .30345 .5974 .2955 Mtetra
.647 .777 .943 r
.5974 .2955 .60458 .30345 .61872 .29855 .61161 .29081 Mtetra
.595 .764 .96 r
.61161 .29081 .61872 .29855 .63298 .29474 .62594 .28747 Mtetra
.543 .757 .976 r
.62594 .28747 .63298 .29474 .64736 .29215 .64039 .28518 Mtetra
.525 .759 .982 r
.64039 .28518 .64736 .29215 .6619 .29075 .65495 .28313 Mtetra
.602 .774 .963 r
.65495 .28313 .6619 .29075 .67654 .28925 .66954 .27951 Mtetra
.704 .758 .894 r
.66954 .27951 .67654 .28925 .69115 .28525 .68406 .27261 Mtetra
.738 .712 .827 r
.68406 .27261 .69115 .28525 .7056 .27694 .69848 .26309 Mtetra
.728 .689 .813 r
.69848 .26309 .7056 .27694 .71995 .2664 .71295 .25364 Mtetra
.704 .698 .841 r
.71295 .25364 .71995 .2664 .7344 .25697 .72756 .24597 Mtetra
.678 .723 .883 r
.72756 .24597 .7344 .25697 .74906 .24981 .74234 .23986 Mtetra
.663 .742 .909 r
.74234 .23986 .74906 .24981 .76388 .24406 .75725 .23445 Mtetra
.657 .749 .918 r
.75725 .23445 .76388 .24406 .77882 .23881 .77225 .22922 Mtetra
.655 .751 .92 r
.1104 .44762 .11908 .45521 .13092 .45117 .12227 .44351 Mtetra
.652 .749 .921 r
.12227 .44351 .13092 .45117 .14278 .44737 .13418 .43946 Mtetra
.638 .74 .922 r
.13418 .43946 .14278 .44737 .15459 .44448 .14611 .4358 Mtetra
.597 .708 .921 r
.14611 .4358 .15459 .44448 .16626 .44347 .15797 .43324 Mtetra
.526 .642 .906 r
.15797 .43324 .16626 .44347 .1778 .44437 .1697 .43252 Mtetra
.483 .585 .881 r
.1697 .43252 .1778 .44437 .1895 .44469 .18137 .43304 Mtetra
.538 .616 .879 r
.18137 .43304 .1895 .44469 .20165 .4413 .19327 .43222 Mtetra
.656 .721 .896 r
.19327 .43222 .20165 .4413 .2142 .43434 .2056 .42787 Mtetra
.736 .805 .907 r
.2056 .42787 .2142 .43434 .22686 .42657 .21823 .42089 Mtetra
.744 .829 .917 r
.21823 .42089 .22686 .42657 .23948 .41973 .23093 .41368 Mtetra
.72 .817 .925 r
.23093 .41368 .23948 .41973 .25204 .41397 .24358 .40731 Mtetra
.696 .798 .928 r
.24358 .40731 .25204 .41397 .26459 .4089 .25622 .4017 Mtetra
.677 .779 .927 r
.25622 .4017 .26459 .4089 .27717 .40408 .26885 .39668 Mtetra
.666 .772 .929 r
.26885 .39668 .27717 .40408 .2898 .39931 .28152 .39196 Mtetra
.666 .775 .931 r
.28152 .39196 .2898 .39931 .30249 .39469 .29425 .38723 Mtetra
.668 .773 .929 r
.29425 .38723 .30249 .39469 .31522 .39016 .30704 .38243 Mtetra
.667 .767 .925 r
.30704 .38243 .31522 .39016 .32801 .38562 .31988 .37763 Mtetra
.669 .761 .92 r
.31988 .37763 .32801 .38562 .34088 .38081 .33279 .37275 Mtetra
.673 .762 .917 r
.33279 .37275 .34088 .38081 .35382 .37579 .34577 .36769 Mtetra
.659 .758 .923 r
.34577 .36769 .35382 .37579 .36679 .37112 .35878 .36306 Mtetra
.633 .752 .934 r
.35878 .36306 .36679 .37112 .37981 .36698 .37182 .35919 Mtetra
.634 .76 .939 r
.37182 .35919 .37981 .36698 .3929 .36251 .38493 .35523 Mtetra
.656 .783 .942 r
.38493 .35523 .3929 .36251 .40608 .3575 .39814 .3506 Mtetra
.649 .793 .952 r
.39814 .3506 .40608 .3575 .4193 .35282 .41141 .3461 Mtetra
.62 .791 .964 r
.41141 .3461 .4193 .35282 .43257 .34894 .42472 .34228 Mtetra
.63 .797 .962 r
.42472 .34228 .43257 .34894 .44593 .34435 .43811 .33816 Mtetra
.668 .823 .958 r
.43811 .33816 .44593 .34435 .45938 .33812 .4516 .33294 Mtetra
.673 .856 .97 r
.4516 .33294 .45938 .33812 .4729 .33119 .46515 .32741 Mtetra
.619 .883 .989 r
.46515 .32741 .4729 .33119 .48646 .32519 .47876 .32255 Mtetra
.558 .892 .985 r
.47876 .32255 .48646 .32519 .50003 .32379 .49243 .3181 Mtetra
.638 .834 .976 r
.49243 .3181 .50003 .32379 .51371 .32027 .50617 .31344 Mtetra
.627 .797 .964 r
.50617 .31344 .51371 .32027 .52747 .31606 .51998 .30928 Mtetra
.557 .773 .979 r
.51998 .30928 .52747 .31606 .54131 .31338 .53387 .30665 Mtetra
.542 .769 .982 r
.53387 .30665 .54131 .31338 .55524 .3109 .54785 .30429 Mtetra
.627 .808 .969 r
.54785 .30429 .55524 .3109 .56924 .30691 .5619 .29997 Mtetra
.694 .821 .943 r
.5619 .29997 .56924 .30691 .58329 .30124 .576 .29379 Mtetra
.683 .804 .94 r
.576 .29379 .58329 .30124 .5974 .2955 .59017 .28794 Mtetra
.628 .783 .956 r
.59017 .28794 .5974 .2955 .61161 .29081 .60444 .28368 Mtetra
.576 .776 .974 r
.60444 .28368 .61161 .29081 .62594 .28747 .61883 .28059 Mtetra
.56 .779 .98 r
.61883 .28059 .62594 .28747 .64039 .28518 .63332 .27773 Mtetra
.613 .785 .964 r
.63332 .27773 .64039 .28518 .65495 .28313 .64786 .27376 Mtetra
.694 .764 .906 r
.64786 .27376 .65495 .28313 .66954 .27951 .66238 .26731 Mtetra
.726 .716 .841 r
.66238 .26731 .66954 .27951 .68406 .27261 .67685 .25863 Mtetra
.719 .684 .815 r
.67685 .25863 .68406 .27261 .69848 .26309 .69134 .24965 Mtetra
.7 .685 .832 r
.69134 .24965 .69848 .26309 .71295 .25364 .70596 .24193 Mtetra
.68 .709 .871 r
.70596 .24193 .71295 .25364 .72756 .24597 .72071 .23563 Mtetra
.665 .734 .902 r
.72071 .23563 .72756 .24597 .74234 .23986 .73559 .23009 Mtetra
.658 .747 .916 r
.73559 .23009 .74234 .23986 .75725 .23445 .75056 .22481 Mtetra
.656 .751 .919 r
.75056 .22481 .75725 .23445 .77225 .22922 .76561 .21956 Mtetra
.656 .751 .92 r
.10164 .43998 .1104 .44762 .12227 .44351 .11354 .43581 Mtetra
.655 .751 .92 r
.11354 .43581 .12227 .44351 .13418 .43946 .1255 .43165 Mtetra
.65 .748 .921 r
.1255 .43165 .13418 .43946 .14611 .4358 .1375 .4276 Mtetra
.634 .734 .92 r
.1375 .4276 .14611 .4358 .15797 .43324 .1495 .42401 Mtetra
.593 .695 .913 r
.1495 .42401 .15797 .43324 .1697 .43252 .16143 .42154 Mtetra
.534 .63 .893 r
.16143 .42154 .1697 .43252 .18137 .43304 .17326 .42069 Mtetra
.507 .589 .871 r
.17326 .42069 .18137 .43304 .19327 .43222 .18508 .42069 Mtetra
.558 .631 .879 r
.18508 .42069 .19327 .43222 .2056 .42787 .19713 .41927 Mtetra
.661 .736 .906 r
.19713 .41927 .2056 .42787 .21823 .42089 .20956 .41474 Mtetra
.73 .816 .919 r
.20956 .41474 .21823 .42089 .23093 .41368 .22225 .40799 Mtetra
.733 .831 .925 r
.22225 .40799 .23093 .41368 .24358 .40731 .235 .40113 Mtetra
.71 .815 .931 r
.235 .40113 .24358 .40731 .25622 .4017 .24772 .39505 Mtetra
.692 .8 .932 r
.24772 .39505 .25622 .4017 .26885 .39668 .26044 .38951 Mtetra
.68 .784 .928 r
.26044 .38951 .26885 .39668 .28152 .39196 .27318 .38431 Mtetra
.668 .769 .925 r
.27318 .38431 .28152 .39196 .29425 .38723 .28595 .37947 Mtetra
.661 .765 .927 r
.28595 .37947 .29425 .38723 .30704 .38243 .29877 .37481 Mtetra
.658 .769 .932 r
.29877 .37481 .30704 .38243 .31988 .37763 .31164 .37023 Mtetra
.663 .778 .934 r
.31164 .37023 .31988 .37763 .33279 .37275 .32458 .36547 Mtetra
.676 .786 .932 r
.32458 .36547 .33279 .37275 .34577 .36769 .3376 .36031 Mtetra
.678 .784 .93 r
.3376 .36031 .34577 .36769 .35878 .36306 .35069 .35505 Mtetra
.656 .762 .928 r
.35069 .35505 .35878 .36306 .37182 .35919 .36381 .35043 Mtetra
.635 .737 .922 r
.36381 .35043 .37182 .35919 .38493 .35523 .37695 .34647 Mtetra
.63 .736 .924 r
.37695 .34647 .38493 .35523 .39814 .3506 .39017 .34261 Mtetra
.625 .756 .941 r
.39017 .34261 .39814 .3506 .41141 .3461 .40345 .33881 Mtetra
.606 .771 .959 r
.40345 .33881 .41141 .3461 .42472 .34228 .41679 .33539 Mtetra
.6 .782 .967 r
.41679 .33539 .42472 .34228 .43811 .33816 .4302 .33199 Mtetra
.624 .813 .973 r
.4302 .33199 .43811 .33816 .4516 .33294 .44372 .32784 Mtetra
.658 .856 .975 r
.44372 .32784 .4516 .33294 .46515 .32741 .45732 .32259 Mtetra
.673 .87 .974 r
.45732 .32259 .46515 .32741 .47876 .32255 .47101 .31687 Mtetra
.652 .84 .972 r
.47101 .31687 .47876 .32255 .49243 .3181 .48474 .31185 Mtetra
.639 .82 .97 r
.48474 .31185 .49243 .3181 .50617 .31344 .49853 .30724 Mtetra
.609 .812 .978 r
.49853 .30724 .50617 .31344 .51998 .30928 .5124 .30328 Mtetra
.552 .798 .99 r
.5124 .30328 .51998 .30928 .53387 .30665 .52634 .30042 Mtetra
.561 .795 .987 r
.52634 .30042 .53387 .30665 .54785 .30429 .54038 .29744 Mtetra
.646 .809 .962 r
.54038 .29744 .54785 .30429 .5619 .29997 .55448 .29262 Mtetra
.692 .811 .939 r
.55448 .29262 .5619 .29997 .576 .29379 .56864 .28646 Mtetra
.67 .806 .948 r
.56864 .28646 .576 .29379 .59017 .28794 .58287 .28096 Mtetra
.62 .8 .968 r
.58287 .28096 .59017 .28794 .60444 .28368 .5972 .27674 Mtetra
.606 .797 .973 r
.5972 .27674 .60444 .28368 .61883 .28059 .61163 .27283 Mtetra
.646 .79 .951 r
.61163 .27283 .61883 .28059 .63332 .27773 .62611 .26798 Mtetra
.697 .756 .898 r
.62611 .26798 .63332 .27773 .64786 .27376 .64059 .26135 Mtetra
.715 .708 .843 r
.64059 .26135 .64786 .27376 .66238 .26731 .65508 .25321 Mtetra
.707 .677 .819 r
.65508 .25321 .66238 .26731 .67685 .25863 .66961 .24489 Mtetra
.691 .677 .831 r
.66961 .24489 .67685 .25863 .69134 .24965 .68423 .23753 Mtetra
.676 .701 .865 r
.68423 .23753 .69134 .24965 .70596 .24193 .69897 .23128 Mtetra
.665 .728 .897 r
.69897 .23128 .70596 .24193 .72071 .23563 .71383 .22571 Mtetra
.658 .744 .913 r
.71383 .22571 .72071 .23563 .73559 .23009 .72877 .22038 Mtetra
.656 .75 .919 r
.72877 .22038 .73559 .23009 .75056 .22481 .7438 .2151 Mtetra
.656 .751 .92 r
.7438 .2151 .75056 .22481 .76561 .21956 .75891 .20981 Mtetra
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Mtetra
.10474 .42806 .11354 .43581 .1255 .43165 .11673 .42384 Mtetra
.655 .75 .92 r
.11673 .42384 .1255 .43165 .1375 .4276 .12877 .41963 Mtetra
.65 .746 .92 r
.12877 .41963 .1375 .4276 .1495 .42401 .14086 .41554 Mtetra
.634 .729 .917 r
.14086 .41554 .1495 .42401 .16143 .42154 .15295 .4119 Mtetra
.598 .689 .906 r
.15295 .4119 .16143 .42154 .17326 .42069 .16499 .40925 Mtetra
.55 .63 .883 r
.16499 .40925 .17326 .42069 .18508 .42069 .17694 .40799 Mtetra
.526 .594 .865 r
.17694 .40799 .18508 .42069 .19713 .41927 .1889 .40748 Mtetra
.56 .629 .877 r
.1889 .40748 .19713 .41927 .20956 .41474 .20105 .40596 Mtetra
.645 .73 .911 r
.20105 .40596 .20956 .41474 .22225 .40799 .21352 .40187 Mtetra
.716 .818 .929 r
.21352 .40187 .22225 .40799 .235 .40113 .22626 .39556 Mtetra
.729 .837 .931 r
.22626 .39556 .235 .40113 .24772 .39505 .23909 .3888 Mtetra
.706 .816 .933 r
.23909 .3888 .24772 .39505 .26044 .38951 .25189 .38278 Mtetra
.686 .799 .935 r
.25189 .38278 .26044 .38951 .27318 .38431 .2647 .37737 Mtetra
.678 .793 .936 r
.2647 .37737 .27318 .38431 .28595 .37947 .27753 .37218 Mtetra
.675 .784 .931 r
.27753 .37218 .28595 .37947 .29877 .37481 .29042 .36705 Mtetra
.67 .771 .926 r
.29042 .36705 .29877 .37481 .31164 .37023 .30336 .36207 Mtetra
.661 .759 .922 r
.30336 .36207 .31164 .37023 .32458 .36547 .31634 .35734 Mtetra
.661 .76 .924 r
.31634 .35734 .32458 .36547 .3376 .36031 .32937 .35259 Mtetra
.668 .775 .93 r
.32937 .35259 .3376 .36031 .35069 .35505 .34249 .3476 Mtetra
.668 .783 .935 r
.34249 .3476 .35069 .35505 .36381 .35043 .35567 .34258 Mtetra
.655 .769 .933 r
.35567 .34258 .36381 .35043 .37695 .34647 .36889 .33793 Mtetra
.639 .747 .927 r
.36889 .33793 .37695 .34647 .39017 .34261 .38215 .33376 Mtetra
.625 .735 .926 r
.38215 .33376 .39017 .34261 .40345 .33881 .39547 .32999 Mtetra
.612 .732 .931 r
.39547 .32999 .40345 .33881 .41679 .33539 .40884 .32657 Mtetra
.605 .731 .934 r
.40884 .32657 .41679 .33539 .4302 .33199 .42229 .3233 Mtetra
.613 .738 .935 r
.42229 .3233 .4302 .33199 .44372 .32784 .43583 .31977 Mtetra
.627 .761 .943 r
.43583 .31977 .44372 .32784 .45732 .32259 .44945 .31578 Mtetra
.634 .801 .963 r
.44945 .31578 .45732 .32259 .47101 .31687 .46316 .3114 Mtetra
.639 .844 .979 r
.46316 .3114 .47101 .31687 .48474 .31185 .47695 .30657 Mtetra
.629 .848 .983 r
.47695 .30657 .48474 .31185 .49853 .30724 .49081 .30189 Mtetra
.587 .832 .991 r
.49081 .30189 .49853 .30724 .5124 .30328 .50473 .29807 Mtetra
.544 .821 .997 r
.50473 .29807 .5124 .30328 .52634 .30042 .51873 .29498 Mtetra
.588 .832 .991 r
.51873 .29498 .52634 .30042 .54038 .29744 .53282 .2911 Mtetra
.674 .836 .961 r
.53282 .2911 .54038 .29744 .55448 .29262 .54698 .28539 Mtetra
.701 .819 .938 r
.54698 .28539 .55448 .29262 .56864 .28646 .5612 .27888 Mtetra
.68 .804 .942 r
.5612 .27888 .56864 .28646 .58287 .28096 .57548 .27305 Mtetra
.664 .791 .942 r
.57548 .27305 .58287 .28096 .5972 .27674 .58984 .26769 Mtetra
.682 .768 .916 r
.58984 .26769 .5972 .27674 .61163 .27283 .60426 .26172 Mtetra
.699 .727 .872 r
.60426 .26172 .61163 .27283 .62611 .26798 .61872 .25471 Mtetra
.7 .688 .835 r
.61872 .25471 .62611 .26798 .64059 .26135 .63321 .24706 Mtetra
.691 .668 .823 r
.63321 .24706 .64059 .26135 .65508 .25321 .64776 .23955 Mtetra
.68 .674 .837 r
.64776 .23955 .65508 .25321 .66961 .24489 .66239 .23278 Mtetra
.67 .699 .868 r
.66239 .23278 .66961 .24489 .68423 .23753 .67713 .22679 Mtetra
.662 .726 .897 r
.67713 .22679 .68423 .23753 .69897 .23128 .69197 .22127 Mtetra
.658 .743 .913 r
.69197 .22127 .69897 .23128 .71383 .22571 .70689 .21593 Mtetra
.656 .749 .918 r
.70689 .21593 .71383 .22571 .72877 .22038 .7219 .21063 Mtetra
.656 .751 .92 r
.7219 .21063 .72877 .22038 .7438 .2151 .73699 .20531 Mtetra
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Mtetra
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Mtetra
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Mtetra
.10788 .41598 .11673 .42384 .12877 .41963 .11996 .41171 Mtetra
.655 .75 .92 r
.11996 .41171 .12877 .41963 .14086 .41554 .13209 .40744 Mtetra
.651 .745 .919 r
.13209 .40744 .14086 .41554 .15295 .4119 .14427 .40327 Mtetra
.638 .729 .914 r
.14427 .40327 .15295 .4119 .16499 .40925 .15646 .39946 Mtetra
.611 .693 .901 r
.15646 .39946 .16499 .40925 .17694 .40799 .16863 .39641 Mtetra
.572 .639 .878 r
.16863 .39641 .17694 .40799 .1889 .40748 .18075 .3945 Mtetra
.545 .6 .859 r
.18075 .3945 .1889 .40748 .20105 .40596 .19285 .39344 Mtetra
.555 .614 .866 r
.19285 .39344 .20105 .40596 .21352 .40187 .20507 .39204 Mtetra
.613 .697 .904 r
.20507 .39204 .21352 .40187 .22626 .39556 .21754 .38886 Mtetra
.685 .8 .936 r
.21754 .38886 .22626 .39556 .23909 .3888 .23028 .38349 Mtetra
.721 .846 .941 r
.23028 .38349 .23909 .3888 .25189 .38278 .24318 .37693 Mtetra
.715 .831 .937 r
.24318 .37693 .25189 .38278 .2647 .37737 .25611 .37056 Mtetra
.691 .801 .934 r
.25611 .37056 .2647 .37737 .27753 .37218 .26903 .36494 Mtetra
.672 .786 .935 r
.26903 .36494 .27753 .37218 .29042 .36705 .28195 .35987 Mtetra
.667 .788 .939 r
.28195 .35987 .29042 .36705 .30336 .36207 .29492 .35493 Mtetra
.667 .79 .94 r
.29492 .35493 .30336 .36207 .31634 .35734 .30796 .34997 Mtetra
.666 .784 .937 r
.30796 .34997 .31634 .35734 .32937 .35259 .32105 .34502 Mtetra
.667 .78 .934 r
.32105 .34502 .32937 .35259 .34249 .3476 .33421 .34003 Mtetra
.669 .782 .934 r
.33421 .34003 .34249 .3476 .35567 .34258 .34743 .33493 Mtetra
.668 .781 .934 r
.34743 .33493 .35567 .34258 .36889 .33793 .36072 .32984 Mtetra
.661 .768 .929 r
.36072 .32984 .36889 .33793 .38215 .33376 .37405 .32496 Mtetra
.648 .746 .921 r
.37405 .32496 .38215 .33376 .39547 .32999 .38744 .32046 Mtetra
.631 .723 .914 r
.38744 .32046 .39547 .32999 .40884 .32657 .40087 .31646 Mtetra
.615 .704 .908 r
.40087 .31646 .40884 .32657 .42229 .3233 .41436 .31295 Mtetra
.605 .695 .907 r
.41436 .31295 .42229 .3233 .43583 .31977 .42792 .30973 Mtetra
.607 .704 .913 r
.42792 .30973 .43583 .31977 .44945 .31578 .44156 .30641 Mtetra
.617 .727 .924 r
.44156 .30641 .44945 .31578 .46316 .3114 .4553 .30273 Mtetra
.617 .746 .938 r
.4553 .30273 .46316 .3114 .47695 .30657 .46911 .29896 Mtetra
.602 .771 .961 r
.46911 .29896 .47695 .30657 .49081 .30189 .483 .29542 Mtetra
.578 .797 .982 r
.483 .29542 .49081 .30189 .50473 .29807 .49698 .29211 Mtetra
.602 .822 .984 r
.49698 .29211 .50473 .29807 .51873 .29498 .51104 .2881 Mtetra
.677 .821 .952 r
.51104 .2881 .51873 .29498 .53282 .2911 .52518 .28232 Mtetra
.716 .783 .904 r
.52518 .28232 .53282 .2911 .54698 .28539 .53938 .27512 Mtetra
.71 .747 .881 r
.53938 .27512 .54698 .28539 .5612 .27888 .55364 .26788 Mtetra
.694 .726 .875 r
.55364 .26788 .5612 .27888 .57548 .27305 .56796 .26117 Mtetra
.689 .708 .862 r
.56796 .26117 .57548 .27305 .58984 .26769 .58233 .25446 Mtetra
.687 .683 .84 r
.58233 .25446 .58984 .26769 .60426 .26172 .59677 .24748 Mtetra
.68 .664 .827 r
.59677 .24748 .60426 .26172 .61872 .25471 .61126 .24056 Mtetra
.674 .663 .832 r
.61126 .24056 .61872 .25471 .63321 .24706 .62582 .23398 Mtetra
.669 .68 .852 r
.62582 .23398 .63321 .24706 .64776 .23955 .64046 .22788 Mtetra
.664 .706 .879 r
.64046 .22788 .64776 .23955 .66239 .23278 .65519 .22221 Mtetra
.659 .73 .902 r
.65519 .22221 .66239 .23278 .67713 .22679 .67001 .21678 Mtetra
.657 .744 .914 r
.67001 .21678 .67713 .22679 .69197 .22127 .68491 .21145 Mtetra
.656 .749 .919 r
.68491 .21145 .69197 .22127 .70689 .21593 .6999 .20613 Mtetra
.656 .751 .92 r
.6999 .20613 .70689 .21593 .7219 .21063 .71496 .20079 Mtetra
.71496 .20079 .7219 .21063 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19003 Mtetra
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Mtetra
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Mtetra
.09895 .40806 .10788 .41598 .11996 .41171 .11106 .40374 Mtetra
.11106 .40374 .11996 .41171 .13209 .40744 .12323 .39941 Mtetra
.655 .75 .92 r
.12323 .39941 .13209 .40744 .14427 .40327 .13546 .39507 Mtetra
.652 .746 .919 r
.13546 .39507 .14427 .40327 .15646 .39946 .14773 .39079 Mtetra
.644 .733 .914 r
.14773 .39079 .15646 .39946 .16863 .39641 .16004 .38674 Mtetra
.626 .704 .901 r
.16004 .38674 .16863 .39641 .18075 .3945 .17235 .3832 Mtetra
.598 .658 .88 r
.17235 .3832 .18075 .3945 .19285 .39344 .18464 .38049 Mtetra
.571 .614 .857 r
.18464 .38049 .19285 .39344 .20507 .39204 .19691 .37861 Mtetra
.56 .602 .852 r
.19691 .37861 .20507 .39204 .21754 .38886 .20923 .37706 Mtetra
.581 .643 .877 r
.20923 .37706 .21754 .38886 .23028 .38349 .2217 .37482 Mtetra
.631 .735 .923 r
.2217 .37482 .23028 .38349 .24318 .37693 .23438 .371 Mtetra
.684 .826 .951 r
.23438 .371 .24318 .37693 .25611 .37056 .24728 .36554 Mtetra
.709 .857 .953 r
.24728 .36554 .25611 .37056 .26903 .36494 .2603 .35923 Mtetra
.708 .838 .945 r
.2603 .35923 .26903 .36494 .28195 .35987 .27337 .35299 Mtetra
.69 .804 .935 r
.27337 .35299 .28195 .35987 .29492 .35493 .28644 .34728 Mtetra
.674 .78 .93 r
.28644 .34728 .29492 .35493 .30796 .34997 .29953 .34207 Mtetra
.663 .771 .93 r
.29953 .34207 .30796 .34997 .32105 .34502 .31266 .33716 Mtetra
.658 .772 .934 r
.31266 .33716 .32105 .34502 .33421 .34003 .32585 .33239 Mtetra
.657 .779 .939 r
.32585 .33239 .33421 .34003 .34743 .33493 .33909 .32762 Mtetra
.658 .79 .945 r
.33909 .32762 .34743 .33493 .36072 .32984 .35241 .32277 Mtetra
.659 .798 .949 r
.35241 .32277 .36072 .32984 .37405 .32496 .3658 .31786 Mtetra
.657 .798 .95 r
.3658 .31786 .37405 .32496 .38744 .32046 .37924 .31297 Mtetra
.652 .786 .946 r
.37924 .31297 .38744 .32046 .40087 .31646 .39275 .30823 Mtetra
.644 .764 .936 r
.39275 .30823 .40087 .31646 .41436 .31295 .40632 .30374 Mtetra
.634 .736 .922 r
.40632 .30374 .41436 .31295 .42792 .30973 .41995 .29956 Mtetra
.622 .71 .908 r
.41995 .29956 .42792 .30973 .44156 .30641 .43364 .29573 Mtetra
.61 .694 .903 r
.43364 .29573 .44156 .30641 .4553 .30273 .4474 .29227 Mtetra
.603 .697 .91 r
.4474 .29227 .4553 .30273 .46911 .29896 .46124 .28899 Mtetra
.607 .712 .919 r
.46124 .28899 .46911 .29896 .483 .29542 .47516 .28555 Mtetra
.638 .727 .913 r
.47516 .28555 .483 .29542 .49698 .29211 .48919 .28112 Mtetra
.68 .719 .879 r
.48919 .28112 .49698 .29211 .51104 .2881 .5033 .27505 Mtetra
.697 .687 .837 r
.5033 .27505 .51104 .2881 .52518 .28232 .51748 .26767 Mtetra
.69 .66 .815 r
.51748 .26767 .52518 .28232 .53938 .27512 .53171 .26014 Mtetra
.677 .65 .815 r
.53171 .26014 .53938 .27512 .55364 .26788 .546 .25318 Mtetra
.67 .651 .823 r
.546 .25318 .55364 .26788 .56796 .26117 .56035 .2467 Mtetra
.667 .654 .828 r
.56035 .2467 .56796 .26117 .58233 .25446 .57476 .24041 Mtetra
.663 .66 .837 r
.57476 .24041 .58233 .25446 .59677 .24748 .58925 .23439 Mtetra
.661 .676 .854 r
.58925 .23439 .59677 .24748 .61126 .24056 .60381 .22864 Mtetra
.66 .7 .876 r
.60381 .22864 .61126 .24056 .62582 .23398 .61844 .22307 Mtetra
.659 .722 .895 r
.61844 .22307 .62582 .23398 .64046 .22788 .63316 .21763 Mtetra
.657 .738 .909 r
.63316 .21763 .64046 .22788 .65519 .22221 .64796 .21228 Mtetra
.656 .747 .916 r
.64796 .21228 .65519 .22221 .67001 .21678 .66284 .20695 Mtetra
.656 .75 .919 r
.66284 .20695 .67001 .21678 .68491 .21145 .67779 .20161 Mtetra
.656 .751 .92 r
.67779 .20161 .68491 .21145 .6999 .20613 .69283 .19625 Mtetra
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19003 .73842 .17999 Mtetra
.06583 .40873 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Mtetra
.10209 .39571 .11106 .40374 .12323 .39941 .11429 .39134 Mtetra
.11429 .39134 .12323 .39941 .13546 .39507 .12655 .38693 Mtetra
.655 .75 .92 r
.12655 .38693 .13546 .39507 .14773 .39079 .13887 .38253 Mtetra
.654 .748 .919 r
.13887 .38253 .14773 .39079 .16004 .38674 .15124 .37814 Mtetra
.649 .739 .915 r
.15124 .37814 .16004 .38674 .17235 .3832 .16366 .37386 Mtetra
.64 .719 .905 r
.16366 .37386 .17235 .3832 .18464 .38049 .17611 .36984 Mtetra
.622 .684 .887 r
.17611 .36984 .18464 .38049 .19691 .37861 .18857 .36633 Mtetra
.601 .643 .864 r
.18857 .36633 .19691 .37861 .20923 .37706 .20104 .36342 Mtetra
.583 .611 .846 r
.20104 .36342 .20923 .37706 .2217 .37482 .21352 .36107 Mtetra
.577 .607 .846 r
.21352 .36107 .2217 .37482 .23438 .371 .22606 .3589 Mtetra
.59 .644 .873 r
.22606 .3589 .23438 .371 .24728 .36554 .23872 .35631 Mtetra
.621 .722 .918 r
.23872 .35631 .24728 .36554 .2603 .35923 .25155 .35271 Mtetra
.656 .806 .955 r
.25155 .35271 .2603 .35923 .27337 .35299 .26454 .34795 Mtetra
.679 .855 .967 r
.26454 .34795 .27337 .35299 .28644 .34728 .27765 .34237 Mtetra
.688 .862 .965 r
.27765 .34237 .28644 .34728 .29953 .34207 .29085 .33648 Mtetra
.688 .844 .958 r
.29085 .33648 .29953 .34207 .31266 .33716 .30409 .33068 Mtetra
.681 .818 .949 r
.30409 .33068 .31266 .33716 .32585 .33239 .31737 .32512 Mtetra
.672 .795 .94 r
.31737 .32512 .32585 .33239 .33909 .32762 .3307 .31983 Mtetra
.665 .78 .935 r
.3307 .31983 .33909 .32762 .35241 .32277 .34407 .31477 Mtetra
.659 .774 .934 r
.34407 .31477 .35241 .32277 .3658 .31786 .3575 .30983 Mtetra
.655 .774 .936 r
.3575 .30983 .3658 .31786 .37924 .31297 .37099 .305 Mtetra
.651 .775 .939 r
.37099 .305 .37924 .31297 .39275 .30823 .38454 .30026 Mtetra
.644 .774 .942 r
.38454 .30026 .39275 .30823 .40632 .30374 .39815 .29568 Mtetra
.636 .77 .944 r
.39815 .29568 .40632 .30374 .41995 .29956 .41183 .29132 Mtetra
.629 .764 .944 r
.41183 .29132 .41995 .29956 .43364 .29573 .42557 .28714 Mtetra
.631 .756 .938 r
.42557 .28714 .43364 .29573 .4474 .29227 .4394 .2829 Mtetra
.645 .742 .92 r
.4394 .2829 .4474 .29227 .46124 .28899 .45331 .27826 Mtetra
.668 .72 .887 r
.45331 .27826 .46124 .28899 .47516 .28555 .46731 .27268 Mtetra
.683 .684 .845 r
.46731 .27268 .47516 .28555 .48919 .28112 .48139 .26606 Mtetra
.681 .649 .812 r
.48139 .26606 .48919 .28112 .5033 .27505 .49554 .25889 Mtetra
.67 .63 .801 r
.49554 .25889 .5033 .27505 .51748 .26767 .50974 .25199 Mtetra
.66 .632 .811 r
.50974 .25199 .51748 .26767 .53171 .26014 .52399 .24576 Mtetra
.655 .65 .833 r
.52399 .24576 .53171 .26014 .546 .25318 .53832 .24004 Mtetra
.656 .672 .854 r
.53832 .24004 .546 .25318 .56035 .2467 .55271 .2345 Mtetra
.656 .691 .871 r
.55271 .2345 .56035 .2467 .57476 .24041 .56717 .22908 Mtetra
.656 .71 .888 r
.56717 .22908 .57476 .24041 .58925 .23439 .58172 .22375 Mtetra
.657 .727 .901 r
.58172 .22375 .58925 .23439 .60381 .22864 .59634 .21843 Mtetra
.657 .738 .91 r
.59634 .21843 .60381 .22864 .61844 .22307 .61103 .21309 Mtetra
.656 .745 .915 r
.61103 .21309 .61844 .22307 .63316 .21763 .62581 .20777 Mtetra
.656 .749 .919 r
.62581 .20777 .63316 .21763 .64796 .21228 .64066 .20244 Mtetra
.656 .751 .92 r
.64066 .20244 .64796 .21228 .66284 .20695 .65559 .19707 Mtetra
.65559 .19707 .66284 .20695 .67779 .20161 .6706 .19169 Mtetra
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73842 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40873 .07786 .40441 .06874 .39639 Mtetra
.06874 .39639 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09303 .38761 Mtetra
.09303 .38761 .10209 .39571 .11429 .39134 .10527 .38319 Mtetra
.10527 .38319 .11429 .39134 .12655 .38693 .11756 .37876 Mtetra
.11756 .37876 .12655 .38693 .13887 .38253 .12992 .37429 Mtetra
.655 .751 .92 r
.12992 .37429 .13887 .38253 .15124 .37814 .14233 .36982 Mtetra
.655 .75 .919 r
.14233 .36982 .15124 .37814 .16366 .37386 .1548 .36533 Mtetra
.653 .745 .917 r
.1548 .36533 .16366 .37386 .17611 .36984 .16733 .36088 Mtetra
.649 .734 .911 r
.16733 .36088 .17611 .36984 .18857 .36633 .17991 .35651 Mtetra
.64 .712 .899 r
.17991 .35651 .18857 .36633 .20104 .36342 .19252 .35238 Mtetra
.628 .681 .881 r
.19252 .35238 .20104 .36342 .21352 .36107 .20516 .34856 Mtetra
.615 .647 .859 r
.20516 .34856 .21352 .36107 .22606 .3589 .21784 .34511 Mtetra
.603 .621 .841 r
.21784 .34511 .22606 .3589 .23872 .35631 .23056 .34196 Mtetra
.596 .609 .835 r
.23056 .34196 .23872 .35631 .25155 .35271 .24333 .33904 Mtetra
.598 .622 .846 r
.24333 .33904 .25155 .35271 .26454 .34795 .25619 .33606 Mtetra
.61 .661 .875 r
.25619 .33606 .26454 .34795 .27765 .34237 .26914 .33272 Mtetra
.628 .719 .912 r
.26914 .33272 .27765 .34237 .29085 .33648 .28222 .32882 Mtetra
.644 .776 .944 r
.28222 .32882 .29085 .33648 .30409 .33068 .29541 .32436 Mtetra
.653 .818 .963 r
.29541 .32436 .30409 .33068 .31737 .32512 .30869 .3195 Mtetra
.656 .84 .971 r
.30869 .3195 .31737 .32512 .3307 .31983 .32206 .31442 Mtetra
.655 .847 .974 r
.32206 .31442 .3307 .31983 .34407 .31477 .33549 .30927 Mtetra
.653 .845 .974 r
.33549 .30927 .34407 .31477 .3575 .30983 .34898 .30416 Mtetra
.651 .841 .973 r
.34898 .30416 .3575 .30983 .37099 .305 .36253 .2991 Mtetra
.651 .836 .971 r
.36253 .2991 .37099 .305 .38454 .30026 .37615 .29406 Mtetra
.655 .829 .967 r
.37615 .29406 .38454 .30026 .39815 .29568 .38984 .28894 Mtetra
.664 .818 .957 r
.38984 .28894 .39815 .29568 .41183 .29132 .40361 .28362 Mtetra
.677 .796 .938 r
.40361 .28362 .41183 .29132 .42557 .28714 .41745 .27795 Mtetra
.688 .762 .908 r
.41745 .27795 .42557 .28714 .4394 .2829 .43137 .27183 Mtetra
.692 .722 .873 r
.43137 .27183 .4394 .2829 .45331 .27826 .44537 .26522 Mtetra
.685 .683 .842 r
.44537 .26522 .45331 .27826 .46731 .27268 .45943 .25844 Mtetra
.674 .659 .827 r
.45943 .25844 .46731 .27268 .48139 .26606 .47354 .25189 Mtetra
.663 .656 .833 r
.47354 .25189 .48139 .26606 .49554 .25889 .4877 .24587 Mtetra
.657 .674 .855 r
.4877 .24587 .49554 .25889 .50974 .25199 .50192 .24034 Mtetra
.656 .701 .88 r
.50192 .24034 .50974 .25199 .52399 .24576 .51622 .23501 Mtetra
.658 .723 .897 r
.51622 .23501 .52399 .24576 .53832 .24004 .53058 .22969 Mtetra
.657 .733 .905 r
.53058 .22969 .53832 .24004 .55271 .2345 .54502 .2244 Mtetra
.655 .739 .912 r
.54502 .2244 .55271 .2345 .56717 .22908 .55954 .21918 Mtetra
.655 .745 .916 r
.55954 .21918 .56717 .22908 .58172 .22375 .57414 .21392 Mtetra
.657 .749 .918 r
.57414 .21392 .58172 .22375 .59634 .21843 .58881 .20859 Mtetra
.656 .75 .919 r
.58881 .20859 .59634 .21843 .61103 .21309 .60356 .20325 Mtetra
.656 .751 .92 r
.60356 .20325 .61103 .21309 .62581 .20777 .61838 .1979 Mtetra
.61838 .1979 .62581 .20777 .64066 .20244 .63329 .19252 Mtetra
.63329 .19252 .64066 .20244 .65559 .19707 .64828 .18711 Mtetra
.64828 .18711 .65559 .19707 .6706 .19169 .66334 .18167 Mtetra
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39639 .05954 .38829 Mtetra
.05954 .38829 .06874 .39639 .08086 .39201 .07169 .38388 Mtetra
.07169 .38388 .08086 .39201 .09303 .38761 .0839 .37944 Mtetra
.0839 .37944 .09303 .38761 .10527 .38319 .09617 .37498 Mtetra
.09617 .37498 .10527 .38319 .11756 .37876 .10849 .3705 Mtetra
.10849 .3705 .11756 .37876 .12992 .37429 .12088 .366 Mtetra
.12088 .366 .12992 .37429 .14233 .36982 .13333 .36148 Mtetra
.13333 .36148 .14233 .36982 .1548 .36533 .14584 .35693 Mtetra
.14584 .35693 .1548 .36533 .16733 .36088 .15841 .35237 Mtetra
.655 .749 .919 r
.15841 .35237 .16733 .36088 .17991 .35651 .17104 .34781 Mtetra
.654 .745 .916 r
.17104 .34781 .17991 .35651 .19252 .35238 .18373 .34323 Mtetra
.651 .734 .91 r
.18373 .34323 .19252 .35238 .20516 .34856 .19647 .33871 Mtetra
.646 .716 .899 r
.19647 .33871 .20516 .34856 .21784 .34511 .20926 .33432 Mtetra
.638 .694 .885 r
.20926 .33432 .21784 .34511 .23056 .34196 .22211 .33011 Mtetra
.632 .671 .869 r
.22211 .33011 .23056 .34196 .24333 .33904 .235 .32601 Mtetra
.626 .647 .851 r
.235 .32601 .24333 .33904 .25619 .33606 .24796 .32199 Mtetra
.621 .628 .836 r
.24796 .32199 .25619 .33606 .26914 .33272 .26098 .31805 Mtetra
.618 .618 .828 r
.26098 .31805 .26914 .33272 .28222 .32882 .27406 .31415 Mtetra
.619 .619 .829 r
.27406 .31415 .28222 .32882 .29541 .32436 .28722 .31019 Mtetra
.624 .63 .836 r
.28722 .31019 .29541 .32436 .30869 .3195 .30047 .30607 Mtetra
.632 .647 .847 r
.30047 .30607 .30869 .3195 .32206 .31442 .3138 .3017 Mtetra
.641 .664 .857 r
.3138 .3017 .32206 .31442 .33549 .30927 .32723 .29706 Mtetra
.649 .678 .864 r
.32723 .29706 .33549 .30927 .34898 .30416 .34073 .29213 Mtetra
.656 .685 .865 r
.34073 .29213 .34898 .30416 .36253 .2991 .35432 .28694 Mtetra
.661 .685 .862 r
.35432 .28694 .36253 .2991 .37615 .29406 .36799 .28149 Mtetra
.665 .68 .855 r
.36799 .28149 .37615 .29406 .38984 .28894 .38173 .27581 Mtetra
.666 .672 .845 r
.38173 .27581 .38984 .28894 .40361 .28362 .39555 .26992 Mtetra
.666 .663 .837 r
.39555 .26992 .40361 .28362 .41745 .27795 .40943 .26391 Mtetra
.664 .657 .833 r
.40943 .26391 .41745 .27795 .43137 .27183 .42337 .2579 Mtetra
.66 .658 .837 r
.42337 .2579 .43137 .27183 .44537 .26522 .43737 .25209 Mtetra
.658 .671 .852 r
.43737 .25209 .44537 .26522 .45943 .25844 .45144 .24651 Mtetra
.657 .695 .874 r
.45144 .24651 .45943 .25844 .47354 .25189 .46556 .24113 Mtetra
.658 .721 .895 r
.46556 .24113 .47354 .25189 .4877 .24587 .47975 .23581 Mtetra
.66 .739 .909 r
.47975 .23581 .4877 .24587 .50192 .24034 .49402 .23047 Mtetra
.659 .745 .913 r
.49402 .23047 .50192 .24034 .51622 .23501 .50836 .22514 Mtetra
.655 .745 .915 r
.50836 .22514 .51622 .23501 .53058 .22969 .52278 .21991 Mtetra
.653 .747 .919 r
.52278 .21991 .53058 .22969 .54502 .2244 .53727 .21472 Mtetra
.655 .752 .921 r
.53727 .21472 .54502 .2244 .55954 .21918 .55184 .20945 Mtetra
.657 .753 .92 r
.55184 .20945 .55954 .21918 .57414 .21392 .56648 .20409 Mtetra
.656 .751 .92 r
.56648 .20409 .57414 .21392 .58881 .20859 .58121 .19872 Mtetra
.58121 .19872 .58881 .20859 .60356 .20325 .59601 .19335 Mtetra
.656 .752 .92 r
.59601 .19335 .60356 .20325 .61838 .1979 .61089 .18794 Mtetra
.656 .751 .92 r
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .1825 Mtetra
.62585 .1825 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Mtetra
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38455 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.05026 .38012 .05954 .38829 .07169 .38388 .06244 .37567 Mtetra
.06244 .37567 .07169 .38388 .0839 .37944 .07468 .37119 Mtetra
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36218 Mtetra
.09934 .36218 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.11176 .35763 .12088 .366 .13333 .36148 .12424 .35307 Mtetra
.656 .752 .92 r
.12424 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Mtetra
.656 .751 .92 r
.13679 .34848 .14584 .35693 .15841 .35237 .14939 .34387 Mtetra
.14939 .34387 .15841 .35237 .17104 .34781 .16206 .33923 Mtetra
.655 .75 .92 r
.16206 .33923 .17104 .34781 .18373 .34323 .17479 .3346 Mtetra
.655 .75 .919 r
.17479 .3346 .18373 .34323 .19647 .33871 .18758 .32994 Mtetra
.655 .747 .918 r
.18758 .32994 .19647 .33871 .20926 .33432 .20044 .32525 Mtetra
.655 .741 .913 r
.20044 .32525 .20926 .33432 .22211 .33011 .21336 .32052 Mtetra
.652 .729 .905 r
.21336 .32052 .22211 .33011 .235 .32601 .22633 .31587 Mtetra
.648 .715 .897 r
.22633 .31587 .235 .32601 .24796 .32199 .23937 .31129 Mtetra
.645 .703 .889 r
.23937 .31129 .24796 .32199 .26098 .31805 .25246 .30677 Mtetra
.644 .691 .879 r
.25246 .30677 .26098 .31805 .27406 .31415 .26563 .30221 Mtetra
.643 .678 .869 r
.26563 .30221 .27406 .31415 .28722 .31019 .27886 .2976 Mtetra
.642 .667 .858 r
.27886 .2976 .28722 .31019 .30047 .30607 .29217 .2929 Mtetra
.642 .657 .85 r
.29217 .2929 .30047 .30607 .3138 .3017 .30555 .28814 Mtetra
.642 .651 .844 r
.30555 .28814 .3138 .3017 .32723 .29706 .319 .28328 Mtetra
.643 .649 .841 r
.319 .28328 .32723 .29706 .34073 .29213 .33253 .27832 Mtetra
.645 .65 .84 r
.33253 .27832 .34073 .29213 .35432 .28694 .34613 .27326 Mtetra
.647 .654 .843 r
.34613 .27326 .35432 .28694 .36799 .28149 .35981 .26811 Mtetra
.65 .661 .848 r
.35981 .26811 .36799 .28149 .38173 .27581 .37355 .2629 Mtetra
.652 .671 .856 r
.37355 .2629 .38173 .27581 .39555 .26992 .38737 .25765 Mtetra
.654 .685 .867 r
.38737 .25765 .39555 .26992 .40943 .26391 .40125 .2524 Mtetra
.655 .702 .881 r
.40125 .2524 .40943 .26391 .42337 .2579 .4152 .24717 Mtetra
.658 .721 .895 r
.4152 .24717 .42337 .2579 .43737 .25209 .42923 .24187 Mtetra
.66 .734 .905 r
.42923 .24187 .43737 .25209 .45144 .24651 .44333 .23655 Mtetra
.66 .741 .91 r
.44333 .23655 .45144 .24651 .46556 .24113 .45749 .2312 Mtetra
.658 .743 .912 r
.45749 .2312 .46556 .24113 .47975 .23581 .47173 .2259 Mtetra
.655 .743 .915 r
.47173 .2259 .47975 .23581 .49402 .23047 .48605 .2207 Mtetra
.652 .747 .919 r
.48605 .2207 .49402 .23047 .50836 .22514 .50043 .21555 Mtetra
.654 .753 .923 r
.50043 .21555 .50836 .22514 .52278 .21991 .5149 .21031 Mtetra
.658 .756 .922 r
.5149 .21031 .52278 .21991 .53727 .21472 .52944 .20493 Mtetra
.657 .752 .92 r
.52944 .20493 .53727 .21472 .55184 .20945 .54406 .19953 Mtetra
.655 .749 .919 r
.54406 .19953 .55184 .20945 .56648 .20409 .55875 .19417 Mtetra
.655 .751 .92 r
.55875 .19417 .56648 .20409 .58121 .19872 .57353 .18879 Mtetra
.656 .752 .921 r
.57353 .18879 .58121 .19872 .59601 .19335 .58838 .18335 Mtetra
.656 .751 .92 r
.58838 .18335 .59601 .19335 .61089 .18794 .60332 .17788 Mtetra
.60332 .17788 .61089 .18794 .62585 .1825 .61833 .17239 Mtetra
.61833 .17239 .62585 .1825 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37636 .03814 .38455 .05026 .38012 .0409 .37188 Mtetra
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Mtetra
.07772 .35833 .08698 .36669 .09934 .36218 .09011 .35377 Mtetra
.09011 .35377 .09934 .36218 .11176 .35763 .10256 .34919 Mtetra
.10256 .34919 .11176 .35763 .12424 .35307 .11508 .34458 Mtetra
.11508 .34458 .12424 .35307 .13679 .34848 .12766 .33996 Mtetra
.12766 .33996 .13679 .34848 .14939 .34387 .1403 .3353 Mtetra
.1403 .3353 .14939 .34387 .16206 .33923 .153 .33063 Mtetra
.656 .752 .92 r
.153 .33063 .16206 .33923 .17479 .3346 .16577 .32592 Mtetra
.656 .751 .92 r
.16577 .32592 .17479 .3346 .18758 .32994 .1786 .3212 Mtetra
.655 .75 .92 r
.1786 .3212 .18758 .32994 .20044 .32525 .19149 .31646 Mtetra
.654 .75 .92 r
.19149 .31646 .20044 .32525 .21336 .32052 .20444 .31174 Mtetra
.656 .752 .92 r
.20444 .31174 .21336 .32052 .22633 .31587 .21747 .30695 Mtetra
.657 .75 .918 r
.21747 .30695 .22633 .31587 .23937 .31129 .23056 .3021 Mtetra
.657 .744 .914 r
.23056 .3021 .23937 .31129 .25246 .30677 .24372 .29719 Mtetra
.655 .735 .908 r
.24372 .29719 .25246 .30677 .26563 .30221 .25694 .29232 Mtetra
.653 .728 .904 r
.25694 .29232 .26563 .30221 .27886 .2976 .27023 .28748 Mtetra
.651 .723 .901 r
.27023 .28748 .27886 .2976 .29217 .2929 .28358 .28265 Mtetra
.651 .721 .9 r
.28358 .28265 .29217 .2929 .30555 .28814 .297 .2778 Mtetra
.652 .721 .899 r
.297 .2778 .30555 .28814 .319 .28328 .31049 .27291 Mtetra
.653 .722 .899 r
.31049 .27291 .319 .28328 .33253 .27832 .32405 .26796 Mtetra
.654 .723 .899 r
.32405 .26796 .33253 .27832 .34613 .27326 .33768 .26295 Mtetra
.655 .726 .901 r
.33768 .26295 .34613 .27326 .35981 .26811 .35139 .25787 Mtetra
.656 .729 .903 r
.35139 .25787 .35981 .26811 .37355 .2629 .36517 .25274 Mtetra
.657 .732 .905 r
.36517 .25274 .37355 .2629 .38737 .25765 .37902 .24755 Mtetra
.658 .735 .907 r
.37902 .24755 .38737 .25765 .40125 .2524 .39294 .24233 Mtetra
.658 .737 .908 r
.39294 .24233 .40125 .2524 .4152 .24717 .40693 .23708 Mtetra
.656 .737 .909 r
.40693 .23708 .4152 .24717 .42923 .24187 .421 .23188 Mtetra
.654 .74 .913 r
.421 .23188 .42923 .24187 .44333 .23655 .43513 .22672 Mtetra
.653 .744 .917 r
.43513 .22672 .44333 .23655 .45749 .2312 .44934 .22159 Mtetra
.653 .751 .922 r
.44934 .22159 .45749 .2312 .47173 .2259 .46363 .21642 Mtetra
.656 .756 .924 r
.46363 .21642 .47173 .2259 .48605 .2207 .47799 .21113 Mtetra
.659 .757 .922 r
.47799 .21113 .48605 .2207 .50043 .21555 .49243 .20573 Mtetra
.658 .752 .919 r
.49243 .20573 .50043 .21555 .5149 .21031 .50694 .20032 Mtetra
.655 .748 .918 r
.50694 .20032 .5149 .21031 .52944 .20493 .52153 .19497 Mtetra
.654 .749 .919 r
.52153 .19497 .52944 .20493 .54406 .19953 .5362 .18962 Mtetra
.656 .752 .921 r
.5362 .18962 .54406 .19953 .55875 .19417 .55095 .1842 Mtetra
.55095 .1842 .55875 .19417 .57353 .18879 .56578 .17873 Mtetra
.656 .751 .92 r
.56578 .17873 .57353 .18879 .58838 .18335 .58068 .17324 Mtetra
.58068 .17324 .58838 .18335 .60332 .17788 .59567 .16772 Mtetra
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .1397 Mtetra
.67184 .1397 .6792 .15013 .69463 .14449 .68732 .134 Mtetra
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37636 .0409 .37188 .03145 .36357 Mtetra
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35448 Mtetra
.056 .35448 .06538 .36287 .07772 .35833 .06836 .34989 Mtetra
.06836 .34989 .07772 .35833 .09011 .35377 .08079 .34529 Mtetra
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.10583 .33602 .11508 .34458 .12766 .33996 .11844 .33135 Mtetra
.11844 .33135 .12766 .33996 .1403 .3353 .13112 .32666 Mtetra
.656 .752 .92 r
.13112 .32666 .1403 .3353 .153 .33063 .14385 .32193 Mtetra
.655 .751 .92 r
.14385 .32193 .153 .33063 .16577 .32592 .15666 .3172 Mtetra
.656 .752 .921 r
.15666 .3172 .16577 .32592 .1786 .3212 .16952 .31244 Mtetra
.16952 .31244 .1786 .3212 .19149 .31646 .18245 .30765 Mtetra
.657 .752 .92 r
.18245 .30765 .19149 .31646 .20444 .31174 .19545 .30279 Mtetra
.656 .749 .919 r
.19545 .30279 .20444 .31174 .21747 .30695 .20851 .29795 Mtetra
.654 .749 .919 r
.20851 .29795 .21747 .30695 .23056 .3021 .22164 .29313 Mtetra
.653 .751 .921 r
.22164 .29313 .23056 .3021 .24372 .29719 .23483 .28832 Mtetra
.655 .754 .923 r
.23483 .28832 .24372 .29719 .25694 .29232 .24808 .28345 Mtetra
.656 .756 .923 r
.24808 .28345 .25694 .29232 .27023 .28748 .26142 .2785 Mtetra
.658 .755 .922 r
.26142 .2785 .27023 .28748 .28358 .28265 .27482 .27348 Mtetra
.658 .751 .919 r
.27482 .27348 .28358 .28265 .297 .2778 .28829 .26844 Mtetra
.657 .747 .917 r
.28829 .26844 .297 .2778 .31049 .27291 .30183 .26337 Mtetra
.656 .744 .915 r
.30183 .26337 .31049 .27291 .32405 .26796 .31543 .25831 Mtetra
.656 .742 .914 r
.31543 .25831 .32405 .26796 .33768 .26295 .32911 .25323 Mtetra
.655 .742 .914 r
.32911 .25323 .33768 .26295 .35139 .25787 .34286 .24816 Mtetra
.655 .743 .915 r
.34286 .24816 .35139 .25787 .36517 .25274 .35667 .24307 Mtetra
.654 .745 .916 r
.35667 .24307 .36517 .25274 .37902 .24755 .37056 .23797 Mtetra
.654 .748 .919 r
.37056 .23797 .37902 .24755 .39294 .24233 .38452 .23287 Mtetra
.653 .752 .922 r
.38452 .23287 .39294 .24233 .40693 .23708 .39855 .22774 Mtetra
.655 .757 .925 r
.39855 .22774 .40693 .23708 .421 .23188 .41266 .22254 Mtetra
.657 .759 .925 r
.41266 .22254 .421 .23188 .43513 .22672 .42685 .21725 Mtetra
.659 .757 .923 r
.42685 .21725 .43513 .22672 .44934 .22159 .44111 .21187 Mtetra
.659 .753 .919 r
.44111 .21187 .44934 .22159 .46363 .21642 .45545 .20647 Mtetra
.656 .748 .917 r
.45545 .20647 .46363 .21642 .47799 .21113 .46986 .2011 Mtetra
.654 .746 .917 r
.46986 .2011 .47799 .21113 .49243 .20573 .48434 .1958 Mtetra
.654 .749 .92 r
.48434 .1958 .49243 .20573 .50694 .20032 .4989 .19047 Mtetra
.656 .753 .922 r
.4989 .19047 .50694 .20032 .52153 .19497 .51355 .18505 Mtetra
.657 .753 .921 r
.51355 .18505 .52153 .19497 .5362 .18962 .52827 .17957 Mtetra
.656 .751 .92 r
.52827 .17957 .5362 .18962 .55095 .1842 .54307 .17408 Mtetra
.54307 .17408 .55095 .1842 .56578 .17873 .55795 .16858 Mtetra
.55795 .16858 .56578 .17873 .58068 .17324 .57291 .16304 Mtetra
.656 .752 .92 r
.57291 .16304 .58068 .17324 .59567 .16772 .58795 .15746 Mtetra
.656 .751 .92 r
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.64894 .13488 .65644 .14536 .67184 .1397 .66439 .12915 Mtetra
.66439 .12915 .67184 .1397 .68732 .134 .67994 .1234 Mtetra
.67994 .1234 .68732 .134 .70289 .12827 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?ooo`<0Z<3[;@2W`>/00`000000Yl3[0:O0j`080:O0ja80oooo00<000000?ooo`3oool0
<P3oool004`0oooo1000001<0?ooo`H0Z<3[;02W`>/00`000000Yl3[0:O0j`090:O0ja00oooo00<0
00000?ooo`000000<`3oool001d0oooo0P0000040?ooo`8000000`3oool4000001h0oooo0P00001=
0?ooo`@0Yl3/1P2X`>/[0:O0j`030000002W`>/0Yl3[00T0Yl3[4P3oool00`000000oooo0?ooo`0a
0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01`0oooo0`00001=
0?ooo`<0Yko[102W`>`30:S0j`<0Yko[:P2W`>/00`000000Yl3[0:O0j`0:0:O0ja80oooo00<00000
0?ooo`3oool0<03oool001`0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0I
0?ooo`800000CP3oool60:Noj`@0Yl3/1P2W_n/20:O0j`<0Yko[902W`>/00`000000Yl3[0:O0j`0;
0:O0ja80oooo00<000000?ooo`3oool0;`3oool001H0oooo100000020?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool05@3oool3000004`0oooo1@2W_^XE0:Nojb<0Yl3[00<00000
0:O0j`2W`>/02`2W`>/B0?ooo`030000003oool0oooo02l0oooo000L0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000004`3oool3000004d0oooo0`2W_nX50:NnjPD0Z<3[1@2W
_n/50:S0j`D0Yko[6`2W`>/30:Noj`D0Yl3[00<000000:O0j`2W`>/0302W`>/B0?ooo`030000003o
ool0oooo02h0oooo000M0?ooo`8000002P3oool200000180oooo1000001<0?ooo`H0YkoZ0P2W_^X3
0:S1k0D0Z<3[0P2W_n/30:S1k0X0Z<3[1@2W`>/50:Noj`@0Yl3[1@2W_n/50:O0j`H0Yko[102W`>/0
0`000000Yl3[0:O0j`0=0:O0ja80oooo00<000000?ooo`3oool0;@3oool003/0oooo0P00001<0?oo
o`D0Z<3[1@2W_nX60:S1k0@0Z<3[1P2X`N`20:S0j`<0Yl3[1@2X`>/20:O0j`<0Z;o[1@2W_n/40:Nn
jPD0Yko[1@2W_nX90:Noj`030000002W`>/0Yl3[00d0Yl3[4P3oool00`000000oooo0?ooo`0]0?oo
o`00>03oool3000004`0oooo0`2X`N`50:S0j`D0Yl7/1@2X`N`50:O0k0D0Z<7/1P2W`>/40:S0j`H0
Z;o[0P2W_n/30:Rlj0@0YkkZ0P2W_n/30:Rlj0D0YkoZ1@2X_^T40:Noj`030000002W_n/0Yko[00<0
Yko[2P2W`>/A0?ooo`800000;P3oool003D0oooo0`00001=0?ooo`H0Z<7/0P2X`>/30:O0k0D0Yl7/
1@2V_n/50:O0k0D0Yko[1@2W`>/50:NnjPD0Z;o[1P2X_>P30:NnjPH0Z;cX0P2W_nX30:RjiPD0Z;kY
0P2W_n/00`2X_^T000000:Rnj@0:0:Noj`D0Yl3[4@3oool00`000000oooo0?ooo`0/0?ooo`00<`3o
ool2000004d0oooo1@2X`^`40:S1k0H0Yl3/0P2W`N`30:NnjPD0Y[o[0P2W`>`30:NnjPD0Yko[1@2W
_NT50:NnjPD0Z;[V1@2X_>P40:Rhi@D0Z;cX1P2X^^H70:Rnj@030000002X_^T0Z;kY0080Yko[0`2X
_^T50:Noj`D0Yl3[4@3oool00`000000oooo0?ooo`0[0?ooo`00<03oool3000004/0oooo1@2W`N`5
0:S2k0@0YkkZ1@2W`>`60:NnjP@0Y[o[1P2W_^X20:Noj`<0Z;_W1@2W_NT20:NnjP<0YkGS1@2X^^H2
0:Rlj0<0Z;?P102X^>D50:Vdh@D0Z;[V1@2Y^ND20:Rnj@030000002X_^T0Z;kY00H0Z;kY102W_n/6
0:O0ja40oooo00<000000?ooo`3oool0:P3oool002h0oooo0`00001;0?ooo`<0Yl3/1@2W`N`50:Nm
j@@0YkkZ1@2X_^T50:NnjPD0Z;kY1@2W_^X60:Rki`@0YkgY1P2W]N<40:RjiPD0Z;?P0P2X^>D30:^^
fPD0ZKCQ0P2X^^H30:^bgPD0ZKWU00<0Z[[U0000002Z^^D00P2Z^^D50:Rnj@D0Z;oZ1@2W`>/A0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`<000000`3oool00`000000oooo0?ooo`160?ooo`H0
Yl3/0P2W`N`30:Nlj0D0YkgY0P2W_^X20:Rmj0D0Z;kY1@2X_NP50:Rnj@D0Z;WU1@2X^nL50:N`gPD0
YkGS1@2Y[MX40:Rch0H0ZjkJ102Y]>460:^bgP80ZKWU0`2]/md00`000000Z[[U0:Zji@020:Zji@D0
Z[_V1@2X_nX50:Roja40oooo00<000000?ooo`3oool0:@3oool002T0oooo0P00001;0?ooo`D0Yko[
1@2W`>`60:Nlj0@0YkgY1@2X_NP30:Rnj@80Z;SU1@2X_NP20:Rnj@<0Yk?Q1@2X^ND20:Rki`<0YjcJ
1@2W/=h20:Neh`<0ZJSF1@2Y[MX20:Rch080[:WD1@2[[]X50:j/ePD0Zk;N1@2]/md00`000000Z[[U
0:Zji@030:jegPD0Z[_V0P2X_nX30:Vmj0@0Z;o[4P3oool00`000000oooo0?ooo`0X0?ooo`009P3o
ool3000004X0oooo102W_^X50:Noj`D0Z;cX1@2W_>P50:Rki`D0Z;gX1@2X^>D40:Rmj0H0Yk?Q102X
^ND60:N/fP@0Yk3N1@2YZ=H50:V]fP@0[:WD102[[]X20;2[dPD0[ZcF0P2[/]h30;2]e0@0[K?M00<0
00000:jegP2^]Mh0102^]Mh40:ZkiPD0ZKgX0P2X_n/30:RojQ40oooo00<000000?ooo`3oool0:03o
ool002@0oooo0P00001;0?ooo`L0YkkZ0`2W_n/70:Rlj080YkcX0`2X^>D50:Rki`D0Z;7O1@2X^>D4
0:R/fPD0Yk?Q1@2WY]D50:N/fPD0ZZOC1@2YZ=H20:V]fP<0[ZWC102/ZM@20:^^fP<0/:_B1@2^[=H6
0;2]e080[K?M0P0000000`2c[m@0[[GN0:jegP030:jegPD0[KWR102Y_NP60:RojQ00oooo0P00000Y
0?ooo`008@3oool3000004/0oooo2P2W_^X90:Rlj0H0Z;SU0P2X^nL30:R[fPD0Z;7O0P2X^>D30:VW
e@@0Z:cJ0P2W/n430:RQc`D0YjKE0P2W[=X30:^VdPD0ZZOC102YZ=H50:jYd`@0[:WD1P2`Zm820:j/
eP<0]:gA102`[M@300000080/joD00@000000;>_e02^]Mh0[[GN0`2d/]L40:fihPD0[;cV1@2X_nXB
0?ooo`030000003oool0oooo02H0oooo000O0?ooo`<00000B@3oool50:Nmj@D0YkkZ1@2X^nL40:Rl
j0D0Yk?Q1@2X^>D50:R[fPD0Z;7O1@2YYmD40:R/fPD0Z:7?1@2WY]D50:^VdPD0ZZOC1@2_[]L50:jY
d`80[:WD0P2c/=D50;2[dPD0]:gA00@0/:gD00000000000000000P2h[m030;>_e0030000002c[m@0
];;G00D0];;G0P2]^N820;>gg0D0[;cV1@2Y_^TA0?ooo`030000003oool0oooo02H0oooo000M0?oo
o`800000B`3oool70:Nmj@D0Yk[W1@2X^nL40:N_g@D0Yk?Q1@2XZ=H50:R[fP80Z;7O0`2/Z=<50:VW
e@80Z:cJ0P2[XLd50:RQc`80YjKE0`2]Y]050:^VdP80ZZOC0`2`]M`50:n^e`@0[ZWC1@2c/=D20;2[
dP<0]kGG0P2d[M4300000080/:gD0`2h[m040;>_e0030000002j/=00];;G00@0];;G1@2c]m`20:bl
iP<0/;_R1@2Y_^TA0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`8000000`3oool40000
00X0oooo000E0?ooo`D000000`3oool2000004T0oooo1`2W_NT30:NiiPD0Yk[W0P2X^nL30:J[f`@0
YjoM0`2W/n420:VXe@D0Z:SF102XZmX50:bXd`D0ZJOE1@2[XLd40:RQc`D0[JK@1@2[Y]850;2eg0D0
[jkG1@2b^]l40;>`e@@0]kGG0`0000030;B]d@H0^:o@0P2c[m@20;Z`d0030000002d/]L0];;G0080
];;G0P2k/]440;>gg0H0/;_R0P2Y_^T30:^nj140oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0
oooo0`0000140?ooo`D0YkkZ102W_NT60:NiiP@0Yk[W1@2VZm/50:N_g@D0ZJSE102XZ=H50:n^e`D0
[:SC0P2YYmD30:jVc`D0Zj7=0P2XXLl20;2Xd0D0[JK@0P2[Y]830;6ig`D0/;GL0P2_[]L30:k4jPD0
/[[O0P2c/=D20;;1i@030;Nee`00000000000080]kGG0P2d[M430;Vge`D0^:o@1@2j/=000`000000
];;G0;Bbe`030;^bd@80/kOL0`2i]]L50;2khPH0ZkkX403oool00`000000oooo0?ooo`0:0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`00000o0?ooo`D0Z;oZ1@2W_^X90:NiiPD0YZWI1@2VZm/20:N_
g@<0ZZWF1@2YZ=D20:RXeP80/KSO1@2_[]L40:bXd`D0[ZK?1@2[XLd40;2Xd0D0[JK@1P2a^Ml40;2e
g0H0[/CZ102b^]l20;;1i@<00000102g]ML60;Vge`80^:o@0`2l]]<40;Z`d0030000002k/]40^k;A
00<0^k;A1P2i]]L20;2khP<0];cO1@2[_^PA0?ooo`030000003oool0oooo00<0oooo100000020?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool02@3oool000l0oooo100000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?oo
o`80Z<3[1@2X_nX50:NhiPL0YkWV0P2UYmL50:JYf@@0YZ_K1@2ZZMH50:VXe@@0/KSO1@2_[]L50:j_
f0D0[ZK?0P2[XLd30;:_eP@0/:S@0P2]Y]030;Foh@D0/KWO1@2Yb_450:k4jP<0YL[c0`0000030;;1
i@80]kGG0`2a`nL50;Vge`H0_;KC0P2j/=020;ndc`040000002k/]40^k;A0;^bd@80`KC=1@2i]]L6
0;Blg`D0[KoW4@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000002P3oool001L0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<0
00000?ooo`3oool0>03oool50:S0j`<0Z;oZ0P2V^>H50:NhiP@0YkWV1@2UYmL40:JYf@D0ZZcH1@2Z
ZMH20:VXe@<0/<?X102a^=l20:n^e`<0ZkSS102^[mP50:jVc`D0/ZoF102`Z=060;Foh@80/KWO0`2^
cO450:W:l@@0Vlci0`0000020:G:l`@0//7U1P2a`nL20;Vge`<0]<;T1@2l]]<50;ndc`030000002k
/]40`KC=0080`KC=102i]]L20<2hdP@0];cO0P2j_M`40:foia00oooo0P00000;0?ooo`8000002P3o
ool2000000/0oooo000F0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03<0oooo1@2X`N`50:S0j`D0Y[SV102W^>H50:FVe`D0YJOG0P2VZMT20:Z^fPD0ZZcH102ZZMH6
0;33j0<0/KSO1@2[^><50:j_f080[ZK?0`2^^>450;:_eP80/:S@0P2gb>L50;Foh@H0[/ga0P2Yb_43
09k<m`<000000P2Kc?T30:G:l`D0W<Sf1@2a`nL50;C2i0@0_;KC0P2j_M`50;ndc`0300000031]<d0
`KC=0080`KC=0P2i]]L40<2hdP80];cO0`2j_M`20:foi`<0[l3V4@3oool00`000000oooo0?ooo`0Q
0?ooo`00703oool00`000000oooo0?ooo`050?ooo`800000<03oool40:O1k0D0Z<7/2@2V^>H50:BV
e`D0YJKG102UYmL40:Z^fPD0ZZcH1@2]bo050;33j0@0YKg[1@2[^><40:j_f0H0[[SQ102b[mH50;O8
i`80]KoQ0`2cdO050:k=l@80W/cg0`0000000`2Nc?L0TlKi09?6n@0309?6n@<0SlOj1@2Lb?H509[6
mPD0]<;T0P2l]]<30;Zmg0@0_kC?00<0`KSB00000031]<d00`31]<d60<2hdPD0^[gL1P2_`>HA0?oo
o`030000003oool0oooo0200oooo000L0?ooo`800000203oool00`000000oooo0?ooo`0[0?ooo`L0
Yl7/1@2V^NH50:JhiP@0Y:KH102TY]L50:FVe`D0ZJoL102Z[]X20:Z/f0<0ZM7d1@2]bo050:71l0@0
YKg[102[^><50:>jj@D0[[SQ1@2]d_<40;O8i`H0/m7`0`2[c_83000000D0X<Sd1@2Ca_T308o7nPD0
Q/;k1@2Ja_H40;C2i0H0^[gL0P2o]<l30<6hdP0300000031]<d0`KC=0080a[K;1030^=820<JjcP<0
^[gL0P30`=X50:o0iQ40oooo00<000000?ooo`3oool0803oool001`0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0X0?ooo`P0Yl7/0P2W^^L50:JiiP80Y[SV0`2TZ=T40:BVf0@0Y:KG
0P2UY]L30:N_g@D0ZJoL0`2Z[]X60:WAm0D0XL?a1@2Q`O030:Fmj`D0VkK[1@2S^^T20:jhh@<0V];k
1@2]d_<40:cFmP<0/m7`0P2aco03000000040:_>lP2^cO00[/g`0:k=l0D0X<Sd1@2H`oD308_1n@D0
Q/;k102Ja_H509k3lPD0^[gL1@31^=800`31]<d000000<Jfb`030<Jfb`80`;SB1036^/h00`2j_M`0
`<3J0<30fP020<30fP80[l3V0`2a`^HA0?ooo`030000003oool0oooo01l0oooo000K0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool50:O0j`D0Yl7/1@2W^^L40:JiiPD0Y:SI
1@2TY]P30:BVe`H0YjoM102Y[m`50:ODm`<0ZM7d0P2RaO450:73l@@0XL7`1@2J/^P409^fj`@0Xk[Y
1P2Jd_/509KDo@@0[=Kf00@0/Lo`00000000000000000P2aco060:k=l0D0YLKa102H`oD408_1n@D0
P;cj1020_OX509k3lP80^[gL0`2]`>L40<6hdP80a[K;00@000000<Jfb`36]//0a[K;1P36^/h50<30
fPH0/L;V4@3oool00`000000oooo0?ooo`0N0?ooo`006`3oool2000000`0oooo00<000000?ooo`3o
ool07`3oool50:Noj`@0Yl3[1@2W_>P50:Nji`@0Y:[K1@2TZ=T40:BVf0@0YZgM1@2W[md50:KFn0D0
YmCg1@2RaO440:73l@D0W;7W1@2J/^P409[5mPD0Tlck1@2;d_l509KDo@80YLof0P0000030;7?l0<0
/M;a0`2^cO030:k?l@D0YLKa102N`_850930m`@0P;cj1020_OX409k3lPH0[L3W0P31^=820;jke`04
0<Jfb`000000a[K;0<Jfb`80bKS:1036^/h20<blb`80`<3J0`35`mP30;72iP<0//?V403oool00`00
0000oooo0?ooo`0N0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0
oooo2P2W_n/50:Rnj@@0YkcX1@2T[Mh40:BZf`@0Y:SI1@2TZM/40:J]g@80YjoM0`2VeoT50:KFn0D0
Y<Ka102RaO4509nej0D0W;7W1@2M__0409[5mPD0U]Cm1@2;d_l308o;o0<000000`2UcoH60;7Bl@H0
[/oa0P2Ua_430:O5k`@0W/;b1@2E`?D408>kn@@0LkKj1021^_T50:g0i`D0_[_G00<0a[K;00000039
^<X00`39^<X20<JjcP<0c;c;1P35`mP50;;3iQ40oooo00<000000?ooo`3oool07@3oool001/0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`80Z<3[1`2W_n/30:Roj`D0Z;kY
102T/>450:B]gP@0Y:[K102QYMP50:BYf`<0YZgM1P2VeoT50:K6l0D0Y<Ka1@2R_>`409nej0D0WK[/
1@2M__040:7In`D0U]Cm102=c?d3000000<0Sl_l102Pc_P30;7Bl@<0[=Kf1@2^co450:O5k`D0Xl?_
1@2E`?D408>kn@@0LkKj1021^_T509Nkl@@0_[_G0P39^<X010000000bKS:0<VhbP39^<X50<blb`03
0=:na`35`mP0aL?H0080aL?H0P3:amL40;;3iQ00oooo0P00000O0?ooo`006`3oool2000000l0oooo
00<000000?ooo`3oool05@3oool50:S0j`@0Yko[1P2X_n/20:Rnj@<0YK?S102T/>440:B]gPD0Wj7F
0`2QYMP50:BYf`H0YmSi1@2Wa^l40:K6l0D0Y<?_1@2R_>`409^dj@D0WK[/0P2M__030:?HnP@0XMWk
1@2KcoX3000000<0S/Gj102:a?/40:3>n0H0[=Kf1@2Wc?<30:O5k`80Z<C]1@2S`nl509W2m0@0R;cg
101`/_T406N^n@@0Uk_a0P2n^mL30;Njg0040<VhbP000000bKS:0<VhbP80bkW90`3<_</30=:na`80
aL?H0`3:amL20;;3iP<0]<GW4@3oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0140oooo102W`>/50:S0j`D0Yl3[102X_n/60:Fch`<0Y;3Q
1@2NW]@409nQeP@0XJGH0P2TZM/60:OHn@<0Z<K_1@2Wa^l40:K9lPD0Y<?_1@2J/NP409^dj@@0WK[/
1P2Sf?X50:?An0<000000P2Pc?H508k5nP@0R/Ck1@2KdO/50:;FnPD0Ylcc1@2Xa>d20:?3k`<0YlG_
1@2I`_@408Rlm`<0L;;i101W[_T409Nkl@D0]k[L0P39^<X00`000000bkW90<^ib@020<^ib@030<bl
b`3B_/L0d[k70080d[k71@3:amL60;C5ia40oooo00<000000?ooo`3oool06`3oool000P0oooo0P00
00040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0<0?ooo`T0Yl3[1@2W_n/50:O0j`@0YKOU1@2U/n<409jNd`@0WYkD1@2OXMH30:6Uf0H0YmSi1P2X
a^l50:S<l`@0Y/Wb1@2M]>P509Zaj0<0VkCY1P2RcOH60:KGn0<000000P2SeOT40:3<mPD0UKS_1@2@
_oH409WBn`D0X]Kj1@2Oa?840:S4k@H0YlG_102I`_@508flmP<0LK;i101BX_H407V_m0D0]k[L00<0
bKS:0<^ib@0000000`3;^LT50=:na`040=O2a@3:amL0b/OG0<[7e`80c/_F0`2daNL30;C6j100oooo
00<000000?ooo`3oool06`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`8000004`3oool00`000000oooo0?ooo`0:0?ooo`L0Yl3[2@2W_n/50:Jji`@0
YKOU0P2U/n<309jPeP@0WYkC102NW]@409nQePH0YmOh102Zanl30:S6k`<0Z<cb1@2Xc?<40:6ij@D0
WKCX102J/NP40:32l@<0X/gf0`2/g_T20:KGn0<0000000<0S^Cl0:?En@2SeOT00`2SeOT40:>lj`D0
UKS_1@2Qb?@409WBn`D0U/Kg1@2Oa?840:W2k0<0YlG_0`2Yb?0409_2l`@0SKcf101a/_T405:RmP@0
NJod102g^]`30<^ib@040000003;^LT0c;W70<bia`<0d[k70`3G`/D00`3:amL0c/_F0<k;eP020<k;
ePD0]<KX4@3oool00`000000oooo0?ooo`0J0?ooo`001`3oool010000000oooo0?ooo`00000;0?oo
o`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`070?ooo`X0Yl3[1@2W_n/4
0:Nmj@D0Y[[W0`2U]nD509jPePD0WYkC0`2NW]@60:OAmPD0[<_`102Zanl60:S<lPD0YKk[102Q^NT4
09fdj0D0W;c_102P`_440:cNn@<000001@2>i?`508oHo`@0Xkc[1@2R]NH40:78m0D0W/cg1@2Fa_L5
09bkkP@0ZL;/1P2Yb?0409_2l`@0T[gd101d/oT3042GlP@0NJod1@2/]^020<^ib@040000003<^LL0
c;W70<bia`80d[k7103G`/D40<k;eP80dLkG0`2da^P20;?6j140oooo00<000000?ooo`3oool06@3o
ool000030?ooo`0000000000008000000P3oool010000000oooo0?ooo`0000090?ooo`800000103o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo3`2W`>/50:Noj`@0YkgY102V
^^L40:2Uf@D0WZ3F102NW]<40:C6l@<0Ym7f0`2^dO850:c;l0D0Z<[a0`2Xc?820:W4k@D0YKk[0`2Q
^NT509Zkk`D0W;c_102XfoT3000000<0W^;m0P2_]ml20=fg/P<0FT^W102?f?l20:>lj`80XjGG1@2R
]NH50:kEm0@0W/cg1@2B^O4409bkkPD0[LG/1@2Yb?0509c1lP@0T[gd101d/oT3042GlP@0F9cb1@2/
]^000`3;^LT0c;W7000000020<bia`030=:na`3G`/D0el;500<0el;500<0gLK20<k;eP3>bmH0103A
c]L50;?6j100oooo00<000000?ooo`3oool06@3oool000L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`030?ooo`8000005P3oool00`000000Yl3[0:O0j`0@0:O0j`H0Yko[102W
_NT40:6[gP@0X:GI102NX=H50:2hj@@0Y<Ka1P2^dO850:S7l0D0Z<[a1@2Ya>d40:Fnj`D0W;_^102J
^nl609o@n@800000102/foP40:ngg`80gKNb101JBjL3085k``D0XjGG0P2R]NH30;KMl`<0[]Gd0P2Z
c?8409g1lPD0T[Wa102O^N/50:g5k0D0Z<[a102L`O8509W1l`@0MKKj0`0/R^d405RLlP@0[;KP0`3<
^LL00`000000c;W70=O2a@040=O2a@80gLK21@3Ac]L20=;Af0@0/lKX403oool2000001X0oooo0008
0?ooo`8000002P3oool3000000<0oooo00<000000?ooo`3oool04P3ooolC0:O0j`T0Yko[1@2S/N84
0:6[gP@0X:GI102LZMl50:2hj@D0/=Se0`2^dO830:S5k`@0Z<O`1@2[anl40:W4k@D0Wkc]1@2L^nh4
09W8m`80Wm3i0`000000102[d_D0[=_h0:cKn02/foP30;O3h`80[kOO103M]k8305Y;Y`@0PG_3102S
YML60;KMl`D0Z/cb102M`O8509:`j`@0WkW[1@2acNh50:S:l@@0W[k_1@2I`O<407FfnP<0;8[]0`0e
Q>X50:6^h@<0c;W700<000000<nia@3G`/D00P3G`/D30=g6`P040>;:`03Ac]L0dLkG0=7>e`<0d]7H
1@2ca^TA0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo0180oooo4@2W
`>/90:Noj`@0YKOV1@2S/N830:6[gPD0VIoH102LZMl20:2hj@<0/=cg1@2`f?D60:S5k`@0ZlS_1@2[
anl40:>ok@D0Wkc]1@2KaOD209W8m`<000001@2[d_D60;O3h`030:ngg`3M]k80gKNb0080gKNb0`1J
BjL4085k``80XjGG102li?<50;3Hm0@0Z/cb1@2J]^/509:`j`80WkW[0P2V_^X50;7=kPD0Y<C`102N
_^l509o7m0@0LkOk0`0CN><303F4jP@0XJkQ0`3<^LL010000000ckW50<nia@3G`/D30=g6`P<0h/[0
1@3BdMP00`3Bd]T0/lKY0;?6j@030;?6jA00oooo00<000000?ooo`3oool05`3oool001T0oooo0P00
000A0?oooa@0Yl3[102W_n/50:Jkj0@0YKOV102S/N8409RKe@D0VIoH0`2LZMl60;3Lm`D0ZLG^0`2X
aNl30:[7k`@0ZlS_1@2Wa>h40:>ok@D0Wl7`0`2KaOD3000000<0XLcf0`2[d_D30;CGlPD0]l?S1@3M
]k8405Y;Y`<0PG_3102li?<30;GTmPD0/=Sd102T_^/509Zfj`@0T[3[1@2V_^X50;7Bl@@0Y<C`1@2T
`Nh509o7m0<0LkOk100CN><00`0DJM`0=HCZ03F4jP040:6^h@050<bia`3?^LD0ckW50000003?^LD0
103Ma/830>;:`0040>O?_P3BdMP0d]7H0=;Af0<0d];I0P2ca^T30;;6jA00oooo00<000000?ooo`3o
ool05P3oool001T0oooo00<000000?ooo`3oool03@3ooolH0:O0j`@0YkkZ1@2V^nP30:FgiPD0VYkG
0`2HVmD509VOf0H0[M[g1@2/anh40:W5kPH0Z/O_102[b>l50:O4kPD0XKc/0`2O`O03000000<0W/[f
102Qc?H60;CGlPD0ZmOg103M]k8405Y;Y`80PG_30`2ah?L60;GTmPD0Yl?^102T_^/509R`j0@0UjoW
0P2V_^X30;;@k`D0/M;a102P_>d50:C1kPD0Xlgf101]]O/201=hh`<056WL102Q[^440<nia@040000
003B^/80gLK20=g6`P<0h/[00`3Wckh00`3BdMP0d];I0=;Bf@020=;Bf@D0//KY4@3oool00`000000
oooo0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`090?oooa/0Yl3[0P2W_n/40:NnjP@0Y[_X
102MYM/409ZNe`@0V9_E0P2IWmP30:O>m0<0[M[g0`2`cNl50:c7kP@0Z/S_0`2Zanl30:_6kP@0ZlS_
1@2R_>`40:6lk0<000000P2Vbo<509k:mPD0YLof1@2?e?h50:_Gm`<0gKNb101JBjL40;7Pm`<0[nWi
1@2[cO450:O3kP@0X;OX1@2H/>P309N_i`H0/]3_1@2Wb_840:2lk@H0Zlkb102Qe?X405nan`030012
`00DJM`056WL008056WL102FYN020<nia@80d[[200<000000=:j`P3Ma/800`3Rb/030>O?_P@0d];I
0P3@dm/20;;6j@<0/<GY403oool00`000000oooo0?ooo`0E0?ooo`006@3oool2000000L0oooo702W
`>/50:Noj`@0YkkZ102P[^4409fUf`@0VYkG0`2HVmD60:O>m0H0/<g_1@2Zb_040:[8k`H0ZlK^1@2W
`nd40::lk0<000000P2Wb?440:K;l`H0XL?a1P2Ze?H308oDoP@0ZmOg102NdoX508g3nP@0[nWi0P2^
e?@50:_=l@D0X[SX102P]nP409R`j0@0X[_[0`2bd>l30;;Qm`@0Yl[b1@2Sb?<30:_>lP<0Y^;k102Q
e?X405nan`030012`000C/`004k<008056WL0`2FYN001P3?^LD0d[[20=:j`P3B^/8000000=:j`P<0
h/[0103Wckh00`3Zdkd0d];I0=;Bf@030=3Cf`H0/<GY403oool00`000000oooo0?ooo`0D0?ooo`00
6@3oool00`000000oooo0?ooo`030?ooob00Yl3[102W_n/50:>fiP@0X:kQ102MYM/309ZNe`H0W[S[
1@2ee_430;3=k`80Z/W`1@2Zb_040:W2k0<0ZlK^0`2]b>h50:O3k@<0000000<0X/;`0:O8l@2Wb?40
0`2Wb?440:Rnj@<0XL?a0`2^and30:[DmP<0/[_P0`2E[^P405JDkP@0W]?j1P2Jgod50:kDm0D0XkWX
102R^>P40:2gj0D0UjgV102R^n/60;;Qm`@0Ul_j1@2Sb?<50:KRn`H0Qn7l0`0bWo801000@/0004k<
001>c000C/`309JUh0D0d[[200@000000=Rm_P3Rb/00h/[00`3Wckh20>[C_@@0d=?K0P3>d]d50;35
jA40oooo00<000000?ooo`3oool04`3oool001P0oooo00<000000?ooo`3oool00`3ooolR0:O0j`D0
Y[_Y102S]^H30:2^h@D0Ti_H0`2GY=l309jhj`<0]M_c1@2ee_450:[9l0T0ZL;/1P2]b>h01@2W`nd0
0000000000000000X/3_00@0X/;`1@2[`^/40:Rnj@H0[/O]1P2b^n0309F^j0@0EYC^1@2?c_d60:WD
m`@0Z<3[1@2S^NP30::hj0D0W;CY1@2G[NH50:OZnPD0P^3k102GboX608WVn0D0Mn3c1@0g_=D01000
GK/0<Yob03:OlP00@/03001>c0<0T9gL103B^/800`3H_Kh000000=Rm_P030>O?_P<0j]>m00<0k=Jm
0=3Cf`3@dm/0103>d]d50:o4j@l0oooo0P00000E0?ooo`00603oool010000000oooo0000003ooolQ
0:O0j`@0YkkZ1@2V^nT30:>fiP@0UIcH102CVmP409NTg`H0]M_c1@2/bNl30:[9l080ZlG]1@2Y`^`5
0:g9kP<0[LS^0P0000050:;0k`80X/;`0P2Wa>h50:_2j`@0/<CY0`2^and30;Rog`D0/[_P102L]>T5
08Fcl`@0Y=?h0`2Ye?L30:W7k`@0Z<3[102S^NP40:74l@D0W;CY1@27hO`604k<a`<0P^3k1P1Od?@0
0`1NdO40S/cm08k<o@0408k<o@<0VMWm0`2fc>/304FIl`03001M^`007jH004;0008004k<0`2@WM`3
0=:j`P80f;fn00@000000=Rm_P3P`[X0ilnn0`3Zdkd30>cF_@@0c];M0P3;dMh40:o4jA40oooo00<0
00000?ooo`3oool01P3oool2000000X0oooo000H0?ooo`030000002W`>/0Yl3[01h0Yl3[1@2W_n/4
0:NnjPD0WjoS0`2IY=d309FLf0D0Ti_H0P2GY=l30:oCl`<0]M_c0P2`cNl50:c9k`D0ZlG]1@2Yanl4
0:g9kP<000000P2X`^`50:;0k`D0YlC^0P2[`^/30:O4kP@0/<CY1P2h_ml20;:kh0<0/L3U102L]>T5
0:3<mP@0Y=?h1P2Yanl30:S0j`D0W=;j102Qa?4606[Cn@0304;4b02R^n/0X[_[00<0X[_[1@24/_<5
09[4m@@0Y[cY0`2>c?d30;K9j@H0]/c[0`15VO<01000GK/001nV000h_P00C/`4092Mg0030=:j`P3H
_Kh0f;fn0080f;fn00<000000>32^P3Zdkd00`3Zdkd30>cF_@030>cG_`3>d]d0c];M00@0bm7N102_
a>XA0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000002@3oool00140oooo0P00
00050?ooo`030000003oool0Yl3[01l0Yl3[1@2W_n/40:>hi`@0WjoS102IY=d309FLf0@0Ti_H1P2_
do<50;3=k`D0[<S^0`2[aNd30:S4kP@0ZLO_0`0000020:c3jP@0Z<;/1@2T`nl:0:O4kP80/<CY0P2d
`nH50;Rog`H0/L3U102Ua_450:3<mP@0Y/Sb1@2Yanl509;KoP@0W=;j1@1Xco/206oCo0@0//GX1@2R
^n/50::^h080V/Ce0`2d_=l40:Jlj@@0]/WY0P37bmd30;K<j`<0]KSK0P1SP]/0100008400028000O
YP00>;h4092Mg0@0f;fn0P3P`[X010000000ilRf0>[C_@3Zdkd30>cF_@80k=No1@3;dMh20<S@h0@0
[lCZ403oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo000@0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0802W`>/30:Noj`80Y[gZ102S^>L409n_
h`<0VJCM0`2EW=P60:6lk0H0]mC_1@2]bnl40:c8kPH0Z<C^0`0000000`2[`^/0[<?Z0:c3jP030:c3
jP@0ZLC]1@2T`nl40:?5l@D0YlC^1@2d`nH50;S;j@<0/L3U0`2]a^`40:G6l@D0Z<_b102Vb?8608cO
o@D0S/7h1@2O]nT20931m`<0]<OX102baNP50:BTe0@0XZkP1P2d_=l20:Jlj@80^l3N0P2fbNT40<O;
g@D0]KSK0`1SP]/0100008400028000[]000>;h4096Ie`<0f;fn0`3P`[X00`000000ilRf0>cF_@02
0>cF_@<0k=No00@0jmS10<_AgP3;dMh0bm7N0`38d>050:k4jQ00oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000090?ooo`00403oool010000000oooo0?ooo`0000040?ooo`800000
0P3ooolP0:O0j`D0Y[gZ102S^>L309n_h`@0Si[J102DY>030:6lk0<0^=S`0`2ge>l20:o<k`D0[L__
102Y`nd20:S4kP<0000000<0Z/C/0:_2j`2[`^/00P2[`^/50:c6k@@0ZLC]1@2T`^l40:?5l@D0Y<?_
0`2d`nH20:k?l@D0^<_Y1@2]a^`50:g?lPD0Z<_b00<0S>?l0:6`hP2Q/>800`2Q/>8409Zej`D0Z;KS
102O]nT60;C7j080//GX0P2YYM850:BTe080XZkP0P2k`^050;Blg`D0^l3N1037bmd20<[<f`@0]KSK
0`1SP]/010000iH000210000R000:k@5096Ie`090=Rm_P3P`[X0h<:j0>32^P3Wb;H000000>O8]P3^
c[80k=Jm00<0k=No0`3[f<440<S@h080a]3R102^a>XA0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000002@3oool00100oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?oooa/0Yl3[1@2W_n/40:JmjPD0VJSQ0`2BWM/408nJfP@0U:CP1P2hf?050:o<k`D0ZlC/
0P2Y`nd3000000D0Z/C/0P2[`^/20:_6kPD0[<K]102Z`>X50:C2k`@0Wl7`1@2T`nl50:k?l@D0[/K/
0`2]a^`20:oBlPD0[Lob0P2Bi?`40:N`g`D0XK3R0P2J]N/20:^hhPD0Z;KS0P2O]nT20;32i`D0]<OX
102YYM850:BTe0D0^l;P1@2h_=`20;_0gP<0aLWN0P37bmd40<[<f`80]KSK0P2TW/l01@1`O<l0Hh;K
06>2f`000iH00028008002^d102AVML40>32^P80ilRf00<000000>k>/P3/ekl00`3/ekl30>_H`@03
0>WIa038d>00b=3P00@0a]3R0P2^a>X20:g3jQ00oooo0P0000040?ooo`8000002P3oool00100oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?oooaH0Yl3[2@2W_n/40:2diP@0
VJSQ102BWM/308nJfPH0[lc_1@2dd>h30:o<k`80[/S]0`2[a>`3000000<0ZlG]1@2Za>`50:_6kPD0
Z[oY102Z`>X50:S2k0@0Wl7`1P2MaoD40:O1k0D0[/K/1@2_d_8409WVo0<0ZK?P102W/=l40:6`hPD0
ZkSR102X]^<50;32i`D0[jkF102YYM820:BTe0<0]lCT0P2k`^030;FkgP@0^;cL1P35bMh50<[<f`@0
Y9k?0`1`O<l20003UP030000R000:k@0Vi_C00@0Vi_C0P3P`[X30>O8]P030>k>/P000000l]:_0080
k=No0`3[f<420>WIa0H0a]3R1@2]`nX>0?ooo`<00000403oool00140oooo0P0000040?ooo`800000
1`3ooolF0:O0j`D0Yko[102T^nT40:2diP@0VJSQ0`2BWM/509bbi`<0[lc_0P2je^h50;C@kP@0[/S]
0`0000030:[6kP@0ZlG]1@2Xa>d30:_6kP<0Z/;[102Z_nT50:k4jP@0Z<;/1P2O_nl40:Bjj@@0Yl7/
1P2]d_<509_YnPH0ZK?P0`2W/=l50:^ih`@0ZkSR1@2/_>D30;32i`80/[OM1@2_[]H30:VUdPD0]lCT
1P2e^mh20;Rlg080_/SR0`35bMh30<SBhP80b/cK0`2k^]P40:BNc`<0L7c?00@000>F0000R0009k40
02^d1@2KVm<00`3P`[X0ilRf0>O8]P030>k>/P030000003bdZl0jmS10080jmS10`3YfL@0103XflL0
a]3R0<K@hP36d>830<??h`80[L?Z0`2/`n/?0?ooo`030000003oool0oooo00h0oooo000G0?ooo`03
0000003oool0oooo00L0oooo5P2W`>/50:Jnj`@0Y;_Y102P]>H309VXh@@0SYgM1@2L/^L50;[FkPD0
/Lc^0`0000030:[5k@@0Z/K^1@2X`^`40:S4k@H0Z/;[102[aNd50:k4jP@0Z[kX0`2O_nl30:VkiP@0
Y;[Y0P2W`N`20:[>l`<0[M;c102Fk?L40:Zgh`D0ZK?P102Y^N@50:^ih`@0Zk[T1@2/_>D50;:gg@@0
[jkF102^_>@30;O4i080]<3S1@2e^mh50;k8hPD0b=;R1@2k^]P40:BNc`@0L7c?00@000>F000W/@00
9k4002^d102KVm<30>O8]P80k/jb00D0l]:_0000003bdZl0mMJ^0>_H`@030>WIa0<0j=_71@33cn<5
0:c3ja00oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?ooo`3oool0203ooolB0:O0
j`D0Yko[102V_^/409baiP@0TZ?P0`2;VM/408jMg@80W;;W0`2gdNd30;[FkP<0]M3^0`0000000`2a
c>h0Z/G]0:[5k@040:[5k@@0ZL?/1@2X`^`40:[3k0<0Z/;[0`2XaNh40:_5k@D0[KoW102Z_^P60:Vk
iP<0Y;[Y1@2Zc_<209K/m`D0Z;[V102Z]n<50:Nhi@@0ZKWT0P2[^N<30:Zii0@0Zk[T1@2`_N<40;:g
g@D0Z;CQ102^_>@50;C0h`80]K_N0`2ga^H20;k8hP<0_loW0`38d^820<?>h`@0^k[H102TW/l4071l
c`04000MZP009k4002Na000W/@D0ZjGA00@0ilRf0>k>/P3^c[80k/jb0P3bdZl00`000000mMJ^0>WI
a0030>WIa0<0j=_700<0iMg<0<??h`33cn<00`30cnD30:c3j`80Zl?[403oool00`000000oooo0?oo
o`0<0?ooo`005`3oool2000000T0oooo502W`>/40:Noj`@0Xk[Y0`2L/NH509:Sh0<0RiWK0`2>WMd6
0;OAk@<0]M3^0P0000000`2ed>h0[LO]0:g7k@030:g7k@D0ZlG]102Y`n`50:[5k@@0Z/?/1P2XaNh4
0:VojPD0[KoW102``^L50:VkiPD0Z/[a0P2;jo040:Nmj@D0Z;[V0P2Z]n<20:Ffi@D0YkSU0`2Y^N@6
0:Zii080Zk[T0P2]_ND40;2mh`D0Yk3N102X]>450;C7j0@0]<3S1@2ga^H60;o?i`D0`lkS102RW<l4
09^Dc0@0OhWC00@001fZ000Z/`009k4002Na102[YM40103Wb;H0k/jb0>k>/P3^c[820?;B[`030?GF
[P000000m]Z_0080jMW40`3XflL20>GMc0H0`<oU1@2[`n/?0?ooo`030000003oool0oooo00`0oooo
000G0?ooo`030000003oool0oooo00X0oooo4`2W`>/40:Jnj`@0Xk[Y0`2L/NH409:Sh0<0RiWK1@2U
^^T30;OAk@040;_Dk00000000000000000@0//c]0`2]and20:_6k@D0ZlG]102Ya>h50:[5k@@0Z<?]
0`2XaNh30:S0j`@0ZKoZ1@2]and40;32i`D0[<W_0`2Zb_4207kWiP80Z<7/102W_NT40:RjiPD0YKKU
102W^>D40:Vhi0D0Z[WT1@2]_ND20;2mh`80ZK7N1@2W/=h20:Rdh@80/L_]1@2danP40;32i`<0]lKV
0P2gbnT30;o?i`<0`=KZ0P33c^<30:f`fP<0XYc?1@2KU<`407n9d`03000MZP00:[<002Na00@0ZjGA
0`3^c[830?;B[`80mMJ^00<000000?KJ[`3XflL00P3XflL30>GMc0040>;Od@30cnD0`<oU0<3?i@<0
_LkW102[`n/@0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0oooo00`0oooo
402W`>/30:Noj`@0Y[k[0`2S^^T309baiPD0QYSM0`2?XN050:Fjj@<0000000@0^mC/0;SAk02hdN`0
^=7/102bc>d50:_6k@D0ZLC]102Ya>h50:S2k0@0Z<?]1P2X`>/20:VojP80YlK`1@2]and40:[7k`D0
[<W_0P1ninH50:S1k0<0YkgY1@2T/n<40:Ffi@D0Z;OT102Y^>@50:^liP@0[KgU1@2Y/Mh40:N`gPD0
/L_]1@2/_^L40;32i`D0]l_Y1@30e^X50:f`fP@0XYc?102KU<`407n9d`04000j_`00:[<002Zc000W
/@80ZjGA0P2o]M020>k>/P<0l]:_00@0mMJ^0?KJ[`000000m]Z_0P3fg[430>GMc0<0h]oA1@2mc^L5
0:[2ja00oooo00<000000?ooo`3oool02P3oool001H0oooo0P00000>0?ooo`d0Yl3[1P2W_n/30:Jn
j`@0VK3W0`2<XN8408JHg@@0Sj7P00@0^]3[00000000000000000P2jd>/60;SAk0@0[/S]0`2[a^d3
0:[5k@@0ZLC]1@2Y`^`40:S2k0@0Z/?/1@2X`>/50:O6l0D0YL7]102Zanl207GSgPD0Z/O_102X`N`4
0:>ahPD0Y;?S102W]><50:Rgi0@0ZK[U102[_>H50:^dh0@0ZK7N1@2]bNl30;7;k@80[;gV102/_^L5
0;?9j`<0]l_Y0`2ie>h40;S7iPD0[K3J0`2RW<l50::SeP@0SIkO00<03eC?000Z/`00:[<01@2o]M03
0?;B[`80mMJ^0P3ffZl01@000000m]ja0?KN/@3fh[D0iMg<00<0h]oA0P3Mh=L20;g>i`<0^LcY102Z
`^/?0?ooo`800000303oool001H0oooo00<000000?ooo`3oool03P3oool>0:O0j`@0Yko[102R^^X4
09V`i`<0S:7R1026V=d01@2?XN000000000000000000ZKcW00<0^]3[0P2ne>X30;SAk0<0/lg]102^
b>d60:[5k@@0ZLC]1@2Y`^`40:[4k@@0Z/?/1P2Va>h40:JmjPD0YL7]0P1fhn<40:kBl`D0Z/O_102S
[ml40:>ahPD0Y[?Q102W]><50:Vii@@0ZK[U102[^>850:^dh0@0ZLG^1@2]bNl50:bmiP80[;kW0P2`
b>`50;?9j`<0^MC^0`2jdnd40;S7iP@0[K3J102KVM450::SeP<0SIkO0P0?E<l2000Z/`<0_kG@0P3C
b=020?;B[`060?GF[P3ffZl0m]Z_0?KJ[`3fg[4000000P3fh[D30>;Od@<0gN3G1P2ic>T40:W2ja00
oooo00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0403oool=0:O0j`@0Y[k[
102R^^X409V`i`<0S:7R00@0QYSM00000000000000001@2Y_>L50;kDjPH0/lg]102/and30:[5k@<0
ZLG^102Ya>d50:S4kP@0Z/C]102X`^`30:K4kP<0ZKoY102V_NX408OXlP<0/N7g102^d_<50:B]gP@0
XjoO102V/^450:Jch@80YkCS1P2Y^ND50:^ji@@0ZkSR0P2[]>030:S1k0@0ZLG^1@2/_nP40:bmiPD0
/<S/1@2ccnh50;[Ck@@0^<OV1@2IU/l309^Id@D0XZ?F0`2=W]l200mDc`04000]]P00:[<0_kG@0;ne
d0@0dlS@0P3eeZh30?KJ[`050?KN/@000000m^:e0?KR]@3di[/0103Mh=L20=OPgP<0^LcY0`2db^/4
0:W2ja00oooo00<000000?ooo`3oool0203oool001H0oooo0P00000B0?ooo`P0Yl3[1@2W_n/40:Jn
j`@0Uk7Y1028XN@3000000<0SZ7Q0`2Y_>L40;c>j0D0_=7[1@2`b^d40:c7k@H0ZLG^102W`nd50:S4
kP@0Z<7/102X`^`60:Voj@80Y[gZ0`2Ji_`60;7Qm`@0Y:kN102T[Mh50:Jah0@0Y[;Q102V/n470:Vi
i@80Z[cV1@2[^^D30:^hhPH0Z<7/102/`nX40:boj0D0[LO]0`2`b>`20:o:k@<0/lo^0P2geo030;[C
k@80[;GO102PX=@409VFc`@0ViWA0P2RXmH30:Zdh0<0TJOT00<096CG00mDc`00;KH01@3Cb=020>7J
c`<0m]Z_0P3fg[401@3fh[D000000?CV^`3di[/0lNW10080gN3G103Gh=h50;C:j`D0ZL7[3`3oool0
0`000000oooo0?ooo`080?ooo`005P3oool00`000000oooo0?ooo`0B0?ooo`T0Yl3[102W_n/40::k
j`@0Uk7Y0`0000001028XN@0PIKN086FgP21U]h308jQh@D0_<kX0P32d^L30;cAj`<0^<k[102`b^d5
0:[6k@<0ZLG^0P2Xa>d40:O3k@D0Z<;/102X`N`50:_3k0@0ZKoY0P2Ji_`50:k_m`D0YK3P102T[]h4
0:Fah0D0Y[7P0`2V/^450:Vji@@0ZKWU1@2Z_>H40:^ji@@0Z;oZ0`2X`N`30:c5k0@0[<?Z102Za>`5
0:g7k@D0[l[]1@2geo040:beg`D0X:3D0`2IU/l409^Id@D0Z[CP102AYn@202ATe`04000]]P3Cb=00
dlS@0=?8d0<0hM[?00<0inK?0?KJ[`3ffZl00P3fg[420?KR]@040000003ajL40lNW10?7Y`@<0en3N
0`3?g^@50;38j`@0ZL7[3`3oool2000000T0oooo00030?ooo`800000103oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo01@0oooo2@2W`>/40:Joj`@0X[_[0`000000102G/NT0R:7T08RQ
i028XN@3086FgP@0YkSU0`2lc^P40<;Bi`H0^<k[102^b>d50:[6k@T0Z<C]1@2X`^`40:S5kPD0Zl?/
102Sf_/30:;cl@@0Z;OT1@2U/>040:B`h@@0YK7P102V/N040:RjiPD0ZK[U102Y_>L40:ZliPD0Z;kY
102X_nX50:c5k0D0ZL7[102Za>`50:k7k@D0/mGb1@2cb>X40:beg`@0X:3D0`2IU/l50:N_gP@0Z[CP
102AYn@302ATe`03000]]P3Cb=00hM[?0080hM[?0`3Wi/l20?KN/@80m^:e0P3di[/010000000lNW1
0?7Y`@3]k<T40<oNi080a][X102`b>/50:S1j`/0oooo0`0000000`3oool000000?ooo`080?ooo`00
0P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool05@3oool90:O0j`@0Y[o[00@0V;G[000000000000V;G[1026Y>L307^Eh@<0RIgQ102W^>D5
0<;Bi`80`M;W0`2hc^/30;C<k0@0[/S]1P2ZaNh40:S4kP@0Z<C]1@2Wa>h40:S5kPH0YLcd0P2Rlo44
0:k6k0@0Z;OT1@2R[n440:B`h@<0YK7P1@2W^nL40:RjiPD0Z;gX102Y_>L90:Rnj@@0Z/G]0`2/aN`2
0:VojPD0ZL7[102]and30:k7k@80[m7b0`2ceO820;CCl0D0/lSZ0`2/]Ml509JFd@<0W:;I1@2W[mh4
0:Rgi0@0SJKV00<0<VgK02ATe`00:JD0103Qf/l20>OVc`80incA0`3fh[D0103di[/0lNW10000003a
jL420>g/b@030>O]d@3?g^@0cmkT00@0a][X102]aN`50:S1j`H0oooo100000040?ooo`030000003o
ool0oooo00L0oooo00020?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool0oooo
0P00000G0?ooo`T0Yl3[00D0Xkg/00000000000000000:>mk00309Rej`@0QZCW0`1kUN4308VMh@H0
^lST1@31d^L60;C<k0@0[<O^0`2ZaNh30:S5kP@0Z<C^102V`nh50:O4kP@0Y/C_0`2Uc?@209cal@<0
]=cd102^a^`40:2^hPD0XZoQ0`2T/>440:Jjj0D0Yk_W102W_NT40:Rmj0D0Z;kZ102X_^T50:W5kP@0
Z/G]1@2Y_nX50:_7kP@0[LO]1@2_dO850;CCl0D0WikB0`2HU<l409JFd@@0W:;I1@2[^^@40:Rgi0<0
SJKV0`0bKM/00`004Yl0hM[?0>7Jc`020>OVc`<0incA0P3Vkm<20?CV^`80lNW100<000000>g/b@3W
kM400P3WkM430<KJj0<0_MC[102]aN`50:S0j`80oooo0`0000080?ooo`030000003oool0oooo00L0
oooo00020?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0oooo01P0
oooo102W`>/0102V_n/000000000000000050:>mk0<0V;G[0`26Y>L307^Eh@@0X:oS0`2kb>@30<C?
hP<0`M;W102ndNP40;7;k@@0[<O^1P2XaNh40:O4kP@0Y/?^1@2Wa>h40:K4k`80W?7a1P2dg?@409n^
hP@0X:kR102R[n440:Bij0@0Y[[X1@2V_>T40:Nmj@@0YkoZ1@2X_^X40:S4kP@0ZLG^202Y_nX20:[7
k`@0ZlO^1P2/cO450;7Fl`@0ZJkL102OW]8409RDc`<0UYKA0P2LX]T30:Rii@@0Zk[T102X]n@308fV
iP@0<VgK00<001:O0>OVc`3Wi/l00`3Wk=420>K_d`80i?3F0P3ajL420>g/b@030000003WkM40ingA
0080h>gJ1@2me>/50:[3k0@0Z<3[0P00000<0?ooo`030000003oool0oooo00H0oooo00020?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?oo
o`040:O0j`0000000000000000@0Y[o[1@2L^Nd308RZj`<0MIKU0`1nUn440:2_h`H0a<oR102ndNP3
0;c?j@@0/L_]102Zanh30:S5kP<0Z<G_102Wa>h50:O5kP@0YlC^0P2Oj_X50;C_mPD0X;7T102O[^83
0:2^hPD0X[OW102T^NP90:Jlj@@0Yko[102W_nX50:O4kP@0Z<C^2@2Y_nX50:[7k`@0ZlW`0`2/cO43
0:oEm080/MKc0`2_`>H30:V^g0@0WikB102HU<l309JFd@H0Z;WU0`2[^^@50:Bfi@<0Qj?W0`0lM=h0
0`00=;/004c30>O/d@020>O/d@80i^oC0P3Tl=H40>C_eP80ingA00<000000>3]fP3PkMX00P3FjN<3
0;gDj`80]<k]102Z`n`50:O0j`d0oooo00<000000?ooo`3oool01P3oool000<0oooo0P00000:0?oo
o`<000000`3oool2000001P0oooo0`0000040:O0j`D0Y;k/102L^Nd308RZj`<0MIKU0`1nUn420:2_
h`<0]KkQ0`34cn830<O@h@H0_<oY102^b^h40:[7kPH0Z<G_102Va>l50:O5kP@0Xm_k0`2[m?<40:Jn
jPD0X;7T0`2O[^840:2diPD0X[OW102U_>T40:Jlj@D0Y[o[102W_n/40:O3kPD0YlC^102X_nX40:Vo
jPD0ZLO_1@2Zanl40:_9l0D0[mGd1@2_`>H40:V^g0<0WikB1@2LYM`30:>bh`D0Z;WU102Y^^H40:Bf
i@@0Qj?W0`0lM=h00`07E=001W7N001<``020>K_d`80i?3F1@3TkmH0103Tl=H0h>gJ0000003PkMX4
0=KYh`D0]<k]102Y`N`40:O0j`d0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?oo
o`3oool05@3oool3000000@0oooo102W_n/50:Bnk0<0W;W]0`28Z^/307FFi@<0OYOQ1P2e_^440<O@
h@80b=3Q0`2lcnT30;W?j`@0[/[^1P2Xa^l40:K5k`@0Y/C_1P2UcOD20:_dl`@0/MGc102V_^X40:2a
i0@0W[7U102P]>H50:BljP@0YKcY102V_n`40:Joj`D0Y/;]102W`nh50:S0j`@0Z;oZ102Xa^l30:W7
k`80ZLK^1@2Zanl50:gCm0@0/<g_102_`>H40:V^g0@0UiWC1@2LYM`30:>bh`D0ZK_W102Y^^H409jc
i`@0PJ3W00@0AG[P03adgP0lM=h01eC@0P06LMh20>C`ePD0i>oF0P3Tl=H20>?ae`030000003FjN<0
e^WS00<0bn?Y0P2dc^d30:k8k@@0ZL7/102W`>/<0?ooo`030000003oool0oooo00H0oooo000D0?oo
o`030000003oool0oooo0180oooo0`0000080?ooo`@0Yko[1@2Q_>d3092bkP<0LicZ0`1]T><3092S
h@<0]KkQ0`33a]d20<O@h@@0b=3Q1P2icn/50:c9k`D0YlK`102VaNl40:K7l@<0YLge0P2Wk_P30;O]
mP@0/MGc102J[N@409b^i0@0W[7U102S^nX40:BljPD0YKo/102V_n`40:K1k@D0Y/;]102W`>/40:S0
j`T0Z<K_1@2Ya^h50:_Bm0D0[]?c102`cNl409bFc@@0V9?>102GVM<409bUg0@0Z;_W102Y^nL50:Ji
iP@0W[?W1021X>L204Ejh0801eC@100oUO830>C_eP80i?3F0P3SlML20>7bf@030000003;hnT0bn?Y
0080bn?Y1@2^b>d50:S1j`@0Yl3[2`3oool00`000000oooo0?ooo`060?ooo`00503oool200000100
oooo0`00000<0?ooo`D0Y[o[102Q_>d3092bkP<0LicZ0`1]T><3092Sh@H0`lKM1038d>440<O@h@@0
]/k/0`2/bNl20:W9l@D0YlK`102Ua_040:K7l@80Ynkh1P2gkOH409^bi`@0VZgT102L[^@40:6ijP@0
Xk_Z102T_^`50:Fok0@0YL7]102V`Nd50:O0k0@0Yl3[102WaNl50:S6k`D0ZLG^102Yd?@30:_Bm080
ZmCf102^do<50::Nd@<0W9K=1@2HTlh309NId`D0Z;cX202X^nL40:JiiP@0W[?W1021X>L304Ejh003
035bg`07E=00LK;i00@0LK;i0P3Tl=H20>?ae`<0hO;I00@0fo;O0000003;hnT0bn?Y0P2nfNd50:_4
k0@0Z<7[1@2W`>/:0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo00`0
oooo0`00000A0?ooo`@0Y[o[102J^^h307fYk`80GhoX0`1]T><50:F`g`<0`lKM0`3:bMT70<O@h@@0
]/k/1@2YbO450:G7l@@0YLK`102Vgo/40;;cl`@0Y<;^102K/^L309Z]i0D0W[KY102Q^NX40:>mk0@0
Y;k/1@2U`>d40:G1k@@0Y/7/1@2W`>`80:O5k`D0Z<C^1@2Xco@40:W@m0D0ZmCf102WZ=L40::Nd@@0
W9K=102HTlh40:Jjj0T0Z;cX102X^nL40:>hi`@0VK3W101kW>L30521hP80<G;O1@2GaoP20>?ae`<0
hO;I0P3Kl]l010000000_]W]0;kIk@2nfNd20;C?kP@0ZlC/2@2W`>/:0?ooo`030000003oool0oooo
00H0oooo000D0?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`@0YKk/102J^^h307fYk`80
GhoX0`1cTn<50:F`g`@0b/WI0P3>bMD70<O@h@D0//k^1@2Vb_840:G7l@D0YM7g0P2blo<60;7NmP<0
Y<;^102F[^L309Zaj0D0W[KY102R_>`40:>mk0@0Y;o]1@2U`>d40:K1k@@0Y/7/1@2VaNl40:O5k`L0
Z<C^0P2Wc_@40:S?m0H0ZMCf102Z/mh40:NXe`@0XYkA0`2LU/d50:6bi0@0Y[[X102W_>P40:Rlj0D0
Y[[X102S^>L409V`i`<0NicW101@PN80101HS^T0<G;O09O7n02GaoP30;?GlP<0hO;I0P3Kl]l20=;^
iP030000002dcnh0]<o^00<0]<o^102X`N`90:O0j`X0oooo00<000000?ooo`3oool01@3oool001@0
oooo00<000000?ooo`3oool01`3oool3000001P0oooo102U_^`309ZjkP<0OJW_0`1OSnP307>Ch`80
YK3O0`2f^=X20<[9f@@0c/WE1@37d>420<K@hP<0//k^0P2_co450:K:lPD0Xl_d102[kOP30;Cbm0D0
V;W_0`2D[^P409J^i`<0V[7X1@2P^n`40::lk0P0Y;o]1@2U`Nd40:K1k@@0YLC_102VaNl50:O4kP@0
Z<C^1@2Wc_@50:SDm`D0ZkcU102Z/mh30:NXe`@0XYkA102LY]`40:6bi0D0Yk_X102W_>P40:Nkj0@0
Y[[X102S^>L509>/j080MiWV101@PN8205R>j@@0/mOb0`36hn`0103Kl]l0d^kV0=;^iP3Bk^H20<KT
k@030000002dcnh0]<o^00<0[LO]102X`N`80:O0j`X0oooo00<000000?ooo`3oool01@3oool001<0
oooo0`0000050?ooo`<00000703oool40:>nk0<0T;K`0`1UW>l204j5i@<0Li?S1P2f^=X40<k9e@@0
dLWB1@36d>850:o?l@H0X/_f1@2Tg_/20;Cbm0@0XmKi1@2H^Nl309B^j0<0UZkW102M^N`40:2kk0D0
Xkk]102T_nd40:C2kP@0YL7]2@2Ua>l40:K4k`D0YlC^1@2VcO@50:OCm`@0Zl;[102[_>D40:ZcgP@0
ViK>102JVm@409bVg0@0Z;cX102W^nP50:Nmj@@0Yk_X102T^NP40:2fj0@0TjcX0`1gVNH305j:i0@0
F8kY0`36hn`20=;/i`80e_;T1@36i>d00`000000[LO]0:g7k@020:g7k@D0Z<3[202W`>/90?ooo`03
0000003oool0oooo00D0oooo000C0?ooo`030000003oool0oooo0080oooo0`00000P0?ooo`@0Xkk/
0`2@]_0306FLk`80CXGU0`22Vn840;JhfP80`[cD0P3>bMD40=79dP80dlO>1P36d>850:_@l`H0W=Ck
102Xl_@30:?_mP<0XmKi102H^Nl409:`j`<0V;C[102M^N`40:6nkPD0Xkk]102S`^l40:C2kP@0Y<?_
1@2Ua>l80:K4k`D0YLgd1@2Ud_L50:W6kP@0Zl;[102OULX409fDb`<0ViK>102JVm@50:W0jP@0Z;cX
102X_^X40:Nmj@D0Y[_X102T^NP40:2fj0<0TjcX101gVNH305j:i0@0O:S_0`3Bk>L20=Kbi0<0d_?V
0`2ienl00`000000^MO_0:W2k0030:W2k0@0Z<3[2@2W`>/80?ooo`030000003oool0oooo00D0oooo
000C0?ooo`030000003oool0000000800000903oool40:2mk@<0P[3b0P16Rn`304j5i@<0PY_R0P2f
^=X40<:le0@0dLWB103Calh40<K@hP<0aloP1@2WdoL309cDn`<0VNSk0P2SkoH408;Ao`<0Q;Of102:
[^d409:`j`<0V;C[102N_Nh40:6nkPD0X/;_102S`^l80:C3k`D0YLG`102Va>l50:G=m@@0Y=;h0`2U
d_L20:S8l0D0ZLK^102QUlX309nEbP@0WIC;102KU/h209ZKe080Z<7/102Y`>X50:NmjP@0Z;kZ2@2V
^nP30:Bij0D0W;?X0`2=Z>L407JGi@<0L9OW1@2L`?420=Kbi0<0d_?V0P39k>d20;WGk`030:o:kP00
0000[l[^00@0ZL;/3@2W`>/70?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000009`3oool4
0:2mk@<0P[3b0P16Rn`204=ni0<0PY_R1@32_=@20<Vlc@80dLWB103Calh30=G4b@@0aloP0P38bm`5
0:OCm`80VNSk0P2Fl>d509?Yn0<0P]7o0`24]oH308Z^k@@0T[3[102J_>l409jmkP@0X<7`1@2R`^l4
0:?3l0@0Y<?_102Ta_440:G5l0H0Xlgf102Rd_P40:CBn0D0Z<S`1@2RV<X30:6GbP@0WiG:0`2MU</4
09^FcPD0Z<7/102V^nP40:NmjPd0Y[_X102R^>P409bcj0@0SJSW0`1fUnD4072Gi`80W<3a0`2hf?03
0=;ciP<0bNc]102_b^h00`000000Z<7[0:S1j`030:S1j``0Yl3[1`3oool00`000000oooo0?ooo`05
0?ooo`00503oool00`000000oooo0?ooo`0W0?ooo`D0WKc^00@0LJWd04J;k016Rn`0AX_/0P13O^@4
09>Sh080`[cD1039_<d40=?7cP@0eLC900<0e[o40<O?h037cn001038bm`40:SLnP<0^NWe0P3>hnL2
0<k6d`@0S/?i0P1NZ_P306f[mP<0Q;?c1@2C^?4309Zlk`@0W/7a102P`O050:74l@@0Xl?`102Sb?<4
0:C6l@D0X/gf1@2Qd_T40:;Bn0D0YlOa102SVL/40::HbP@0XIO:0`2OULX309fDb`H0YKo/102V^NL4
0:Jkj0@0YkcX1@2V^nP40:Jkj@@0Y;[X102R^>P409N_i`@0R:?V0P1jVND4072Gi`@0^=S`0P39jnd4
0<W/k@<0_=c`0P2Z`n`00`000000Z/?/0:S1j`030:S1j`d0Yl3[1`3oool00`000000oooo0?ooo`04
0?ooo`002`3oool5000000D0oooo0P00000Y0?ooo`@0WKc^0P1aZO@0100QM^<0@gkT04=ni013O^@4
09>Sh0@0bKc=0P3?^lL20=?7cP@0eLC90`3F_l@40<S;g0<0c<KD0`2ijOD30<kSi`@0c/KC102DW]/2
06VHj`<0KJ_f0`24/o<50931m`<0VL7d102N`O4409o5l`@0XLCa1@2QbOD40:?8l`D0X<kg1@2Od_X3
0:7Bn@D0YLG`1@2TVL/30:>Ib`@0XYS:102QUlX40::bi0@0XkWX1@2W^^L40:Jii`80Y[_X0P2X_nX4
0:Nlj080Y[_X0`2W_NX40:Jkj@<0Y;[X1@2P]^P409N_i`<0R:?V0`1jVND508NYj`<0bN_]0`3>m>T3
0;cLl0<0/<g_0P2Z`n`00`000000Z/?/0:O0j`0@0:O0j`H0oooo00<000000?ooo`3oool0103oool0
00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`@0V[__0P1MXO@00`0Q
M^<0>GWR03UihP050::Yg080bKc=103?^lL40=G4b@@0e[o400<0ekZm0<S;g038bm`00`3<a]@40=?1
b080f[bl103>a]<20<Nba@@0U9kK0P1YV>/306NYmP<0OK[j1@2@`OL309W1m0D0VlSg0`2OaO<509g;
m`@0XLWe1@2Nc_T509gAnP@0Y;WX102U`>d40:BIbP@0Y9W;102SVL/30::HbPD0XZkO102R/^@20:>i
j080Z;cX102W^^L40:Jii`D0Z;oZ0`2W_>P50:NmjP@0Y[_Y102S^NP40:2fj0@0UjoW0`28XnH407ZI
i@D0X/;`0`3>m>T30<Sak@D0/<g_0`2X`N/00`000000Z<7[0:O0j`0@0:O0j`D0oooo00<000000?oo
o`3oool0103oool000d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?ooo`@0
V[__0P1MXO@00`00F]80>GWR03UihP050::Yg0D0ck_700<0d[S10=G4b@3Ea<T0103F_l@30=Nj_@<0
c<KD103C`LP30=Zl_0030=jj/`3>a]<0c/KC00@0ak;50`2DW]/306VHj`<0IjWf0`1m^_X508K4o0@0
T/Sj102Bbo/409S<nP@0Ulkk102KcoX609c>n@@0Xk3Q102T^NP40:BHb@<0Y9W:1@2TVL/30:>Ib`@0
Xj_L102R[]l40::bi0D0Z;cX0`2W^^L50:S1k0D0Y[_X102V_NT30:NmjPD0Y;[X102S^NP409bbi`@0
TZ[V0`25Wn@408FQiP80X/;`0`2kgo840<Sak@80_>3a1@2Za>`30:S1j`030000002W`>/0Yl3[00l0
Yl3[1@3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02L0oooo102H^o0204RGlP03001JdP0[L^00>GWR0080XZWL0`2][=L30<nka`<0d[S1
103F_l@40=Nj_@80ekBf103C`LP30=Zl_0<0g[Zc1@37//D40::HbP<0SYCE1022XnT307jhn0@0Q/Cl
1@2=a_/309;;n`D0UL[j0`2Gc_/509c7mPD0XjKH102S/>440:FHb0<0Y9S9102TVLX40:BIb`@0YJWJ
102SZm`30::^g`D0ZKoZ102X_>P50:O1k0@0Y[[W102V^nP50:Jlj0<0YK[X102T^^P50:6fj0@0W;;W
0`2BZ^H408FOi0<0QJ7V102kgo830<OckP<0_>3a0P2`cNl40:[4k0<0Yl3[00<000000:O0j`2W`>/0
402W`>/40?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00X0oooo0P00
000X0?ooo`@0V;_`0P18Uo800`00=kD0:g;P0:f/e`050:f/e`030<nka`3B^<40d[S10080d[S100<0
e;Fk0=Joa03F_l@0103G^[d30=Nd]P040=Va/03C`LP0dl780=?1b0<0f[bl0`3N^[<0103Q^k40ak;5
0<Nba@37//D20<B]``@0XYS:0`2>U=D409jJd0<0UZKQ102>^O<509^^i@@0U[od102PZmh409jjk0@0
Y9o@102SY]P20:>`h@<0Yi[80`2UV<P40:BHb@<0Y9W:1@2VZ]T40:FYfP<0Xj_L102Y`^`40:VojPD0
Y[k[1@2W^nL40:Jji`80Y[_X0P2W_^X40:Jlj0@0YK[X102T^NP40:6fj0@0W;;W0`2BZ^H408FOi0D0
V;G/0`37lnh30<Gbk`D0/<g_102X`N/30:O0j`030000002W`>/0Yl3[00l0Yl3[103oool00`000000
oooo0?ooo`040?ooo`00303oool2000000h0oooo00<000000?ooo`3oool09P3oool409Jkl@80=8k_
00<003Ne02]bh02][=L0102][=L40=:h`@<0e;Fk1@3G^[d30=Nd]P80fK6`00@0dl780=Zl_03J_;`0
f[bl0`3N^[<30>6k/@040<Nba@34[L<0a:g30<B]``@0XYS:102UV/X409jJd0<0UZKQ102QX=@409^^
i@D0XioB102PZmh40:JKb`@0Y9o@0`2SY]P50:NJb0@0YIS80`2TV<T40:R/fP@0YZ[I102UZMX40:S4
k@@0ZL;/1@2V_>T40:Rmj0@0Yk_W102V^^L50:NnjP<0Y[cX1@2U_>T40:Bij0@0WkCW102H[NH308jT
i0@0RJ7T0P2H]N`30;;Gl`80aO;_102jgo850:W3k0@0Z<7[0`2W`>/00`000000Yl3[0:O0j`0?0:O0
j`<0oooo00<000000?ooo`3oool0103oool001d0oooo00<000000?ooo`3oool09P3oool409Jkl@80
=8k_00<003Ne015UfP2][=L00P2][=L20;>^d`<0d[S10`3D]K/20=Fb]P80ekZm0`3G];H30=Va/0@0
f[bl0`3N^[<30>6k/@D0a:g30P2RV<X20:bPb`@0YI[:0`2NV]040:RMb`@0XJ3D102XWL/50:>OdP80
X:_N0P2ZWLT30:JKb`@0Y9o@102ZWLX40:NJb0@0YIS8102Z/=d40:R/fP<0YZ[I1@2Wa>h40:S4k@@0
Y[[X0`2V_>T20:RojP@0Z;gX0`2W^nL50:Noj`@0YkkZ202U_>T50::gj0@0WkCW0`2H[NH408jTi0<0
RJ7T102beo<20<7cl080`O;a0P2jgo820:k;k`@0ZL?/202W`>/00`000000Yl3[0:O0j`0>0:O0j`@0
oooo00<000000?ooo`3oool00`3oool001h0oooo00<000000?ooo`3oool09P3oool409JklP80:8S/
00<003Ne015UfP2c[]<0102c[]<0103B^<40e;Fk0=Be^`3D]K/40=Fb]P@0ekBf0`3I/K000`3M/Z`0
f[bl0=Zl_0030=jj/`@0hK^a00<0h[jd0<B]``34[L<00P34[L<40:bPb`@0YI[:102^X//40:RMb`80
XJ3D0P2_X//40:RMb`@0XioB102ZWLT40:JKb`80Y9o@0P2]Y<h30:ZMbP@0Yi[81@2/]^040:Z`g@<0
Z:cJ1@2Wa>h40:NiiP@0YkWW102V^^P50:RojP<0Z;gX1@2V_n/40:Jji`@0YK[X102U_>T40:Bhi`@0
X[OX1@2K[^@309>Wh`@0SZ?S102F/>T30<7cl0<0`O;a1@2^bnl40:S1j`L0Yl3[00<000000:O0j`2W
`>/0402W`>/20?ooo`030000003oool0oooo00<0oooo000O0?ooo`8000009`3oool409JklP80:8S/
0P0AIMX40;>^d`@0e;Fk103E/[H0103G/K<0ekBf0=Nd]P3G];H20=Va/0<0gK:/103N^[<30>6k/@80
h[jd0P34[L<30<6ab`@0[:3;0P2UV/X20:jXdP<0[Z;;102XWL/40:nRb`@0Z9g;1@2`Y<`40:ZMb@<0
YY_;102]Y<h40:ZMbP80Yi[80P2/_>D40:bfh0@0Z[3M1@2V`nh80:NiiP<0YkWW1@2X`N/50:Jlj@@0
Y[kZ102W^nL40:Jji`P0YK[X102T^>L40:6diP@0VjkT102CYn<308jSh`D0[mKd00<0`O;a0;OKl`2g
fo<00`2gfo<50:W2k0@0Z<7[1`2W`>/00`000000Yl3[0:O0j`0@0:O0j`030?ooo`000000oooo00@0
oooo000Q0?ooo`030000003oool0oooo02D0oooo102F_?4202F7j`040018a`0AIMX0/jkC0;>^d`80
]jo@0P3D]K/40=Fb]P80ek6c0P3G];H30=Va/0<0gK:/00<0hkNZ0=jj/`3N^[<0103Q^k420>:n]0H0
`K7;0`2/X</40:jXdP@0[Z;;0P2XWL/20;>/d@@0[j;;0P2XWL/20;>_e0@0/:C<102ZWLT40;6^e@@0
[JC>0`2ZWLX50:bli@<0[;KP1@2V`Nd50:RjiPL0YkWV1@2X`^`40:Jkj0@0Y[cY1@2W_>P40:Nki`@0
Ykk[0`2V_NT40:Fjj0D0XkWX102Q]>H309^^i0@0TjOS102H/NP30:oFm0040;cdl@2lko<0_>oc0;c_
l`@0[<S^102Y`^`<0:O0j`030000002W`>/0Yl3[00l0Yl3[00<0oooo0000003oool0103oool00280
oooo00<000000?ooo`3oool09P3oool309Jll@809HO[00<004S70;N_d02g[m000`2g[m000`3D]K/0
eK:f0=Fb]P020=Fb]P<0ek6c00<0ekBf0=Va/03I/K00103M/Z`20>>gZP@0hK^a0`3R_[@00`3N`;X0
`K7;0<6ab`030<6ab`@0ZJ_H102^Z=830:jRb`D0/jcA0`2_X//40;>_e0@0/:C<1@2a^=h40;6^e@<0
[JC>102/`NT40:bli@@0Y[k[0`2V`Nd20:Rki`@0Z;[V102W^NH50:O2k@@0Yk[W102V^nP40:RnjP@0
YkcX1@2V_^/40:Nnj`<0Y[gY102T^^P40:>ij0D0W:kT0`2GZ>8409:Th@@0V;7X00@0_?Ca0;c_l`2l
ko<0_>oc0`2be?840:c8kP@0Z<3[302W`>/00`000000Yl3[0:O0j`0?0:O0j`030000003oool0oooo
00<0oooo000S0?ooo`030000003oool0oooo02H0oooo0`2H_?4202b;k@030018a`2g[m00]jo@0080
]jo@103E/[H40=Na/`<0fK6`0`3M/Z`30>>gZP040>RnZP3Q^k40hK^a0>6k/@80h[jd0`3N`;X20<6a
b`<0^[?C102YZmP30:jXdP@0/;;J102c[=440;:gg@@0/joD0P2`Y<`20:jmi0@0/KSN102a[]D40:W2
j`@0[<7Y102V^nT40:Jnj`D0Z;_W0`2X^^H50:O2k@T0Yk[W102X`>/40:RnjP@0Y[gZ102V_^/50:Fh
iP<0Y;WW102T^^P40:2bi0@0W:kT102GZ>8309:Th@@0[mgg0P2hm_050;;DlPD0Z<7/102X`>/;0:O0
j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002@0oooo0P00000W0?ooo`<0
V;ca0P0/Rnd00`00B<L0]jo@0;N_d0020;R`dP<0eK:f103G/K<00`3H/[80fK6`0=fb[0030=fb[0<0
hkNZ0P3X_ZX0103Q^k40h[jd0>:n]03R_[@30=k0^PD0^[?C102YZmP40:Nbh@@0/;;J102/^N<40;:g
g@<0/joD1@2^_N@30;6hgPD0Yko[102Y`^/40:Jji`@0Y[_Y102X_NP40:Rki`D0Yl7]102W^^H40:Nj
i`D0Yl7/102X`>/40:Jkj0@0Y[gZ102V^NL40:FhiP@0Y;WW102T]^H40:2bi0<0W:kT102GZ>8509bf
j`030;Sfl02hi_D0^>Ke00<0^>Ke102Za>d40:S1k100Yl3[00<000000:O0j`2W`>/02`2W`>/30?oo
o`030000003oool0oooo00<0oooo000V0?ooo`030000003oool0oooo02D0oooo1@2J_O050;R`dP03
0=Fb]P3G/K<0ek6c0080ek6c0P3H/[80103I/K00gK:/0=fb[03M/Z`30>>gZP<0j;jZ0`3R_[@40=k0
^P030=Vo_`2j/m<0^[?C0080^[?C1@2S[n040:Nbh@@0Y[SV102/^N<30;:gg@@0ZKcW102^_N@40:Jl
j@@0Yko[1@2W^^H40:Jji`D0ZKoZ0`2X_NP50:O0k0@0Z;[W102W^^H80:O1k0D0Y[[W102V^nP40:Nl
j0@0Y[WW102V_NX40:Fjj0@0Y;KV102N[^<309VWg`@0UJGP0P2L]^/20:o[n080]_Cb1@2^c?040:[4
kA@0Yl3[00<000000:O0j`2W`>/01P2W`>/80?ooo`030000003oool0oooo0080oooo000W0?ooo`03
0000003oool0oooo02D0oooo1@2K_O040;R`dP@0ek6c0`3H/[840=fb[0<0hkNZ0`3X_ZX00`3[a:`0
h[jd0>:n]0030=k0^P<0fKno102g/mD40:>_h0D0XkGU102V^>H30:bih`@0Yk_W102Y_>L40:Nkj0@0
Y[cY102X^nL40:NjiPD0Z<7[1@2V_>T40:Jnj`@0Z;_W102X^^L80:O1k0@0Yk[W102V^^L50:Nnj@<0
YkcX1@2U_>X40:JmjP<0YK[X1@2P/^@309j^h`@0VJOO0`2EYN020:o[n0<0]_Cb0P2bfO@40:k<l0D0
Z<3[4`2W`>/00`000000Yl3[0:O0j`030:O0j`/0oooo00<000000?ooo`3oool00P3oool002P0oooo
00<000000?ooo`3oool09P3oool409^ml0@0/[;H0`3G/K<30=Rb/P030=^g/`3M/Z`0gK:/00<0hkNZ
103X_ZX20>_4[0@0g/2j0`3I_kl00`3F_L80]k?E0;Nce@020;Nce@@0Y[7Q102S]ND40:JhiP@0Y[[W
102W^nL40:Rlj0@0Yk_X102Y_^T40:Rki`D0Yl7/102W^nL40:Jlj@D0Z;gX0`2X^nL90:O1k0@0YkWV
102W^^L40:Noj`@0YkkY102U^nT40:FljPD0Y;CT0`2R/n@40:2bi0<0WZkS1@2HZn<20:;8l`<0ZoCb
1@2bfO@40:S2k0@0Z<3[502W`>/00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
000Y0?ooo`8000009`3oool409fmk`@0/[;H00<0ek6c0=Rb/P3H/[800P3H/[820=^g/`040=fb[03S
]jX0hkNZ0>>gZP<0j;jZ0`3[a:`00`3[ak00g/2j0=k0^P030=Vo_`<0e[g20P2g/mD20;Vde0@0Y[7Q
102U]^D40:Jii`@0Y[[W202X_>P50:Rnj@<0ZKkY1@2W_^/40:Rji`@0Yk_W102Y_^T40:Rmj0@0Yko[
102W`N`50:NjiP@0YkWV102W`>/40:Noj`@0Y[[W102U^nT40:Jfi@@0Y;CT102R/n@409jXg@<0VJ?L
102HZn<20:_dlP@0]NWg1@2ZaNd40:S2k1D0Yl3[0`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo000[0?ooo`030000003oool0oooo02D0oooo102M_Nl30;:bf0@0f;:b0`3K
]k<40>>gZP<0j;jZ0P3[a:`30>_7/0@0fKno0`3F_L850;Vde0@0Zk?O102U]^D30:Jii`D0Yk_W102X
_>P50:Nlj@@0Yk_W102V_>T40:Vli`@0Z;[W102X`>X40:Vnj@@0YkkZ102W_n/40:RjiP@0Yk[V1@2W
`>`40:O0j`@0Y[WV102V^^L40:NiiP@0Y[KU0`2T]>@50::`hP@0WZSM0`2IXm`30:KVn`<0[OCc102]
c?040:[5kAD0Yl3[203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000/
0?ooo`030000003oool0oooo02D0oooo0`2N_^l409ndi`<0f;:b0`3K]k<00`3O_kP0hkNZ0>>gZP03
0>RnZP<0jlB/0`3[ak000`3Yak<0fKno0=Vo_`040=Jm`P040=>l``2i]=@0^KCD0;Vde080_;GB102[
/ml40:Rgh`@0YkWV102X^nL40:Nki`D0ZKcW0`2W^nL50:Vnj0@0ZKcW102X`>/40:S0jP@0YkcY102W
_^X40:Rki`@0Z;[V202W`>`50:Nhi@<0Y[WV1@2W_>P40:NiiP<0Y[KU102S]^D40::`hP@0WZSM102N
a?<20:gdl`@0/=Od102]c?050:S0ja00Yl3[2`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo000]0?ooo`030000003oool0oooo02H0oooo0P2N_^l309ndi`80f;:b0`3K]k<3
0=no^0040>>gZP3X_ZX0j;jZ0>RnZP80jlB/103[ak020>W7/`@0e[g20`3C_<<50;bedP80Zk?O0P2_
]=d40:Rgh`@0ZKWU102X^nL80:Vli`@0ZKkY102Y_^P50:NnjP@0Z<3[102W^nL40:Nlj@@0Z;cW102X
^nL40:O0j`@0Yl3/202W^>D40:NnjP@0YkcX1@2T]^D30:BgiP@0XkKU0`2R/>8509Z[hP80W/Cc00@0
Wo?_0;7Tn02ai?P0/NCh102`eo@40:S2k140Yl3[3`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0040oooo000^0?ooo`030000003oool0oooo02H0oooo0P2O_^h309ndi`040=Rb/P3K
]k<0fkNc0=^g/`<0gknh0`3X_ZX30>_4[0<0jlN`0`3Yak<00`3VakP0e[g20=Jm`P040=>l``030=:l
a02l]M80_;GB0080_;GB1@2_]=d20:Rgh`80ZkOR102Y^ND40:VkiP@0ZKcW102X_>P40:Vnj@@0YkcX
102W_^X50:RjiP<0Yk_W1@2Y_^T40:Rli`@0Yko[102W`>/80:Nhi@@0Yko[102W_^X40:Fdi0@0Y;KU
0`2T]nH509nRe`<0Vj7I102JZn800`2Olnl0/NCh0;7Tn0030;7Tn0D0ZLC]402W`>/D0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool002l0oooo0P00000W0?ooo`80XKk^0P1V
Z?H30=^g/`@0gknh00<0hlVn0>RnZP3X_ZX00P3[a:`40>_7/080jLNc0`3VakP40=>l``<0d[c40P2l
]M820;nfd@@0[kCM1@2[]n840:Zii0P0ZK_V102X_>P40:Rki`@0YkcX102Y_>L40:RjiP@0ZKoY102Y
_^T50:Nmj@<0Yko[1@2X^ND40:Nhi@P0Yko[102V]><40:Fdi0@0YJoN0`2SZ=X409nRe`@0Vj7I00<0
V^ch0:__m`2[koL00`2[koL50:_9k`P0Yl3[102W_n/40:O0jaP0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0U0?ooo`80XKk^0P1VZ?H2
0=^g/`<0gknh0`3SbKh30>_4[0<0jlN`0`3Yak<30>K7^0030>?7_@3C_<<0dkc300@0d[c41@2o]]44
0;>efP<0ZkOR0P2^]ml40:Zii0@0Z[[U102Y^nH40:ZliP@0Z;_W102Z_NL40:Vli`@0Z;oZ102Y_nT4
0:Nkj0@0YkgY202X^ND80:Noj`D0Y[?R202V]><40:F_gP<0XjSJ0`2OX]L409gHo0<0Vo7`102/co85
0:S0j`<0Yl3[202W_n/L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool0
0380oooo00<000000?ooo`3oool09@3oool20::okP8006kF103O_kP30>?9_P80i];2103[ak020>W7
/`<0i/Nh0`3Sakd50=:la0040=6laP2o]]40_kKA0;nfd@80`KK?102c]MX50:jgg`@0[;WR102Z^^D4
0:ZkiP@0Z[cV102Y_NP40:Zmi`@0Z;gY102X_nX40:RjiP@0Yk_X102Y^nH40:Rii@P0Yko[102W/n84
0:JchPD0YkSV0`2V]><40:F_gP@0WJcQ102M_^l00`2KlO00[MKf0:gFmP030:gFmP@0Z<7/102X`>/4
0:S1j`@0Yko[803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000c0?oo
o`030000003oool0oooo02D0oooo0P2R_nh2001^eP80gknh0`3SbKh30>KB`P<0imO60`3Yak<30>K7
^0<0hlNm00@0glW30=:la03B_<@0d[c40`3A_<H50<6fc`@0][GH0`2^]ml20;6fg@@0[;WR102[^^@4
0:ZkiP@0ZK_V102Y_NP40:Rki`@0Z;gY102X^ND40:RjiP@0ZKcW102Y^nH40:NnjP@0Yko[102W]>44
0:NchP@0Yk[W102W^>H30:Jdh`D0WZ?H102M[>400`28k>P0[=ki0:cNn@030:cNn@@0ZLC]102X`N`4
0:O1k0@0Z<7[903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000d0?oo
o`8000009P3oool30:>ok@0306<0003SbKh0hlVn0080hlVn0P3Vd/830>OGaP<0i]_:0`3VakP30>?7
_@<0glW300<0d[c40=6laP3A_<H00P3A_<H0103@_/T0`KK?0<6fc`31]/l20<>gc`@0][GH1@2a]]d2
0:bihP80[[SP202[^^@40:VkiP@0ZK[U102X^nL40:Zji@@0Z;WU102Y_^P40:Vli`@0YkcX102W_^X4
0:Rdh@@0YkCQ102W^nP40:Nji`@0XYoB0`2PX=@409jSf080PNO[102Xi_/50:W8k`<0ZLC]202W`N`Y
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool003H0oooo00<000000?oo
o`3oool09@3oool30:>ok@80hlVn0`3Vd/820>OGaP<0i]_:0P3Rgm820>K7^080hlNm103ObL<40=6l
aP<0d;k900<0`KK?0<>gc`33]ll00P33]ll20;Jef080^[GE102a]]d40:jhh0D0[KSQ202[^^@30:Vj
i@D0ZkcV0`2Z^^D80:Vnj0D0Z;WV102W_>P40:VehP@0Z;CQ202W^nP40:BOd@@0XYoB0`2PX=@308OU
m`<0Wn_j102Ybo440:W8k`@0Yko[102W`N`/0?ooo`030000003oool0oooo00L0oooo0@0000010?oo
o`40oooo000g0?ooo`030000003oool0oooo02D0oooo0`2T_nd30>KB`P80imO60`3VflX40>;OdP80
hlNm103ObL<20=_<b`80dKc6103@_/T50<>gc`@0^[GE1@2d]MX20:jhh080/KKL102]^>440:fihP@0
Zk[T102[^nD40:^liP@0ZK_W102Y_^P40:Rgi0@0Z;WV1@2Y]^830:VehPD0Z;_W0`2W^nP50:FPd@<0
Y9oA102RWm84097PoP80Wn_j102Yc_<40:W;l@D0YkkZ0`2W_n/`0?ooo`030000003oool0oooo00H0
oooo0@0000010?ooo`40oooo000h0?ooo`030000003oool0oooo02D0oooo102U_n`20>OGaP<0i]_:
103Rgm820=[Sg@@0glW3103Kc</40=2nb@80cl;>0P33]ll30<Bic`80^[GE0P2l]M<40;BefPD0/KKL
102_]]h40:fihP@0ZkSS102[^nD40:Vhi0@0ZK_W102Y]^840:Rgi0@0Z[SS102Y]^840:Rhi@@0Z;_W
102VXM440:FPd@<0Y9oA1@2Jf?d2097[m@@0Z<od102Yc_<40:RnjSP0oooo00<000000?ooo`3oool0
1@3oool100000040oooo0@3oool003T0oooo0P00000V0?ooo`<0YKo/102L_O040>;OdP80f^?M0`3;
in/50=_<b`80eM;F0P3@_/T30<o2cPD0a;W?1@2l]M<40;NdeP<0/KKL0P2c/mP40:nfgP@0[[GN102[
^><40:^fh@@0ZKST102[]^440:VfhP@0ZkWT102Z^><40:RehP@0Z;SU102VXM040:JQd@<0YJ3A1@2O
dOT00`21ind0Ym7f0:OAmP030:OAmP<0Z<od1@2X_nXk0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo000k0?ooo`030000003oool0oooo02@0oooo0`2V`>`409bml00306f_n@3Jhmd0
f^?M00@0bnO[0P2]ioT30=_<b`<0eM;F103?`/h20<c8e`<0a;W?0P35_]<30;bed`80_[SC102g]=H5
0;>cf080[kKN0P2a/mT40:jegP@0[[CM102[]^440:ffh0@0ZkKQ102[^><40:^ii0@0Z:oM102X]N84
0:NRd0@0YZ7@0`2VXM450:;=mP0307;QiP2Vd_L0Y];g00<0Y];g102X`nd40:S1k3l0oooo00<00000
0?ooo`3oool0103oool100000040oooo0@3oool003`0oooo00<000000?ooo`3oool0903oool30:K0
k0D0XKo^0`25^?H50:gWn@@0eM;F0P3:fnH20<o2cP@0c<SG1@35_]<50;jhd`80]kCF0P2j]MD40;>c
f0D0/K?I102a/]T80:jdg@@0[KKP102[/mh40:^hh`@0Z:[H102X[md40:VTd@@0Yj;@0`2VXM050:C>
m@0306OKh@2Td_L0Y=;g00<0Y=;g102Xa>h40:S3kD<0oooo00<000000?ooo`3oool00`3oool10000
0040oooo0@3oool003d0oooo00<000000?ooo`3oool0903oool40:K0k0@0Y;o]102E_?8205V[n@<0
M=Kl1@3:fnH40<c8e`80a=CV0`35_]<20<C8g@@0_[SC1@2j]MD40;JceP<0/K?I0P2d/]H40;6bf@@0
[k3H102^]=d40:b]f0<0Zk?N1@2ZYm<30:RZf0D0[:WD0`2YY=440:NRd0@0YM;g0P1Pemh40:?An0D0
YlC^0`2Xa>i80?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40oooo000n0?ooo`800000
9@3oool40:O0j`@0Y;o]102N_^l4082in00302>Ek@00O;l0[>;i00@0[>;i1@34e>H50<C8g@80_[SC
0P30`MX30;Zee@80_;gJ102f/mH50;BbeP80/K;I0P2c/MH30:n`f0D0[jcE0`2/[MP40:fYd`@0ZZOC
102`/m/40:bYe0<0ZJCA1@2Sf_/205gEh0@0X]3h102Wa>l40:O4kT/0oooo00<000000?ooo`3oool0
0`3oool100000040oooo00100?ooo`030000003oool0oooo02<0oooo102W`>/40:Jok0@0W[k_102F
_O<306Jcn`D0ILoi102Uh?/40<C8g@D0`<7J1@2l_MX40;Zlf`@0];;F102c/MH20:n`f080];GI102_
[=D40;>df@@0[JWC102ba>L40;2cf`<0[:WD1@2Ih_d00`1OeND0XLkg0:7>m`030:7>m`@0Y/C^102W
a>m?0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`00@@3oool00`000000oooo0?ooo`0S
0?ooo`D0Yl3[0`2V_n`50:Bok@<0U[gc102<_?H204n^nP<04IcH0`2Uh?/50;KJl`@0^MG^0`2l_MX2
0;OEk`<0^[cK1@2i_ml30;>aePD0];GI0P2_[=D20;K:j@@0/kCI0P2]ZM<20:gLn0@0//CW0`2`/m/2
08CTm`@0LMSh1@2QcOH40:K3kP@0Y/C^D`3oool01@000000oooo0?ooo`3oool000000040oooo0012
0?ooo`030000003oool0oooo02@0oooo202W`>/40:K0k0@0XKo^0`2<_?H408Bln@80A:gg0`1=a?44
06oEnP@0^MG^102geNl40;7Km@@0^KoO102hc>T40;Bef@D0]/[Y0`2c]=T50:gLn0@0B<SH0P1neoh4
0:;8l`@0X/_e1@2V`Nd30:K3kUL0oooo00@000000?ooo`3oool000000@3oool004<0oooo0P00000U
0?ooo`P0Yl3[102V`>`40:Fok0<0WKo`102K_o44086mnP<0A[7h00<08ZSP07OIn`1gfO/00`1gfO/5
06WEmP<0/M_e1@2Khod30;S<j@D0Xn?l0`2fb^T508STn@0304?4g@1Fbo80Tlkl00<0Tlkl1@2Sa_83
0:;8l`@0Y/3/GP3oool010000000oooo0?ooo`0000010?ooo`00A@3oool00`000000oooo0?ooo`0S
0?ooo``0Yl3[0`2U_n`50:Bok@<0Vkoa1@2L_o4308FonPD0SL7h0`1V_oh303Nek0<0B/KY1@0i^n@4
05W6n@D0RL[m102OaO<409[9n0D0Y<?_102W_^X30:Nojf80oooo00<000000?ooo`0000000@3oool0
04H0oooo00<000000?ooo`3oool08`3oool@0:O0j`@0Yl3/102T_nd40:G0k@@0W/3`102Q`>l309O1
m@D0W/7a0`2Ca?P409o2l@@0UlGg1@2R`_0309o5l`@0YL7]1@2X_nX30:NnjVH0oooo0@0000010?oo
o`40000000170?ooo`030000003oool0oooo02<0oooo402W`>/40:O0k0@0Yl3[102U`>d40:G0k0<0
XL3_102T`>d409k1l@D0Y<3^0`2O`_450:G0k@@0Yl3[0`2V`>`40:S0j`@0Z;oZJP3oool200000000
B03oool2000002D0oooo6`2W`>/30:G0k0D0Y/3/0`2T`>d50:K0k0@0Yl3[102V`>`70:O0j`@0Yl7/
102X`>]]0?ooo`800000001:0?ooo`030000003oool0oooo02<0oooo=P2W`>/40:O0k0@0Yl7/L03o
ool200000000B`3oool00`000000oooo0?ooo`0R0?ooocP0Yl3[0`2W`>a_0?ooo`@000000P3oool0
04`0oooo00<000000?ooo`3oool08`3ooolc0:O0jg40oooo100000060?ooo`00C@3oool2000002@0
oooo;`2W`>]`0?ooo`@000002P3oool004l0oooo00<000000?ooo`3oool08P3oool[0:O0jfl0oooo
1000000>0?ooo`00D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo001A
0?ooo`030000003oool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580oooo0P00000T0?oo
oah0Yl3[K@3oool4000001T0oooo001D0?ooo`030000003oool0oooo0280oooo5`2W`>]_0?ooo`@0
00007@3oool005D0oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00EP3o
ool00`000000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?ooo`8000008`3oool;
0:O0jf`0oooo1000000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool30000
02d0oooo001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3oool400000300
oooo001K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool4000003@0oooo
001L0?ooo`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool005h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00000L0?ooo`030000
003oool0oooo05<0oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo04/0oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
04L0oooo1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0
oooo1000001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03oool3000005/0oooo
001Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4000005h0oooo001Z
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool400000680oooo001[0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0oooo001/0?ooo`80
0000403oool00`000000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`030000003oool0oooo
0280oooo1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0
oooo1000001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
100000210?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo1000
00250?ooo`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool3000008T0oooo001h0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0oooo001i0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo001j0?ooo`050000
003oool0oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0oooo0000003oool0
103oool4000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L0?ooo`00OP3oool2
00000:00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Mtetra
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Mtetra
.656 .752 .92 r
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.656 .751 .92 r
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Mtetra
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Mtetra
.656 .752 .92 r
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.656 .751 .92 r
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Mtetra
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Mtetra
.655 .751 .92 r
.51621 .66199 .52232 .66784 .53355 .66466 .52747 .65881 Mtetra
.656 .752 .921 r
.52747 .65881 .53355 .66466 .54483 .66149 .53878 .65561 Mtetra
.53878 .65561 .54483 .66149 .55616 .65833 .55014 .65237 Mtetra
.656 .75 .919 r
.55014 .65237 .55616 .65833 .56753 .65517 .56155 .64914 Mtetra
.653 .748 .92 r
.56155 .64914 .56753 .65517 .57895 .65192 .573 .64599 Mtetra
.649 .751 .924 r
.573 .64599 .57895 .65192 .59042 .64863 .5845 .64292 Mtetra
.645 .758 .931 r
.5845 .64292 .59042 .64863 .60193 .64533 .59606 .6399 Mtetra
.643 .768 .939 r
.59606 .6399 .60193 .64533 .6135 .64208 .60766 .63688 Mtetra
.641 .777 .946 r
.60766 .63688 .6135 .64208 .62511 .63886 .61931 .63384 Mtetra
.64 .785 .951 r
.61931 .63384 .62511 .63886 .63677 .63567 .63101 .63076 Mtetra
.64 .79 .954 r
.63101 .63076 .63677 .63567 .64848 .63245 .64277 .62763 Mtetra
.641 .794 .956 r
.64277 .62763 .64848 .63245 .66024 .6292 .65457 .62444 Mtetra
.643 .798 .957 r
.65457 .62444 .66024 .6292 .67205 .62589 .66642 .62117 Mtetra
.645 .801 .958 r
.66642 .62117 .67205 .62589 .68391 .62253 .67831 .61782 Mtetra
.648 .803 .957 r
.67831 .61782 .68391 .62253 .69581 .61912 .69026 .61437 Mtetra
.651 .804 .956 r
.69026 .61437 .69581 .61912 .70776 .61566 .70225 .61083 Mtetra
.654 .803 .954 r
.70225 .61083 .70776 .61566 .71977 .61219 .71428 .60722 Mtetra
.657 .799 .951 r
.71428 .60722 .71977 .61219 .73182 .60874 .72637 .60355 Mtetra
.66 .793 .945 r
.72637 .60355 .73182 .60874 .74393 .60531 .7385 .59983 Mtetra
.663 .784 .939 r
.7385 .59983 .74393 .60531 .75609 .60193 .75068 .59607 Mtetra
.663 .772 .93 r
.75068 .59607 .75609 .60193 .76831 .59857 .76291 .59232 Mtetra
.662 .759 .922 r
.76291 .59232 .76831 .59857 .78058 .59516 .77519 .58865 Mtetra
.658 .749 .917 r
.77519 .58865 .78058 .59516 .79289 .59165 .78754 .58509 Mtetra
.655 .748 .918 r
.78754 .58509 .79289 .59165 .80525 .58806 .79995 .5816 Mtetra
.655 .752 .921 r
.79995 .5816 .80525 .58806 .81767 .5845 .81242 .5781 Mtetra
.656 .755 .923 r
.81242 .5781 .81767 .5845 .83015 .58102 .82493 .57454 Mtetra
.656 .754 .921 r
.82493 .57454 .83015 .58102 .84268 .57754 .83749 .57096 Mtetra
.656 .751 .92 r
.83749 .57096 .84268 .57754 .85527 .57399 .85012 .56738 Mtetra
.85012 .56738 .85527 .57399 .8679 .57041 .8628 .5638 Mtetra
.8628 .5638 .8679 .57041 .88059 .56683 .87553 .56019 Mtetra
.656 .752 .92 r
.87553 .56019 .88059 .56683 .89334 .56324 .88832 .55656 Mtetra
.656 .751 .92 r
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.90116 .55292 .90615 .55963 .91901 .556 .91406 .54926 Mtetra
.91406 .54926 .91901 .556 .93192 .55236 .92702 .54559 Mtetra
.92702 .54559 .93192 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Mtetra
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Mtetra
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Mtetra
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Mtetra
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Mtetra
.655 .752 .921 r
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .6561 Mtetra
.51005 .6561 .51621 .66199 .52747 .65881 .52135 .6529 Mtetra
.653 .751 .922 r
.52135 .6529 .52747 .65881 .53878 .65561 .53269 .64976 Mtetra
.648 .752 .926 r
.53269 .64976 .53878 .65561 .55014 .65237 .54408 .64673 Mtetra
.64 .758 .934 r
.54408 .64673 .55014 .65237 .56155 .64914 .55552 .64385 Mtetra
.631 .769 .946 r
.55552 .64385 .56155 .64914 .573 .64599 .56701 .64111 Mtetra
.62 .782 .959 r
.56701 .64111 .573 .64599 .5845 .64292 .57856 .6385 Mtetra
.604 .796 .973 r
.57856 .6385 .5845 .64292 .59606 .6399 .59016 .63602 Mtetra
.585 .812 .986 r
.59016 .63602 .59606 .6399 .60766 .63688 .60182 .63365 Mtetra
.56 .831 .996 r
.60182 .63365 .60766 .63688 .61931 .63384 .61353 .6313 Mtetra
.532 .849 .998 r
.61353 .6313 .61931 .63384 .63101 .63076 .6253 .62886 Mtetra
.504 .862 .989 r
.6253 .62886 .63101 .63076 .64277 .62763 .63711 .62624 Mtetra
.484 .87 .973 r
.63711 .62624 .64277 .62763 .65457 .62444 .64898 .62338 Mtetra
.477 .876 .96 r
.64898 .62338 .65457 .62444 .66642 .62117 .66089 .62026 Mtetra
.485 .884 .954 r
.66089 .62026 .66642 .62117 .67831 .61782 .67284 .61687 Mtetra
.509 .894 .957 r
.67284 .61687 .67831 .61782 .69026 .61437 .68482 .6132 Mtetra
.544 .904 .967 r
.68482 .6132 .69026 .61437 .70225 .61083 .69685 .60928 Mtetra
.585 .909 .978 r
.69685 .60928 .70225 .61083 .71428 .60722 .70891 .60513 Mtetra
.622 .905 .985 r
.70891 .60513 .71428 .60722 .72637 .60355 .72101 .60079 Mtetra
.65 .889 .983 r
.72101 .60079 .72637 .60355 .7385 .59983 .73315 .59636 Mtetra
.665 .865 .975 r
.73315 .59636 .7385 .59983 .75068 .59607 .74533 .59195 Mtetra
.67 .841 .965 r
.74533 .59195 .75068 .59607 .76291 .59232 .75757 .58763 Mtetra
.671 .82 .955 r
.75757 .58763 .76291 .59232 .77519 .58865 .76987 .58342 Mtetra
.669 .8 .945 r
.76987 .58342 .77519 .58865 .78754 .58509 .78222 .57934 Mtetra
.667 .781 .934 r
.78222 .57934 .78754 .58509 .79995 .5816 .79464 .57539 Mtetra
.662 .764 .926 r
.79464 .57539 .79995 .5816 .81242 .5781 .80712 .57161 Mtetra
.658 .754 .921 r
.80712 .57161 .81242 .5781 .82493 .57454 .81966 .56796 Mtetra
.656 .752 .92 r
.81966 .56796 .82493 .57454 .83749 .57096 .83227 .56436 Mtetra
.656 .752 .921 r
.83227 .56436 .83749 .57096 .85012 .56738 .84493 .56075 Mtetra
.84493 .56075 .85012 .56738 .8628 .5638 .85765 .55713 Mtetra
.656 .752 .92 r
.85765 .55713 .8628 .5638 .87553 .56019 .87042 .55348 Mtetra
.656 .751 .92 r
.87042 .55348 .87553 .56019 .88832 .55656 .88325 .54983 Mtetra
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91406 .54926 .90908 .54247 Mtetra
.90908 .54247 .91406 .54926 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94825 .53132 Mtetra
.94825 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Mtetra
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Mtetra
.655 .751 .92 r
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65659 Mtetra
.654 .751 .921 r
.48134 .65659 .4876 .66248 .4988 .65929 .49257 .65341 Mtetra
.651 .752 .923 r
.49257 .65341 .4988 .65929 .51005 .6561 .50385 .65031 Mtetra
.644 .753 .929 r
.50385 .65031 .51005 .6561 .52135 .6529 .51517 .64737 Mtetra
.63 .759 .94 r
.51517 .64737 .52135 .6529 .53269 .64976 .52655 .64473 Mtetra
.606 .771 .959 r
.52655 .64473 .53269 .64976 .54408 .64673 .53798 .64246 Mtetra
.568 .79 .982 r
.53798 .64246 .54408 .64673 .55552 .64385 .54946 .64058 Mtetra
.507 .809 .999 r
.54946 .64058 .55552 .64385 .56701 .64111 .561 .63903 Mtetra
.417 .815 .984 r
.561 .63903 .56701 .64111 .57856 .6385 .57261 .63758 Mtetra
.324 .797 .921 r
.57261 .63758 .57856 .6385 .59016 .63602 .58427 .63592 Mtetra
.279 .78 .857 r
.58427 .63592 .59016 .63602 .60182 .63365 .59599 .6338 Mtetra
.307 .799 .85 r
.59599 .6338 .60182 .63365 .61353 .6313 .60775 .63115 Mtetra
.388 .845 .896 r
.60775 .63115 .61353 .6313 .6253 .62886 .61955 .62807 Mtetra
.477 .881 .949 r
.61955 .62807 .6253 .62886 .63711 .62624 .6314 .62472 Mtetra
.542 .891 .981 r
.6314 .62472 .63711 .62624 .64898 .62338 .64329 .62126 Mtetra
.575 .884 .991 r
.64329 .62126 .64898 .62338 .66089 .62026 .65524 .6178 Mtetra
.585 .876 .993 r
.65524 .6178 .66089 .62026 .67284 .61687 .66723 .6144 Mtetra
.58 .875 .994 r
.66723 .6144 .67284 .61687 .68482 .6132 .67929 .61106 Mtetra
.561 .881 .991 r
.67929 .61106 .68482 .6132 .69685 .60928 .69139 .60772 Mtetra
.532 .889 .979 r
.69139 .60772 .69685 .60928 .70891 .60513 .70354 .60425 Mtetra
.498 .892 .949 r
.70354 .60425 .70891 .60513 .72101 .60079 .71573 .6005 Mtetra
.478 .893 .914 r
.71573 .6005 .72101 .60079 .73315 .59636 .72795 .59631 Mtetra
.498 .905 .9 r
.72795 .59631 .73315 .59636 .74533 .59195 .74018 .59157 Mtetra
.562 .93 .925 r
.74018 .59157 .74533 .59195 .75757 .58763 .75242 .58637 Mtetra
.635 .939 .961 r
.75242 .58637 .75757 .58763 .76987 .58342 .76469 .58094 Mtetra
.677 .912 .975 r
.76469 .58094 .76987 .58342 .78222 .57934 .77701 .57562 Mtetra
.687 .867 .967 r
.77701 .57562 .78222 .57934 .79464 .57539 .78939 .57063 Mtetra
.682 .825 .952 r
.78939 .57063 .79464 .57539 .80712 .57161 .80185 .56602 Mtetra
.673 .793 .938 r
.80185 .56602 .80712 .57161 .81966 .56796 .8144 .56179 Mtetra
.665 .77 .928 r
.8144 .56179 .81966 .56796 .83227 .56436 .82702 .55786 Mtetra
.659 .758 .923 r
.82702 .55786 .83227 .56436 .84493 .56075 .83971 .5541 Mtetra
.657 .753 .921 r
.83971 .5541 .84493 .56075 .85765 .55713 .85246 .55041 Mtetra
.656 .752 .92 r
.85246 .55041 .85765 .55713 .87042 .55348 .86528 .54673 Mtetra
.656 .751 .92 r
.86528 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Mtetra
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94825 .53132 .94336 .52438 Mtetra
.94336 .52438 .94825 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Mtetra
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Mtetra
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65708 Mtetra
.655 .751 .921 r
.45265 .65708 .45901 .66296 .47015 .65978 .46381 .65389 Mtetra
.652 .751 .923 r
.46381 .65389 .47015 .65978 .48134 .65659 .47503 .65077 Mtetra
.644 .752 .928 r
.47503 .65077 .48134 .65659 .49257 .65341 .48629 .64785 Mtetra
.625 .756 .941 r
.48629 .64785 .49257 .65341 .50385 .65031 .49759 .64534 Mtetra
.587 .767 .965 r
.49759 .64534 .50385 .65031 .51517 .64737 .50895 .64343 Mtetra
.517 .784 .993 r
.50895 .64343 .51517 .64737 .52655 .64473 .52035 .64217 Mtetra
.401 .789 .989 r
.52035 .64217 .52655 .64473 .53798 .64246 .53182 .6413 Mtetra
.284 .767 .92 r
.53182 .6413 .53798 .64246 .54946 .64058 .54336 .64024 Mtetra
.287 .783 .878 r
.54336 .64024 .54946 .64058 .561 .63903 .55495 .63835 Mtetra
.448 .868 .943 r
.55495 .63835 .561 .63903 .57261 .63758 .56658 .63534 Mtetra
.623 .891 .988 r
.56658 .63534 .57261 .63758 .58427 .63592 .57825 .63139 Mtetra
.688 .818 .945 r
.57825 .63139 .58427 .63592 .59599 .6338 .58996 .62694 Mtetra
.69 .742 .891 r
.58996 .62694 .59599 .6338 .60775 .63115 .60171 .62242 Mtetra
.679 .691 .854 r
.60171 .62242 .60775 .63115 .61955 .62807 .61351 .61808 Mtetra
.668 .661 .834 r
.61351 .61808 .61955 .62807 .6314 .62472 .62535 .61399 Mtetra
.66 .644 .824 r
.62535 .61399 .6314 .62472 .64329 .62126 .63725 .61015 Mtetra
.654 .636 .82 r
.63725 .61015 .64329 .62126 .65524 .6178 .64921 .60653 Mtetra
.649 .632 .819 r
.64921 .60653 .65524 .6178 .66723 .6144 .66122 .60309 Mtetra
.645 .629 .82 r
.66122 .60309 .66723 .6144 .67929 .61106 .6733 .59984 Mtetra
.64 .629 .823 r
.6733 .59984 .67929 .61106 .69139 .60772 .68544 .59681 Mtetra
.635 .633 .831 r
.68544 .59681 .69139 .60772 .70354 .60425 .69765 .59404 Mtetra
.629 .644 .846 r
.69765 .59404 .70354 .60425 .71573 .6005 .70993 .59153 Mtetra
.624 .669 .873 r
.70993 .59153 .71573 .6005 .72795 .59631 .72228 .58919 Mtetra
.619 .719 .917 r
.72228 .58919 .72795 .59631 .74018 .59157 .73469 .58678 Mtetra
.615 .8 .971 r
.73469 .58678 .74018 .59157 .75242 .58637 .74713 .58386 Mtetra
.599 .888 .991 r
.74713 .58386 .75242 .58637 .76469 .58094 .75956 .57998 Mtetra
.586 .93 .951 r
.75956 .57998 .76469 .58094 .77701 .57562 .77197 .57494 Mtetra
.62 .949 .936 r
.77197 .57494 .77701 .57562 .78939 .57063 .78435 .56904 Mtetra
.678 .946 .96 r
.78435 .56904 .78939 .57063 .80185 .56602 .79675 .56294 Mtetra
.702 .9 .967 r
.79675 .56294 .80185 .56602 .8144 .56179 .80923 .55724 Mtetra
.694 .841 .954 r
.80923 .55724 .8144 .56179 .82702 .55786 .8218 .5522 Mtetra
.677 .796 .938 r
.8218 .5522 .82702 .55786 .83971 .5541 .83448 .54777 Mtetra
.665 .769 .927 r
.83448 .54777 .83971 .5541 .85246 .55041 .84724 .54376 Mtetra
.659 .757 .922 r
.84724 .54376 .85246 .55041 .86528 .54673 .86009 .53995 Mtetra
.657 .753 .921 r
.86009 .53995 .86528 .54673 .87815 .54304 .873 .53621 Mtetra
.656 .752 .92 r
.873 .53621 .87815 .54304 .89107 .53934 .88597 .53247 Mtetra
.656 .751 .92 r
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Mtetra
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Mtetra
.655 .751 .92 r
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65437 Mtetra
.654 .751 .921 r
.43508 .65437 .44152 .66027 .45265 .65708 .44623 .6512 Mtetra
.648 .751 .925 r
.44623 .6512 .45265 .65708 .46381 .65389 .45742 .64818 Mtetra
.631 .753 .936 r
.45742 .64818 .46381 .65389 .47503 .65077 .46866 .64555 Mtetra
.591 .759 .959 r
.46866 .64555 .47503 .65077 .48629 .64785 .47994 .64366 Mtetra
.507 .77 .991 r
.47994 .64366 .48629 .64785 .49759 .64534 .49126 .64267 Mtetra
.362 .766 .984 r
.49126 .64267 .49759 .64534 .50895 .64343 .50264 .64225 Mtetra
.25 .746 .908 r
.50264 .64225 .50895 .64343 .52035 .64217 .51409 .64149 Mtetra
.356 .818 .921 r
.51409 .64149 .52035 .64217 .53182 .6413 .52561 .63938 Mtetra
.603 .895 .988 r
.52561 .63938 .53182 .6413 .54336 .64024 .53717 .63559 Mtetra
.705 .815 .934 r
.53717 .63559 .54336 .64024 .55495 .63835 .54878 .6307 Mtetra
.702 .722 .866 r
.54878 .6307 .55495 .63835 .56658 .63534 .56042 .62563 Mtetra
.683 .671 .832 r
.56042 .62563 .56658 .63534 .57825 .63139 .5721 .62094 Mtetra
.668 .652 .825 r
.5721 .62094 .57825 .63139 .58996 .62694 .58383 .61678 Mtetra
.661 .654 .833 r
.58383 .61678 .58996 .62694 .60171 .62242 .59562 .613 Mtetra
.658 .669 .849 r
.59562 .613 .60171 .62242 .61351 .61808 .60746 .60943 Mtetra
.657 .686 .866 r
.60746 .60943 .61351 .61808 .62535 .61399 .61935 .60594 Mtetra
.657 .702 .88 r
.61935 .60594 .62535 .61399 .63725 .61015 .63129 .60247 Mtetra
.657 .712 .889 r
.63129 .60247 .63725 .61015 .64921 .60653 .64329 .59901 Mtetra
.656 .718 .893 r
.64329 .59901 .64921 .60653 .66122 .60309 .65533 .59555 Mtetra
.656 .718 .894 r
.65533 .59555 .66122 .60309 .6733 .59984 .66743 .5921 Mtetra
.655 .713 .89 r
.66743 .5921 .6733 .59984 .68544 .59681 .67958 .58865 Mtetra
.654 .702 .881 r
.67958 .58865 .68544 .59681 .69765 .59404 .69179 .58521 Mtetra
.651 .685 .869 r
.69179 .58521 .69765 .59404 .70993 .59153 .70405 .58185 Mtetra
.644 .664 .854 r
.70405 .58185 .70993 .59153 .72228 .58919 .71638 .57871 Mtetra
.634 .643 .842 r
.71638 .57871 .72228 .58919 .73469 .58678 .72879 .57594 Mtetra
.62 .631 .84 r
.72879 .57594 .73469 .58678 .74713 .58386 .7413 .57372 Mtetra
.609 .64 .856 r
.7413 .57372 .74713 .58386 .75956 .57998 .7539 .57189 Mtetra
.609 .69 .9 r
.7539 .57189 .75956 .57998 .77197 .57494 .76655 .56986 Mtetra
.625 .797 .965 r
.76655 .56986 .77197 .57494 .78435 .56904 .77919 .56671 Mtetra
.64 .912 .981 r
.77919 .56671 .78435 .56904 .79675 .56294 .79175 .56184 Mtetra
.659 .954 .947 r
.79175 .56184 .79675 .56294 .80923 .55724 .80425 .55556 Mtetra
.702 .951 .954 r
.80425 .55556 .80923 .55724 .8218 .5522 .81675 .54891 Mtetra
.715 .9 .962 r
.81675 .54891 .8218 .5522 .83448 .54777 .82933 .54285 Mtetra
.696 .832 .948 r
.82933 .54285 .83448 .54777 .84724 .54376 .84205 .53772 Mtetra
.674 .785 .933 r
.84205 .53772 .84724 .54376 .86009 .53995 .85488 .53334 Mtetra
.662 .762 .924 r
.85488 .53334 .86009 .53995 .873 .53621 .86781 .52938 Mtetra
.657 .754 .921 r
.86781 .52938 .873 .53621 .88597 .53247 .88082 .52556 Mtetra
.656 .752 .92 r
.88082 .52556 .88597 .53247 .89899 .52873 .89388 .52177 Mtetra
.656 .751 .92 r
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Mtetra
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Mtetra
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Mtetra
.655 .751 .921 r
.40635 .65485 .41291 .66076 .42397 .65756 .41744 .65165 Mtetra
.652 .751 .922 r
.41744 .65165 .42397 .65756 .43508 .65437 .42858 .6485 Mtetra
.643 .751 .928 r
.42858 .6485 .43508 .65437 .44623 .6512 .43975 .6456 Mtetra
.614 .753 .944 r
.43975 .6456 .44623 .6512 .45742 .64818 .45096 .64332 Mtetra
.544 .758 .976 r
.45096 .64332 .45742 .64818 .46866 .64555 .4622 .6421 Mtetra
.4 .755 .994 r
.4622 .6421 .46866 .64555 .47994 .64366 .47349 .6419 Mtetra
.239 .725 .927 r
.47349 .6419 .47994 .64366 .49126 .64267 .48485 .64175 Mtetra
.321 .794 .922 r
.48485 .64175 .49126 .64267 .50264 .64225 .49628 .64017 Mtetra
.609 .89 .989 r
.49628 .64017 .50264 .64225 .51409 .64149 .50779 .63643 Mtetra
.715 .802 .919 r
.50779 .63643 .51409 .64149 .52561 .63938 .51934 .63123 Mtetra
.704 .711 .853 r
.51934 .63123 .52561 .63938 .53717 .63559 .53093 .62592 Mtetra
.682 .671 .833 r
.53093 .62592 .53717 .63559 .54878 .6307 .54256 .62126 Mtetra
.67 .672 .843 r
.54256 .62126 .54878 .6307 .56042 .62563 .55423 .6172 Mtetra
.667 .694 .866 r
.55423 .6172 .56042 .62563 .5721 .62094 .56595 .61339 Mtetra
.667 .717 .886 r
.56595 .61339 .5721 .62094 .58383 .61678 .57772 .60962 Mtetra
.668 .729 .895 r
.57772 .60962 .58383 .61678 .59562 .613 .58954 .60584 Mtetra
.666 .729 .896 r
.58954 .60584 .59562 .613 .60746 .60943 .6014 .60207 Mtetra
.664 .724 .894 r
.6014 .60207 .60746 .60943 .61935 .60594 .61332 .59837 Mtetra
.661 .718 .89 r
.61332 .59837 .61935 .60594 .63129 .60247 .62529 .59475 Mtetra
.659 .713 .888 r
.62529 .59475 .63129 .60247 .64329 .59901 .63731 .59119 Mtetra
.656 .711 .888 r
.63731 .59119 .64329 .59901 .65533 .59555 .64939 .5877 Mtetra
.654 .71 .888 r
.64939 .5877 .65533 .59555 .66743 .5921 .66152 .58428 Mtetra
.652 .71 .891 r
.66152 .58428 .66743 .5921 .67958 .58865 .67371 .58093 Mtetra
.649 .713 .895 r
.67371 .58093 .67958 .58865 .69179 .58521 .68595 .57766 Mtetra
.646 .718 .9 r
.68595 .57766 .69179 .58521 .70405 .58185 .69826 .57445 Mtetra
.645 .722 .905 r
.69826 .57445 .70405 .58185 .71638 .57871 .71062 .57126 Mtetra
.645 .722 .904 r
.71062 .57126 .71638 .57871 .72879 .57594 .72304 .56806 Mtetra
.644 .71 .895 r
.72304 .56806 .72879 .57594 .7413 .57372 .73552 .56489 Mtetra
.637 .683 .877 r
.73552 .56489 .7413 .57372 .7539 .57189 .74808 .56198 Mtetra
.621 .652 .86 r
.74808 .56198 .7539 .57189 .76655 .56986 .76074 .55967 Mtetra
.603 .638 .859 r
.76074 .55967 .76655 .56986 .77919 .56671 .77351 .55801 Mtetra
.601 .673 .891 r
.77351 .55801 .77919 .56671 .79175 .56184 .78635 .55624 Mtetra
.633 .784 .954 r
.78635 .55624 .79175 .56184 .80425 .55556 .79914 .55297 Mtetra
.676 .916 .975 r
.79914 .55297 .80425 .55556 .81675 .54891 .8118 .54745 Mtetra
.705 .96 .946 r
.8118 .54745 .81675 .54891 .82933 .54285 .82437 .54046 Mtetra
.73 .938 .955 r
.82437 .54046 .82933 .54285 .84205 .53772 .83698 .53351 Mtetra
.715 .868 .954 r
.83698 .53351 .84205 .53772 .85488 .53334 .84972 .52762 Mtetra
.685 .803 .938 r
.84972 .52762 .85488 .53334 .86781 .52938 .86262 .52282 Mtetra
.666 .769 .926 r
.86262 .52282 .86781 .52938 .88082 .52556 .87564 .51867 Mtetra
.658 .756 .922 r
.87564 .51867 .88082 .52556 .89388 .52177 .88874 .51477 Mtetra
.656 .752 .921 r
.88874 .51477 .89388 .52177 .90701 .51797 .90191 .51093 Mtetra
.656 .751 .92 r
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Mtetra
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Mtetra
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Mtetra
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65213 Mtetra
.655 .751 .921 r
.38868 .65213 .39531 .65806 .40635 .65485 .39975 .64891 Mtetra
.652 .751 .922 r
.39975 .64891 .40635 .65485 .41744 .65165 .41087 .64578 Mtetra
.638 .751 .93 r
.41087 .64578 .41744 .65165 .42858 .6485 .42202 .64297 Mtetra
.598 .751 .951 r
.42202 .64297 .42858 .6485 .43975 .6456 .4332 .64099 Mtetra
.496 .751 .986 r
.4332 .64099 .43975 .6456 .45096 .64332 .4444 .64034 Mtetra
.301 .723 .973 r
.4444 .64034 .45096 .64332 .4622 .6421 .45565 .64068 Mtetra
.21 .716 .901 r
.45565 .64068 .4622 .6421 .47349 .6419 .46698 .64044 Mtetra
.479 .862 .979 r
.46698 .64044 .47349 .6419 .48485 .64175 .4784 .63788 Mtetra
.703 .842 .949 r
.4784 .63788 .48485 .64175 .49628 .64017 .48991 .63298 Mtetra
.717 .738 .867 r
.48991 .63298 .49628 .64017 .50779 .63643 .50145 .62734 Mtetra
.694 .687 .839 r
.50145 .62734 .50779 .63643 .51934 .63123 .51303 .62226 Mtetra
.681 .686 .848 r
.51303 .62226 .51934 .63123 .53093 .62592 .52464 .61781 Mtetra
.677 .705 .868 r
.52464 .61781 .53093 .62592 .54256 .62126 .5363 .61363 Mtetra
.675 .717 .88 r
.5363 .61363 .54256 .62126 .55423 .6172 .54801 .60955 Mtetra
.671 .716 .883 r
.54801 .60955 .55423 .6172 .56595 .61339 .55975 .60563 Mtetra
.665 .712 .883 r
.55975 .60563 .56595 .61339 .57772 .60962 .57155 .6019 Mtetra
.66 .712 .887 r
.57155 .6019 .57772 .60962 .58954 .60584 .5834 .59832 Mtetra
.658 .718 .893 r
.5834 .59832 .58954 .60584 .6014 .60207 .59531 .59483 Mtetra
.656 .726 .9 r
.59531 .59483 .6014 .60207 .61332 .59837 .60726 .59136 Mtetra
.656 .733 .906 r
.60726 .59136 .61332 .59837 .62529 .59475 .61927 .58788 Mtetra
.656 .739 .911 r
.61927 .58788 .62529 .59475 .63731 .59119 .63133 .58438 Mtetra
.656 .741 .913 r
.63133 .58438 .63731 .59119 .64939 .5877 .64344 .58087 Mtetra
.64344 .58087 .64939 .5877 .66152 .58428 .6556 .57734 Mtetra
.656 .739 .911 r
.6556 .57734 .66152 .58428 .67371 .58093 .66781 .57379 Mtetra
.656 .734 .907 r
.66781 .57379 .67371 .58093 .68595 .57766 .68008 .57023 Mtetra
.655 .726 .901 r
.68008 .57023 .68595 .57766 .69826 .57445 .69241 .56669 Mtetra
.652 .716 .895 r
.69241 .56669 .69826 .57445 .71062 .57126 .70479 .56323 Mtetra
.648 .708 .891 r
.70479 .56323 .71062 .57126 .72304 .56806 .71724 .55993 Mtetra
.641 .704 .892 r
.71724 .55993 .72304 .56806 .73552 .56489 .72976 .55682 Mtetra
.636 .704 .895 r
.72976 .55682 .73552 .56489 .74808 .56198 .74234 .55387 Mtetra
.632 .702 .896 r
.74234 .55387 .74808 .56198 .76074 .55967 .755 .55103 Mtetra
.625 .686 .887 r
.755 .55103 .76074 .55967 .77351 .55801 .76774 .54845 Mtetra
.608 .657 .872 r
.76774 .54845 .77351 .55801 .78635 .55624 .78059 .54651 Mtetra
.592 .646 .873 r
.78059 .54651 .78635 .55624 .79914 .55297 .79356 .54513 Mtetra
.607 .703 .911 r
.79356 .54513 .79914 .55297 .8118 .54745 .80654 .54298 Mtetra
.669 .843 .967 r
.80654 .54298 .8118 .54745 .82437 .54046 .81938 .53841 Mtetra
.719 .948 .953 r
.81938 .53841 .82437 .54046 .83698 .53351 .83206 .53144 Mtetra
.743 .953 .944 r
.83206 .53144 .83698 .53351 .84972 .52762 .84471 .52385 Mtetra
.732 .892 .952 r
.84471 .52385 .84972 .52762 .86262 .52282 .85749 .5173 Mtetra
.695 .816 .94 r
.85749 .5173 .86262 .52282 .87564 .51867 .87045 .51212 Mtetra
.669 .773 .927 r
.87045 .51212 .87564 .51867 .88874 .51477 .88356 .50782 Mtetra
.659 .757 .922 r
.88356 .50782 .88874 .51477 .90191 .51093 .89676 .50384 Mtetra
.656 .752 .921 r
.89676 .50384 .90191 .51093 .91513 .50708 .91003 .49995 Mtetra
.656 .751 .92 r
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Mtetra
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Mtetra
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Mtetra
.655 .751 .921 r
.37094 .64939 .37765 .65534 .38868 .65213 .382 .64617 Mtetra
.652 .751 .922 r
.382 .64617 .38868 .65213 .39975 .64891 .3931 .64302 Mtetra
.637 .75 .93 r
.3931 .64302 .39975 .64891 .41087 .64578 .40423 .64023 Mtetra
.59 .749 .953 r
.40423 .64023 .41087 .64578 .42202 .64297 .41538 .63841 Mtetra
.463 .74 .988 r
.41538 .63841 .42202 .64297 .4332 .64099 .42654 .63814 Mtetra
.234 .69 .951 r
.42654 .63814 .4332 .64099 .4444 .64034 .43774 .63891 Mtetra
.215 .719 .903 r
.43774 .63891 .4444 .64034 .45565 .64068 .44904 .63862 Mtetra
.57 .878 .993 r
.44904 .63862 .45565 .64068 .46698 .64044 .46046 .63544 Mtetra
.724 .805 .915 r
.46046 .63544 .46698 .64044 .4784 .63788 .47196 .62992 Mtetra
.717 .719 .851 r
.47196 .62992 .4784 .63788 .48991 .63298 .4835 .62408 Mtetra
.697 .693 .842 r
.4835 .62408 .48991 .63298 .50145 .62734 .49507 .61892 Mtetra
.687 .7 .857 r
.49507 .61892 .50145 .62734 .51303 .62226 .50668 .61429 Mtetra
.679 .71 .871 r
.50668 .61429 .51303 .62226 .52464 .61781 .51832 .61003 Mtetra
.67 .713 .88 r
.51832 .61003 .52464 .61781 .5363 .61363 .53001 .60613 Mtetra
.663 .718 .89 r
.53001 .60613 .5363 .61363 .54801 .60955 .54174 .60248 Mtetra
.66 .73 .901 r
.54174 .60248 .54801 .60955 .55975 .60563 .55352 .5989 Mtetra
.661 .742 .91 r
.55352 .5989 .55975 .60563 .57155 .6019 .56536 .5953 Mtetra
.662 .747 .913 r
.56536 .5953 .57155 .6019 .5834 .59832 .57724 .59163 Mtetra
.662 .745 .912 r
.57724 .59163 .5834 .59832 .59531 .59483 .58917 .58795 Mtetra
.661 .74 .908 r
.58917 .58795 .59531 .59483 .60726 .59136 .60116 .58429 Mtetra
.66 .735 .905 r
.60116 .58429 .60726 .59136 .61927 .58788 .61319 .58067 Mtetra
.658 .731 .903 r
.61319 .58067 .61927 .58788 .63133 .58438 .62528 .57709 Mtetra
.656 .728 .902 r
.62528 .57709 .63133 .58438 .64344 .58087 .63742 .57354 Mtetra
.655 .728 .903 r
.63742 .57354 .64344 .58087 .6556 .57734 .64962 .57004 Mtetra
.653 .729 .905 r
.64962 .57004 .6556 .57734 .66781 .57379 .66187 .56658 Mtetra
.651 .732 .908 r
.66187 .56658 .66781 .57379 .68008 .57023 .67419 .56316 Mtetra
.649 .736 .913 r
.67419 .56316 .68008 .57023 .69241 .56669 .68655 .55976 Mtetra
.649 .741 .917 r
.68655 .55976 .69241 .56669 .70479 .56323 .69897 .55634 Mtetra
.65 .744 .918 r
.69897 .55634 .70479 .56323 .71724 .55993 .71145 .55286 Mtetra
.651 .74 .914 r
.71145 .55286 .71724 .55993 .72976 .55682 .72398 .54935 Mtetra
.649 .728 .906 r
.72398 .54935 .72976 .55682 .74234 .55387 .73658 .5459 Mtetra
.642 .711 .898 r
.73658 .5459 .74234 .55387 .755 .55103 .74925 .54271 Mtetra
.631 .698 .894 r
.74925 .54271 .755 .55103 .76774 .54845 .762 .53989 Mtetra
.62 .688 .892 r
.762 .53989 .76774 .54845 .78059 .54651 .77485 .53743 Mtetra
.604 .669 .885 r
.77485 .53743 .78059 .54651 .79356 .54513 .78781 .53552 Mtetra
.585 .648 .879 r
.78781 .53552 .79356 .54513 .80654 .54298 .8009 .5343 Mtetra
.591 .674 .898 r
.8009 .5343 .80654 .54298 .81938 .53841 .81403 .53272 Mtetra
.656 .796 .95 r
.81403 .53272 .81938 .53841 .83206 .53144 .82703 .52873 Mtetra
.733 .931 .955 r
.82703 .52873 .83206 .53144 .84471 .52385 .8398 .52172 Mtetra
.76 .956 .936 r
.8398 .52172 .84471 .52385 .85749 .5173 .8525 .51361 Mtetra
.744 .901 .948 r
.8525 .51361 .85749 .5173 .87045 .51212 .86533 .50659 Mtetra
.7 .821 .939 r
.86533 .50659 .87045 .51212 .88356 .50782 .87838 .50118 Mtetra
.67 .773 .927 r
.87838 .50118 .88356 .50782 .89676 .50384 .89158 .49679 Mtetra
.659 .756 .922 r
.89158 .49679 .89676 .50384 .91003 .49995 .90488 .49277 Mtetra
.656 .752 .921 r
.90488 .49277 .91003 .49995 .92336 .49605 .91826 .48882 Mtetra
.656 .751 .92 r
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Mtetra
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Mtetra
.655 .751 .92 r
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .6434 Mtetra
.653 .751 .922 r
.36418 .6434 .37094 .64939 .382 .64617 .37526 .64022 Mtetra
.639 .75 .929 r
.37526 .64022 .382 .64617 .3931 .64302 .38638 .63737 Mtetra
.592 .747 .951 r
.38638 .63737 .3931 .64302 .40423 .64023 .3975 .63551 Mtetra
.456 .732 .986 r
.3975 .63551 .40423 .64023 .41538 .63841 .40862 .63539 Mtetra
.197 .663 .94 r
.40862 .63539 .41538 .63841 .42654 .63814 .41977 .63657 Mtetra
.188 .698 .897 r
.41977 .63657 .42654 .63814 .43774 .63891 .43103 .6366 Mtetra
.59 .875 .993 r
.43103 .6366 .43774 .63891 .44904 .63862 .44244 .63329 Mtetra
.733 .795 .902 r
.44244 .63329 .44904 .63862 .46046 .63544 .45395 .62739 Mtetra
.723 .719 .846 r
.45395 .62739 .46046 .63544 .47196 .62992 .46549 .62118 Mtetra
.703 .699 .843 r
.46549 .62118 .47196 .62992 .4835 .62408 .47706 .61572 Mtetra
.689 .703 .858 r
.47706 .61572 .4835 .62408 .49507 .61892 .48865 .61101 Mtetra
.676 .711 .874 r
.48865 .61101 .49507 .61892 .50668 .61429 .50027 .60687 Mtetra
.668 .722 .889 r
.50027 .60687 .50668 .61429 .51832 .61003 .51195 .60304 Mtetra
.668 .735 .9 r
.51195 .60304 .51832 .61003 .53001 .60613 .52366 .59924 Mtetra
.668 .739 .903 r
.52366 .59924 .53001 .60613 .54174 .60248 .53543 .59541 Mtetra
.666 .734 .9 r
.53543 .59541 .54174 .60248 .55352 .5989 .54724 .59162 Mtetra
.662 .727 .898 r
.54724 .59162 .55352 .5989 .56536 .5953 .55911 .58795 Mtetra
.659 .725 .898 r
.55911 .58795 .56536 .5953 .57724 .59163 .57102 .58438 Mtetra
.656 .728 .902 r
.57102 .58438 .57724 .59163 .58917 .58795 .58299 .58087 Mtetra
.655 .733 .907 r
.58299 .58087 .58917 .58795 .60116 .58429 .59501 .57737 Mtetra
.655 .739 .911 r
.59501 .57737 .60116 .58429 .61319 .58067 .60708 .57385 Mtetra
.655 .743 .914 r
.60708 .57385 .61319 .58067 .62528 .57709 .61921 .57031 Mtetra
.655 .745 .916 r
.61921 .57031 .62528 .57709 .63742 .57354 .63139 .56674 Mtetra
.656 .746 .916 r
.63139 .56674 .63742 .57354 .64962 .57004 .64362 .56314 Mtetra
.656 .744 .914 r
.64362 .56314 .64962 .57004 .66187 .56658 .6559 .55952 Mtetra
.657 .74 .911 r
.6559 .55952 .66187 .56658 .67419 .56316 .66824 .55588 Mtetra
.656 .734 .907 r
.66824 .55588 .67419 .56316 .68655 .55976 .68063 .55225 Mtetra
.654 .727 .903 r
.68063 .55225 .68655 .55976 .69897 .55634 .69308 .54868 Mtetra
.65 .723 .901 r
.69308 .54868 .69897 .55634 .71145 .55286 .70559 .54521 Mtetra
.646 .722 .903 r
.70559 .54521 .71145 .55286 .72398 .54935 .71817 .54185 Mtetra
.644 .727 .909 r
.71817 .54185 .72398 .54935 .73658 .5459 .73081 .53854 Mtetra
.644 .732 .912 r
.73081 .53854 .73658 .5459 .74925 .54271 .74351 .53519 Mtetra
.643 .727 .91 r
.74351 .53519 .74925 .54271 .762 .53989 .75626 .53188 Mtetra
.634 .711 .902 r
.75626 .53188 .762 .53989 .77485 .53743 .76911 .52887 Mtetra
.617 .689 .895 r
.76911 .52887 .77485 .53743 .78781 .53552 .78206 .52645 Mtetra
.595 .667 .889 r
.78206 .52645 .78781 .53552 .8009 .5343 .79514 .52478 Mtetra
.573 .646 .885 r
.79514 .52478 .8009 .5343 .81403 .53272 .80837 .52388 Mtetra
.579 .667 .899 r
.80837 .52388 .81403 .53272 .82703 .52873 .82165 .52264 Mtetra
.654 .784 .943 r
.82165 .52264 .82703 .52873 .8398 .52172 .83476 .51869 Mtetra
.75 .925 .948 r
.83476 .51869 .8398 .52172 .8525 .51361 .84759 .51127 Mtetra
.778 .954 .929 r
.84759 .51127 .8525 .51361 .86533 .50659 .86033 .50267 Mtetra
.751 .896 .943 r
.86033 .50267 .86533 .50659 .87838 .50118 .87324 .49541 Mtetra
.7 .815 .937 r
.87324 .49541 .87838 .50118 .89158 .49679 .88639 .48998 Mtetra
.669 .77 .926 r
.88639 .48998 .89158 .49679 .90488 .49277 .8997 .48559 Mtetra
.658 .755 .921 r
.8997 .48559 .90488 .49277 .91826 .48882 .91311 .48154 Mtetra
.656 .752 .92 r
.91311 .48154 .91826 .48882 .9317 .48488 .92659 .47756 Mtetra
.656 .751 .92 r
.92659 .47756 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Mtetra
.654 .751 .921 r
.3463 .64063 .35314 .64665 .36418 .6434 .35737 .63741 Mtetra
.644 .75 .926 r
.35737 .63741 .36418 .6434 .37526 .64022 .36847 .63443 Mtetra
.604 .746 .945 r
.36847 .63443 .37526 .64022 .38638 .63737 .37957 .63233 Mtetra
.478 .729 .981 r
.37957 .63233 .38638 .63737 .3975 .63551 .39067 .63206 Mtetra
.194 .646 .943 r
.39067 .63206 .3975 .63551 .40862 .63539 .40176 .63358 Mtetra
.109 .64 .869 r
.40176 .63358 .40862 .63539 .41977 .63657 .41296 .63438 Mtetra
.548 .866 .995 r
.41296 .63438 .41977 .63657 .43103 .6366 .42433 .63155 Mtetra
.74 .805 .904 r
.42433 .63155 .43103 .6366 .44244 .63329 .43585 .62544 Mtetra
.735 .727 .843 r
.43585 .62544 .44244 .63329 .45395 .62739 .4474 .61868 Mtetra
.712 .702 .84 r
.4474 .61868 .45395 .62739 .46549 .62118 .45897 .61282 Mtetra
.692 .705 .857 r
.45897 .61282 .46549 .62118 .47706 .61572 .47055 .60797 Mtetra
.679 .716 .877 r
.47055 .60797 .47706 .61572 .48865 .61101 .48217 .60375 Mtetra
.674 .729 .891 r
.48217 .60375 .48865 .61101 .50027 .60687 .49382 .59973 Mtetra
.67 .732 .896 r
.49382 .59973 .50027 .60687 .51195 .60304 .50553 .59582 Mtetra
.665 .729 .898 r
.50553 .59582 .51195 .60304 .52366 .59924 .51727 .59209 Mtetra
.659 .73 .902 r
.51727 .59209 .52366 .59924 .53543 .59541 .52907 .58851 Mtetra
.657 .738 .909 r
.52907 .58851 .53543 .59541 .54724 .59162 .54092 .58499 Mtetra
.658 .747 .916 r
.54092 .58499 .54724 .59162 .55911 .58795 .55282 .58141 Mtetra
.659 .751 .918 r
.55282 .58141 .55911 .58795 .57102 .58438 .56477 .57776 Mtetra
.66 .75 .916 r
.56477 .57776 .57102 .58438 .58299 .58087 .57676 .57408 Mtetra
.66 .745 .913 r
.57676 .57408 .58299 .58087 .59501 .57737 .58882 .5704 Mtetra
.659 .741 .91 r
.58882 .5704 .59501 .57737 .60708 .57385 .60092 .56675 Mtetra
.657 .737 .908 r
.60092 .56675 .60708 .57385 .61921 .57031 .61308 .56312 Mtetra
.656 .735 .908 r
.61308 .56312 .61921 .57031 .63139 .56674 .62529 .55952 Mtetra
.655 .734 .908 r
.62529 .55952 .63139 .56674 .64362 .56314 .63755 .55595 Mtetra
.653 .735 .91 r
.63755 .55595 .64362 .56314 .6559 .55952 .64988 .55241 Mtetra
.652 .738 .913 r
.64988 .55241 .6559 .55952 .66824 .55588 .66225 .5489 Mtetra
.651 .743 .917 r
.66225 .5489 .66824 .55588 .68063 .55225 .67469 .54538 Mtetra
.651 .747 .92 r
.67469 .54538 .68063 .55225 .69308 .54868 .68718 .54183 Mtetra
.653 .749 .921 r
.68718 .54183 .69308 .54868 .70559 .54521 .69972 .53821 Mtetra
.654 .746 .917 r
.69972 .53821 .70559 .54521 .71817 .54185 .71232 .53454 Mtetra
.653 .737 .911 r
.71232 .53454 .71817 .54185 .73081 .53854 .72498 .53091 Mtetra
.648 .727 .906 r
.72498 .53091 .73081 .53854 .74351 .53519 .73771 .52744 Mtetra
.642 .722 .906 r
.73771 .52744 .74351 .53519 .75626 .53188 .75051 .52415 Mtetra
.638 .722 .909 r
.75051 .52415 .75626 .53188 .76911 .52887 .76338 .52096 Mtetra
.631 .715 .907 r
.76338 .52096 .76911 .52887 .78206 .52645 .77632 .51798 Mtetra
.612 .692 .9 r
.77632 .51798 .78206 .52645 .79514 .52478 .78939 .51564 Mtetra
.582 .662 .892 r
.78939 .51564 .79514 .52478 .80837 .52388 .80261 .51433 Mtetra
.555 .639 .889 r
.80261 .51433 .80837 .52388 .82165 .52264 .81599 .51393 Mtetra
.571 .669 .905 r
.81599 .51393 .82165 .52264 .83476 .51869 .8294 .51284 Mtetra
.671 .801 .945 r
.8294 .51284 .83476 .51869 .84759 .51127 .84257 .50831 Mtetra
.775 .934 .935 r
.84257 .50831 .84759 .51127 .86033 .50267 .85541 .50001 Mtetra
.792 .948 .923 r
.85541 .50001 .86033 .50267 .87324 .49541 .86821 .49097 Mtetra
.749 .88 .939 r
.86821 .49097 .87324 .49541 .88639 .48998 .88123 .4838 Mtetra
.693 .802 .932 r
.88123 .4838 .88639 .48998 .8997 .48559 .8945 .47856 Mtetra
.665 .764 .924 r
.8945 .47856 .8997 .48559 .91311 .48154 .90793 .47424 Mtetra
.657 .754 .921 r
.90793 .47424 .91311 .48154 .92659 .47756 .92145 .47017 Mtetra
.656 .752 .92 r
.92145 .47017 .92659 .47756 .94014 .47356 .93504 .46614 Mtetra
.655 .751 .921 r
.32836 .63786 .33528 .64389 .3463 .64063 .33941 .63459 Mtetra
.649 .75 .924 r
.33941 .63459 .3463 .64063 .35737 .63741 .35049 .63146 Mtetra
.622 .747 .936 r
.35049 .63146 .35737 .63741 .36847 .63443 .3616 .62899 Mtetra
.522 .733 .97 r
.3616 .62899 .36847 .63443 .37957 .63233 .37267 .62824 Mtetra
.244 .653 .962 r
.37267 .62824 .37957 .63233 .39067 .63206 .38372 .62979 Mtetra
.01 .558 .831 r
.38372 .62979 .39067 .63206 .40176 .63358 .39483 .63167 Mtetra
.411 .818 .979 r
.39483 .63167 .40176 .63358 .41296 .63438 .40614 .63011 Mtetra
.736 .832 .924 r
.40614 .63011 .41296 .63438 .42433 .63155 .41765 .6242 Mtetra
.751 .742 .844 r
.41765 .6242 .42433 .63155 .43585 .62544 .42923 .61677 Mtetra
.724 .707 .834 r
.42923 .61677 .43585 .62544 .4474 .61868 .44081 .61025 Mtetra
.7 .706 .853 r
.44081 .61025 .4474 .61868 .45897 .61282 .45239 .60503 Mtetra
.684 .718 .875 r
.45239 .60503 .45897 .61282 .47055 .60797 .464 .60059 Mtetra
.675 .727 .889 r
.464 .60059 .47055 .60797 .48217 .60375 .47564 .5965 Mtetra
.667 .729 .896 r
.47564 .5965 .48217 .60375 .49382 .59973 .48732 .59267 Mtetra
.662 .734 .903 r
.48732 .59267 .49382 .59973 .50553 .59582 .49905 .589 Mtetra
.663 .742 .909 r
.49905 .589 .50553 .59582 .51727 .59209 .51083 .5853 Mtetra
.664 .744 .91 r
.51083 .5853 .51727 .59209 .52907 .58851 .52266 .58153 Mtetra
.663 .739 .906 r
.52266 .58153 .52907 .58851 .54092 .58499 .53454 .57778 Mtetra
.66 .732 .903 r
.53454 .57778 .54092 .58499 .55282 .58141 .54647 .57411 Mtetra
.657 .729 .902 r
.54647 .57411 .55282 .58141 .56477 .57776 .55845 .57052 Mtetra
.655 .731 .905 r
.55845 .57052 .56477 .57776 .57676 .57408 .57049 .56698 Mtetra
.654 .736 .909 r
.57049 .56698 .57676 .57408 .58882 .5704 .58257 .56344 Mtetra
.654 .741 .913 r
.58257 .56344 .58882 .5704 .60092 .56675 .59471 .55989 Mtetra
.655 .745 .916 r
.59471 .55989 .60092 .56675 .61308 .56312 .60691 .5563 Mtetra
.655 .747 .917 r
.60691 .5563 .61308 .56312 .62529 .55952 .61915 .55267 Mtetra
.656 .747 .917 r
.61915 .55267 .62529 .55952 .63755 .55595 .63145 .54901 Mtetra
.657 .746 .916 r
.63145 .54901 .63755 .55595 .64988 .55241 .64381 .54531 Mtetra
.657 .742 .913 r
.64381 .54531 .64988 .55241 .66225 .5489 .65622 .54159 Mtetra
.657 .737 .909 r
.65622 .54159 .66225 .5489 .67469 .54538 .66868 .53788 Mtetra
.655 .731 .906 r
.66868 .53788 .67469 .54538 .68718 .54183 .6812 .53421 Mtetra
.652 .728 .905 r
.6812 .53421 .68718 .54183 .69972 .53821 .69378 .53063 Mtetra
.649 .728 .907 r
.69378 .53063 .69972 .53821 .71232 .53454 .70643 .52713 Mtetra
.647 .734 .912 r
.70643 .52713 .71232 .53454 .72498 .53091 .71913 .52364 Mtetra
.649 .74 .916 r
.71913 .52364 .72498 .53091 .73771 .52744 .7319 .52008 Mtetra
.649 .738 .914 r
.7319 .52008 .73771 .52744 .75051 .52415 .74471 .51649 Mtetra
.645 .728 .909 r
.74471 .51649 .75051 .52415 .76338 .52096 .7576 .51305 Mtetra
.636 .719 .907 r
.7576 .51305 .76338 .52096 .77632 .51798 .77058 .50988 Mtetra
.625 .709 .907 r
.77058 .50988 .77632 .51798 .78939 .51564 .78364 .50707 Mtetra
.601 .687 .902 r
.78364 .50707 .78939 .51564 .80261 .51433 .79684 .50505 Mtetra
.561 .65 .895 r
.79684 .50505 .80261 .51433 .81599 .51393 .81023 .50436 Mtetra
.532 .629 .893 r
.81023 .50436 .81599 .51393 .8294 .51284 .82379 .50458 Mtetra
.575 .686 .916 r
.82379 .50458 .8294 .51284 .84257 .50831 .83729 .5032 Mtetra
.712 .844 .945 r
.83729 .5032 .84257 .50831 .85541 .50001 .85043 .49728 Mtetra
.805 .948 .916 r
.85043 .49728 .85541 .50001 .86821 .49097 .86325 .48777 Mtetra
.798 .933 .921 r
.86325 .48777 .86821 .49097 .88123 .4838 .87613 .47862 Mtetra
.735 .852 .935 r
.87613 .47862 .88123 .4838 .8945 .47856 .8893 .4719 Mtetra
.682 .785 .928 r
.8893 .4719 .8945 .47856 .90793 .47424 .90271 .46698 Mtetra
.661 .759 .922 r
.90271 .46698 .90793 .47424 .92145 .47017 .91626 .46274 Mtetra
.656 .752 .921 r
.91626 .46274 .92145 .47017 .93504 .46614 .9299 .45866 Mtetra
.653 .751 .922 r
.32139 .63178 .32836 .63786 .33941 .63459 .33246 .62854 Mtetra
.638 .749 .929 r
.33246 .62854 .33941 .63459 .35049 .63146 .34356 .62568 Mtetra
.573 .739 .955 r
.34356 .62568 .35049 .63146 .3616 .62899 .35464 .62416 Mtetra
.352 .683 .979 r
.35464 .62416 .3616 .62899 .37267 .62824 .36566 .62518 Mtetra
0 .509 .83 r
.36566 .62518 .37267 .62824 .38372 .62979 .37668 .62798 Mtetra
.14 .662 .883 r
.37668 .62798 .38372 .62979 .39483 .63167 .38788 .62851 Mtetra
.69 .867 .966 r
.38788 .62851 .39483 .63167 .40614 .63011 .39934 .62375 Mtetra
.769 .77 .854 r
.39934 .62375 .40614 .63011 .41765 .6242 .41095 .61576 Mtetra
.744 .718 .827 r
.41095 .61576 .41765 .6242 .42923 .61677 .42257 .60819 Mtetra
.713 .707 .843 r
.42257 .60819 .42923 .61677 .44081 .61025 .43416 .60226 Mtetra
.69 .715 .868 r
.43416 .60226 .44081 .61025 .45239 .60503 .44576 .59751 Mtetra
.676 .724 .886 r
.44576 .59751 .45239 .60503 .464 .60059 .45739 .59336 Mtetra
.668 .731 .896 r
.45739 .59336 .464 .60059 .47564 .5965 .46906 .58949 Mtetra
.666 .737 .903 r
.46906 .58949 .47564 .5965 .48732 .59267 .48077 .58567 Mtetra
.665 .738 .904 r
.48077 .58567 .48732 .59267 .49905 .589 .49254 .58187 Mtetra
.661 .734 .904 r
.49254 .58187 .49905 .589 .51083 .5853 .50435 .5782 Mtetra
.656 .734 .907 r
.50435 .5782 .51083 .5853 .52266 .58153 .51621 .57466 Mtetra
.655 .741 .913 r
.51621 .57466 .52266 .58153 .53454 .57778 .52812 .57115 Mtetra
.656 .75 .919 r
.52812 .57115 .53454 .57778 .54647 .57411 .54008 .56757 Mtetra
.658 .754 .921 r
.54008 .56757 .54647 .57411 .55845 .57052 .5521 .56391 Mtetra
.659 .753 .92 r
.5521 .56391 .55845 .57052 .57049 .56698 .56416 .5602 Mtetra
.659 .749 .916 r
.56416 .5602 .57049 .56698 .58257 .56344 .57628 .55648 Mtetra
.658 .744 .913 r
.57628 .55648 .58257 .56344 .59471 .55989 .58846 .55277 Mtetra
.657 .74 .911 r
.58846 .55277 .59471 .55989 .60691 .5563 .60068 .54909 Mtetra
.656 .738 .91 r
.60068 .54909 .60691 .5563 .61915 .55267 .61296 .54544 Mtetra
.654 .737 .91 r
.61296 .54544 .61915 .55267 .63145 .54901 .6253 .54181 Mtetra
.653 .739 .912 r
.6253 .54181 .63145 .54901 .64381 .54531 .63769 .53821 Mtetra
.652 .742 .915 r
.63769 .53821 .64381 .54531 .65622 .54159 .65014 .53462 Mtetra
.651 .747 .919 r
.65014 .53462 .65622 .54159 .66868 .53788 .66265 .53102 Mtetra
.652 .751 .922 r
.66265 .53102 .66868 .53788 .6812 .53421 .67521 .52736 Mtetra
.654 .753 .923 r
.67521 .52736 .6812 .53421 .69378 .53063 .68783 .52363 Mtetra
.656 .75 .919 r
.68783 .52363 .69378 .53063 .70643 .52713 .7005 .51982 Mtetra
.655 .742 .913 r
.7005 .51982 .70643 .52713 .71913 .52364 .71322 .51605 Mtetra
.651 .732 .909 r
.71322 .51605 .71913 .52364 .7319 .52008 .72602 .5124 Mtetra
.647 .729 .909 r
.72602 .5124 .7319 .52008 .74471 .51649 .73888 .50888 Mtetra
.645 .732 .912 r
.73888 .50888 .74471 .51649 .7576 .51305 .75181 .50538 Mtetra
.643 .73 .912 r
.75181 .50538 .7576 .51305 .77058 .50988 .7648 .50193 Mtetra
.634 .719 .909 r
.7648 .50193 .77058 .50988 .78364 .50707 .77788 .49877 Mtetra
.616 .702 .906 r
.77788 .49877 .78364 .50707 .79684 .50505 .79107 .4962 Mtetra
.578 .672 .903 r
.79107 .4962 .79684 .50505 .81023 .50436 .80444 .49485 Mtetra
.525 .629 .896 r
.80444 .49485 .81023 .50436 .82379 .50458 .81803 .49518 Mtetra
.509 .624 .9 r
.81803 .49518 .82379 .50458 .83729 .5032 .83177 .49591 Mtetra
.61 .734 .933 r
.83177 .49591 .83729 .5032 .85043 .49728 .84527 .49325 Mtetra
.775 .901 .931 r
.84527 .49325 .85043 .49728 .86325 .48777 .8583 .48506 Mtetra
.829 .952 .898 r
.8583 .48506 .86325 .48777 .87613 .47862 .8711 .47451 Mtetra
.786 .904 .923 r
.8711 .47451 .87613 .47862 .8893 .4719 .88412 .46585 Mtetra
.712 .818 .931 r
.88412 .46585 .8893 .4719 .90271 .46698 .89747 .45988 Mtetra
.67 .769 .924 r
.89747 .45988 .90271 .46698 .91626 .46274 .91104 .4553 Mtetra
.658 .754 .921 r
.91104 .4553 .91626 .46274 .9299 .45866 .92471 .45112 Mtetra
.649 .751 .924 r
.31435 .62569 .32139 .63178 .33246 .62854 .32545 .62252 Mtetra
.614 .745 .939 r
.32545 .62252 .33246 .62854 .34356 .62568 .33655 .62018 Mtetra
.478 .716 .975 r
.33655 .62018 .34356 .62568 .35464 .62416 .34758 .62005 Mtetra
.076 .551 .9 r
.34758 .62005 .35464 .62416 .36566 .62518 .35854 .62289 Mtetra
0 .441 .733 r
.35854 .62289 .36566 .62518 .37668 .62798 .36958 .62582 Mtetra
.48 .842 .992 r
.36958 .62582 .37668 .62798 .38788 .62851 .38093 .62371 Mtetra
.777 .816 .884 r
.38093 .62371 .38788 .62851 .39934 .62375 .39254 .61599 Mtetra
.771 .738 .822 r
.39254 .61599 .39934 .62375 .41095 .61576 .40422 .60703 Mtetra
.735 .711 .828 r
.40422 .60703 .41095 .61576 .42257 .60819 .41585 .59988 Mtetra
.702 .712 .856 r
.41585 .59988 .42257 .60819 .43416 .60226 .42746 .59456 Mtetra
.681 .721 .88 r
.42746 .59456 .43416 .60226 .44576 .59751 .43908 .5902 Mtetra
.671 .73 .894 r
.43908 .5902 .44576 .59751 .45739 .59336 .45073 .58621 Mtetra
.667 .734 .9 r
.45073 .58621 .45739 .59336 .46906 .58949 .46243 .58236 Mtetra
.661 .734 .903 r
.46243 .58236 .46906 .58949 .48077 .58567 .47417 .57867 Mtetra
.658 .737 .908 r
.47417 .57867 .48077 .58567 .49254 .58187 .48596 .57508 Mtetra
.659 .745 .913 r
.48596 .57508 .49254 .58187 .50435 .5782 .49781 .57142 Mtetra
.662 .747 .913 r
.49781 .57142 .50435 .5782 .51621 .57466 .5097 .56765 Mtetra
.662 .741 .908 r
.5097 .56765 .51621 .57466 .52812 .57115 .52164 .56387 Mtetra
.659 .733 .904 r
.52164 .56387 .52812 .57115 .54008 .56757 .53364 .56017 Mtetra
.656 .729 .903 r
.53364 .56017 .54008 .56757 .5521 .56391 .54569 .55656 Mtetra
.654 .731 .906 r
.54569 .55656 .5521 .56391 .56416 .5602 .55779 .55299 Mtetra
.653 .736 .91 r
.55779 .55299 .56416 .5602 .57628 .55648 .56994 .54943 Mtetra
.654 .741 .914 r
.56994 .54943 .57628 .55648 .58846 .55277 .58215 .54584 Mtetra
.654 .746 .917 r
.58215 .54584 .58846 .55277 .60068 .54909 .59442 .5422 Mtetra
.655 .748 .918 r
.59442 .5422 .60068 .54909 .61296 .54544 .60673 .53852 Mtetra
.656 .749 .918 r
.60673 .53852 .61296 .54544 .6253 .54181 .6191 .53479 Mtetra
.657 .747 .916 r
.6191 .53479 .6253 .54181 .63769 .53821 .63153 .53101 Mtetra
.658 .743 .913 r
.63153 .53101 .63769 .53821 .65014 .53462 .64401 .5272 Mtetra
.657 .737 .909 r
.64401 .5272 .65014 .53462 .66265 .53102 .65654 .5234 Mtetra
.655 .732 .905 r
.65654 .5234 .66265 .53102 .67521 .52736 .66914 .51964 Mtetra
.652 .728 .905 r
.66914 .51964 .67521 .52736 .68783 .52363 .68179 .51597 Mtetra
.649 .73 .908 r
.68179 .51597 .68783 .52363 .7005 .51982 .69451 .51238 Mtetra
.649 .737 .914 r
.69451 .51238 .7005 .51982 .71322 .51605 .70729 .50877 Mtetra
.652 .744 .917 r
.70729 .50877 .71322 .51605 .72602 .5124 .72012 .50505 Mtetra
.653 .743 .916 r
.72012 .50505 .72602 .5124 .73888 .50888 .73301 .50127 Mtetra
.65 .735 .911 r
.73301 .50127 .73888 .50888 .75181 .50538 .74596 .49758 Mtetra
.645 .729 .91 r
.74596 .49758 .75181 .50538 .7648 .50193 .75899 .49405 Mtetra
.64 .725 .91 r
.75899 .49405 .7648 .50193 .77788 .49877 .77209 .49066 Mtetra
.628 .715 .909 r
.77209 .49066 .77788 .49877 .79107 .4962 .78528 .48764 Mtetra
.598 .69 .907 r
.78528 .48764 .79107 .4962 .80444 .49485 .79863 .48561 Mtetra
.538 .644 .902 r
.79863 .48561 .80444 .49485 .81803 .49518 .81222 .48546 Mtetra
.475 .6 .897 r
.81222 .48546 .81803 .49518 .83177 .49591 .82607 .48715 Mtetra
.512 .645 .916 r
.82607 .48715 .83177 .49591 .84527 .49325 .8399 .48752 Mtetra
.697 .823 .942 r
.8399 .48752 .84527 .49325 .8583 .48506 .85325 .482 Mtetra
.834 .942 .895 r
.85325 .482 .8583 .48506 .8711 .47451 .86611 .47122 Mtetra
.832 .936 .896 r
.86611 .47122 .8711 .47451 .88412 .46585 .87899 .46057 Mtetra
.755 .859 .926 r
.87899 .46057 .88412 .46585 .89747 .45988 .89223 .45305 Mtetra
.687 .787 .926 r
.89223 .45305 .89747 .45988 .91104 .4553 .90578 .44787 Mtetra
.661 .758 .922 r
.90578 .44787 .91104 .4553 .92471 .45112 .91948 .44355 Mtetra
.642 .75 .928 r
.30727 .61958 .31435 .62569 .32545 .62252 .31838 .61658 Mtetra
.573 .736 .953 r
.31838 .61658 .32545 .62252 .33655 .62018 .32945 .61505 Mtetra
.306 .651 .97 r
.32945 .61505 .33655 .62018 .34758 .62005 .34042 .61664 Mtetra
0 .364 .722 r
.34042 .61664 .34758 .62005 .35854 .62289 .35133 .62096 Mtetra
0 .53 .786 r
.35133 .62096 .35854 .62289 .36958 .62582 .36245 .62283 Mtetra
.711 .877 .959 r
.36245 .62283 .36958 .62582 .38093 .62371 .37398 .61749 Mtetra
.8 .776 .831 r
.37398 .61749 .38093 .62371 .39254 .61599 .38572 .60751 Mtetra
.767 .723 .812 r
.38572 .60751 .39254 .61599 .40422 .60703 .39744 .59836 Mtetra
.724 .71 .837 r
.39744 .59836 .40422 .60703 .41585 .59988 .40908 .59183 Mtetra
.691 .716 .868 r
.40908 .59183 .41585 .59988 .42746 .59456 .4207 .58702 Mtetra
.674 .725 .888 r
.4207 .58702 .42746 .59456 .43908 .5902 .43234 .58292 Mtetra
.666 .73 .898 r
.43234 .58292 .43908 .5902 .45073 .58621 .44402 .57909 Mtetra
.661 .735 .904 r
.44402 .57909 .45073 .58621 .46243 .58236 .45574 .57539 Mtetra
.662 .74 .908 r
.45574 .57539 .46243 .58236 .47417 .57867 .46752 .57166 Mtetra
.662 .74 .907 r
.46752 .57166 .47417 .57867 .48596 .57508 .47934 .5679 Mtetra
.658 .735 .906 r
.47934 .5679 .48596 .57508 .49781 .57142 .49122 .56426 Mtetra
.653 .735 .909 r
.49122 .56426 .49781 .57142 .5097 .56765 .50314 .56075 Mtetra
.652 .742 .916 r
.50314 .56075 .5097 .56765 .52164 .56387 .51512 .55726 Mtetra
.653 .753 .923 r
.51512 .55726 .52164 .56387 .53364 .56017 .52715 .55369 Mtetra
.656 .758 .925 r
.52715 .55369 .53364 .56017 .54569 .55656 .53923 .55 Mtetra
.658 .758 .923 r
.53923 .55 .54569 .55656 .55779 .55299 .55136 .54624 Mtetra
.659 .753 .919 r
.55136 .54624 .55779 .55299 .56994 .54943 .56355 .54245 Mtetra
.658 .747 .915 r
.56355 .54245 .56994 .54943 .58215 .54584 .57579 .53868 Mtetra
.657 .742 .912 r
.57579 .53868 .58215 .54584 .59442 .5422 .58809 .53493 Mtetra
.656 .739 .911 r
.58809 .53493 .59442 .5422 .60673 .53852 .60044 .53122 Mtetra
.654 .738 .912 r
.60044 .53122 .60673 .53852 .6191 .53479 .61285 .52754 Mtetra
.652 .74 .914 r
.61285 .52754 .6191 .53479 .63153 .53101 .62532 .52389 Mtetra
.651 .745 .918 r
.62532 .52389 .63153 .53101 .64401 .5272 .63784 .52025 Mtetra
.651 .751 .922 r
.63784 .52025 .64401 .5272 .65654 .5234 .65042 .51658 Mtetra
.653 .756 .926 r
.65042 .51658 .65654 .5234 .66914 .51964 .66305 .51283 Mtetra
.656 .759 .925 r
.66305 .51283 .66914 .51964 .68179 .51597 .67574 .50897 Mtetra
.659 .755 .921 r
.67574 .50897 .68179 .51597 .69451 .51238 .68848 .50503 Mtetra
.658 .745 .914 r
.68848 .50503 .69451 .51238 .70729 .50877 .70128 .5011 Mtetra
.653 .735 .909 r
.70128 .5011 .70729 .50877 .72012 .50505 .71415 .49731 Mtetra
.649 .732 .91 r
.71415 .49731 .72012 .50505 .73301 .50127 .72709 .49363 Mtetra
.65 .736 .913 r
.72709 .49363 .73301 .50127 .74596 .49758 .74008 .48993 Mtetra
.65 .737 .913 r
.74008 .48993 .74596 .49758 .75899 .49405 .75313 .48618 Mtetra
.646 .73 .91 r
.75313 .48618 .75899 .49405 .77209 .49066 .76626 .48257 Mtetra
.637 .721 .909 r
.76626 .48257 .77209 .49066 .78528 .48764 .77947 .47924 Mtetra
.615 .704 .908 r
.77947 .47924 .78528 .48764 .79863 .48561 .79281 .47663 Mtetra
.558 .662 .906 r
.79281 .47663 .79863 .48561 .81222 .48546 .80637 .47578 Mtetra
.466 .597 .899 r
.80637 .47578 .81222 .48546 .82607 .48715 .82026 .47763 Mtetra
.43 .582 .903 r
.82026 .47763 .82607 .48715 .8399 .48752 .83434 .48029 Mtetra
.589 .732 .942 r
.83434 .48029 .8399 .48752 .85325 .482 .84807 .47808 Mtetra
.811 .914 .909 r
.84807 .47808 .85325 .482 .86611 .47122 .8611 .46831 Mtetra
.863 .947 .869 r
.8611 .46831 .86611 .47122 .87899 .46057 .87389 .45601 Mtetra
.802 .895 .909 r
.87389 .45601 .87899 .46057 .89223 .45305 .88698 .44661 Mtetra
.713 .81 .925 r
.88698 .44661 .89223 .45305 .90578 .44787 .90048 .44051 Mtetra
.667 .765 .923 r
.90048 .44051 .90578 .44787 .91948 .44355 .91422 .43595 Mtetra
.63 .749 .933 r
.30012 .6135 .30727 .61958 .31838 .61658 .31124 .61075 Mtetra
.505 .717 .967 r
.31124 .61075 .31838 .61658 .32945 .61505 .32228 .6103 Mtetra
.046 .511 .888 r
.32228 .6103 .32945 .61505 .34042 .61664 .33316 .61379 Mtetra
.367 0 0 r
.33316 .61379 .34042 .61664 .35133 .62096 .34404 .61904 Mtetra
.234 .721 .925 r
.34404 .61904 .35133 .62096 .36245 .62283 .3553 .6189 Mtetra
.8 .844 .884 r
.3553 .6189 .36245 .62283 .37398 .61749 .36701 .61025 Mtetra
.807 .754 .803 r
.36701 .61025 .37398 .61749 .38572 .60751 .37886 .59871 Mtetra
.761 .717 .811 r
.37886 .59871 .38572 .60751 .39744 .59836 .39061 .58981 Mtetra
.712 .711 .847 r
.39061 .58981 .39744 .59836 .40908 .59183 .40226 .58393 Mtetra
.68 .718 .878 r
.40226 .58393 .40908 .59183 .4207 .58702 .41389 .57956 Mtetra
.666 .727 .894 r
.41389 .57956 .4207 .58702 .43234 .58292 .42555 .57569 Mtetra
.662 .733 .902 r
.42555 .57569 .43234 .58292 .44402 .57909 .43726 .57195 Mtetra
.661 .735 .905 r
.43726 .57195 .44402 .57909 .45574 .57539 .44901 .56824 Mtetra
.657 .735 .907 r
.44901 .56824 .45574 .57539 .46752 .57166 .46081 .56464 Mtetra
.654 .739 .912 r
.46081 .56464 .46752 .57166 .47934 .5679 .47266 .56111 Mtetra
.657 .747 .916 r
.47266 .56111 .47934 .5679 .49122 .56426 .48457 .55745 Mtetra
.662 .749 .915 r
.48457 .55745 .49122 .56426 .50314 .56075 .49653 .55364 Mtetra
.663 .741 .908 r
.49653 .55364 .50314 .56075 .51512 .55726 .50854 .54979 Mtetra
.66 .731 .902 r
.50854 .54979 .51512 .55726 .52715 .55369 .5206 .54602 Mtetra
.655 .725 .9 r
.5206 .54602 .52715 .55369 .53923 .55 .53272 .54237 Mtetra
.653 .726 .903 r
.53272 .54237 .53923 .55 .55136 .54624 .54489 .5388 Mtetra
.652 .732 .908 r
.54489 .5388 .55136 .54624 .56355 .54245 .55711 .53523 Mtetra
.652 .739 .913 r
.55711 .53523 .56355 .54245 .57579 .53868 .56939 .53163 Mtetra
.653 .746 .917 r
.56939 .53163 .57579 .53868 .58809 .53493 .58172 .52796 Mtetra
.655 .749 .919 r
.58172 .52796 .58809 .53493 .60044 .53122 .59411 .52421 Mtetra
.657 .75 .918 r
.59411 .52421 .60044 .53122 .61285 .52754 .60655 .52039 Mtetra
.659 .747 .915 r
.60655 .52039 .61285 .52754 .62532 .52389 .61905 .51651 Mtetra
.66 .742 .911 r
.61905 .51651 .62532 .52389 .63784 .52025 .6316 .51258 Mtetra
.659 .734 .905 r
.6316 .51258 .63784 .52025 .65042 .51658 .64421 .50867 Mtetra
.656 .727 .901 r
.64421 .50867 .65042 .51658 .66305 .51283 .65688 .50483 Mtetra
.652 .724 .902 r
.65688 .50483 .66305 .51283 .67574 .50897 .66961 .50111 Mtetra
.649 .728 .906 r
.66961 .50111 .67574 .50897 .68848 .50503 .6824 .49748 Mtetra
.649 .738 .914 r
.6824 .49748 .68848 .50503 .70128 .5011 .69526 .49379 Mtetra
.653 .747 .919 r
.69526 .49379 .70128 .5011 .71415 .49731 .70816 .48995 Mtetra
.657 .748 .917 r
.70816 .48995 .71415 .49731 .72709 .49363 .72112 .48598 Mtetra
.655 .739 .912 r
.72112 .48598 .72709 .49363 .74008 .48993 .73414 .48208 Mtetra
.651 .733 .91 r
.73414 .48208 .74008 .48993 .75313 .48618 .74723 .47829 Mtetra
.649 .732 .91 r
.74723 .47829 .75313 .48618 .76626 .48257 .76039 .47454 Mtetra
.645 .728 .909 r
.76039 .47454 .76626 .48257 .77947 .47924 .77362 .47091 Mtetra
.629 .714 .907 r
.77362 .47091 .77947 .47924 .79281 .47663 .78696 .46779 Mtetra
.581 .679 .908 r
.78696 .46779 .79281 .47663 .80637 .47578 .80049 .46621 Mtetra
.474 .606 .903 r
.80049 .46621 .80637 .47578 .82026 .47763 .81439 .46776 Mtetra
.367 .539 .893 r
.81439 .46776 .82026 .47763 .83434 .48029 .82865 .472 Mtetra
.465 .639 .931 r
.82865 .472 .83434 .48029 .84807 .47808 .84274 .47317 Mtetra
.759 .874 .93 r
.84274 .47317 .84807 .47808 .8611 .46831 .85605 .46541 Mtetra
.88 .946 .851 r
.85605 .46541 .8611 .46831 .87389 .45601 .8688 .45204 Mtetra
.846 .918 .881 r
.8688 .45204 .87389 .45601 .88698 .44661 .88174 .44056 Mtetra
.746 .835 .92 r
.88174 .44056 .88698 .44661 .90048 .44051 .89516 .43324 Mtetra
.676 .773 .924 r
.89516 .43324 .90048 .44051 .91422 .43595 .90891 .42835 Mtetra
.614 .747 .94 r
.29291 .60743 .30012 .6135 .31124 .61075 .30404 .60502 Mtetra
.399 .678 .973 r
.30404 .60502 .31124 .61075 .32228 .6103 .31501 .60589 Mtetra
0 .303 .708 r
.31501 .60589 .32228 .6103 .33316 .61379 .3258 .61132 Mtetra
.437 0 0 r
.3258 .61132 .33316 .61379 .34404 .61904 .33669 .61696 Mtetra
.53 .865 .993 r
.33669 .61696 .34404 .61904 .3553 .6189 .34811 .61418 Mtetra
.836 .813 .827 r
.34811 .61418 .3553 .6189 .36701 .61025 .36003 .60235 Mtetra
.811 .741 .787 r
.36003 .60235 .36701 .61025 .37886 .59871 .37197 .58977 Mtetra
.753 .713 .815 r
.37197 .58977 .37886 .59871 .39061 .58981 .38372 .58135 Mtetra
.698 .71 .858 r
.38372 .58135 .39061 .58981 .40226 .58393 .39537 .57613 Mtetra
.669 .719 .886 r
.39537 .57613 .40226 .58393 .41389 .57956 .40702 .57213 Mtetra
.661 .727 .899 r
.40702 .57213 .41389 .57956 .42555 .57569 .41871 .56843 Mtetra
.657 .732 .904 r
.41871 .56843 .42555 .57569 .43726 .57195 .43044 .56482 Mtetra
.656 .736 .909 r
.43044 .56482 .43726 .57195 .44901 .56824 .44222 .56123 Mtetra
.659 .741 .911 r
.44222 .56123 .44901 .56824 .46081 .56464 .45405 .55753 Mtetra
.661 .74 .909 r
.45405 .55753 .46081 .56464 .47266 .56111 .46594 .55377 Mtetra
.656 .732 .906 r
.46594 .55377 .47266 .56111 .48457 .55745 .47788 .55014 Mtetra
.65 .732 .909 r
.47788 .55014 .48457 .55745 .49653 .55364 .48987 .54668 Mtetra
.648 .743 .918 r
.48987 .54668 .49653 .55364 .50854 .54979 .50191 .54322 Mtetra
.653 .757 .926 r
.50191 .54322 .50854 .54979 .5206 .54602 .514 .53959 Mtetra
.66 .765 .927 r
.514 .53959 .5206 .54602 .53272 .54237 .52616 .53572 Mtetra
.666 .76 .921 r
.52616 .53572 .53272 .54237 .54489 .5388 .53836 .53167 Mtetra
.668 .748 .91 r
.53836 .53167 .54489 .5388 .55711 .53523 .55061 .52756 Mtetra
.665 .732 .9 r
.55061 .52756 .55711 .53523 .56939 .53163 .56292 .52349 Mtetra
.661 .719 .892 r
.56292 .52349 .56939 .53163 .58172 .52796 .57528 .51956 Mtetra
.655 .711 .889 r
.57528 .51956 .58172 .52796 .59411 .52421 .5877 .51578 Mtetra
.65 .709 .891 r
.5877 .51578 .59411 .52421 .60655 .52039 .60018 .51217 Mtetra
.646 .714 .897 r
.60018 .51217 .60655 .52039 .61905 .51651 .61272 .50869 Mtetra
.644 .725 .908 r
.61272 .50869 .61905 .51651 .6316 .51258 .62532 .50525 Mtetra
.644 .74 .919 r
.62532 .50525 .6316 .51258 .64421 .50867 .63798 .50175 Mtetra
.649 .755 .927 r
.63798 .50175 .64421 .50867 .65688 .50483 .6507 .49806 Mtetra
.655 .763 .929 r
.6507 .49806 .65688 .50483 .66961 .50111 .66346 .49414 Mtetra
.661 .76 .923 r
.66346 .49414 .66961 .50111 .6824 .49748 .67628 .49004 Mtetra
.661 .747 .914 r
.67628 .49004 .6824 .49748 .69526 .49379 .68915 .48595 Mtetra
.655 .734 .908 r
.68915 .48595 .69526 .49379 .70816 .48995 .70209 .48203 Mtetra
.651 .731 .908 r
.70209 .48203 .70816 .48995 .72112 .48598 .7151 .47824 Mtetra
.652 .738 .912 r
.7151 .47824 .72112 .48598 .73414 .48208 .72817 .47438 Mtetra
.655 .741 .913 r
.72817 .47438 .73414 .48208 .74723 .47829 .74129 .4704 Mtetra
.654 .736 .91 r
.74129 .4704 .74723 .47829 .76039 .47454 .75448 .46645 Mtetra
.651 .73 .907 r
.75448 .46645 .76039 .47454 .77362 .47091 .76773 .46259 Mtetra
.641 .721 .906 r
.76773 .46259 .77362 .47091 .78696 .46779 .78108 .45903 Mtetra
.603 .693 .907 r
.78108 .45903 .78696 .46779 .80049 .46621 .79459 .45672 Mtetra
.491 .619 .905 r
.79459 .45672 .80049 .46621 .81439 .46776 .80847 .45772 Mtetra
.322 .509 .885 r
.80847 .45772 .81439 .46776 .82865 .472 .82284 .463 Mtetra
.329 .542 .908 r
.82284 .463 .82865 .472 .84274 .47317 .83728 .46742 Mtetra
.677 .823 .953 r
.83728 .46742 .84274 .47317 .85605 .46541 .85092 .46234 Mtetra
.887 .94 .844 r
.85092 .46234 .85605 .46541 .8688 .45204 .8637 .44846 Mtetra
.882 .929 .848 r
.8637 .44846 .8688 .45204 .88174 .44056 .87649 .43485 Mtetra
.782 .857 .907 r
.87649 .43485 .88174 .44056 .89516 .43324 .88981 .42608 Mtetra
.687 .783 .924 r
.88981 .42608 .89516 .43324 .90891 .42835 .90357 .42076 Mtetra
.593 .743 .948 r
.28564 .60138 .29291 .60743 .30404 .60502 .29676 .59939 Mtetra
.248 .606 .954 r
.29676 .59939 .30404 .60502 .31501 .60589 .30767 .60173 Mtetra
.473 0 0 r
.30767 .60173 .31501 .60589 .3258 .61132 .31836 .60909 Mtetra
.45 0 0 r
.31836 .60909 .3258 .61132 .33669 .61696 .32926 .61469 Mtetra
.718 .904 .961 r
.32926 .61469 .33669 .61696 .34811 .61418 .34089 .60888 Mtetra
.856 .793 .788 r
.34089 .60888 .34811 .61418 .36003 .60235 .35301 .59404 Mtetra
.813 .735 .778 r
.35301 .59404 .36003 .60235 .37197 .58977 .36502 .58075 Mtetra
.743 .711 .821 r
.36502 .58075 .37197 .58977 .38372 .58135 .37679 .57293 Mtetra
.683 .708 .867 r
.37679 .57293 .38372 .58135 .39537 .57613 .38844 .56834 Mtetra
.658 .717 .892 r
.38844 .56834 .39537 .57613 .40702 .57213 .4001 .5647 Mtetra
.654 .727 .902 r
.4001 .5647 .40702 .57213 .41871 .56843 .41181 .56117 Mtetra
.656 .733 .906 r
.41181 .56117 .41871 .56843 .43044 .56482 .42357 .55758 Mtetra
.657 .735 .907 r
.42357 .55758 .43044 .56482 .44222 .56123 .43538 .55394 Mtetra
.654 .733 .908 r
.43538 .55394 .44222 .56123 .45405 .55753 .44724 .55036 Mtetra
.657 .738 .91 r
.44724 .55036 .45405 .55753 .46594 .55377 .45916 .54668 Mtetra
.671 .746 .907 r
.45916 .54668 .46594 .55377 .47788 .55014 .47114 .54253 Mtetra
.687 .737 .888 r
.47114 .54253 .47788 .55014 .48987 .54668 .48317 .53776 Mtetra
.692 .707 .859 r
.48317 .53776 .48987 .54668 .50191 .54322 .49525 .53256 Mtetra
.685 .669 .829 r
.49525 .53256 .50191 .54322 .514 .53959 .50738 .5273 Mtetra
.672 .638 .807 r
.50738 .5273 .514 .53959 .52616 .53572 .51955 .52224 Mtetra
.661 .617 .794 r
.51955 .52224 .52616 .53572 .53836 .53167 .53176 .5175 Mtetra
.652 .604 .788 r
.53176 .5175 .53836 .53167 .55061 .52756 .54403 .51308 Mtetra
.646 .598 .786 r
.54403 .51308 .55061 .52756 .56292 .52349 .55634 .50892 Mtetra
.642 .595 .786 r
.55634 .50892 .56292 .52349 .57528 .51956 .56871 .50494 Mtetra
.639 .594 .787 r
.56871 .50494 .57528 .51956 .5877 .51578 .58114 .50113 Mtetra
.636 .592 .788 r
.58114 .50113 .5877 .51578 .60018 .51217 .59363 .49746 Mtetra
.632 .59 .788 r
.59363 .49746 .60018 .51217 .61272 .50869 .60618 .494 Mtetra
.627 .588 .79 r
.60618 .494 .61272 .50869 .62532 .50525 .6188 .4908 Mtetra
.621 .588 .796 r
.6188 .4908 .62532 .50525 .63798 .50175 .63149 .48792 Mtetra
.615 .594 .806 r
.63149 .48792 .63798 .50175 .6507 .49806 .64426 .48538 Mtetra
.611 .61 .825 r
.64426 .48538 .6507 .49806 .66346 .49414 .6571 .48304 Mtetra
.613 .639 .853 r
.6571 .48304 .66346 .49414 .67628 .49004 .67002 .48064 Mtetra
.623 .682 .884 r
.67002 .48064 .67628 .49004 .68915 .48595 .68299 .47781 Mtetra
.641 .722 .907 r
.68299 .47781 .68915 .48595 .70209 .48203 .69599 .47435 Mtetra
.654 .741 .914 r
.69599 .47435 .70209 .48203 .7151 .47824 .70903 .47041 Mtetra
.657 .739 .91 r
.70903 .47041 .7151 .47824 .72817 .47438 .72213 .46637 Mtetra
.654 .734 .908 r
.72213 .46637 .72817 .47438 .74129 .4704 .7353 .46239 Mtetra
.656 .735 .908 r
.7353 .46239 .74129 .4704 .75448 .46645 .74852 .45836 Mtetra
.657 .735 .907 r
.74852 .45836 .75448 .46645 .76773 .46259 .7618 .45425 Mtetra
.653 .727 .903 r
.7618 .45425 .76773 .46259 .78108 .45903 .77515 .45027 Mtetra
.624 .704 .903 r
.77515 .45027 .78108 .45903 .79459 .45672 .78865 .44726 Mtetra
.515 .634 .906 r
.78865 .44726 .79459 .45672 .80847 .45772 .8025 .44759 Mtetra
.288 .488 .879 r
.8025 .44759 .80847 .45772 .82284 .463 .81696 .45356 Mtetra
.186 .441 .87 r
.81696 .45356 .82284 .463 .83728 .46742 .83171 .46106 Mtetra
.561 .756 .969 r
.83171 .46106 .83728 .46742 .85092 .46234 .84571 .45907 Mtetra
.886 .936 .844 r
.84571 .45907 .85092 .46234 .8637 .44846 .85857 .44512 Mtetra
.909 .93 .815 r
.85857 .44512 .8637 .44846 .87649 .43485 .87122 .42939 Mtetra
.817 .873 .887 r
.87122 .42939 .87649 .43485 .88981 .42608 .88443 .419 Mtetra
.701 .792 .922 r
.88443 .419 .88981 .42608 .90357 .42076 .89818 .41317 Mtetra
.568 .736 .955 r
.27831 .59532 .28564 .60138 .29676 .59939 .28942 .59379 Mtetra
.057 .493 .891 r
.28942 .59379 .29676 .59939 .30767 .60173 .30024 .5977 Mtetra
.623 .066 0 r
.30024 .5977 .30767 .60173 .31836 .60909 .31082 .60698 Mtetra
.434 0 0 r
.31082 .60698 .31836 .60909 .32926 .61469 .32177 .61231 Mtetra
.814 .894 .9 r
.32177 .61231 .32926 .61469 .34089 .60888 .33362 .60326 Mtetra
.87 .781 .76 r
.33362 .60326 .34089 .60888 .35301 .59404 .34595 .5855 Mtetra
.816 .732 .772 r
.34595 .5855 .35301 .59404 .36502 .58075 .35804 .57165 Mtetra
.731 .707 .828 r
.35804 .57165 .36502 .58075 .37679 .57293 .3698 .56449 Mtetra
.666 .704 .876 r
.3698 .56449 .37679 .57293 .38844 .56834 .38145 .56053 Mtetra
.648 .715 .897 r
.38145 .56053 .38844 .56834 .4001 .5647 .39313 .55718 Mtetra
.651 .725 .903 r
.39313 .55718 .4001 .5647 .41181 .56117 .40486 .55373 Mtetra
.657 .73 .903 r
.40486 .55373 .41181 .56117 .42357 .55758 .41665 .55007 Mtetra
.671 .732 .896 r
.41665 .55007 .42357 .55758 .43538 .55394 .42851 .54594 Mtetra
.692 .727 .877 r
.42851 .54594 .43538 .55394 .44724 .55036 .44043 .54096 Mtetra
.702 .699 .843 r
.44043 .54096 .44724 .55036 .45916 .54668 .45242 .53518 Mtetra
.693 .657 .811 r
.45242 .53518 .45916 .54668 .47114 .54253 .46445 .52927 Mtetra
.674 .624 .791 r
.46445 .52927 .47114 .54253 .48317 .53776 .4765 .52387 Mtetra
.657 .609 .789 r
.4765 .52387 .48317 .53776 .49525 .53256 .48859 .51924 Mtetra
.647 .612 .8 r
.48859 .51924 .49525 .53256 .50738 .5273 .50072 .51525 Mtetra
.643 .63 .822 r
.50072 .51525 .50738 .5273 .51955 .52224 .5129 .51164 Mtetra
.643 .656 .848 r
.5129 .51164 .51955 .52224 .53176 .5175 .52514 .50817 Mtetra
.646 .685 .873 r
.52514 .50817 .53176 .5175 .54403 .51308 .53744 .50469 Mtetra
.649 .71 .892 r
.53744 .50469 .54403 .51308 .55634 .50892 .54979 .50112 Mtetra
.652 .728 .905 r
.54979 .50112 .55634 .50892 .56871 .50494 .5622 .49742 Mtetra
.656 .738 .91 r
.5622 .49742 .56871 .50494 .58114 .50113 .57466 .49357 Mtetra
.66 .74 .909 r
.57466 .49357 .58114 .50113 .59363 .49746 .58718 .48958 Mtetra
.664 .732 .901 r
.58718 .48958 .59363 .49746 .60618 .494 .59975 .48545 Mtetra
.665 .716 .887 r
.59975 .48545 .60618 .494 .6188 .4908 .61237 .48123 Mtetra
.663 .692 .867 r
.61237 .48123 .6188 .4908 .63149 .48792 .62505 .47699 Mtetra
.655 .661 .844 r
.62505 .47699 .63149 .48792 .64426 .48538 .63779 .47289 Mtetra
.641 .629 .822 r
.63779 .47289 .64426 .48538 .6571 .48304 .6506 .46919 Mtetra
.624 .6 .806 r
.6506 .46919 .6571 .48304 .67002 .48064 .66351 .46614 Mtetra
.606 .583 .801 r
.66351 .46614 .67002 .48064 .68299 .47781 .67651 .46388 Mtetra
.595 .585 .812 r
.67651 .46388 .68299 .47781 .69599 .47435 .68962 .46216 Mtetra
.597 .615 .84 r
.68962 .46216 .69599 .47435 .70903 .47041 .7028 .4603 Mtetra
.617 .666 .875 r
.7028 .4603 .70903 .47041 .72213 .46637 .71601 .45763 Mtetra
.641 .71 .898 r
.71601 .45763 .72213 .46637 .7353 .46239 .72924 .45408 Mtetra
.654 .728 .904 r
.72924 .45408 .7353 .46239 .74852 .45836 .7425 .45006 Mtetra
.66 .732 .903 r
.7425 .45006 .74852 .45836 .7618 .45425 .75582 .44583 Mtetra
.662 .73 .9 r
.75582 .44583 .7618 .45425 .77515 .45027 .76918 .44148 Mtetra
.644 .714 .899 r
.76918 .44148 .77515 .45027 .78865 .44726 .78267 .43777 Mtetra
.54 .648 .904 r
.78267 .43777 .78865 .44726 .8025 .44759 .79649 .43736 Mtetra
.262 .47 .874 r
.79649 .43736 .8025 .44759 .81696 .45356 .81102 .44387 Mtetra
.036 .334 .815 r
.81102 .44387 .81696 .45356 .83171 .46106 .82607 .45437 Mtetra
.403 .665 .966 r
.82607 .45437 .83171 .46106 .84571 .45907 .84043 .45567 Mtetra
.882 .934 .848 r
.84043 .45567 .84571 .45907 .85857 .44512 .8534 .44191 Mtetra
.93 .924 .783 r
.8534 .44191 .85857 .44512 .87122 .42939 .86592 .42406 Mtetra
.848 .882 .864 r
.86592 .42406 .87122 .42939 .88443 .419 .87901 .41194 Mtetra
.715 .8 .918 r
.87901 .41194 .88443 .419 .89818 .41317 .89276 .40555 Mtetra
.539 .727 .961 r
.27091 .58923 .27831 .59532 .28942 .59379 .28202 .58817 Mtetra
0 .348 .783 r
.28202 .58817 .28942 .59379 .30024 .5977 .29274 .59368 Mtetra
.715 .183 0 r
.29274 .59368 .30024 .5977 .31082 .60698 .3032 .6049 Mtetra
.406 0 0 r
.3032 .6049 .31082 .60698 .32177 .61231 .31419 .60991 Mtetra
.863 .875 .846 r
.31419 .60991 .32177 .61231 .33362 .60326 .32629 .5976 Mtetra
.882 .774 .738 r
.32629 .5976 .33362 .60326 .34595 .5855 .33884 .5769 Mtetra
.82 .732 .767 r
.33884 .5769 .34595 .5855 .35804 .57165 .35101 .56246 Mtetra
.719 .704 .835 r
.35101 .56246 .35804 .57165 .3698 .56449 .36277 .55594 Mtetra
.649 .697 .881 r
.36277 .55594 .3698 .56449 .38145 .56053 .37442 .55251 Mtetra
.646 .711 .895 r
.37442 .55251 .38145 .56053 .39313 .55718 .38612 .5492 Mtetra
.67 .72 .886 r
.38612 .5492 .39313 .55718 .40486 .55373 .39791 .54507 Mtetra
.697 .712 .86 r
.39791 .54507 .40486 .55373 .41665 .55007 .40978 .53977 Mtetra
.705 .682 .825 r
.40978 .53977 .41665 .55007 .42851 .54594 .42172 .53357 Mtetra
.69 .643 .798 r
.42172 .53357 .42851 .54594 .44043 .54096 .43369 .52753 Mtetra
.665 .618 .792 r
.43369 .52753 .44043 .54096 .45242 .53518 .44567 .52259 Mtetra
.646 .621 .811 r
.44567 .52259 .45242 .53518 .46445 .52927 .45767 .51881 Mtetra
.634 .654 .852 r
.45767 .51881 .46445 .52927 .4765 .52387 .46971 .51574 Mtetra
.628 .707 .903 r
.46971 .51574 .4765 .52387 .48859 .51924 .48181 .51286 Mtetra
.623 .758 .943 r
.48181 .51286 .48859 .51924 .50072 .51525 .49397 .50991 Mtetra
.619 .794 .966 r
.49397 .50991 .50072 .51525 .5129 .51164 .50619 .50678 Mtetra
.62 .812 .974 r
.50619 .50678 .5129 .51164 .52514 .50817 .51847 .50347 Mtetra
.624 .82 .976 r
.51847 .50347 .52514 .50817 .53744 .50469 .53081 .5 Mtetra
.63 .823 .975 r
.53081 .5 .53744 .50469 .54979 .50112 .5432 .49638 Mtetra
.636 .824 .973 r
.5432 .49638 .54979 .50112 .5622 .49742 .55566 .49263 Mtetra
.641 .825 .971 r
.55566 .49263 .5622 .49742 .57466 .49357 .56817 .48875 Mtetra
.646 .826 .969 r
.56817 .48875 .57466 .49357 .58718 .48958 .58073 .48473 Mtetra
.651 .828 .968 r
.58073 .48473 .58718 .48958 .59975 .48545 .59335 .48058 Mtetra
.656 .83 .967 r
.59335 .48058 .59975 .48545 .61237 .48123 .60602 .47629 Mtetra
.662 .83 .964 r
.60602 .47629 .61237 .48123 .62505 .47699 .61874 .47184 Mtetra
.67 .826 .958 r
.61874 .47184 .62505 .47699 .63779 .47289 .63151 .46721 Mtetra
.679 .811 .946 r
.63151 .46721 .63779 .47289 .6506 .46919 .64433 .4624 Mtetra
.683 .777 .922 r
.64433 .4624 .6506 .46919 .66351 .46614 .6572 .4575 Mtetra
.674 .724 .887 r
.6572 .4575 .66351 .46614 .67651 .46388 .67013 .45281 Mtetra
.65 .661 .847 r
.67013 .45281 .67651 .46388 .68962 .46216 .68316 .44882 Mtetra
.618 .608 .818 r
.68316 .44882 .68962 .46216 .7028 .4603 .6963 .44603 Mtetra
.592 .581 .81 r
.6963 .44603 .7028 .4603 .71601 .45763 .70958 .44438 Mtetra
.587 .595 .827 r
.70958 .44438 .71601 .45763 .72924 .45408 .72296 .4429 Mtetra
.609 .643 .859 r
.72296 .4429 .72924 .45408 .7425 .45006 .73636 .4405 Mtetra
.64 .693 .883 r
.73636 .4405 .7425 .45006 .75582 .44583 .74976 .4369 Mtetra
.663 .719 .89 r
.74976 .4369 .75582 .44583 .76918 .44148 .76316 .43246 Mtetra
.66 .717 .891 r
.76316 .43246 .76918 .44148 .78267 .43777 .77663 .42814 Mtetra
.563 .658 .9 r
.77663 .42814 .78267 .43777 .79649 .43736 .79043 .42703 Mtetra
.234 .452 .867 r
.79043 .42703 .79649 .43736 .81102 .44387 .80503 .4341 Mtetra
0 .219 .742 r
.80503 .4341 .81102 .44387 .82607 .45437 .82037 .44761 Mtetra
.203 .542 .928 r
.82037 .44761 .82607 .45437 .84043 .45567 .8351 .45224 Mtetra
.878 .935 .854 r
.8351 .45224 .84043 .45567 .8534 .44191 .84817 .4387 Mtetra
.945 .915 .754 r
.84817 .4387 .8534 .44191 .86592 .42406 .86056 .41873 Mtetra
.873 .883 .839 r
.86056 .41873 .86592 .42406 .87901 .41194 .87354 .40484 Mtetra
.729 .806 .912 r
.87354 .40484 .87901 .41194 .89276 .40555 .88728 .39789 Mtetra
.51 .716 .965 r
.26346 .58309 .27091 .58923 .28202 .58817 .27455 .58249 Mtetra
0 .199 .65 r
.27455 .58249 .28202 .58817 .29274 .59368 .28518 .58957 Mtetra
.774 .266 0 r
.28518 .58957 .29274 .59368 .3032 .6049 .29551 .60271 Mtetra
.382 0 0 r
.29551 .60271 .3032 .6049 .31419 .60991 .30653 .60756 Mtetra
.889 .858 .805 r
.30653 .60756 .31419 .60991 .32629 .5976 .31888 .59214 Mtetra
.894 .772 .72 r
.31888 .59214 .32629 .5976 .33884 .5769 .33168 .56842 Mtetra
.828 .736 .762 r
.33168 .56842 .33884 .5769 .35101 .56246 .34393 .55314 Mtetra
.713 .7 .837 r
.34393 .55314 .35101 .56246 .36277 .55594 .35571 .54691 Mtetra
.652 .688 .871 r
.35571 .54691 .36277 .55594 .37442 .55251 .36739 .54334 Mtetra
.677 .694 .858 r
.36739 .54334 .37442 .55251 .38612 .5492 .37917 .53876 Mtetra
.701 .677 .824 r
.37917 .53876 .38612 .5492 .39791 .54507 .39105 .53275 Mtetra
.692 .644 .798 r
.39105 .53275 .39791 .54507 .40978 .53977 .40296 .52663 Mtetra
.664 .621 .797 r
.40296 .52663 .40978 .53977 .42172 .53357 .41487 .52183 Mtetra
.637 .631 .828 r
.41487 .52183 .42172 .53357 .43369 .52753 .42678 .51855 Mtetra
.618 .681 .887 r
.42678 .51855 .43369 .52753 .44567 .52259 .43873 .51603 Mtetra
.603 .745 .945 r
.43873 .51603 .44567 .52259 .45767 .51881 .45073 .5136 Mtetra
.595 .789 .973 r
.45073 .5136 .45767 .51881 .46971 .51574 .4628 .51097 Mtetra
.599 .807 .98 r
.4628 .51097 .46971 .51574 .48181 .51286 .47494 .50809 Mtetra
.609 .811 .978 r
.47494 .50809 .48181 .51286 .49397 .50991 .48714 .50499 Mtetra
.619 .81 .973 r
.48714 .50499 .49397 .50991 .50619 .50678 .49941 .50172 Mtetra
.627 .808 .969 r
.49941 .50172 .50619 .50678 .51847 .50347 .51173 .49828 Mtetra
.633 .807 .966 r
.51173 .49828 .51847 .50347 .53081 .5 .52411 .49472 Mtetra
.639 .806 .963 r
.52411 .49472 .53081 .5 .5432 .49638 .53655 .49103 Mtetra
.643 .806 .961 r
.53655 .49103 .5432 .49638 .55566 .49263 .54905 .48723 Mtetra
.647 .807 .96 r
.54905 .48723 .55566 .49263 .56817 .48875 .5616 .48332 Mtetra
.65 .808 .959 r
.5616 .48332 .56817 .48875 .58073 .48473 .57421 .47931 Mtetra
.654 .81 .958 r
.57421 .47931 .58073 .48473 .59335 .48058 .58688 .47519 Mtetra
.658 .813 .958 r
.58688 .47519 .59335 .48058 .60602 .47629 .5996 .47094 Mtetra
.662 .817 .958 r
.5996 .47094 .60602 .47629 .61874 .47184 .61237 .46654 Mtetra
.667 .821 .958 r
.61237 .46654 .61874 .47184 .63151 .46721 .62519 .46197 Mtetra
.673 .826 .957 r
.62519 .46197 .63151 .46721 .64433 .4624 .63806 .45721 Mtetra
.68 .831 .956 r
.63806 .45721 .64433 .4624 .6572 .4575 .65098 .45224 Mtetra
.688 .832 .952 r
.65098 .45224 .6572 .4575 .67013 .45281 .66394 .44703 Mtetra
.696 .818 .941 r
.66394 .44703 .67013 .45281 .68316 .44882 .67695 .44162 Mtetra
.693 .773 .913 r
.67695 .44162 .68316 .44882 .6963 .44603 .69001 .4363 Mtetra
.665 .698 .871 r
.69001 .4363 .6963 .44603 .70958 .44438 .70316 .43175 Mtetra
.622 .623 .831 r
.70316 .43175 .70958 .44438 .72296 .4429 .71647 .42876 Mtetra
.589 .584 .815 r
.71647 .42876 .72296 .4429 .73636 .4405 .72994 .42715 Mtetra
.591 .598 .827 r
.72994 .42715 .73636 .4405 .74976 .4369 .74348 .42542 Mtetra
.627 .648 .852 r
.74348 .42542 .74976 .4369 .76316 .43246 .757 .42224 Mtetra
.654 .687 .869 r
.757 .42224 .76316 .43246 .77663 .42814 .77052 .41801 Mtetra
.576 .654 .89 r
.77052 .41801 .77663 .42814 .79043 .42703 .78433 .41655 Mtetra
.194 .425 .856 r
.78433 .41655 .79043 .42703 .80503 .4341 .79901 .42445 Mtetra
0 .099 .648 r
.79901 .42445 .80503 .4341 .82037 .44761 .81465 .44104 Mtetra
0 .394 .844 r
.81465 .44104 .82037 .44761 .8351 .45224 .82971 .44884 Mtetra
.875 .938 .856 r
.82971 .44884 .8351 .45224 .84817 .4387 .84287 .43537 Mtetra
.956 .903 .729 r
.84287 .43537 .84817 .4387 .86056 .41873 .85514 .41328 Mtetra
.892 .879 .814 r
.85514 .41328 .86056 .41873 .87354 .40484 .86801 .39766 Mtetra
.742 .81 .906 r
.86801 .39766 .87354 .40484 .88728 .39789 .88176 .39015 Mtetra
.48 .704 .968 r
.25594 .57688 .26346 .58309 .27455 .58249 .26703 .57672 Mtetra
.47 0 0 r
.26703 .57672 .27455 .58249 .28518 .58957 .27755 .58525 Mtetra
.812 .325 0 r
.27755 .58525 .28518 .58957 .29551 .60271 .28775 .60025 Mtetra
.371 0 0 r
.28775 .60025 .29551 .60271 .30653 .60756 .29879 .60519 Mtetra
.903 .844 .776 r
.29879 .60519 .30653 .60756 .31888 .59214 .31138 .5871 Mtetra
.905 .772 .704 r
.31138 .5871 .31888 .59214 .33168 .56842 .32444 .56023 Mtetra
.842 .741 .752 r
.32444 .56023 .33168 .56842 .34393 .55314 .33684 .54326 Mtetra
.726 .695 .82 r
.33684 .54326 .34393 .55314 .35571 .54691 .34869 .53607 Mtetra
.677 .662 .827 r
.34869 .53607 .35571 .54691 .36739 .54334 .36046 .53114 Mtetra
.683 .642 .803 r
.36046 .53114 .36739 .54334 .37917 .53876 .37229 .52556 Mtetra
.666 .622 .795 r
.37229 .52556 .37917 .53876 .39105 .53275 .38414 .52061 Mtetra
.634 .623 .822 r
.38414 .52061 .39105 .53275 .40296 .52663 .39597 .51738 Mtetra
.603 .669 .886 r
.39597 .51738 .40296 .52663 .41487 .52183 .4078 .51532 Mtetra
.578 .738 .952 r
.4078 .51532 .41487 .52183 .42678 .51855 .4197 .51341 Mtetra
.569 .783 .98 r
.4197 .51341 .42678 .51855 .43873 .51603 .43168 .51124 Mtetra
.581 .801 .983 r
.43168 .51124 .43873 .51603 .45073 .5136 .44372 .5087 Mtetra
.6 .804 .978 r
.44372 .5087 .45073 .5136 .4628 .51097 .45584 .50582 Mtetra
.617 .801 .97 r
.45584 .50582 .4628 .51097 .47494 .50809 .46802 .50265 Mtetra
.629 .796 .962 r
.46802 .50265 .47494 .50809 .48714 .50499 .48026 .49927 Mtetra
.638 .789 .955 r
.48026 .49927 .48714 .50499 .49941 .50172 .49257 .49572 Mtetra
.643 .783 .948 r
.49257 .49572 .49941 .50172 .51173 .49828 .50493 .49207 Mtetra
.647 .778 .943 r
.50493 .49207 .51173 .49828 .52411 .49472 .51735 .48834 Mtetra
.649 .774 .94 r
.51735 .48834 .52411 .49472 .53655 .49103 .52983 .48453 Mtetra
.652 .772 .937 r
.52983 .48453 .53655 .49103 .54905 .48723 .54237 .48066 Mtetra
.654 .772 .936 r
.54237 .48066 .54905 .48723 .5616 .48332 .55496 .47671 Mtetra
.656 .772 .935 r
.55496 .47671 .5616 .48332 .57421 .47931 .56762 .47269 Mtetra
.658 .773 .935 r
.56762 .47269 .57421 .47931 .58688 .47519 .58032 .4686 Mtetra
.659 .776 .935 r
.58032 .4686 .58688 .47519 .5996 .47094 .59309 .46444 Mtetra
.66 .78 .938 r
.59309 .46444 .5996 .47094 .61237 .46654 .60591 .46022 Mtetra
.662 .788 .941 r
.60591 .46022 .61237 .46654 .62519 .46197 .61879 .45589 Mtetra
.666 .798 .945 r
.61879 .45589 .62519 .46197 .63806 .45721 .63171 .45141 Mtetra
.672 .81 .949 r
.63171 .45141 .63806 .45721 .65098 .45224 .64469 .4467 Mtetra
.681 .823 .951 r
.64469 .4467 .65098 .45224 .66394 .44703 .65772 .44167 Mtetra
.692 .833 .951 r
.65772 .44167 .66394 .44703 .67695 .44162 .67077 .43626 Mtetra
.704 .838 .946 r
.67077 .43626 .67695 .44162 .69001 .4363 .68387 .43048 Mtetra
.713 .826 .935 r
.68387 .43048 .69001 .4363 .70316 .43175 .697 .42445 Mtetra
.705 .778 .909 r
.697 .42445 .70316 .43175 .71647 .42876 .71018 .4186 Mtetra
.665 .692 .865 r
.71018 .4186 .71647 .42876 .72994 .42715 .72349 .41394 Mtetra
.617 .614 .825 r
.72349 .41394 .72994 .42715 .74348 .42542 .73698 .41107 Mtetra
.601 .59 .812 r
.73698 .41107 .74348 .42542 .757 .42224 .75059 .40885 Mtetra
.616 .612 .824 r
.75059 .40885 .757 .42224 .77052 .41801 .76423 .40599 Mtetra
.555 .605 .858 r
.76423 .40599 .77052 .41801 .78433 .41655 .77814 .40547 Mtetra
.131 .37 .828 r
.77814 .40547 .78433 .41655 .79901 .42445 .79298 .41507 Mtetra
0 0 .538 r
.79298 .41507 .79901 .42445 .81465 .44104 .8089 .4349 Mtetra
0 .247 .73 r
.8089 .4349 .81465 .44104 .82971 .44884 .82425 .4454 Mtetra
.877 .937 .854 r
.82425 .4454 .82971 .44884 .84287 .43537 .83749 .43173 Mtetra
.963 .889 .708 r
.83749 .43173 .84287 .43537 .85514 .41328 .84965 .40759 Mtetra
.906 .871 .793 r
.84965 .40759 .85514 .41328 .86801 .39766 .86243 .39037 Mtetra
.753 .812 .899 r
.86243 .39037 .86801 .39766 .88176 .39015 .87618 .38233 Mtetra
.45 .692 .969 r
.24837 .57064 .25594 .57688 .26703 .57672 .25944 .57087 Mtetra
.571 .033 0 r
.25944 .57087 .26703 .57672 .27755 .58525 .26987 .58069 Mtetra
.836 .366 .044 r
.26987 .58069 .27755 .58525 .28775 .60025 .27995 .59732 Mtetra
.364 0 0 r
.27995 .59732 .28775 .60025 .29879 .60519 .29099 .60253 Mtetra
.908 .829 .756 r
.29099 .60253 .29879 .60519 .31138 .5871 .30379 .58237 Mtetra
.914 .77 .688 r
.30379 .58237 .31138 .5871 .32444 .56023 .31715 .55204 Mtetra
.859 .74 .731 r
.31715 .55204 .32444 .56023 .33684 .54326 .3298 .5318 Mtetra
.745 .675 .784 r
.3298 .5318 .33684 .54326 .34869 .53607 .34178 .52248 Mtetra
.664 .615 .79 r
.34178 .52248 .34869 .53607 .36046 .53114 .35356 .51752 Mtetra
.627 .598 .801 r
.35356 .51752 .36046 .53114 .37229 .52556 .36529 .51446 Mtetra
.59 .623 .853 r
.36529 .51446 .37229 .52556 .38414 .52061 .377 .5129 Mtetra
.553 .691 .931 r
.377 .5129 .38414 .52061 .39597 .51738 .38877 .51181 Mtetra
.535 .755 .978 r
.38877 .51181 .39597 .51738 .4078 .51532 .40062 .5104 Mtetra
.553 .786 .986 r
.40062 .5104 .4078 .51532 .4197 .51341 .41255 .5084 Mtetra
.586 .795 .979 r
.41255 .5084 .4197 .51341 .43168 .51124 .42457 .50583 Mtetra
.613 .79 .967 r
.42457 .50583 .43168 .51124 .44372 .5087 .43667 .50283 Mtetra
.628 .78 .954 r
.43667 .50283 .44372 .5087 .45584 .50582 .44883 .49958 Mtetra
.636 .771 .945 r
.44883 .49958 .45584 .50582 .46802 .50265 .46105 .49618 Mtetra
.64 .766 .94 r
.46105 .49618 .46802 .50265 .48026 .49927 .47333 .49269 Mtetra
.643 .765 .937 r
.47333 .49269 .48026 .49927 .49257 .49572 .48568 .48911 Mtetra
.645 .766 .936 r
.48568 .48911 .49257 .49572 .50493 .49207 .49808 .48547 Mtetra
.647 .767 .936 r
.49808 .48547 .50493 .49207 .51735 .48834 .51054 .48175 Mtetra
.649 .769 .937 r
.51054 .48175 .51735 .48834 .52983 .48453 .52306 .47795 Mtetra
.651 .771 .937 r
.52306 .47795 .52983 .48453 .54237 .48066 .53563 .47408 Mtetra
.653 .773 .937 r
.53563 .47408 .54237 .48066 .55496 .47671 .54827 .47013 Mtetra
.655 .775 .937 r
.54827 .47013 .55496 .47671 .56762 .47269 .56096 .4661 Mtetra
.657 .776 .937 r
.56096 .4661 .56762 .47269 .58032 .4686 .57371 .46199 Mtetra
.659 .777 .936 r
.57371 .46199 .58032 .4686 .59309 .46444 .58652 .45778 Mtetra
.663 .778 .935 r
.58652 .45778 .59309 .46444 .60591 .46022 .59938 .45347 Mtetra
.666 .777 .932 r
.59938 .45347 .60591 .46022 .61879 .45589 .6123 .44905 Mtetra
.668 .776 .93 r
.6123 .44905 .61879 .45589 .63171 .45141 .62527 .44452 Mtetra
.671 .777 .929 r
.62527 .44452 .63171 .45141 .64469 .4467 .6383 .43991 Mtetra
.673 .781 .931 r
.6383 .43991 .64469 .4467 .65772 .44167 .65138 .43518 Mtetra
.679 .794 .936 r
.65138 .43518 .65772 .44167 .67077 .43626 .66451 .43024 Mtetra
.692 .814 .94 r
.66451 .43024 .67077 .43626 .68387 .43048 .67768 .42485 Mtetra
.71 .833 .941 r
.67768 .42485 .68387 .43048 .697 .42445 .69086 .41885 Mtetra
.728 .84 .933 r
.69086 .41885 .697 .42445 .71018 .4186 .70406 .41222 Mtetra
.735 .818 .916 r
.70406 .41222 .71018 .4186 .72349 .41394 .71729 .40527 Mtetra
.712 .748 .88 r
.71729 .40527 .72349 .41394 .73698 .41107 .73059 .39884 Mtetra
.662 .654 .832 r
.73059 .39884 .73698 .41107 .75059 .40885 .74404 .39397 Mtetra
.613 .59 .804 r
.74404 .39397 .75059 .40885 .76423 .40599 .7577 .39108 Mtetra
.508 .533 .817 r
.7577 .39108 .76423 .40599 .77814 .40547 .77178 .39272 Mtetra
.045 .277 .771 r
.77178 .39272 .77814 .40547 .79298 .41507 .7869 .40568 Mtetra
0 0 .435 r
.7869 .40568 .79298 .41507 .8089 .4349 .80313 .42904 Mtetra
0 .137 .63 r
.80313 .42904 .8089 .4349 .82425 .4454 .81871 .44164 Mtetra
.881 .928 .848 r
.81871 .44164 .82425 .4454 .83749 .43173 .83199 .42757 Mtetra
.966 .874 .693 r
.83199 .42757 .83749 .43173 .84965 .40759 .84408 .40163 Mtetra
.915 .863 .775 r
.84408 .40163 .84965 .40759 .86243 .39037 .8568 .38297 Mtetra
.763 .813 .893 r
.8568 .38297 .86243 .39037 .87618 .38233 .87055 .37444 Mtetra
.419 .679 .97 r
.24073 .56436 .24837 .57064 .25944 .57087 .25179 .56497 Mtetra
.641 .11 0 r
.25179 .56497 .25944 .57087 .26987 .58069 .26213 .5759 Mtetra
.85 .391 .071 r
.26213 .5759 .26987 .58069 .27995 .59732 .2721 .5937 Mtetra
.315 0 0 r
.2721 .5937 .27995 .59732 .29099 .60253 .28316 .59898 Mtetra
.906 .808 .74 r
.28316 .59898 .29099 .60253 .30379 .58237 .29616 .57707 Mtetra
.915 .759 .674 r
.29616 .57707 .30379 .58237 .31715 .55204 .30985 .54316 Mtetra
.868 .73 .708 r
.30985 .54316 .31715 .55204 .3298 .5318 .32279 .51904 Mtetra
.746 .66 .765 r
.32279 .51904 .3298 .5318 .34178 .52248 .33485 .50878 Mtetra
.606 .587 .806 r
.33485 .50878 .34178 .52248 .35356 .51752 .34649 .50657 Mtetra
.516 .593 .87 r
.34649 .50657 .35356 .51752 .36529 .51446 .35805 .50706 Mtetra
.472 .668 .949 r
.35805 .50706 .36529 .51446 .377 .5129 .36971 .50736 Mtetra
.489 .74 .983 r
.36971 .50736 .377 .5129 .38877 .51181 .38149 .50661 Mtetra
.545 .774 .983 r
.38149 .50661 .38877 .51181 .40062 .5104 .39338 .50484 Mtetra
.591 .778 .969 r
.39338 .50484 .40062 .5104 .41255 .5084 .40537 .50234 Mtetra
.615 .77 .954 r
.40537 .50234 .41255 .5084 .42457 .50583 .41744 .49944 Mtetra
.626 .764 .945 r
.41744 .49944 .42457 .50583 .43667 .50283 .42957 .4963 Mtetra
.633 .762 .941 r
.42957 .4963 .43667 .50283 .44883 .49958 .44177 .493 Mtetra
.638 .763 .939 r
.44177 .493 .44883 .49958 .46105 .49618 .45403 .48955 Mtetra
.642 .764 .937 r
.45403 .48955 .46105 .49618 .47333 .49269 .46635 .48598 Mtetra
.646 .764 .935 r
.46635 .48598 .47333 .49269 .48568 .48911 .47873 .4823 Mtetra
.648 .762 .932 r
.47873 .4823 .48568 .48911 .49808 .48547 .49117 .47854 Mtetra
.651 .76 .93 r
.49117 .47854 .49808 .48547 .51054 .48175 .50366 .47471 Mtetra
.652 .758 .927 r
.50366 .47471 .51054 .48175 .52306 .47795 .51622 .47081 Mtetra
.654 .757 .925 r
.51622 .47081 .52306 .47795 .53563 .47408 .52884 .46684 Mtetra
.656 .755 .923 r
.52884 .46684 .53563 .47408 .54827 .47013 .54151 .46281 Mtetra
.657 .754 .922 r
.54151 .46281 .54827 .47013 .56096 .4661 .55424 .45871 Mtetra
.658 .754 .921 r
.55424 .45871 .56096 .4661 .57371 .46199 .56703 .45457 Mtetra
.659 .754 .921 r
.56703 .45457 .57371 .46199 .58652 .45778 .57988 .4504 Mtetra
.659 .756 .922 r
.57988 .4504 .58652 .45778 .59938 .45347 .59278 .44621 Mtetra
.659 .761 .925 r
.59278 .44621 .59938 .45347 .6123 .44905 .60575 .44197 Mtetra
.661 .768 .929 r
.60575 .44197 .6123 .44905 .62527 .44452 .61877 .43764 Mtetra
.666 .777 .932 r
.61877 .43764 .62527 .44452 .6383 .43991 .63185 .43313 Mtetra
.673 .784 .933 r
.63185 .43313 .6383 .43991 .65138 .43518 .64498 .42838 Mtetra
.681 .786 .93 r
.64498 .42838 .65138 .43518 .66451 .43024 .65815 .42336 Mtetra
.688 .787 .926 r
.65815 .42336 .66451 .43024 .67768 .42485 .67138 .4181 Mtetra
.697 .795 .926 r
.67138 .4181 .67768 .42485 .69086 .41885 .68463 .41252 Mtetra
.717 .816 .926 r
.68463 .41252 .69086 .41885 .70406 .41222 .69791 .40623 Mtetra
.746 .835 .919 r
.69791 .40623 .70406 .41222 .71729 .40527 .71117 .39888 Mtetra
.77 .829 .898 r
.71117 .39888 .71729 .40527 .73059 .39884 .7244 .39043 Mtetra
.759 .772 .863 r
.7244 .39043 .73059 .39884 .74404 .39397 .73765 .38183 Mtetra
.68 .665 .829 r
.73765 .38183 .74404 .39397 .7577 .39108 .75113 .37603 Mtetra
.482 .517 .817 r
.75113 .37603 .7577 .39108 .77178 .39272 .76529 .3786 Mtetra
0 .175 .705 r
.76529 .3786 .77178 .39272 .7869 .40568 .78072 .39553 Mtetra
0 0 .371 r
.78072 .39553 .7869 .40568 .80313 .42904 .79726 .42255 Mtetra
0 .084 .594 r
.79726 .42255 .80313 .42904 .81871 .44164 .81302 .43689 Mtetra
.878 .902 .844 r
.81302 .43689 .81871 .44164 .83199 .42757 .82637 .42268 Mtetra
.965 .858 .685 r
.82637 .42268 .83199 .42757 .84408 .40163 .83843 .39541 Mtetra
.921 .856 .76 r
.83843 .39541 .84408 .40163 .8568 .38297 .85111 .3755 Mtetra
.772 .816 .888 r
.85111 .3755 .8568 .38297 .87055 .37444 .86488 .36651 Mtetra
.385 .665 .969 r
.23302 .55809 .24073 .56436 .25179 .56497 .24407 .55907 Mtetra
.69 .166 0 r
.24407 .55907 .25179 .56497 .26213 .5759 .25433 .57092 Mtetra
.855 .399 .078 r
.25433 .57092 .26213 .5759 .2721 .5937 .26425 .58921 Mtetra
0 .409 .79 r
.26425 .58921 .2721 .5937 .28316 .59898 .27539 .59353 Mtetra
.894 .775 .723 r
.27539 .59353 .28316 .59898 .29616 .57707 .28859 .56976 Mtetra
.904 .738 .665 r
.28859 .56976 .29616 .57707 .30985 .54316 .30252 .5337 Mtetra
.869 .724 .699 r
.30252 .5337 .30985 .54316 .32279 .51904 .31563 .50807 Mtetra
.75 .686 .79 r
.31563 .50807 .32279 .51904 .33485 .50878 .32767 .49864 Mtetra
.521 .614 .886 r
.32767 .49864 .33485 .50878 .34649 .50657 .3392 .49877 Mtetra
.366 .605 .94 r
.3392 .49877 .34649 .50657 .35805 .50706 .3507 .50079 Mtetra
.412 .68 .972 r
.3507 .50079 .35805 .50706 .36971 .50736 .36236 .50144 Mtetra
.515 .738 .975 r
.36236 .50144 .36971 .50736 .38149 .50661 .37418 .50041 Mtetra
.577 .753 .961 r
.37418 .50041 .38149 .50661 .39338 .50484 .38612 .49834 Mtetra
.607 .754 .948 r
.38612 .49834 .39338 .50484 .40537 .50234 .39815 .49569 Mtetra
.622 .755 .942 r
.39815 .49569 .40537 .50234 .41744 .49944 .41025 .49269 Mtetra
.632 .756 .937 r
.41025 .49269 .41744 .49944 .42957 .4963 .42242 .48943 Mtetra
.638 .755 .933 r
.42242 .48943 .42957 .4963 .44177 .493 .43465 .48602 Mtetra
.642 .754 .93 r
.43465 .48602 .44177 .493 .45403 .48955 .44695 .48248 Mtetra
.644 .753 .928 r
.44695 .48248 .45403 .48955 .46635 .48598 .4593 .47886 Mtetra
.646 .753 .927 r
.4593 .47886 .46635 .48598 .47873 .4823 .47172 .47517 Mtetra
.648 .754 .927 r
.47172 .47517 .47873 .4823 .49117 .47854 .48419 .47141 Mtetra
.649 .755 .927 r
.48419 .47141 .49117 .47854 .50366 .47471 .49673 .4676 Mtetra
.65 .757 .928 r
.49673 .4676 .50366 .47471 .51622 .47081 .50932 .46373 Mtetra
.652 .76 .929 r
.50932 .46373 .51622 .47081 .52884 .46684 .52198 .4598 Mtetra
.653 .762 .93 r
.52198 .4598 .52884 .46684 .54151 .46281 .53469 .45579 Mtetra
.656 .765 .93 r
.53469 .45579 .54151 .46281 .55424 .45871 .54746 .45169 Mtetra
.658 .767 .93 r
.54746 .45169 .55424 .45871 .56703 .45457 .56029 .44749 Mtetra
.662 .767 .928 r
.56029 .44749 .56703 .45457 .57988 .4504 .57318 .44318 Mtetra
.665 .765 .924 r
.57318 .44318 .57988 .4504 .59278 .44621 .58613 .43873 Mtetra
.668 .76 .919 r
.58613 .43873 .59278 .44621 .60575 .44197 .59913 .43419 Mtetra
.669 .752 .913 r
.59913 .43419 .60575 .44197 .61877 .43764 .61219 .4296 Mtetra
.667 .745 .909 r
.61219 .4296 .61877 .43764 .63185 .43313 .6253 .42504 Mtetra
.665 .744 .909 r
.6253 .42504 .63185 .43313 .64498 .42838 .63848 .42053 Mtetra
.667 .753 .915 r
.63848 .42053 .64498 .42838 .65815 .42336 .65172 .41595 Mtetra
.677 .77 .921 r
.65172 .41595 .65815 .42336 .67138 .4181 .665 .411 Mtetra
.694 .786 .921 r
.665 .411 .67138 .4181 .68463 .41252 .67832 .40548 Mtetra
.712 .794 .915 r
.67832 .40548 .68463 .41252 .69791 .40623 .69165 .39928 Mtetra
.738 .805 .905 r
.69165 .39928 .69791 .40623 .71117 .39888 .70497 .39207 Mtetra
.776 .819 .887 r
.70497 .39207 .71117 .39888 .7244 .39043 .71824 .3832 Mtetra
.799 .813 .863 r
.71824 .3832 .7244 .39043 .73765 .38183 .73144 .37294 Mtetra
.749 .76 .862 r
.73144 .37294 .73765 .38183 .75113 .37603 .74479 .36466 Mtetra
.474 .579 .879 r
.74479 .36466 .75113 .37603 .76529 .3786 .75891 .36629 Mtetra
0 .087 .646 r
.75891 .36629 .76529 .3786 .78072 .39553 .77445 .38471 Mtetra
.621 .219 0 r
.77445 .38471 .78072 .39553 .79726 .42255 .79115 .4139 Mtetra
0 .082 .623 r
.79115 .4139 .79726 .42255 .81302 .43689 .80709 .43012 Mtetra
.848 .848 .842 r
.80709 .43012 .81302 .43689 .82637 .42268 .8206 .41684 Mtetra
.959 .842 .683 r
.8206 .41684 .82637 .42268 .83843 .39541 .83271 .38898 Mtetra
.926 .851 .749 r
.83271 .38898 .83843 .39541 .85111 .3755 .84537 .36802 Mtetra
.781 .82 .883 r
.84537 .36802 .85111 .3755 .86488 .36651 .85915 .35856 Mtetra
.347 .649 .967 r
.22524 .55183 .23302 .55809 .24407 .55907 .23627 .55318 Mtetra
.722 .205 0 r
.23627 .55318 .24407 .55907 .25433 .57092 .24647 .56575 Mtetra
.848 .386 .056 r
.24647 .56575 .25433 .57092 .26425 .58921 .25641 .58353 Mtetra
.271 .634 .963 r
.25641 .58353 .26425 .58921 .27539 .59353 .26775 .58533 Mtetra
.877 .738 .705 r
.26775 .58533 .27539 .59353 .28859 .56976 .28116 .5597 Mtetra
.885 .716 .666 r
.28116 .5597 .28859 .56976 .30252 .5337 .2951 .5249 Mtetra
.866 .733 .713 r
.2951 .5249 .30252 .5337 .31563 .50807 .30813 .50168 Mtetra
.778 .786 .86 r
.30813 .50168 .31563 .50807 .32767 .49864 .32017 .49306 Mtetra
.474 .733 .983 r
.32017 .49306 .32767 .49864 .3392 .49877 .33175 .49252 Mtetra
.351 .652 .968 r
.33175 .49252 .3392 .49877 .3507 .50079 .34331 .49387 Mtetra
.447 .676 .962 r
.34331 .49387 .3507 .50079 .36236 .50144 .35501 .49427 Mtetra
.536 .707 .95 r
.35501 .49427 .36236 .50144 .37418 .50041 .36685 .49326 Mtetra
.585 .727 .941 r
.36685 .49326 .37418 .50041 .38612 .49834 .37882 .49121 Mtetra
.611 .738 .935 r
.37882 .49121 .38612 .49834 .39815 .49569 .39087 .48854 Mtetra
.624 .742 .932 r
.39087 .48854 .39815 .49569 .41025 .49269 .40301 .48552 Mtetra
.632 .745 .929 r
.40301 .48552 .41025 .49269 .42242 .48943 .41521 .48227 Mtetra
.637 .748 .928 r
.41521 .48227 .42242 .48943 .43465 .48602 .42748 .47886 Mtetra
.641 .75 .928 r
.42748 .47886 .43465 .48602 .44695 .48248 .43981 .47533 Mtetra
.643 .752 .928 r
.43981 .47533 .44695 .48248 .4593 .47886 .4522 .47171 Mtetra
.646 .754 .928 r
.4522 .47171 .4593 .47886 .47172 .47517 .46465 .468 Mtetra
.648 .755 .928 r
.46465 .468 .47172 .47517 .48419 .47141 .47716 .46422 Mtetra
.65 .756 .927 r
.47716 .46422 .48419 .47141 .49673 .4676 .48974 .46035 Mtetra
.651 .756 .926 r
.48974 .46035 .49673 .4676 .50932 .46373 .50237 .45642 Mtetra
.653 .755 .925 r
.50237 .45642 .50932 .46373 .52198 .4598 .51506 .45243 Mtetra
.654 .755 .924 r
.51506 .45243 .52198 .4598 .53469 .45579 .52781 .44837 Mtetra
.655 .755 .923 r
.52781 .44837 .53469 .45579 .54746 .45169 .54063 .44427 Mtetra
.655 .756 .924 r
.54063 .44427 .54746 .45169 .56029 .44749 .5535 .44015 Mtetra
.655 .759 .926 r
.5535 .44015 .56029 .44749 .57318 .44318 .56643 .43602 Mtetra
.654 .765 .931 r
.56643 .43602 .57318 .44318 .58613 .43873 .57942 .43187 Mtetra
.656 .776 .937 r
.57942 .43187 .58613 .43873 .59913 .43419 .59248 .42762 Mtetra
.662 .788 .941 r
.59248 .42762 .59913 .43419 .61219 .4296 .60558 .42314 Mtetra
.673 .796 .94 r
.60558 .42314 .61219 .4296 .6253 .42504 .61874 .4183 Mtetra
.684 .792 .932 r
.61874 .4183 .6253 .42504 .63848 .42053 .63195 .41312 Mtetra
.688 .774 .917 r
.63195 .41312 .63848 .42053 .65172 .41595 .6452 .40779 Mtetra
.684 .753 .904 r
.6452 .40779 .65172 .41595 .665 .411 .65852 .40255 Mtetra
.683 .746 .899 r
.65852 .40255 .665 .411 .67832 .40548 .67189 .39729 Mtetra
.7 .76 .898 r
.67189 .39729 .67832 .40548 .69165 .39928 .68528 .39138 Mtetra
.733 .779 .89 r
.68528 .39138 .69165 .39928 .70497 .39207 .69866 .38416 Mtetra
.766 .789 .872 r
.69866 .38416 .70497 .39207 .71824 .3832 .71198 .37537 Mtetra
.784 .796 .863 r
.71198 .37537 .71824 .3832 .73144 .37294 .72528 .36567 Mtetra
.746 .804 .898 r
.72528 .36567 .73144 .37294 .74479 .36466 .73873 .35799 Mtetra
.415 .682 .972 r
.73873 .35799 .74479 .36466 .75891 .36629 .75283 .35869 Mtetra
0 .037 .568 r
.75283 .35869 .75891 .36629 .77445 .38471 .76818 .37451 Mtetra
.623 .209 0 r
.76818 .37451 .77445 .38471 .79115 .4139 .78476 .40232 Mtetra
0 .096 .651 r
.78476 .40232 .79115 .4139 .80709 .43012 .80086 .42042 Mtetra
.782 .765 .838 r
.80086 .42042 .80709 .43012 .8206 .41684 .81467 .40972 Mtetra
.947 .825 .69 r
.81467 .40972 .8206 .41684 .83271 .38898 .82692 .38232 Mtetra
.929 .846 .741 r
.82692 .38232 .83271 .38898 .84537 .36802 .83958 .36053 Mtetra
.789 .824 .879 r
.83958 .36053 .84537 .36802 .85915 .35856 .85338 .3506 Mtetra
.311 .633 .963 r
.21739 .54559 .22524 .55183 .23627 .55318 .22841 .54727 Mtetra
.736 .223 0 r
.22841 .54727 .23627 .55318 .24647 .56575 .23856 .56019 Mtetra
.821 .341 0 r
.23856 .56019 .24647 .56575 .25641 .58353 .24862 .57637 Mtetra
.58 .724 .941 r
.24862 .57637 .25641 .58353 .26775 .58533 .26026 .57446 Mtetra
.86 .709 .694 r
.26026 .57446 .26775 .58533 .28116 .5597 .27382 .5478 Mtetra
.864 .7 .677 r
.27382 .5478 .28116 .5597 .2951 .5249 .28753 .51742 Mtetra
.857 .757 .752 r
.28753 .51742 .2951 .5249 .30813 .50168 .30029 .4993 Mtetra
.786 .908 .925 r
.30029 .4993 .30813 .50168 .32017 .49306 .31235 .4912 Mtetra
.545 .884 .987 r
.31235 .4912 .32017 .49306 .33175 .49252 .32415 .48775 Mtetra
.489 .77 .994 r
.32415 .48775 .33175 .49252 .34331 .49387 .33588 .48656 Mtetra
.509 .692 .951 r
.33588 .48656 .34331 .49387 .35501 .49427 .34765 .48607 Mtetra
.544 .681 .928 r
.34765 .48607 .35501 .49427 .36685 .49326 .35951 .48513 Mtetra
.578 .697 .923 r
.35951 .48513 .36685 .49326 .37882 .49121 .37148 .48339 Mtetra
.604 .716 .924 r
.37148 .48339 .37882 .49121 .39087 .48854 .38356 .48095 Mtetra
.62 .73 .925 r
.38356 .48095 .39087 .48854 .40301 .48552 .39572 .47803 Mtetra
.63 .737 .925 r
.39572 .47803 .40301 .48552 .41521 .48227 .40795 .47483 Mtetra
.636 .741 .924 r
.40795 .47483 .41521 .48227 .42748 .47886 .42025 .47145 Mtetra
.64 .744 .924 r
.42025 .47145 .42748 .47886 .43981 .47533 .43261 .46791 Mtetra
.644 .746 .923 r
.43261 .46791 .43981 .47533 .4522 .47171 .44504 .46423 Mtetra
.647 .746 .922 r
.44504 .46423 .4522 .47171 .46465 .468 .45753 .46045 Mtetra
.649 .746 .92 r
.45753 .46045 .46465 .468 .47716 .46422 .47008 .4566 Mtetra
.651 .746 .919 r
.47008 .4566 .47716 .46422 .48974 .46035 .48269 .45267 Mtetra
.653 .745 .918 r
.48269 .45267 .48974 .46035 .50237 .45642 .49536 .44867 Mtetra
.655 .745 .916 r
.49536 .44867 .50237 .45642 .51506 .45243 .50809 .44458 Mtetra
.658 .745 .914 r
.50809 .44458 .51506 .45243 .52781 .44837 .52088 .44038 Mtetra
.661 .743 .91 r
.52088 .44038 .52781 .44837 .54063 .44427 .53373 .43607 Mtetra
.664 .739 .906 r
.53373 .43607 .54063 .44427 .5535 .44015 .54663 .43164 Mtetra
.665 .732 .9 r
.54663 .43164 .5535 .44015 .56643 .43602 .5596 .42714 Mtetra
.665 .723 .893 r
.5596 .42714 .56643 .43602 .57942 .43187 .57262 .4226 Mtetra
.661 .713 .887 r
.57262 .4226 .57942 .43187 .59248 .42762 .58571 .41818 Mtetra
.654 .708 .886 r
.58571 .41818 .59248 .42762 .60558 .42314 .59886 .41395 Mtetra
.649 .713 .894 r
.59886 .41395 .60558 .42314 .61874 .4183 .61208 .4099 Mtetra
.652 .735 .91 r
.61208 .4099 .61874 .4183 .63195 .41312 .62536 .40575 Mtetra
.669 .772 .927 r
.62536 .40575 .63195 .41312 .6452 .40779 .63868 .401 Mtetra
.698 .799 .928 r
.63868 .401 .6452 .40779 .65852 .40255 .65203 .39529 Mtetra
.718 .792 .91 r
.65203 .39529 .65852 .40255 .67189 .39729 .6654 .38881 Mtetra
.721 .761 .884 r
.6654 .38881 .67189 .39729 .68528 .39138 .67879 .38198 Mtetra
.723 .74 .865 r
.67879 .38198 .68528 .39138 .69866 .38416 .69222 .37479 Mtetra
.732 .745 .862 r
.69222 .37479 .69866 .38416 .71198 .37537 .70566 .36715 Mtetra
.728 .773 .889 r
.70566 .36715 .71198 .37537 .72528 .36567 .71917 .36002 Mtetra
.659 .831 .966 r
.71917 .36002 .72528 .36567 .73873 .35799 .73287 .35518 Mtetra
.246 .718 .942 r
.73287 .35518 .73873 .35799 .75283 .35869 .74698 .35521 Mtetra
.443 0 0 r
.74698 .35521 .75283 .35869 .76818 .37451 .76197 .36564 Mtetra
0 0 .406 r
.76197 .36564 .76818 .37451 .78476 .40232 .77817 .38875 Mtetra
0 .107 .661 r
.77817 .38875 .78476 .40232 .80086 .42042 .79435 .40787 Mtetra
.694 .679 .831 r
.79435 .40787 .80086 .42042 .81467 .40972 .80854 .40101 Mtetra
.927 .803 .704 r
.80854 .40101 .81467 .40972 .82692 .38232 .82103 .37523 Mtetra
.927 .838 .736 r
.82103 .37523 .82692 .38232 .83958 .36053 .83374 .353 Mtetra
.796 .826 .875 r
.83374 .353 .83958 .36053 .85338 .3506 .84757 .34265 Mtetra
.286 .621 .96 r
.20947 .53933 .21739 .54559 .22841 .54727 .22048 .54123 Mtetra
.726 .211 0 r
.22048 .54123 .22841 .54727 .23856 .56019 .23064 .55396 Mtetra
.747 .24 0 r
.23064 .55396 .23856 .56019 .24862 .57637 .24089 .56762 Mtetra
.699 .719 .864 r
.24089 .56762 .24862 .57637 .26026 .57446 .25285 .56205 Mtetra
.848 .695 .691 r
.25285 .56205 .26026 .57446 .27382 .5478 .26643 .53584 Mtetra
.848 .699 .697 r
.26643 .53584 .27382 .5478 .28753 .51742 .27983 .5108 Mtetra
.829 .78 .805 r
.27983 .5108 .28753 .51742 .30029 .4993 .29229 .49784 Mtetra
.726 .936 .956 r
.29229 .49784 .30029 .4993 .31235 .4912 .30432 .49117 Mtetra
.621 .946 .943 r
.30432 .49117 .31235 .4912 .32415 .48775 .31632 .48548 Mtetra
.644 .903 .983 r
.31632 .48548 .32415 .48775 .33588 .48656 .3283 .48074 Mtetra
.606 .778 .963 r
.3283 .48074 .33588 .48656 .34765 .48607 .34022 .47791 Mtetra
.573 .696 .924 r
.34022 .47791 .34765 .48607 .35951 .48513 .35214 .47626 Mtetra
.575 .678 .91 r
.35214 .47626 .35951 .48513 .37148 .48339 .36413 .47467 Mtetra
.592 .689 .91 r
.36413 .47467 .37148 .48339 .38356 .48095 .37621 .47262 Mtetra
.609 .707 .914 r
.37621 .47262 .38356 .48095 .39572 .47803 .38839 .47003 Mtetra
.624 .722 .917 r
.38839 .47003 .39572 .47803 .40795 .47483 .40064 .46699 Mtetra
.634 .731 .918 r
.40064 .46699 .40795 .47483 .42025 .47145 .41297 .46365 Mtetra
.639 .735 .918 r
.41297 .46365 .42025 .47145 .43261 .46791 .42537 .46012 Mtetra
.643 .737 .917 r
.42537 .46012 .43261 .46791 .44504 .46423 .43783 .45648 Mtetra
.646 .74 .918 r
.43783 .45648 .44504 .46423 .45753 .46045 .45035 .45273 Mtetra
.649 .743 .918 r
.45035 .45273 .45753 .46045 .47008 .4566 .46293 .44887 Mtetra
.652 .745 .917 r
.46293 .44887 .47008 .4566 .48269 .45267 .47558 .44487 Mtetra
.656 .745 .915 r
.47558 .44487 .48269 .45267 .49536 .44867 .48829 .44075 Mtetra
.659 .743 .913 r
.48829 .44075 .49536 .44867 .50809 .44458 .50106 .43652 Mtetra
.661 .741 .91 r
.50106 .43652 .50809 .44458 .52088 .44038 .51388 .43221 Mtetra
.661 .739 .908 r
.51388 .43221 .52088 .44038 .53373 .43607 .52677 .42785 Mtetra
.52677 .42785 .53373 .43607 .54663 .43164 .53972 .42347 Mtetra
.662 .742 .909 r
.53972 .42347 .54663 .43164 .5596 .42714 .55272 .41905 Mtetra
.665 .746 .91 r
.55272 .41905 .5596 .42714 .57262 .4226 .56579 .4145 Mtetra
.672 .749 .908 r
.56579 .4145 .57262 .4226 .58571 .41818 .5789 .40969 Mtetra
.679 .742 .898 r
.5789 .40969 .58571 .41818 .59886 .41395 .59208 .40459 Mtetra
.679 .722 .881 r
.59208 .40459 .59886 .41395 .61208 .4099 .6053 .39938 Mtetra
.668 .692 .863 r
.6053 .39938 .61208 .4099 .62536 .40575 .61859 .39445 Mtetra
.653 .671 .855 r
.61859 .39445 .62536 .40575 .63868 .401 .63196 .39002 Mtetra
.653 .678 .861 r
.63196 .39002 .63868 .401 .65203 .39529 .64539 .38563 Mtetra
.682 .719 .877 r
.64539 .38563 .65203 .39529 .6654 .38881 .65884 .38018 Mtetra
.723 .76 .881 r
.65884 .38018 .6654 .38881 .67879 .38198 .67228 .37318 Mtetra
.729 .759 .876 r
.67228 .37318 .67879 .38198 .69222 .37479 .68575 .36585 Mtetra
.689 .742 .892 r
.68575 .36585 .69222 .37479 .70566 .36715 .69935 .36017 Mtetra
.613 .771 .956 r
.69935 .36017 .70566 .36715 .71917 .36002 .71314 .35679 Mtetra
.467 .833 .993 r
.71314 .35679 .71917 .36002 .73287 .35518 .72706 .35429 Mtetra
.223 .74 .859 r
.72706 .35429 .73287 .35518 .74698 .35521 .74113 .35268 Mtetra
0 .393 .721 r
.74113 .35268 .74698 .35521 .76197 .36564 .75578 .35761 Mtetra
0 0 .536 r
.75578 .35761 .76197 .36564 .77817 .38875 .77154 .37507 Mtetra
0 .12 .671 r
.77154 .37507 .77817 .38875 .79435 .40787 .78767 .39366 Mtetra
.611 .613 .829 r
.78767 .39366 .79435 .40787 .80854 .40101 .80222 .39059 Mtetra
.897 .777 .721 r
.80222 .39059 .80854 .40101 .82103 .37523 .81502 .3674 Mtetra
.919 .825 .737 r
.81502 .3674 .82103 .37523 .83374 .353 .82783 .34531 Mtetra
.8 .825 .87 r
.82783 .34531 .83374 .353 .84757 .34265 .8417 .33465 Mtetra
.285 .619 .959 r
.20149 .53295 .20947 .53933 .22048 .54123 .21251 .53488 Mtetra
.682 .16 0 r
.21251 .53488 .22048 .54123 .23064 .55396 .22273 .5468 Mtetra
.567 .049 0 r
.22273 .5468 .23064 .55396 .24089 .56762 .23321 .55759 Mtetra
.738 .703 .818 r
.23321 .55759 .24089 .56762 .25285 .56205 .2454 .54949 Mtetra
.841 .693 .698 r
.2454 .54949 .25285 .56205 .26643 .53584 .25891 .52513 Mtetra
.84 .712 .722 r
.25891 .52513 .26643 .53584 .27983 .5108 .27204 .50456 Mtetra
.795 .793 .851 r
.27204 .50456 .27983 .5108 .29229 .49784 .28431 .49487 Mtetra
.665 .885 .979 r
.28431 .49487 .29229 .49784 .30432 .49117 .29626 .49003 Mtetra
.639 .931 .97 r
.29626 .49003 .30432 .49117 .31632 .48548 .30829 .48474 Mtetra
.695 .952 .954 r
.30829 .48474 .31632 .48548 .3283 .48074 .32044 .47822 Mtetra
.707 .909 .966 r
.32044 .47822 .3283 .48074 .34022 .47791 .33259 .47223 Mtetra
.658 .799 .95 r
.33259 .47223 .34022 .47791 .35214 .47626 .34468 .46811 Mtetra
.609 .712 .917 r
.34468 .46811 .35214 .47626 .36413 .47467 .35675 .4655 Mtetra
.595 .68 .901 r
.35675 .4655 .36413 .47467 .37621 .47262 .36885 .46337 Mtetra
.601 .682 .898 r
.36885 .46337 .37621 .47262 .38839 .47003 .38104 .46105 Mtetra
.612 .693 .901 r
.38104 .46105 .38839 .47003 .40064 .46699 .3933 .45837 Mtetra
.623 .708 .906 r
.3933 .45837 .40064 .46699 .41297 .46365 .40565 .45534 Mtetra
.633 .721 .91 r
.40565 .45534 .41297 .46365 .42537 .46012 .41807 .45199 Mtetra
.642 .729 .912 r
.41807 .45199 .42537 .46012 .43783 .45648 .43056 .44835 Mtetra
.649 .732 .91 r
.43056 .44835 .43783 .45648 .45035 .45273 .44312 .44448 Mtetra
.654 .732 .907 r
.44312 .44448 .45035 .45273 .46293 .44887 .45574 .44043 Mtetra
.657 .729 .902 r
.45574 .44043 .46293 .44887 .47558 .44487 .46842 .43626 Mtetra
.657 .725 .899 r
.46842 .43626 .47558 .44487 .48829 .44075 .48117 .43204 Mtetra
.657 .724 .898 r
.48117 .43204 .48829 .44075 .50106 .43652 .49397 .42783 Mtetra
.655 .725 .9 r
.49397 .42783 .50106 .43652 .51388 .43221 .50683 .42364 Mtetra
.655 .728 .903 r
.50683 .42364 .51388 .43221 .52677 .42785 .51975 .41946 Mtetra
.655 .734 .908 r
.51975 .41946 .52677 .42785 .53972 .42347 .53274 .41526 Mtetra
.656 .74 .912 r
.53274 .41526 .53972 .42347 .55272 .41905 .54578 .41101 Mtetra
.657 .746 .916 r
.54578 .41101 .55272 .41905 .56579 .4145 .55889 .40669 Mtetra
.657 .754 .921 r
.55889 .40669 .56579 .4145 .5789 .40969 .57206 .40234 Mtetra
.663 .77 .929 r
.57206 .40234 .5789 .40969 .59208 .40459 .58529 .39777 Mtetra
.681 .793 .934 r
.58529 .39777 .59208 .40459 .6053 .39938 .59857 .39259 Mtetra
.709 .803 .923 r
.59857 .39259 .6053 .39938 .61859 .39445 .61187 .38646 Mtetra
.724 .775 .893 r
.61187 .38646 .61859 .39445 .63196 .39002 .62521 .37962 Mtetra
.704 .712 .855 r
.62521 .37962 .63196 .39002 .64539 .38563 .6386 .37305 Mtetra
.667 .657 .83 r
.6386 .37305 .64539 .38563 .65884 .38018 .65208 .36769 Mtetra
.643 .648 .84 r
.65208 .36769 .65884 .38018 .67228 .37318 .66568 .36347 Mtetra
.629 .7 .897 r
.66568 .36347 .67228 .37318 .68575 .36585 .67937 .35995 Mtetra
.566 .788 .983 r
.67937 .35995 .68575 .36585 .69935 .36017 .69319 .35728 Mtetra
.42 .82 .982 r
.69319 .35728 .69935 .36017 .71314 .35679 .70712 .35514 Mtetra
.406 .842 .944 r
.70712 .35514 .71314 .35679 .72706 .35429 .72109 .35207 Mtetra
.474 .866 .97 r
.72109 .35207 .72706 .35429 .74113 .35268 .73511 .34856 Mtetra
.222 .664 .953 r
.73511 .34856 .74113 .35268 .75578 .35761 .74955 .34998 Mtetra
0 .17 .684 r
.74955 .34998 .75578 .35761 .77154 .37507 .76498 .36267 Mtetra
0 .152 .695 r
.76498 .36267 .77154 .37507 .78767 .39366 .78094 .37925 Mtetra
.548 .578 .836 r
.78094 .37925 .78767 .39366 .80222 .39059 .79573 .37877 Mtetra
.864 .753 .738 r
.79573 .37877 .80222 .39059 .81502 .3674 .80887 .35856 Mtetra
.904 .808 .743 r
.80887 .35856 .81502 .3674 .82783 .34531 .82184 .33726 Mtetra
.799 .817 .866 r
.82184 .33726 .82783 .34531 .8417 .33465 .83577 .32651 Mtetra
.313 .627 .961 r
.19345 .52632 .20149 .53295 .21251 .53488 .20451 .52804 Mtetra
.588 .063 0 r
.20451 .52804 .21251 .53488 .22273 .5468 .21484 .53867 Mtetra
0 .195 .696 r
.21484 .53867 .22273 .5468 .23321 .55759 .22554 .54681 Mtetra
.747 .694 .801 r
.22554 .54681 .23321 .55759 .2454 .54949 .23785 .53767 Mtetra
.836 .7 .713 r
.23785 .53767 .2454 .54949 .25891 .52513 .2512 .51597 Mtetra
.837 .733 .75 r
.2512 .51597 .25891 .52513 .27204 .50456 .26414 .49861 Mtetra
.774 .803 .876 r
.26414 .49861 .27204 .50456 .28431 .49487 .27636 .49029 Mtetra
.651 .832 .97 r
.27636 .49029 .28431 .49487 .29626 .49003 .2883 .48618 Mtetra
.63 .852 .984 r
.2883 .48618 .29626 .49003 .30829 .48474 .30029 .48226 Mtetra
.671 .904 .978 r
.30029 .48226 .30829 .48474 .32044 .47822 .3124 .47702 Mtetra
.705 .944 .958 r
.3124 .47702 .32044 .47822 .33259 .47223 .32465 .47046 Mtetra
.724 .933 .958 r
.32465 .47046 .33259 .47223 .34468 .46811 .33694 .46372 Mtetra
.701 .852 .955 r
.33694 .46372 .34468 .46811 .35675 .4655 .3492 .45824 Mtetra
.651 .753 .924 r
.3492 .45824 .35675 .4655 .36885 .46337 .36142 .45437 Mtetra
.619 .697 .9 r
.36142 .45437 .36885 .46337 .38104 .46105 .37365 .45148 Mtetra
.613 .681 .89 r
.37365 .45148 .38104 .46105 .3933 .45837 .38595 .44877 Mtetra
.619 .684 .889 r
.38595 .44877 .3933 .45837 .40565 .45534 .39831 .44586 Mtetra
.628 .69 .889 r
.39831 .44586 .40565 .45534 .41807 .45199 .41075 .44265 Mtetra
.636 .698 .89 r
.41075 .44265 .41807 .45199 .43056 .44835 .42327 .43917 Mtetra
.642 .705 .892 r
.42327 .43917 .43056 .44835 .44312 .44448 .43585 .43546 Mtetra
.646 .711 .895 r
.43585 .43546 .44312 .44448 .45574 .44043 .4485 .43161 Mtetra
.646 .717 .9 r
.4485 .43161 .45574 .44043 .46842 .43626 .46121 .42774 Mtetra
.645 .725 .907 r
.46121 .42774 .46842 .43626 .48117 .43204 .47398 .42391 Mtetra
.642 .736 .917 r
.47398 .42391 .48117 .43204 .49397 .42783 .48681 .42011 Mtetra
.642 .748 .926 r
.48681 .42011 .49397 .42783 .50683 .42364 .49971 .4163 Mtetra
.644 .761 .934 r
.49971 .4163 .50683 .42364 .51975 .41946 .51268 .41236 Mtetra
.65 .771 .937 r
.51268 .41236 .51975 .41946 .53274 .41526 .5257 .40821 Mtetra
.659 .776 .936 r
.5257 .40821 .53274 .41526 .54578 .41101 .53879 .40378 Mtetra
.668 .775 .93 r
.53879 .40378 .54578 .41101 .55889 .40669 .55194 .39907 Mtetra
.678 .768 .919 r
.55194 .39907 .55889 .40669 .57206 .40234 .56515 .39402 Mtetra
.68 .751 .904 r
.56515 .39402 .57206 .40234 .58529 .39777 .5784 .38883 Mtetra
.678 .735 .894 r
.5784 .38883 .58529 .39777 .59857 .39259 .59172 .38366 Mtetra
.68 .737 .894 r
.59172 .38366 .59857 .39259 .61187 .38646 .6051 .37838 Mtetra
.701 .767 .903 r
.6051 .37838 .61187 .38646 .62521 .37962 .61851 .37238 Mtetra
.725 .799 .91 r
.61851 .37238 .62521 .37962 .6386 .37305 .63194 .36554 Mtetra
.705 .787 .915 r
.63194 .36554 .6386 .37305 .65208 .36769 .64545 .35942 Mtetra
.612 .732 .931 r
.64545 .35942 .65208 .36769 .66568 .36347 .65913 .35628 Mtetra
.474 .703 .969 r
.65913 .35628 .66568 .36347 .67937 .35995 .67303 .35595 Mtetra
.376 .762 .989 r
.67303 .35595 .67937 .35995 .69319 .35728 .68701 .35523 Mtetra
.443 .854 .963 r
.68701 .35523 .69319 .35728 .70712 .35514 .70095 .35203 Mtetra
.599 .898 .987 r
.70095 .35203 .70712 .35514 .72109 .35207 .71488 .34716 Mtetra
.624 .851 .986 r
.71488 .34716 .72109 .35207 .73511 .34856 .7289 .34271 Mtetra
.415 .722 .988 r
.7289 .34271 .73511 .34856 .74955 .34998 .7433 .34264 Mtetra
0 .32 .796 r
.7433 .34264 .74955 .34998 .76498 .36267 .75849 .35187 Mtetra
0 .214 .738 r
.75849 .35187 .76498 .36267 .78094 .37925 .77424 .36557 Mtetra
.516 .573 .852 r
.77424 .36557 .78094 .37925 .79573 .37877 .78914 .36613 Mtetra
.834 .735 .755 r
.78914 .36613 .79573 .37877 .80887 .35856 .80258 .34865 Mtetra
.884 .79 .751 r
.80258 .34865 .80887 .35856 .82184 .33726 .81575 .32867 Mtetra
.791 .803 .862 r
.81575 .32867 .82184 .33726 .83577 .32651 .82976 .31808 Mtetra
.363 .641 .962 r
.18538 .51933 .19345 .52632 .20451 .52804 .1965 .52063 Mtetra
0 .076 .565 r
.1965 .52063 .20451 .52804 .21484 .53867 .20696 .52971 Mtetra
.009 .372 .839 r
.20696 .52971 .21484 .53867 .22554 .54681 .21784 .53583 Mtetra
.743 .691 .801 r
.21784 .53583 .22554 .54681 .23785 .53767 .23015 .52689 Mtetra
.831 .711 .732 r
.23015 .52689 .23785 .53767 .2512 .51597 .24333 .50798 Mtetra
.833 .754 .776 r
.24333 .50798 .2512 .51597 .26414 .49861 .25615 .49287 Mtetra
.767 .81 .887 r
.25615 .49287 .26414 .49861 .27636 .49029 .26839 .48497 Mtetra
.664 .812 .954 r
.26839 .48497 .27636 .49029 .2883 .48618 .28038 .48064 Mtetra
.636 .799 .961 r
.28038 .48064 .2883 .48618 .30029 .48226 .29238 .477 Mtetra
.645 .812 .963 r
.29238 .477 .30029 .48226 .3124 .47702 .30445 .47308 Mtetra
.662 .859 .975 r
.30445 .47308 .3124 .47702 .32465 .47046 .31663 .46845 Mtetra
.68 .921 .972 r
.31663 .46845 .32465 .47046 .33694 .46372 .32892 .4627 Mtetra
.7 .95 .955 r
.32892 .4627 .33694 .46372 .3492 .45824 .3413 .45602 Mtetra
.719 .924 .961 r
.3413 .45602 .3492 .45824 .36142 .45437 .35372 .44944 Mtetra
.702 .839 .948 r
.35372 .44944 .36142 .45437 .37365 .45148 .36612 .44389 Mtetra
.664 .751 .915 r
.36612 .44389 .37365 .45148 .38595 .44877 .37851 .43954 Mtetra
.639 .701 .891 r
.37851 .43954 .38595 .44877 .39831 .44586 .39093 .43596 Mtetra
.632 .684 .881 r
.39093 .43596 .39831 .44586 .41075 .44265 .4034 .43258 Mtetra
.634 .682 .877 r
.4034 .43258 .41075 .44265 .42327 .43917 .41594 .42909 Mtetra
.637 .683 .877 r
.41594 .42909 .42327 .43917 .43585 .43546 .42855 .42551 Mtetra
.637 .687 .881 r
.42855 .42551 .43585 .43546 .4485 .43161 .44122 .42192 Mtetra
.637 .694 .887 r
.44122 .42192 .4485 .43161 .46121 .42774 .45395 .41832 Mtetra
.639 .702 .892 r
.45395 .41832 .46121 .42774 .47398 .42391 .46675 .41462 Mtetra
.646 .709 .893 r
.46675 .41462 .47398 .42391 .48681 .42011 .47962 .41068 Mtetra
.656 .71 .887 r
.47962 .41068 .48681 .42011 .49971 .4163 .49255 .40636 Mtetra
.665 .703 .875 r
.49255 .40636 .49971 .4163 .51268 .41236 .50555 .40162 Mtetra
.669 .688 .859 r
.50555 .40162 .51268 .41236 .5257 .40821 .51861 .3966 Mtetra
.667 .671 .844 r
.51861 .3966 .5257 .40821 .53879 .40378 .53172 .39149 Mtetra
.662 .658 .835 r
.53172 .39149 .53879 .40378 .55194 .39907 .5449 .38647 Mtetra
.657 .651 .832 r
.5449 .38647 .55194 .39907 .56515 .39402 .55813 .38163 Mtetra
.658 .656 .836 r
.55813 .38163 .56515 .39402 .5784 .38883 .57142 .37675 Mtetra
.66 .663 .841 r
.57142 .37675 .5784 .38883 .59172 .38366 .58477 .37181 Mtetra
.65 .663 .849 r
.58477 .37181 .59172 .38366 .6051 .37838 .59819 .36733 Mtetra
.622 .668 .873 r
.59819 .36733 .6051 .37838 .61851 .37238 .61171 .364 Mtetra
.584 .718 .935 r
.61171 .364 .61851 .37238 .63194 .36554 .62533 .36161 Mtetra
.508 .831 .999 r
.62533 .36161 .63194 .36554 .64545 .35942 .63903 .35896 Mtetra
.354 .826 .88 r
.63903 .35896 .64545 .35942 .65913 .35628 .65278 .35551 Mtetra
.372 .835 .899 r
.65278 .35551 .65913 .35628 .67303 .35595 .66661 .35209 Mtetra
.518 .84 .999 r
.66661 .35209 .67303 .35595 .68701 .35523 .68054 .34913 Mtetra
.608 .804 .975 r
.68054 .34913 .68701 .35523 .70095 .35203 .69452 .34547 Mtetra
.658 .809 .956 r
.69452 .34547 .70095 .35203 .71488 .34716 .70851 .34061 Mtetra
.642 .805 .961 r
.70851 .34061 .71488 .34716 .7289 .34271 .72259 .33616 Mtetra
.468 .728 .982 r
.72259 .33616 .7289 .34271 .7433 .34264 .737 .33549 Mtetra
.031 .431 .868 r
.737 .33549 .7433 .34264 .75849 .35187 .75205 .34228 Mtetra
0 .304 .798 r
.75205 .34228 .75849 .35187 .77424 .36557 .76758 .35295 Mtetra
.516 .594 .871 r
.76758 .35295 .77424 .36557 .78914 .36613 .78248 .35321 Mtetra
.812 .725 .769 r
.78248 .35321 .78914 .36613 .80258 .34865 .79616 .33782 Mtetra
.862 .772 .761 r
.79616 .33782 .80258 .34865 .81575 .32867 .80955 .31943 Mtetra
.778 .786 .859 r
.80955 .31943 .81575 .32867 .82976 .31808 .82366 .30925 Mtetra
.419 .655 .957 r
.17729 .5119 .18538 .51933 .1965 .52063 .18847 .51264 Mtetra
0 .229 .72 r
.18847 .51264 .1965 .52063 .20696 .52971 .19908 .52015 Mtetra
.169 .457 .883 r
.19908 .52015 .20696 .52971 .21784 .53583 .21007 .52495 Mtetra
.729 .69 .813 r
.21007 .52495 .21784 .53583 .23015 .52689 .22232 .51704 Mtetra
.824 .724 .755 r
.22232 .51704 .23015 .52689 .24333 .50798 .23533 .50073 Mtetra
.828 .77 .798 r
.23533 .50073 .24333 .50798 .25615 .49287 .24808 .48715 Mtetra
.765 .813 .89 r
.24808 .48715 .25615 .49287 .26839 .48497 .26036 .47932 Mtetra
.68 .806 .943 r
.26036 .47932 .26839 .48497 .28038 .48064 .27242 .47457 Mtetra
.649 .787 .948 r
.27242 .47457 .28038 .48064 .29238 .477 .28447 .47065 Mtetra
.647 .78 .944 r
.28447 .47065 .29238 .477 .30445 .47308 .29658 .46679 Mtetra
.649 .783 .945 r
.29658 .46679 .30445 .47308 .31663 .46845 .30874 .46286 Mtetra
.651 .806 .958 r
.30874 .46286 .31663 .46845 .32892 .4627 .32097 .45877 Mtetra
.654 .861 .978 r
.32097 .45877 .32892 .4627 .3413 .45602 .33329 .4542 Mtetra
.656 .924 .975 r
.33329 .4542 .3413 .45602 .35372 .44944 .3457 .44868 Mtetra
.667 .951 .954 r
.3457 .44868 .35372 .44944 .36612 .44389 .35821 .44232 Mtetra
.699 .941 .961 r
.35821 .44232 .36612 .44389 .37851 .43954 .37077 .43577 Mtetra
.714 .882 .959 r
.37077 .43577 .37851 .43954 .39093 .43596 .38334 .42961 Mtetra
.696 .799 .929 r
.38334 .42961 .39093 .43596 .4034 .43258 .39593 .42418 Mtetra
.667 .735 .901 r
.39593 .42418 .4034 .43258 .41594 .42909 .40854 .41963 Mtetra
.646 .703 .888 r
.40854 .41963 .41594 .42909 .42855 .42551 .42119 .41571 Mtetra
.64 .694 .884 r
.42119 .41571 .42855 .42551 .44122 .42192 .43389 .41198 Mtetra
.644 .693 .881 r
.43389 .41198 .44122 .42192 .45395 .41832 .44666 .40809 Mtetra
.652 .69 .873 r
.44666 .40809 .45395 .41832 .46675 .41462 .45949 .40388 Mtetra
.661 .684 .861 r
.45949 .40388 .46675 .41462 .47962 .41068 .4724 .39922 Mtetra
.668 .673 .846 r
.4724 .39922 .47962 .41068 .49255 .40636 .48537 .39413 Mtetra
.67 .661 .833 r
.48537 .39413 .49255 .40636 .50555 .40162 .4984 .38878 Mtetra
.667 .65 .824 r
.4984 .38878 .50555 .40162 .51861 .3966 .51148 .38342 Mtetra
.662 .644 .821 r
.51148 .38342 .51861 .3966 .53172 .39149 .52461 .37822 Mtetra
.656 .64 .822 r
.52461 .37822 .53172 .39149 .5449 .38647 .53781 .3733 Mtetra
.648 .638 .827 r
.53781 .3733 .5449 .38647 .55813 .38163 .55106 .36875 Mtetra
.63 .636 .838 r
.55106 .36875 .55813 .38163 .57142 .37675 .56439 .36504 Mtetra
.605 .646 .865 r
.56439 .36504 .57142 .37675 .58477 .37181 .57781 .36233 Mtetra
.569 .682 .916 r
.57781 .36233 .58477 .37181 .59819 .36733 .59132 .36052 Mtetra
.497 .729 .976 r
.59132 .36052 .59819 .36733 .61171 .364 .60495 .35952 Mtetra
.391 .756 .993 r
.60495 .35952 .61171 .364 .62533 .36161 .61868 .3589 Mtetra
.387 .807 .973 r
.61868 .3589 .62533 .36161 .63903 .35896 .63248 .35701 Mtetra
.539 .901 .969 r
.63248 .35701 .63903 .35896 .65278 .35551 .64626 .35242 Mtetra
.663 .918 .976 r
.64626 .35242 .65278 .35551 .66661 .35209 .66004 .34631 Mtetra
.664 .836 .966 r
.66004 .34631 .66661 .35209 .68054 .34913 .67393 .34116 Mtetra
.631 .757 .938 r
.67393 .34116 .68054 .34913 .69452 .34547 .68794 .33725 Mtetra
.636 .753 .933 r
.68794 .33725 .69452 .34547 .70851 .34061 .70203 .33318 Mtetra
.626 .773 .951 r
.70203 .33318 .70851 .34061 .72259 .33616 .7162 .32928 Mtetra
.485 .728 .978 r
.7162 .32928 .72259 .33616 .737 .33549 .73064 .32839 Mtetra
.137 .511 .912 r
.73064 .32839 .737 .33549 .75205 .34228 .74561 .33344 Mtetra
.066 .407 .86 r
.74561 .33344 .75205 .34228 .76758 .35295 .76095 .34128 Mtetra
.544 .63 .887 r
.76095 .34128 .76758 .35295 .78248 .35321 .7758 .34037 Mtetra
.798 .723 .781 r
.7758 .34037 .78248 .35321 .79616 .33782 .78965 .32632 Mtetra
.841 .758 .771 r
.78965 .32632 .79616 .33782 .80955 .31943 .80324 .30956 Mtetra
.762 .768 .858 r
.80324 .30956 .80955 .31943 .82366 .30925 .81747 .29994 Mtetra
.47 .667 .949 r
.16916 .50406 .17729 .5119 .18847 .51264 .18042 .50416 Mtetra
0 .36 .827 r
.18042 .50416 .18847 .51264 .19908 .52015 .19117 .51019 Mtetra
.243 .491 .893 r
.19117 .51019 .19908 .52015 .21007 .52495 .20223 .51428 Mtetra
.704 .687 .831 r
.20223 .51428 .21007 .52495 .22232 .51704 .21437 .50787 Mtetra
.813 .735 .778 r
.21437 .50787 .22232 .51704 .23533 .50073 .22723 .49387 Mtetra
.822 .781 .814 r
.22723 .49387 .23533 .50073 .24808 .48715 .23994 .48138 Mtetra
.766 .813 .89 r
.23994 .48138 .24808 .48715 .26036 .47932 .25227 .47345 Mtetra
.693 .804 .933 r
.25227 .47345 .26036 .47932 .27242 .47457 .2644 .46829 Mtetra
.661 .786 .94 r
.2644 .46829 .27242 .47457 .28447 .47065 .27651 .46404 Mtetra
.653 .775 .938 r
.27651 .46404 .28447 .47065 .29658 .46679 .28866 .46003 Mtetra
.652 .771 .936 r
.28866 .46003 .29658 .46679 .30874 .46286 .30086 .45603 Mtetra
.654 .771 .935 r
.30086 .45603 .30874 .46286 .32097 .45877 .31312 .45197 Mtetra
.654 .772 .936 r
.31312 .45197 .32097 .45877 .33329 .4542 .32545 .44788 Mtetra
.65 .787 .947 r
.32545 .44788 .33329 .4542 .3457 .44868 .33782 .44383 Mtetra
.646 .833 .973 r
.33782 .44383 .3457 .44868 .35821 .44232 .35026 .4396 Mtetra
.638 .898 .985 r
.35026 .4396 .35821 .44232 .37077 .43577 .36279 .43474 Mtetra
.623 .936 .962 r
.36279 .43474 .37077 .43577 .38334 .42961 .37541 .42914 Mtetra
.609 .941 .946 r
.37541 .42914 .38334 .42961 .39593 .42418 .38808 .42333 Mtetra
.616 .938 .956 r
.38808 .42333 .39593 .42418 .40854 .41963 .4008 .41763 Mtetra
.658 .926 .974 r
.4008 .41763 .40854 .41963 .42119 .41571 .41356 .41189 Mtetra
.694 .883 .968 r
.41356 .41189 .42119 .41571 .43389 .41198 .42638 .40609 Mtetra
.696 .82 .941 r
.42638 .40609 .43389 .41198 .44666 .40809 .43923 .40051 Mtetra
.688 .769 .913 r
.43923 .40051 .44666 .40809 .45949 .40388 .45214 .39517 Mtetra
.683 .739 .894 r
.45214 .39517 .45949 .40388 .4724 .39922 .46509 .38989 Mtetra
.679 .724 .884 r
.46509 .38989 .4724 .39922 .48537 .39413 .4781 .38466 Mtetra
.669 .718 .886 r
.4781 .38466 .48537 .39413 .4984 .38878 .49116 .37978 Mtetra
.653 .725 .902 r
.49116 .37978 .4984 .38878 .51148 .38342 .50427 .37549 Mtetra
.63 .746 .931 r
.50427 .37549 .51148 .38342 .52461 .37822 .51744 .37184 Mtetra
.601 .784 .968 r
.51744 .37184 .52461 .37822 .53781 .3733 .53069 .36864 Mtetra
.55 .822 .997 r
.53069 .36864 .53781 .3733 .55106 .36875 .54401 .36578 Mtetra
.475 .843 .99 r
.54401 .36578 .55106 .36875 .56439 .36504 .55742 .36305 Mtetra
.405 .833 .959 r
.55742 .36305 .56439 .36504 .57781 .36233 .5709 .36045 Mtetra
.414 .84 .957 r
.5709 .36045 .57781 .36233 .59132 .36052 .58447 .35762 Mtetra
.512 .864 .99 r
.58447 .35762 .59132 .36052 .60495 .35952 .5981 .3542 Mtetra
.581 .818 .989 r
.5981 .3542 .60495 .35952 .61868 .3589 .61181 .35089 Mtetra
.583 .734 .947 r
.61181 .35089 .61868 .3589 .63248 .35701 .62562 .34832 Mtetra
.612 .728 .928 r
.62562 .34832 .63248 .35701 .64626 .35242 .6395 .34505 Mtetra
.679 .792 .934 r
.6395 .34505 .64626 .35242 .66004 .34631 .65336 .33962 Mtetra
.696 .819 .941 r
.65336 .33962 .66004 .34631 .67393 .34116 .66727 .33359 Mtetra
.652 .779 .941 r
.66727 .33359 .67393 .34116 .68794 .33725 .6813 .32898 Mtetra
.621 .747 .937 r
.6813 .32898 .68794 .33725 .70203 .33318 .69546 .3253 Mtetra
.602 .752 .949 r
.69546 .3253 .70203 .33318 .7162 .32928 .70972 .32206 Mtetra
.487 .72 .974 r
.70972 .32206 .7162 .32928 .73064 .32839 .72422 .32124 Mtetra
.219 .566 .938 r
.72422 .32124 .73064 .32839 .74561 .33344 .73915 .325 Mtetra
.19 .507 .911 r
.73915 .325 .74561 .33344 .76095 .34128 .75433 .33027 Mtetra
.591 .671 .895 r
.75433 .33027 .76095 .34128 .7758 .34037 .76908 .32768 Mtetra
.792 .725 .79 r
.76908 .32768 .7758 .34037 .78965 .32632 .78305 .31434 Mtetra
.821 .746 .782 r
.78305 .31434 .78965 .32632 .80324 .30956 .79684 .29915 Mtetra
.746 .753 .858 r
.79684 .29915 .80324 .30956 .81747 .29994 .81119 .29018 Mtetra
.513 .678 .94 r
.161 .49592 .16916 .50406 .18042 .50416 .17235 .49534 Mtetra
.129 .458 .887 r
.17235 .49534 .18042 .50416 .19117 .51019 .18323 .49996 Mtetra
.274 .503 .895 r
.18323 .49996 .19117 .51019 .20223 .51428 .19431 .50373 Mtetra
.667 .679 .852 r
.19431 .50373 .20223 .51428 .21437 .50787 .20631 .49907 Mtetra
.797 .742 .802 r
.20631 .49907 .21437 .50787 .22723 .49387 .21902 .48721 Mtetra
.815 .788 .827 r
.21902 .48721 .22723 .49387 .23994 .48138 .23172 .47555 Mtetra
.769 .812 .887 r
.23172 .47555 .23994 .48138 .25227 .47345 .2441 .46744 Mtetra
.705 .803 .926 r
.2441 .46744 .25227 .47345 .2644 .46829 .25631 .46187 Mtetra
.671 .786 .935 r
.25631 .46187 .2644 .46829 .27651 .46404 .26848 .45734 Mtetra
.66 .776 .935 r
.26848 .45734 .27651 .46404 .28866 .46003 .28068 .4531 Mtetra
.656 .769 .933 r
.28068 .4531 .28866 .46003 .30086 .45603 .29292 .44896 Mtetra
.653 .765 .932 r
.29292 .44896 .30086 .45603 .31312 .45197 .30522 .4449 Mtetra
.654 .766 .932 r
.30522 .4449 .31312 .45197 .32545 .44788 .31758 .44078 Mtetra
.66 .768 .93 r
.31758 .44078 .32545 .44788 .33782 .44383 .33 .43647 Mtetra
.662 .762 .925 r
.33 .43647 .33782 .44383 .35026 .4396 .34249 .4321 Mtetra
.661 .759 .923 r
.34249 .4321 .35026 .4396 .36279 .43474 .35503 .42774 Mtetra
.649 .771 .938 r
.35503 .42774 .36279 .43474 .37541 .42914 .36761 .42366 Mtetra
.631 .814 .971 r
.36761 .42366 .37541 .42914 .38808 .42333 .38025 .41979 Mtetra
.624 .874 .989 r
.38025 .41979 .38808 .42333 .4008 .41763 .39297 .4154 Mtetra
.632 .914 .98 r
.39297 .4154 .4008 .41763 .41356 .41189 .40577 .4102 Mtetra
.612 .922 .973 r
.40577 .4102 .41356 .41189 .42638 .40609 .41863 .40498 Mtetra
.55 .912 .959 r
.41863 .40498 .42638 .40609 .43923 .40051 .43153 .40023 Mtetra
.49 .897 .921 r
.43153 .40023 .43923 .40051 .45214 .39517 .44449 .39558 Mtetra
.461 .888 .882 r
.44449 .39558 .45214 .39517 .46509 .38989 .45751 .39064 Mtetra
.425 .87 .854 r
.45751 .39064 .46509 .38989 .4781 .38466 .47059 .38576 Mtetra
.342 .821 .806 r
.47059 .38576 .4781 .38466 .49116 .37978 .48372 .38144 Mtetra
.24 .751 .73 r
.48372 .38144 .49116 .37978 .50427 .37549 .49691 .37761 Mtetra
.202 .719 .682 r
.49691 .37761 .50427 .37549 .51744 .37184 .51017 .37373 Mtetra
.253 .757 .718 r
.51017 .37373 .51744 .37184 .53069 .36864 .52349 .36947 Mtetra
.388 .849 .83 r
.52349 .36947 .53069 .36864 .54401 .36578 .53689 .36468 Mtetra
.55 .917 .948 r
.53689 .36468 .54401 .36578 .55742 .36305 .55034 .35948 Mtetra
.642 .893 .985 r
.55034 .35948 .55742 .36305 .5709 .36045 .56385 .35425 Mtetra
.652 .814 .961 r
.56385 .35425 .5709 .36045 .58447 .35762 .57744 .34958 Mtetra
.644 .757 .931 r
.57744 .34958 .58447 .35762 .5981 .3542 .59109 .34534 Mtetra
.634 .732 .919 r
.59109 .34534 .5981 .3542 .61181 .35089 .60483 .34144 Mtetra
.601 .704 .916 r
.60483 .34144 .61181 .35089 .62562 .34832 .61867 .33856 Mtetra
.589 .692 .913 r
.61867 .33856 .62562 .34832 .6395 .34505 .63262 .33604 Mtetra
.64 .734 .917 r
.63262 .33604 .6395 .34505 .65336 .33962 .64658 .33189 Mtetra
.687 .788 .927 r
.64658 .33189 .65336 .33962 .66727 .33359 .66055 .32615 Mtetra
.666 .79 .94 r
.66055 .32615 .66727 .33359 .6813 .32898 .67462 .32103 Mtetra
.619 .758 .945 r
.67462 .32103 .6813 .32898 .69546 .3253 .68882 .31732 Mtetra
.581 .742 .953 r
.68882 .31732 .69546 .3253 .70972 .32206 .70317 .31459 Mtetra
.479 .71 .971 r
.70317 .31459 .70972 .32206 .72422 .32124 .71773 .31396 Mtetra
.282 .605 .953 r
.71773 .31396 .72422 .32124 .73915 .325 .73263 .31673 Mtetra
.316 .595 .945 r
.73263 .31673 .73915 .325 .75433 .33027 .74769 .31959 Mtetra
.644 .705 .891 r
.74769 .31959 .75433 .33027 .76908 .32768 .76234 .31507 Mtetra
.789 .726 .794 r
.76234 .31507 .76908 .32768 .78305 .31434 .77638 .30206 Mtetra
.801 .737 .792 r
.77638 .30206 .78305 .31434 .79684 .29915 .79036 .28834 Mtetra
.729 .74 .86 r
.79036 .28834 .79684 .29915 .81119 .29018 .80483 .28007 Mtetra
.549 .689 .932 r
.15278 .48761 .161 .49592 .17235 .49534 .16422 .48634 Mtetra
.262 .533 .917 r
.16422 .48634 .17235 .49534 .18323 .49996 .17525 .48958 Mtetra
.291 .51 .895 r
.17525 .48958 .18323 .49996 .19431 .50373 .18635 .49314 Mtetra
.615 .661 .872 r
.18635 .49314 .19431 .50373 .20631 .49907 .19818 .49034 Mtetra
.773 .743 .826 r
.19818 .49034 .20631 .49907 .21902 .48721 .21074 .48058 Mtetra
.806 .791 .838 r
.21074 .48058 .21902 .48721 .23172 .47555 .22341 .46968 Mtetra
.772 .813 .885 r
.22341 .46968 .23172 .47555 .2441 .46744 .23587 .46135 Mtetra
.716 .804 .92 r
.23587 .46135 .2441 .46744 .25631 .46187 .24815 .45538 Mtetra
.68 .787 .931 r
.24815 .45538 .25631 .46187 .26848 .45734 .26038 .45054 Mtetra
.665 .776 .932 r
.26038 .45054 .26848 .45734 .28068 .4531 .27262 .44613 Mtetra
.659 .77 .932 r
.27262 .44613 .28068 .4531 .29292 .44896 .28491 .44186 Mtetra
.659 .768 .93 r
.28491 .44186 .29292 .44896 .30522 .4449 .29726 .43759 Mtetra
.658 .763 .927 r
.29726 .43759 .30522 .4449 .31758 .44078 .30966 .43333 Mtetra
.654 .758 .926 r
.30966 .43333 .31758 .44078 .33 .43647 .32211 .42917 Mtetra
.657 .764 .929 r
.32211 .42917 .33 .43647 .34249 .4321 .33462 .42489 Mtetra
.664 .77 .929 r
.33462 .42489 .34249 .4321 .35503 .42774 .34721 .42039 Mtetra
.661 .766 .928 r
.34721 .42039 .35503 .42774 .36761 .42366 .35985 .41596 Mtetra
.662 .758 .921 r
.35985 .41596 .36761 .42366 .38025 .41979 .37255 .41146 Mtetra
.679 .747 .902 r
.37255 .41146 .38025 .41979 .39297 .4154 .38533 .40638 Mtetra
.675 .729 .891 r
.38533 .40638 .39297 .4154 .40577 .4102 .39816 .40137 Mtetra
.643 .725 .907 r
.39816 .40137 .40577 .4102 .41863 .40498 .41101 .39742 Mtetra
.625 .754 .939 r
.41101 .39742 .41863 .40498 .43153 .40023 .42392 .39391 Mtetra
.655 .801 .953 r
.42392 .39391 .43153 .40023 .44449 .39558 .43691 .38942 Mtetra
.69 .817 .943 r
.43691 .38942 .44449 .39558 .45751 .39064 .45 .38389 Mtetra
.686 .799 .935 r
.45 .38389 .45751 .39064 .47059 .38576 .46313 .37848 Mtetra
.651 .775 .939 r
.46313 .37848 .47059 .38576 .48372 .38144 .4763 .37413 Mtetra
.613 .762 .951 r
.4763 .37413 .48372 .38144 .49691 .37761 .48953 .37078 Mtetra
.605 .775 .961 r
.48953 .37078 .49691 .37761 .51017 .37373 .50283 .36749 Mtetra
.628 .803 .966 r
.50283 .36749 .51017 .37373 .52349 .36947 .51621 .3635 Mtetra
.639 .816 .968 r
.51621 .3635 .52349 .36947 .53689 .36468 .52966 .35917 Mtetra
.661 .838 .968 r
.52966 .35917 .53689 .36468 .55034 .35948 .54317 .35415 Mtetra
.688 .853 .961 r
.54317 .35415 .55034 .35948 .56385 .35425 .55673 .34834 Mtetra
.684 .835 .956 r
.55673 .34834 .56385 .35425 .57744 .34958 .57036 .34271 Mtetra
.669 .802 .946 r
.57036 .34271 .57744 .34958 .59109 .34534 .58405 .33761 Mtetra
.658 .774 .935 r
.58405 .33761 .59109 .34534 .60483 .34144 .59782 .33286 Mtetra
.62 .738 .931 r
.59782 .33286 .60483 .34144 .61867 .33856 .61169 .32928 Mtetra
.581 .703 .926 r
.61169 .32928 .61867 .33856 .63262 .33604 .62567 .32688 Mtetra
.613 .721 .922 r
.62567 .32688 .63262 .33604 .64658 .33189 .63971 .32352 Mtetra
.67 .766 .922 r
.63971 .32352 .64658 .33189 .66055 .32615 .65376 .31831 Mtetra
.667 .781 .934 r
.65376 .31831 .66055 .32615 .67462 .32103 .66788 .31315 Mtetra
.618 .762 .948 r
.66788 .31315 .67462 .32103 .68882 .31732 .68213 .30942 Mtetra
.565 .74 .958 r
.68213 .30942 .68882 .31732 .70317 .31459 .69655 .30702 Mtetra
.468 .704 .971 r
.69655 .30702 .70317 .31459 .71773 .31396 .71117 .30659 Mtetra
.338 .638 .963 r
.71117 .30659 .71773 .31396 .73263 .31673 .72606 .30843 Mtetra
.438 .667 .959 r
.72606 .30843 .73263 .31673 .74769 .31959 .741 .3089 Mtetra
.693 .728 .877 r
.741 .3089 .74769 .31959 .76234 .31507 .75554 .30235 Mtetra
.785 .725 .797 r
.75554 .30235 .76234 .31507 .77638 .30206 .76966 .28958 Mtetra
.78 .728 .804 r
.76966 .28958 .77638 .30206 .79036 .28834 .78382 .27734 Mtetra
.713 .731 .865 r
.78382 .27734 .79036 .28834 .80483 .28007 .7984 .26978 Mtetra
.58 .702 .926 r
.14449 .47931 .15278 .48761 .16422 .48634 .15602 .47733 Mtetra
.372 .593 .931 r
.15602 .47733 .16422 .48634 .17525 .48958 .16721 .47913 Mtetra
.313 .523 .898 r
.16721 .47913 .17525 .48958 .18635 .49314 .17835 .48234 Mtetra
.549 .631 .885 r
.17835 .48234 .18635 .49314 .19818 .49034 .19001 .48136 Mtetra
.735 .733 .849 r
.19001 .48136 .19818 .49034 .21074 .48058 .20238 .47384 Mtetra
.794 .79 .849 r
.20238 .47384 .21074 .48058 .22341 .46968 .21503 .4638 Mtetra
.776 .814 .883 r
.21503 .4638 .22341 .46968 .23587 .46135 .22755 .45526 Mtetra
.727 .807 .914 r
.22755 .45526 .23587 .46135 .24815 .45538 .23991 .44885 Mtetra
.689 .789 .927 r
.23991 .44885 .24815 .45538 .26038 .45054 .2522 .4437 Mtetra
.671 .778 .93 r
.2522 .4437 .26038 .45054 .27262 .44613 .2645 .43907 Mtetra
.663 .77 .929 r
.2645 .43907 .27262 .44613 .28491 .44186 .27683 .43465 Mtetra
.659 .766 .929 r
.27683 .43465 .28491 .44186 .29726 .43759 .28921 .43035 Mtetra
.28921 .43035 .29726 .43759 .30966 .43333 .30165 .42603 Mtetra
.663 .767 .927 r
.30165 .42603 .30966 .43333 .32211 .42917 .31416 .42156 Mtetra
.664 .76 .921 r
.31416 .42156 .32211 .42917 .33462 .42489 .32672 .41704 Mtetra
.66 .753 .919 r
.32672 .41704 .33462 .42489 .34721 .42039 .33934 .41262 Mtetra
.65 .753 .925 r
.33934 .41262 .34721 .42039 .35985 .41596 .352 .40847 Mtetra
.661 .765 .927 r
.352 .40847 .35985 .41596 .37255 .41146 .36473 .40397 Mtetra
.68 .772 .92 r
.36473 .40397 .37255 .41146 .38533 .40638 .37756 .39885 Mtetra
.663 .767 .927 r
.37756 .39885 .38533 .40638 .39816 .40137 .39041 .39424 Mtetra
.621 .766 .949 r
.39041 .39424 .39816 .40137 .41101 .39742 .40329 .39074 Mtetra
.638 .786 .953 r
.40329 .39074 .41101 .39742 .42392 .39391 .41625 .38673 Mtetra
.698 .789 .921 r
.41625 .38673 .42392 .39391 .43691 .38942 .42933 .38094 Mtetra
.713 .76 .889 r
.42933 .38094 .43691 .38942 .45 .38389 .44248 .37438 Mtetra
.681 .727 .884 r
.44248 .37438 .45 .38389 .46313 .37848 .45565 .36892 Mtetra
.624 .706 .904 r
.45565 .36892 .46313 .37848 .4763 .37413 .46884 .36545 Mtetra
.564 .706 .936 r
.46884 .36545 .4763 .37413 .48953 .37078 .48209 .36349 Mtetra
.556 .744 .964 r
.48209 .36349 .48953 .37078 .50283 .36749 .49542 .36136 Mtetra
.585 .793 .978 r
.49542 .36136 .50283 .36749 .51621 .3635 .50884 .35826 Mtetra
.588 .823 .989 r
.50884 .35826 .51621 .3635 .52966 .35917 .52235 .35477 Mtetra
.628 .865 .987 r
.52235 .35477 .52966 .35917 .54317 .35415 .53592 .35011 Mtetra
.692 .895 .971 r
.53592 .35011 .54317 .35415 .55673 .34834 .54955 .34382 Mtetra
.71 .886 .961 r
.54955 .34382 .55673 .34834 .57036 .34271 .56323 .33713 Mtetra
.701 .853 .955 r
.56323 .33713 .57036 .34271 .58405 .33761 .57696 .33087 Mtetra
.682 .813 .946 r
.57696 .33087 .58405 .33761 .59782 .33286 .59076 .32529 Mtetra
.634 .774 .947 r
.59076 .32529 .59782 .33286 .61169 .32928 .60467 .32114 Mtetra
.587 .739 .949 r
.60467 .32114 .61169 .32928 .62567 .32688 .61868 .31832 Mtetra
.608 .738 .937 r
.61868 .31832 .62567 .32688 .63971 .32352 .63277 .31497 Mtetra
.658 .759 .924 r
.63277 .31497 .63971 .32352 .65376 .31831 .64688 .31011 Mtetra
.658 .77 .932 r
.64688 .31011 .65376 .31831 .66788 .31315 .66107 .30519 Mtetra
.611 .759 .95 r
.66107 .30519 .66788 .31315 .68213 .30942 .67538 .30161 Mtetra
.549 .737 .963 r
.67538 .30161 .68213 .30942 .69655 .30702 .68987 .29951 Mtetra
.459 .703 .973 r
.68987 .29951 .69655 .30702 .71117 .30659 .70455 .29916 Mtetra
.399 .674 .971 r
.70455 .29916 .71117 .30659 .72606 .30843 .71942 .29989 Mtetra
.552 .721 .952 r
.71942 .29989 .72606 .30843 .741 .3089 .73423 .29783 Mtetra
.731 .736 .855 r
.73423 .29783 .741 .3089 .75554 .30235 .74868 .28937 Mtetra
.777 .719 .799 r
.74868 .28937 .75554 .30235 .76966 .28958 .76289 .27705 Mtetra
.758 .72 .817 r
.76289 .27705 .76966 .28958 .78382 .27734 .77723 .26634 Mtetra
.698 .727 .873 r
.77723 .26634 .78382 .27734 .7984 .26978 .79192 .25946 Mtetra
.606 .716 .923 r
.13611 .47115 .14449 .47931 .15602 .47733 .14774 .46848 Mtetra
.465 .644 .935 r
.14774 .46848 .15602 .47733 .16721 .47913 .1591 .46877 Mtetra
.358 .551 .905 r
.1591 .46877 .16721 .47913 .17835 .48234 .17031 .47125 Mtetra
.483 .596 .89 r
.17031 .47125 .17835 .48234 .19001 .48136 .18182 .47179 Mtetra
.678 .708 .87 r
.18182 .47179 .19001 .48136 .20238 .47384 .19399 .46672 Mtetra
.772 .783 .862 r
.19399 .46672 .20238 .47384 .21503 .4638 .20656 .45788 Mtetra
.777 .814 .883 r
.20656 .45788 .21503 .4638 .22755 .45526 .21914 .44925 Mtetra
.738 .812 .91 r
.21914 .44925 .22755 .45526 .23991 .44885 .23158 .44236 Mtetra
.699 .794 .924 r
.23158 .44236 .23991 .44885 .2522 .4437 .24394 .43684 Mtetra
.677 .78 .928 r
.24394 .43684 .2522 .4437 .2645 .43907 .25629 .43199 Mtetra
.667 .773 .929 r
.25629 .43199 .2645 .43907 .27683 .43465 .26867 .42743 Mtetra
.664 .769 .928 r
.26867 .42743 .27683 .43465 .28921 .43035 .2811 .42292 Mtetra
.662 .764 .926 r
.2811 .42292 .28921 .43035 .30165 .42603 .29359 .41848 Mtetra
.658 .76 .926 r
.29359 .41848 .30165 .42603 .31416 .42156 .30612 .41414 Mtetra
.661 .766 .928 r
.30612 .41414 .31416 .42156 .32672 .41704 .31872 .40968 Mtetra
.664 .77 .928 r
.31872 .40968 .32672 .41704 .33934 .41262 .33138 .4051 Mtetra
.665 .766 .925 r
.33138 .4051 .33934 .41262 .352 .40847 .3441 .40046 Mtetra
.674 .756 .913 r
.3441 .40046 .352 .40847 .36473 .40397 .3569 .39552 Mtetra
.675 .746 .904 r
.3569 .39552 .36473 .40397 .37756 .39885 .36975 .39049 Mtetra
.647 .741 .918 r
.36975 .39049 .37756 .39885 .39041 .39424 .38262 .38635 Mtetra
.619 .746 .937 r
.38262 .38635 .39041 .39424 .40329 .39074 .39553 .38295 Mtetra
.656 .761 .928 r
.39553 .38295 .40329 .39074 .41625 .38673 .40855 .3785 Mtetra
.703 .764 .899 r
.40855 .3785 .41625 .38673 .42933 .38094 .42168 .37237 Mtetra
.709 .758 .891 r
.42168 .37237 .42933 .38094 .44248 .37438 .43487 .36594 Mtetra
.669 .751 .912 r
.43487 .36594 .44248 .37438 .45565 .36892 .44807 .36101 Mtetra
.587 .738 .947 r
.44807 .36101 .45565 .36892 .46884 .36545 .46128 .35832 Mtetra
.471 .713 .975 r
.46128 .35832 .46884 .36545 .48209 .36349 .47455 .35774 Mtetra
.566 .799 .987 r
.47455 .35774 .48209 .36349 .49542 .36136 .48794 .35487 Mtetra
.763 .832 .905 r
.48794 .35487 .49542 .36136 .50884 .35826 .50145 .34645 Mtetra
.602 .652 .872 r
.50145 .34645 .50884 .35826 .52235 .35477 .51497 .3436 Mtetra
.596 .664 .886 r
.51497 .3436 .52235 .35477 .53592 .35011 .52858 .34091 Mtetra
.66 .737 .907 r
.52858 .34091 .53592 .35011 .54955 .34382 .54226 .33608 Mtetra
.687 .786 .925 r
.54226 .33608 .54955 .34382 .56323 .33713 .556 .33034 Mtetra
.696 .817 .94 r
.556 .33034 .56323 .33713 .57696 .33087 .5698 .32429 Mtetra
.683 .82 .949 r
.5698 .32429 .57696 .33087 .59076 .32529 .58366 .31862 Mtetra
.643 .806 .961 r
.58366 .31862 .59076 .32529 .60467 .32114 .59761 .31403 Mtetra
.602 .779 .965 r
.59761 .31403 .60467 .32114 .61868 .31832 .61166 .31055 Mtetra
.623 .768 .95 r
.61166 .31055 .61868 .31832 .63277 .31497 .62578 .30664 Mtetra
.657 .766 .93 r
.62578 .30664 .63277 .31497 .64688 .31011 .63994 .30176 Mtetra
.647 .763 .934 r
.63994 .30176 .64688 .31011 .66107 .30519 .65419 .29716 Mtetra
.596 .753 .953 r
.65419 .29716 .66107 .30519 .67538 .30161 .66858 .29391 Mtetra
.531 .735 .968 r
.66858 .29391 .67538 .30161 .68987 .29951 .68312 .29211 Mtetra
.461 .71 .976 r
.68312 .29211 .68987 .29951 .70455 .29916 .69785 .2916 Mtetra
.48 .716 .974 r
.69785 .2916 .70455 .29916 .71942 .29989 .71268 .29077 Mtetra
.648 .75 .924 r
.71268 .29077 .71942 .29989 .73423 .29783 .72736 .28601 Mtetra
.751 .73 .833 r
.72736 .28601 .73423 .29783 .74868 .28937 .74176 .27608 Mtetra
.762 .71 .804 r
.74176 .27608 .74868 .28937 .76289 .27705 .75609 .26466 Mtetra
.733 .715 .834 r
.75609 .26466 .76289 .27705 .77723 .26634 .7706 .25552 Mtetra
.683 .727 .883 r
.7706 .25552 .77723 .26634 .79192 .25946 .78541 .24927 Mtetra
.627 .73 .921 r
.12764 .46318 .13611 .47115 .14774 .46848 .13936 .45992 Mtetra
.541 .685 .932 r
.13936 .45992 .14774 .46848 .1591 .46877 .1509 .45871 Mtetra
.426 .595 .914 r
.1509 .45871 .1591 .46877 .17031 .47125 .16224 .45996 Mtetra
.44 .572 .89 r
.16224 .45996 .17031 .47125 .18182 .47179 .17367 .46133 Mtetra
.601 .664 .883 r
.17367 .46133 .18182 .47179 .19399 .46672 .18559 .45883 Mtetra
.732 .761 .876 r
.18559 .45883 .19399 .46672 .20656 .45788 .19802 .45177 Mtetra
.771 .811 .885 r
.19802 .45177 .20656 .45788 .21914 .44925 .21063 .44336 Mtetra
.749 .818 .906 r
.21063 .44336 .21914 .44925 .23158 .44236 .22316 .43601 Mtetra
.712 .802 .921 r
.22316 .43601 .23158 .44236 .24394 .43684 .2356 .43004 Mtetra
.686 .786 .926 r
.2356 .43004 .24394 .43684 .25629 .43199 .24801 .42488 Mtetra
.672 .775 .927 r
.24801 .42488 .25629 .43199 .26867 .42743 .26044 .42013 Mtetra
.664 .769 .928 r
.26044 .42013 .26867 .42743 .2811 .42292 .27291 .41559 Mtetra
.663 .768 .928 r
.27291 .41559 .2811 .42292 .29359 .41848 .28543 .41107 Mtetra
.666 .768 .926 r
.28543 .41107 .29359 .41848 .30612 .41414 .29802 .40644 Mtetra
.664 .761 .922 r
.29802 .40644 .30612 .41414 .31872 .40968 .31066 .40184 Mtetra
.662 .758 .921 r
.31066 .40184 .31872 .40968 .33138 .4051 .32336 .39728 Mtetra
.66 .758 .923 r
.32336 .39728 .33138 .4051 .3441 .40046 .33611 .39276 Mtetra
.668 .765 .923 r
.33611 .39276 .3441 .40046 .3569 .39552 .34894 .38799 Mtetra
.662 .769 .929 r
.34894 .38799 .3569 .39552 .36975 .39049 .36181 .38336 Mtetra
.647 .777 .943 r
.36181 .38336 .36975 .39049 .38262 .38635 .37473 .37911 Mtetra
.64 .773 .944 r
.37473 .37911 .38262 .38635 .39553 .38295 .3877 .37506 Mtetra
.668 .764 .922 r
.3877 .37506 .39553 .38295 .40855 .3785 .40077 .37017 Mtetra
.679 .757 .91 r
.40077 .37017 .40855 .3785 .42168 .37237 .41392 .36491 Mtetra
.683 .783 .926 r
.41392 .36491 .42168 .37237 .43487 .36594 .42712 .3595 Mtetra
.647 .804 .958 r
.42712 .3595 .43487 .36594 .44807 .36101 .44036 .35505 Mtetra
.618 .81 .974 r
.44036 .35505 .44807 .36101 .46128 .35832 .45365 .35118 Mtetra
.568 .757 .967 r
.45365 .35118 .46128 .35832 .47455 .35774 .46698 .34867 Mtetra
.671 .741 .903 r
.46698 .34867 .47455 .35774 .48794 .35487 .48044 .34352 Mtetra
.882 .743 .704 r
.48044 .34352 .48794 .35487 .50145 .34645 .49416 .31812 Mtetra
.414 .366 .695 r
.49416 .31812 .50145 .34645 .51497 .3436 .50758 .32508 Mtetra
.465 .477 .787 r
.50758 .32508 .51497 .3436 .52858 .34091 .52118 .32769 Mtetra
.604 .63 .85 r
.52118 .32769 .52858 .34091 .54226 .33608 .53489 .32467 Mtetra
.642 .682 .873 r
.53489 .32467 .54226 .33608 .556 .33034 .54868 .32029 Mtetra
.652 .717 .896 r
.54868 .32029 .556 .33034 .5698 .32429 .56254 .31563 Mtetra
.625 .743 .932 r
.56254 .31563 .5698 .32429 .58366 .31862 .57648 .31178 Mtetra
.619 .795 .966 r
.57648 .31178 .58366 .31862 .59761 .31403 .59049 .3078 Mtetra
.625 .817 .974 r
.59049 .3078 .59761 .31403 .61166 .31055 .60458 .30348 Mtetra
.659 .804 .953 r
.60458 .30348 .61166 .31055 .62578 .30664 .61872 .29842 Mtetra
.658 .772 .934 r
.61872 .29842 .62578 .30664 .63994 .30176 .63293 .29344 Mtetra
.631 .761 .94 r
.63293 .29344 .63994 .30176 .65419 .29716 .64725 .28925 Mtetra
.576 .75 .96 r
.64725 .28925 .65419 .29716 .66858 .29391 .66171 .28643 Mtetra
.517 .737 .974 r
.66171 .28643 .66858 .29391 .68312 .29211 .67632 .2848 Mtetra
.489 .73 .978 r
.67632 .2848 .68312 .29211 .69785 .2916 .69107 .28364 Mtetra
.584 .756 .96 r
.69107 .28364 .69785 .2916 .71268 .29077 .70581 .28055 Mtetra
.712 .75 .882 r
.70581 .28055 .71268 .29077 .72736 .28601 .72038 .27319 Mtetra
.752 .715 .817 r
.72038 .27319 .72736 .28601 .74176 .27608 .73479 .26268 Mtetra
.74 .701 .815 r
.73479 .26268 .74176 .27608 .75609 .26466 .74927 .25269 Mtetra
.708 .714 .854 r
.74927 .25269 .75609 .26466 .7706 .25552 .76396 .24502 Mtetra
.671 .731 .895 r
.76396 .24502 .7706 .25552 .78541 .24927 .77885 .23926 Mtetra
.642 .74 .92 r
.11906 .45538 .12764 .46318 .13936 .45992 .13086 .45168 Mtetra
.595 .715 .928 r
.13086 .45168 .13936 .45992 .1509 .45871 .14257 .44918 Mtetra
.506 .648 .921 r
.14257 .44918 .1509 .45871 .16224 .45996 .1541 .4488 Mtetra
.445 .58 .894 r
.1541 .4488 .16224 .45996 .17367 .46133 .16555 .44997 Mtetra
.521 .612 .884 r
.16555 .44997 .17367 .46133 .18559 .45883 .17725 .44961 Mtetra
.664 .716 .887 r
.17725 .44961 .18559 .45883 .19802 .45177 .18946 .44507 Mtetra
.748 .796 .891 r
.18946 .44507 .19802 .45177 .21063 .44336 .20202 .43755 Mtetra
.756 .822 .904 r
.20202 .43755 .21063 .44336 .22316 .43601 .21462 .42991 Mtetra
.727 .813 .918 r
.21462 .42991 .22316 .43601 .2356 .43004 .22716 .42338 Mtetra
.696 .793 .925 r
.22716 .42338 .2356 .43004 .24801 .42488 .23964 .41786 Mtetra
.678 .781 .928 r
.23964 .41786 .24801 .42488 .26044 .42013 .25213 .41288 Mtetra
.672 .774 .927 r
.25213 .41288 .26044 .42013 .27291 .41559 .26465 .40808 Mtetra
.665 .766 .925 r
.26465 .40808 .27291 .41559 .28543 .41107 .27722 .40346 Mtetra
.66 .763 .926 r
.27722 .40346 .28543 .41107 .29802 .40644 .28983 .39897 Mtetra
.662 .768 .929 r
.28983 .39897 .29802 .40644 .31066 .40184 .30251 .3944 Mtetra
.666 .772 .928 r
.30251 .3944 .31066 .40184 .32336 .39728 .31525 .38968 Mtetra
.673 .77 .923 r
.31525 .38968 .32336 .39728 .33611 .39276 .32807 .38471 Mtetra
.673 .759 .915 r
.32807 .38471 .33611 .39276 .34894 .38799 .34094 .37973 Mtetra
.657 .75 .918 r
.34094 .37973 .34894 .38799 .36181 .38336 .35385 .37524 Mtetra
.642 .75 .927 r
.35385 .37524 .36181 .38336 .37473 .37911 .36679 .37117 Mtetra
.652 .759 .928 r
.36679 .37117 .37473 .37911 .3877 .37506 .37982 .36676 Mtetra
.663 .754 .918 r
.37982 .36676 .3877 .37506 .40077 .37017 .39292 .36202 Mtetra
.649 .754 .926 r
.39292 .36202 .40077 .37017 .41392 .36491 .40607 .35766 Mtetra
.637 .777 .948 r
.40607 .35766 .41392 .36491 .42712 .3595 .41928 .35355 Mtetra
.654 .822 .964 r
.41928 .35355 .42712 .3595 .44036 .35505 .43258 .34878 Mtetra
.683 .822 .95 r
.43258 .34878 .44036 .35505 .45365 .35118 .44595 .34326 Mtetra
.691 .778 .918 r
.44595 .34326 .45365 .35118 .46698 .34867 .4594 .33748 Mtetra
.706 .708 .849 r
.4594 .33748 .46698 .34867 .48044 .34352 .47292 .33041 Mtetra
.69 .669 .824 r
.47292 .33041 .48044 .34352 .49416 .31812 .48648 .32356 Mtetra
.139 0 0 r
.48648 .32356 .49416 .31812 .50758 .32508 .50006 .32113 Mtetra
.435 .802 .995 r
.50006 .32113 .50758 .32508 .52118 .32769 .51372 .3193 Mtetra
.631 .751 .934 r
.51372 .3193 .52118 .32769 .53489 .32467 .52747 .3153 Mtetra
.649 .734 .911 r
.52747 .3153 .53489 .32467 .54868 .32029 .5413 .31072 Mtetra
.61 .714 .919 r
.5413 .31072 .54868 .32029 .56254 .31563 .55521 .30737 Mtetra
.567 .733 .953 r
.55521 .30737 .56254 .31563 .57648 .31178 .56922 .30493 Mtetra
.596 .788 .972 r
.56922 .30493 .57648 .31178 .59049 .3078 .5833 .30144 Mtetra
.661 .827 .963 r
.5833 .30144 .59049 .3078 .60458 .30348 .59742 .29617 Mtetra
.683 .807 .942 r
.59742 .29617 .60458 .30348 .61872 .29842 .6116 .29035 Mtetra
.656 .778 .939 r
.6116 .29035 .61872 .29842 .63293 .29344 .62587 .28537 Mtetra
.611 .762 .951 r
.62587 .28537 .63293 .29344 .64725 .28925 .64026 .28167 Mtetra
.556 .754 .97 r
.64026 .28167 .64725 .28925 .66171 .28643 .65478 .27918 Mtetra
.52 .748 .979 r
.65478 .27918 .66171 .28643 .67632 .2848 .66944 .27733 Mtetra
.564 .763 .972 r
.66944 .27733 .67632 .2848 .69107 .28364 .68416 .27454 Mtetra
.678 .766 .917 r
.68416 .27454 .69107 .28364 .70581 .28055 .6988 .26869 Mtetra
.737 .727 .842 r
.6988 .26869 .70581 .28055 .72038 .27319 .71331 .25954 Mtetra
.736 .697 .813 r
.71331 .25954 .72038 .27319 .73479 .26268 .72781 .24964 Mtetra
.713 .698 .834 r
.72781 .24964 .73479 .26268 .74927 .25269 .74245 .24134 Mtetra
.685 .72 .875 r
.74245 .24134 .74927 .25269 .76396 .24502 .75728 .23486 Mtetra
.663 .738 .906 r
.75728 .23486 .76396 .24502 .77885 .23926 .77226 .22939 Mtetra
.65 .747 .92 r
.11039 .44767 .11906 .45538 .13086 .45168 .12225 .4437 Mtetra
.629 .735 .923 r
.12225 .4437 .13086 .45168 .14257 .44918 .13409 .44029 Mtetra
.576 .694 .922 r
.13409 .44029 .14257 .44918 .1541 .4488 .14582 .43827 Mtetra
.5 .622 .903 r
.14582 .43827 .1541 .4488 .16555 .44997 .15741 .43817 Mtetra
.482 .585 .882 r
.15741 .43817 .16555 .44997 .17725 .44961 .16902 .43871 Mtetra
.572 .647 .886 r
.16902 .43871 .17725 .44961 .18946 .44507 .18096 .43692 Mtetra
.692 .752 .898 r
.18096 .43692 .18946 .44507 .20202 .43755 .19335 .43144 Mtetra
.747 .815 .906 r
.19335 .43144 .20202 .43755 .21462 .42991 .20597 .42409 Mtetra
.739 .823 .917 r
.20597 .42409 .21462 .42991 .22716 .42338 .21859 .41708 Mtetra
.713 .808 .924 r
.21859 .41708 .22716 .42338 .23964 .41786 .23117 .41097 Mtetra
.688 .788 .927 r
.23117 .41097 .23964 .41786 .25213 .41288 .24373 .40564 Mtetra
.672 .776 .928 r
.24373 .40564 .25213 .41288 .26465 .40808 .25629 .40077 Mtetra
.669 .774 .929 r
.25629 .40077 .26465 .40808 .27722 .40346 .26891 .39599 Mtetra
.669 .771 .927 r
.26891 .39599 .27722 .40346 .28983 .39897 .28158 .3912 Mtetra
.665 .763 .923 r
.28158 .3912 .28983 .39897 .30251 .3944 .2943 .3865 Mtetra
.661 .759 .923 r
.2943 .3865 .30251 .3944 .31525 .38968 .30707 .3819 Mtetra
.665 .765 .924 r
.30707 .3819 .31525 .38968 .32807 .38471 .31991 .37715 Mtetra
.671 .774 .927 r
.31991 .37715 .32807 .38471 .34094 .37973 .33283 .37218 Mtetra
.656 .771 .934 r
.33283 .37218 .34094 .37973 .35385 .37524 .34577 .36764 Mtetra
.638 .765 .94 r
.34577 .36764 .35385 .37524 .36679 .37117 .35876 .36359 Mtetra
.65 .77 .937 r
.35876 .36359 .36679 .37117 .37982 .36676 .37182 .3592 Mtetra
.665 .777 .932 r
.37182 .3592 .37982 .36676 .39292 .36202 .38497 .35432 Mtetra
.649 .769 .936 r
.38497 .35432 .39292 .36202 .40607 .35766 .39817 .34991 Mtetra
.627 .761 .943 r
.39817 .34991 .40607 .35766 .41928 .35355 .41141 .34608 Mtetra
.647 .777 .943 r
.41141 .34608 .41928 .35355 .43258 .34878 .42474 .34166 Mtetra
.686 .799 .935 r
.42474 .34166 .43258 .34878 .44595 .34326 .43817 .33603 Mtetra
.704 .802 .926 r
.43817 .33603 .44595 .34326 .4594 .33748 .45167 .32976 Mtetra
.685 .785 .926 r
.45167 .32976 .4594 .33748 .47292 .33041 .46521 .32412 Mtetra
.619 .807 .972 r
.46521 .32412 .47292 .33041 .48648 .32356 .47879 .32011 Mtetra
.546 .867 .995 r
.47879 .32011 .48648 .32356 .50006 .32113 .49244 .31633 Mtetra
.596 .847 .992 r
.49244 .31633 .50006 .32113 .51372 .3193 .50617 .31229 Mtetra
.645 .798 .956 r
.50617 .31229 .51372 .3193 .52747 .3153 .51998 .30767 Mtetra
.64 .78 .948 r
.51998 .30767 .52747 .3153 .5413 .31072 .53386 .30324 Mtetra
.581 .763 .965 r
.53386 .30324 .5413 .31072 .55521 .30737 .54782 .30025 Mtetra
.541 .758 .977 r
.54782 .30025 .55521 .30737 .56922 .30493 .56188 .29801 Mtetra
.604 .791 .971 r
.56188 .29801 .56922 .30493 .5833 .30144 .57601 .2943 Mtetra
.682 .813 .946 r
.57601 .2943 .5833 .30144 .59742 .29617 .59018 .28848 Mtetra
.689 .801 .934 r
.59018 .28848 .59742 .29617 .6116 .29035 .60441 .28241 Mtetra
.643 .779 .946 r
.60441 .28241 .6116 .29035 .62587 .28537 .61875 .27776 Mtetra
.587 .768 .965 r
.61875 .27776 .62587 .28537 .64026 .28167 .63321 .2745 Mtetra
.552 .767 .978 r
.63321 .2745 .64026 .28167 .65478 .27918 .64779 .27189 Mtetra
.576 .775 .973 r
.64779 .27189 .65478 .27918 .66944 .27733 .66244 .26875 Mtetra
.664 .775 .932 r
.66244 .26875 .66944 .27733 .68416 .27454 .67708 .26338 Mtetra
.723 .736 .862 r
.67708 .26338 .68416 .27454 .6988 .26869 .69165 .25521 Mtetra
.728 .697 .82 r
.69165 .25521 .6988 .26869 .71331 .25954 .70619 .24587 Mtetra
.711 .687 .825 r
.70619 .24587 .71331 .25954 .72781 .24964 .72083 .23748 Mtetra
.688 .705 .861 r
.72083 .23748 .72781 .24964 .74245 .24134 .73563 .23069 Mtetra
.669 .73 .896 r
.73563 .23069 .74245 .24134 .75728 .23486 .75057 .22495 Mtetra
.658 .745 .914 r
.75057 .22495 .75728 .23486 .77226 .22939 .76562 .21961 Mtetra
.654 .75 .92 r
.10164 .43999 .11039 .44767 .12225 .4437 .11354 .43587 Mtetra
.647 .745 .921 r
.11354 .43587 .12225 .4437 .13409 .44029 .12546 .43194 Mtetra
.622 .725 .921 r
.12546 .43194 .13409 .44029 .14582 .43827 .13737 .42869 Mtetra
.569 .676 .912 r
.13737 .42869 .14582 .43827 .15741 .43817 .14917 .42685 Mtetra
.51 .611 .889 r
.14917 .42685 .15741 .43817 .16902 .43871 .16086 .42661 Mtetra
.511 .596 .875 r
.16086 .42661 .16902 .43871 .18096 .43692 .17263 .42647 Mtetra
.597 .669 .89 r
.17263 .42647 .18096 .43692 .19335 .43144 .18474 .42393 Mtetra
.699 .772 .909 r
.18474 .42393 .19335 .43144 .20597 .42409 .19723 .41822 Mtetra
.739 .824 .917 r
.19723 .41822 .20597 .42409 .21859 .41708 .20991 .41117 Mtetra
.727 .823 .924 r
.20991 .41117 .21859 .41708 .23117 .41097 .22257 .40456 Mtetra
.704 .807 .929 r
.22257 .40456 .23117 .41097 .24373 .40564 .23522 .39869 Mtetra
.687 .789 .928 r
.23522 .39869 .24373 .40564 .25629 .40077 .24786 .39332 Mtetra
.672 .773 .926 r
.24786 .39332 .25629 .40077 .26891 .39599 .26053 .38841 Mtetra
.664 .768 .928 r
.26053 .38841 .26891 .39599 .28158 .3912 .27322 .38373 Mtetra
.664 .773 .931 r
.27322 .38373 .28158 .3912 .2943 .3865 .28598 .37902 Mtetra
.666 .774 .93 r
.28598 .37902 .2943 .3865 .30707 .3819 .29881 .37423 Mtetra
.671 .771 .926 r
.29881 .37423 .30707 .3819 .31991 .37715 .3117 .36927 Mtetra
.677 .769 .92 r
.3117 .36927 .31991 .37715 .33283 .37218 .32467 .36407 Mtetra
.669 .761 .919 r
.32467 .36407 .33283 .37218 .34577 .36764 .33767 .35911 Mtetra
.643 .743 .922 r
.33767 .35911 .34577 .36764 .35876 .36359 .3507 .35494 Mtetra
.631 .737 .924 r
.3507 .35494 .35876 .36359 .37182 .3592 .36377 .3511 Mtetra
.639 .756 .933 r
.36377 .3511 .37182 .3592 .38497 .35432 .37693 .34699 Mtetra
.638 .778 .948 r
.37693 .34699 .38497 .35432 .39817 .34991 .39016 .34279 Mtetra
.625 .781 .956 r
.39016 .34279 .39817 .34991 .41141 .34608 .40344 .33889 Mtetra
.631 .782 .954 r
.40344 .33889 .41141 .34608 .42474 .34166 .41681 .33482 Mtetra
.658 .802 .952 r
.41681 .33482 .42474 .34166 .43817 .33603 .43026 .32996 Mtetra
.676 .831 .958 r
.43026 .32996 .43817 .33603 .45167 .32976 .4438 .32449 Mtetra
.666 .853 .971 r
.4438 .32449 .45167 .32976 .46521 .32412 .4574 .3191 Mtetra
.65 .857 .979 r
.4574 .3191 .46521 .32412 .47879 .32011 .47106 .314 Mtetra
.639 .822 .971 r
.47106 .314 .47879 .32011 .49244 .31633 .48477 .30939 Mtetra
.637 .798 .96 r
.48477 .30939 .49244 .31633 .50617 .31229 .49855 .30496 Mtetra
.637 .788 .955 r
.49855 .30496 .50617 .31229 .51998 .30767 .51241 .30057 Mtetra
.617 .789 .964 r
.51241 .30057 .51998 .30767 .53386 .30324 .52634 .29662 Mtetra
.564 .784 .982 r
.52634 .29662 .53386 .30324 .54782 .30025 .54036 .29371 Mtetra
.552 .783 .984 r
.54036 .29371 .54782 .30025 .56188 .29801 .55446 .29098 Mtetra
.629 .799 .964 r
.55446 .29098 .56188 .29801 .57601 .2943 .56864 .2866 Mtetra
.687 .801 .935 r
.56864 .2866 .57601 .2943 .59018 .28848 .58287 .28058 Mtetra
.676 .793 .937 r
.58287 .28058 .59018 .28848 .60441 .28241 .59716 .27489 Mtetra
.624 .787 .96 r
.59716 .27489 .60441 .28241 .61875 .27776 .61157 .27064 Mtetra
.588 .785 .974 r
.61157 .27064 .61875 .27776 .63321 .2745 .62608 .26718 Mtetra
.607 .788 .968 r
.62608 .26718 .63321 .2745 .64779 .27189 .64067 .26326 Mtetra
.67 .777 .93 r
.64067 .26326 .64779 .27189 .66244 .26875 .65527 .25765 Mtetra
.714 .735 .868 r
.65527 .25765 .66244 .26875 .67708 .26338 .66985 .24994 Mtetra
.718 .694 .826 r
.66985 .24994 .67708 .26338 .69165 .25521 .68442 .24124 Mtetra
.703 .679 .825 r
.68442 .24124 .69165 .25521 .70619 .24587 .69908 .23318 Mtetra
.685 .695 .853 r
.69908 .23318 .70619 .24587 .72083 .23748 .71387 .22639 Mtetra
.669 .722 .888 r
.71387 .22639 .72083 .23748 .73563 .23069 .72879 .22056 Mtetra
.66 .741 .91 r
.72879 .22056 .73563 .23069 .75057 .22495 .74381 .21514 Mtetra
.656 .749 .918 r
.74381 .21514 .75057 .22495 .76562 .21961 .75892 .20982 Mtetra
.655 .751 .92 r
.0928 .43227 .10164 .43999 .11354 .43587 .10474 .42807 Mtetra
.653 .75 .92 r
.10474 .42807 .11354 .43587 .12546 .43194 .11672 .42392 Mtetra
.645 .742 .92 r
.11672 .42392 .12546 .43194 .13737 .42869 .12873 .41998 Mtetra
.621 .718 .916 r
.12873 .41998 .13737 .42869 .14917 .42685 .14072 .41673 Mtetra
.574 .668 .902 r
.14072 .41673 .14917 .42685 .16086 .42661 .15262 .41476 Mtetra
.527 .61 .879 r
.15262 .41476 .16086 .42661 .17263 .42647 .16444 .41413 Mtetra
.529 .601 .871 r
.16444 .41413 .17263 .42647 .18474 .42393 .17635 .41353 Mtetra
.599 .674 .893 r
.17635 .41353 .18474 .42393 .19723 .41822 .18855 .41086 Mtetra
.69 .778 .918 r
.18855 .41086 .19723 .41822 .20991 .41117 .20111 .40541 Mtetra
.731 .829 .925 r
.20111 .40541 .20991 .41117 .22257 .40456 .21384 .39861 Mtetra
.72 .823 .929 r
.21384 .39861 .22257 .40456 .23522 .39869 .22658 .39218 Mtetra
.697 .806 .932 r
.22658 .39218 .23522 .39869 .24786 .39332 .2393 .38647 Mtetra
.686 .795 .932 r
.2393 .38647 .24786 .39332 .26053 .38841 .25204 .3811 Mtetra
.677 .781 .928 r
.25204 .3811 .26053 .38841 .27322 .38373 .26481 .37595 Mtetra
.669 .768 .924 r
.26481 .37595 .27322 .38373 .28598 .37902 .27762 .37106 Mtetra
.66 .762 .925 r
.27762 .37106 .28598 .37902 .29881 .37423 .29047 .3664 Mtetra
.657 .765 .929 r
.29047 .3664 .29881 .37423 .3117 .36927 .30338 .36181 Mtetra
.666 .779 .934 r
.30338 .36181 .3117 .36927 .32467 .36407 .31636 .35693 Mtetra
.675 .791 .936 r
.31636 .35693 .32467 .36407 .33767 .35911 .32943 .35174 Mtetra
.669 .784 .935 r
.32943 .35174 .33767 .35911 .3507 .35494 .34254 .34673 Mtetra
.649 .757 .928 r
.34254 .34673 .3507 .35494 .36377 .3511 .35568 .34231 Mtetra
.634 .738 .923 r
.35568 .34231 .36377 .3511 .37693 .34699 .36887 .33833 Mtetra
.624 .739 .929 r
.36887 .33833 .37693 .34699 .39016 .34279 .38211 .33459 Mtetra
.614 .748 .941 r
.38211 .33459 .39016 .34279 .40344 .33889 .39542 .33107 Mtetra
.609 .759 .95 r
.39542 .33107 .40344 .33889 .41681 .33482 .4088 .32759 Mtetra
.621 .781 .958 r
.4088 .32759 .41681 .33482 .43026 .32996 .42228 .32369 Mtetra
.643 .818 .967 r
.42228 .32369 .43026 .32996 .4438 .32449 .43585 .31906 Mtetra
.658 .848 .973 r
.43585 .31906 .4438 .32449 .4574 .3191 .4495 .31384 Mtetra
.657 .854 .975 r
.4495 .31384 .4574 .3191 .47106 .314 .46322 .30856 Mtetra
.651 .848 .976 r
.46322 .30856 .47106 .314 .48477 .30939 .477 .30345 Mtetra
.639 .831 .974 r
.477 .30345 .48477 .30939 .49855 .30496 .49084 .2987 Mtetra
.629 .819 .973 r
.49084 .2987 .49855 .30496 .51241 .30057 .50476 .29424 Mtetra
.601 .808 .98 r
.50476 .29424 .51241 .30057 .52634 .29662 .51874 .29042 Mtetra
.559 .797 .988 r
.51874 .29042 .52634 .29662 .54036 .29371 .53281 .28742 Mtetra
.576 .802 .985 r
.53281 .28742 .54036 .29371 .55446 .29098 .54697 .28406 Mtetra
.65 .812 .961 r
.54697 .28406 .55446 .29098 .56864 .2866 .5612 .27904 Mtetra
.687 .807 .939 r
.5612 .27904 .56864 .2866 .58287 .28058 .57548 .27297 Mtetra
.668 .801 .946 r
.57548 .27297 .58287 .28058 .59716 .27489 .58984 .26747 Mtetra
.638 .797 .959 r
.58984 .26747 .59716 .27489 .61157 .27064 .60429 .26278 Mtetra
.65 .79 .949 r
.60429 .26278 .61157 .27064 .62608 .26718 .61881 .25777 Mtetra
.688 .764 .909 r
.61881 .25777 .62608 .26718 .64067 .26326 .63337 .25149 Mtetra
.707 .72 .859 r
.63337 .25149 .64067 .26326 .65527 .25765 .64793 .24392 Mtetra
.704 .684 .828 r
.64793 .24392 .65527 .25765 .66985 .24994 .66253 .23588 Mtetra
.691 .674 .828 r
.66253 .23588 .66985 .24994 .68442 .24124 .67721 .2284 Mtetra
.678 .69 .854 r
.67721 .2284 .68442 .24124 .69908 .23318 .692 .22189 Mtetra
.667 .717 .886 r
.692 .22189 .69908 .23318 .71387 .22639 .7069 .21611 Mtetra
.66 .738 .908 r
.7069 .21611 .71387 .22639 .72879 .22056 .7219 .21066 Mtetra
.657 .748 .917 r
.7219 .21066 .72879 .22056 .74381 .21514 .73699 .20531 Mtetra
.656 .751 .92 r
.73699 .20531 .74381 .21514 .75892 .20982 .75215 .19997 Mtetra
.08389 .42449 .0928 .43227 .10474 .42807 .09586 .42025 Mtetra
.655 .751 .92 r
.09586 .42025 .10474 .42807 .11672 .42392 .10788 .416 Mtetra
.653 .749 .92 r
.10788 .416 .11672 .42392 .12873 .41998 .11995 .41179 Mtetra
.646 .741 .918 r
.11995 .41179 .12873 .41998 .14072 .41673 .13205 .40778 Mtetra
.625 .716 .912 r
.13205 .40778 .14072 .41673 .15262 .41476 .14414 .40435 Mtetra
.587 .669 .896 r
.14414 .40435 .15262 .41476 .16444 .41413 .15617 .402 Mtetra
.548 .616 .872 r
.15617 .402 .16444 .41413 .17635 .41353 .16814 .40082 Mtetra
.539 .602 .864 r
.16814 .40082 .17635 .41353 .18855 .41086 .18017 .39991 Mtetra
.585 .659 .888 r
.18017 .39991 .18855 .41086 .20111 .40541 .19242 .3976 Mtetra
.665 .763 .923 r
.19242 .3976 .20111 .40541 .21384 .39861 .20499 .39286 Mtetra
.719 .831 .934 r
.20499 .39286 .21384 .39861 .22658 .39218 .21777 .38643 Mtetra
.721 .832 .934 r
.21777 .38643 .22658 .39218 .2393 .38647 .23061 .37991 Mtetra
.697 .807 .933 r
.23061 .37991 .2393 .38647 .25204 .3811 .24343 .37413 Mtetra
.679 .793 .935 r
.24343 .37413 .25204 .3811 .26481 .37595 .25625 .36889 Mtetra
.674 .79 .936 r
.25625 .36889 .26481 .37595 .27762 .37106 .26912 .36378 Mtetra
.674 .786 .933 r
.26912 .36378 .27762 .37106 .29047 .3664 .28204 .35865 Mtetra
.669 .773 .927 r
.28204 .35865 .29047 .3664 .30338 .36181 .29502 .35365 Mtetra
.664 .761 .923 r
.29502 .35365 .30338 .36181 .31636 .35693 .30804 .34879 Mtetra
.665 .763 .923 r
.30804 .34879 .31636 .35693 .32943 .35174 .32113 .34388 Mtetra
.668 .773 .928 r
.32113 .34388 .32943 .35174 .34254 .34673 .33428 .33884 Mtetra
.664 .772 .93 r
.33428 .33884 .34254 .34673 .35568 .34231 .34749 .3339 Mtetra
.652 .756 .926 r
.34749 .3339 .35568 .34231 .36887 .33833 .36075 .32931 Mtetra
.638 .736 .92 r
.36075 .32931 .36887 .33833 .38211 .33459 .37405 .32515 Mtetra
.623 .721 .917 r
.37405 .32515 .38211 .33459 .39542 .33107 .3874 .3214 Mtetra
.614 .713 .916 r
.3874 .3214 .39542 .33107 .4088 .32759 .40081 .31793 Mtetra
.613 .714 .917 r
.40081 .31793 .4088 .32759 .42228 .32369 .41431 .31447 Mtetra
.622 .73 .924 r
.41431 .31447 .42228 .32369 .43585 .31906 .42789 .31069 Mtetra
.633 .757 .937 r
.42789 .31069 .43585 .31906 .4495 .31384 .44156 .30651 Mtetra
.641 .79 .954 r
.44156 .30651 .4495 .31384 .46322 .30856 .45531 .30198 Mtetra
.638 .812 .967 r
.45531 .30198 .46322 .30856 .477 .30345 .46914 .29737 Mtetra
.632 .827 .975 r
.46914 .29737 .477 .30345 .49084 .2987 .48304 .29278 Mtetra
.611 .826 .982 r
.48304 .29278 .49084 .2987 .50476 .29424 .49701 .28858 Mtetra
.57 .819 .992 r
.49701 .28858 .50476 .29424 .51874 .29042 .51105 .28513 Mtetra
.557 .826 .996 r
.51105 .28513 .51874 .29042 .53281 .28742 .52518 .28173 Mtetra
.624 .841 .983 r
.52518 .28173 .53281 .28742 .54697 .28406 .53939 .27706 Mtetra
.693 .825 .946 r
.53939 .27706 .54697 .28406 .5612 .27904 .55367 .27076 Mtetra
.704 .794 .921 r
.55367 .27076 .5612 .27904 .57548 .27297 .568 .26404 Mtetra
.688 .774 .916 r
.568 .26404 .57548 .27297 .58984 .26747 .5824 .2578 Mtetra
.686 .756 .905 r
.5824 .2578 .58984 .26747 .60429 .26278 .59686 .25158 Mtetra
.695 .726 .874 r
.59686 .25158 .60429 .26278 .61881 .25777 .61137 .24469 Mtetra
.695 .691 .842 r
.61137 .24469 .61881 .25777 .63337 .25149 .62593 .23733 Mtetra
.687 .67 .828 r
.62593 .23733 .63337 .25149 .64793 .24392 .64055 .23006 Mtetra
.678 .672 .837 r
.64055 .23006 .64793 .24392 .66253 .23588 .65524 .22331 Mtetra
.67 .692 .862 r
.65524 .22331 .66253 .23588 .67721 .2284 .67003 .21722 Mtetra
.663 .719 .89 r
.67003 .21722 .67721 .2284 .692 .22189 .68492 .21158 Mtetra
.659 .738 .909 r
.68492 .21158 .692 .22189 .7069 .21611 .6999 .20616 Mtetra
.656 .748 .917 r
.6999 .20616 .7069 .21611 .7219 .21066 .71496 .20079 Mtetra
.656 .751 .92 r
.71496 .20079 .7219 .21066 .73699 .20531 .7301 .19542 Mtetra
.7301 .19542 .73699 .20531 .75215 .19997 .74532 .19003 Mtetra
.0749 .41664 .08389 .42449 .09586 .42025 .0869 .41236 Mtetra
.0869 .41236 .09586 .42025 .10788 .416 .09895 .40806 Mtetra
.655 .751 .92 r
.09895 .40806 .10788 .416 .11995 .41179 .11106 .40376 Mtetra
.654 .749 .92 r
.11106 .40376 .11995 .41179 .13205 .40778 .12322 .39947 Mtetra
.648 .741 .917 r
.12322 .39947 .13205 .40778 .14414 .40435 .13543 .39534 Mtetra
.633 .72 .91 r
.13543 .39534 .14414 .40435 .15617 .402 .14764 .39162 Mtetra
.605 .679 .893 r
.14764 .39162 .15617 .402 .16814 .40082 .15982 .3887 Mtetra
.572 .629 .87 r
.15982 .3887 .16814 .40082 .18017 .39991 .17196 .38679 Mtetra
.553 .602 .857 r
.17196 .38679 .18017 .39991 .19242 .3976 .18411 .38546 Mtetra
.568 .629 .872 r
.18411 .38546 .19242 .3976 .20499 .39286 .1964 .38362 Mtetra
.624 .717 .913 r
.1964 .38362 .20499 .39286 .21777 .38643 .20893 .38008 Mtetra
.687 .811 .942 r
.20893 .38008 .21777 .38643 .23061 .37991 .22172 .37461 Mtetra
.716 .847 .944 r
.22172 .37461 .23061 .37991 .24343 .37413 .23464 .36815 Mtetra
.71 .829 .938 r
.23464 .36815 .24343 .37413 .25625 .36889 .2476 .36189 Mtetra
.688 .797 .933 r
.2476 .36189 .25625 .36889 .26912 .36378 .26054 .35631 Mtetra
.671 .782 .933 r
.26054 .35631 .26912 .36378 .28204 .35865 .2735 .35125 Mtetra
.664 .783 .937 r
.2735 .35125 .28204 .35865 .29502 .35365 .28651 .34635 Mtetra
.663 .787 .94 r
.28651 .34635 .29502 .35365 .30804 .34879 .29958 .34146 Mtetra
.29958 .34146 .30804 .34879 .32113 .34388 .31271 .33653 Mtetra
.666 .788 .94 r
.31271 .33653 .32113 .34388 .33428 .33884 .3259 .33152 Mtetra
.667 .79 .94 r
.3259 .33152 .33428 .33884 .34749 .3339 .33917 .32642 Mtetra
.666 .787 .939 r
.33917 .32642 .34749 .3339 .36075 .32931 .35249 .32135 Mtetra
.659 .773 .934 r
.35249 .32135 .36075 .32931 .37405 .32515 .36587 .31648 Mtetra
.647 .752 .926 r
.36587 .31648 .37405 .32515 .3874 .3214 .37929 .31196 Mtetra
.633 .728 .917 r
.37929 .31196 .3874 .3214 .40081 .31793 .39277 .30787 Mtetra
.62 .709 .909 r
.39277 .30787 .40081 .31793 .41431 .31447 .4063 .30416 Mtetra
.613 .702 .907 r
.4063 .30416 .41431 .31447 .42789 .31069 .41991 .30064 Mtetra
.614 .709 .913 r
.41991 .30064 .42789 .31069 .44156 .30651 .4336 .29705 Mtetra
.619 .727 .924 r
.4336 .29705 .44156 .30651 .45531 .30198 .44737 .29328 Mtetra
.624 .75 .937 r
.44737 .29328 .45531 .30198 .46914 .29737 .46123 .28929 Mtetra
.615 .764 .951 r
.46123 .28929 .46914 .29737 .48304 .29278 .47517 .28543 Mtetra
.598 .78 .968 r
.47517 .28543 .48304 .29278 .49701 .28858 .48918 .28185 Mtetra
.604 .802 .976 r
.48918 .28185 .49701 .28858 .51105 .28513 .50328 .27795 Mtetra
.656 .809 .956 r
.50328 .27795 .51105 .28513 .52518 .28173 .51747 .27277 Mtetra
.705 .777 .908 r
.51747 .27277 .52518 .28173 .53939 .27706 .53172 .26595 Mtetra
.711 .731 .866 r
.53172 .26595 .53939 .27706 .55367 .27076 .54603 .25838 Mtetra
.698 .703 .851 r
.54603 .25838 .55367 .27076 .568 .26404 .5604 .2511 Mtetra
.687 .689 .846 r
.5604 .2511 .568 .26404 .5824 .2578 .57482 .24421 Mtetra
.682 .676 .838 r
.57482 .24421 .5824 .2578 .59686 .25158 .58931 .23735 Mtetra
.676 .664 .831 r
.58931 .23735 .59686 .25158 .61137 .24469 .60386 .23061 Mtetra
.669 .664 .836 r
.60386 .23061 .61137 .24469 .62593 .23733 .61848 .22423 Mtetra
.666 .68 .854 r
.61848 .22423 .62593 .23733 .64055 .23006 .63318 .21821 Mtetra
.663 .705 .878 r
.63318 .21821 .64055 .23006 .65524 .22331 .64797 .21251 Mtetra
.659 .727 .899 r
.64797 .21251 .65524 .22331 .67003 .21722 .66284 .20702 Mtetra
.657 .742 .912 r
.66284 .20702 .67003 .21722 .68492 .21158 .67779 .20163 Mtetra
.656 .748 .918 r
.67779 .20163 .68492 .21158 .6999 .20616 .69283 .19625 Mtetra
.656 .751 .92 r
.69283 .19625 .6999 .20616 .71496 .20079 .70795 .19086 Mtetra
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Mtetra
.72315 .18544 .7301 .19542 .74532 .19003 .73842 .17999 Mtetra
.06583 .40873 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Mtetra
.08995 .40007 .09895 .40806 .11106 .40376 .10209 .39571 Mtetra
.655 .751 .92 r
.10209 .39571 .11106 .40376 .12322 .39947 .11429 .39134 Mtetra
.655 .75 .92 r
.11429 .39134 .12322 .39947 .13543 .39534 .12655 .38698 Mtetra
.651 .744 .917 r
.12655 .38698 .13543 .39534 .14764 .39162 .13885 .38269 Mtetra
.642 .728 .911 r
.13885 .38269 .14764 .39162 .15982 .3887 .15118 .37865 Mtetra
.624 .696 .896 r
.15118 .37865 .15982 .3887 .17196 .38679 .16352 .37512 Mtetra
.599 .652 .874 r
.16352 .37512 .17196 .38679 .18411 .38546 .17584 .37232 Mtetra
.576 .615 .854 r
.17584 .37232 .18411 .38546 .1964 .38362 .18816 .37022 Mtetra
.568 .608 .852 r
.18816 .37022 .1964 .38362 .20893 .38008 .20054 .36837 Mtetra
.586 .649 .879 r
.20054 .36837 .20893 .38008 .22172 .37461 .21305 .36591 Mtetra
.629 .736 .925 r
.21305 .36591 .22172 .37461 .23464 .36815 .22576 .36211 Mtetra
.676 .822 .954 r
.22576 .36211 .23464 .36815 .2476 .36189 .23868 .35683 Mtetra
.701 .856 .956 r
.23868 .35683 .2476 .36189 .26054 .35631 .25172 .35072 Mtetra
.704 .843 .949 r
.25172 .35072 .26054 .35631 .2735 .35125 .26482 .34454 Mtetra
.692 .81 .938 r
.26482 .34454 .2735 .35125 .28651 .34635 .27794 .33875 Mtetra
.677 .784 .93 r
.27794 .33875 .28651 .34635 .29958 .34146 .29108 .3334 Mtetra
.666 .77 .927 r
.29108 .3334 .29958 .34146 .31271 .33653 .30425 .32837 Mtetra
.659 .766 .929 r
.30425 .32837 .31271 .33653 .3259 .33152 .31748 .32352 Mtetra
.657 .771 .933 r
.31748 .32352 .3259 .33152 .33917 .32642 .33077 .3187 Mtetra
.658 .78 .939 r
.33077 .3187 .33917 .32642 .35249 .32135 .34412 .31384 Mtetra
.658 .787 .943 r
.34412 .31384 .35249 .32135 .36587 .31648 .35754 .30892 Mtetra
.657 .786 .943 r
.35754 .30892 .36587 .31648 .37929 .31196 .37103 .30403 Mtetra
.653 .776 .939 r
.37103 .30403 .37929 .31196 .39277 .30787 .38458 .29924 Mtetra
.646 .757 .93 r
.38458 .29924 .39277 .30787 .4063 .30416 .39819 .29465 Mtetra
.638 .732 .917 r
.39819 .29465 .4063 .30416 .41991 .30064 .41187 .2903 Mtetra
.628 .71 .905 r
.41187 .2903 .41991 .30064 .4336 .29705 .4256 .28623 Mtetra
.62 .697 .899 r
.4256 .28623 .4336 .29705 .44737 .29328 .43941 .28241 Mtetra
.612 .693 .902 r
.43941 .28241 .44737 .29328 .46123 .28929 .4533 .27883 Mtetra
.615 .705 .909 r
.4533 .27883 .46123 .28929 .47517 .28543 .46726 .27512 Mtetra
.638 .719 .906 r
.46726 .27512 .47517 .28543 .48918 .28185 .48133 .27063 Mtetra
.672 .713 .879 r
.48133 .27063 .48918 .28185 .50328 .27795 .49548 .2648 Mtetra
.69 .684 .839 r
.49548 .2648 .50328 .27795 .51747 .27277 .50971 .2577 Mtetra
.687 .654 .811 r
.50971 .2577 .51747 .27277 .53172 .26595 .52399 .25016 Mtetra
.676 .639 .806 r
.52399 .25016 .53172 .26595 .54603 .25838 .53833 .24305 Mtetra
.666 .642 .816 r
.53833 .24305 .54603 .25838 .5604 .2511 .55273 .23655 Mtetra
.663 .653 .83 r
.55273 .23655 .5604 .2511 .57482 .24421 .56719 .23041 Mtetra
.661 .665 .843 r
.56719 .23041 .57482 .24421 .58931 .23735 .58173 .2245 Mtetra
.659 .682 .861 r
.58173 .2245 .58931 .23735 .60386 .23061 .59635 .21883 Mtetra
.658 .704 .881 r
.59635 .21883 .60386 .23061 .61848 .22423 .61104 .21332 Mtetra
.659 .724 .897 r
.61104 .21332 .61848 .22423 .63318 .21821 .62581 .20786 Mtetra
.657 .738 .909 r
.62581 .20786 .63318 .21821 .64797 .21251 .64066 .20246 Mtetra
.656 .746 .916 r
.64066 .20246 .64797 .21251 .66284 .20702 .65559 .19708 Mtetra
.656 .75 .919 r
.65559 .19708 .66284 .20702 .67779 .20163 .6706 .19169 Mtetra
.656 .751 .92 r
.6706 .19169 .67779 .20163 .69283 .19625 .6857 .18627 Mtetra
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Mtetra
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73842 .17999 .73146 .16985 Mtetra
.05668 .40074 .06583 .40873 .07786 .40441 .06874 .39639 Mtetra
.06874 .39639 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39571 .09303 .38761 Mtetra
.09303 .38761 .10209 .39571 .11429 .39134 .10527 .38319 Mtetra
.10527 .38319 .11429 .39134 .12655 .38698 .11756 .37876 Mtetra
.655 .75 .92 r
.11756 .37876 .12655 .38698 .13885 .38269 .12991 .37431 Mtetra
.653 .747 .918 r
.12991 .37431 .13885 .38269 .15118 .37865 .14232 .3699 Mtetra
.649 .737 .913 r
.14232 .3699 .15118 .37865 .16352 .37512 .15477 .36558 Mtetra
.64 .716 .903 r
.15477 .36558 .16352 .37512 .17584 .37232 .16726 .36151 Mtetra
.624 .683 .885 r
.16726 .36151 .17584 .37232 .18816 .37022 .17976 .35788 Mtetra
.606 .645 .863 r
.17976 .35788 .18816 .37022 .20054 .36837 .19227 .35476 Mtetra
.591 .617 .846 r
.19227 .35476 .20054 .36837 .21305 .36591 .20481 .35209 Mtetra
.584 .611 .845 r
.20481 .35209 .21305 .36591 .22576 .36211 .2174 .34963 Mtetra
.592 .64 .867 r
.2174 .34963 .22576 .36211 .23868 .35683 .2301 .34692 Mtetra
.616 .705 .909 r
.2301 .34692 .23868 .35683 .25172 .35072 .24294 .34344 Mtetra
.645 .784 .948 r
.24294 .34344 .25172 .35072 .26482 .34454 .25594 .33899 Mtetra
.667 .84 .966 r
.25594 .33899 .26482 .34454 .27794 .33875 .26906 .33376 Mtetra
.678 .859 .969 r
.26906 .33376 .27794 .33875 .29108 .3334 .28228 .32811 Mtetra
.681 .853 .965 r
.28228 .32811 .29108 .3334 .30425 .32837 .29555 .32241 Mtetra
.678 .834 .958 r
.29555 .32241 .30425 .32837 .31748 .32352 .30888 .31683 Mtetra
.672 .813 .951 r
.30888 .31683 .31748 .32352 .33077 .3187 .32225 .31147 Mtetra
.666 .798 .946 r
.32225 .31147 .33077 .3187 .34412 .31384 .33566 .30631 Mtetra
.66 .789 .944 r
.33566 .30631 .34412 .31384 .35754 .30892 .34914 .3013 Mtetra
.655 .787 .944 r
.34914 .3013 .35754 .30892 .37103 .30403 .36267 .29641 Mtetra
.65 .786 .947 r
.36267 .29641 .37103 .30403 .38458 .29924 .37627 .29163 Mtetra
.644 .786 .95 r
.37627 .29163 .38458 .29924 .39819 .29465 .38993 .28698 Mtetra
.638 .784 .951 r
.38993 .28698 .39819 .29465 .41187 .2903 .40365 .28246 Mtetra
.635 .779 .95 r
.40365 .28246 .41187 .2903 .4256 .28623 .41745 .27802 Mtetra
.639 .772 .943 r
.41745 .27802 .4256 .28623 .43941 .28241 .43132 .27348 Mtetra
.656 .759 .926 r
.43132 .27348 .43941 .28241 .4533 .27883 .44529 .26844 Mtetra
.674 .732 .893 r
.44529 .26844 .4533 .27883 .46726 .27512 .45934 .26265 Mtetra
.684 .693 .853 r
.45934 .26265 .46726 .27512 .48133 .27063 .47347 .25605 Mtetra
.681 .658 .821 r
.47347 .25605 .48133 .27063 .49548 .2648 .48766 .24903 Mtetra
.671 .637 .808 r
.48766 .24903 .49548 .2648 .50971 .2577 .50191 .2422 Mtetra
.66 .637 .815 r
.50191 .2422 .50971 .2577 .52399 .25016 .51621 .23596 Mtetra
.655 .655 .838 r
.51621 .23596 .52399 .25016 .53833 .24305 .53058 .23026 Mtetra
.655 .681 .862 r
.53058 .23026 .53833 .24305 .55273 .23655 .54503 .22477 Mtetra
.657 .702 .88 r
.54503 .22477 .55273 .23655 .56719 .23041 .55954 .21933 Mtetra
.656 .718 .894 r
.55954 .21933 .56719 .23041 .58173 .2245 .57414 .21398 Mtetra
.656 .732 .905 r
.57414 .21398 .58173 .2245 .59635 .21883 .58881 .20866 Mtetra
.657 .741 .912 r
.58881 .20866 .59635 .21883 .61104 .21332 .60356 .20329 Mtetra
.656 .746 .916 r
.60356 .20329 .61104 .21332 .62581 .20786 .61838 .19791 Mtetra
.656 .749 .919 r
.61838 .19791 .62581 .20786 .64066 .20246 .63329 .19252 Mtetra
.656 .751 .92 r
.63329 .19252 .64066 .20246 .65559 .19708 .64828 .18711 Mtetra
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18166 Mtetra
.66334 .18166 .6706 .19169 .6857 .18627 .67849 .1762 Mtetra
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.656 .752 .92 r
.04745 .39269 .05668 .40074 .06874 .39639 .05954 .38829 Mtetra
.656 .751 .92 r
.05954 .38829 .06874 .39639 .08086 .39201 .07169 .38388 Mtetra
.656 .752 .92 r
.07169 .38388 .08086 .39201 .09303 .38761 .0839 .37944 Mtetra
.656 .751 .92 r
.0839 .37944 .09303 .38761 .10527 .38319 .09617 .37498 Mtetra
.656 .752 .92 r
.09617 .37498 .10527 .38319 .11756 .37876 .10849 .3705 Mtetra
.656 .751 .92 r
.10849 .3705 .11756 .37876 .12991 .37431 .12088 .366 Mtetra
.12088 .366 .12991 .37431 .14232 .3699 .13333 .36148 Mtetra
.655 .749 .919 r
.13333 .36148 .14232 .3699 .15477 .36558 .14583 .35696 Mtetra
.654 .745 .917 r
.14583 .35696 .15477 .36558 .16726 .36151 .1584 .35246 Mtetra
.65 .734 .91 r
.1584 .35246 .16726 .36151 .17976 .35788 .17101 .34803 Mtetra
.642 .713 .899 r
.17101 .34803 .17976 .35788 .19227 .35476 .18367 .34378 Mtetra
.632 .686 .883 r
.18367 .34378 .19227 .35476 .20481 .35209 .19636 .33982 Mtetra
.621 .656 .863 r
.19636 .33982 .20481 .35209 .2174 .34963 .20909 .3361 Mtetra
.612 .631 .845 r
.20909 .3361 .2174 .34963 .2301 .34692 .22186 .33262 Mtetra
.604 .615 .836 r
.22186 .33262 .2301 .34692 .24294 .34344 .23469 .32934 Mtetra
.603 .619 .84 r
.23469 .32934 .24294 .34344 .25594 .33899 .24759 .32612 Mtetra
.61 .644 .859 r
.24759 .32612 .25594 .33899 .26906 .33376 .26059 .3227 Mtetra
.623 .687 .889 r
.26059 .3227 .26906 .33376 .28228 .32811 .27368 .3189 Mtetra
.638 .736 .919 r
.27368 .3189 .28228 .32811 .29555 .32241 .28689 .31464 Mtetra
.648 .778 .943 r
.28689 .31464 .29555 .32241 .30888 .31683 .30019 .31001 Mtetra
.654 .807 .957 r
.30019 .31001 .30888 .31683 .32225 .31147 .31357 .30511 Mtetra
.656 .822 .963 r
.31357 .30511 .32225 .31147 .33566 .30631 .32704 .30006 Mtetra
.657 .827 .965 r
.32704 .30006 .33566 .30631 .34914 .3013 .34057 .29495 Mtetra
.657 .825 .964 r
.34057 .29495 .34914 .3013 .36267 .29641 .35416 .28981 Mtetra
.66 .82 .96 r
.35416 .28981 .36267 .29641 .37627 .29163 .36783 .28461 Mtetra
.665 .811 .953 r
.36783 .28461 .37627 .29163 .38993 .28698 .38157 .27928 Mtetra
.673 .796 .94 r
.38157 .27928 .38993 .28698 .40365 .28246 .39539 .27373 Mtetra
.681 .772 .92 r
.39539 .27373 .40365 .28246 .41745 .27802 .40928 .26787 Mtetra
.687 .741 .892 r
.40928 .26787 .41745 .27802 .43132 .27348 .42325 .26163 Mtetra
.685 .706 .863 r
.42325 .26163 .43132 .27348 .44529 .26844 .43729 .25513 Mtetra
.678 .677 .842 r
.43729 .25513 .44529 .26844 .45934 .26265 .45139 .24856 Mtetra
.67 .662 .833 r
.45139 .24856 .45934 .26265 .47347 .25605 .46554 .24222 Mtetra
.661 .663 .841 r
.46554 .24222 .47347 .25605 .48766 .24903 .47975 .2363 Mtetra
.657 .681 .862 r
.47975 .2363 .48766 .24903 .50191 .2422 .49402 .23077 Mtetra
.656 .708 .886 r
.49402 .23077 .50191 .2422 .51621 .23596 .50836 .22541 Mtetra
.658 .73 .902 r
.50836 .22541 .51621 .23596 .53058 .23026 .52278 .22004 Mtetra
.658 .739 .909 r
.52278 .22004 .53058 .23026 .54503 .22477 .53727 .21467 Mtetra
.655 .741 .913 r
.53727 .21467 .54503 .22477 .55954 .21933 .55184 .20939 Mtetra
.654 .746 .917 r
.55184 .20939 .55954 .21933 .57414 .21398 .56648 .20412 Mtetra
.656 .75 .919 r
.56648 .20412 .57414 .21398 .58881 .20866 .58121 .19876 Mtetra
.657 .751 .919 r
.58121 .19876 .58881 .20866 .60356 .20329 .59601 .19335 Mtetra
.656 .751 .92 r
.59601 .19335 .60356 .20329 .61838 .19791 .61089 .18794 Mtetra
.61089 .18794 .61838 .19791 .63329 .19252 .62585 .18251 Mtetra
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18166 .65601 .17155 Mtetra
.65601 .17155 .66334 .18166 .67849 .1762 .67121 .16602 Mtetra
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Mtetra
.656 .752 .92 r
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.656 .751 .92 r
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Mtetra
.03814 .38455 .04745 .39269 .05954 .38829 .05026 .38012 Mtetra
.656 .752 .92 r
.05026 .38012 .05954 .38829 .07169 .38388 .06244 .37567 Mtetra
.656 .751 .92 r
.06244 .37567 .07169 .38388 .0839 .37944 .07468 .37119 Mtetra
.656 .752 .92 r
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Mtetra
.656 .751 .92 r
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36218 Mtetra
.656 .752 .92 r
.09934 .36218 .10849 .3705 .12088 .366 .11176 .35763 Mtetra
.656 .751 .92 r
.11176 .35763 .12088 .366 .13333 .36148 .12424 .35307 Mtetra
.12424 .35307 .13333 .36148 .14583 .35696 .13679 .34848 Mtetra
.655 .75 .92 r
.13679 .34848 .14583 .35696 .1584 .35246 .14939 .34388 Mtetra
.655 .749 .919 r
.14939 .34388 .1584 .35246 .17101 .34803 .16206 .33927 Mtetra
.654 .745 .917 r
.16206 .33927 .17101 .34803 .18367 .34378 .17478 .33465 Mtetra
.653 .737 .911 r
.17478 .33465 .18367 .34378 .19636 .33982 .18757 .33004 Mtetra
.648 .721 .902 r
.18757 .33004 .19636 .33982 .20909 .3361 .20041 .32554 Mtetra
.642 .702 .89 r
.20041 .32554 .20909 .3361 .22186 .33262 .21329 .32118 Mtetra
.637 .682 .876 r
.21329 .32118 .22186 .33262 .23469 .32934 .22623 .31691 Mtetra
.633 .662 .861 r
.22623 .31691 .23469 .32934 .24759 .32612 .23924 .31266 Mtetra
.629 .643 .846 r
.23924 .31266 .24759 .32612 .26059 .3227 .25232 .30844 Mtetra
.626 .629 .834 r
.25232 .30844 .26059 .3227 .27368 .3189 .26546 .30423 Mtetra
.624 .623 .829 r
.26546 .30423 .27368 .3189 .28689 .31464 .27867 .3 Mtetra
.627 .625 .83 r
.27867 .3 .28689 .31464 .30019 .31001 .29196 .29568 Mtetra
.631 .633 .834 r
.29196 .29568 .30019 .31001 .31357 .30511 .30533 .29119 Mtetra
.637 .643 .84 r
.30533 .29119 .31357 .30511 .32704 .30006 .31879 .28647 Mtetra
.643 .652 .844 r
.31879 .28647 .32704 .30006 .34057 .29495 .33233 .28153 Mtetra
.649 .659 .846 r
.33233 .28153 .34057 .29495 .35416 .28981 .34596 .27635 Mtetra
.654 .661 .844 r
.34596 .27635 .35416 .28981 .36783 .28461 .35966 .27094 Mtetra
.657 .659 .841 r
.35966 .27094 .36783 .28461 .38157 .27928 .37343 .26534 Mtetra
.658 .656 .837 r
.37343 .26534 .38157 .27928 .39539 .27373 .38728 .25961 Mtetra
.659 .654 .834 r
.38728 .25961 .39539 .27373 .40928 .26787 .40119 .25381 Mtetra
.657 .656 .837 r
.40119 .25381 .40928 .26787 .42325 .26163 .41517 .24806 Mtetra
.657 .665 .846 r
.41517 .24806 .42325 .26163 .43729 .25513 .42921 .24242 Mtetra
.656 .681 .861 r
.42921 .24242 .43729 .25513 .45139 .24856 .44331 .23694 Mtetra
.657 .703 .881 r
.44331 .23694 .45139 .24856 .46554 .24222 .45749 .23158 Mtetra
.658 .726 .899 r
.45749 .23158 .46554 .24222 .47975 .2363 .47173 .22622 Mtetra
.66 .741 .91 r
.47173 .22622 .47975 .2363 .49402 .23077 .48604 .22082 Mtetra
.659 .745 .913 r
.48604 .22082 .49402 .23077 .50836 .22541 .50043 .21543 Mtetra
.656 .744 .915 r
.50043 .21543 .50836 .22541 .52278 .22004 .5149 .21014 Mtetra
.653 .746 .918 r
.5149 .21014 .52278 .22004 .53727 .21467 .52944 .20492 Mtetra
.655 .752 .922 r
.52944 .20492 .53727 .21467 .55184 .20939 .54406 .19962 Mtetra
.657 .754 .921 r
.54406 .19962 .55184 .20939 .56648 .20412 .55875 .1942 Mtetra
.657 .751 .92 r
.55875 .1942 .56648 .20412 .58121 .19876 .57353 .18876 Mtetra
.655 .75 .92 r
.57353 .18876 .58121 .19876 .59601 .19335 .58838 .18334 Mtetra
.656 .751 .92 r
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17789 Mtetra
.656 .752 .92 r
.60332 .17789 .61089 .18794 .62585 .18251 .61833 .17239 Mtetra
.656 .751 .92 r
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Mtetra
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Mtetra
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15575 Mtetra
.656 .752 .92 r
.66386 .15575 .67121 .16602 .6865 .16047 .6792 .15013 Mtetra
.656 .751 .92 r
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Mtetra
.656 .752 .92 r
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Mtetra
.02874 .37636 .03814 .38455 .05026 .38012 .0409 .37188 Mtetra
.656 .751 .92 r
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Mtetra
.656 .752 .92 r
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.656 .751 .92 r
.06538 .36287 .07468 .37119 .08698 .36669 .07771 .35834 Mtetra
.656 .752 .92 r
.07771 .35834 .08698 .36669 .09934 .36218 .09011 .35377 Mtetra
.656 .751 .92 r
.09011 .35377 .09934 .36218 .11176 .35763 .10256 .34919 Mtetra
.656 .752 .92 r
.10256 .34919 .11176 .35763 .12424 .35307 .11508 .34458 Mtetra
.656 .751 .92 r
.11508 .34458 .12424 .35307 .13679 .34848 .12766 .33996 Mtetra
.656 .752 .92 r
.12766 .33996 .13679 .34848 .14939 .34388 .1403 .3353 Mtetra
.656 .751 .92 r
.1403 .3353 .14939 .34388 .16206 .33927 .153 .33062 Mtetra
.656 .75 .92 r
.153 .33062 .16206 .33927 .17478 .33465 .16576 .32593 Mtetra
.655 .75 .92 r
.16576 .32593 .17478 .33465 .18757 .33004 .17859 .32125 Mtetra
.656 .749 .919 r
.17859 .32125 .18757 .33004 .20041 .32554 .19148 .3165 Mtetra
.656 .744 .915 r
.19148 .3165 .20041 .32554 .21329 .32118 .20444 .31171 Mtetra
.654 .734 .908 r
.20444 .31171 .21329 .32118 .22623 .31691 .21747 .30694 Mtetra
.65 .722 .901 r
.21747 .30694 .22623 .31691 .23924 .31266 .23054 .30226 Mtetra
.647 .712 .895 r
.23054 .30226 .23924 .31266 .25232 .30844 .24368 .29763 Mtetra
.646 .704 .889 r
.24368 .29763 .25232 .30844 .26546 .30423 .25688 .293 Mtetra
.646 .696 .882 r
.25688 .293 .26546 .30423 .27867 .3 .27016 .2883 Mtetra
.646 .687 .874 r
.27016 .2883 .27867 .3 .29196 .29568 .28351 .28353 Mtetra
.646 .68 .867 r
.28351 .28353 .29196 .29568 .30533 .29119 .29693 .27866 Mtetra
.646 .673 .862 r
.29693 .27866 .30533 .29119 .31879 .28647 .31043 .27373 Mtetra
.647 .671 .858 r
.31043 .27373 .31879 .28647 .33233 .28153 .324 .26872 Mtetra
.648 .671 .858 r
.324 .26872 .33233 .28153 .34596 .27635 .33764 .26365 Mtetra
.65 .674 .86 r
.33764 .26365 .34596 .27635 .35966 .27094 .35135 .25851 Mtetra
.651 .681 .865 r
.35135 .25851 .35966 .27094 .37343 .26534 .36514 .25333 Mtetra
.653 .691 .873 r
.36514 .25333 .37343 .26534 .38728 .25961 .37899 .24811 Mtetra
.655 .703 .882 r
.37899 .24811 .38728 .25961 .40119 .25381 .39292 .24287 Mtetra
.657 .717 .892 r
.39292 .24287 .40119 .25381 .41517 .24806 .40691 .23758 Mtetra
.658 .729 .901 r
.40691 .23758 .41517 .24806 .42921 .24242 .42098 .23226 Mtetra
.66 .738 .908 r
.42098 .23226 .42921 .24242 .44331 .23694 .43513 .2269 Mtetra
.66 .742 .911 r
.43513 .2269 .44331 .23694 .45749 .23158 .44934 .22152 Mtetra
.657 .742 .912 r
.44934 .22152 .45749 .23158 .47173 .22622 .46363 .2162 Mtetra
.654 .743 .915 r
.46363 .2162 .47173 .22622 .48604 .22082 .47799 .21098 Mtetra
.652 .747 .919 r
.47799 .21098 .48604 .22082 .50043 .21543 .49243 .20578 Mtetra
.655 .754 .923 r
.49243 .20578 .50043 .21543 .5149 .21014 .50694 .20048 Mtetra
.658 .757 .923 r
.50694 .20048 .5149 .21014 .52944 .20492 .52153 .19504 Mtetra
.658 .752 .92 r
.52153 .19504 .52944 .20492 .54406 .19962 .5362 .18957 Mtetra
.655 .749 .919 r
.5362 .18957 .54406 .19962 .55875 .1942 .55095 .18416 Mtetra
.655 .75 .92 r
.55095 .18416 .55875 .1942 .57353 .18876 .56578 .17874 Mtetra
.656 .752 .921 r
.56578 .17874 .57353 .18876 .58838 .18334 .58068 .17325 Mtetra
.656 .752 .92 r
.58068 .17325 .58838 .18334 .60332 .17789 .59567 .16772 Mtetra
.656 .751 .92 r
.59567 .16772 .60332 .17789 .61833 .17239 .61074 .16218 Mtetra
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.656 .752 .92 r
.64112 .151 .6486 .16132 .66386 .15575 .65644 .14536 Mtetra
.656 .751 .92 r
.65644 .14536 .66386 .15575 .6792 .15013 .67184 .1397 Mtetra
.656 .752 .92 r
.67184 .1397 .6792 .15013 .69463 .14449 .68732 .13399 Mtetra
.656 .751 .92 r
.68732 .13399 .69463 .14449 .71014 .13882 .70289 .12827 Mtetra
.01926 .36808 .02874 .37636 .0409 .37188 .03145 .36357 Mtetra
.656 .752 .92 r
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Mtetra
.656 .751 .92 r
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35448 Mtetra
.656 .752 .92 r
.056 .35448 .06538 .36287 .07771 .35834 .06836 .34989 Mtetra
.656 .751 .92 r
.06836 .34989 .07771 .35834 .09011 .35377 .08079 .3453 Mtetra
.656 .752 .92 r
.08079 .3453 .09011 .35377 .10256 .34919 .09328 .34067 Mtetra
.656 .751 .92 r
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Mtetra
.656 .752 .92 r
.10583 .33602 .11508 .34458 .12766 .33996 .11844 .33135 Mtetra
.656 .751 .92 r
.11844 .33135 .12766 .33996 .1403 .3353 .13112 .32666 Mtetra
.656 .752 .92 r
.13112 .32666 .1403 .3353 .153 .33062 .14385 .32194 Mtetra
.14385 .32194 .153 .33062 .16576 .32593 .15666 .3172 Mtetra
.15666 .3172 .16576 .32593 .17859 .32125 .16952 .31241 Mtetra
.655 .75 .919 r
.16952 .31241 .17859 .32125 .19148 .3165 .18245 .30763 Mtetra
.654 .75 .92 r
.18245 .30763 .19148 .3165 .20444 .31171 .19545 .30286 Mtetra
.654 .751 .921 r
.19545 .30286 .20444 .31171 .21747 .30694 .2085 .29807 Mtetra
.657 .753 .921 r
.2085 .29807 .21747 .30694 .23054 .30226 .22163 .29318 Mtetra
.658 .749 .917 r
.22163 .29318 .23054 .30226 .24368 .29763 .23483 .28823 Mtetra
.657 .742 .912 r
.23483 .28823 .24368 .29763 .25688 .293 .2481 .28326 Mtetra
.655 .734 .908 r
.2481 .28326 .25688 .293 .27016 .2883 .26143 .27833 Mtetra
.653 .729 .905 r
.26143 .27833 .27016 .2883 .28351 .28353 .27482 .27343 Mtetra
.651 .727 .904 r
.27482 .27343 .28351 .28353 .29693 .27866 .28828 .26855 Mtetra
.652 .728 .905 r
.28828 .26855 .29693 .27866 .31043 .27373 .30181 .26363 Mtetra
.652 .729 .906 r
.30181 .26363 .31043 .27373 .324 .26872 .31541 .25866 Mtetra
.654 .732 .907 r
.31541 .25866 .324 .26872 .33764 .26365 .32909 .25362 Mtetra
.655 .734 .908 r
.32909 .25362 .33764 .26365 .35135 .25851 .34284 .24851 Mtetra
.657 .737 .909 r
.34284 .24851 .35135 .25851 .36514 .25333 .35666 .24332 Mtetra
.658 .738 .909 r
.35666 .24332 .36514 .25333 .37899 .24811 .37055 .23809 Mtetra
.658 .739 .91 r
.37055 .23809 .37899 .24811 .39292 .24287 .38452 .23282 Mtetra
.657 .739 .91 r
.38452 .23282 .39292 .24287 .40691 .23758 .39856 .22756 Mtetra
.656 .741 .912 r
.39856 .22756 .40691 .23758 .42098 .23226 .41267 .22232 Mtetra
.654 .743 .915 r
.41267 .22232 .42098 .23226 .43513 .2269 .42685 .21712 Mtetra
.653 .748 .919 r
.42685 .21712 .43513 .2269 .44934 .22152 .44111 .21193 Mtetra
.654 .754 .923 r
.44111 .21193 .44934 .22152 .46363 .2162 .45544 .20667 Mtetra
.657 .758 .924 r
.45544 .20667 .46363 .2162 .47799 .21098 .46985 .20129 Mtetra
.659 .756 .922 r
.46985 .20129 .47799 .21098 .49243 .20578 .48434 .19582 Mtetra
.658 .75 .918 r
.48434 .19582 .49243 .20578 .50694 .20048 .49891 .19037 Mtetra
.655 .747 .917 r
.49891 .19037 .50694 .20048 .52153 .19504 .51355 .18498 Mtetra
.654 .749 .92 r
.51355 .18498 .52153 .19504 .5362 .18957 .52827 .17958 Mtetra
.656 .753 .921 r
.52827 .17958 .5362 .18957 .55095 .18416 .54307 .17411 Mtetra
.54307 .17411 .55095 .18416 .56578 .17874 .55795 .16858 Mtetra
.656 .751 .92 r
.55795 .16858 .56578 .17874 .58068 .17325 .57291 .16303 Mtetra
.57291 .16303 .58068 .17325 .59567 .16772 .58795 .15747 Mtetra
.656 .752 .92 r
.58795 .15747 .59567 .16772 .61074 .16218 .60307 .15186 Mtetra
.656 .751 .92 r
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Mtetra
.656 .752 .92 r
.64894 .13488 .65644 .14536 .67184 .1397 .66439 .12915 Mtetra
.656 .751 .92 r
.66439 .12915 .67184 .1397 .68732 .13399 .67994 .1234 Mtetra
.656 .752 .92 r
.67994 .1234 .68732 .13399 .70289 .12827 .69556 .1176 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3ooolZ0:O0
j`030000002W`>/0Yl3[00L0Yl3[4P3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000004`0
oooo;P2W`>/00`000000Yl3[0:O0j`080:O0ja40oooo00<000000?ooo`3oool0<`3oool004l0oooo
0P00001=0?ooo`<0Yko[1`2W`>/30:Nojb<0Yl3[00<000000:O0j`2W`>/0202W`>/B0?ooo`030000
003oool0oooo0380oooo001<0?ooo`@00000C03oool60:Noj`@0Yl3[1P2W_n/30:O0j`80Yko[7@2W
`>/00`000000Yl3[0:O0j`090:O0ja00oooo00<000000?ooo`000000<`3oool001d0oooo0P000004
0?ooo`8000000`3oool4000001h0oooo0P00001=0?ooo`@0YkoZ5@2W_n/L0:O0j`030000002W`>/0
Yl3[00T0Yl3[4P3oool00`000000oooo0?ooo`0a0?ooo`00703oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo01`0oooo0`00001=0?ooo`<0Z;o[102W_nX30:Noj`<0Z<3[1@2W_n/5
0:S0j`D0Yko[6`2W`>/00`000000Yl3[0:O0j`0:0:O0ja80oooo00<000000?ooo`3oool0<03oool0
01`0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0I0?ooo`800000CP3oool6
0:Roj`@0YkoZ1P2X`>/20:Noj`<0Z<7[1@2X`>/20:Noj`<0Z<3[102W`>/50:Noj`D0Yl3[1@2W_n/7
0:O0j`030000002W`>/0Yl3[00/0Yl3[4P3oool00`000000oooo0?ooo`0_0?ooo`005P3oool40000
0080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0E0?ooo`<00000C03oool5
0:S1k0D0Z;o[1@2X`N`50:S0j`H0Z<7[2P2X`>/20:O0j`80YkkZ1@2W_n/20:O0j`<0YkkZ2P2W_n/0
0`2W`>/000000:O0j`0<0:O0ja80oooo00<000000?ooo`3oool0;`3oool001`0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000C0?ooo`<00000C@3oool30:S2k0D0Z<7/1@2W
`N`50:S1k0D0Yl3/1@2X`N/50:Noj`D0Z<3[1@2W_^X40:Noj`H0YkkZ0P2W_n/30:Rmj@D0Yko[00<0
00000:O0j`2W_nX00P2W_nX:0:O0ja80oooo00<000000?ooo`3oool0;P3oool001d0oooo0P00000:
0?ooo`8000004P3oool4000004`0oooo1P2X`^`20:S1k0<0Y[o[1@2W`N`20:S1k0<0Ykk[1@2W`>`5
0:NnjPD0Yko[1@2X_NT40:NnjPD0Z;cX1@2W_^X60:Rmj@@0Yko[00<000000:NojP2W_nX00`2W_nX2
0:O0j`<0Z;oZ1@2W`>/B0?ooo`030000003oool0oooo02d0oooo000k0?ooo`800000C03oool50:O1
k0D0Z<;/1P2V_n/40:O1k0H0Ykk[0P2W`>`30:Nmj@D0YkkZ0P2W_n/30:Nki`D0Z;gY102X^ND50:Rl
j0D0Z;[V1@2X_NT40:Rlj0030000002W_nX0YkoZ00<0YkoZ1P2X_nX40:O0ja80oooo00<000000?oo
o`3oool0;@3oool003P0oooo0`00001<0?ooo`<0Yko[1@2W`N`50:NnjPD0Y[o[1@2W_^X50:Nnj`H0
YkgY102W_^X60:Nki`80Z;gY0`2X]>440:Rii@80Z;cX0`2Y]>050:RjiP80Z;gY0`2Y^><40:Rlj003
0000002X_>P0Z;cX00<0Z;cX1@2X_nX50:Noja40oooo0P00000^0?ooo`00=@3oool3000004d0oooo
1P2W_n/20:O1k0<0Z;gY1@2W_^X50:Rnj@D0YkkZ1@2X_NP50:Nmj@D0YkOT1@2W^nL60:Rdh@<0Z;WU
1P2Y]>040:RjiPH0ZKSS0P2X_>P00`2Z]n8000000:ZghP050:Rlj0D0Z;gX1@2W_n/A0?ooo`030000
003oool0oooo02`0oooo000c0?ooo`800000C@3oool50:NnjP@0Yko[1P2X_NT20:NnjP<0Z;gX1@2X
_^T20:NnjP<0Z;[V1@2X_NP20:Nmj@<0Z;?Q1@2W]n@50:R^g0D0Z;CQ102Z[]X50:Vdh0D0Zk7L1@2Y
^><30:ZghP030000002Z]n80Z[OR0080Z;cX0`2[^><50:Rmj080Yko[0`2X_^TA0?ooo`030000003o
ool0oooo02/0oooo000`0?ooo`<00000B`3oool50:Nmj@D0YkkZ2@2X_NT60:Rmj0@0Z;kY1P2X^^H4
0:Rmj0H0Z;?Q0P2W]n@30:VZe`D0Z:kL0P2X]>430:^YeP@0ZZkJ0P2Y]>030:f/ePD0Zk7L0P2Y^><3
0:f`fP80Z[OR00<000000:ZghP2Z]n801P2[^><40:Rmj0H0Z;kY4@3oool00`000000oooo0?ooo`0Z
0?ooo`00;P3oool3000004/0oooo0`2X_NP50:Nmj@80YkkZ0`2X_>P40:Rmj@D0Z;WV1@2X_NP50:Ne
hPD0Z;[V1@2W[]`50:Rch@D0ZJ[G1@2X[]`50:^YeP@0ZZkJ1@2][=H50:^ag0H0[K3J00<0Z[OR0000
002_/MX00P2_/MX50:^hh`D0Zk[U1@2X_^TA0?ooo`030000003oool0oooo02X0oooo000[0?ooo`<0
00000`3oool00`000000oooo0?ooo`160?ooo`H0Z;gX102W_NT60:Rlj080Z;gY0P2X/n450:RiiP80
Z;gX0`2X[]`50:NehP80Z;[V0`2WYmH50:N^g080Z;?Q0`2YYm@50:VZe`80Z:kL0`2]ZM@50:^YeP80
ZZkJ0P2_Zm<50:f/eP80Zk7L0`2`[=<50:f`fP030:nafP000000[k7J00<0[k7J0P2[^><30;2dg0D0
Zk[U1@2Y_>LA0?ooo`030000003oool0oooo02T0oooo000Y0?ooo`800000B`3oool:0:Rmj0D0Z;[V
1@2X_>P50:Rch@@0Z;WV1P2X[]`40:NehPH0YjOF102W[]`50:VWe0D0ZJ[G1@2]ZM@50:^YeP@0[j_C
1@2][=H60;2/d`80[K3J0`2c[M<00`000000[k7J0:nafP020:nafPH0/;CL0P2[^^D30:nhg`@0ZKcW
4P3oool00`000000oooo0?ooo`0X0?ooo`009P3oool3000004`0oooo0P2X_>P50:Rmj0D0Z;OT1@2X
^^H50:N^g0D0Z;?Q102YZML50:R^g0D0Z:?@1@2WYmH50:ZTd0D0ZJOD0P2YZ]L30:j]ePD0[JWD0P2[
ZMH30;6`e`@0[j_C0P2][=H30;B_d`D0/:cC1@2c[M<00`000000[k7J0:nafP030;J_d`D0/;CL1@2_
^=l20:Vli`<0Zk_U4@3oool00`000000oooo0?ooo`0X0?ooo`00903oool2000004d0oooo1@2X_>P3
0:Rmj080Yk?Q1@2X]n@20:RjiP<0Z:[H1@2W[]`20:Rch@<0ZjWE102YZML30:R^g080Zj?>1@2XXm02
0:NWeP<0[J?>102ZY=050:VWe0D0[ZgF1@2]ZM@50;6`e`@0[j_C1P2d[m<20;2/d`<0]k7C0`2c[M<2
000000H0]ZoC0P2`]=`30;Jbe@@0[kSO1P2[^nD@0?ooo`800000:@3oool00240oooo0`00001;0?oo
o`X0Z;cX1@2W/n440:Rgi0D0Z:[H1@2W[]`50:^Ye@D0ZJWG102[Xlh50:RSd0D0[J?>1@2ZY=020:VW
e0<0[k3H1@2^[MH20:fYe0<0/KWO102a/=L20:n[d`<0];SK1@2d[m<50;Nad`<0000000<0/jgC0;Zb
d@0000001@2f[m<50;Jbe@80[kSO0`2e]]X50:^kiA80oooo00<000000?ooo`3oool09P3oool001l0
oooo0`0000190?ooo`D0Yk_X1@2X_>P50:N`g`@0Yk?Q1@2XYmH50:RZf080YjkL0`2][ML50:^Ye@80
ZJWG0`2^Z=840:^ScP80Z:?@0`2_Yll50:fScP@0ZZC@1P2_/=P40:j]ePH0/KWO0`2a/=L60;Bhf`80
]:oC0`2f_=h01@2g/M<00000000000000000]k7C0080/jgC0P2j/]400`000000]ZoC0;J_d`020;J_
d`80_;;@102f/]D60;FffP80Zk_U0`2^^^8A0?ooo`030000003oool0oooo02H0oooo000M0?ooo`80
0000B`3oool70:Nkj080Z;cX0`2V[]d50:N`g`80Yk?Q0P2XYmD50:RWeP@0Z:[H1@2][ML50:^Ye@D0
[ZSB102[Xlh50:nWc`D0[J?>0P2ZY=030;:cf@D0[k3H1@2_`NL50;6ig`@0/<?X1@2d^=/30;JlgP<0
0000102g/M<50;Zbd@030000002f[m<0]ZoC00<0_;;@0`2f/]D20;fcd0D0]KKJ1P2^^^8A0?ooo`03
0000003oool0oooo00`0oooo0P0000040?ooo`8000000`3oool4000000X0oooo000E0?ooo`D00000
0`3oool2000004T0oooo2@2W^nP60:J^g@@0Yk3O1@2XYmD40:RWePD0[kCL1@2][ML20:^Ye@<0[k7J
1@2^Z=820:^ScP80/:oF1@2_Yll40:fScPH0/[?I0P2_/=P30;36jPD0[l7W0P2a^Ml30:K:lP@0/<?X
0P2d^=/20:_6kP<000000`2f_=h20;Nad`<0^KcL1@2j/]400`000000_;;@0;bbd0030;bbd0030;Jb
e@2m/m00_K?@0080_K?@0P2e]]X30;^ge@D0[[[R4P3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool02`3oool001L0oooo00<000000?ooo`3oool0
0`3oool3000004@0oooo1@2V^^L40:Nkj0D0YZcL1@2V[]d50:RWePD0Z:OE0P2XYmH20:nmi0D0[kCL
102][ML50:nafPD0[ZSB1@2`[mH40:nWc`80[J?>0`2f^md50;:cf@H0/<KZ102_`NL60:K:lP<0/<?X
0P2[a^h200000080ZlK^102f_=h60;Vlg080^[;A0`2l^]L00`000000_;;@0;bbd0020;bbd0D0_K?@
1P2k]mD20:jjhP<0/[[O4@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`00000o0?ooo`X0Y[[W102UZm/50:J/g080YZkM0`2XZ=L40:RWePD0Z:OE102__N@50:ndg0D0
[;_T1@2_/MX20:jXdP<0[;KQ1@2`[mH30:nWc`H0][_M0P2b/mT30;C;j`D0/<KZ1@2Sc?D50:K:lP80
VlWg0`0000040:_6kPD0ZLK^1@2i_=`50;bje`030000002l/]00_;;@00<0`;OA0`2m/m020<>ec@D0
^kOE1P2b^]lA0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool02@3oool000l0oooo100000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`T0Y[[W1`2UZm/40:J/g0D0
Z:SG1@2XYmH20:RWe@<0[/G[102__N@20:ndg0<0Yl;]1@2/^n@40:nafPD0[;KQ1@2`[mH40;C6j0D0
][_M1P2dbn/50:_=lPD0Xlce0`2Fb?T3000000<0VlWg1@2Ca_T50:W6kP80^KcL0`2]a>X50;bje`03
00000030]m40`;OA0080`;OA0P2m/m030<>ec@@0^kOE0P32^=450;:jga80oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000X0oooo000G0?oo
o`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo03P0oooo2@2V^^L:0:F[
f`@0YjWH1@2XZ=L40:RWePH0[/G[0`2__N@60:O2k@@0[;_T1@2S^>L50:bfh@80/:oF0`2Wco@40;C6
j080][_M0`2ado830;C;j`<0[lk`1@2[cO8409o9m@<000000P2Fb?T508g4nPD0TlKi102Ya^h60:g4
jP80_;[G0`2f_n4010000000`;OA0<2gd@30]m460<>ec@80^kOE1032^=420;:jg`<0][_M403oool2
000000/0oooo0P00000:0?ooo`8000002`3oool001H0oooo0P0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0<`3oool50:Nji`D0Y[[W102U[=`70:F[f`<0YZSH102WZMP40:RX
e`D0[<_`1@2^aN/50:?5l@@0Yl;]1@2M]>P50:>hi`@0[;KQ1P2Wco@30;C6j0H0/M?b1P2_c_050:g;
k`<000000P2ObOD409K4m`D0SLCj102Ca_T50933n0D0[LCZ1@2f_n400`30]m4000000<2gd@020<2j
e@D0`kG=1P32^=450;JkgA80oooo00<000000?ooo`3oool08@3oool001`0oooo00<000000?ooo`3o
ool01@3oool200000300oooo102W^nP50:Nji`D0YJkM102U[=`40:F[f`D0YZSH1@2WZMP20:RXe`80
Z/oc1@2/bo050:;7l`D0XlGa102L/NH509fdj0@0XkSW1@2JcOT50:O?m0D0WmOk1@2VcoH30:o>l0<0
[lg_00D0[L__00000000000000000:g;k`050:C7lP@0U/Cg1@2>`OP408FonPD0T<?h1@2E`OD50;Jo
h@0400000030^]D0`;[E0<2je@@0`kG=0P36^<`40<:hd@80ak[=0`2f^md20;Zmg180oooo00<00000
0?ooo`3oool0803oool001`0oooo0P0000080?ooo`030000003oool0oooo02/0oooo0`2X_NT40:Nk
j080Yk[W0`2U[ml50:F^g@<0YJcL1@2TY]P50:JXf0@0YjWH1@2Zco<50:?8l`D0X/Oc1@2N/^H409ba
iP@0WKCX1@2IaoL509[=n@H0S]?n102CcO`50:K?mP<0[lg_0`0000020:g;k`<0/<g_102Tao8509c3
l`D0S/7h1025_oX507fjnPD0UL7e102f_n400`30^]D000000<2je@020<2je@80`kG=1036^<`20<:h
d@<0ak[=0P2f^md40;Zmg140oooo00<000000?ooo`3oool0803oool001`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0X0?ooo`H0Z;gY0`2W^nP50:F_g`D0YJkM102SY=L50:BVf0@0
YZSH1P2XdOD50:C9l`@0XlSc1@2P]NL509jbiP<0W;7V1@2M`o<509W7m`H0TM7m1@2?c?`409?=o0@0
XLcf0`0000030:o=k`H0/<g_102Wao0509c3l`D0Tkoe1024_?T507fjnP@0UL7e1@2U_n`01030^]D0
00000<2je@30^]D60<Jhc0D0ak[=1P2j_M`B0?ooo`030000003oool0oooo01l0oooo000K0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool50:RojPD0Z;gY102U/^450:F_g`80
YJkM0`2QX]D40:>Te`@0Y:KH1@2XdoH30:SAm@<0Y/Wb1@2TbO<40:>kjPD0X;GW102N/^H509nok`@0
WL?c1P2Ldo/509W>nPD0Slcl102=b?/300000080XLcf1@2^d?830;3=k`<0[/ka102Wao050:72l0D0
Tkoe1024_?T507Jen@@0N[Oi102U_n`20<2je@030000002k_=X0^kcJ00@0a[S<0P38^L`30<Njc@80
cKc:0`2j_M`30;k0fa80oooo00<000000?ooo`3oool07P3oool001/0oooo0P00000<0?ooo`030000
003oool0oooo01l0oooo1@2X`>/40:RojPD0YKCS102U/^440:F_g`D0XJ;E1@2SY=L20:BVf0<0Z=?g
102XdoH60:K9lPD0YL7^102S^nX40:2ei`D0W[[/1@2O_nl50:7Cn@D0XM7i1@2Ic_X50938n`0408g8
n`000000000008g8n`D0V/[h1@2^d?860:k>l@@0Z<G_1@2Q`_0509S0l`@0Qkcg1@1f]OT407Zgn@<0
YKo/0P2k_=X010000000^kcJ0;^lfP2k_=X20<Jhc0@0b;W<00<0ak[=0<flbP3=_<X00P3=_<X60;k0
fa40oooo00<000000?ooo`3oool07P3oool001/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0J0?ooo`D0Yl3[1@2X`>/40:Ffi@D0YKCS102U/^440:2Oe0D0XJ;E102SY=L60:SCm`@0
YlWa0`2VbO830:O6l0D0YL7^0`2S^nX509fej@D0W[[/1@2ScoL30:7Cn@80XmCi1@2QdOT509g9mP80
T<Sk0`00000408[2nPD0V/[h1@2YdoH30:k>l@<0Z<gc102XaNl50:G3k`D0V<3c1027_?L507Fcn@<0
IZch102=^?<20;^lfP030000002k_=X0^kcJ00H0b;W<1@3=_<X00`3B_/P0_/3K0;k0f`030;k0fa80
oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0H0?ooo`80Yko[1@2W`>/20:S0j`<0Y[SV102U]^D40:Fdh`D0WioD102PWm@40:6Re@H0Ym;f
1@2XbO440:O9l@H0YlK`102U`Nh409bcj0D0WKGY1@2Tb_@50:??m`D0XmCi1@2SbO@309g9mP<00000
102D`oL408[2nPD0V<Wh1@2YdoH50:S=l`D0Z<C^1@2U`nl509c2l`@0S;cf101e/oT406J/n0@0SKSc
0P2k_=X00`000000/K[P0;6jh0040<Ric080bKW;0`3=_<X30=:nb080_/3K0`33a=/@0?ooo`800000
7`3oool001/0oooo0P00000?0?ooo`030000003oool0oooo01D0oooo1@2W_n/40:O0j`H0Y[SV102U
]^D40:2Qe@@0WioD102PWm@50:O>m0<0Ym;f0`2Zc?8:0:S9l@@0YlK`1@2N]NP409bcj0<0WKGY0P2R
`Nl50:C:m0H0Y]Wi102Sc?D40:?9m0<000000`2Sao8509C3m`@0TK_c1@2HbOP609oAn@@0WlCc1@2X
a>h50:S5kPD0W<;c0`2<_?H507Ndn0<0EZ?f102=^?<20;6jh0030000002a^^00/K[P00<0b;W<1039
^L/00`3=_<X0d[k80=:nb0020=:nb0D0`lCK4P3oool00`000000oooo0?ooo`0L0?ooo`006`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo2@2W_n/50:Nkj0@0Y[SV1@2QY=P3
0:2Qe@D0WioD0P2PWm@30:G7l@@0Ylkd1P2Zc?8:0:S9l@@0X[[Z1@2N]NP409bcj0D0X/7_1P2Xf_T5
0:?Bn0@0Xlce0`0000020:G<m0D0XlOb1@2L]^/4096kl`H0W/_g1@2JaoL409o4l`80Z<C^0`2X`^`5
0:S5kPD0W/?b0`2@_OD507Ndn0<0EZ?f101`Z_D20;6jh0040000002a^^00/K[P0<Ric0D0bKW;1@3B
_/P0103G`/D0`lCK0<?4f`33a=/20<O9fa80oooo00<000000?ooo`3oool06`3oool000P0oooo0P00
00040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0<0?ooo`D0Yl3[102W_n/50:NnjPD0Yk_X102RZM`40:6Tf0@0X:7E102OWm@60:G7l@D0[=3c0`2Z
c?820:S7l0D0Z<Wa1@2U`>d40::jjP@0W[GX1@2O^^`30:;1k`80Z=Wi0`2Xf_T30:KKnPD0Xm;h0`00
000209SHo@@0YLcd1@2V^nT509bfj`@0Wkk^0`2NboL30:C>mPD0V/Og0`2Oa?<60:S2k080Z<G^0`2Z
anl409k3lP@0T;ge1@1j]OP304RJl`@0L:[e0P2a^^000`000000/K[P0<Vib`040<Vib`80b[W:0`3B
_/P30=O2a@030<?4f`37bM/0alWK0080alWK4@3oool00`000000oooo0?ooo`0K0?ooo`001`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00000C0?ooo`030000
003oool0oooo00X0oooo1`2W`>/50:Noj`@0YkkZ1@2S[^030::Yg0D0XJCH0`2PXMD50:>lj`<0YLOa
0`2]eOD50:c@l`D0Z<O`1@2XaNl50:G0k@@0WKKZ102L]^X509njk0D0Z=Wi1P2VfoX0102;gOh00000
00000000000208_MoP@0V=Sm102Q`>l50:Jkj@D0Y[OU102O_^h60:C>mP@0V/Og102K_>l50:S2k0H0
Z/O_102N`_4409Bml`D0N[Gh0`18V_<3052Hl@<0Y;CT00<000000:Bdi039^L/00P39^L/30<ZibP80
d[k8103G`/D40<O9f`80b/gL4@3oool00`000000oooo0?ooo`0J0?ooo`001`3oool010000000oooo
0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`070?oo
o`P0Yl3[1`2W_n/40:Bch`@0XjkP102RZM`40:6Tf0D0WjoS102S_>/60:gEm@D0Z<G^0`2Xao030:[9
l0@0Z<G_1@2O^>X409ffjP@0W;KZ1P2TdOL60:[Jn00509k>n000000000000000002Nc_P00P2`Zm80
103Q_[@0JEfa06UM/@1YGK4306o=oP@0XL3_1@2T[]l50:Jgi@D0[]7b1@2Ra_8409JmlP@0Vkc_1@2[
a>`30:[7k`<0Z/[`102N`_4409Bml`D0O;Si0`0hT?03052Hl@80Y;CT00@000000:Bdi02T]>@0bKW;
103:^LX00`3B_/P0el;50=O2a@030=O2a@030=c5`P37bM/0alWK00@0b/gL4@3oool00`000000oooo
0?ooo`0I0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000T0oooo
0P0000040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool:0:O0j`L0Yko[
0`2U^>H40:Bch`@0XjkP0`2RZM`509bTf`D0WjoS1P2^f_L40:S4k@D0Z<G^1P2ZbO040:>lj`D0WkSZ
0`2M]^X509k7m@<0Y=7g0`2]e?D30:[Jn0<000000`2Nc_P20;2[dP80hKjd101YGK4307Mjb@@0VZ7I
1@2T[]l20:Jgi@<0/]7`0P2^dO830:k@lPD0X/Kb0`2F_O8509bhk0D0ZlC/1@2Zb_0509jok`D0V/3b
0`1l^?T403R@l0030321j@1@V?40D9Sa0080Y;CT00<000000:Bdi03:^LX0103:^LX50=O2a@80g<G2
1P3:cM`A0?ooo`030000003oool0oooo01T0oooo00070?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool00`3oool2000001H0oooo00<000000:O0j`2W`>/01`2W`>/90:Noj`H0YKSV
102T/n<30:>^h0@0VYkG1@2LY=/209n_h`<0[M_h0`2^f_L30:[5k@@0Z<C]1@2Zb_030:[9l0<0Y/7]
102S_>/409nhjPD0Vl;c102NaoD60:gDm@800000102_b>d40;2[dP80hKjd101YGK4407Mjb@@0VZ7I
102T[]l50;;Al0H0[]3b1@2N_>h309Bck@D0W;S/1@2_bNd30:[:l080Y/O`1@2N_nl209[0lP<0X<Gc
0`1l^_X202>2j@80>93`0P0`PNT309N[i@030000002GZnD0b[W:0080b[W:0P3<^LL30=O2a@<0g<G2
00<0h/[00<[=g03:cM`00P3:cM`20<cAgA00oooo0P00000J0?ooo`00203oool2000000X0oooo0`00
00030?ooo`030000003oool0oooo0180oooo3`2W`>/40:Noj`D0YkcY102U^>H509bQf0<0VYgF102J
W]L409bTf`H0[M_h1P2ZaNd50:[9l0@0Z/[`1P2V`Nd30:>lj`D0WKo`1@2K`_<50:S=l`050;C=k@00
000000000000002dcNd00`2_b>d30;Bef@80/:_B103Q_[@406UM/@<0Mg[9102JXMT50:o9k0<0/]7`
0P2cf_@30:k@lP<0Z<K_1@2N_>h309Bck@D0Xk_Z1@2_bNd50:K7l0@0W[o_1@2PaO<407bjnP<08h;Y
0`0`PNT309N[i@030000002GZnD0b[W:00@0c;W700@0el;50=c5`P3LaL80g<G20`3Rb/020<[=g0<0
c=7M4P3oool00`000000oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`0B0?oooa40Yl3[
102W_^X50:Nlj@@0WZOL102LXMP409ZMeP@0VYkG1@2ZeoL50:g8kP<0Z/G]0`2YbO050:[9l0@0ZLG^
1@2V`Nd409nmk@D0WKo`1@2Qb?@20:S=l`<000001@2dcNd60;Bef@030;2[dP3Q_[@0hKjd0080hKjd
101YGK4307Mjb@80VZ7I0`2X_>P50:o9k0D0/m[d1P2Xa^l409jlkP@0U[7Y1@2S^nX50;;Al0@0Y/O`
1@2R`>h30:35l`80Y<kf101g^_/01007K]h08h;Y02>2j@0@J=`20321j@80Uj_U00<0000009N[i@3<
^LL0103<^LL40=c5`P<0h/[0103<dMd20<cCgQ40oooo00<000000?ooo`3oool05`3oool001T0oooo
0P00000A0?ooo`l0Yl3[1@2W_n/40:NnjPD0XJoR0`2NYm`509bQf0<0VYgF1@2Ub?830:[Gm`<0/Lo`
102]b>h60:W9l0D0ZlG]102YaNh50::lk0@0Wkg]1@2Oao@30:78m0<00000102_c>l50;37j`D0];GI
1@3Q_[@406UM/@<0Mg[91P2X_>P60;GRmP@0Zlgb1@2Xa^l509VdjP@0U[7Y0P2S^nX30:g:k`@0/]7`
1@2Q`O050:;0kPD0Y<kf101g^_/200M^gP<046SL0`2;XN<00`000000Rj7S0<bia`020<bia`80ckW4
0P3LaL840>;:`0030>O>_P3<dMd0c=7M00@0c=?N4@3oool00`000000oooo0?ooo`0F0?ooo`006@3o
ool00`000000oooo0?ooo`0=0?oooa40Yl3[1`2W_n/40:BfiP@0XJoR102NYm`409bQf0@0WKCX1@2U
b?860;7?l0P0ZLW`0P2Z`n`50:_5k@@0Y/7]1@2R_>`50:?7lP<0WlOd0`0000030:G6l@<0[lc_0P2^
d_<50;37j`80];GI0`2[_NL40>6n]0D0VZKO0`2HZN830:Rlj0<0/NGh0`2eh_H30:oEm0@0Zlgb1@2R
^n/409VdjP@0U[7Y1P2]b^l40:WFm`D0XL7`1@2Xco@509oIo0@0J[Sl00<0057;00M^gP00CL`00P0@
J=`308^Qh`030000003<^LL0c;W700@0ckW400@0g<G20>;:`03Rb/00h/[00P3Wc[h50<cCgP80bm?O
4@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`090?oooa<0Yl3[202W
_n/20:Jkj0@0Y;KV102Q[n8309jWg0D0Uj?M102M]>P60;CGlPD0ZLS_1@2YbO050:[3k0D0ZlS_102V
`Nd50:?1kP@0XlOb0`0000020:32l@D0YLKa1@2^d_<40;37j`H0ZkgW0P3Q_[@20<?Di`D0VZKO0`2H
ZN860;7Un0H0[mGd102T`Nh50::kj`<0VKCZ1@2L^^d30:g:k`<0ZN_i102Ye_L509_=n@<0Z<od0P2I
iO`509oIo0@0J[Sl00@0057;00M^gP00CL`046SL102;XN<00`000000ckW40<nia0030<nia0<0h/[0
0`3Wc[h0103[dk`0c=?N0<cCgP3<dmh30<_Cga40oooo00<000000?ooo`3oool05@3oool001T0oooo
0P0000070?oooaL0Yl3[1@2W_n/50:Jkj0@0Y;KV0`2Q[n8409FLf0D0Uj?M0P2M]>P30;?Km0<0]=Ob
0`2[b>h40:W8k`D0ZL;/0`2Z`n`20:c:k`D0ZlS_1@2Q_>`40:?1kP<000000P2Va>l40:32l@H0Ym;f
102NcoT40971m`D0ZkgW1@33e>L409ZVg`D0X=gl1P2`f_H50:K@mP@0Y<7^1@2DdOd309FklPD0W;[]
1@2YjoT608CGo`@0Vlgi1@2IiO`507WMn0@0>:Wc00<002^_001=c000CL`0102;XN<00`000000ckW4
0<nia0020<nia080eKc100@0h/[00>O>_P3Wc[h0iljn0`3[dk`40<_Cg`80bM;Q4@3oool00`000000
oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`030?oooa/0Yl3[1@2W_^X40:Jkj0D0VjGL
0`2GWMP409FLf0@0Uj?M1P2cfo@60:_8kP@0ZlG]1@2Y`^`50:c:k`D0Y;k/1@2Q_>`3000000030:[6
kP2Va>l0Y/C_00<0Y/C_102Sa_830:OBmP<0YLge102NcoT40971m`D0T<cl1033e>L609KBo@@0ZMKg
0`2`f_H30:CTo0@0Y]3f1@23gOd509CAo@<0UK_b0P29i_P505[Ch@@0GmGV1@1P`od606_An`<0MmGn
102Xe?L303jgl@0507400000:jl002^_000f_000CL`01024V=h00`000000ckW40<nia0030=Fl`@@0
iljn0`3[dk`00`3]e[`0bm?O0<_Cg`040<WBhA40oooo00<000000?ooo`3oool04`3oool001P0oooo
00<000000?ooo`3oool00`3ooolI0:O0j`D0Yko[102W_^X409n^hP@0VjGL102GWMP409FLf0D0[M;d
1@2`c>h30:_8kP<0[<W^102[aNd50:[7k`<0[<[_0P2[`^/50:Bnk0050:6lk000000000000000002V
aNl0102Za^h50:K1k@@0XlKb1P2UcOD509JllP<0N;Ki1@2@c?`409G;nP<0U];m0`2Sd?L40:WFm`H0
Y>Cl1@1Yeo@408?Mo@D0I<7n1P22e?l409bkkPD0NK?h1@2@bO/509c5m0@0Z=Cg0`2ncND306Z^n005
07400000:jl002^_000f_000CL`01024V=h00`000000eKc10=Fl`@020=Fl`@030=g0_03Wc[h0iljn
00<0jm>l0`3]e[`40<WBh@80am7R3`3oool2000001D0oooo000H0?ooo`040000003oool000000?oo
oa`0Yl3[1@2W_n/40:>gi`@0WjkR102KYM`309NMf0D0XKc/0`2]d_@30;GDl0@0/<c^1P2/bNh50:S3
k@@0Z/O_1@2[`^/30:Bnk08000001@2VaNl20:[6kP80ZL7[1@2V`Nd50:k8k@D0Zl3Y1@2F_?8307Rf
n@D0S[kf102EboX60:?@m`D0S>[b0P1WeOD509ZUg@<0TJkZ1@1o^_T509Fgk`D0]<WZ102L^nh60:6c
i@@0/;gT0`2LaO@30;[5h`D0_/gU101Z[_P0101a000002^_000[[`00=[`408BHgP040000003E_<40
eKc10=Fl`@<0gL2l00@0iljn0>_C_03[dk`0jm>l0`3]e[`00`3]f;d0bM;Q0<WBh@030<OAhQ40oooo
00<000000?ooo`3oool01P3oool2000000X0oooo000H0?ooo`030000002W`>/0Yl3[01h0Yl3[1@2V
_>T40:>gi`<0WjkR102KYM`409JVh@D0XKc/1P2ee?040:c:k`<0[<W^0`2X`n`50:S3k@@0[LC[102[
`^/300000080Xl?`1@2VaNl50:W1j`D0[L7X0`2^b>d20;G2i0D0Zl3Y1@2O]>L3092dk`D0S[kf1@2P
cOL206?Ie0D0S=;o1@2QX]H509ZUg@<0TJkZ1@2OZml309Fgk`80^LcX1@2dbNX40:BUe`<0XK?U0`2j
`^040;2mi0@0^/GS0P38bm`30;k=i@80_l;L101iU>40101a000002^_000V/@00=[`408BBfP030000
003E_<40eKc100<0gL2l0`3[dk`30>gF_080kMRm1037dN820<G@ha40oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000090?ooo`004@3oool2000000D0oooo00<000000?ooo`2W`>/0
7@2W`>/20:Noj`D0Y[cY0`2S]nL409>MfP@0TI_J102FY^420:6lk0@0]mSa1@2]bnl40:c:k`H0Z<?/
1@2[aNd40:g4j`<000000P2WaNl40:?3l0D0Y/;]0`2Y`N/20:_3k0D0[L7X1@2e`^@20:_0j@<0[[[R
1@2O]>L3092dk`H0V/Kf0P10`KL509W8m`@0YJ?C1@2QX]H409ZUg@@0YZWI1@2OZml50;W<j0D0ZZSD
102TYML50;[2h080/;gT0`2k_]`20;[5h`@0b<_L1@2o`]`307VDh@04000FY@1a000002Ja000V/@@0
Q9;J00<0eKc10000003M`;`00`3M`;`00`3Ua[P0jm>l0>_C_0020>gF_0<0kMRm00<0kMVo0<OAhP37
dN801035d><@0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000002@3oool00100
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0:O0j`D0Yko[102V_>T409VV
g`@0TigJ102AVmX309JVh@D0]mSa0`2bc^h40:g;k`D0ZlC/0`2X`n`20:[6kPD0ZlG]0`0000000`2[
a^d0YlG_0:O5k`030:O5k`@0Y;o]1@2V`^d50:_3k080[L7X0`2c`nH40;G2i0H0[[[R0P2O]>L30:K6
l0@0W<?c0P0c^:h50:6nkP80VLSg0`2WXm840:FSd`@0XJ;F1@2XZML40:JYf@80Wj_O0`2ca>L20;W<
j0<0];KJ102ZZ=@20:BUe`<0^L;Q102j`^060;^ng0@0b<_L0P3<d=`40;o2g0@0NICQ00@001JU000V
/@009[4002Ja1024T]X0103E_<4000000=g0_03M`;`30>G6^0<0kMJl0P3]f;d30>gI_`D0aM3S4@3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000003o
ool0oooo000000@0oooo0P0000020?oooaL0Yl3[2@2W_n/409nbi@<0VJKO1@2CWMX3096KfPH0[loa
1P2bc^h40:g7k@D0ZlC/1@2Za^h01@2[aNd00000000000000000Z/?/00@0ZlK]1@2X_n/40:Bok@D0
XlGa102[`n`60;?3iP@0]/;S1@2^^^850:K6l080?L2j1@2W^NH40:6nkPD0Yj?B102UXm<50:RWeP@0
Z:WG102VZMT50;?4i`D0];KJ102ZZ=@60;W2h@80^/;P0P2i_Md30;^ng0<0a<WO0P38bm`30<c@g080
_l;L0`2^Z]@307^4d@8001JU0P009[4408BBfP040=g0_0000000gL2l0=g0_0<0iLJh00<0kLfd0>gF
_03]f;d00P3]f;d30>gI_`030>_K`P35d><0aM3S00<0`m3T4@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3ooolG0:O0j`@0Yko[1@2T^^T409nbi@<0VJKO102CWMX409ngj@<0[loa0`2he>l3
0;;>kP<0[l_^102]and50:W5kP80Z/K^0`0000050:[3k0@0[<;Z1@2X_n/40:G6l@D0XlGa102W`^d3
0;?3iP<0//W[102f`^<50:o<k`<0Y/K`102[]n850:NiiP@0ZJCB1@2WXm820:FSd`80Z:KD1@2XYmH3
0:RYe`D0[[cT0`2ca>L20;W6i0D0];KJ0P2ZZ=@20:jhh0D0^L;Q1@2i_Md50<C9g`D0c=3L1@2^Z]@4
07^4d@04000FY@2O=@0002Ja000V/@@0S9?F00<0gL2l0000003Ua[P00P3Ua[P20>g=]0<0kMRm0`3]
fKl20>_K`PD0`m3T4@3oool2000000@0oooo0P00000:0?ooo`00403oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00D0oooo5P2W`>/50:JnjP@0Y;[Y0`2O/^D309VVg`D0TJ7O102O
]nT60;SDk`H0[l_^102Ya>d30:W5kP<000000`2Y`^`30:[3k0<0[<G/102/`^X50:W4k@@0YLKa1@2N
_^l40:O2k@H0//W[0P2f`^<20;3Al@D0[lc_00<0K=kJ0:fihP2]^N80102[]n850:ZVdP@0ZJCB102W
Xm840:RVe0D0Z:OF102]_>@50:jli0D0^LKT102d]]X50:jhh0D0^<;R0P2i_Md30;_7h`<0a<WO0P36
dN<30<c@g080`/GL1@2^Z]@307^4d@04000/]0005ZD001j[000V/@D0S9?F00@0gL2l0000003Ua[P0
iLJh0P3]cK@20?;C/0<0kMVo0`3[fl80103Zg<H0`m3T0<?@i033d>@20<3?iPl0oooo0`00000@0?oo
o`004@3oool2000000@0oooo0P0000070?oooa80Yl3[102W_n/50:JnjP@0VZgT0`2BXMh308fJf`D0
TJ7O1P2he>l40;;>kP<0[l_^0`2/aNd30:W4k@<000000`2Z`n`40:W2k0H0[<G/1@2[`n`40:W4k@D0
YKg[102N_^l50:?9l`@0//W[1@2`dO4306cNfPD0[KWR0P2[]n820:^Ye@D0ZZKB0`2YY=850:VXe@@0
Z:KD0P2XYmH30:k0i`@0[KcT1@2ecN`40;W6i0D0YjgL0P2^^>030;O:j0@0^<;R1P2kan<50<KAh`D0
`/GL102^Z]@307^4d@8002bd00<001JU000NZ`009[40102<TmH20>G6^0040000003]cK@0kLfd0>g=
]080l]>`00<0mMN^0>gI_`3[fl800P3[fl830>[LaPD0`<oV403oool00`000000oooo0?ooo`0>0?oo
o`005`3oool00`000000oooo0?ooo`070?oooa80Yl3[102W_n/50::hj0<0VZgT102BXMh308fJf`<0
TJ7O0P2Z`n`30;SDk`<0^=;]102bc^h50:c5k@<000000`2[aNd40:[3k0D0Z/G]0`2/aN`20:S2k0D0
Zl?/102/_^L50:Fmj`@0W/Cb1@2SbO<50:O=l`80M^?Q1@2^_N@40:fihP@0ZjWE1@2ZY]840:Z[f0D0
ZJSE0`2XY]@60:k0i`80[KcT0P2^bnl50;G=k0@0Yj_J102W[M`60;O:j080^<;R0P2c`^D30;_7h`<0
_<kW0P36dN<30<GDi@@0`/GL1@2LUld308:8d@0400]6a@00;;@001^Y000NZ`D0W9cD00@0iLJh0000
003]cK@0kLfd0`3bdk000`3eejh0jm_20>_K`P020>_K`P80j]c60P3Wg//20<3?iP<0_LoW403oool0
0`000000oooo0?ooo`0=0?ooo`005`3oool00`000000oooo0?ooo`080?oooa80Yl3[102U_NX50::h
j0<0VZgT0`2BXMh408fJf`D0Z/?/1P2hd^d50:o9k@<000000P2[a^d50:_5k@@0ZLC]1@2ZaNd50:S2
k080Zl?/0`2/`NT40:bni`D0ZLC]102Na?8609o1l0@0ONG[0P2`a>T40:jmi0D0ZjcH102[ZMD20:ZV
dP<0Zk3K102ZZmP40:VXe@@0[LC[1@2^`>L50:k;k`D0Zk7L102WZmX20:N]g080//c]1@2gb^P50;?2
i@D0_<kW1@35e>D50:VWe0@0W9O=0`22R=4200]6a@03000/]0006jT001j[00@0W9cD00@0iLJh0>g=
]0000000kLfd0P3bdk020?GG[P030?OK[`3[fl80jm_20080j]c60`3Wg//50;g?ia40oooo00<00000
0?ooo`3oool0303oool001L0oooo0P0000090?ooo`l0Yl3[102W_n/40:FmjP@0X[SX0`2J[N@408VJ
g@@0UJSS0`2Z`n`30;_Dk0<0^=;]0P2dc^d20:o9k@80000000<0[lW]0:_6k@2[a^d00`2[a^d50:S3
k@@0ZLC]1@2Y`^/40:S2k0H0[<7Y102^aN/50:W4k@@0Y;WX0`2O`O0408cYm@D0/<CY102Y[m`50:^/
f0<0ZjWE1@2[/=/40:Z[f0D0ZlK^102]a>/50:W5k@80[/__0`2]^>440:^ag0@0Yj_J1@2bc>d50:jn
iP<0/l;U0P2fbnX30;c>i`80_]G[0`35e>D20;Joh@@0ZJOD102LUld408:8d@802dK50P006jT01000
7Z/0W9cD09bLe02LW=@30>g=]0030000003bdk00l]>`0080mMN^0P3gfjl20>[LaP@0imk;00@0i>7@
0;g?i`2mcnL0_LoW0P2jc^T@0?ooo`030000003oool0oooo00`0oooo000G0?ooo`030000003oool0
oooo00X0oooo3P2W`>/40:Noj`@0YKgZ102FZnD308bMg`@0RI[M102EZ><60;_Dk0<0]<k]0`000004
0:c6k@<0ZlK]0P2Za>`50:S3k@@0ZL;/1@2Y`^/40:[4k0<0[<7Y0`2Y`nd40:k5j`D0[;[T102T^NP2
08cYm@D0/]7`0`2`a>T20:J`g`@0ZJoL102[[=P40:Zcg`D0Zk3K0P2ZZmP20:S6k`D0ZlK^102X`N/4
0:W5k@H0[KSQ0`2[/M`60:_5k@@0[l3W1@2^_^H50;K;jPD0_]G[1@2f_n440:VWe0<0W9O=1022R=43
00]6a@8001^Y102a[M@20>g=]0040?;C/0000000l]>`0?GG[P<0mm^_00<0mmna0>ONb`3Wg//00P3W
g//30>CQd0D0^/kY403oool00`000000oooo0?ooo`0;0?ooo`005P3oool00`000000oooo0?ooo`0<
0?ooo`h0Yl3[0P2W_n/20:Fmj`@0WkOY102FZnD308bMg`@0RI[M1@2`an/40;[Bk0<00000102`bNd4
0:c6k@D0Z/C/1@2Za>d40:W2k0D0ZLG]102Za>`60:W3k@@0[KoV1@2/^^@409c/n@80/N;g1@2bdO05
0:J`g`<0ZJoL1@2W]N<40:Zcg`@0Zk3K1@2Xa^l50:RnjP@0Z<7[102]_ND50:fhh@@0Y[cX0`2[aNd3
0;36jP@0[l3W1@2abN/20;K;jP<0]m3]0P2neN/30;cAjP@0][oQ102YYm@409fLdP@0SY[K00<08EkC
00]6a@0;A/D00P006jT40;6]e080l]>`00<000000?GG[P3eejh00`3gfjl0103ggk40m^>e0>ONb`3W
g//30>CQd080gn;F0P2jc^T30;O<ja00oooo00<000000?ooo`3oool02P3oool001H0oooo0P00000>
0?ooo`d0Yl3[1@2U_N/409ngj@<0UZ_U0`2<WMl509V/i0<0/<O[0P2md^X3000000030;[Bk02fc^`0
]/k/00D0/<W]102/a^d30:[4k0<0ZLC]102Za>d50:W4k@@0ZLG]102V`>`30:W3k@<0ZL;[102]_nH2
0:bji0@0XNWj1@2ah_L50:Bah@@0Y[3O102U]N@50:Neh`<0Z[?O1P2VaNl40:Nmj@@0Z;kZ1@2/_nP4
0:fmi@D0Y[KT102V_>P50;36jP80[l3W0`2]aN/40;79j`D0]m3]1P2ldNX409fMd`@0VIO?102MW=84
08jJf`808EkC00<001RV000KZ@2a[M@00P2a[M@20<S3eP80l]>`00@000000?OK[`3gfjl0mm^_0P3g
gk420?KS]@<0i>7@0`3Oh]H50;O<j`l0oooo0P00000<0?ooo`005P3oool00`000000oooo0?ooo`0>
0?ooo`T0Yl3[1@2W_n/40:Fmj`@0TZ_V0`26W>4308NIgPD0VJcT00@0_M;Z00000000000000000P2m
d^X50;K>k0D0[LO]102/a^d60:W4k@@0Z<;]1@2Ya>d40:S0j`@0Y/3/1P2Y`^/30:foiP80XNWj1P2X
kOT40:>ahPD0Y;7Q102S/n@40:Fei0@0YkGS102T`^l30:K5k`<0Yk_X102W_NT40:Znj0D0[;oX102W
]N850:Jfi0@0[l[^102`a^X60:g5j`D0//_]1@2jenh50:Zag@<0WIgC1@2IUll309fLdP@0SY[K0`0Q
G]<00`006:H0/JgD0;6]e0040<S3eP80mMN^00@000000?OK[`3gfjl0mmna0`3fhkD00`3dikX0gn;F
0=oReP020=oReP<0fN7M102cb^`@0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000003o
ool0oooo0100oooo202W`>/50:Noj`@0W[OZ0`2BZnH408JLh@<0QiWN0P2I[>@3000000H0_M;Z0`2f
c^`20;;;k0D0[LO]1`2Ya>d30:W3k@@0Z<;]1@2Y`^/40:S0j`@0ZLC]1@2Y`^/409oOo@<0WO3d1@2U
/n<40:>ahPD0Xk7S102S/n@30:Fei0D0Y;o]102T`^l50:Nkj080YkgY0`2Y_NP40:Znj0D0ZKKS102W
]N820:Jfi0<0[<_`102_b^h40:[0jP<0[LG[0`2`bNd20;;;k@<0]MG`0`2jenh20;C7j0@0Z[7M102M
WM<409VGc`@0YjoN102CYn<00`0aK=/08EkC000DW`050<S3eP80fMWG00<0mm^_0000003gfjl00P3g
gk420?KS]@80m>Nj00<0lN[10=oReP3Oh]H00`3IhMd20=7Oh`@0/l[/403oool00`000000oooo0?oo
o`080?ooo`005P3oool200000180oooo202W`>/50:Fmj`@0W[OZ0`2BZnH308JLh@80QiWN0`000004
0;;5j0H0_M;Z1@2bbn`50:c6k@@0ZLC]1P2Y`nd40:W4k@D0ZL;[102YaNd40:W4k@H0XM3h0P2Ml?@4
0:ZliPD0YK?S102S[n440:>ah`@0Xk?T102T_>X50:Bok@@0Yk[W102W^nP60:Vmj080Z[kX0P2Z^N@5
0:Vfh`<0YkGR1@2/bo050:Znj0@0Z/3Z1@2`bNd60;GEl0D0]<OX0`2Z/Md409fMd`D0X:GJ102W[mh3
09>Wh`<0<FcK00@001FH0<S3eP38`mH0b<?F0`3IfML0103Pi]P0mm^_0000003ggk420?KS]@80m>Nj
0`3aj/430=WQg@<0dMoS1@2_b>`?0?ooo`030000003oool0oooo00P0oooo000F0?ooo`030000003o
ool0oooo0180oooo102W`>/50:Noj`@0YKg[0`2N]nX309:[iP80PYSO0`00000309R[h`<0//GX102o
d>L50;[@j`D0[lW]102/a^d50:W4k@<0ZL?]0P2Xa>d40:W4k@D0Z<?]102YaNd60:K5l080Vo3b102b
c>d40:ZliPD0XjkP102S[n430:>ah`D0YKWX102T_>X50:NiiP@0Yk[W2@2Y_NP50:Zii0@0ZKKS1@2Y
bO090:Znj0D0[/W^102ad?030;GEl0<0]]?_102danP30:Zag@D0UiWC102PYMX40:N_gP<0TjOS100a
K=/00`005IP0fMWG0=WIe`020=WIe`<0h>KH00@0mmna0000003fhkD0m^>e0P3dikX30?7Z`@030>k/
b03Agn<0dMoS0080dMoS0P38fnP40:o8k0l0oooo0P0000090?ooo`000`3oool2000000@0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`0D0?ooo`D0Yl3[102W_n/409nij`<0TJgY00@0
PYcS00000000000000000`22V=l409R[h`@0_m3W0`31d^L30;[@j`80]/g[1@2_bNd40:[5k@D0ZLC]
1@2Xa>d40:O2k@D0Z<?]102Y`^`30:K5l080Wnof0`2fhOD40;;<k@@0XZkP1@2S[^030:>_h@@0YKOV
1@2U^NP40:Rii@D0YkWV202Y_NP50:ZkiP@0Z[WT1@2Wa^l20:W9l0<0Zl3Y102Z_^P50:c8kP80[/W^
0`2]bnl40;7@l0D0]]?_1@2OWm@309JEd0D0UiWC0`2PYMX50:Rgi0<0T:SV00D0>g?M035/f`0aK=/0
01VU000EV0020=WIe`<0h>KH0P3QkMT0103fhkD000000?CW^P3dikX30?7Z`@80k^c800<0j>k@0=7O
h`3Agn<00`38fnP50:g5k0/0oooo0`0000000`3oool000000?ooo`080?ooo`000P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool5
0:O0j`@0YKk[102O^N/00`2A[NT000000000000308:Lh`@0PYSO1@2a`>D60<7Bi`D0]/g[1@2]and4
0:[5k@H0Z<C]102X`nd40:O2k@D0ZL?/102Y`^`209o_mPH0]^7e102Q[n440::^h0@0XjkP102U]^D4
0:FgiPD0Z;WV102X^ND90:Vmj0@0ZKgW1@2Z^nH40:O3kP@0YlK_1P2[`>T40:[6kP@0[<S^1@2]bnl6
0;CFlP@0Z[;N102OWm@409JEd0@0UiWC102Y^><40:Rgi0@0T:SV0P0kLmd00`006JD002>Q000EV003
0>3Vf0<0hNgI00@0h>oJ0000003dikX0m>Nj0P3aj/420>k/b080j>k@1038fnP20;kEj`D0[LG/1P3o
ool4000000@0oooo00<000000?ooo`3oool01`3oool00080oooo00@000000?ooo`3oool000002`3o
ool010000000oooo0?ooo`3oool2000001L0oooo1@2W_n/40:Fnj`0409nij`000000000000000080
TJgY0`22W><509:UhP<0/L3U0P2obn@30<7Bi`<0_m7W0`2fcN/30;;;k0@0[LO]102YaNd30:S4k@<0
Z<C^102X`nd40:S4kPD0ZL?/102SiO`30;;`mPD0Xk?T102Q[n430::^h0D0Y;CT102U]^D40:RjiPD0
Z;WV102X_^T40:Vmj0D0ZKkX102Y_NL50:O2k@@0Yl?^102[`^/30:_0j@<0ZLC]102Za^h40:c7kP<0
[L__0P2aeO<30;CFlP<0/LGY102Z/]h309nOe0@0UYG@1@2S/N840:Vhh`@0Y;KV102:YNL01P13N=l0
>g?M000h_@006JD001FH0>3Vf0<0hNgI00@0h>oJ0=o`f`3Ol=/000000P3aj/420>k/b080j>k@0`3Q
kMT50;kEj`D0Z/?/0P3oool3000000P0oooo00<000000?ooo`3oool01`3oool00080oooo00@00000
0?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0603oool40:Noj`040:6lk000
00000000000000<0Tk7/0`1oWnL307^Eh@D0TZGR1@2obn@60;oAi`H0//_/102[anh40:W5k@H0Z<C^
102Wa>h40:S4kPH0YMGi0P2bl?H40:W0jPD0Xk?T0`2Q[n440::bh`D0Y;CT102W^nP40:RjiPD0YkkZ
202X_^T50:Vnj0@0Yl7/102W`^d50:[3k0@0Zl;[1@2Ya>d50:_6k@@0[<O^1@2aeO<50;75j@@0Z[;N
0`2OWm@509^Tf`@0Xk7R0P2Y^><30:VjiP@0Y;KV102:YNL204=hg`03000h_@006JD0hNgI0080hNgI
00H0h>oJ0=o`f`3Ol=/0go3K0>3_fP0000020>k/b080j>k@0`3QkMT20=S[h@80_]G[0`2fcn`40:[3
k0800000303oool00`000000oooo0?ooo`060?ooo`000P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool0102V_n/00000000000000004
0:6lk0<0Tk7/0`1oWnL307^Eh@<0TZGR0P2Y]n<30;o;i0<0aLoR0`2odNL30;c?j0D0/<W]102[anh5
0:S5kPD0Yl?^102Wa>h60:K9lP@0Z_?d0P2ce_840:W0jP@0Xk?T102P/><40::bh`D0Y[_X102W^nP4
0:JnjPT0YkkZ102X_^T90:O1k0@0ZLC]1@2Z`n`50:S2k0@0ZlK^1@2[a^d50:kBl`D0/]7`0`2aaNT5
09NDc`<0UYSC1@2KY=/30:>ahPD0ZK[V102T]^H408ZUi`<0@gSO00@02EG@001Tf000I=P0h>oJ0`3O
l=/20>3_fP040>7_f@000000h^oH0>;_f0<0hNgI0`3Hjn450;K?k0D0ZL;/3@3oool00`000000oooo
0?ooo`060?ooo`000`3oool2000000X0oooo0`0000030?ooo`800000603oool3000000@0Y[o[0`2Q
_>`4086Uj`80LICT101kUN450:Vgh`H0aLoR102lcnP30;[>j@@0/<W]102Za^h30:S5kP<0YlC^102W
`nh40:O5k`<0Y/Wb102Wk?T50;?FlP@0W:kS102N[n<40:2`h`@0Y;[Y1@2V^nP40:Jnj`@0Y[kZ1@2W
_^/40:NnjPT0Yl7/102Xa>h40:W4k@D0Z<7/0P2X`^`30:[6kP@0ZlK^1@2/co850;3Dl`80/]7`0`2V
ZMP309jKd@@0UiC?102FV=<409^Tf`@0Z;_W102Y^^H509ndi`@0Pj;W00@0BGcQ04=hg`13N=l02EG@
0`0cR^d30>3_fP80hNoI00@000000>;_f03RkmP0ho3H103Hjn420<gUj0<0]/o/0P2_bNd40:W2k0d0
oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool05@3oool3000000@0oooo
102T_N/409Rgk@<0PJG[0P1aU>@408FLhP<0ZKOS0P2k`^030<G?hP@0a]3R1P2jc^T40:k9kP@0Z/K^
1P2Wa>h80:O5k`80Ynci1P2hk?H409jbiP@0W:kS102N[n<40::hj0@0Y;[Y1@2U_N/40:Jnj`80Y[kZ
0P2V_^/40:Nnj`T0Yl7/1@2W`nh40:S4kP@0Z<7[102X`N`60:[6kP@0Z/ca0`2/co820:kDm0@0/=Cc
1@2VZMP309jKd@D0UiC?0`2FV=<50:Nji`@0Z;_W102W^^L509ndi`<0Pj;W0`19O>4200UEd0@0<h[]
0P3QkmT20>;_f0030000003Sl=P0ho3H0080hO;I1@3=iNP50:o9k@@0Z<7[303oool00`000000oooo
0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0B0?ooo`<00000203oool40:Bmj`@0V;O]0`21
YN/2076Di0@0QIcR1@2k`^070<K@hP<0^/kY0`2gcN/40:k9kPD0Z<K_1@2VaNl40:O5k`@0Ymcj102c
lo@40:K0k0@0W[;V0`2L[^<509nei`@0X[SX102T_>X40:Fmj`T0Y[k[0P2W_^/20:K1k@D0Yl7/202W
`nh90:S1j`D0ZLO_1@2YbO040:[<l@D0[]Cd102/^N<50:JYf0<0WY_A102GU<l40:Bei@@0Yk[W1@2X
_>P40:Nji`@0WkCW0`23X^L404Ulh@0302m`gP09EM00Ij[g00<0Ij[g0`3RkmP0103Sl=P000000>7b
f@3Ql]T20=cbgP80cNGX0`31fnd50:_4k0@0Z<7[2`3oool00`000000oooo0?ooo`060?ooo`00503o
ool200000100oooo0`00000<0?ooo`@0X;[[102:[nh306fHj@80L9;S102IZN830;_2h0@0aLSL1@36
d>860;O=j`@0ZlW_0`2Xa^l20:O6l0D0Y/G_1@2Vc_D20;?cm0D0/m[d102V`>`309jbiP@0W;7V1@2O
]NL40:>lj`@0Y;cZ0`2U_N/90:Jnj`D0Y/7]1@2V`^d40:O3kP@0Z<7/1@2X`N/40:S6k`<0ZLO_0P2X
ao040:W9l0D0[=?d1@2^a^`40:bih`@0YZWH0`2NVm4509fZg`@0Y;GU102W_>P40:Rlj0D0Y;SW102J
/NP307fNi`<0DX;R0`0_L=h508o1n080ho3H00<0hO;I0000003Ll]h00P3Ll]h40<7Kk@80]]7^102[
a>`50:O0j`X0oooo00<000000?ooo`3oool01P3oool001@0oooo00<000000?ooo`3oool0303oool3
00000140oooo0`2P^^/408Z_kP<0KISY0P1`T^<409VYhPD0aLSL0P3;b]T30<K@hP<0aM3R1@2dcNd4
0:_9k`D0YlK`1@2Vb?430:K>m@80[^_h0P2ik_D50;?Jm0@0V:kV0`2I[^D409baiPD0X[_[102S_>/3
0:BljP@0YKk/1@2V_^/90:K1k@D0Y/;]102W`N`40:S1k0T0Z<K_1@2Xao050:[Bm@@0[Lob1@2^a^`4
09^Ec@@0V9G?0`2HWML409fZg`D0Yk_X102W_>P40:Jjj0D0Y;SW0`2J/NP407fNi`<0DX;R0`1DR^P5
0:gBl`80hO;I00<000000=cbgP3Ll]h00`3DknD40;KAkPD0ZL;/102W`>/:0?ooo`030000003oool0
oooo00H0oooo000D0?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`<0X;[[0`2:[nh306fH
j@<0L9;S0P2IZN820:fegP<0aLSL103;b]T40<G@hP<0a<oS102dcNd50:W9l0D0YLOa102Vb?420:k[
n0D0^Nke1@2K]^X409R^iP<0VJkU102O^>X50::kj`<0Xkc[102T_^`40:Fnk0H0YL7]202V`Nd90:O1
k0@0YlK_2@2Xa^l50:WAm@<0Z];e0P2[doD40:g?lPD0WiW>0`2KULd409REc`@0V9gG102X_NP40:Nk
j0D0YkcX102V^^P40:Bhi`@0U:gX0`1iVnL405:2hP<0E8[X0P2]d_<30<;OkP80g?;N00<000000=C_
i@3DknD00`39in`20;KAkP80[/S]1@2Y`^`40:O0j`X0oooo00<000000?ooo`3oool01@3oool001@0
oooo00<000000?ooo`3oool01`3oool3000001P0oooo0`2K]n`307NTk`<0FhgW0P1kV><50:fegPD0
bl[I0P3>b]H20<G@hPD0a<oS1@2acNh40:K9lPD0YLOa102YfoT30;Cam@@0Z<cc1@2K]^X309R^iP@0
VkCY102O^>X50::mk0<0Xkk/102T_^`:0:G1k@@0Y/7]102V`^d40:O1k0D0YlG_102Wa^l50:S5k`@0
Z=3e1@2YdOD50:_Cm@@0Y:7B102OVLh409^Ec@<0V9G?1@2W_NT40:Rmj0@0YkgY102W_>P50:Fjj0@0
XKKX102D[NP307VKi`<0GHWT0`1DR^P40<;OkP80cnWX0P3ElND00`000000bNO/0<WWk0020<WWk0D0
[/S]1@2X`N/30:O0j`X0oooo00<000000?ooo`3oool01@3oool001<0oooo0`0000050?ooo`<00000
703oool309^gk0<0MjC_0`1KSNL207^Hh`<0[KGN0`2l^mT20<_:f@@0c/[F1034cn<30<C@h`<0/Lg^
0P2^c_440:K9lPH0YLof0P2dlOD50;CXm`<0Z<cc1@2C[NP309N`j0@0VkCY102Q_>`40::mk0@0Xkk/
1@2T`>d40:G0k@@0YL7]1@2V`^h40:K2k@@0Y/G_2@2WaNl30:S5k`80Yloe102Xd?D50:WDmPD0YjWH
0`2TXM8409nIcP@0ViG=102T^>P40:Nmj@D0Y[cY102W_NT40:Jkj0D0YK[X0`2Q]^P409B]j0<0NI_W
101MRN@407NSkP<0cnWX0P3ElND20=Cci@030000002lf^l0_=[_0080_=[_1@2Z`n`40:S1j`@0Yl3[
2@3oool00`000000oooo0?ooo`050?ooo`004`3oool00`000000oooo0?ooo`020?ooo`<000007`3o
ool409Bck@80GiO^0`1KSNL307^Hh`H0_;_I103>b]H30=39d`H0a=3S1@2^c_450:;<mPD0ZnOj0`2a
lo@409_7mP<0T[;/102C[NP409N`j0@0W[[/102Q_>`40:>ok@D0Y;o]102T`>d40:G0k@@0YL?^1@2V
`^h40:K4k`@0Y/G_2@2WaNl50:O?m@D0YmCg102Y/Md40:NYf0@0Y:7B0`2OVLh509n^hP@0Y;SX102V
^nP40:Jlj@T0Y[_X102U^^P409fdj0@0SZWW0`1gV>H306jDi`D0U[_a0`3ElND20=Cci@030<c^j`00
0000_=[_0080_=[_0P2acNh40:[3k0T0Yl3[203oool00`000000oooo0?ooo`050?ooo`004`3oool0
0`000000oooo00000002000002<0oooo102D/nd205nGkP<0D8GU0`2<XN840;bkf@80aKkC0P3>b]H3
0=39d`<0d/O@0`34d><30<?@h`D0ZLod1P2Qf_/20;7cm0@0Y>Ok102KaoH309:bk0<0TjgX1@2J]n`4
09jjk0@0XKk]102S_nd50:C1kP@0Y<3]102U`nl40:G3kPD0YLC_102Va>l40:K5k`@0YlG_1@2Vc_D6
0:KCm`@0Z[OS102Y/Md30:NYf0@0Y:7B102LXmX409n^hPD0Yk_X102V^nP40:Nmj@D0Y[_X102U^^P4
0:>hj0@0WKCX0`2>ZNL407NHiP<0KYCW0`2F^o430;;Bl@80e??U0`3<k^/00`000000/Lg^0;7=kP03
0;7=kP@0Z<7[2@2W`>/70?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000009P3oool408b`
kP80@hSZ0`1@QND308bQhP80_;_I1035_]<30=39d`D0d/O@1033d><20<C?h`<0ZLod0`2Ve?P50:?^
n0<0W_;a0`2Tio/408:al`<0Rjk]0`2C/^`509Zgk0@0Wkg^102Q_^d40:?1kPD0Y<7^102T`nl40:G3
k`P0YLC_1@2Va_040:K5k`D0YLke1@2UdoP50:VkiP@0Z[OS0`2Y/Md409fHcP@0W9cC102LXmX40:Vo
j@@0Yk_X1@2X_nX40:Nmj@D0Y[cY102U^^P30:>hj0D0VK3X0`29Y>H307VIi@@0KYCW0`2bd_430<KV
kP<0c>k[0P2ohO000`000000ZlG]0:_5k@030:_5k@@0Z<7[202W`>/70?ooo`030000003oool0oooo
00D0oooo000D0?ooo`030000003oool0oooo02H0oooo102</>h204>8jP80BX;U0`2<XN850<Fnd`<0
c;g=1@3Bam030=?5c0D0a<oS102Ve?P40:[RnP80W_;a1@2;h_`307g5oP<0P[7c0`2;[^d309>bk0D0
W;c_102O_Nh40:71k`@0Xl7^1@2S`o080:C3k`@0YLC_102Uao450:K6l0D0Y<kf1@2TdoP40:Rmj0@0
ZK_V102Z]n<409jFb`<0WIS>1@2LW=<209bSfP80ZL;/102Y_nT40:Noj`D0Z;oZ202V_>T40:Fjj0@0
X;OX102I/>P408VTiP<0NIWU1023YNX40<KVkP80c_;Z102ohO000`000000/m3_0:_5k@030:_5k@d0
Yl3[1`3oool00`000000oooo0?ooo`040?ooo`002`3oool5000000D0oooo0P00000W0?ooo`<0S;3^
0`13R>X204Z2i@<0WJWO0`35_]<30<bmc@80d;c70`3Bam030=?5c080eL760`34cn<30<K=h0@0Z^;j
0P2iko@30<WXk080alWL0`1i^o/305VVm`80LZgf1029]?<309Fjl0D0W;c_102O`O440:71k`@0X/?`
102S`o050:?4l0@0Y<?_102Tb?840:G7l@D0Xlkf1@2Rd_T50:Nlj0@0Z;gX0`2Y^nH50:2FbP<0WYK;
102MV<h409bLd`D0ZL;/102V_>T40:Noj`D0Y[_X1`2V_>T50:>ij0@0X;OX0`2I/>P408VTiP@0NIWU
1@2L^nh30<kbjP<0b_;/0`2cd>l00`000000/m3_0:S1k0030:S1k0d0Yl3[1P3oool00`000000oooo
0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo0`23
[O02025eh`<0BX;U0`2MZMl40<bmc@@0d;c7103CaL`40=G1aP@0a/gP0`3;bmT20;W_m0@0bNS/1037
bM`307Vkn`<0FJKg0P1b[OH408Vdl`<0UK[`1@2K`O8409o1l@@0X<?a102R`o040:;5l@D0XlC`102S
bO@40:C8lPD0X/kg1@2Qd_T40:Jji`D0YkcX102RUlT30:6Gb@@0X9K:102NU//309fHcPD0Yl?]1@2V
^^L40:Jlj@@0YkcX102V^nP50:Jlj@<0YK[X102S^NP509fci`<0TjcW1026XND408:OiP80W;_^0`2f
f?430<[bk0<0`>Ga0`2[aNd00`000000ZlG]0:S1k0020:S1k0h0Yl3[1@3oool00`000000oooo0?oo
o`040?ooo`003@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02D0oooo0`23[O02
025eh`80AX3U102Z[MX20<bmc@D0d;c700<0d[W10=?5c03CaL`0103E`LH30=Jk_`@0bl_I0`3Dalh3
0=_1`0@0alWL0P2o[lX308FMhP<0GI[`0P1Y[_P408>ln@@0Tl3f102K`O8409g5m0@0X<?a102Pao@4
0:;5l@D0XL_f102SbO@50:3>n0D0Wm7i102V]N@40:Jji`D0XiS90`2RUlT40:6Gb@<0X9K:102NU//5
0:K1k@@0Y[WV102V^^L50:Rnj@@0YkcX102W_^X40:Jlj@@0YK[X102R^>P409fci`@0TjcW0`26XND4
08:OiP<0]]Sa0`36knl40<3Ul@80/m;`0`2[aNd00`000000Yl3[0:O0j`0?0:O0j`D0oooo00<00000
0?ooo`3oool0103oool000d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?oo
o`<0N:[b00<08GGS04J0i@16P>D0102Z[MX50=2la`<0d[W1103E`LH40=Jk_`030=Nf^03;bmT0bl_I
00<0e<O>103K`L020=fk]PD0_jo:0`25WN8305fJl0<0JJkh0`23_?T408_6n`@0UlOh102MaO@509c:
m`<0X<Od1@2McOP409_?nPX0W/oi102U[ml40:Jei080Y[[W0P2TV<T40:>Hb@@0XYO90`2QUlT30:2F
bPD0Y;g[1@2W^^H40:JiiP80Y[[W0P2X`N/40:Rnj@D0Y[kZ102W_^X30:Jlj@D0Y;[Y102R^>P409V_
iP@0SjKU0`28XN@409>_jP@0a^o_0`37m>d40;?Bl0<0Z<7/00<000000:S1k02W`>/0402W`>/40?oo
o`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00X0oooo0P00000W0?ooo`<0
N:[b0`16P>D20:Z]fP80]:oD103@_<L30=:i`@030=Bf^`3E`LH0eL7600@0e[^o0`3G][P40=C7cP<0
fl700`3M^kH0103N^K80_jo:0;n_bP2o[lX20;jX``<0ViK>0`24Umh307R[lP@0OKgk0`2;a_/408g9
o0D0U/_j102DcO/409W=nP@0VLkj102KcoX509k;m`D0Y:OI102U[ml30:Jei0@0Y9S9102SV<T40::G
b@@0YKKU102T^NP40:Rki`@0Yk[V102V^NH50:S1j`@0Y[cY102V_^X50:Fjj0<0YK_Y102T^^T509ne
j0@0VJoV0`2?Y^D408RQi080TjoZ0`2[cO430<Odk@<0_^Kb102[aNd30:S1k0030000002W`>/0Yl3[
00l0Yl3[103oool00`000000oooo0?ooo`040?ooo`00303oool2000000h0oooo00<000000?ooo`3o
ool09@3oool306^Wm080?WgT1@2d[m@20=2la`<0d[W10`3D][/40=Jk_`@0ekJh00<0fK:b0=C7cP3D
alh00`3K`L030=fk]P80g[Vb0P2o[lX30;jX``@0ViK>0`24Umh307R[lP@0SK3^1028`OX308g9o0D0
TLSj102DcO/509S9n@<0VLkj1@2O`_440:BQdP@0Y:OI102U[ml40:FIb@@0Y9S90`2SV<T50:Jei0@0
YKKU0P2T^NP20:Rmj@@0Z;_W0`2W^^H50:O2k0D0Y[[X102V_>T40:Jkj0@0YK[X102U^nT40::hj0@0
WkGX102I[nH308nVi@@0R:7T0`2[cO430;o/lP<0_^Kb0`2ad?040:_5k@<0Yl3[00<000000:O0j`2W
`>/03`2W`>/30?ooo`030000003oool0oooo00@0oooo000M0?ooo`030000003oool0oooo02D0oooo
0`1[Yo@203imi0D0]:oD103B^L430=Bf^`040=Jc]P3F^kl0e[^o0=Jk_`<0ekJh0`3I/[840=_1`0<0
gK^f0P3N^K860;jX``<0ViK>102PVLd309NOfP@0SK3^102JZn8409>ll`@0WZkS1@2J__440::WfP@0
X;CW102UW<`40:BQdP<0Y:OI1@2VV/T40:FIb@<0Y9S9102W]^<40:Jei0@0YKKU1@2X_NT30:Rki`D0
Yl7]102V^^L40:Jjj0D0YkgY102V^nP80:Fjj0@0X[SX102L/NH409BYi0<0SZ?S102BZnL40;o/lP80
`_C_1@2ad?050:S1k0<0Yl3[00<000000:O0j`2W`>/03P2W`>/40?ooo`030000003oool0oooo00<0
oooo000N0?ooo`030000003oool0oooo02D0oooo0P1LY?H303imi080]:oD0`2j/=020=:i`@<0e;Jk
0`3F/kH00`3F^kl0ekJh0=Nf^0020=Nf^0<0fK:b00<0gK>]0=_1`03K`L000`3M^kH30=ji/P030=jj
]@2nZ<<0_ZS300<0_ZS3102YWLX40:2Ic@<0UioJ102RWm8409Z[hP@0Xj7C102N[^<50:FNc`@0XZOJ
102XVlT40:FLc0<0Y:7B102YWL/40:JJb@@0YIW9102Y^>@40:Nfh`<0Y[GT1@2X_nX40:Rmj@D0Y/3/
102W^nL40:Jji`@0Yko[102W_NT50:JmjP<0Y[cY102U^^P50:6gj0@0W;7V0`2DZN@408jSh`D0YlSa
00<0`_C_0;_Tl`2ki?<00`2ki?<40:[4k@@0Z<7/0`2W`>/00`000000Yl3[0:O0j`0@0:O0j`80oooo
00<000000?ooo`3oool00`3oool001l0oooo0P00000V0?ooo`80G:Cf00<001>@02]dhP2j/=001@2j
/=040=Bf^`<0e[>f103G][P30=Vb/P<0gK>]103M^kH30=ji/P030=jj]@2nZ<<0_ZS30080_ZS30P2n
[<P40:VMbP<0X9W=102ZWl/40::OdP@0ZIk<102SXM<40:ZNbP@0YIk?0P2RYmX30:bObP<0Z9_9102U
W<`40:bScP<0ZIg;102VV/T50:ZkiP@0ZKST0`2W]^<50:Roj`<0Z;oZ1@2V_^/50:Rlj0@0Yk_W102W
`>`40:Noj`@0YK_Y102V_NX40:Jlj@@0XkSX102Q]nP409baiP<0U:WT1@2DZ^H20:O8l@80^nkd0P2n
lo420;_Tl`<0[lg`102Za>d70:O0j`030000002W`>/0Yl3[0100Yl3[00<0oooo0000003oool0103o
ool00240oooo00<000000?ooo`3oool0903oool2052PmP03000CT00[M>80^[3@00<0^[3@0P2n/<d2
0=Bf^`@0e[>f00@0ek6b0=Nf^03G][P0ekJh0`3I/[830=fc[@030>:gZP3M^kH0gK^f00<0g[Vb0`3N
^[D20;jX``<0_Zc8102YWLX40:jTc@@0ZYo;0P2RWm820;6Tc0@0ZIk<0P2SXM<20;2Tc0<0ZYk:102U
W/l50:bObP@0Z9_90P2UW<`20:n[e0<0[:?>102YWL/20:JJb@80ZkoX102Z^nH40:Vhi0D0Yko[102W
_>T40:Jmj@@0Z;kY102X_>P50:K0k0@0Yl3/102V^^P40:Fkj@@0YK[W102T^>L40:>hj0@0WK3U102H
Z^<309:UhP@0U:[V0`2kk_@30;kcl@D0[lg`1@2X`N/70:O0j`030000002W`>/0Yl3[00l0Yl3[00<0
oooo0000003oool0103oool00280oooo00<000000?ooo`3oool0903oool3052PmP0302]dhP2j/=00
^[3@00@0_[3=00@0e;Jk0=Jc]P3F/kH0e[>f0`3G/K80103G][P0fK:b0=Vb/P3I/[840=fc[@80h[NZ
103N^K830=jj]@D0_Zc80P2YWLX30:fYd`@0[ZC=0`2ZWl/40;6Tc0@0ZIk<102`Y<`40:ZNbP80YIk?
0P2aZ<l40:bObP@0Z9_9102_Zm@40:bScP<0ZIg;1@2[_nP30:ZkiPD0YkkZ1@2W_NT40:Nlj@@0Z;oZ
102X_^T40:Joj`@0Y/3/1@2V^^L40:Jjj0@0YkcY102U^^L30:Bhi`D0X[KV102M/>D309RZh`@0TZGR
1@2Wbo<00`2nlo40]mkd0;ONm0030;ONm0@0ZL?/102X`N/80:O0j`030000002W`>/0Yl3[00l0Yl3[
00<000000?ooo`3oool00`3oool002<0oooo00<000000?ooo`3oool0903oool304RNm@H0_[3=103F
/kH30=Na/P@0fK:b0`3M/jd30>:gZP030>NlZP3N^K80g[Vb00@0g[Ze00<0fkfk0;j/b02n[<P00P2n
[<P50:fYd`@0[ZC=102c[M840;6Tc080ZIk<0P2d[]<40;2Tc0<0ZYk:1@2aZ<l30:bObPD0/KCK102_
Zm@30:bScPD0Z/;[0`2[_nP50:Jmj@@0Z;gY102W_NT50:Noj`@0Z;oZ102V_NX40:Joj`@0Yk_W102V
^^L50:NnjP@0YkcY0`2U^^L40:Bjj0@0X[KV102M/>D409FUh@@0UjcU102hl_<20;[`m0D0[<S^102Y
`n`;0:O0j`030000002W`>/0Yl3[00l0Yl3[00<000000?ooo`3oool00`3oool002@0oooo0P00000U
0?ooo`<0B9ke102n/<d20;nac@80e[>f103G/K800`3I/K00fK:b0=Vb/P040=fc[@<0h[NZ0P3W_:X0
103N^K80g[Ze0=jj]@3N^[D30=^m^`80_Zc80P2i/M440:fYd`80[ZC=0`2]/M/40;>]dP<0/JC<1@2d
[]<30;2Tc0@0/k;G102aZ<l40:nlh`@0/KCK102_Zm@50:S3k@@0YkWW102V^nP40:RojP@0Z;gY202W
_n/50:Nmj@@0Y[gZ102X_>P40:Nki`@0Yko[102W_^X50:Bjj0<0Y;_Y102T^^P409j`i0@0VZ_R102E
YN4209N/i@<0ZmOg0`2jl?@20;;DlP@0[<S^1@2X`>/;0:O0j`030000002W`>/0Yl3[00/0Yl3[0`3o
ool00`000000oooo0?ooo`030?ooo`009P3oool00`000000oooo0?ooo`0T0?ooo`80BIke0P2n/<d4
0;nac@030=Jc]P3G/K80ek6b0080ek6b0P3I/K00103I/[80gK>]0=fc[@3M/jd30>:gZP<0ikbZ103N
^[D30=^m^`D0^K7A0`2]ZM<50:faf`@0/jgB102b]]`40;B^d`@0/K[P102c/]L20;6Xc`80ZkkX102_
_><30;6df`D0Yl7]1@2W^NH40:Nii`@0Z<3[102X_nX40:NnjP@0Yko[102W_>P40:Nmj@D0Z;gY102X
_>P40:Joj`@0Yko[102U^>L40:Bjj0<0Y;_Y1@2Q/^@409j`i0<0VZ_R102EYN430:_Gm`<0]?Gb1@2b
e?840:S1k0@0Z<3[302W`>/00`000000Yl3[0:O0j`060:O0j`P0oooo00<000000?ooo`3oool00P3o
ool002L0oooo00<000000?ooo`3oool0903oool00`1?X_H0_k7=0;nac@040;nac@@0ek6b0`3I/K04
0=fc[@<0h[NZ0`3W_:X00`3Z`Z`0g[Ze0=jj]@040=^m^`030=Nm`02i/M40^K7A0080^K7A102V/=h4
0:faf`D0ZkSR102b]]`20;B^d`80Zk_U102a^^030;>be`D0ZkkX0`2__><50:Fnj`@0Z;_V102W^NH5
0:S2k0@0Z<3[102W_NT40:NnjPP0YkcX102X_^X40:Rmj@D0Y[kZ0`2V_n/50:JiiP@0YKSW102V^^L3
0:Bfi@@0XK;T102N/>@409NUg`@0Vk?Y0P2dmO840;OVmPD0Z/C]0`2X`N`@0:O0j`030000002W`>/0
Yl3[00<0Yl3[2`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`0T0?oo
o`0304nRmP2o/Ld0_k7=0080_k7=0P2l/m430=Na/P<0fK6`00<0g;Fa0=fc[@3M/jd00`3R]jX40>Nl
ZP80j/:/103K_K/30=Nm`0@0][?F102V/=h40:Ffi@@0ZkSR102b]]`50:^ki@<0/K[P1@2X_>P30:^n
j0D0Y[_X102Y_NP40:RkiP@0Yl;/102X`^`50:Nlj0<0YkgY1@2X_NT40:Nlj0@0YkoZ102X_^X40:Jl
j@@0Y[kZ102W^^L40:JiiPD0Y[gY102V^^L30:Bfi@@0WjoS102KZ=l409NUg`<0[N[i0`2clo@40:g;
l0@0Z/C]502W`>/00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo000Y0?ooo`80
00009@3oool00`1HY_L0_k7=0;nac@030;bcd@80ek6b103I/K020=be/@040=fc[@3R]jX0h[NZ0>:g
ZP<0ikbZ0`3Z`Z`00`3YaK00fkfk0=^m^`040=Nm`0030=>l``2f/mH0][?F0080][?F102V/^440:Ff
i@@0Y[WW102X^^L40:^ki@D0Yk_X102Y_NP40:Nki`@0ZKoZ102Y_NP40:O0k0@0Yl;/102W^nL40:Nl
j0@0Z;kY102X_NT90:NojP@0YkcX102V_>T40:Nkj0@0Yk[W102V_^/40:Jmj@@0Y[[W102Q/nD409n_
h`<0VjSO1@2Rb?@20;?cm0@0/MOd102]bo040:S0ja40Yl3[0`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo02<0oooo00<0F:Kg0;bcd@2l
/m400`2l/m40103G/K80fK6`0=Va/03I/K030=be/@@0h[NZ0`3W_:X20>[2[0<0jLF`103G_L030=>l
``80][?F0P2h]=D40:Jbh@@0YKOU102V^NL30:Rji`D0Z;cX1@2X_NT40:Vmj0@0Z;oZ102Y_nX40:Jm
jP@0Yl3/102W^^L40:Nki`@0Z;oZ102X_^T40:NnjP@0YkoZ1@2W^nP40:Nlj0@0Z;gY102W^nP40:Jm
jP@0Y[k[102T]>@40::di@@0XK?U0`2O[n<409V/i0<0X/Sd00@0Z?Cb0;?Vm`2ci_L0/nKg0`2aeo@5
0:S2k100Yl3[203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000/0?oo
o`030000003oool0oooo02@0oooo102l/m440=Va/0<0g;Fa00<0h;bd0>:gZP3R]jX00`3W_:X30>[2
[0<0jLF`00<0ilFd0=Nm`03G_L00103C_<<50;Rde@@0Z[CP102U]nD40:NjiP@0Yk_W102W_>P40:Rm
j@D0YkgY102X_nX40:Nlj0@0Y[gZ102X^nL40:Nji`@0Z<3[102X_nX40:Nmj@@0YkkZ102W_>P40:Nk
j0D0YkkY0`2X_NT50:Jlj@@0Y[gZ102U]N@40:Bdi0<0X[CU1@2NY]`309ZSf`@0VJcT00<0Z?Cb0;?V
m`2ci_L00`2ci_L50:[5kA00Yl3[2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo000]0?ooo`030000003oool0oooo02@0oooo102b^=d20=Va/0@0g;Fa0P3P_;@0103R]jX0
ikbZ0>NlZP3W_:X20>[2[0<0jLF`0`3WaK@50=>l``040=6ka02h]=D0^;CE0;Rde@80^kCC102Z]>04
0:Rgi0@0Yk[V102X^nL40:Nlj0@0Z;cX102W_NT50:Rli`<0YkcX1@2Y_NP40:Rki`@0Z<7[102X`>/4
0:Nlj0@0YkgY102X_>P40:Nlj0@0YkkZ102W_^T40:Jkj0@0Y[cY1@2V]nD30:Fei0D0Y;GU0`2S[^04
09jVg0<0VZ?K102SjO/30:gbm@@0[<_`4@2W`>/?0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00@3oool002h0oooo00<000000?ooo`3oool0903oool40;:hg@040=Va/03L]K40g;Fa
0=be/@<0h;bd0`3W_:X30>[2[0<0jLF`0`3WaK@0103TaKP0dkc30=>l``3C_<<30=6ka0D0^kCC0P2Z
]>020:jeg@@0Z;OT102Y^^H40:Rki`@0ZKcW102X_>P40:Vmj0@0Z;cW102Y_nT40:Vmj0D0Yko[0`2X
`N/50:Nki`@0YkcX102X_NP40:Rlj0P0YkkZ102W^^L40:Jkj0@0YkWV102V]nD40:Fhi`@0Y;GU102S
[^0309jVg0D0Wlcg00<0[O;e0:kCl`2^do<00`2^do<40:S1j``0Yl3[503oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0040oooo000_0?ooo`8000009@3oool30;:hg@@0g;Fa0`3P_;@0
0`3Ta[T0ikbZ0>NlZP020>[2[0<0jLF`0`3WaK@30>C5^0030=>l``3A^l@0dK_40080dK_400<0d;_5
0;^dd`2k]=<00P2k]=<50:jeg@@0ZkSR102Y^^H40:VkiP@0ZKcW202Y_NP40:Rnj@@0ZKoY102W_NT4
0:Noj`@0Z;[V102W^nL50:Rnj@<0Z;gX1@2W_^T40:NnjPP0Yk[W102W^nP40:NiiPP0YKSW0`2T]ND5
09^Sf`@0Vk3V00<0W_;_0:oMm`2_gOL00`2_gOL40:W3k@@0Z<7[102W`N/40:O0jaP0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0R0?oo
o`@0U;W`0P3L]K430>2l]0<0i<Ji0`3Z`Z`30>W5/0<0ilFd0`3TaKP40=6ka0<0d;_50P2k]=<20;jf
dP<0[[GM0P2b]M/40:^hhP@0Z[[T102Y^nH40:Vli`@0ZKgX102X_>P40:Rnj@@0Yk_X102W_NT40:Rk
i`@0Z;[V102X_nX40:Rnj@@0YkgY102W_^T50:NjiP<0Yk[W1@2W_NT40:Nkj0@0YKOV102U^>L40::T
e`<0WZ7G102KXm/409K^l`80[NWi1@2Zanl30:W3k@D0Yl7/0`2W`N/L0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3oool08`3oool309Bil004
0=be/@3P_;@0h;bd0>2l]0<0i<Ji0P3Wc[d30>W5/0<0ilFd103TaKP00`3Qa[`0dK_40=6ka0040=2k
a@D0_[KB1@2b]M/20:^hhP80[[OP102Z^^@40:Zji@@0ZKcW102Y^nL40:Rlj0@0ZK_W102W^nP40:Vm
i`@0Z;_W102X`>/40:RojP@0Yk_X102W_NT40:Rki`@0Yk[V202W_NT50:Jfi@<0YKOV1@2TZMX40::T
e`<0WZ7G0P2KXm/309WSo@030:gYn@2[c?40Zlca0080Zlca102Zanl40:O0j`@0Yl7/803oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000c0?ooo`030000003oool0oooo02<0
oooo0P15X_H30>2l]0<0i<Ji0`3Wc[d20>SD`@@0ilFd0`3TaKP30>76_0@0d;_50P3@_<L30;jfdP80
`;K@102b]M/50:jgh0@0[;WS102Z^^D40:ZkiP@0ZK_W102Z_>L40:Vki`@0ZKkX102Y_NL40:RojP@0
Z<3[102W^^H40:Nkj0@0Z;cW102X^nL80:Nmj@@0Y[GT102V]^D40:J_gP@0Y:WJ102RY=L309jQe`03
09WSo@2Rl?H0X_3f0080X_3f0P2[dO@40:_<l@@0Yko[102W`>/T0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00@3oool003@0oooo0P00000T0?ooo`80AJ;f0P3P_;@30>C6^@80iljm
0`3Xe<400`3Wf<H0ilFd0>O5]0030>C5^0@0hLJl00<0g/O20=2ka@3@^lD0103@_<L50<2fd0@0][KH
0`2^]n020;2ggP@0[;WS102[^^@40:ZkiPP0Z[cW102Y_NP40:Vnj0@0Z;cX102X_nX40:Rii@@0Yk[V
102Y_NP40:Rli`P0YkgY102W]N<40:Jei0@0Yk?Q102V[mh30:BYfPD0W[SZ0P2Mc?P308o^k0@0Zm7d
1@2X_nX30:NojbT0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`010?ooo`00=P3o
ool00`000000oooo0?ooo`0S0?ooo`04001XbP3Ta[T0i<Ji0>C6^@<0iljm0P3Xe<430>OHaP<0i<Fh
103Qa[`30=k7`P@0d;c70P3?_LT30<2fd080`[O?102f]]P40;2ggPD0[[SQ0`2[^^@50:^ki@<0Z[cW
1@2Y^nL30:Vmj0D0Z;[V0`2X_>P50:Vji@<0Z;WU1@2Y_^T40:Vmj0@0Yk_W1@2X]^<30:Nfh`@0YkGS
102W]^<40:Nch@<0YZoN102OZml409jhjP0308o^k02[eoL0ZmOg00<0ZmOg102Y`^`40:RojR`0oooo
00<000000?ooo`3oool01`3oool100000040oooo0@3oool003L0oooo00<000000?ooo`3oool0903o
ool20>C6^@80iljm0`3Xe<430>OHaP80hm_>103Qa[`30=k7`P80fl_90P3@_<L30<nmb@80`;K@0`32
]ll50;VeeP80/;ON0P2c]]/40:jhh@@0[KWR102[^nD40:Zji@@0ZK_W102Z^^D40:RjiP@0Z[_V102Y
^^D50:Voj@@0Z;OT102W^NH40:Vgh`@0Z;KS0`2W]^<50:Ngi0<0YkKS1@2RX]@30:6Tf0@0Wj_O00<0
OnOV0:[Mn@2ZgOT00`2ZgOT50:W5kP<0ZL;/<03oool00`000000oooo0?ooo`060?ooo`4000000@3o
ool10?ooo`00>03oool00`000000oooo0?ooo`0T0?ooo`<0iljm0P3Xe<430>OHaP80hm_>0P3LgmP2
0>76_0<0g/O20`3KblT50<nmb@@0`[O?0P34^Ll40;VeePD0/kKK102`]mh40:fihP@0[;[S102Z^^D4
0:^ki@@0Z[[U102[_NL40:ZkiPD0ZKgX102X]^<40:Rgi0@0ZKWT102Y]n<30:Rfh`P0YkOT102SXM84
0::Re0@0XJCH00<0N^CY0:KSn`2Vho/00`2Vho/40:W8l3P0oooo00<000000?ooo`3oool01@3oool1
00000040oooo0@3oool003T0oooo0P00000V0?ooo`80j=C10`3Wf<H20>?KcP@0g=oH0`3Nal840=_;
b@040=K@d`3?_LT0ckg90<nmb@80c/7=0P32]ll40<Bic`80^KGF0P2l]]<30;>ff`80][CG102`]mh4
0:ngg`@0[;[S102/^^@40:^ki@D0ZkcV0`2[_NL50:RjiP@0Z[KR102X]^<40:Zji@@0ZKWT0`2Y]n<4
0:Rfh`@0YkOT102UXM440:>QdP<0XZ;D0P1oi?8409oWo0D0Z<_a>`3oool00`000000oooo0?ooo`05
0?ooo`4000000@3oool10?ooo`00>`3oool00`000000oooo0?ooo`0S0?ooo`@0WKo`0P3Sflh40=cO
f0<0d>CV103KblT30=K@d`030<nmb@3>`Ld0c/7=0080c/7=1@34^Ll50;bfd`D0][CG0P2`]mh20;>d
fP@0[kOO102]]n040:bji0@0ZkSS0`2[_>H20:^fh@@0ZKOS102[]n840:ZfhP@0Zk[U102Z^^D40:R_
g@<0Z;?Q102X]^<40:JQd@@0YJ7A0`2SXM800`28hoX0UNSj09GXnP0309GXnPD0Z<cc?`3oool00`00
0000oooo0?ooo`040?ooo`4000000@3oool10?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`<0
WKo`0`1V[OT40=3TiP80]nOf0P3KblT40=K@d`@0c/7=0P3<a]@30<Bic`80aKcB0`2l]]<20;jgd`@0
][CG1@2c]=X40;6df`@0[KOP102]]]l40:^hh`D0ZkKQ102/]n430:^ghPD0Z[OR0`2[^^D50:R[f@<0
Z:oM102X/n440:NRd@@0YZ7A0`2UXM400`2?hOd0RnOg08_Wm`0308_Wm`D0Ylgd@`3oool00`000000
oooo0?ooo`030?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?ooo`0T0?ooo`@0XKo^
0`21]oL50;OWmP@0e]3C0P3<f>820<k1c@@0c<KD1@35_=850;jgd`@0^KCE0`2c]=X20;Jce`@0/KCK
102`/m/40:ffg`@0[KGN0P2[]^430:fdgP<0[;OQ102Z/Md40:ZghP@0ZJOE102XZmT30:R_g@D0Z:CB
0`2WX]440:JQd@0309COoP22i?@0P^Cd00<0P^Cd102VcOA80?ooo`030000003oool0oooo0080oooo
0@0000010?ooo`40oooo000n0?ooo`8000009@3oool40:Bok@@0T[cc0P1>Y_P308OMoPD0c=SR103<
a]@20<K@hP<0aKcB0P34aMX30;jgd`80`;gH102i]=D50;Jce`80/KCK0P2c/]L40;2cf`@0[k?K0`2]
]Mh50:fdgP80[;OQ0P2[[=L40:Zag@@0ZjKC102YYmD30:R[f@@0ZjWE102XY=830:NRd@80UN3n1@1l
h_@40:G=m4/0oooo00<000000?ooo`3oool00`3oool100000040oooo00100?ooo`030000003oool0
oooo02<0oooo102T_nd409fnl0@0N[Oi00<04hgV0027b@2fh?D0102fh?D50<K@hPD0a<GJ1@30_MP2
0;Vde@80_;[G102f/mL40;>be`D0/[7G0`2_/m/40:j_f@@0[KCN1@2[[=L20:Zag@80[Z_D102[Y]<3
0:VWe@@0[K3J102[ZMD30:RTdP80Tn;m101jh?D50:G=mDl0oooo00<000000?ooo`3oool00P3oool1
00000040oooo00110?ooo`030000003oool0oooo02<0oooo1@2V`>`309fnl0@0T[gd0P1J[_X00`00
L;/0N]Om07[Go@0307[Go@@0/=gg0`34aMX20;cDk0@0`;gH1@2l^]L40;Vhf080/k;G0P2g^=T40;:a
e`@0/JoF102^[mT40:j[e@@0ZjcG1@2^Zm@30:^Vd`@0/;gT102]/=X407[QlP80Nmki102Tbo@40:C<
m5<0oooo00D000000?ooo`3oool0oooo000000010?ooo`00@P3oool00`000000oooo0?ooo`0T0?oo
o`@0Yl3/102S_nd309:mm0D0QK_h00@0?ZOf02>YhP0SZN808jWR0`2`gOL50;cDk0@0_LkW0P2l^]L3
0;_;iP<0^KSH1@2g^=T20;:ae`80]kcM102a[mH40;BffP@0[Z_E102c^=d40:j[e0@0/=7a102`_N@4
06?Hi@80PMcm102Sb_@40:C;m5L0oooo00@000000?ooo`3oool000000@3oool004<0oooo0P00000U
0?ooo`@0Yl3/102V_n`409nok`@0V[ka0`1j^_/2036Ul@<0JM7j102<gOh30;g>i`D0^l_V102ic^X4
0;Nhf@D0]kcM0P2a[mH20;O=j`@0];KJ102dd>l40;>hg@@0WnCl102`dO400`1>c=T0AlOK08oDoP03
08oDoP@0XlSc102Sb_AJ0?ooo`040000003oool0oooo00000040oooo00150?ooo`030000003oool0
oooo02<0oooo102W`>/40:Jok0@0Y;o]0`2J__4409Nol`@0M;_l00@0<ZW`08cMoP2<gOh0S=gn1@2G
goh4097PoP@0^LkZ102ceo840;Nlg@D0]lg[102JiO`40;C@k`@0L]ka0P1Bc>/409[;n@@0ULol102T
a_9R0?ooo`030000003oool000000040oooo00160?ooo`030000003oool0oooo02<0oooo2@2W`>/3
0:Bok@@0Xko]202G_o<307Jmo0<0>k3c0`0g^>L3097PoPD0N]cj0`2ceo8509_So@@0Fm7[0`2JiO`2
04W8h00304S4j`21col0PLoo0080PLoo102Nb?D409[;n@@0Y<C`IP3oool100000040oooo0@000000
04L0oooo00<000000?ooo`3oool08`3oool90:O0j`<0Yl3/102V`>`40:>okP@0Xl3^102I`?<409g0
l@<0Rl;i0`1V`Oh50875o@@0U/Cg1024b?h509_5m@<0TL[k102Qa?840:K0k0@0YL;^JP3oool20000
0000B03oool2000002D0oooo2`2W`>/80:K0k0@0Xl3^102T`>d309g0l@D0XL3_0`2G`_D509o1l0<0
U/Cg1@2Q`_040:G0k@<0Xl;_102W_n/40:K0k6d0oooo0P00000004X0oooo00<000000?ooo`3oool0
8`3oool?0:O0j`P0Y/3/0`2T`>d50:G0k0@0Y/3/102T`>d40:K0k0@0Y<3]102W`>`30:G0k@P0Yko[
L03oool200000000B`3oool00`000000oooo0?ooo`0R0?ooob00Yl3[102V`>`40:O0j`@0Y/3/102W
`>/30:O0k0D0Yl3[0`2W_n]_0?ooo`@000000P3oool004`0oooo00<000000?ooo`3oool08`3ooolc
0:O0jg40oooo100000060?ooo`00C@3oool2000002@0oooo;`2W`>]`0?ooo`@000002P3oool004l0
oooo00<000000?ooo`3oool08P3oool[0:O0jfl0oooo1000000>0?ooo`00D03oool00`000000oooo
0?ooo`0S0?ooobH0Yl3[KP3oool400000180oooo001A0?ooo`030000003oool0oooo02<0oooo8P2W
`>]^0?ooo`<000005P3oool00580oooo0P00000T0?oooah0Yl3[K@3oool4000001T0oooo001D0?oo
o`030000003oool0oooo0280oooo5`2W`>]_0?ooo`@000007@3oool005D0oooo00<000000?ooo`3o
ool08@3ooolD0:O0jfh0oooo1000000Q0?ooo`00EP3oool00`000000oooo0?ooo`0R0?ooo`l0Yl3[
K@3oool4000002D0oooo001G0?ooo`8000008`3oool;0:O0jf`0oooo1000000Y0?ooo`00F@3oool0
0`000000oooo0?ooo`0Q0?ooo`@0Yl3[K`3oool3000002d0oooo001J0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0JP3oool400000300oooo001K0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0IP3oool4000003@0oooo001L0?ooo`8000008@3oool00`000000oooo
0?ooo`1R0?ooo`@00000>03oool005h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1N0?ooo`@00000?03oool005l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J
0?ooo`@00000@03oool00600oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?oo
o`<00000A03oool00640oooo0P00000L0?ooo`030000003oool0oooo05<0oooo100000170?ooo`00
H`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04l0oooo1000001;0?ooo`00I03o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo1000001?0?ooo`00I@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04L0oooo1000001C0?ooo`00IP3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0oooo1000001G0?ooo`00I`3oool2000001H0
oooo00<000000?ooo`3oool0@03oool3000005/0oooo001Y0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0?03oool4000005h0oooo001Z0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0>03oool400000680oooo001[0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0=03oool4000006H0oooo001/0?ooo`800000403oool00`000000oooo0?ooo`0a0?oo
o`@00000JP3oool006h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`@0
0000KP3oool006l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Z0?ooo`<00000
LP3oool00700oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`@00000M@3o
ool00740oooo0P00000;0?ooo`030000003oool0oooo0280oooo1000001i0?ooo`00L`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo1000001m0?ooo`00M03oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000210?ooo`00M@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01H0oooo100000250?ooo`00MP3oool2000000H0oooo00<0
00000?ooo`3oool04`3oool3000008T0oooo001h0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03`3oool4000008`0oooo001i0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool400000900oooo001j0?ooo`050000003oool0oooo0?ooo`0000002@3oool40000
09@0oooo001k0?ooo`80000000<0oooo0000003oool0103oool4000009P0oooo001m0?ooo`800000
00<0oooo0000000000000P00002L0?ooo`00OP3oool200000:00oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09678 .21894 -24 -8.90524 ]
[.09678 .21894 0 .09476 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5956 .02278 -15.3266 -9 ]
[.5956 .02278 2.67338 0 ]
[.70636 .00349 0 -6.25383 ]
[.70636 .00349 24 2.74617 ]
[.79908 .14546 0 -6.11502 ]
[.79908 .14546 24 2.88498 ]
[.88062 .27033 0 -5.99657 ]
[.88062 .27033 24 3.00343 ]
[.95289 .38101 0 -5.8943 ]
[.95289 .38101 6 3.1057 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -24 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69413 .00825 m
.68802 .01064 L
s
[(-0.6)] .70636 .00349 -1 .38974 Mshowa
.78673 .1499 m
.78056 .15211 L
s
[(-0.4)] .79908 .14546 -1 .35889 Mshowa
.86817 .27448 m
.86195 .27655 L
s
[(-0.2)] .88062 .27033 -1 .33257 Mshowa
.94036 .3849 m
.93409 .38684 L
s
[(0)] .95289 .38101 -1 .30985 Mshowa
.125 Mabswid
.71845 .04545 m
.71477 .04686 L
s
.74196 .08142 m
.73828 .0828 L
s
.76471 .11622 m
.76102 .11757 L
s
.80805 .18252 m
.80434 .18382 L
s
.82872 .21412 m
.825 .21541 L
s
.84875 .24476 m
.84502 .24602 L
s
.88702 .30331 m
.88328 .30453 L
s
.90532 .3313 m
.90157 .3325 L
s
.92309 .35848 m
.91934 .35967 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-1)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-0.5)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(0.5)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(1)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Mtetra
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Mtetra
.41686 .69013 .42323 .69578 .43406 .69272 .42772 .68706 Mtetra
.656 .752 .92 r
.42772 .68706 .43406 .69272 .44494 .68966 .43863 .68396 Mtetra
.656 .751 .92 r
.43863 .68396 .44494 .68966 .45586 .68658 .44958 .68086 Mtetra
.656 .752 .92 r
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Mtetra
.656 .751 .92 r
.46057 .67775 .46682 .68349 .47783 .68038 .47161 .67462 Mtetra
.656 .752 .92 r
.47161 .67462 .47783 .68038 .48889 .67727 .48269 .67148 Mtetra
.656 .751 .92 r
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Mtetra
.656 .752 .92 r
.49382 .66833 .49998 .67414 .51113 .67099 .50499 .66517 Mtetra
.656 .752 .921 r
.50499 .66517 .51113 .67099 .52232 .66784 .51621 .662 Mtetra
.51621 .662 .52232 .66784 .53355 .66471 .52747 .65881 Mtetra
.654 .75 .921 r
.52747 .65881 .53355 .66471 .54483 .66155 .53878 .65566 Mtetra
.65 .75 .923 r
.53878 .65566 .54483 .66155 .55616 .65833 .55014 .65261 Mtetra
.644 .755 .93 r
.55014 .65261 .55616 .65833 .56753 .65512 .56155 .64968 Mtetra
.638 .764 .939 r
.56155 .64968 .56753 .65512 .57896 .65199 .57301 .64684 Mtetra
.631 .774 .949 r
.57301 .64684 .57896 .65199 .59043 .64897 .58452 .64407 Mtetra
.624 .782 .957 r
.58452 .64407 .59043 .64897 .60195 .64602 .59609 .64138 Mtetra
.616 .79 .965 r
.59609 .64138 .60195 .64602 .61352 .64308 .6077 .63877 Mtetra
.607 .802 .974 r
.6077 .63877 .61352 .64308 .62515 .64011 .61938 .63619 Mtetra
.599 .816 .983 r
.61938 .63619 .62515 .64011 .63682 .63707 .6311 .63358 Mtetra
.592 .833 .99 r
.6311 .63358 .63682 .63707 .64854 .63395 .64288 .63085 Mtetra
.589 .848 .993 r
.64288 .63085 .64854 .63395 .6603 .63074 .6547 .62793 Mtetra
.59 .861 .994 r
.6547 .62793 .6603 .63074 .67212 .62745 .66657 .62479 Mtetra
.597 .871 .993 r
.66657 .62479 .67212 .62745 .68398 .62405 .67847 .62142 Mtetra
.608 .876 .991 r
.67847 .62142 .68398 .62405 .69588 .62056 .69042 .61782 Mtetra
.623 .877 .989 r
.69042 .61782 .69588 .62056 .70783 .61699 .70241 .614 Mtetra
.639 .873 .985 r
.70241 .614 .70783 .61699 .71983 .61336 .71444 .61001 Mtetra
.651 .863 .98 r
.71444 .61001 .71983 .61336 .73188 .60968 .72651 .60593 Mtetra
.66 .85 .973 r
.72651 .60593 .73188 .60968 .74397 .60596 .73862 .60181 Mtetra
.664 .836 .966 r
.73862 .60181 .74397 .60596 .75611 .60223 .75078 .5977 Mtetra
.666 .822 .959 r
.75078 .5977 .75611 .60223 .76831 .59856 .763 .59364 Mtetra
.667 .808 .951 r
.763 .59364 .76831 .59856 .78056 .59501 .77526 .58961 Mtetra
.668 .791 .941 r
.77526 .58961 .78056 .59501 .79288 .59158 .78759 .58564 Mtetra
.665 .772 .929 r
.78759 .58564 .79288 .59158 .80526 .58817 .79997 .58179 Mtetra
.661 .756 .921 r
.79997 .58179 .80526 .58817 .81768 .58467 .81241 .57809 Mtetra
.657 .749 .918 r
.81241 .57809 .81768 .58467 .83015 .58107 .82493 .57453 Mtetra
.655 .751 .92 r
.82493 .57453 .83015 .58107 .84268 .57748 .8375 .57098 Mtetra
.656 .754 .922 r
.8375 .57098 .84268 .57748 .85526 .57395 .85012 .5674 Mtetra
.656 .753 .921 r
.85012 .5674 .85526 .57395 .8679 .57042 .8628 .56379 Mtetra
.656 .751 .92 r
.8628 .56379 .8679 .57042 .8806 .56684 .87553 .56018 Mtetra
.87553 .56018 .8806 .56684 .89334 .56324 .88832 .55656 Mtetra
.656 .752 .92 r
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Mtetra
.656 .751 .92 r
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Mtetra
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Mtetra
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Mtetra
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Mtetra
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Mtetra
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Mtetra
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Mtetra
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Mtetra
.41045 .68444 .41686 .69013 .42772 .68706 .42134 .68134 Mtetra
.42134 .68134 .42772 .68706 .43863 .68396 .43227 .67823 Mtetra
.43227 .67823 .43863 .68396 .44958 .68086 .44325 .6751 Mtetra
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Mtetra
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Mtetra
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66566 Mtetra
.656 .752 .921 r
.47644 .66566 .48269 .67148 .49382 .66833 .4876 .66249 Mtetra
.655 .751 .921 r
.4876 .66249 .49382 .66833 .50499 .66517 .4988 .65933 Mtetra
.652 .752 .923 r
.4988 .65933 .50499 .66517 .51621 .662 .51005 .65622 Mtetra
.646 .753 .927 r
.51005 .65622 .51621 .662 .52747 .65881 .52135 .65326 Mtetra
.635 .758 .937 r
.52135 .65326 .52747 .65881 .53878 .65566 .53269 .65052 Mtetra
.618 .769 .952 r
.53269 .65052 .53878 .65566 .55014 .65261 .54409 .64807 Mtetra
.592 .785 .972 r
.54409 .64807 .55014 .65261 .56155 .64968 .55554 .64592 Mtetra
.551 .804 .992 r
.55554 .64592 .56155 .64968 .57301 .64684 .56705 .64408 Mtetra
.489 .821 .999 r
.56705 .64408 .57301 .64684 .58452 .64407 .57862 .64242 Mtetra
.407 .823 .972 r
.57862 .64242 .58452 .64407 .59609 .64138 .59025 .64071 Mtetra
.333 .806 .911 r
.59025 .64071 .59609 .64138 .6077 .63877 .60193 .63873 Mtetra
.3 .794 .861 r
.60193 .63873 .6077 .63877 .61938 .63619 .61366 .63635 Mtetra
.316 .805 .852 r
.61366 .63635 .61938 .63619 .6311 .63358 .62543 .6336 Mtetra
.363 .833 .877 r
.62543 .6336 .6311 .63358 .64288 .63085 .63725 .63055 Mtetra
.415 .859 .91 r
.63725 .63055 .64288 .63085 .6547 .62793 .64912 .62731 Mtetra
.454 .874 .936 r
.64912 .62731 .6547 .62793 .66657 .62479 .66103 .62398 Mtetra
.474 .88 .947 r
.66103 .62398 .66657 .62479 .67847 .62142 .673 .62061 Mtetra
.475 .881 .947 r
.673 .62061 .67847 .62142 .69042 .61782 .68501 .61719 Mtetra
.465 .88 .935 r
.68501 .61719 .69042 .61782 .70241 .614 .69707 .61366 Mtetra
.45 .878 .915 r
.69707 .61366 .70241 .614 .71444 .61001 .70917 .60994 Mtetra
.447 .879 .896 r
.70917 .60994 .71444 .61001 .72651 .60593 .7213 .60591 Mtetra
.475 .894 .896 r
.7213 .60591 .72651 .60593 .73862 .60181 .73346 .60147 Mtetra
.535 .919 .923 r
.73346 .60147 .73862 .60181 .75078 .5977 .74563 .59665 Mtetra
.607 .934 .958 r
.74563 .59665 .75078 .5977 .763 .59364 .75784 .59155 Mtetra
.659 .92 .976 r
.75784 .59155 .763 .59364 .77526 .58961 .77008 .58641 Mtetra
.68 .884 .974 r
.77008 .58641 .77526 .58961 .78759 .58564 .78238 .58145 Mtetra
.681 .845 .962 r
.78238 .58145 .78759 .58564 .79997 .58179 .79475 .5768 Mtetra
.676 .814 .949 r
.79475 .5768 .79997 .58179 .81241 .57809 .80719 .57244 Mtetra
.67 .788 .937 r
.80719 .57244 .81241 .57809 .82493 .57453 .8197 .56834 Mtetra
.663 .768 .927 r
.8197 .56834 .82493 .57453 .8375 .57098 .83228 .56448 Mtetra
.659 .756 .922 r
.83228 .56448 .8375 .57098 .85012 .5674 .84494 .56078 Mtetra
.656 .752 .921 r
.84494 .56078 .85012 .5674 .8628 .56379 .85765 .55713 Mtetra
.85765 .55713 .8628 .56379 .87553 .56018 .87042 .55349 Mtetra
.656 .752 .92 r
.87042 .55349 .87553 .56018 .88832 .55656 .88325 .54983 Mtetra
.656 .751 .92 r
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Mtetra
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Mtetra
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Mtetra
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Mtetra
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Mtetra
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Mtetra
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Mtetra
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Mtetra
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Mtetra
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Mtetra
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Mtetra
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Mtetra
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Mtetra
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66297 Mtetra
.655 .751 .921 r
.45901 .66297 .46533 .66882 .47644 .66566 .47015 .65981 Mtetra
.652 .751 .923 r
.47015 .65981 .47644 .66566 .4876 .66249 .48134 .65671 Mtetra
.645 .753 .928 r
.48134 .65671 .4876 .66249 .4988 .65933 .49257 .65378 Mtetra
.629 .757 .939 r
.49257 .65378 .4988 .65933 .51005 .65622 .50384 .65121 Mtetra
.598 .768 .961 r
.50384 .65121 .51005 .65622 .52135 .65326 .51517 .64913 Mtetra
.543 .785 .988 r
.51517 .64913 .52135 .65326 .53269 .65052 .52655 .64763 Mtetra
.451 .799 .998 r
.52655 .64763 .53269 .65052 .54409 .64807 .53799 .64653 Mtetra
.335 .787 .951 r
.53799 .64653 .54409 .64807 .55554 .64592 .54949 .64541 Mtetra
.283 .778 .886 r
.54949 .64541 .55554 .64592 .56705 .64408 .56105 .64373 Mtetra
.368 .831 .906 r
.56105 .64373 .56705 .64408 .57862 .64242 .57266 .64115 Mtetra
.537 .893 .976 r
.57266 .64115 .57862 .64242 .59025 .64071 .5843 .6377 Mtetra
.651 .869 .981 r
.5843 .6377 .59025 .64071 .60193 .63873 .59599 .63368 Mtetra
.683 .798 .936 r
.59599 .63368 .60193 .63873 .61366 .63635 .60771 .62943 Mtetra
.682 .737 .892 r
.60771 .62943 .61366 .63635 .62543 .6336 .61947 .62521 Mtetra
.674 .696 .863 r
.61947 .62521 .62543 .6336 .63725 .63055 .63129 .62115 Mtetra
.665 .671 .846 r
.63129 .62115 .63725 .63055 .64912 .62731 .64316 .61732 Mtetra
.658 .656 .837 r
.64316 .61732 .64912 .62731 .66103 .62398 .65508 .6137 Mtetra
.652 .649 .834 r
.65508 .6137 .66103 .62398 .673 .62061 .66706 .61029 Mtetra
.647 .647 .836 r
.66706 .61029 .673 .62061 .68501 .61719 .67911 .60709 Mtetra
.642 .649 .842 r
.67911 .60709 .68501 .61719 .69707 .61366 .69122 .60411 Mtetra
.637 .659 .855 r
.69122 .60411 .69707 .61366 .70917 .60994 .70339 .60136 Mtetra
.631 .68 .878 r
.70339 .60136 .70917 .60994 .7213 .60591 .71564 .59879 Mtetra
.626 .718 .913 r
.71564 .59879 .7213 .60591 .73346 .60147 .72794 .59625 Mtetra
.618 .782 .96 r
.72794 .59625 .73346 .60147 .74563 .59665 .7403 .59347 Mtetra
.6 .859 .993 r
.7403 .59347 .74563 .59665 .75784 .59155 .75267 .59009 Mtetra
.571 .911 .972 r
.75267 .59009 .75784 .59155 .77008 .58641 .76503 .5858 Mtetra
.574 .932 .935 r
.76503 .5858 .77008 .58641 .78238 .58145 .77737 .58059 Mtetra
.628 .948 .944 r
.77737 .58059 .78238 .58145 .79475 .5768 .78972 .57479 Mtetra
.682 .933 .968 r
.78972 .57479 .79475 .5768 .80719 .57244 .8021 .56899 Mtetra
.697 .883 .967 r
.8021 .56899 .80719 .57244 .8197 .56834 .81455 .5636 Mtetra
.688 .831 .952 r
.81455 .5636 .8197 .56834 .83228 .56448 .8271 .55879 Mtetra
.674 .792 .937 r
.8271 .55879 .83228 .56448 .84494 .56078 .83974 .55449 Mtetra
.664 .768 .927 r
.83974 .55449 .84494 .56078 .85765 .55713 .85248 .55054 Mtetra
.659 .757 .922 r
.85248 .55054 .85765 .55713 .87042 .55349 .86528 .54676 Mtetra
.657 .753 .921 r
.86528 .54676 .87042 .55349 .88325 .54983 .87815 .54305 Mtetra
.656 .752 .92 r
.87815 .54305 .88325 .54983 .89614 .54616 .89107 .53934 Mtetra
.656 .751 .92 r
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Mtetra
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Mtetra
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Mtetra
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Mtetra
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Mtetra
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Mtetra
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Mtetra
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Mtetra
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Mtetra
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Mtetra
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66346 Mtetra
.655 .751 .921 r
.43044 .66346 .43687 .6693 .44792 .66614 .44152 .66028 Mtetra
.653 .751 .922 r
.44152 .66028 .44792 .66614 .45901 .66297 .45264 .65715 Mtetra
.647 .752 .925 r
.45264 .65715 .45901 .66297 .47015 .65981 .46381 .65416 Mtetra
.631 .754 .936 r
.46381 .65416 .47015 .65981 .48134 .65671 .47502 .65155 Mtetra
.594 .761 .958 r
.47502 .65155 .48134 .65671 .49257 .65378 .48627 .6496 Mtetra
.521 .775 .989 r
.48627 .6496 .49257 .65378 .50384 .65121 .49757 .64845 Mtetra
.394 .778 .991 r
.49757 .64845 .50384 .65121 .51517 .64913 .50893 .64782 Mtetra
.278 .76 .924 r
.50893 .64782 .51517 .64913 .52655 .64763 .52035 .64698 Mtetra
.333 .806 .913 r
.52035 .64698 .52655 .64763 .53799 .64653 .53183 .64504 Mtetra
.554 .892 .984 r
.53183 .64504 .53799 .64653 .54949 .64541 .54337 .64162 Mtetra
.688 .844 .958 r
.54337 .64162 .54949 .64541 .56105 .64373 .55494 .63709 Mtetra
.702 .749 .888 r
.55494 .63709 .56105 .64373 .57266 .64115 .56654 .63219 Mtetra
.687 .686 .844 r
.56654 .63219 .57266 .64115 .5843 .6377 .57819 .62749 Mtetra
.672 .656 .826 r
.57819 .62749 .5843 .6377 .59599 .63368 .58989 .62321 Mtetra
.663 .648 .826 r
.58989 .62321 .59599 .63368 .60771 .62943 .60164 .61932 Mtetra
.658 .654 .834 r
.60164 .61932 .60771 .62943 .61947 .62521 .61344 .61569 Mtetra
.656 .665 .847 r
.61344 .61569 .61947 .62521 .63129 .62115 .6253 .61219 Mtetra
.656 .678 .859 r
.6253 .61219 .63129 .62115 .64316 .61732 .63721 .60874 Mtetra
.656 .687 .868 r
.63721 .60874 .64316 .61732 .65508 .6137 .64917 .60531 Mtetra
.656 .693 .873 r
.64917 .60531 .65508 .6137 .66706 .61029 .66118 .60188 Mtetra
.655 .693 .873 r
.66118 .60188 .66706 .61029 .67911 .60709 .67324 .59845 Mtetra
.655 .688 .869 r
.67324 .59845 .67911 .60709 .69122 .60411 .68536 .59503 Mtetra
.652 .677 .861 r
.68536 .59503 .69122 .60411 .70339 .60136 .69753 .59166 Mtetra
.648 .662 .85 r
.69753 .59166 .70339 .60136 .71564 .59879 .70976 .58842 Mtetra
.64 .646 .84 r
.70976 .58842 .71564 .59879 .72794 .59625 .72206 .58542 Mtetra
.63 .634 .835 r
.72206 .58542 .72794 .59625 .7403 .59347 .73445 .58283 Mtetra
.619 .633 .842 r
.73445 .58283 .7403 .59347 .75267 .59009 .74692 .58067 Mtetra
.612 .655 .868 r
.74692 .58067 .75267 .59009 .76503 .5858 .75948 .57873 Mtetra
.615 .72 .921 r
.75948 .57873 .76503 .5858 .77737 .58059 .77207 .5764 Mtetra
.626 .831 .979 r
.77207 .5764 .77737 .58059 .78972 .57479 .78464 .57293 Mtetra
.63 .923 .975 r
.78464 .57293 .78972 .57479 .8021 .56899 .79715 .56793 Mtetra
.651 .953 .946 r
.79715 .56793 .8021 .56899 .81455 .5636 .80961 .56179 Mtetra
.696 .946 .959 r
.80961 .56179 .81455 .5636 .8271 .55879 .82208 .55541 Mtetra
.709 .893 .964 r
.82208 .55541 .8271 .55879 .83974 .55449 .83464 .54958 Mtetra
.693 .83 .949 r
.83464 .54958 .83974 .55449 .85248 .55054 .84732 .54457 Mtetra
.674 .786 .933 r
.84732 .54457 .85248 .55054 .86528 .54676 .86012 .54023 Mtetra
.663 .763 .925 r
.86012 .54023 .86528 .54676 .87815 .54305 .873 .53628 Mtetra
.658 .755 .921 r
.873 .53628 .87815 .54305 .89107 .53934 .88597 .53249 Mtetra
.656 .752 .921 r
.88597 .53249 .89107 .53934 .90406 .53563 .89899 .52873 Mtetra
.656 .751 .92 r
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52497 Mtetra
.91208 .52497 .9171 .5319 .9302 .52815 .92522 .52119 Mtetra
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Mtetra
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Mtetra
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Mtetra
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Mtetra
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Mtetra
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Mtetra
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Mtetra
.655 .751 .921 r
.41291 .66076 .41941 .66663 .43044 .66346 .42397 .65759 Mtetra
.652 .751 .923 r
.42397 .65759 .43044 .66346 .44152 .66028 .43507 .65449 Mtetra
.64 .751 .929 r
.43507 .65449 .44152 .66028 .45264 .65715 .44622 .65167 Mtetra
.61 .754 .947 r
.44622 .65167 .45264 .65715 .46381 .65416 .4574 .64947 Mtetra
.542 .762 .979 r
.4574 .64947 .46381 .65416 .47502 .65155 .46861 .64825 Mtetra
.407 .763 .995 r
.46861 .64825 .47502 .65155 .48627 .6496 .47988 .64789 Mtetra
.263 .741 .934 r
.47988 .64789 .48627 .6496 .49757 .64845 .49121 .64753 Mtetra
.334 .801 .927 r
.49121 .64753 .49757 .64845 .50893 .64782 .50262 .64585 Mtetra
.598 .89 .99 r
.50262 .64585 .50893 .64782 .52035 .64698 .51409 .64223 Mtetra
.709 .811 .928 r
.51409 .64223 .52035 .64698 .53183 .64504 .52561 .63725 Mtetra
.704 .718 .86 r
.52561 .63725 .53183 .64504 .54337 .64162 .53716 .63208 Mtetra
.683 .673 .834 r
.53716 .63208 .54337 .64162 .55494 .63709 .54875 .62744 Mtetra
.669 .666 .838 r
.54875 .62744 .55494 .63709 .56654 .63219 .56039 .6234 Mtetra
.664 .683 .858 r
.56039 .6234 .56654 .63219 .57819 .62749 .57208 .61967 Mtetra
.664 .707 .88 r
.57208 .61967 .57819 .62749 .58989 .62321 .58382 .61603 Mtetra
.665 .726 .895 r
.58382 .61603 .58989 .62321 .60164 .61932 .59561 .61237 Mtetra
.664 .733 .901 r
.59561 .61237 .60164 .61932 .61344 .61569 .60744 .60871 Mtetra
.663 .733 .901 r
.60744 .60871 .61344 .61569 .6253 .61219 .61933 .60507 Mtetra
.661 .729 .9 r
.61933 .60507 .6253 .61219 .63721 .60874 .63126 .60148 Mtetra
.659 .725 .898 r
.63126 .60148 .63721 .60874 .64917 .60531 .64325 .59796 Mtetra
.657 .722 .897 r
.64325 .59796 .64917 .60531 .66118 .60188 .65529 .59449 Mtetra
.654 .721 .898 r
.65529 .59449 .66118 .60188 .67324 .59845 .66739 .5911 Mtetra
.652 .722 .9 r
.66739 .5911 .67324 .59845 .68536 .59503 .67954 .58777 Mtetra
.65 .725 .904 r
.67954 .58777 .68536 .59503 .69753 .59166 .69175 .58449 Mtetra
.648 .727 .907 r
.69175 .58449 .69753 .59166 .70976 .58842 .70402 .58124 Mtetra
.648 .728 .908 r
.70402 .58124 .70976 .58842 .72206 .58542 .71634 .57798 Mtetra
.648 .722 .902 r
.71634 .57798 .72206 .58542 .73445 .58283 .72872 .5747 Mtetra
.646 .702 .888 r
.72872 .5747 .73445 .58283 .74692 .58067 .74116 .5715 Mtetra
.637 .674 .868 r
.74116 .5715 .74692 .58067 .75948 .57873 .75368 .56861 Mtetra
.621 .646 .854 r
.75368 .56861 .75948 .57873 .77207 .5764 .7663 .56633 Mtetra
.606 .641 .859 r
.7663 .56633 .77207 .5764 .78464 .57293 .77903 .56459 Mtetra
.606 .683 .896 r
.77903 .56459 .78464 .57293 .79715 .56793 .79182 .56266 Mtetra
.634 .795 .96 r
.79182 .56266 .79715 .56793 .80961 .56179 .80456 .55932 Mtetra
.666 .916 .976 r
.80456 .55932 .80961 .56179 .82208 .55541 .81718 .55397 Mtetra
.692 .957 .949 r
.81718 .55397 .82208 .55541 .83464 .54958 .82973 .54726 Mtetra
.721 .938 .957 r
.82973 .54726 .83464 .54958 .84732 .54457 .84231 .54053 Mtetra
.713 .872 .956 r
.84231 .54053 .84732 .54457 .86012 .54023 .85501 .53469 Mtetra
.687 .808 .94 r
.85501 .53469 .86012 .54023 .873 .53628 .86786 .52986 Mtetra
.668 .772 .928 r
.86786 .52986 .873 .53628 .88597 .53249 .88083 .52569 Mtetra
.659 .757 .922 r
.88083 .52569 .88597 .53249 .89899 .52873 .89389 .5218 Mtetra
.656 .753 .921 r
.89389 .5218 .89899 .52873 .91208 .52497 .90701 .51798 Mtetra
.656 .752 .92 r
.90701 .51798 .91208 .52497 .92522 .52119 .9202 .51416 Mtetra
.656 .751 .92 r
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Mtetra
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Mtetra
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Mtetra
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Mtetra
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Mtetra
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Mtetra
.655 .751 .921 r
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65488 Mtetra
.65 .751 .923 r
.40635 .65488 .41291 .66076 .42397 .65759 .41744 .65182 Mtetra
.633 .751 .933 r
.41744 .65182 .42397 .65759 .43507 .65449 .42856 .64915 Mtetra
.588 .753 .957 r
.42856 .64915 .43507 .65449 .44622 .65167 .43971 .64736 Mtetra
.48 .755 .991 r
.43971 .64736 .44622 .65167 .4574 .64947 .45089 .6468 Mtetra
.297 .731 .968 r
.45089 .6468 .4574 .64947 .46861 .64825 .46212 .64695 Mtetra
.25 .743 .913 r
.46212 .64695 .46861 .64825 .47988 .64789 .47343 .6463 Mtetra
.518 .874 .986 r
.47343 .6463 .47988 .64789 .49121 .64753 .48483 .64345 Mtetra
.705 .834 .944 r
.48483 .64345 .49121 .64753 .50262 .64585 .49629 .63857 Mtetra
.713 .733 .867 r
.49629 .63857 .50262 .64585 .51409 .64223 .5078 .63313 Mtetra
.69 .684 .839 r
.5078 .63313 .51409 .64223 .52561 .63725 .51934 .62825 Mtetra
.677 .682 .848 r
.51934 .62825 .52561 .63725 .53716 .63208 .53092 .62398 Mtetra
.674 .703 .869 r
.53092 .62398 .53716 .63208 .54875 .62744 .54255 .61996 Mtetra
.674 .719 .883 r
.54255 .61996 .54875 .62744 .56039 .6234 .55422 .61598 Mtetra
.671 .721 .887 r
.55422 .61598 .56039 .6234 .57208 .61967 .56594 .61208 Mtetra
.667 .716 .885 r
.56594 .61208 .57208 .61967 .58382 .61603 .5777 .60832 Mtetra
.662 .712 .885 r
.5777 .60832 .58382 .61603 .59561 .61237 .58952 .6047 Mtetra
.659 .712 .887 r
.58952 .6047 .59561 .61237 .60744 .60871 .60138 .60117 Mtetra
.657 .716 .892 r
.60138 .60117 .60744 .60871 .61933 .60507 .6133 .5977 Mtetra
.657 .722 .897 r
.6133 .5977 .61933 .60507 .63126 .60148 .62527 .59424 Mtetra
.656 .726 .9 r
.62527 .59424 .63126 .60148 .64325 .59796 .6373 .59077 Mtetra
.656 .729 .902 r
.6373 .59077 .64325 .59796 .65529 .59449 .64937 .58729 Mtetra
.656 .729 .903 r
.64937 .58729 .65529 .59449 .66739 .5911 .6615 .58379 Mtetra
.656 .726 .901 r
.6615 .58379 .66739 .5911 .67954 .58777 .67368 .58027 Mtetra
.656 .722 .897 r
.67368 .58027 .67954 .58777 .69175 .58449 .68591 .57677 Mtetra
.654 .716 .894 r
.68591 .57677 .69175 .58449 .70402 .58124 .6982 .57331 Mtetra
.651 .709 .89 r
.6982 .57331 .70402 .58124 .71634 .57798 .71055 .56994 Mtetra
.646 .705 .89 r
.71055 .56994 .71634 .57798 .72872 .5747 .72296 .56673 Mtetra
.641 .706 .894 r
.72296 .56673 .72872 .5747 .74116 .5715 .73545 .56366 Mtetra
.638 .709 .898 r
.73545 .56366 .74116 .5715 .75368 .56861 .74799 .56066 Mtetra
.637 .706 .897 r
.74799 .56066 .75368 .56861 .7663 .56633 .7606 .55771 Mtetra
.63 .687 .885 r
.7606 .55771 .7663 .56633 .77903 .56459 .77329 .555 Mtetra
.613 .657 .869 r
.77329 .555 .77903 .56459 .79182 .56266 .7861 .55292 Mtetra
.597 .647 .87 r
.7861 .55292 .79182 .56266 .80456 .55932 .79901 .5514 Mtetra
.607 .699 .908 r
.79901 .5514 .80456 .55932 .81718 .55397 .81196 .54929 Mtetra
.658 .83 .966 r
.81196 .54929 .81718 .55397 .82973 .54726 .82478 .54509 Mtetra
.704 .94 .961 r
.82478 .54509 .82973 .54726 .84231 .54053 .83745 .53859 Mtetra
.731 .954 .947 r
.83745 .53859 .84231 .54053 .85501 .53469 .85007 .53125 Mtetra
.731 .903 .955 r
.85007 .53125 .85501 .53469 .86786 .52986 .86281 .52467 Mtetra
.699 .828 .944 r
.86281 .52467 .86786 .52986 .88083 .52569 .87571 .51935 Mtetra
.673 .779 .93 r
.87571 .51935 .88083 .52569 .89389 .5218 .88876 .51496 Mtetra
.661 .759 .923 r
.88876 .51496 .89389 .5218 .90701 .51798 .90191 .51097 Mtetra
.657 .753 .921 r
.90191 .51097 .90701 .51798 .9202 .51416 .91514 .50709 Mtetra
.656 .752 .92 r
.91514 .50709 .9202 .51416 .93344 .51034 .92842 .50323 Mtetra
.656 .751 .92 r
.92842 .50323 .93344 .51034 .94675 .50649 .94177 .49935 Mtetra
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Mtetra
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Mtetra
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65535 Mtetra
.655 .751 .921 r
.37765 .65535 .38431 .66125 .39531 .65806 .38868 .65216 Mtetra
.649 .751 .924 r
.38868 .65216 .39531 .65806 .40635 .65488 .39975 .64911 Mtetra
.629 .75 .935 r
.39975 .64911 .40635 .65488 .41744 .65182 .41084 .64653 Mtetra
.57 .75 .962 r
.41084 .64653 .41744 .65182 .42856 .64915 .42196 .64504 Mtetra
.426 .741 .992 r
.42196 .64504 .42856 .64915 .43971 .64736 .43309 .64498 Mtetra
.224 .699 .939 r
.43309 .64498 .43971 .64736 .45089 .6468 .44428 .64547 Mtetra
.298 .772 .932 r
.44428 .64547 .45089 .6468 .46212 .64695 .45557 .64446 Mtetra
.627 .878 .988 r
.45557 .64446 .46212 .64695 .47343 .6463 .46697 .64072 Mtetra
.723 .784 .901 r
.46697 .64072 .47343 .6463 .48483 .64345 .47844 .63521 Mtetra
.708 .709 .848 r
.47844 .63521 .48483 .64345 .49629 .63857 .48994 .62971 Mtetra
.69 .69 .845 r
.48994 .62971 .49629 .63857 .5078 .63313 .50147 .62488 Mtetra
.683 .702 .861 r
.50147 .62488 .5078 .63313 .51934 .62825 .51304 .62047 Mtetra
.678 .713 .875 r
.51304 .62047 .51934 .62825 .53092 .62398 .52464 .61631 Mtetra
.671 .714 .881 r
.52464 .61631 .53092 .62398 .54255 .61996 .5363 .61242 Mtetra
.663 .716 .888 r
.5363 .61242 .54255 .61996 .55422 .61598 .548 .60878 Mtetra
.66 .725 .898 r
.548 .60878 .55422 .61598 .56594 .61208 .55975 .60527 Mtetra
.659 .737 .908 r
.55975 .60527 .56594 .61208 .5777 .60832 .57155 .60176 Mtetra
.659 .746 .914 r
.57155 .60176 .5777 .60832 .58952 .6047 .5834 .59821 Mtetra
.66 .749 .916 r
.5834 .59821 .58952 .6047 .60138 .60117 .5953 .59461 Mtetra
.66 .748 .915 r
.5953 .59461 .60138 .60117 .6133 .5977 .60725 .59101 Mtetra
.659 .744 .913 r
.60725 .59101 .6133 .5977 .62527 .59424 .61926 .58743 Mtetra
.658 .741 .911 r
.61926 .58743 .62527 .59424 .6373 .59077 .63131 .58388 Mtetra
.656 .739 .911 r
.63131 .58388 .6373 .59077 .64937 .58729 .64342 .58037 Mtetra
.654 .738 .911 r
.64342 .58037 .64937 .58729 .6615 .58379 .65558 .57689 Mtetra
.653 .739 .913 r
.65558 .57689 .6615 .58379 .67368 .58027 .6678 .57344 Mtetra
.651 .742 .916 r
.6678 .57344 .67368 .58027 .68591 .57677 .68007 .57001 Mtetra
.651 .745 .918 r
.68007 .57001 .68591 .57677 .6982 .57331 .6924 .56658 Mtetra
.651 .747 .92 r
.6924 .56658 .6982 .57331 .71055 .56994 .70478 .56312 Mtetra
.653 .745 .917 r
.70478 .56312 .71055 .56994 .72296 .56673 .71722 .55959 Mtetra
.653 .736 .911 r
.71722 .55959 .72296 .56673 .73545 .56366 .72971 .55607 Mtetra
.649 .723 .902 r
.72971 .55607 .73545 .56366 .74799 .56066 .74227 .55266 Mtetra
.642 .709 .896 r
.74227 .55266 .74799 .56066 .7606 .55771 .7549 .54951 Mtetra
.633 .701 .895 r
.7549 .54951 .7606 .55771 .77329 .555 .76761 .54665 Mtetra
.625 .694 .894 r
.76761 .54665 .77329 .555 .7861 .55292 .7804 .54403 Mtetra
.613 .676 .886 r
.7804 .54403 .7861 .55292 .79901 .5514 .7933 .54184 Mtetra
.595 .652 .876 r
.7933 .54184 .79901 .5514 .81196 .54929 .80632 .54032 Mtetra
.592 .666 .89 r
.80632 .54032 .81196 .54929 .82478 .54509 .81942 .5388 Mtetra
.638 .767 .941 r
.81942 .5388 .82478 .54509 .83745 .53859 .83243 .53544 Mtetra
.711 .909 .964 r
.83243 .53544 .83745 .53859 .85007 .53125 .84522 .52923 Mtetra
.746 .957 .941 r
.84522 .52923 .85007 .53125 .86281 .52467 .85791 .52148 Mtetra
.746 .918 .95 r
.85791 .52148 .86281 .52467 .87571 .51935 .87068 .5143 Mtetra
.709 .84 .945 r
.87068 .5143 .87571 .51935 .88876 .51496 .88364 .50861 Mtetra
.676 .783 .93 r
.88364 .50861 .88876 .51496 .90191 .51097 .89678 .50405 Mtetra
.661 .76 .923 r
.89678 .50405 .90191 .51097 .91514 .50709 .91003 .49999 Mtetra
.657 .753 .921 r
.91003 .49999 .91514 .50709 .92842 .50323 .92336 .49606 Mtetra
.656 .752 .92 r
.92336 .49606 .92842 .50323 .94177 .49935 .93676 .49214 Mtetra
.656 .751 .92 r
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Mtetra
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Mtetra
.655 .751 .921 r
.35993 .65262 .36667 .65855 .37765 .65535 .37094 .64942 Mtetra
.65 .751 .923 r
.37094 .64942 .37765 .65535 .38868 .65216 .38199 .64634 Mtetra
.629 .749 .934 r
.38199 .64634 .38868 .65216 .39975 .64911 .39307 .64376 Mtetra
.563 .747 .963 r
.39307 .64376 .39975 .64911 .41084 .64653 .40415 .64239 Mtetra
.395 .726 .99 r
.40415 .64239 .41084 .64653 .42196 .64504 .41524 .64266 Mtetra
.177 .67 .92 r
.41524 .64266 .42196 .64504 .43309 .64498 .42639 .64348 Mtetra
.321 .781 .946 r
.42639 .64348 .43309 .64498 .44428 .64547 .43765 .64243 Mtetra
.665 .866 .976 r
.43765 .64243 .44428 .64547 .45557 .64446 .44905 .63825 Mtetra
.729 .766 .882 r
.44905 .63825 .45557 .64446 .46697 .64072 .46052 .63234 Mtetra
.712 .707 .844 r
.46052 .63234 .46697 .64072 .47844 .63521 .47201 .62662 Mtetra
.696 .698 .848 r
.47201 .62662 .47844 .63521 .48994 .62971 .48353 .62159 Mtetra
.685 .706 .864 r
.48353 .62159 .48994 .62971 .50147 .62488 .49509 .61711 Mtetra
.674 .712 .877 r
.49509 .61711 .50147 .62488 .51304 .62047 .50668 .6131 Mtetra
.666 .722 .89 r
.50668 .6131 .51304 .62047 .52464 .61631 .51832 .60937 Mtetra
.665 .734 .902 r
.51832 .60937 .52464 .61631 .5363 .61242 .53 .60569 Mtetra
.666 .742 .906 r
.53 .60569 .5363 .61242 .548 .60878 .54174 .60194 Mtetra
.666 .739 .904 r
.54174 .60194 .548 .60878 .55975 .60527 .55352 .59818 Mtetra
.664 .732 .9 r
.55352 .59818 .55975 .60527 .57155 .60176 .56535 .59449 Mtetra
.661 .726 .898 r
.56535 .59449 .57155 .60176 .5834 .59821 .57723 .59089 Mtetra
.658 .725 .899 r
.57723 .59089 .5834 .59821 .5953 .59461 .58916 .58735 Mtetra
.657 .727 .901 r
.58916 .58735 .5953 .59461 .60725 .59101 .60115 .58384 Mtetra
.656 .73 .904 r
.60115 .58384 .60725 .59101 .61926 .58743 .61318 .58034 Mtetra
.656 .733 .907 r
.61318 .58034 .61926 .58743 .63131 .58388 .62527 .57682 Mtetra
.656 .735 .908 r
.62527 .57682 .63131 .58388 .64342 .58037 .63742 .57328 Mtetra
.63742 .57328 .64342 .58037 .65558 .57689 .64961 .56972 Mtetra
.656 .734 .907 r
.64961 .56972 .65558 .57689 .6678 .57344 .66186 .56614 Mtetra
.656 .73 .904 r
.66186 .56614 .6678 .57344 .68007 .57001 .67416 .56256 Mtetra
.655 .727 .902 r
.67416 .56256 .68007 .57001 .6924 .56658 .68652 .55901 Mtetra
.652 .723 .901 r
.68652 .55901 .6924 .56658 .70478 .56312 .69893 .55552 Mtetra
.649 .722 .902 r
.69893 .55552 .70478 .56312 .71722 .55959 .71141 .55213 Mtetra
.646 .726 .907 r
.71141 .55213 .71722 .55959 .72971 .55607 .72395 .5488 Mtetra
.646 .732 .912 r
.72395 .5488 .72971 .55607 .74227 .55266 .73655 .54547 Mtetra
.647 .736 .914 r
.73655 .54547 .74227 .55266 .7549 .54951 .7492 .54207 Mtetra
.646 .729 .909 r
.7492 .54207 .7549 .54951 .76761 .54665 .76192 .5387 Mtetra
.637 .712 .901 r
.76192 .5387 .76761 .54665 .7804 .54403 .77471 .53562 Mtetra
.624 .694 .895 r
.77471 .53562 .7804 .54403 .7933 .54184 .78761 .53301 Mtetra
.607 .677 .89 r
.78761 .53301 .7933 .54184 .80632 .54032 .80062 .53096 Mtetra
.587 .655 .884 r
.80062 .53096 .80632 .54032 .81942 .5388 .81377 .52962 Mtetra
.58 .657 .889 r
.81377 .52962 .81942 .5388 .83243 .53544 .827 .52845 Mtetra
.627 .741 .929 r
.827 .52845 .83243 .53544 .84522 .52923 .84015 .52547 Mtetra
.718 .891 .959 r
.84015 .52547 .84522 .52923 .85791 .52148 .85305 .51924 Mtetra
.763 .955 .936 r
.85305 .51924 .85791 .52148 .87068 .5143 .86579 .51105 Mtetra
.758 .921 .944 r
.86579 .51105 .87068 .5143 .88364 .50861 .87862 .50345 Mtetra
.714 .84 .942 r
.87862 .50345 .88364 .50861 .89678 .50405 .89167 .49757 Mtetra
.676 .782 .929 r
.89167 .49757 .89678 .50405 .91003 .49999 .9049 .49295 Mtetra
.661 .759 .923 r
.9049 .49295 .91003 .49999 .92336 .49606 .91826 .48886 Mtetra
.657 .753 .921 r
.91826 .48886 .92336 .49606 .93676 .49214 .9317 .48488 Mtetra
.656 .752 .92 r
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Mtetra
.655 .751 .921 r
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64667 Mtetra
.651 .751 .923 r
.35314 .64667 .35993 .65262 .37094 .64942 .36418 .64353 Mtetra
.633 .749 .932 r
.36418 .64353 .37094 .64942 .38199 .64634 .37524 .64084 Mtetra
.571 .745 .959 r
.37524 .64084 .38199 .64634 .39307 .64376 .3863 .63936 Mtetra
.397 .718 .988 r
.3863 .63936 .39307 .64376 .40415 .64239 .39735 .63974 Mtetra
.141 .639 .91 r
.39735 .63974 .40415 .64239 .41524 .64266 .40843 .64103 Mtetra
.28 .754 .936 r
.40843 .64103 .41524 .64266 .42639 .64348 .41966 .64041 Mtetra
.666 .864 .975 r
.41966 .64041 .42639 .64348 .43765 .64243 .43104 .63621 Mtetra
.737 .767 .877 r
.43104 .63621 .43765 .64243 .44905 .63825 .44252 .62994 Mtetra
.72 .711 .841 r
.44252 .62994 .44905 .63825 .46052 .63234 .45402 .6238 Mtetra
.701 .701 .847 r
.45402 .6238 .46052 .63234 .47201 .62662 .46554 .61853 Mtetra
.685 .708 .865 r
.46554 .61853 .47201 .62662 .48353 .62159 .47708 .61404 Mtetra
.674 .719 .883 r
.47708 .61404 .48353 .62159 .49509 .61711 .48866 .61003 Mtetra
.671 .732 .895 r
.48866 .61003 .49509 .61711 .50668 .6131 .50028 .60613 Mtetra
.67 .735 .899 r
.50028 .60613 .50668 .6131 .51832 .60937 .51195 .60227 Mtetra
.665 .731 .899 r
.51195 .60227 .51832 .60937 .53 .60569 .52366 .59854 Mtetra
.66 .729 .9 r
.52366 .59854 .53 .60569 .54174 .60194 .53543 .59497 Mtetra
.657 .734 .906 r
.53543 .59497 .54174 .60194 .55352 .59818 .54724 .59148 Mtetra
.656 .743 .914 r
.54724 .59148 .55352 .59818 .56535 .59449 .55911 .58799 Mtetra
.657 .75 .919 r
.55911 .58799 .56535 .59449 .57723 .59089 .57102 .58444 Mtetra
.658 .753 .92 r
.57102 .58444 .57723 .59089 .58916 .58735 .58299 .58085 Mtetra
.658 .752 .919 r
.58299 .58085 .58916 .58735 .60115 .58384 .59501 .57723 Mtetra
.658 .749 .918 r
.59501 .57723 .60115 .58384 .61318 .58034 .60708 .57362 Mtetra
.657 .747 .916 r
.60708 .57362 .61318 .58034 .62527 .57682 .6192 .57003 Mtetra
.656 .745 .916 r
.6192 .57003 .62527 .57682 .63742 .57328 .63138 .56646 Mtetra
.654 .744 .916 r
.63138 .56646 .63742 .57328 .64961 .56972 .64361 .56291 Mtetra
.653 .745 .917 r
.64361 .56291 .64961 .56972 .66186 .56614 .65589 .55939 Mtetra
.652 .748 .92 r
.65589 .55939 .66186 .56614 .67416 .56256 .66824 .55586 Mtetra
.652 .75 .922 r
.66824 .55586 .67416 .56256 .68652 .55901 .68063 .55232 Mtetra
.653 .752 .922 r
.68063 .55232 .68652 .55901 .69893 .55552 .69308 .54873 Mtetra
.655 .75 .92 r
.69308 .54873 .69893 .55552 .71141 .55213 .70559 .54508 Mtetra
.655 .743 .915 r
.70559 .54508 .71141 .55213 .72395 .5488 .71814 .54142 Mtetra
.652 .733 .909 r
.71814 .54142 .72395 .5488 .73655 .54547 .73077 .53784 Mtetra
.647 .725 .905 r
.73077 .53784 .73655 .54547 .7492 .54207 .74346 .53443 Mtetra
.643 .724 .907 r
.74346 .53443 .7492 .54207 .76192 .5387 .75621 .53114 Mtetra
.641 .726 .91 r
.75621 .53114 .76192 .5387 .77471 .53562 .76904 .52789 Mtetra
.637 .72 .908 r
.76904 .52789 .77471 .53562 .78761 .53301 .78193 .52475 Mtetra
.623 .701 .901 r
.78193 .52475 .78761 .53301 .80062 .53096 .79493 .5221 Mtetra
.6 .675 .894 r
.79493 .5221 .80062 .53096 .81377 .52962 .80806 .52024 Mtetra
.574 .651 .888 r
.80806 .52024 .81377 .52962 .827 .52845 .82135 .51927 Mtetra
.568 .654 .894 r
.82135 .51927 .827 .52845 .84015 .52547 .83473 .51841 Mtetra
.627 .742 .93 r
.83473 .51841 .84015 .52547 .85305 .51924 .84799 .51538 Mtetra
.735 .894 .951 r
.84799 .51538 .85305 .51924 .86579 .51105 .86093 .50862 Mtetra
.782 .953 .928 r
.86093 .50862 .86579 .51105 .87862 .50345 .87371 .49988 Mtetra
.764 .913 .939 r
.87371 .49988 .87862 .50345 .89167 .49757 .88662 .49208 Mtetra
.711 .83 .939 r
.88662 .49208 .89167 .49757 .9049 .49295 .89977 .48625 Mtetra
.673 .776 .927 r
.89977 .48625 .9049 .49295 .91826 .48886 .91313 .48168 Mtetra
.66 .757 .922 r
.91313 .48168 .91826 .48886 .9317 .48488 .9266 .47758 Mtetra
.656 .752 .921 r
.9266 .47758 .9317 .48488 .9452 .48092 .94014 .47356 Mtetra
.653 .751 .922 r
.33528 .64391 .34215 .64989 .35314 .64667 .3463 .64071 Mtetra
.64 .75 .928 r
.3463 .64071 .35314 .64667 .36418 .64353 .35735 .63784 Mtetra
.59 .745 .95 r
.35735 .63784 .36418 .64353 .37524 .64084 .36839 .63603 Mtetra
.432 .719 .985 r
.36839 .63603 .37524 .64084 .3863 .63936 .37941 .63622 Mtetra
.13 .617 .915 r
.37941 .63622 .3863 .63936 .39735 .63974 .39044 .63797 Mtetra
.167 .68 .896 r
.39044 .63797 .39735 .63974 .40843 .64103 .40159 .63831 Mtetra
.628 .87 .988 r
.40159 .63831 .40843 .64103 .41966 .64041 .41295 .63465 Mtetra
.747 .783 .882 r
.41295 .63465 .41966 .64041 .43104 .63621 .42444 .6281 Mtetra
.732 .719 .839 r
.42444 .6281 .43104 .63621 .44252 .62994 .43595 .62137 Mtetra
.709 .704 .843 r
.43595 .62137 .44252 .62994 .45402 .6238 .44747 .61572 Mtetra
.69 .71 .864 r
.44747 .61572 .45402 .6238 .46554 .61853 .45901 .61104 Mtetra
.679 .723 .883 r
.45901 .61104 .46554 .61853 .47708 .61404 .47057 .60686 Mtetra
.673 .73 .893 r
.47057 .60686 .47708 .61404 .48866 .61003 .48218 .60288 Mtetra
.666 .73 .897 r
.48218 .60288 .48866 .61003 .50028 .60613 .49383 .59912 Mtetra
.661 .733 .903 r
.49383 .59912 .50028 .60613 .51195 .60227 .50553 .59551 Mtetra
.661 .741 .91 r
.50553 .59551 .51195 .60227 .52366 .59854 .51727 .5919 Mtetra
.663 .747 .912 r
.51727 .5919 .52366 .59854 .53543 .59497 .52907 .58821 Mtetra
.664 .744 .91 r
.52907 .58821 .53543 .59497 .54724 .59148 .54092 .58448 Mtetra
.662 .737 .905 r
.54092 .58448 .54724 .59148 .55911 .58799 .55281 .58078 Mtetra
.659 .731 .903 r
.55281 .58078 .55911 .58799 .57102 .58444 .56476 .57716 Mtetra
.657 .729 .902 r
.56476 .57716 .57102 .58444 .58299 .58085 .57676 .57359 Mtetra
.656 .73 .904 r
.57676 .57359 .58299 .58085 .59501 .57723 .58881 .57004 Mtetra
.655 .733 .906 r
.58881 .57004 .59501 .57723 .60708 .57362 .60091 .56649 Mtetra
.656 .736 .908 r
.60091 .56649 .60708 .57362 .6192 .57003 .61307 .56293 Mtetra
.656 .737 .91 r
.61307 .56293 .6192 .57003 .63138 .56646 .62528 .55933 Mtetra
.656 .737 .909 r
.62528 .55933 .63138 .56646 .64361 .56291 .63755 .5557 Mtetra
.657 .736 .908 r
.63755 .5557 .64361 .56291 .65589 .55939 .64986 .55206 Mtetra
.656 .733 .906 r
.64986 .55206 .65589 .55939 .66824 .55586 .66223 .54841 Mtetra
.655 .73 .905 r
.66223 .54841 .66824 .55586 .68063 .55232 .67466 .54478 Mtetra
.653 .728 .904 r
.67466 .54478 .68063 .55232 .69308 .54873 .68715 .5412 Mtetra
.65 .728 .906 r
.68715 .5412 .69308 .54873 .70559 .54508 .6997 .5377 Mtetra
.648 .732 .91 r
.6997 .5377 .70559 .54508 .71814 .54142 .71231 .53423 Mtetra
.649 .739 .915 r
.71231 .53423 .71814 .54142 .73077 .53784 .72497 .53073 Mtetra
.651 .743 .917 r
.72497 .53073 .73077 .53784 .74346 .53443 .73769 .52713 Mtetra
.651 .739 .914 r
.73769 .52713 .74346 .53443 .75621 .53114 .75047 .52353 Mtetra
.646 .728 .909 r
.75047 .52353 .75621 .53114 .76904 .52789 .76331 .52009 Mtetra
.639 .721 .907 r
.76331 .52009 .76904 .52789 .78193 .52475 .77624 .51686 Mtetra
.632 .717 .908 r
.77624 .51686 .78193 .52475 .79493 .5221 .78925 .51385 Mtetra
.617 .701 .904 r
.78925 .51385 .79493 .5221 .80806 .52024 .80236 .51133 Mtetra
.587 .67 .897 r
.80236 .51133 .80806 .52024 .82135 .51927 .81563 .5098 Mtetra
.555 .642 .891 r
.81563 .5098 .82135 .51927 .83473 .51841 .82909 .50937 Mtetra
.558 .654 .9 r
.82909 .50937 .83473 .51841 .84799 .51538 .84261 .50874 Mtetra
.645 .766 .936 r
.84261 .50874 .84799 .51538 .86093 .50862 .85592 .50507 Mtetra
.765 .914 .939 r
.85592 .50507 .86093 .50862 .87371 .49988 .86886 .49722 Mtetra
.798 .95 .919 r
.86886 .49722 .87371 .49988 .88662 .49208 .88167 .48792 Mtetra
.762 .894 .937 r
.88167 .48792 .88662 .49208 .89977 .48625 .89469 .48025 Mtetra
.702 .812 .934 r
.89469 .48025 .89977 .48625 .91313 .48168 .90798 .47469 Mtetra
.668 .768 .925 r
.90798 .47469 .91313 .48168 .9266 .47758 .92146 .47025 Mtetra
.658 .754 .921 r
.92146 .47025 .9266 .47758 .94014 .47356 .93504 .46616 Mtetra
.648 .751 .925 r
.32836 .63793 .33528 .64391 .3463 .64071 .3394 .63483 Mtetra
.613 .746 .94 r
.3394 .63483 .3463 .64071 .35735 .63784 .35044 .63255 Mtetra
.493 .727 .976 r
.35044 .63255 .35735 .63784 .36839 .63603 .36145 .63218 Mtetra
.178 .624 .94 r
.36145 .63218 .36839 .63603 .37941 .63622 .37242 .63408 Mtetra
.02 .569 .832 r
.37242 .63408 .37941 .63622 .39044 .63797 .38348 .63577 Mtetra
.505 .849 .995 r
.38348 .63577 .39044 .63797 .40159 .63831 .39476 .63347 Mtetra
.75 .812 .902 r
.39476 .63347 .40159 .63831 .41295 .63465 .40625 .627 Mtetra
.749 .734 .838 r
.40625 .627 .41295 .63465 .42444 .6281 .4178 .61952 Mtetra
.722 .708 .836 r
.4178 .61952 .42444 .6281 .43595 .62137 .42933 .61318 Mtetra
.698 .71 .858 r
.42933 .61318 .43595 .62137 .44747 .61572 .44087 .60811 Mtetra
.683 .721 .879 r
.44087 .60811 .44747 .61572 .45901 .61104 .45242 .60375 Mtetra
.673 .728 .891 r
.45242 .60375 .45901 .61104 .47057 .60686 .46401 .59978 Mtetra
.666 .732 .899 r
.46401 .59978 .47057 .60686 .48218 .60288 .47565 .59601 Mtetra
.665 .739 .905 r
.47565 .59601 .48218 .60288 .49383 .59912 .48733 .59226 Mtetra
.665 .741 .906 r
.48733 .59226 .49383 .59912 .50553 .59551 .49906 .58849 Mtetra
.662 .736 .904 r
.49906 .58849 .50553 .59551 .51727 .5919 .51084 .58481 Mtetra
.657 .733 .905 r
.51084 .58481 .51727 .5919 .52907 .58821 .52266 .58126 Mtetra
.655 .737 .91 r
.52266 .58126 .52907 .58821 .54092 .58448 .53454 .57778 Mtetra
.654 .745 .917 r
.53454 .57778 .54092 .58448 .55281 .58078 .54647 .57428 Mtetra
.655 .753 .922 r
.54647 .57428 .55281 .58078 .56476 .57716 .55845 .57072 Mtetra
.657 .756 .923 r
.55845 .57072 .56476 .57716 .57676 .57359 .57049 .5671 Mtetra
.657 .756 .922 r
.57049 .5671 .57676 .57359 .58881 .57004 .58257 .56345 Mtetra
.657 .753 .921 r
.58257 .56345 .58881 .57004 .60091 .56649 .59471 .5598 Mtetra
.656 .75 .919 r
.59471 .5598 .60091 .56649 .61307 .56293 .6069 .55615 Mtetra
.655 .749 .919 r
.6069 .55615 .61307 .56293 .62528 .55933 .61915 .55253 Mtetra
.654 .748 .919 r
.61915 .55253 .62528 .55933 .63755 .5557 .63145 .54892 Mtetra
.653 .749 .92 r
.63145 .54892 .63755 .5557 .64986 .55206 .64381 .54532 Mtetra
.653 .752 .922 r
.64381 .54532 .64986 .55206 .66223 .54841 .65622 .54172 Mtetra
.653 .754 .924 r
.65622 .54172 .66223 .54841 .67466 .54478 .66869 .53809 Mtetra
.654 .756 .924 r
.66869 .53809 .67466 .54478 .68715 .5412 .68121 .5344 Mtetra
.656 .754 .922 r
.68121 .5344 .68715 .5412 .6997 .5377 .69378 .53063 Mtetra
.657 .747 .916 r
.69378 .53063 .6997 .5377 .71231 .53423 .70641 .52685 Mtetra
.654 .737 .911 r
.70641 .52685 .71231 .53423 .72497 .53073 .71911 .52314 Mtetra
.65 .731 .908 r
.71911 .52314 .72497 .53073 .73769 .52713 .73186 .51957 Mtetra
.647 .731 .91 r
.73186 .51957 .73769 .52713 .75047 .52353 .74469 .51608 Mtetra
.647 .735 .914 r
.74469 .51608 .75047 .52353 .76331 .52009 .75757 .51257 Mtetra
.646 .734 .913 r
.75757 .51257 .76331 .52009 .77624 .51686 .77052 .50907 Mtetra
.639 .724 .909 r
.77052 .50907 .77624 .51686 .78925 .51385 .78354 .50578 Mtetra
.627 .712 .907 r
.78354 .50578 .78925 .51385 .80236 .51133 .79666 .50288 Mtetra
.605 .692 .905 r
.79666 .50288 .80236 .51133 .81563 .5098 .80992 .5007 Mtetra
.565 .657 .898 r
.80992 .5007 .81563 .5098 .82909 .50937 .82336 .49982 Mtetra
.529 .629 .894 r
.82336 .49982 .82909 .50937 .84261 .50874 .837 .50011 Mtetra
.558 .668 .911 r
.837 .50011 .84261 .50874 .85592 .50507 .85063 .49931 Mtetra
.689 .816 .943 r
.85063 .49931 .85592 .50507 .86886 .49722 .86391 .49414 Mtetra
.802 .938 .919 r
.86391 .49414 .86886 .49722 .88167 .48792 .87679 .48481 Mtetra
.807 .939 .915 r
.87679 .48481 .88167 .48792 .89469 .48025 .88967 .47527 Mtetra
.746 .864 .934 r
.88967 .47527 .89469 .48025 .90798 .47469 .90284 .46813 Mtetra
.687 .791 .929 r
.90284 .46813 .90798 .47469 .92146 .47025 .91629 .463 Mtetra
.662 .76 .923 r
.91629 .463 .92146 .47025 .93504 .46616 .92991 .45873 Mtetra
.637 .752 .931 r
.32137 .63199 .32836 .63793 .3394 .63483 .33242 .62914 Mtetra
.557 .737 .96 r
.33242 .62914 .3394 .63483 .35044 .63255 .34344 .62788 Mtetra
.3 .663 .973 r
.34344 .62788 .35044 .63255 .36145 .63218 .35438 .6293 Mtetra
0 .486 .803 r
.35438 .6293 .36145 .63218 .37242 .63408 .36534 .63219 Mtetra
.221 .713 .921 r
.36534 .63219 .37242 .63408 .38348 .63577 .3765 .63219 Mtetra
.721 .854 .945 r
.3765 .63219 .38348 .63577 .39476 .63347 .38795 .62675 Mtetra
.769 .76 .844 r
.38795 .62675 .39476 .63347 .40625 .627 .39953 .61853 Mtetra
.742 .716 .827 r
.39953 .61853 .40625 .627 .4178 .61952 .41111 .61109 Mtetra
.711 .709 .847 r
.41111 .61109 .4178 .61952 .42933 .61318 .42266 .60535 Mtetra
.688 .718 .872 r
.42266 .60535 .42933 .61318 .44087 .60811 .43421 .60073 Mtetra
.675 .727 .889 r
.43421 .60073 .44087 .60811 .45242 .60375 .44578 .59665 Mtetra
.669 .733 .898 r
.44578 .59665 .45242 .60375 .46401 .59978 .4574 .59278 Mtetra
.667 .737 .902 r
.4574 .59278 .46401 .59978 .47565 .59601 .46907 .58897 Mtetra
.662 .735 .904 r
.46907 .58897 .47565 .59601 .48733 .59226 .48078 .58531 Mtetra
.657 .737 .908 r
.48078 .58531 .48733 .59226 .49906 .58849 .49254 .58176 Mtetra
.658 .744 .914 r
.49254 .58176 .49906 .58849 .51084 .58481 .50435 .57818 Mtetra
.661 .749 .916 r
.50435 .57818 .51084 .58481 .52266 .58126 .51621 .57448 Mtetra
.662 .746 .912 r
.51621 .57448 .52266 .58126 .53454 .57778 .52812 .57073 Mtetra
.661 .739 .907 r
.52812 .57073 .53454 .57778 .54647 .57428 .54008 .567 Mtetra
.659 .732 .904 r
.54008 .567 .54647 .57428 .55845 .57072 .55209 .56333 Mtetra
.657 .729 .903 r
.55209 .56333 .55845 .57072 .57049 .5671 .56416 .55972 Mtetra
.655 .73 .904 r
.56416 .55972 .57049 .5671 .58257 .56345 .57628 .55613 Mtetra
.655 .732 .906 r
.57628 .55613 .58257 .56345 .59471 .5598 .58845 .55254 Mtetra
.655 .735 .908 r
.58845 .55254 .59471 .5598 .6069 .55615 .60068 .54892 Mtetra
.656 .737 .909 r
.60068 .54892 .6069 .55615 .61915 .55253 .61296 .54527 Mtetra
.61296 .54527 .61915 .55253 .63145 .54892 .62529 .54158 Mtetra
.657 .736 .908 r
.62529 .54158 .63145 .54892 .64381 .54532 .63768 .53786 Mtetra
.656 .733 .906 r
.63768 .53786 .64381 .54532 .65622 .54172 .65012 .53414 Mtetra
.655 .73 .904 r
.65012 .53414 .65622 .54172 .66869 .53809 .66263 .53043 Mtetra
.653 .728 .904 r
.66263 .53043 .66869 .53809 .68121 .5344 .67518 .52679 Mtetra
.651 .729 .907 r
.67518 .52679 .68121 .5344 .69378 .53063 .68781 .52321 Mtetra
.649 .735 .912 r
.68781 .52321 .69378 .53063 .70641 .52685 .70049 .51965 Mtetra
.65 .743 .917 r
.70049 .51965 .70641 .52685 .71911 .52314 .71322 .51603 Mtetra
.653 .748 .919 r
.71322 .51603 .71911 .52314 .73186 .51957 .72601 .51229 Mtetra
.654 .744 .916 r
.72601 .51229 .73186 .51957 .74469 .51608 .73886 .50852 Mtetra
.65 .735 .911 r
.73886 .50852 .74469 .51608 .75757 .51257 .75177 .50486 Mtetra
.645 .73 .91 r
.75177 .50486 .75757 .51257 .77052 .50907 .76476 .50135 Mtetra
.643 .729 .911 r
.76476 .50135 .77052 .50907 .78354 .50578 .77781 .4979 Mtetra
.636 .723 .91 r
.77781 .4979 .78354 .50578 .79666 .50288 .79095 .49466 Mtetra
.619 .707 .908 r
.79095 .49466 .79666 .50288 .80992 .5007 .80419 .49196 Mtetra
.583 .677 .905 r
.80419 .49196 .80992 .5007 .82336 .49982 .81761 .49042 Mtetra
.529 .634 .899 r
.81761 .49042 .82336 .49982 .837 .50011 .83128 .49062 Mtetra
.502 .618 .899 r
.83128 .49062 .837 .50011 .85063 .49931 .84511 .49159 Mtetra
.588 .712 .929 r
.84511 .49159 .85063 .49931 .86391 .49414 .85876 .48963 Mtetra
.76 .883 .934 r
.85876 .48963 .86391 .49414 .87679 .48481 .87189 .48197 Mtetra
.831 .95 .897 r
.87189 .48197 .87679 .48481 .88967 .47527 .88472 .4713 Mtetra
.797 .912 .919 r
.88472 .4713 .88967 .47527 .90284 .46813 .89774 .46221 Mtetra
.72 .826 .931 r
.89774 .46221 .90284 .46813 .91629 .463 .91111 .45594 Mtetra
.67 .771 .926 r
.91111 .45594 .91629 .463 .92991 .45873 .92474 .45134 Mtetra
.617 .752 .942 r
.31432 .62618 .32137 .63199 .33242 .62914 .32538 .62377 Mtetra
.45 .709 .978 r
.32538 .62377 .33242 .62914 .34344 .62788 .33634 .62394 Mtetra
.015 .515 .869 r
.33634 .62394 .34344 .62788 .35438 .6293 .34722 .62708 Mtetra
0 .456 .741 r
.34722 .62708 .35438 .6293 .36534 .63219 .35821 .62981 Mtetra
.552 .861 .997 r
.35821 .62981 .36534 .63219 .3765 .63219 .36953 .62703 Mtetra
.782 .804 .87 r
.36953 .62703 .3765 .63219 .38795 .62675 .38113 .61885 Mtetra
.769 .733 .82 r
.38113 .61885 .38795 .62675 .39953 .61853 .39278 .60991 Mtetra
.732 .711 .831 r
.39278 .60991 .39953 .61853 .41111 .61109 .40437 .60295 Mtetra
.7 .714 .86 r
.40437 .60295 .41111 .61109 .42266 .60535 .41592 .59778 Mtetra
.68 .724 .883 r
.41592 .59778 .42266 .60535 .43421 .60073 .42749 .59349 Mtetra
.671 .731 .895 r
.42749 .59349 .43421 .60073 .44578 .59665 .43909 .58955 Mtetra
.665 .734 .901 r
.43909 .58955 .44578 .59665 .4574 .59278 .45074 .58578 Mtetra
.661 .737 .906 r
.45074 .58578 .4574 .59278 .46907 .58897 .46243 .58214 Mtetra
.662 .742 .91 r
.46243 .58214 .46907 .58897 .48078 .58531 .47417 .57845 Mtetra
.663 .743 .909 r
.47417 .57845 .48078 .58531 .49254 .58176 .48597 .5747 Mtetra
.66 .737 .907 r
.48597 .5747 .49254 .58176 .50435 .57818 .49781 .57102 Mtetra
.655 .733 .907 r
.49781 .57102 .50435 .57818 .51621 .57448 .5097 .56748 Mtetra
.652 .738 .912 r
.5097 .56748 .51621 .57448 .52812 .57073 .52164 .56401 Mtetra
.652 .747 .92 r
.52164 .56401 .52812 .57073 .54008 .567 .53364 .56053 Mtetra
.653 .756 .925 r
.53364 .56053 .54008 .567 .55209 .56333 .54569 .55696 Mtetra
.655 .761 .927 r
.54569 .55696 .55209 .56333 .56416 .55972 .55779 .55331 Mtetra
.656 .761 .927 r
.55779 .55331 .56416 .55972 .57628 .55613 .56995 .54961 Mtetra
.656 .758 .925 r
.56995 .54961 .57628 .55613 .58845 .55254 .58215 .5459 Mtetra
.656 .755 .923 r
.58215 .5459 .58845 .55254 .60068 .54892 .59441 .5422 Mtetra
.655 .753 .922 r
.59441 .5422 .60068 .54892 .61296 .54527 .60673 .53851 Mtetra
.654 .753 .923 r
.60673 .53851 .61296 .54527 .62529 .54158 .6191 .53485 Mtetra
.653 .754 .924 r
.6191 .53485 .62529 .54158 .63768 .53786 .63153 .53119 Mtetra
.652 .757 .927 r
.63153 .53119 .63768 .53786 .65012 .53414 .64402 .52752 Mtetra
.653 .76 .928 r
.64402 .52752 .65012 .53414 .66263 .53043 .65656 .5238 Mtetra
.655 .761 .928 r
.65656 .5238 .66263 .53043 .67518 .52679 .66915 .52 Mtetra
.658 .758 .924 r
.66915 .52 .67518 .52679 .68781 .52321 .6818 .51611 Mtetra
.659 .75 .917 r
.6818 .51611 .68781 .52321 .70049 .51965 .6945 .5122 Mtetra
.656 .739 .911 r
.6945 .5122 .70049 .51965 .71322 .51603 .70727 .50837 Mtetra
.652 .732 .909 r
.70727 .50837 .71322 .51603 .72601 .51229 .7201 .50467 Mtetra
.649 .734 .911 r
.7201 .50467 .72601 .51229 .73886 .50852 .73299 .50104 Mtetra
.65 .739 .915 r
.73299 .50104 .73886 .50852 .75177 .50486 .74595 .49735 Mtetra
.651 .74 .914 r
.74595 .49735 .75177 .50486 .76476 .50135 .75896 .49362 Mtetra
.647 .733 .911 r
.75896 .49362 .76476 .50135 .77781 .4979 .77204 .49 Mtetra
.641 .726 .91 r
.77204 .49 .77781 .4979 .79095 .49466 .7852 .48656 Mtetra
.63 .717 .909 r
.7852 .48656 .79095 .49466 .80419 .49196 .79845 .48347 Mtetra
.602 .695 .908 r
.79845 .48347 .80419 .49196 .81761 .49042 .81186 .48129 Mtetra
.543 .65 .904 r
.81186 .48129 .81761 .49042 .83128 .49062 .8255 .48094 Mtetra
.475 .601 .898 r
.8255 .48094 .83128 .49062 .84511 .49159 .83944 .48262 Mtetra
.496 .632 .913 r
.83944 .48262 .84511 .49159 .85876 .48963 .8534 .48347 Mtetra
.676 .802 .942 r
.8534 .48347 .85876 .48963 .87189 .48197 .86688 .47864 Mtetra
.83 .935 .898 r
.86688 .47864 .87189 .48197 .88472 .4713 .87979 .46804 Mtetra
.838 .939 .891 r
.87979 .46804 .88472 .4713 .89774 .46221 .89268 .45704 Mtetra
.763 .867 .925 r
.89268 .45704 .89774 .46221 .91111 .45594 .90593 .44919 Mtetra
.684 .789 .93 r
.90593 .44919 .91111 .45594 .92474 .45134 .91955 .44407 Mtetra
.582 .751 .958 r
.3072 .62059 .31432 .62618 .32538 .62377 .31825 .61879 Mtetra
.263 .634 .963 r
.31825 .61879 .32538 .62377 .33634 .62394 .32914 .62067 Mtetra
0 .336 .689 r
.32914 .62067 .33634 .62394 .34722 .62708 .33997 .62513 Mtetra
.026 .578 .826 r
.33997 .62513 .34722 .62708 .35821 .62981 .35105 .62656 Mtetra
.737 .868 .941 r
.35105 .62656 .35821 .62981 .36953 .62703 .36256 .62056 Mtetra
.8 .769 .825 r
.36256 .62056 .36953 .62703 .38113 .61885 .37429 .61036 Mtetra
.765 .722 .812 r
.37429 .61036 .38113 .61885 .39278 .60991 .38597 .60136 Mtetra
.721 .711 .84 r
.38597 .60136 .39278 .60991 .40437 .60295 .39756 .59503 Mtetra
.689 .718 .871 r
.39756 .59503 .40437 .60295 .41592 .59778 .40913 .59033 Mtetra
.672 .726 .89 r
.40913 .59033 .41592 .59778 .42749 .59349 .42072 .5863 Mtetra
.665 .732 .9 r
.42072 .5863 .42749 .59349 .43909 .58955 .43235 .58251 Mtetra
.663 .737 .905 r
.43235 .58251 .43909 .58955 .45074 .58578 .44403 .57879 Mtetra
.662 .738 .907 r
.44403 .57879 .45074 .58578 .46243 .58214 .45575 .57507 Mtetra
.658 .736 .907 r
.45575 .57507 .46243 .58214 .47417 .57845 .46752 .57147 Mtetra
.654 .738 .912 r
.46752 .57147 .47417 .57845 .48597 .5747 .47934 .56796 Mtetra
.655 .747 .917 r
.47934 .56796 .48597 .5747 .49781 .57102 .49121 .5644 Mtetra
.66 .753 .919 r
.49121 .5644 .49781 .57102 .5097 .56748 .50314 .56067 Mtetra
.663 .749 .914 r
.50314 .56067 .5097 .56748 .52164 .56401 .51512 .55684 Mtetra
.662 .738 .907 r
.51512 .55684 .52164 .56401 .53364 .56053 .52715 .55302 Mtetra
.659 .729 .901 r
.52715 .55302 .53364 .56053 .54569 .55696 .53923 .54928 Mtetra
.656 .724 .899 r
.53923 .54928 .54569 .55696 .55779 .55331 .55136 .54561 Mtetra
.655 .724 .9 r
.55136 .54561 .55779 .55331 .56995 .54961 .56355 .54198 Mtetra
.654 .726 .902 r
.56355 .54198 .56995 .54961 .58215 .5459 .57579 .53835 Mtetra
.655 .73 .904 r
.57579 .53835 .58215 .5459 .59441 .5422 .58809 .53469 Mtetra
.656 .732 .906 r
.58809 .53469 .59441 .5422 .60673 .53851 .60044 .53098 Mtetra
.657 .732 .905 r
.60044 .53098 .60673 .53851 .6191 .53485 .61284 .52721 Mtetra
.657 .731 .904 r
.61284 .52721 .6191 .53485 .63153 .53119 .6253 .52341 Mtetra
.657 .727 .901 r
.6253 .52341 .63153 .53119 .64402 .52752 .63782 .51961 Mtetra
.655 .724 .9 r
.63782 .51961 .64402 .52752 .65656 .5238 .65039 .51585 Mtetra
.653 .723 .9 r
.65039 .51585 .65656 .5238 .66915 .52 .66303 .51216 Mtetra
.65 .726 .905 r
.66303 .51216 .66915 .52 .6818 .51611 .67572 .50855 Mtetra
.648 .734 .912 r
.67572 .50855 .6818 .51611 .6945 .5122 .68848 .50495 Mtetra
.651 .745 .919 r
.68848 .50495 .6945 .5122 .70727 .50837 .70129 .50124 Mtetra
.655 .752 .921 r
.70129 .50124 .70727 .50837 .7201 .50467 .71416 .49737 Mtetra
.657 .748 .917 r
.71416 .49737 .7201 .50467 .73299 .50104 .72707 .49343 Mtetra
.654 .738 .912 r
.72707 .49343 .73299 .50104 .74595 .49735 .74006 .4896 Mtetra
.65 .734 .911 r
.74006 .4896 .74595 .49735 .75896 .49362 .75311 .48588 Mtetra
.649 .735 .912 r
.75311 .48588 .75896 .49362 .77204 .49 .76623 .48216 Mtetra
.647 .732 .911 r
.76623 .48216 .77204 .49 .7852 .48656 .77941 .47851 Mtetra
.639 .724 .909 r
.77941 .47851 .7852 .48656 .79845 .48347 .79268 .4751 Mtetra
.618 .707 .909 r
.79268 .4751 .79845 .48347 .81186 .48129 .80608 .47237 Mtetra
.564 .668 .908 r
.80608 .47237 .81186 .48129 .8255 .48094 .8197 .47133 Mtetra
.471 .602 .901 r
.8197 .47133 .8255 .48094 .83944 .48262 .83366 .47303 Mtetra
.422 .576 .901 r
.83366 .47303 .83944 .48262 .8534 .48347 .84786 .47592 Mtetra
.566 .712 .94 r
.84786 .47592 .8534 .48347 .86688 .47864 .86172 .47438 Mtetra
.8 .904 .914 r
.86172 .47438 .86688 .47864 .87979 .46804 .87485 .46505 Mtetra
.866 .947 .866 r
.87485 .46505 .87979 .46804 .89268 .45704 .88765 .45258 Mtetra
.809 .901 .906 r
.88765 .45258 .89268 .45704 .90593 .44919 .90075 .44285 Mtetra
.704 .812 .932 r
.90075 .44285 .90593 .44919 .91955 .44407 .91434 .43702 Mtetra
.53 .745 .974 r
.3 .61528 .3072 .62059 .31825 .61879 .31102 .61424 Mtetra
0 .484 .863 r
.31102 .61424 .31825 .61879 .32914 .62067 .32183 .61792 Mtetra
.376 0 0 r
.32183 .61792 .32914 .62067 .33997 .62513 .33264 .62312 Mtetra
.321 .77 .958 r
.33264 .62312 .33997 .62513 .35105 .62656 .34387 .62237 Mtetra
.807 .833 .87 r
.34387 .62237 .35105 .62656 .36256 .62056 .35558 .61316 Mtetra
.806 .749 .8 r
.35558 .61316 .36256 .62056 .37429 .61036 .36741 .60161 Mtetra
.758 .716 .813 r
.36741 .60161 .37429 .61036 .38597 .60136 .37911 .59293 Mtetra
.709 .712 .851 r
.37911 .59293 .38597 .60136 .39756 .59503 .39071 .58724 Mtetra
.678 .72 .881 r
.39071 .58724 .39756 .59503 .40913 .59033 .40229 .58296 Mtetra
.666 .728 .896 r
.40229 .58296 .40913 .59033 .42072 .5863 .4139 .57912 Mtetra
.662 .733 .902 r
.4139 .57912 .42072 .5863 .43235 .58251 .42556 .57541 Mtetra
.659 .735 .906 r
.42556 .57541 .43235 .58251 .44403 .57879 .43726 .57178 Mtetra
.656 .738 .91 r
.43726 .57178 .44403 .57879 .45575 .57507 .44901 .56821 Mtetra
.659 .744 .913 r
.44901 .56821 .45575 .57507 .46752 .57147 .46081 .56454 Mtetra
.662 .744 .911 r
.46081 .56454 .46752 .57147 .47934 .56796 .47267 .56075 Mtetra
.659 .735 .906 r
.47267 .56075 .47934 .56796 .49121 .5644 .48458 .55705 Mtetra
.653 .73 .906 r
.48458 .55705 .49121 .5644 .50314 .56067 .49653 .55353 Mtetra
.648 .736 .913 r
.49653 .55353 .50314 .56067 .51512 .55684 .50854 .55011 Mtetra
.649 .749 .923 r
.50854 .55011 .51512 .55684 .52715 .55302 .5206 .54665 Mtetra
.652 .763 .931 r
.5206 .54665 .52715 .55302 .53923 .54928 .53272 .54305 Mtetra
.656 .769 .933 r
.53272 .54305 .53923 .54928 .55136 .54561 .54489 .5393 Mtetra
.659 .768 .93 r
.54489 .5393 .55136 .54561 .56355 .54198 .55711 .53545 Mtetra
.66 .762 .926 r
.55711 .53545 .56355 .54198 .57579 .53835 .56939 .53158 Mtetra
.658 .755 .922 r
.56939 .53158 .57579 .53835 .58809 .53469 .58172 .52776 Mtetra
.655 .751 .92 r
.58172 .52776 .58809 .53469 .60044 .53098 .59411 .52402 Mtetra
.652 .75 .921 r
.59411 .52402 .60044 .53098 .61284 .52721 .60655 .52035 Mtetra
.649 .753 .925 r
.60655 .52035 .61284 .52721 .6253 .52341 .61906 .51673 Mtetra
.649 .759 .93 r
.61906 .51673 .6253 .52341 .63782 .51961 .63162 .51309 Mtetra
.651 .766 .933 r
.63162 .51309 .63782 .51961 .65039 .51585 .64423 .50935 Mtetra
.655 .769 .933 r
.64423 .50935 .65039 .51585 .66303 .51216 .6569 .50547 Mtetra
.66 .766 .928 r
.6569 .50547 .66303 .51216 .67572 .50855 .66962 .50143 Mtetra
.662 .754 .918 r
.66962 .50143 .67572 .50855 .68848 .50495 .6824 .49735 Mtetra
.658 .739 .91 r
.6824 .49735 .68848 .50495 .70129 .50124 .69523 .49338 Mtetra
.652 .73 .907 r
.69523 .49338 .70129 .50124 .71416 .49737 .70814 .48959 Mtetra
.649 .733 .91 r
.70814 .48959 .71416 .49737 .72707 .49343 .72111 .48588 Mtetra
.652 .741 .915 r
.72111 .48588 .72707 .49343 .74006 .4896 .73414 .48206 Mtetra
.655 .744 .915 r
.73414 .48206 .74006 .4896 .75311 .48588 .74722 .47812 Mtetra
.653 .737 .912 r
.74722 .47812 .75311 .48588 .76623 .48216 .76037 .47424 Mtetra
.65 .733 .91 r
.76037 .47424 .76623 .48216 .77941 .47851 .77359 .47046 Mtetra
.645 .728 .909 r
.77359 .47046 .77941 .47851 .79268 .4751 .78688 .46679 Mtetra
.631 .716 .908 r
.78688 .46679 .79268 .4751 .80608 .47237 .80027 .46358 Mtetra
.586 .683 .908 r
.80027 .46358 .80608 .47237 .8197 .47133 .81387 .46182 Mtetra
.482 .612 .904 r
.81387 .46182 .8197 .47133 .83366 .47303 .82783 .46314 Mtetra
.368 .539 .892 r
.82783 .46314 .83366 .47303 .84786 .47592 .84218 .46741 Mtetra
.444 .621 .927 r
.84218 .46741 .84786 .47592 .86172 .47438 .85642 .46915 Mtetra
.741 .86 .936 r
.85642 .46915 .86172 .47438 .87485 .46505 .86984 .46202 Mtetra
.879 .944 .852 r
.86984 .46202 .87485 .46505 .88765 .45258 .88263 .44866 Mtetra
.85 .923 .879 r
.88263 .44866 .88765 .45258 .90075 .44285 .89558 .43695 Mtetra
.729 .837 .932 r
.89558 .43695 .90075 .44285 .91434 .43702 .90913 .43023 Mtetra
.456 .728 .985 r
.29272 .61024 .3 .61528 .31102 .61424 .30371 .61007 Mtetra
0 .28 .675 r
.30371 .61007 .31102 .61424 .32183 .61792 .31442 .61554 Mtetra
.423 0 0 r
.31442 .61554 .32183 .61792 .33264 .62312 .32525 .62091 Mtetra
.594 .881 .992 r
.32525 .62091 .33264 .62312 .34387 .62237 .33666 .6174 Mtetra
.837 .804 .819 r
.33666 .6174 .34387 .62237 .35558 .61316 .34858 .60517 Mtetra
.808 .738 .786 r
.34858 .60517 .35558 .61316 .36741 .60161 .36049 .59275 Mtetra
.749 .713 .818 r
.36049 .59275 .36741 .60161 .37911 .59293 .3722 .5846 Mtetra
.695 .712 .861 r
.3722 .5846 .37911 .59293 .39071 .58724 .3838 .57953 Mtetra
.668 .72 .888 r
.3838 .57953 .39071 .58724 .40229 .58296 .39539 .5756 Mtetra
.66 .728 .9 r
.39539 .5756 .40229 .58296 .4139 .57912 .40703 .57194 Mtetra
.657 .733 .906 r
.40703 .57194 .4139 .57912 .42556 .57541 .41871 .56835 Mtetra
.658 .738 .908 r
.41871 .56835 .42556 .57541 .43726 .57178 .43044 .5647 Mtetra
.659 .738 .908 r
.43044 .5647 .43726 .57178 .44901 .56821 .44222 .56101 Mtetra
.655 .735 .908 r
.44222 .56101 .44901 .56821 .46081 .56454 .45406 .55743 Mtetra
.653 .738 .911 r
.45406 .55743 .46081 .56454 .47267 .56075 .46594 .55389 Mtetra
.662 .748 .914 r
.46594 .55389 .47267 .56075 .48458 .55705 .47788 .55007 Mtetra
.677 .75 .906 r
.47788 .55007 .48458 .55705 .49653 .55353 .48988 .54574 Mtetra
.687 .731 .884 r
.48988 .54574 .49653 .55353 .50854 .55011 .50192 .54097 Mtetra
.686 .699 .856 r
.50192 .54097 .50854 .55011 .5206 .54665 .51402 .53599 Mtetra
.678 .666 .831 r
.51402 .53599 .5206 .54665 .53272 .54305 .52615 .53105 Mtetra
.668 .64 .813 r
.52615 .53105 .53272 .54305 .54489 .5393 .53834 .52632 Mtetra
.658 .622 .801 r
.53834 .52632 .54489 .5393 .55711 .53545 .55057 .52184 Mtetra
.651 .61 .795 r
.55057 .52184 .55711 .53545 .56939 .53158 .56285 .51762 Mtetra
.645 .603 .792 r
.56285 .51762 .56939 .53158 .58172 .52776 .57519 .51363 Mtetra
.641 .599 .792 r
.57519 .51363 .58172 .52776 .59411 .52402 .58759 .50985 Mtetra
.636 .597 .793 r
.58759 .50985 .59411 .52402 .60655 .52035 .60005 .50628 Mtetra
.632 .597 .796 r
.60005 .50628 .60655 .52035 .61906 .51673 .61257 .50293 Mtetra
.627 .598 .801 r
.61257 .50293 .61906 .51673 .63162 .51309 .62516 .49985 Mtetra
.623 .605 .811 r
.62516 .49985 .63162 .51309 .64423 .50935 .63782 .49703 Mtetra
.619 .618 .827 r
.63782 .49703 .64423 .50935 .6569 .50547 .65056 .49443 Mtetra
.618 .641 .851 r
.65056 .49443 .6569 .50547 .66962 .50143 .66337 .49187 Mtetra
.623 .675 .879 r
.66337 .49187 .66962 .50143 .6824 .49735 .67624 .4891 Mtetra
.635 .714 .904 r
.67624 .4891 .6824 .49735 .69523 .49338 .68915 .48588 Mtetra
.649 .742 .917 r
.68915 .48588 .69523 .49338 .70814 .48959 .7021 .48214 Mtetra
.657 .747 .916 r
.7021 .48214 .70814 .48959 .72111 .48588 .7151 .47812 Mtetra
.656 .739 .911 r
.7151 .47812 .72111 .48588 .73414 .48206 .72816 .47415 Mtetra
.652 .734 .909 r
.72816 .47415 .73414 .48206 .74722 .47812 .74128 .47028 Mtetra
.653 .737 .911 r
.74128 .47028 .74722 .47812 .76037 .47424 .75447 .46636 Mtetra
.654 .737 .911 r
.75447 .46636 .76037 .47424 .77359 .47046 .76772 .46239 Mtetra
.652 .732 .908 r
.76772 .46239 .77359 .47046 .78688 .46679 .78103 .45848 Mtetra
.643 .723 .906 r
.78103 .45848 .78688 .46679 .80027 .46358 .79444 .45485 Mtetra
.607 .697 .907 r
.79444 .45485 .80027 .46358 .81387 .46182 .80801 .45239 Mtetra
.501 .627 .906 r
.80801 .45239 .81387 .46182 .82783 .46314 .82195 .45312 Mtetra
.33 .514 .886 r
.82195 .45312 .82783 .46314 .84218 .46741 .83641 .45825 Mtetra
.315 .529 .902 r
.83641 .45825 .84218 .46741 .85642 .46915 .85099 .4631 Mtetra
.652 .804 .956 r
.85099 .4631 .85642 .46915 .86984 .46202 .86476 .45876 Mtetra
.882 .939 .848 r
.86476 .45876 .86984 .46202 .88263 .44866 .8776 .44512 Mtetra
.883 .932 .847 r
.8776 .44512 .88263 .44866 .89558 .43695 .89041 .43143 Mtetra
.755 .859 .927 r
.89041 .43143 .89558 .43695 .90913 .43023 .90391 .42373 Mtetra
.358 .694 .982 r
.28536 .60543 .29272 .61024 .30371 .61007 .29631 .60618 Mtetra
.486 0 0 r
.29631 .60618 .30371 .61007 .31442 .61554 .30693 .61338 Mtetra
.415 0 0 r
.30693 .61338 .31442 .61554 .32525 .62091 .31779 .61849 Mtetra
.752 .898 .943 r
.31779 .61849 .32525 .62091 .33666 .6174 .32942 .61186 Mtetra
.854 .785 .783 r
.32942 .61186 .33666 .6174 .34858 .60517 .34154 .59679 Mtetra
.81 .732 .779 r
.34154 .59679 .34858 .60517 .36049 .59275 .35352 .58381 Mtetra
.739 .711 .825 r
.35352 .58381 .36049 .59275 .3722 .5846 .36523 .5763 Mtetra
.68 .709 .87 r
.36523 .5763 .3722 .5846 .3838 .57953 .37683 .57184 Mtetra
.657 .719 .894 r
.37683 .57184 .3838 .57953 .39539 .5756 .38844 .56823 Mtetra
.655 .728 .903 r
.38844 .56823 .39539 .5756 .40703 .57194 .4001 .5647 Mtetra
.656 .733 .906 r
.4001 .5647 .40703 .57194 .41871 .56835 .41181 .5611 Mtetra
.658 .734 .906 r
.41181 .5611 .41871 .56835 .43044 .5647 .42357 .55743 Mtetra
.666 .736 .902 r
.42357 .55743 .43044 .5647 .44222 .56101 .43539 .55348 Mtetra
.686 .736 .889 r
.43539 .55348 .44222 .56101 .45406 .55743 .44728 .54883 Mtetra
.7 .714 .86 r
.44728 .54883 .45406 .55743 .46594 .55389 .45923 .5434 Mtetra
.696 .675 .825 r
.45923 .5434 .46594 .55389 .47788 .55007 .47122 .53765 Mtetra
.68 .638 .8 r
.47122 .53765 .47788 .55007 .48988 .54574 .48324 .53215 Mtetra
.664 .615 .79 r
.48324 .53215 .48988 .54574 .50192 .54097 .4953 .52724 Mtetra
.653 .608 .792 r
.4953 .52724 .50192 .54097 .51402 .53599 .5074 .52292 Mtetra
.647 .615 .803 r
.5074 .52292 .51402 .53599 .52615 .53105 .51955 .51902 Mtetra
.645 .63 .821 r
.51955 .51902 .52615 .53105 .53834 .52632 .53176 .51535 Mtetra
.646 .65 .839 r
.53176 .51535 .53834 .52632 .55057 .52184 .54402 .51175 Mtetra
.649 .669 .856 r
.54402 .51175 .55057 .52184 .56285 .51762 .55633 .50812 Mtetra
.652 .684 .867 r
.55633 .50812 .56285 .51762 .57519 .51363 .5687 .50441 Mtetra
.655 .692 .873 r
.5687 .50441 .57519 .51363 .58759 .50985 .58113 .50059 Mtetra
.657 .693 .872 r
.58113 .50059 .58759 .50985 .60005 .50628 .59361 .49667 Mtetra
.658 .686 .865 r
.59361 .49667 .60005 .50628 .61257 .50293 .60614 .49266 Mtetra
.657 .672 .853 r
.60614 .49266 .61257 .50293 .62516 .49985 .61873 .48862 Mtetra
.652 .652 .837 r
.61873 .48862 .62516 .49985 .63782 .49703 .63138 .48466 Mtetra
.643 .629 .821 r
.63138 .48466 .63782 .49703 .65056 .49443 .6441 .48092 Mtetra
.631 .607 .807 r
.6441 .48092 .65056 .49443 .66337 .49187 .65689 .47761 Mtetra
.617 .59 .801 r
.65689 .47761 .66337 .49187 .67624 .4891 .66977 .47491 Mtetra
.604 .585 .805 r
.66977 .47491 .67624 .4891 .68915 .48588 .68275 .47282 Mtetra
.598 .599 .824 r
.68275 .47282 .68915 .48588 .7021 .48214 .69582 .471 Mtetra
.605 .637 .856 r
.69582 .471 .7021 .48214 .7151 .47812 .70895 .46885 Mtetra
.626 .688 .888 r
.70895 .46885 .7151 .47812 .72816 .47415 .7221 .4659 Mtetra
.645 .723 .905 r
.7221 .4659 .72816 .47415 .74128 .47028 .73529 .46222 Mtetra
.653 .733 .908 r
.73529 .46222 .74128 .47028 .75447 .46636 .74851 .45828 Mtetra
.655 .734 .908 r
.74851 .45828 .75447 .46636 .76772 .46239 .7618 .45425 Mtetra
.656 .734 .907 r
.7618 .45425 .76772 .46239 .78103 .45848 .77514 .45015 Mtetra
.654 .729 .904 r
.77514 .45015 .78103 .45848 .79444 .45485 .78856 .44613 Mtetra
.627 .708 .904 r
.78856 .44613 .79444 .45485 .80801 .45239 .80211 .44299 Mtetra
.525 .642 .907 r
.80211 .44299 .80801 .45239 .82195 .45312 .81602 .443 Mtetra
.304 .498 .882 r
.81602 .443 .82195 .45312 .83641 .45825 .83056 .44867 Mtetra
.182 .435 .866 r
.83056 .44867 .83641 .45825 .85099 .4631 .84545 .45644 Mtetra
.528 .73 .967 r
.84545 .45644 .85099 .4631 .86476 .45876 .85961 .45528 Mtetra
.878 .934 .853 r
.85961 .45528 .86476 .45876 .8776 .44512 .87254 .44181 Mtetra
.908 .933 .817 r
.87254 .44181 .8776 .44512 .89041 .43143 .88523 .42621 Mtetra
.781 .877 .917 r
.88523 .42621 .89041 .43143 .90391 .42373 .89868 .41744 Mtetra
.241 .639 .96 r
.27791 .60076 .28536 .60543 .29631 .60618 .28882 .60247 Mtetra
.619 .058 0 r
.28882 .60247 .29631 .60618 .30693 .61338 .29934 .61135 Mtetra
.372 0 0 r
.29934 .61135 .30693 .61338 .31779 .61849 .31026 .61593 Mtetra
.83 .882 .881 r
.31026 .61593 .31779 .61849 .32942 .61186 .32214 .606 Mtetra
.867 .774 .757 r
.32214 .606 .32942 .61186 .34154 .59679 .33446 .58819 Mtetra
.811 .729 .774 r
.33446 .58819 .34154 .59679 .35352 .58381 .34651 .57481 Mtetra
.727 .707 .832 r
.34651 .57481 .35352 .58381 .36523 .5763 .35822 .56797 Mtetra
.664 .705 .878 r
.35822 .56797 .36523 .5763 .37683 .57184 .36982 .5641 Mtetra
.65 .717 .897 r
.36982 .5641 .37683 .57184 .38844 .56823 .38145 .56071 Mtetra
.657 .726 .9 r
.38145 .56071 .38844 .56823 .4001 .5647 .39313 .55708 Mtetra
.674 .729 .891 r
.39313 .55708 .4001 .5647 .41181 .5611 .40489 .55288 Mtetra
.696 .721 .868 r
.40489 .55288 .41181 .5611 .42357 .55743 .41673 .54771 Mtetra
.706 .692 .834 r
.41673 .54771 .42357 .55743 .43539 .55348 .42863 .54168 Mtetra
.693 .652 .804 r
.42863 .54168 .43539 .55348 .44728 .54883 .44057 .53564 Mtetra
.671 .623 .792 r
.44057 .53564 .44728 .54883 .45923 .5434 .45252 .53047 Mtetra
.652 .618 .803 r
.45252 .53047 .45923 .5434 .47122 .53765 .4645 .52636 Mtetra
.64 .64 .834 r
.4645 .52636 .47122 .53765 .48324 .53215 .47652 .523 Mtetra
.635 .682 .877 r
.47652 .523 .48324 .53215 .4953 .52724 .48858 .51996 Mtetra
.632 .731 .92 r
.48858 .51996 .4953 .52724 .5074 .52292 .50071 .51693 Mtetra
.629 .772 .949 r
.50071 .51693 .5074 .52292 .51955 .51902 .5129 .51378 Mtetra
.627 .799 .965 r
.5129 .51378 .51955 .51902 .53176 .51535 .52514 .51047 Mtetra
.628 .813 .971 r
.52514 .51047 .53176 .51535 .54402 .51175 .53745 .50701 Mtetra
.632 .82 .973 r
.53745 .50701 .54402 .51175 .55633 .50812 .54981 .50342 Mtetra
.636 .824 .973 r
.54981 .50342 .55633 .50812 .5687 .50441 .56222 .49969 Mtetra
.64 .825 .971 r
.56222 .49969 .5687 .50441 .58113 .50059 .57469 .49584 Mtetra
.645 .827 .97 r
.57469 .49584 .58113 .50059 .59361 .49667 .58722 .49186 Mtetra
.65 .827 .968 r
.58722 .49186 .59361 .49667 .60614 .49266 .5998 .48776 Mtetra
.656 .827 .965 r
.5998 .48776 .60614 .49266 .61873 .48862 .61243 .48353 Mtetra
.663 .823 .96 r
.61243 .48353 .61873 .48862 .63138 .48466 .62512 .47913 Mtetra
.671 .811 .95 r
.62512 .47913 .63138 .48466 .6441 .48092 .63785 .47458 Mtetra
.677 .787 .932 r
.63785 .47458 .6441 .48092 .65689 .47761 .65063 .46991 Mtetra
.677 .747 .904 r
.65063 .46991 .65689 .47761 .66977 .47491 .66347 .46525 Mtetra
.664 .693 .868 r
.66347 .46525 .66977 .47491 .68275 .47282 .67637 .4609 Mtetra
.639 .639 .834 r
.67637 .4609 .68275 .47282 .69582 .471 .68937 .45731 Mtetra
.612 .598 .813 r
.68937 .45731 .69582 .471 .70895 .46885 .7025 .45482 Mtetra
.591 .583 .812 r
.7025 .45482 .70895 .46885 .7221 .4659 .71575 .45323 Mtetra
.59 .604 .834 r
.71575 .45323 .7221 .4659 .73529 .46222 .72909 .45165 Mtetra
.611 .655 .868 r
.72909 .45165 .73529 .46222 .74851 .45828 .74244 .44917 Mtetra
.638 .701 .892 r
.74244 .44917 .74851 .45828 .7618 .45425 .75581 .44571 Mtetra
.654 .724 .9 r
.75581 .44571 .7618 .45425 .77514 .45015 .7692 .44165 Mtetra
.661 .729 .9 r
.7692 .44165 .77514 .45015 .78856 .44613 .78263 .43734 Mtetra
.646 .716 .899 r
.78263 .43734 .78856 .44613 .80211 .44299 .79617 .43354 Mtetra
.55 .655 .905 r
.79617 .43354 .80211 .44299 .81602 .443 .81005 .4328 Mtetra
.285 .486 .879 r
.81005 .4328 .81602 .443 .83056 .44867 .82464 .43885 Mtetra
.046 .337 .816 r
.82464 .43885 .83056 .44867 .84545 .45644 .83983 .44942 Mtetra
.365 .632 .956 r
.83983 .44942 .84545 .45644 .85961 .45528 .85438 .45165 Mtetra
.87 .932 .861 r
.85438 .45165 .85961 .45528 .87254 .44181 .86744 .43862 Mtetra
.927 .93 .788 r
.86744 .43862 .87254 .44181 .88523 .42621 .88002 .42115 Mtetra
.806 .889 .904 r
.88002 .42115 .88523 .42621 .89868 .41744 .89341 .41129 Mtetra
.115 .566 .918 r
.2704 .59612 .27791 .60076 .28882 .60247 .28126 .5988 Mtetra
.703 .165 0 r
.28126 .5988 .28882 .60247 .29934 .61135 .29168 .60935 Mtetra
.31 0 0 r
.29168 .60935 .29934 .61135 .31026 .61593 .30266 .61333 Mtetra
.87 .862 .829 r
.30266 .61333 .31026 .61593 .32214 .606 .3148 .60005 Mtetra
.878 .769 .737 r
.3148 .60005 .32214 .606 .33446 .58819 .32734 .5795 Mtetra
.814 .729 .771 r
.32734 .5795 .33446 .58819 .34651 .57481 .33946 .56571 Mtetra
.714 .703 .838 r
.33946 .56571 .34651 .57481 .35822 .56797 .35116 .55949 Mtetra
.653 .699 .88 r
.35116 .55949 .35822 .56797 .36982 .5641 .36277 .55596 Mtetra
.662 .712 .885 r
.36277 .55596 .36982 .5641 .38145 .56071 .37444 .55214 Mtetra
.692 .711 .863 r
.37444 .55214 .38145 .56071 .39313 .55708 .38621 .54709 Mtetra
.707 .686 .828 r
.38621 .54709 .39313 .55708 .40489 .55288 .39806 .54092 Mtetra
.695 .65 .801 r
.39806 .54092 .40489 .55288 .41673 .54771 .40995 .53474 Mtetra
.668 .624 .797 r
.40995 .53474 .41673 .54771 .42863 .54168 .42183 .52978 Mtetra
.643 .63 .822 r
.42183 .52978 .42863 .54168 .44057 .53564 .43372 .52624 Mtetra
.627 .673 .875 r
.43372 .52624 .44057 .53564 .45252 .53047 .44565 .5235 Mtetra
.614 .734 .931 r
.44565 .5235 .45252 .53047 .4645 .52636 .45763 .52091 Mtetra
.606 .783 .966 r
.45763 .52091 .4645 .52636 .47652 .523 .46967 .51817 Mtetra
.605 .806 .977 r
.46967 .51817 .47652 .523 .48858 .51996 .48178 .51523 Mtetra
.612 .812 .977 r
.48178 .51523 .48858 .51996 .50071 .51693 .49395 .5121 Mtetra
.62 .812 .974 r
.49395 .5121 .50071 .51693 .5129 .51378 .50618 .50881 Mtetra
.627 .81 .97 r
.50618 .50881 .5129 .51378 .52514 .51047 .51846 .50538 Mtetra
.633 .809 .967 r
.51846 .50538 .52514 .51047 .53745 .50701 .53081 .50184 Mtetra
.638 .808 .965 r
.53081 .50184 .53745 .50701 .54981 .50342 .54321 .49818 Mtetra
.642 .808 .963 r
.54321 .49818 .54981 .50342 .56222 .49969 .55567 .49441 Mtetra
.646 .809 .961 r
.55567 .49441 .56222 .49969 .57469 .49584 .56819 .49054 Mtetra
.65 .81 .96 r
.56819 .49054 .57469 .49584 .58722 .49186 .58076 .48655 Mtetra
.653 .812 .96 r
.58076 .48655 .58722 .49186 .5998 .48776 .59339 .48246 Mtetra
.657 .815 .959 r
.59339 .48246 .5998 .48776 .61243 .48353 .60607 .47824 Mtetra
.661 .817 .959 r
.60607 .47824 .61243 .48353 .62512 .47913 .6188 .4739 Mtetra
.665 .822 .959 r
.6188 .4739 .62512 .47913 .63785 .47458 .63159 .46941 Mtetra
.67 .826 .959 r
.63159 .46941 .63785 .47458 .65063 .46991 .64442 .46476 Mtetra
.676 .83 .957 r
.64442 .46476 .65063 .46991 .66347 .46525 .6573 .45992 Mtetra
.683 .827 .952 r
.6573 .45992 .66347 .46525 .67637 .4609 .67023 .45488 Mtetra
.69 .807 .937 r
.67023 .45488 .67637 .4609 .68937 .45731 .6832 .4497 Mtetra
.684 .757 .907 r
.6832 .4497 .68937 .45731 .7025 .45482 .69623 .44468 Mtetra
.657 .684 .864 r
.69623 .44468 .7025 .45482 .71575 .45323 .70936 .44046 Mtetra
.617 .617 .828 r
.70936 .44046 .71575 .45323 .72909 .45165 .72264 .43769 Mtetra
.588 .585 .816 r
.72264 .43769 .72909 .45165 .74244 .44917 .73608 .4362 Mtetra
.587 .6 .832 r
.73608 .4362 .74244 .44917 .75581 .44571 .7496 .4347 Mtetra
.614 .65 .862 r
.7496 .4347 .75581 .44571 .7692 .44165 .76313 .43205 Mtetra
.648 .697 .882 r
.76313 .43205 .7692 .44165 .78263 .43734 .77663 .42813 Mtetra
.656 .711 .888 r
.77663 .42813 .78263 .43734 .79617 .43354 .79018 .42392 Mtetra
.573 .664 .899 r
.79018 .42392 .79617 .43354 .81005 .4328 .80403 .42249 Mtetra
.267 .473 .874 r
.80403 .42249 .81005 .4328 .82464 .43885 .81868 .42892 Mtetra
0 .233 .752 r
.81868 .42892 .82464 .43885 .83983 .44942 .83416 .4423 Mtetra
.164 .503 .909 r
.83416 .4423 .83983 .44942 .85438 .45165 .84909 .44796 Mtetra
.86 .932 .871 r
.84909 .44796 .85438 .45165 .86744 .43862 .86229 .43546 Mtetra
.941 .922 .762 r
.86229 .43546 .86744 .43862 .88002 .42115 .87476 .41612 Mtetra
.828 .894 .888 r
.87476 .41612 .88002 .42115 .89341 .41129 .8881 .40516 Mtetra
0 .483 .86 r
.26282 .59144 .2704 .59612 .28126 .5988 .27363 .59506 Mtetra
.758 .242 0 r
.27363 .59506 .28126 .5988 .29168 .60935 .28393 .60728 Mtetra
.247 0 0 r
.28393 .60728 .29168 .60935 .30266 .61333 .29497 .61077 Mtetra
.893 .845 .79 r
.29497 .61077 .30266 .61333 .3148 .60005 .30738 .59425 Mtetra
.889 .767 .72 r
.30738 .59425 .3148 .60005 .32734 .5795 .32017 .57087 Mtetra
.82 .731 .767 r
.32017 .57087 .32734 .5795 .33946 .56571 .33237 .55636 Mtetra
.711 .699 .836 r
.33237 .55636 .33946 .56571 .35116 .55949 .34409 .5502 Mtetra
.669 .687 .858 r
.34409 .5502 .35116 .55949 .36277 .55596 .35576 .54596 Mtetra
.693 .682 .834 r
.35576 .54596 .36277 .55596 .37444 .55214 .36752 .5405 Mtetra
.697 .655 .805 r
.36752 .5405 .37444 .55214 .38621 .54709 .37936 .5343 Mtetra
.673 .629 .797 r
.37936 .5343 .38621 .54709 .39806 .54092 .39119 .52908 Mtetra
.641 .63 .824 r
.39119 .52908 .39806 .54092 .40995 .53474 .403 .52563 Mtetra
.614 .675 .884 r
.403 .52563 .40995 .53474 .42183 .52978 .41483 .52327 Mtetra
.592 .741 .947 r
.41483 .52327 .42183 .52978 .43372 .52624 .42671 .52111 Mtetra
.582 .786 .976 r
.42671 .52111 .43372 .52624 .44565 .5235 .43866 .51873 Mtetra
.589 .803 .981 r
.43866 .51873 .44565 .5235 .45763 .52091 .45068 .51608 Mtetra
.603 .806 .977 r
.45068 .51608 .45763 .52091 .46967 .51817 .46276 .51315 Mtetra
.617 .804 .972 r
.46276 .51315 .46967 .51817 .48178 .51523 .47491 .50999 Mtetra
.628 .801 .965 r
.47491 .50999 .48178 .51523 .49395 .5121 .48712 .50663 Mtetra
.636 .796 .959 r
.48712 .50663 .49395 .5121 .50618 .50881 .4994 .50311 Mtetra
.642 .791 .954 r
.4994 .50311 .50618 .50881 .51846 .50538 .51172 .49948 Mtetra
.646 .786 .949 r
.51172 .49948 .51846 .50538 .53081 .50184 .52411 .49576 Mtetra
.649 .782 .945 r
.52411 .49576 .53081 .50184 .54321 .49818 .53655 .49198 Mtetra
.651 .78 .942 r
.53655 .49198 .54321 .49818 .55567 .49441 .54905 .48813 Mtetra
.653 .779 .941 r
.54905 .48813 .55567 .49441 .56819 .49054 .56161 .48421 Mtetra
.655 .779 .94 r
.56161 .48421 .56819 .49054 .58076 .48655 .57423 .48023 Mtetra
.656 .781 .94 r
.57423 .48023 .58076 .48655 .59339 .48246 .5869 .4762 Mtetra
.657 .784 .942 r
.5869 .4762 .59339 .48246 .60607 .47824 .59962 .4721 Mtetra
.659 .789 .944 r
.59962 .4721 .60607 .47824 .6188 .4739 .61241 .46791 Mtetra
.661 .796 .947 r
.61241 .46791 .6188 .4739 .63159 .46941 .62524 .46362 Mtetra
.665 .805 .95 r
.62524 .46362 .63159 .46941 .64442 .46476 .63813 .45918 Mtetra
.671 .815 .953 r
.63813 .45918 .64442 .46476 .6573 .45992 .65107 .45451 Mtetra
.678 .825 .954 r
.65107 .45451 .6573 .45992 .67023 .45488 .66405 .44958 Mtetra
.687 .832 .953 r
.66405 .44958 .67023 .45488 .6832 .4497 .67708 .44435 Mtetra
.696 .834 .949 r
.67708 .44435 .6832 .4497 .69623 .44468 .69014 .43885 Mtetra
.703 .821 .938 r
.69014 .43885 .69623 .44468 .70936 .44046 .70324 .43316 Mtetra
.696 .774 .912 r
.70324 .43316 .70936 .44046 .72264 .43769 .71641 .42768 Mtetra
.66 .691 .869 r
.71641 .42768 .72264 .43769 .73608 .4362 .72969 .42331 Mtetra
.611 .615 .83 r
.72969 .42331 .73608 .4362 .7496 .4347 .74317 .42076 Mtetra
.587 .587 .819 r
.74317 .42076 .7496 .4347 .76313 .43205 .75679 .41925 Mtetra
.604 .614 .835 r
.75679 .41925 .76313 .43205 .77663 .42813 .77044 .41697 Mtetra
.635 .66 .857 r
.77044 .41697 .77663 .42813 .79018 .42392 .78408 .41344 Mtetra
.579 .648 .883 r
.78408 .41344 .79018 .42392 .80403 .42249 .79795 .41191 Mtetra
.239 .451 .865 r
.79795 .41191 .80403 .42249 .81868 .42892 .81269 .41903 Mtetra
0 .124 .671 r
.81269 .41903 .81868 .42892 .83416 .4423 .82845 .43532 Mtetra
0 .352 .821 r
.82845 .43532 .83416 .4423 .84909 .44796 .84374 .44428 Mtetra
.851 .935 .88 r
.84374 .44428 .84909 .44796 .86229 .43546 .85707 .4322 Mtetra
.952 .912 .739 r
.85707 .4322 .86229 .43546 .87476 .41612 .86944 .411 Mtetra
.847 .894 .871 r
.86944 .411 .87476 .41612 .8881 .40516 .88273 .39896 Mtetra
0 .399 .797 r
.25517 .58664 .26282 .59144 .27363 .59506 .26593 .59115 Mtetra
.795 .299 0 r
.26593 .59115 .27363 .59506 .28393 .60728 .27612 .60498 Mtetra
0 .396 .683 r
.27612 .60498 .28393 .60728 .29497 .61077 .2872 .60819 Mtetra
.906 .831 .762 r
.2872 .60819 .29497 .61077 .30738 .59425 .29988 .58876 Mtetra
.9 .766 .705 r
.29988 .58876 .30738 .59425 .32017 .57087 .31294 .56228 Mtetra
.833 .733 .754 r
.31294 .56228 .32017 .57087 .33237 .55636 .32528 .54601 Mtetra
.726 .686 .811 r
.32528 .54601 .33237 .55636 .34409 .5502 .33711 .53859 Mtetra
.684 .651 .811 r
.33711 .53859 .34409 .5502 .35576 .54596 .34885 .53312 Mtetra
.674 .629 .796 r
.34885 .53312 .35576 .54596 .36752 .5405 .36062 .52785 Mtetra
.646 .619 .809 r
.36062 .52785 .36752 .5405 .37936 .5343 .37236 .52406 Mtetra
.608 .647 .863 r
.37236 .52406 .37936 .5343 .39119 .52908 .38409 .5219 Mtetra
.574 .714 .938 r
.38409 .5219 .39119 .52908 .403 .52563 .39585 .52029 Mtetra
.556 .77 .978 r
.39585 .52029 .403 .52563 .41483 .52327 .40769 .51846 Mtetra
.568 .794 .984 r
.40769 .51846 .41483 .52327 .42671 .52111 .41962 .5162 Mtetra
.594 .8 .978 r
.41962 .5162 .42671 .52111 .43866 .51873 .43161 .51349 Mtetra
.616 .796 .968 r
.43161 .51349 .43866 .51873 .45068 .51608 .44368 .51043 Mtetra
.63 .787 .957 r
.44368 .51043 .45068 .51608 .46276 .51315 .45581 .50712 Mtetra
.638 .777 .947 r
.45581 .50712 .46276 .51315 .47491 .50999 .468 .50367 Mtetra
.642 .77 .941 r
.468 .50367 .47491 .50999 .48712 .50663 .48025 .50013 Mtetra
.644 .766 .937 r
.48025 .50013 .48712 .50663 .4994 .50311 .49256 .49654 Mtetra
.646 .765 .936 r
.49256 .49654 .4994 .50311 .51172 .49948 .50493 .49289 Mtetra
.648 .766 .935 r
.50493 .49289 .51172 .49948 .52411 .49576 .51735 .48917 Mtetra
.649 .768 .935 r
.51735 .48917 .52411 .49576 .53655 .49198 .52983 .4854 Mtetra
.651 .77 .936 r
.52983 .4854 .53655 .49198 .54905 .48813 .54237 .48155 Mtetra
.653 .771 .936 r
.54237 .48155 .54905 .48813 .56161 .48421 .55497 .47762 Mtetra
.655 .773 .935 r
.55497 .47762 .56161 .48421 .57423 .48023 .56763 .47362 Mtetra
.657 .774 .935 r
.56763 .47362 .57423 .48023 .5869 .4762 .58034 .46954 Mtetra
.66 .774 .934 r
.58034 .46954 .5869 .4762 .59962 .4721 .59311 .46537 Mtetra
.662 .773 .932 r
.59311 .46537 .59962 .4721 .61241 .46791 .60593 .46112 Mtetra
.664 .773 .931 r
.60593 .46112 .61241 .46791 .62524 .46362 .61881 .45678 Mtetra
.666 .773 .93 r
.61881 .45678 .62524 .46362 .63813 .45918 .63175 .45238 Mtetra
.667 .776 .931 r
.63175 .45238 .63813 .45918 .65107 .45451 .64474 .44791 Mtetra
.669 .784 .935 r
.64474 .44791 .65107 .45451 .66405 .44958 .65778 .44334 Mtetra
.675 .799 .941 r
.65778 .44334 .66405 .44958 .67708 .44435 .67088 .43854 Mtetra
.686 .817 .946 r
.67088 .43854 .67708 .44435 .69014 .43885 .68401 .43335 Mtetra
.701 .833 .946 r
.68401 .43335 .69014 .43885 .70324 .43316 .69717 .42766 Mtetra
.714 .838 .941 r
.69717 .42766 .70324 .43316 .71641 .42768 .71035 .42152 Mtetra
.72 .819 .927 r
.71035 .42152 .71641 .42768 .72969 .42331 .72357 .41519 Mtetra
.699 .756 .896 r
.72357 .41519 .72969 .42331 .74317 .42076 .73687 .40944 Mtetra
.647 .662 .85 r
.73687 .40944 .74317 .42076 .75679 .41925 .75034 .40537 Mtetra
.608 .6 .818 r
.75034 .40537 .75679 .41925 .77044 .41697 .764 .40283 Mtetra
.603 .595 .816 r
.764 .40283 .77044 .41697 .78408 .41344 .77775 .40052 Mtetra
.551 .587 .844 r
.77775 .40052 .78408 .41344 .79795 .41191 .79175 .40026 Mtetra
.192 .398 .835 r
.79175 .40026 .79795 .41191 .81269 .41903 .80666 .40917 Mtetra
0 .014 .576 r
.80666 .40917 .81269 .41903 .82845 .43532 .82272 .42865 Mtetra
0 .204 .706 r
.82272 .42865 .82845 .43532 .84374 .44428 .83834 .44058 Mtetra
.847 .935 .884 r
.83834 .44058 .84374 .44428 .85707 .4322 .85177 .42867 Mtetra
.96 .899 .72 r
.85177 .42867 .85707 .4322 .86944 .411 .86404 .40569 Mtetra
.861 .89 .855 r
.86404 .40569 .86944 .411 .88273 .39896 .87731 .39262 Mtetra
0 .325 .735 r
.24746 .58175 .25517 .58664 .26593 .59115 .25818 .58702 Mtetra
.819 .338 .023 r
.25818 .58702 .26593 .59115 .27612 .60498 .26825 .60224 Mtetra
0 .436 .739 r
.26825 .60224 .27612 .60498 .2872 .60819 .27937 .60535 Mtetra
.911 .816 .741 r
.27937 .60535 .2872 .60819 .29988 .58876 .29229 .58341 Mtetra
.908 .762 .688 r
.29229 .58341 .29988 .58876 .31294 .56228 .30568 .55322 Mtetra
.847 .727 .731 r
.30568 .55322 .31294 .56228 .32528 .54601 .31828 .53372 Mtetra
.733 .66 .777 r
.31828 .53372 .32528 .54601 .33711 .53859 .33021 .52479 Mtetra
.651 .606 .791 r
.33021 .52479 .33711 .53859 .34885 .53312 .34189 .52054 Mtetra
.603 .601 .823 r
.34189 .52054 .34885 .53312 .36062 .52785 .35351 .51857 Mtetra
.558 .649 .896 r
.35351 .51857 .36062 .52785 .37236 .52406 .36513 .51773 Mtetra
.523 .723 .965 r
.36513 .51773 .37236 .52406 .38409 .5219 .37683 .51683 Mtetra
.53 .77 .986 r
.37683 .51683 .38409 .5219 .39585 .52029 .38863 .51531 Mtetra
.569 .789 .982 r
.38863 .51531 .39585 .52029 .40769 .51846 .40052 .51308 Mtetra
.603 .787 .969 r
.40052 .51308 .40769 .51846 .41962 .5162 .41249 .51031 Mtetra
.622 .776 .955 r
.41249 .51031 .41962 .5162 .43161 .51349 .42453 .50724 Mtetra
.631 .768 .945 r
.42453 .50724 .43161 .51349 .44368 .51043 .43664 .50399 Mtetra
.636 .765 .94 r
.43664 .50399 .44368 .51043 .45581 .50712 .44881 .50064 Mtetra
.64 .765 .939 r
.44881 .50064 .45581 .50712 .468 .50367 .46103 .49717 Mtetra
.643 .766 .938 r
.46103 .49717 .468 .50367 .48025 .50013 .47332 .4936 Mtetra
.646 .767 .937 r
.47332 .4936 .48025 .50013 .49256 .49654 .48567 .48993 Mtetra
.648 .767 .935 r
.48567 .48993 .49256 .49654 .50493 .49289 .49807 .48619 Mtetra
.65 .766 .933 r
.49807 .48619 .50493 .49289 .51735 .48917 .51054 .48238 Mtetra
.652 .764 .931 r
.51054 .48238 .51735 .48917 .52983 .4854 .52306 .4785 Mtetra
.654 .763 .929 r
.52306 .4785 .52983 .4854 .54237 .48155 .53563 .47457 Mtetra
.655 .761 .928 r
.53563 .47457 .54237 .48155 .55497 .47762 .54827 .47059 Mtetra
.656 .761 .927 r
.54827 .47059 .55497 .47762 .56763 .47362 .56097 .46655 Mtetra
.657 .761 .927 r
.56097 .46655 .56763 .47362 .58034 .46954 .57372 .46248 Mtetra
.657 .763 .928 r
.57372 .46248 .58034 .46954 .59311 .46537 .58653 .45838 Mtetra
.658 .766 .93 r
.58653 .45838 .59311 .46537 .60593 .46112 .5994 .45423 Mtetra
.659 .771 .932 r
.5994 .45423 .60593 .46112 .61881 .45678 .61233 .45003 Mtetra
.661 .777 .935 r
.61233 .45003 .61881 .45678 .63175 .45238 .62531 .44572 Mtetra
.666 .782 .936 r
.62531 .44572 .63175 .45238 .64474 .44791 .63835 .44124 Mtetra
.672 .784 .934 r
.63835 .44124 .64474 .44791 .65778 .44334 .65144 .43656 Mtetra
.676 .784 .931 r
.65144 .43656 .65778 .44334 .67088 .43854 .66457 .43172 Mtetra
.68 .785 .929 r
.66457 .43172 .67088 .43854 .68401 .43335 .67777 .42674 Mtetra
.687 .795 .932 r
.67777 .42674 .68401 .43335 .69717 .42766 .691 .42152 Mtetra
.702 .816 .936 r
.691 .42152 .69717 .42766 .71035 .42152 .70426 .41578 Mtetra
.724 .836 .934 r
.70426 .41578 .71035 .42152 .72357 .41519 .71753 .40927 Mtetra
.741 .836 .923 r
.71753 .40927 .72357 .41519 .73687 .40944 .7308 .40213 Mtetra
.737 .794 .898 r
.7308 .40213 .73687 .40944 .75034 .40537 .74411 .39493 Mtetra
.693 .702 .854 r
.74411 .39493 .75034 .40537 .764 .40283 .75754 .38893 Mtetra
.63 .613 .815 r
.75754 .38893 .764 .40283 .77775 .40052 .77121 .38531 Mtetra
.52 .536 .812 r
.77121 .38531 .77775 .40052 .79175 .40026 .78535 .38657 Mtetra
.122 .312 .782 r
.78535 .38657 .79175 .40026 .80666 .40917 .80055 .3988 Mtetra
0 0 .487 r
.80055 .3988 .80666 .40917 .82272 .42865 .81695 .42208 Mtetra
0 .09 .604 r
.81695 .42208 .82272 .42865 .83834 .44058 .83284 .43657 Mtetra
.845 .927 .884 r
.83284 .43657 .83834 .44058 .85177 .42867 .84636 .42466 Mtetra
.963 .885 .706 r
.84636 .42466 .85177 .42867 .86404 .40569 .85857 .40012 Mtetra
.871 .884 .842 r
.85857 .40012 .86404 .40569 .87731 .39262 .87182 .38617 Mtetra
0 .266 .681 r
.23968 .57683 .24746 .58175 .25818 .58702 .25036 .58267 Mtetra
.832 .36 .046 r
.25036 .58267 .25818 .58702 .26825 .60224 .26036 .59882 Mtetra
0 .511 .831 r
.26036 .59882 .26825 .60224 .27937 .60535 .27152 .60157 Mtetra
.908 .795 .723 r
.27152 .60157 .27937 .60535 .29229 .58341 .28469 .57729 Mtetra
.908 .749 .673 r
.28469 .57729 .29229 .58341 .30568 .55322 .29843 .54325 Mtetra
.853 .716 .711 r
.29843 .54325 .30568 .55322 .31828 .53372 .31129 .52059 Mtetra
.722 .645 .772 r
.31129 .52059 .31828 .53372 .33021 .52479 .32321 .51206 Mtetra
.572 .585 .828 r
.32321 .51206 .33021 .52479 .34189 .52054 .33471 .51117 Mtetra
.472 .609 .906 r
.33471 .51117 .34189 .52054 .35351 .51857 .34619 .51218 Mtetra
.448 .691 .969 r
.34619 .51218 .35351 .51857 .36513 .51773 .35778 .51243 Mtetra
.501 .752 .985 r
.35778 .51243 .36513 .51773 .37683 .51683 .36952 .51142 Mtetra
.564 .773 .977 r
.36952 .51142 .37683 .51683 .38863 .51531 .38137 .50941 Mtetra
.601 .769 .96 r
.38137 .50941 .38863 .51531 .40052 .51308 .3933 .5068 Mtetra
.619 .763 .948 r
.3933 .5068 .40052 .51308 .41249 .51031 .40532 .50386 Mtetra
.629 .762 .942 r
.40532 .50386 .41249 .51031 .42453 .50724 .4174 .50069 Mtetra
.636 .762 .939 r
.4174 .50069 .42453 .50724 .43664 .50399 .42954 .49733 Mtetra
.641 .761 .935 r
.42954 .49733 .43664 .50399 .44881 .50064 .44175 .49384 Mtetra
.644 .758 .932 r
.44175 .49384 .44881 .50064 .46103 .49717 .45401 .49025 Mtetra
.647 .756 .929 r
.45401 .49025 .46103 .49717 .47332 .4936 .46634 .48658 Mtetra
.648 .755 .927 r
.46634 .48658 .47332 .4936 .48567 .48993 .47872 .48286 Mtetra
.649 .754 .926 r
.47872 .48286 .48567 .48993 .49807 .48619 .49116 .47909 Mtetra
.65 .755 .926 r
.49116 .47909 .49807 .48619 .51054 .48238 .50366 .47527 Mtetra
.652 .756 .926 r
.50366 .47527 .51054 .48238 .52306 .4785 .51622 .4714 Mtetra
.653 .758 .926 r
.51622 .4714 .52306 .4785 .53563 .47457 .52884 .46747 Mtetra
.655 .759 .927 r
.52884 .46747 .53563 .47457 .54827 .47059 .54151 .46346 Mtetra
.657 .76 .926 r
.54151 .46346 .54827 .47059 .56097 .46655 .55425 .45938 Mtetra
.659 .761 .925 r
.55425 .45938 .56097 .46655 .57372 .46248 .56704 .4552 Mtetra
.662 .759 .923 r
.56704 .4552 .57372 .46248 .58653 .45838 .57989 .45093 Mtetra
.663 .756 .919 r
.57989 .45093 .58653 .45838 .5994 .45423 .59279 .44659 Mtetra
.665 .752 .915 r
.59279 .44659 .5994 .45423 .61233 .45003 .60576 .4422 Mtetra
.664 .747 .912 r
.60576 .4422 .61233 .45003 .62531 .44572 .61878 .4378 Mtetra
.662 .745 .912 r
.61878 .4378 .62531 .44572 .63835 .44124 .63186 .43346 Mtetra
.661 .75 .916 r
.63186 .43346 .63835 .44124 .65144 .43656 .64501 .42913 Mtetra
.664 .762 .923 r
.64501 .42913 .65144 .43656 .66457 .43172 .65821 .42467 Mtetra
.673 .777 .928 r
.65821 .42467 .66457 .43172 .67777 .42674 .67146 .41988 Mtetra
.685 .788 .929 r
.67146 .41988 .67777 .42674 .691 .42152 .68474 .41468 Mtetra
.696 .794 .925 r
.68474 .41468 .691 .42152 .70426 .41578 .69806 .4091 Mtetra
.711 .804 .923 r
.69806 .4091 .70426 .41578 .71753 .40927 .71141 .40299 Mtetra
.738 .825 .919 r
.71141 .40299 .71753 .40927 .7308 .40213 .72474 .39589 Mtetra
.77 .835 .902 r
.72474 .39589 .7308 .40213 .74411 .39493 .73803 .3875 Mtetra
.778 .804 .874 r
.73803 .3875 .74411 .39493 .75754 .38893 .75129 .37834 Mtetra
.715 .71 .844 r
.75129 .37834 .75754 .38893 .77121 .38531 .76473 .37118 Mtetra
.525 .555 .829 r
.76473 .37118 .77121 .38531 .78535 .38657 .77885 .37196 Mtetra
.022 .229 .735 r
.77885 .37196 .78535 .38657 .80055 .3988 .79431 .38743 Mtetra
0 0 .423 r
.79431 .38743 .80055 .3988 .81695 .42208 .81105 .41467 Mtetra
0 .029 .56 r
.81105 .41467 .81695 .42208 .83284 .43657 .82719 .43153 Mtetra
.836 .898 .883 r
.82719 .43153 .83284 .43657 .84636 .42466 .84082 .41992 Mtetra
.962 .869 .699 r
.84082 .41992 .84636 .42466 .85857 .40012 .85302 .3943 Mtetra
.878 .878 .831 r
.85302 .3943 .85857 .40012 .87182 .38617 .86628 .37965 Mtetra
0 .226 .639 r
.23182 .57194 .23968 .57683 .25036 .58267 .24248 .57814 Mtetra
.833 .361 .043 r
.24248 .57814 .25036 .58267 .26036 .59882 .25246 .59441 Mtetra
.233 .655 .959 r
.25246 .59441 .26036 .59882 .27152 .60157 .26375 .59579 Mtetra
.897 .764 .707 r
.26375 .59579 .27152 .60157 .28469 .57729 .27716 .56929 Mtetra
.899 .731 .665 r
.27716 .56929 .28469 .57729 .29843 .54325 .29114 .53323 Mtetra
.856 .716 .708 r
.29114 .53323 .29843 .54325 .31129 .52059 .3041 .50991 Mtetra
.717 .68 .813 r
.3041 .50991 .31129 .52059 .32321 .51206 .31595 .50291 Mtetra
.455 .608 .912 r
.31595 .50291 .32321 .51206 .33471 .51117 .32735 .50412 Mtetra
.338 .615 .952 r
.32735 .50412 .33471 .51117 .34619 .51218 .33879 .50611 Mtetra
.432 .697 .976 r
.33879 .50611 .34619 .51218 .35778 .51243 .3504 .50639 Mtetra
.536 .742 .97 r
.3504 .50639 .35778 .51243 .36952 .51142 .36218 .50507 Mtetra
.587 .751 .955 r
.36218 .50507 .36952 .51142 .38137 .50941 .37407 .50285 Mtetra
.612 .753 .945 r
.37407 .50285 .38137 .50941 .3933 .5068 .38605 .50009 Mtetra
.626 .754 .939 r
.38605 .50009 .3933 .5068 .40532 .50386 .39809 .49702 Mtetra
.633 .753 .934 r
.39809 .49702 .40532 .50386 .4174 .50069 .41021 .49375 Mtetra
.638 .752 .931 r
.41021 .49375 .4174 .50069 .42954 .49733 .42239 .49035 Mtetra
.641 .753 .93 r
.42239 .49035 .42954 .49733 .44175 .49384 .43463 .48685 Mtetra
.643 .754 .929 r
.43463 .48685 .44175 .49384 .45401 .49025 .44693 .48327 Mtetra
.645 .756 .93 r
.44693 .48327 .45401 .49025 .46634 .48658 .45929 .47961 Mtetra
.647 .758 .93 r
.45929 .47961 .46634 .48658 .47872 .48286 .47171 .47589 Mtetra
.648 .759 .93 r
.47171 .47589 .47872 .48286 .49116 .47909 .48419 .47211 Mtetra
.65 .76 .93 r
.48419 .47211 .49116 .47909 .50366 .47527 .49672 .46827 Mtetra
.651 .761 .93 r
.49672 .46827 .50366 .47527 .51622 .4714 .50932 .46437 Mtetra
.652 .761 .93 r
.50932 .46437 .51622 .4714 .52884 .46747 .52198 .46042 Mtetra
.653 .762 .93 r
.52198 .46042 .52884 .46747 .54151 .46346 .53469 .45642 Mtetra
.654 .764 .93 r
.53469 .45642 .54151 .46346 .55425 .45938 .54747 .45238 Mtetra
.654 .766 .932 r
.54747 .45238 .55425 .45938 .56704 .4552 .5603 .44832 Mtetra
.654 .771 .935 r
.5603 .44832 .56704 .4552 .57989 .45093 .5732 .44423 Mtetra
.655 .777 .939 r
.5732 .44423 .57989 .45093 .59279 .44659 .58615 .44006 Mtetra
.658 .785 .942 r
.58615 .44006 .59279 .44659 .60576 .4422 .59916 .43577 Mtetra
.664 .792 .943 r
.59916 .43577 .60576 .4422 .61878 .4378 .61223 .43126 Mtetra
.673 .792 .938 r
.61223 .43126 .61878 .4378 .63186 .43346 .62535 .42649 Mtetra
.679 .781 .928 r
.62535 .42649 .63186 .43346 .64501 .42913 .63852 .42152 Mtetra
.678 .763 .915 r
.63852 .42152 .64501 .42913 .65821 .42467 .65174 .41656 Mtetra
.672 .748 .908 r
.65174 .41656 .65821 .42467 .67146 .41988 .66504 .41177 Mtetra
.67 .749 .909 r
.66504 .41177 .67146 .41988 .68474 .41468 .67839 .40701 Mtetra
.682 .766 .915 r
.67839 .40701 .68474 .41468 .69806 .4091 .69178 .40186 Mtetra
.704 .787 .916 r
.69178 .40186 .69806 .4091 .71141 .40299 .70519 .39592 Mtetra
.731 .802 .908 r
.70519 .39592 .71141 .40299 .72474 .39589 .71858 .38896 Mtetra
.768 .816 .89 r
.71858 .38896 .72474 .39589 .73803 .3875 .73192 .38041 Mtetra
.8 .819 .866 r
.73192 .38041 .73803 .3875 .75129 .37834 .74517 .37015 Mtetra
.776 .786 .861 r
.74517 .37015 .75129 .37834 .76473 .37118 .7585 .36074 Mtetra
.552 .642 .893 r
.7585 .36074 .76473 .37118 .77885 .37196 .77252 .35987 Mtetra
0 .164 .703 r
.77252 .35987 .77885 .37196 .79431 .38743 .78803 .37595 Mtetra
0 0 .379 r
.78803 .37595 .79431 .38743 .81105 .41467 .80493 .40522 Mtetra
0 .015 .572 r
.80493 .40522 .81105 .41467 .82719 .43153 .82129 .42435 Mtetra
.796 .831 .879 r
.82129 .42435 .82719 .43153 .84082 .41992 .83512 .4141 Mtetra
.955 .851 .701 r
.83512 .4141 .84082 .41992 .85302 .3943 .8474 .38827 Mtetra
.881 .873 .825 r
.8474 .38827 .85302 .3943 .86628 .37965 .86069 .37317 Mtetra
0 .215 .624 r
.22388 .56712 .23182 .57194 .24248 .57814 .23455 .57338 Mtetra
.814 .33 0 r
.23455 .57338 .24248 .57814 .25246 .59441 .24459 .58863 Mtetra
.537 .751 .975 r
.24459 .58863 .25246 .59441 .26375 .59579 .25612 .58721 Mtetra
.879 .731 .693 r
.25612 .58721 .26375 .59579 .27716 .56929 .26973 .55915 Mtetra
.883 .714 .668 r
.26973 .55915 .27716 .56929 .29114 .53323 .28367 .52484 Mtetra
.86 .738 .727 r
.28367 .52484 .29114 .53323 .3041 .50991 .29655 .50388 Mtetra
.739 .792 .895 r
.29655 .50388 .3041 .50991 .31595 .50291 .30841 .49731 Mtetra
.4 .699 .982 r
.30841 .49731 .31595 .50291 .32735 .50412 .31988 .49773 Mtetra
.352 .648 .966 r
.31988 .49773 .32735 .50412 .33879 .50611 .33137 .49914 Mtetra
.467 .683 .96 r
.33137 .49914 .33879 .50611 .3504 .50639 .34302 .49927 Mtetra
.55 .713 .948 r
.34302 .49927 .3504 .50639 .36218 .50507 .35482 .49797 Mtetra
.593 .731 .94 r
.35482 .49797 .36218 .50507 .37407 .50285 .36673 .49574 Mtetra
.615 .739 .934 r
.36673 .49574 .37407 .50285 .38605 .50009 .37874 .49298 Mtetra
.626 .743 .931 r
.37874 .49298 .38605 .50009 .39809 .49702 .39082 .48993 Mtetra
.633 .747 .93 r
.39082 .48993 .39809 .49702 .41021 .49375 .40297 .48665 Mtetra
.638 .749 .929 r
.40297 .48665 .41021 .49375 .42239 .49035 .41518 .48323 Mtetra
.641 .751 .928 r
.41518 .48323 .42239 .49035 .43463 .48685 .42745 .4797 Mtetra
.644 .751 .927 r
.42745 .4797 .43463 .48685 .44693 .48327 .43979 .47607 Mtetra
.647 .752 .926 r
.43979 .47607 .44693 .48327 .45929 .47961 .45218 .47234 Mtetra
.649 .751 .924 r
.45218 .47234 .45929 .47961 .47171 .47589 .46464 .46853 Mtetra
.651 .75 .922 r
.46464 .46853 .47171 .47589 .48419 .47211 .47716 .46466 Mtetra
.652 .749 .921 r
.47716 .46466 .48419 .47211 .49672 .46827 .48973 .46074 Mtetra
.654 .748 .919 r
.48973 .46074 .49672 .46827 .50932 .46437 .50237 .45675 Mtetra
.656 .747 .917 r
.50237 .45675 .50932 .46437 .52198 .46042 .51506 .45268 Mtetra
.658 .746 .915 r
.51506 .45268 .52198 .46042 .53469 .45642 .52781 .44853 Mtetra
.66 .743 .912 r
.52781 .44853 .53469 .45642 .54747 .45238 .54063 .44429 Mtetra
.662 .739 .907 r
.54063 .44429 .54747 .45238 .5603 .44832 .5535 .43998 Mtetra
.662 .734 .903 r
.5535 .43998 .5603 .44832 .5732 .44423 .56643 .43562 Mtetra
.66 .727 .899 r
.56643 .43562 .5732 .44423 .58615 .44006 .57941 .43131 Mtetra
.657 .723 .897 r
.57941 .43131 .58615 .44006 .59916 .43577 .59246 .42709 Mtetra
.652 .724 .901 r
.59246 .42709 .59916 .43577 .61223 .43126 .60558 .42302 Mtetra
.649 .735 .912 r
.60558 .42302 .61223 .43126 .62535 .42649 .61876 .41903 Mtetra
.653 .76 .928 r
.61876 .41903 .62535 .42649 .63852 .42152 .63201 .41486 Mtetra
.668 .791 .94 r
.63201 .41486 .63852 .42152 .65174 .41656 .64529 .41015 Mtetra
.688 .806 .938 r
.64529 .41015 .65174 .41656 .66504 .41177 .65861 .40479 Mtetra
.698 .793 .923 r
.65861 .40479 .66504 .41177 .67839 .40701 .67197 .39907 Mtetra
.694 .765 .906 r
.67197 .39907 .67839 .40701 .69178 .40186 .68539 .39343 Mtetra
.695 .753 .896 r
.68539 .39343 .69178 .40186 .70519 .39592 .69885 .38767 Mtetra
.72 .767 .89 r
.69885 .38767 .70519 .39592 .71858 .38896 .71231 .38093 Mtetra
.758 .785 .876 r
.71231 .38093 .71858 .38896 .73192 .38041 .72571 .3725 Mtetra
.785 .796 .862 r
.72571 .3725 .73192 .38041 .74517 .37015 .73905 .36269 Mtetra
.767 .805 .883 r
.73905 .36269 .74517 .37015 .7585 .36074 .75249 .35399 Mtetra
.527 .738 .971 r
.75249 .35399 .7585 .36074 .77252 .35987 .76651 .35257 Mtetra
0 .128 .647 r
.76651 .35257 .77252 .35987 .78803 .37595 .78184 .3661 Mtetra
.617 .199 0 r
.78184 .3661 .78803 .37595 .80493 .40522 .79857 .39347 Mtetra
0 .029 .597 r
.79857 .39347 .80493 .40522 .82129 .42435 .81507 .41417 Mtetra
.718 .734 .864 r
.81507 .41417 .82129 .42435 .83512 .4141 .82922 .40681 Mtetra
.937 .829 .712 r
.82922 .40681 .83512 .4141 .8474 .38827 .8417 .38197 Mtetra
.88 .868 .822 r
.8417 .38197 .8474 .38827 .86069 .37317 .85505 .36673 Mtetra
0 .251 .659 r
.21587 .56227 .22388 .56712 .23455 .57338 .22657 .56816 Mtetra
.755 .242 0 r
.22657 .56816 .23455 .57338 .24459 .58863 .23679 .5812 Mtetra
.696 .747 .891 r
.23679 .5812 .24459 .58863 .25612 .58721 .24864 .57606 Mtetra
.862 .706 .687 r
.24864 .57606 .25612 .58721 .26973 .55915 .26234 .54783 Mtetra
.865 .704 .682 r
.26234 .54783 .26973 .55915 .28367 .52484 .276 .51846 Mtetra
.859 .776 .769 r
.276 .51846 .28367 .52484 .29655 .50388 .28865 .50175 Mtetra
.756 .916 .945 r
.28865 .50175 .29655 .50388 .30841 .49731 .3006 .49463 Mtetra
.514 .848 .997 r
.3006 .49463 .30841 .49731 .31988 .49773 .31229 .49208 Mtetra
.474 .732 .983 r
.31229 .49208 .31988 .49773 .33137 .49914 .32392 .49152 Mtetra
.507 .681 .944 r
.32392 .49152 .33137 .49914 .34302 .49927 .33562 .49116 Mtetra
.55 .686 .929 r
.33562 .49116 .34302 .49927 .35482 .49797 .34743 .49008 Mtetra
.586 .706 .926 r
.34743 .49008 .35482 .49797 .36673 .49574 .35936 .48813 Mtetra
.61 .724 .926 r
.35936 .48813 .36673 .49574 .37874 .49298 .37139 .48553 Mtetra
.623 .734 .926 r
.37139 .48553 .37874 .49298 .39082 .48993 .38349 .48253 Mtetra
.631 .739 .925 r
.38349 .48253 .39082 .48993 .40297 .48665 .39567 .47929 Mtetra
.637 .743 .925 r
.39567 .47929 .40297 .48665 .41518 .48323 .40791 .47587 Mtetra
.642 .745 .924 r
.40791 .47587 .41518 .48323 .42745 .4797 .42022 .4723 Mtetra
.645 .746 .923 r
.42022 .4723 .42745 .4797 .43979 .47607 .43259 .46863 Mtetra
.647 .746 .922 r
.43259 .46863 .43979 .47607 .45218 .47234 .44502 .46488 Mtetra
.648 .748 .922 r
.44502 .46488 .45218 .47234 .46464 .46853 .45752 .46107 Mtetra
.65 .749 .922 r
.45752 .46107 .46464 .46853 .47716 .46466 .47007 .45718 Mtetra
.653 .75 .921 r
.47007 .45718 .47716 .46466 .48973 .46074 .48268 .4532 Mtetra
.655 .75 .92 r
.48268 .4532 .48973 .46074 .50237 .45675 .49535 .44912 Mtetra
.658 .75 .918 r
.49535 .44912 .50237 .45675 .51506 .45268 .50809 .44495 Mtetra
.66 .748 .916 r
.50809 .44495 .51506 .45268 .52781 .44853 .52088 .4407 Mtetra
.661 .747 .914 r
.52088 .4407 .52781 .44853 .54063 .44429 .53373 .43639 Mtetra
.662 .746 .913 r
.53373 .43639 .54063 .44429 .5535 .43998 .54664 .43205 Mtetra
.663 .747 .912 r
.54664 .43205 .5535 .43998 .56643 .43562 .5596 .42764 Mtetra
.666 .747 .911 r
.5596 .42764 .56643 .43562 .57941 .43131 .57263 .4231 Mtetra
.67 .744 .906 r
.57263 .4231 .57941 .43131 .59246 .42709 .58571 .4184 Mtetra
.673 .733 .895 r
.58571 .4184 .59246 .42709 .60558 .42302 .59885 .41356 Mtetra
.669 .714 .882 r
.59885 .41356 .60558 .42302 .61876 .41903 .61205 .40877 Mtetra
.657 .692 .871 r
.61205 .40877 .61876 .41903 .63201 .41486 .62531 .40434 Mtetra
.644 .681 .871 r
.62531 .40434 .63201 .41486 .64529 .41015 .63866 .4004 Mtetra
.642 .699 .887 r
.63866 .4004 .64529 .41015 .65861 .40479 .65208 .39654 Mtetra
.665 .747 .912 r
.65208 .39654 .65861 .40479 .67197 .39907 .66553 .3919 Mtetra
.704 .792 .919 r
.66553 .3919 .67197 .39907 .68539 .39343 .67898 .38593 Mtetra
.729 .791 .902 r
.67898 .38593 .68539 .39343 .69885 .38767 .69243 .37895 Mtetra
.732 .761 .876 r
.69243 .37895 .69885 .38767 .71231 .38093 .70591 .37153 Mtetra
.735 .747 .861 r
.70591 .37153 .71231 .38093 .72571 .3725 .71939 .36372 Mtetra
.736 .763 .874 r
.71939 .36372 .72571 .3725 .73905 .36269 .73293 .35605 Mtetra
.694 .811 .937 r
.73293 .35605 .73905 .36269 .75249 .35399 .74664 .35029 Mtetra
.386 .775 .989 r
.74664 .35029 .75249 .35399 .76651 .35257 .76076 .3493 Mtetra
.376 0 0 r
.76076 .3493 .76651 .35257 .78184 .3661 .77577 .35829 Mtetra
.592 .136 0 r
.77577 .35829 .78184 .3661 .79857 .39347 .79206 .38042 Mtetra
0 .055 .621 r
.79206 .38042 .79857 .39347 .81507 .41417 .80856 .40123 Mtetra
.623 .639 .846 r
.80856 .40123 .81507 .41417 .82922 .40681 .82311 .39774 Mtetra
.908 .801 .73 r
.82311 .39774 .82922 .40681 .8417 .38197 .83589 .37517 Mtetra
.871 .856 .824 r
.83589 .37517 .8417 .38197 .85505 .36673 .84936 .36023 Mtetra
0 .346 .755 r
.2078 .5571 .21587 .56227 .22657 .56816 .21859 .56218 Mtetra
.585 .045 0 r
.21859 .56218 .22657 .56816 .23679 .5812 .22906 .57216 Mtetra
.753 .723 .825 r
.22906 .57216 .23679 .5812 .24864 .57606 .24123 .56359 Mtetra
.849 .694 .689 r
.24123 .56359 .24864 .57606 .26234 .54783 .25488 .53671 Mtetra
.849 .706 .705 r
.25488 .53671 .26234 .54783 .276 .51846 .26819 .51301 Mtetra
.833 .806 .824 r
.26819 .51301 .276 .51846 .28865 .50175 .28057 .50078 Mtetra
.725 .947 .952 r
.28057 .50078 .28865 .50175 .3006 .49463 .29256 .49395 Mtetra
.639 .94 .961 r
.29256 .49395 .3006 .49463 .31229 .49208 .3045 .48848 Mtetra
.625 .856 .986 r
.3045 .48848 .31229 .49208 .32392 .49152 .31637 .48467 Mtetra
.577 .735 .95 r
.31637 .48467 .32392 .49152 .33562 .49116 .32818 .4827 Mtetra
.562 .682 .92 r
.32818 .4827 .33562 .49116 .34743 .49008 .34003 .48138 Mtetra
.576 .682 .913 r
.34003 .48138 .34743 .49008 .35936 .48813 .35196 .47976 Mtetra
.597 .7 .915 r
.35196 .47976 .35936 .48813 .37139 .48553 .36399 .47753 Mtetra
.616 .718 .918 r
.36399 .47753 .37139 .48553 .38349 .48253 .37612 .47475 Mtetra
.629 .729 .92 r
.37612 .47475 .38349 .48253 .39567 .47929 .38832 .47158 Mtetra
.635 .734 .919 r
.38832 .47158 .39567 .47929 .40791 .47587 .4006 .46821 Mtetra
.64 .738 .92 r
.4006 .46821 .40791 .47587 .42022 .4723 .41294 .46469 Mtetra
.643 .741 .92 r
.41294 .46469 .42022 .4723 .43259 .46863 .42534 .46103 Mtetra
.648 .744 .92 r
.42534 .46103 .43259 .46863 .44502 .46488 .43781 .45722 Mtetra
.652 .745 .917 r
.43781 .45722 .44502 .46488 .45752 .46107 .45034 .45327 Mtetra
.656 .743 .914 r
.45034 .45327 .45752 .46107 .47007 .45718 .46293 .44917 Mtetra
.658 .739 .909 r
.46293 .44917 .47007 .45718 .48268 .4532 .47558 .44499 Mtetra
.659 .735 .905 r
.47558 .44499 .48268 .4532 .49535 .44912 .48829 .44075 Mtetra
.659 .731 .903 r
.48829 .44075 .49535 .44912 .50809 .44495 .50106 .43652 Mtetra
.657 .73 .903 r
.50106 .43652 .50809 .44495 .52088 .4407 .51388 .4323 Mtetra
.656 .732 .905 r
.51388 .4323 .52088 .4407 .53373 .43639 .52677 .42811 Mtetra
.655 .735 .908 r
.52677 .42811 .53373 .43639 .54664 .43205 .53972 .42392 Mtetra
.655 .741 .913 r
.53972 .42392 .54664 .43205 .5596 .42764 .55273 .41974 Mtetra
.654 .747 .918 r
.55273 .41974 .5596 .42764 .57263 .4231 .5658 .41556 Mtetra
.655 .759 .926 r
.5658 .41556 .57263 .4231 .58571 .4184 .57893 .41132 Mtetra
.659 .775 .935 r
.57893 .41132 .58571 .4184 .59885 .41356 .59212 .40689 Mtetra
.672 .793 .939 r
.59212 .40689 .59885 .41356 .61205 .40877 .60537 .40201 Mtetra
.691 .797 .931 r
.60537 .40201 .61205 .40877 .62531 .40434 .61865 .39653 Mtetra
.699 .77 .907 r
.61865 .39653 .62531 .40434 .63866 .4004 .63198 .39071 Mtetra
.682 .718 .876 r
.63198 .39071 .63866 .4004 .65208 .39654 .64538 .38529 Mtetra
.657 .675 .856 r
.64538 .38529 .65208 .39654 .66553 .3919 .65886 .38066 Mtetra
.656 .676 .857 r
.65886 .38066 .66553 .3919 .67898 .38593 .67241 .37605 Mtetra
.694 .721 .87 r
.67241 .37605 .67898 .38593 .69243 .37895 .68596 .37004 Mtetra
.73 .757 .875 r
.68596 .37004 .69243 .37895 .70591 .37153 .69948 .36265 Mtetra
.717 .755 .882 r
.69948 .36265 .70591 .37153 .71939 .36372 .71308 .35581 Mtetra
.656 .76 .927 r
.71308 .35581 .71939 .36372 .73293 .35605 .72687 .35132 Mtetra
.537 .817 .998 r
.72687 .35132 .73293 .35605 .74664 .35029 .74086 .34864 Mtetra
.269 .76 .91 r
.74086 .34864 .74664 .35029 .76076 .3493 .75502 .34723 Mtetra
0 .422 .721 r
.75502 .34723 .76076 .3493 .77577 .35829 .76972 .35142 Mtetra
0 .018 .537 r
.76972 .35142 .77577 .35829 .79206 .38042 .78553 .36752 Mtetra
0 .089 .648 r
.78553 .36752 .79206 .38042 .80856 .40123 .8019 .38687 Mtetra
.536 .571 .837 r
.8019 .38687 .80856 .40123 .82311 .39774 .8168 .38693 Mtetra
.869 .77 .75 r
.8168 .38693 .82311 .39774 .83589 .37517 .82996 .36753 Mtetra
.853 .836 .829 r
.82996 .36753 .83589 .37517 .84936 .36023 .84358 .35339 Mtetra
.019 .477 .875 r
.19972 .55127 .2078 .5571 .21859 .56218 .21062 .55519 Mtetra
0 .269 .738 r
.21062 .55519 .21859 .56218 .22906 .57216 .22138 .56194 Mtetra
.771 .707 .791 r
.22138 .56194 .22906 .57216 .24123 .56359 .23376 .55119 Mtetra
.842 .693 .698 r
.23376 .55119 .24123 .56359 .25488 .53671 .24729 .52671 Mtetra
.838 .719 .733 r
.24729 .52671 .25488 .53671 .26819 .51301 .2603 .50753 Mtetra
.791 .812 .869 r
.2603 .50753 .26819 .51301 .28057 .50078 .2725 .49844 Mtetra
.68 .906 .975 r
.2725 .49844 .28057 .50078 .29256 .49395 .28444 .4931 Mtetra
.676 .944 .961 r
.28444 .4931 .29256 .49395 .3045 .48848 .29647 .48709 Mtetra
.711 .938 .96 r
.29647 .48709 .3045 .48848 .31637 .48467 .30856 .48064 Mtetra
.683 .856 .965 r
.30856 .48064 .31637 .48467 .32818 .4827 .3206 .47566 Mtetra
.621 .746 .936 r
.3206 .47566 .32818 .4827 .34003 .48138 .33257 .47266 Mtetra
.59 .688 .91 r
.33257 .47266 .34003 .48138 .35196 .47976 .34454 .47065 Mtetra
.591 .68 .902 r
.34454 .47065 .35196 .47976 .36399 .47753 .35659 .46864 Mtetra
.603 .691 .904 r
.35659 .46864 .36399 .47753 .37612 .47475 .36872 .46625 Mtetra
.617 .707 .909 r
.36872 .46625 .37612 .47475 .38832 .47158 .38093 .46342 Mtetra
.63 .721 .913 r
.38093 .46342 .38832 .47158 .4006 .46821 .39323 .4602 Mtetra
.639 .73 .914 r
.39323 .4602 .4006 .46821 .41294 .46469 .4056 .45666 Mtetra
.646 .732 .912 r
.4056 .45666 .41294 .46469 .42534 .46103 .41804 .45291 Mtetra
.65 .732 .909 r
.41804 .45291 .42534 .46103 .43781 .45722 .43054 .449 Mtetra
.653 .731 .907 r
.43054 .449 .43781 .45722 .45034 .45327 .44311 .445 Mtetra
.653 .731 .906 r
.44311 .445 .45034 .45327 .46293 .44917 .45573 .44096 Mtetra
.651 .733 .909 r
.45573 .44096 .46293 .44917 .47558 .44499 .46841 .43696 Mtetra
.648 .738 .915 r
.46841 .43696 .47558 .44499 .48829 .44075 .48115 .43305 Mtetra
.644 .747 .923 r
.48115 .43305 .48829 .44075 .50106 .43652 .49396 .42922 Mtetra
.642 .759 .933 r
.49396 .42922 .50106 .43652 .51388 .4323 .50682 .42539 Mtetra
.643 .772 .942 r
.50682 .42539 .51388 .4323 .52677 .42811 .51975 .4215 Mtetra
.646 .783 .947 r
.51975 .4215 .52677 .42811 .53972 .42392 .53274 .41745 Mtetra
.651 .79 .948 r
.53274 .41745 .53972 .42392 .55273 .41974 .5458 .41321 Mtetra
.659 .792 .945 r
.5458 .41321 .55273 .41974 .5658 .41556 .55891 .40874 Mtetra
.665 .786 .939 r
.55891 .40874 .5658 .41556 .57893 .41132 .57209 .4041 Mtetra
.666 .775 .931 r
.57209 .4041 .57893 .41132 .59212 .40689 .58532 .39944 Mtetra
.663 .769 .928 r
.58532 .39944 .59212 .40689 .60537 .40201 .59862 .39485 Mtetra
.665 .779 .934 r
.59862 .39485 .60537 .40201 .61865 .39653 .61197 .39015 Mtetra
.687 .811 .942 r
.61197 .39015 .61865 .39653 .63198 .39071 .62537 .38473 Mtetra
.724 .835 .933 r
.62537 .38473 .63198 .39071 .64538 .38529 .63878 .37804 Mtetra
.74 .802 .901 r
.63878 .37804 .64538 .38529 .65886 .38066 .6522 .3706 Mtetra
.709 .723 .861 r
.6522 .3706 .65886 .38066 .67241 .37605 .66569 .36383 Mtetra
.666 .664 .839 r
.66569 .36383 .67241 .37605 .68596 .37004 .67931 .3586 Mtetra
.642 .669 .86 r
.67931 .3586 .68596 .37004 .69948 .36265 .69305 .3545 Mtetra
.611 .737 .934 r
.69305 .3545 .69948 .36265 .71308 .35581 .70691 .35134 Mtetra
.5 .81 1 r
.70691 .35134 .71308 .35581 .72687 .35132 .72091 .34912 Mtetra
.393 .824 .96 r
.72091 .34912 .72687 .35132 .74086 .34864 .73498 .34669 Mtetra
.416 .843 .955 r
.73498 .34669 .74086 .34864 .75502 .34723 .74911 .34369 Mtetra
.23 .687 .949 r
.74911 .34369 .75502 .34723 .76972 .35142 .76361 .3445 Mtetra
0 .219 .715 r
.76361 .3445 .76972 .35142 .78553 .36752 .77906 .35578 Mtetra
0 .139 .685 r
.77906 .35578 .78553 .36752 .8019 .38687 .7952 .37253 Mtetra
.472 .536 .842 r
.7952 .37253 .8019 .38687 .8168 .38693 .81032 .37482 Mtetra
.826 .741 .77 r
.81032 .37482 .8168 .38693 .82996 .36753 .82386 .35878 Mtetra
.826 .807 .833 r
.82386 .35878 .82996 .36753 .84358 .35339 .83767 .34582 Mtetra
.23 .577 .942 r
.19166 .54446 .19972 .55127 .21062 .55519 .20269 .54711 Mtetra
.17 .5 .908 r
.20269 .54711 .21062 .55519 .22138 .56194 .21369 .55113 Mtetra
.774 .699 .781 r
.21369 .55113 .22138 .56194 .23376 .55119 .22617 .53967 Mtetra
.837 .702 .714 r
.22617 .53967 .23376 .55119 .24729 .52671 .23952 .51803 Mtetra
.833 .74 .761 r
.23952 .51803 .24729 .52671 .2603 .50753 .25235 .50189 Mtetra
.764 .81 .89 r
.25235 .50189 .2603 .50753 .2725 .49844 .26449 .4942 Mtetra
.656 .843 .972 r
.26449 .4942 .2725 .49844 .28444 .4931 .27639 .48993 Mtetra
.657 .879 .981 r
.27639 .48993 .28444 .4931 .29647 .48709 .28837 .4853 Mtetra
.702 .927 .966 r
.28837 .4853 .29647 .48709 .30856 .48064 .30049 .47917 Mtetra
.728 .939 .955 r
.30049 .47917 .30856 .48064 .3206 .47566 .31271 .47228 Mtetra
.715 .884 .959 r
.31271 .47228 .3206 .47566 .33257 .47266 .3249 .46629 Mtetra
.661 .78 .937 r
.3249 .46629 .33257 .47266 .34454 .47065 .33703 .46213 Mtetra
.618 .707 .909 r
.33703 .46213 .34454 .47065 .35659 .46864 .34914 .45929 Mtetra
.605 .682 .896 r
.34914 .45929 .35659 .46864 .36872 .46625 .3613 .45684 Mtetra
.611 .684 .894 r
.3613 .45684 .36872 .46625 .38093 .46342 .37353 .4542 Mtetra
.621 .693 .895 r
.37353 .4542 .38093 .46342 .39323 .4602 .38584 .45125 Mtetra
.63 .704 .899 r
.38584 .45125 .39323 .4602 .4056 .45666 .39823 .44799 Mtetra
.639 .715 .902 r
.39823 .44799 .4056 .45666 .41804 .45291 .41069 .44442 Mtetra
.646 .723 .904 r
.41069 .44442 .41804 .45291 .43054 .449 .42322 .44061 Mtetra
.648 .727 .906 r
.42322 .44061 .43054 .449 .44311 .445 .43581 .43672 Mtetra
.646 .73 .91 r
.43581 .43672 .44311 .445 .45573 .44096 .44847 .43288 Mtetra
.643 .736 .916 r
.44847 .43288 .45573 .44096 .46841 .43696 .46118 .4291 Mtetra
.642 .742 .921 r
.46118 .4291 .46841 .43696 .48115 .43305 .47396 .42531 Mtetra
.646 .748 .923 r
.47396 .42531 .48115 .43305 .49396 .42922 .4868 .42138 Mtetra
.654 .749 .919 r
.4868 .42138 .49396 .42922 .50682 .42539 .49971 .41719 Mtetra
.662 .743 .91 r
.49971 .41719 .50682 .42539 .51975 .4215 .51267 .41273 Mtetra
.666 .73 .898 r
.51267 .41273 .51975 .4215 .53274 .41745 .5257 .40809 Mtetra
.665 .716 .887 r
.5257 .40809 .53274 .41745 .5458 .41321 .53879 .40342 Mtetra
.661 .706 .88 r
.53879 .40342 .5458 .41321 .55891 .40874 .55194 .39886 Mtetra
.658 .704 .88 r
.55194 .39886 .55891 .40874 .57209 .4041 .56515 .39437 Mtetra
.661 .709 .883 r
.56515 .39437 .57209 .4041 .58532 .39944 .57842 .38977 Mtetra
.667 .714 .883 r
.57842 .38977 .58532 .39944 .59862 .39485 .59175 .38492 Mtetra
.67 .71 .878 r
.59175 .38492 .59862 .39485 .61197 .39015 .60513 .37992 Mtetra
.668 .703 .873 r
.60513 .37992 .61197 .39015 .62537 .38473 .61858 .37493 Mtetra
.679 .718 .879 r
.61858 .37493 .62537 .38473 .63878 .37804 .63207 .36956 Mtetra
.712 .763 .892 r
.63207 .36956 .63878 .37804 .6522 .3706 .64558 .36304 Mtetra
.731 .794 .902 r
.64558 .36304 .6522 .3706 .66569 .36383 .65911 .35586 Mtetra
.682 .769 .917 r
.65911 .35586 .66569 .36383 .67931 .3586 .67277 .35049 Mtetra
.558 .715 .946 r
.67277 .35049 .67931 .3586 .69305 .3545 .68667 .34867 Mtetra
.426 .726 .988 r
.68667 .34867 .69305 .3545 .70691 .35134 .70075 .34844 Mtetra
.396 .808 .978 r
.70075 .34844 .70691 .35134 .72091 .34912 .71484 .34655 Mtetra
.526 .883 .981 r
.71484 .34655 .72091 .34912 .73498 .34669 .72889 .34249 Mtetra
.601 .867 .993 r
.72889 .34249 .73498 .34669 .74911 .34369 .74299 .33814 Mtetra
.443 .748 .993 r
.74299 .33814 .74911 .34369 .76361 .3445 .75743 .3374 Mtetra
0 .378 .834 r
.75743 .3374 .76361 .3445 .77906 .35578 .77266 .3454 Mtetra
0 .212 .737 r
.77266 .3454 .77906 .35578 .7952 .37253 .78855 .35907 Mtetra
.44 .534 .857 r
.78855 .35907 .7952 .37253 .81032 .37482 .80375 .36205 Mtetra
.789 .72 .787 r
.80375 .36205 .81032 .37482 .82386 .35878 .81761 .34886 Mtetra
.796 .775 .834 r
.81761 .34886 .82386 .35878 .83767 .34582 .83161 .3372 Mtetra
.377 .619 .946 r
.18364 .53654 .19166 .54446 .20269 .54711 .19479 .53808 Mtetra
.369 .582 .925 r
.19479 .53808 .20269 .54711 .21369 .55113 .20597 .54021 Mtetra
.768 .697 .784 r
.20597 .54021 .21369 .55113 .22617 .53967 .21844 .52922 Mtetra
.833 .715 .734 r
.21844 .52922 .22617 .53967 .23952 .51803 .23161 .51037 Mtetra
.828 .759 .787 r
.23161 .51037 .23952 .51803 .25235 .50189 .24433 .49622 Mtetra
.755 .811 .897 r
.24433 .49622 .25235 .50189 .26449 .4942 .25647 .4889 Mtetra
.661 .811 .955 r
.25647 .4889 .26449 .4942 .27639 .48993 .26841 .48466 Mtetra
.643 .809 .963 r
.26841 .48466 .27639 .48993 .28837 .4853 .28037 .48084 Mtetra
.661 .84 .969 r
.28037 .48084 .28837 .4853 .30049 .47917 .29242 .47642 Mtetra
.689 .9 .972 r
.29242 .47642 .30049 .47917 .31271 .47228 .3046 .47086 Mtetra
.713 .94 .958 r
.3046 .47086 .31271 .47228 .3249 .46629 .3169 .4642 Mtetra
.727 .925 .958 r
.3169 .4642 .3249 .46629 .33703 .46213 .32923 .45745 Mtetra
.704 .845 .95 r
.32923 .45745 .33703 .46213 .34914 .45929 .34153 .45187 Mtetra
.659 .752 .919 r
.34153 .45187 .34914 .45929 .3613 .45684 .35381 .44772 Mtetra
.629 .699 .896 r
.35381 .44772 .3613 .45684 .37353 .4542 .36609 .44448 Mtetra
.622 .683 .886 r
.36609 .44448 .37353 .4542 .38584 .45125 .37843 .44145 Mtetra
.628 .684 .883 r
.37843 .44145 .38584 .45125 .39823 .44799 .39084 .43821 Mtetra
.634 .688 .883 r
.39084 .43821 .39823 .44799 .41069 .44442 .40332 .43475 Mtetra
.634 .691 .886 r
.40332 .43475 .41069 .44442 .42322 .44061 .41587 .43127 Mtetra
.633 .7 .893 r
.41587 .43127 .42322 .44061 .43581 .43672 .42848 .42782 Mtetra
.636 .712 .902 r
.42848 .42782 .43581 .43672 .44847 .43288 .44116 .42427 Mtetra
.643 .723 .907 r
.44116 .42427 .44847 .43288 .46118 .4291 .4539 .42047 Mtetra
.653 .728 .903 r
.4539 .42047 .46118 .4291 .47396 .42531 .46672 .41631 Mtetra
.665 .723 .892 r
.46672 .41631 .47396 .42531 .4868 .42138 .4796 .41172 Mtetra
.673 .711 .877 r
.4796 .41172 .4868 .42138 .49971 .41719 .49255 .40676 Mtetra
.674 .695 .862 r
.49255 .40676 .49971 .41719 .51267 .41273 .50555 .40159 Mtetra
.671 .681 .851 r
.50555 .40159 .51267 .41273 .5257 .40809 .51861 .39641 Mtetra
.667 .67 .843 r
.51861 .39641 .5257 .40809 .53879 .40342 .53172 .3913 Mtetra
.663 .661 .838 r
.53172 .3913 .53879 .40342 .55194 .39886 .54489 .38626 Mtetra
.658 .651 .832 r
.54489 .38626 .55194 .39886 .56515 .39437 .55812 .38135 Mtetra
.652 .643 .828 r
.55812 .38135 .56515 .39437 .57842 .38977 .57142 .37663 Mtetra
.65 .64 .827 r
.57142 .37663 .57842 .38977 .59175 .38492 .58477 .37201 Mtetra
.653 .646 .831 r
.58477 .37201 .59175 .38492 .60513 .37992 .59819 .36726 Mtetra
.654 .651 .835 r
.59819 .36726 .60513 .37992 .61858 .37493 .61167 .36246 Mtetra
.641 .65 .843 r
.61167 .36246 .61858 .37493 .63207 .36956 .62523 .35826 Mtetra
.619 .662 .87 r
.62523 .35826 .63207 .36956 .64558 .36304 .63889 .35503 Mtetra
.599 .737 .941 r
.63889 .35503 .64558 .36304 .65911 .35586 .65265 .35215 Mtetra
.523 .846 .998 r
.65265 .35215 .65911 .35586 .67277 .35049 .66648 .34906 Mtetra
.38 .831 .93 r
.66648 .34906 .67277 .35049 .68667 .34867 .6804 .34612 Mtetra
.419 .83 .973 r
.6804 .34612 .68667 .34867 .70075 .34844 .69442 .34362 Mtetra
.554 .826 .996 r
.69442 .34362 .70075 .34844 .71484 .34655 .7085 .34052 Mtetra
.638 .82 .97 r
.7085 .34052 .71484 .34655 .72889 .34249 .72258 .33606 Mtetra
.642 .81 .964 r
.72258 .33606 .72889 .34249 .74299 .33814 .73673 .33155 Mtetra
.5 .744 .982 r
.73673 .33155 .74299 .33814 .75743 .3374 .75119 .33027 Mtetra
.099 .48 .896 r
.75119 .33027 .75743 .3374 .77266 .3454 .76629 .33607 Mtetra
0 .306 .799 r
.76629 .33607 .77266 .3454 .78855 .35907 .78196 .34671 Mtetra
.442 .558 .878 r
.78196 .34671 .78855 .35907 .80375 .36205 .79713 .34912 Mtetra
.762 .709 .802 r
.79713 .34912 .80375 .36205 .81761 .34886 .81122 .33787 Mtetra
.768 .746 .833 r
.81122 .33787 .81761 .34886 .83161 .3372 .82539 .32739 Mtetra
.456 .627 .926 r
.17565 .52757 .18364 .53654 .19479 .53808 .18689 .52829 Mtetra
.446 .601 .911 r
.18689 .52829 .19479 .53808 .20597 .54021 .19817 .52946 Mtetra
.755 .698 .797 r
.19817 .52946 .20597 .54021 .21844 .52922 .21056 .51969 Mtetra
.827 .728 .756 r
.21056 .51969 .21844 .52922 .23161 .51037 .22356 .50332 Mtetra
.823 .774 .806 r
.22356 .50332 .23161 .51037 .24433 .49622 .23622 .49051 Mtetra
.755 .811 .897 r
.23622 .49051 .24433 .49622 .25647 .4889 .24842 .48318 Mtetra
.675 .802 .943 r
.24842 .48318 .25647 .4889 .26841 .48466 .26042 .47859 Mtetra
.65 .787 .947 r
.26042 .47859 .26841 .48466 .28037 .48084 .27241 .47467 Mtetra
.65 .784 .946 r
.27241 .47467 .28037 .48084 .29242 .47642 .28447 .47076 Mtetra
.654 .803 .954 r
.28447 .47076 .29242 .47642 .3046 .47086 .29659 .46664 Mtetra
.665 .852 .971 r
.29659 .46664 .3046 .47086 .3169 .4642 .3088 .46196 Mtetra
.68 .916 .974 r
.3088 .46196 .3169 .4642 .32923 .45745 .32113 .45628 Mtetra
.698 .947 .958 r
.32113 .45628 .32923 .45745 .34153 .45187 .33355 .44967 Mtetra
.72 .925 .96 r
.33355 .44967 .34153 .45187 .35381 .44772 .34601 .44301 Mtetra
.711 .849 .948 r
.34601 .44301 .35381 .44772 .36609 .44448 .35847 .43715 Mtetra
.68 .765 .915 r
.35847 .43715 .36609 .44448 .37843 .44145 .37093 .43227 Mtetra
.651 .709 .889 r
.37093 .43227 .37843 .44145 .39084 .43821 .3834 .42824 Mtetra
.631 .684 .881 r
.3834 .42824 .39084 .43821 .40332 .43475 .39591 .42484 Mtetra
.627 .685 .885 r
.39591 .42484 .40332 .43475 .41587 .43127 .40847 .42157 Mtetra
.637 .694 .886 r
.40847 .42157 .41587 .43127 .42848 .42782 .42112 .41797 Mtetra
.649 .696 .88 r
.42112 .41797 .42848 .42782 .44116 .42427 .43383 .41392 Mtetra
.657 .689 .868 r
.43383 .41392 .44116 .42427 .4539 .42047 .44662 .4095 Mtetra
.663 .679 .855 r
.44662 .4095 .4539 .42047 .46672 .41631 .45948 .40475 Mtetra
.667 .67 .844 r
.45948 .40475 .46672 .41631 .4796 .41172 .47239 .39971 Mtetra
.667 .663 .837 r
.47239 .39971 .4796 .41172 .49255 .40676 .48536 .39457 Mtetra
.663 .659 .836 r
.48536 .39457 .49255 .40676 .50555 .40159 .49839 .38956 Mtetra
.659 .661 .841 r
.49839 .38956 .50555 .40159 .51861 .39641 .51147 .38474 Mtetra
.657 .667 .848 r
.51147 .38474 .51861 .39641 .53172 .3913 .52461 .38005 Mtetra
.659 .677 .856 r
.52461 .38005 .53172 .3913 .54489 .38626 .53781 .37533 Mtetra
.665 .687 .861 r
.53781 .37533 .54489 .38626 .55812 .38135 .55108 .37038 Mtetra
.669 .688 .859 r
.55108 .37038 .55812 .38135 .57142 .37663 .56439 .36522 Mtetra
.663 .678 .854 r
.56439 .36522 .57142 .37663 .58477 .37201 .57777 .36025 Mtetra
.646 .665 .854 r
.57777 .36025 .58477 .37201 .59819 .36726 .59123 .35592 Mtetra
.622 .663 .869 r
.59123 .35592 .59819 .36726 .61167 .36246 .60477 .35255 Mtetra
.576 .676 .907 r
.60477 .35255 .61167 .36246 .62523 .35826 .61844 .35058 Mtetra
.482 .695 .962 r
.61844 .35058 .62523 .35826 .63889 .35503 .63225 .35021 Mtetra
.379 .738 .991 r
.63225 .35021 .63889 .35503 .65265 .35215 .64616 .34996 Mtetra
.416 .836 .964 r
.64616 .34996 .65265 .35215 .66648 .34906 .66008 .34722 Mtetra
.573 .919 .963 r
.66008 .34722 .66648 .34906 .6804 .34612 .67396 .34189 Mtetra
.649 .883 .983 r
.67396 .34189 .6804 .34612 .69442 .34362 .68791 .33656 Mtetra
.632 .786 .956 r
.68791 .33656 .69442 .34362 .7085 .34052 .70198 .33245 Mtetra
.632 .757 .937 r
.70198 .33245 .7085 .34052 .72258 .33606 .71615 .32845 Mtetra
.628 .77 .948 r
.71615 .32845 .72258 .33606 .73673 .33155 .73039 .3245 Mtetra
.513 .737 .975 r
.73039 .3245 .73673 .33155 .75119 .33027 .74489 .3231 Mtetra
.194 .547 .93 r
.74489 .3231 .75119 .33027 .76629 .33607 .75992 .32737 Mtetra
.059 .406 .859 r
.75992 .32737 .76629 .33607 .78196 .34671 .77539 .33529 Mtetra
.477 .6 .896 r
.77539 .33529 .78196 .34671 .79713 .34912 .79049 .33631 Mtetra
.749 .707 .812 r
.79049 .33631 .79713 .34912 .81122 .33787 .80471 .32605 Mtetra
.746 .724 .831 r
.80471 .32605 .81122 .33787 .82539 .32739 .81902 .31645 Mtetra
.495 .623 .907 r
.1677 .51774 .17565 .52757 .18689 .52829 .179 .51796 Mtetra
.463 .597 .9 r
.179 .51796 .18689 .52829 .19817 .52946 .1903 .51892 Mtetra
.734 .697 .816 r
.1903 .51892 .19817 .52946 .21056 .51969 .20256 .51081 Mtetra
.817 .739 .778 r
.20256 .51081 .21056 .51969 .22356 .50332 .21542 .49661 Mtetra
.817 .783 .821 r
.21542 .49661 .22356 .50332 .23622 .49051 .22805 .48471 Mtetra
.757 .81 .895 r
.22805 .48471 .23622 .49051 .24842 .48318 .24029 .47724 Mtetra
.688 .799 .934 r
.24029 .47724 .24842 .48318 .26042 .47859 .25236 .47226 Mtetra
.66 .783 .939 r
.25236 .47226 .26042 .47859 .27241 .47467 .26442 .46807 Mtetra
.653 .774 .937 r
.26442 .46807 .27241 .47467 .28447 .47076 .27651 .46406 Mtetra
.653 .772 .936 r
.27651 .46406 .28447 .47076 .29659 .46664 .28866 .46004 Mtetra
.654 .776 .939 r
.28866 .46004 .29659 .46664 .3088 .46196 .30087 .45598 Mtetra
.653 .796 .951 r
.30087 .45598 .3088 .46196 .32113 .45628 .31313 .45185 Mtetra
.656 .847 .973 r
.31313 .45185 .32113 .45628 .33355 .44967 .32548 .44735 Mtetra
.657 .912 .979 r
.32548 .44735 .33355 .44967 .34601 .44301 .33792 .44203 Mtetra
.666 .946 .959 r
.33792 .44203 .34601 .44301 .35847 .43715 .35047 .43579 Mtetra
.693 .945 .96 r
.35047 .43579 .35847 .43715 .37093 .43227 .36307 .42921 Mtetra
.701 .902 .968 r
.36307 .42921 .37093 .43227 .3834 .42824 .37568 .42316 Mtetra
.693 .839 .953 r
.37568 .42316 .3834 .42824 .39591 .42484 .38832 .41772 Mtetra
.688 .778 .919 r
.38832 .41772 .39591 .42484 .40847 .42157 .401 .41247 Mtetra
.678 .724 .884 r
.401 .41247 .40847 .42157 .42112 .41797 .41372 .40739 Mtetra
.662 .687 .863 r
.41372 .40739 .42112 .41797 .43383 .41392 .42648 .40274 Mtetra
.653 .672 .856 r
.42648 .40274 .43383 .41392 .44662 .4095 .43929 .39835 Mtetra
.655 .674 .856 r
.43929 .39835 .44662 .4095 .45948 .40475 .45217 .39386 Mtetra
.66 .682 .86 r
.45217 .39386 .45948 .40475 .47239 .39971 .4651 .38919 Mtetra
.659 .69 .868 r
.4651 .38919 .47239 .39971 .48536 .39457 .4781 .38457 Mtetra
.655 .701 .88 r
.4781 .38457 .48536 .39457 .49839 .38956 .49115 .38015 Mtetra
.655 .716 .893 r
.49115 .38015 .49839 .38956 .51147 .38474 .50427 .37575 Mtetra
.661 .729 .9 r
.50427 .37575 .51147 .38474 .52461 .38005 .51745 .37117 Mtetra
.665 .734 .901 r
.51745 .37117 .52461 .38005 .53781 .37533 .53069 .36644 Mtetra
.658 .732 .905 r
.53069 .36644 .53781 .37533 .55108 .37038 .54399 .36193 Mtetra
.644 .74 .919 r
.54399 .36193 .55108 .37038 .56439 .36522 .55736 .35785 Mtetra
.616 .762 .949 r
.55736 .35785 .56439 .36522 .57777 .36025 .57082 .35442 Mtetra
.555 .788 .986 r
.57082 .35442 .57777 .36025 .59123 .35592 .58436 .3519 Mtetra
.458 .805 .998 r
.58436 .3519 .59123 .35592 .60477 .35255 .598 .35002 Mtetra
.399 .818 .971 r
.598 .35002 .60477 .35255 .61844 .35058 .61172 .34784 Mtetra
.441 .836 .981 r
.61172 .34784 .61844 .35058 .63225 .35021 .62552 .34524 Mtetra
.519 .805 .998 r
.62552 .34524 .63225 .35021 .64616 .34996 .63942 .34286 Mtetra
.584 .764 .965 r
.63942 .34286 .64616 .34996 .66008 .34722 .65338 .34001 Mtetra
.66 .791 .945 r
.65338 .34001 .66008 .34722 .67396 .34189 .66734 .33514 Mtetra
.694 .818 .941 r
.66734 .33514 .67396 .34189 .68791 .33656 .68131 .32916 Mtetra
.66 .788 .943 r
.68131 .32916 .68791 .33656 .70198 .33245 .6954 .32424 Mtetra
.625 .752 .938 r
.6954 .32424 .70198 .33245 .71615 .32845 .70962 .32043 Mtetra
.606 .751 .946 r
.70962 .32043 .71615 .32845 .73039 .3245 .72396 .31709 Mtetra
.511 .726 .97 r
.72396 .31709 .73039 .3245 .74489 .3231 .73852 .31583 Mtetra
.262 .59 .948 r
.73852 .31583 .74489 .3231 .75992 .32737 .75351 .31901 Mtetra
.177 .5 .908 r
.75351 .31901 .75992 .32737 .77539 .33529 .76884 .3245 Mtetra
.533 .647 .907 r
.76884 .3245 .77539 .33529 .79049 .33631 .78382 .32369 Mtetra
.747 .711 .818 r
.78382 .32369 .79049 .33631 .80471 .32605 .7981 .31362 Mtetra
.732 .709 .829 r
.7981 .31362 .80471 .32605 .81902 .31645 .81251 .30459 Mtetra
.513 .618 .894 r
.15975 .50732 .1677 .51774 .179 .51796 .17108 .50726 Mtetra
.45 .583 .895 r
.17108 .50726 .179 .51796 .1903 .51892 .18235 .50851 Mtetra
.702 .692 .838 r
.18235 .50851 .1903 .51892 .20256 .51081 .19446 .50229 Mtetra
.803 .747 .8 r
.19446 .50229 .20256 .51081 .21542 .49661 .20718 .49006 Mtetra
.811 .789 .832 r
.20718 .49006 .21542 .49661 .22805 .48471 .2198 .47884 Mtetra
.76 .81 .892 r
.2198 .47884 .22805 .48471 .24029 .47724 .23211 .47116 Mtetra
.699 .799 .927 r
.23211 .47116 .24029 .47724 .25236 .47226 .24424 .4658 Mtetra
.669 .783 .934 r
.24424 .4658 .25236 .47226 .26442 .46807 .25635 .46134 Mtetra
.659 .774 .934 r
.25635 .46134 .26442 .46807 .27651 .46406 .26849 .45714 Mtetra
.655 .768 .932 r
.26849 .45714 .27651 .46406 .28866 .46004 .28068 .45304 Mtetra
.654 .766 .932 r
.28068 .45304 .28866 .46004 .30087 .45598 .29292 .44896 Mtetra
.658 .768 .931 r
.29292 .44896 .30087 .45598 .31313 .45185 .30523 .44475 Mtetra
.659 .767 .929 r
.30523 .44475 .31313 .45185 .32548 .44735 .31759 .4405 Mtetra
.655 .774 .937 r
.31759 .4405 .32548 .44735 .33792 .44203 .33001 .43632 Mtetra
.654 .81 .958 r
.33001 .43632 .33792 .44203 .35047 .43579 .34249 .43201 Mtetra
.638 .868 .985 r
.34249 .43201 .35047 .43579 .36307 .42921 .35504 .42754 Mtetra
.6 .916 .976 r
.35504 .42754 .36307 .42921 .37568 .42316 .36766 .42267 Mtetra
.607 .94 .946 r
.36766 .42267 .37568 .42316 .38832 .41772 .38038 .41687 Mtetra
.657 .95 .953 r
.38038 .41687 .38832 .41772 .401 .41247 .39317 .41046 Mtetra
.663 .928 .972 r
.39317 .41046 .401 .41247 .41372 .40739 .40598 .40458 Mtetra
.639 .902 .984 r
.40598 .40458 .41372 .40739 .42648 .40274 .41881 .39953 Mtetra
.643 .892 .985 r
.41881 .39953 .42648 .40274 .43929 .39835 .4317 .39453 Mtetra
.671 .882 .976 r
.4317 .39453 .43929 .39835 .45217 .39386 .44465 .38914 Mtetra
.676 .856 .968 r
.44465 .38914 .45217 .39386 .4651 .38919 .45765 .38385 Mtetra
.651 .831 .97 r
.45765 .38385 .4651 .38919 .4781 .38457 .4707 .37929 Mtetra
.61 .822 .981 r
.4707 .37929 .4781 .38457 .49115 .38015 .48379 .37561 Mtetra
.565 .831 .995 r
.48379 .37561 .49115 .38015 .50427 .37575 .49695 .37247 Mtetra
.507 .848 .996 r
.49695 .37247 .50427 .37575 .51745 .37117 .51019 .36954 Mtetra
.415 .844 .951 r
.51019 .36954 .51745 .37117 .53069 .36644 .5235 .3666 Mtetra
.302 .797 .839 r
.5235 .3666 .53069 .36644 .54399 .36193 .53688 .36337 Mtetra
.223 .74 .73 r
.53688 .36337 .54399 .36193 .55736 .35785 .55034 .35977 Mtetra
.241 .748 .706 r
.55034 .35977 .55736 .35785 .57082 .35442 .56387 .35548 Mtetra
.365 .834 .803 r
.56387 .35548 .57082 .35442 .58436 .3519 .57745 .35057 Mtetra
.529 .907 .951 r
.57745 .35057 .58436 .3519 .598 .35002 .5911 .3457 Mtetra
.624 .868 .988 r
.5911 .3457 .598 .35002 .61172 .34784 .60482 .34105 Mtetra
.641 .796 .957 r
.60482 .34105 .61172 .34784 .62552 .34524 .61862 .3367 Mtetra
.61 .733 .933 r
.61862 .3367 .62552 .34524 .63942 .34286 .63253 .33345 Mtetra
.587 .701 .921 r
.63253 .33345 .63942 .34286 .65338 .34001 .64654 .33093 Mtetra
.628 .728 .919 r
.64654 .33093 .65338 .34001 .66734 .33514 .66059 .32711 Mtetra
.68 .778 .924 r
.66059 .32711 .66734 .33514 .68131 .32916 .67464 .32155 Mtetra
.671 .788 .937 r
.67464 .32155 .68131 .32916 .6954 .32424 .68877 .31628 Mtetra
.626 .762 .944 r
.68877 .31628 .6954 .32424 .70962 .32043 .70304 .31235 Mtetra
.589 .744 .95 r
.70304 .31235 .70962 .32043 .72396 .31709 .71745 .30943 Mtetra
.501 .716 .968 r
.71745 .30943 .72396 .31709 .73852 .31583 .73208 .30842 Mtetra
.313 .62 .958 r
.73208 .30842 .73852 .31583 .75351 .31901 .74707 .31078 Mtetra
.293 .582 .941 r
.74707 .31078 .75351 .31901 .76884 .3245 .76226 .31406 Mtetra
.597 .69 .907 r
.76226 .31406 .76884 .3245 .78382 .32369 .77711 .31114 Mtetra
.753 .716 .818 r
.77711 .31114 .78382 .32369 .7981 .31362 .79142 .30076 Mtetra
.722 .699 .827 r
.79142 .30076 .7981 .31362 .81251 .30459 .80591 .29208 Mtetra
.522 .617 .888 r
.15177 .49661 .15975 .50732 .17108 .50726 .16313 .49634 Mtetra
.423 .566 .893 r
.16313 .49634 .17108 .50726 .18235 .50851 .17435 .49808 Mtetra
.655 .678 .86 r
.17435 .49808 .18235 .50851 .19446 .50229 .18627 .49388 Mtetra
.783 .749 .822 r
.18627 .49388 .19446 .50229 .20718 .49006 .19885 .48355 Mtetra
.804 .792 .842 r
.19885 .48355 .20718 .49006 .2198 .47884 .21147 .47291 Mtetra
.764 .81 .889 r
.21147 .47291 .2198 .47884 .23211 .47116 .22384 .46499 Mtetra
.709 .799 .921 r
.22384 .46499 .23211 .47116 .24424 .4658 .23605 .45926 Mtetra
.677 .784 .93 r
.23605 .45926 .24424 .4658 .25635 .46134 .24822 .45453 Mtetra
.664 .774 .931 r
.24822 .45453 .25635 .46134 .26849 .45714 .26041 .45016 Mtetra
.66 .769 .931 r
.26041 .45016 .26849 .45714 .28068 .45304 .27264 .4459 Mtetra
.658 .765 .929 r
.27264 .4459 .28068 .45304 .29292 .44896 .28493 .44168 Mtetra
.655 .761 .928 r
.28493 .44168 .29292 .44896 .30523 .44475 .29726 .43751 Mtetra
.656 .764 .929 r
.29726 .43751 .30523 .44475 .31759 .4405 .30966 .4333 Mtetra
.665 .768 .927 r
.30966 .4333 .31759 .4405 .33001 .43632 .32213 .42882 Mtetra
.667 .761 .921 r
.32213 .42882 .33001 .43632 .34249 .43201 .33466 .42426 Mtetra
.655 .752 .921 r
.33466 .42426 .34249 .43201 .35504 .42754 .34723 .42002 Mtetra
.655 .76 .927 r
.34723 .42002 .35504 .42754 .36766 .42267 .35986 .41578 Mtetra
.672 .783 .933 r
.35986 .41578 .36766 .42267 .38038 .41687 .37257 .41098 Mtetra
.661 .812 .956 r
.37257 .41098 .38038 .41687 .39317 .41046 .38533 .40639 Mtetra
.593 .851 .993 r
.38533 .40639 .39317 .41046 .40598 .40458 .39811 .4027 Mtetra
.517 .884 .977 r
.39811 .4027 .40598 .40458 .41881 .39953 .41096 .39893 Mtetra
.547 .919 .942 r
.41096 .39893 .41881 .39953 .4317 .39453 .42392 .39381 Mtetra
.611 .941 .947 r
.42392 .39381 .4317 .39453 .44465 .38914 .43696 .38781 Mtetra
.602 .929 .963 r
.43696 .38781 .44465 .38914 .45765 .38385 .45003 .38233 Mtetra
.518 .893 .965 r
.45003 .38233 .45765 .38385 .4707 .37929 .46314 .37815 Mtetra
.413 .85 .936 r
.46314 .37815 .4707 .37929 .48379 .37561 .47629 .37492 Mtetra
.366 .83 .905 r
.47629 .37492 .48379 .37561 .49695 .37247 .48952 .37182 Mtetra
.368 .832 .903 r
.48952 .37182 .49695 .37247 .51019 .36954 .50282 .36862 Mtetra
.389 .841 .919 r
.50282 .36862 .51019 .36954 .5235 .3666 .5162 .36538 Mtetra
.455 .872 .943 r
.5162 .36538 .5235 .3666 .53688 .36337 .52966 .36157 Mtetra
.54 .901 .969 r
.52966 .36157 .53688 .36337 .55034 .35977 .54318 .357 Mtetra
.625 .911 .982 r
.54318 .357 .55034 .35977 .56387 .35548 .55677 .35162 Mtetra
.687 .899 .973 r
.55677 .35162 .56387 .35548 .57745 .35057 .5704 .3454 Mtetra
.697 .863 .961 r
.5704 .3454 .57745 .35057 .5911 .3457 .58408 .33925 Mtetra
.68 .82 .95 r
.58408 .33925 .5911 .3457 .60482 .34105 .59784 .33373 Mtetra
.667 .791 .94 r
.59784 .33373 .60482 .34105 .61862 .3367 .61167 .32866 Mtetra
.635 .759 .938 r
.61167 .32866 .61862 .3367 .63253 .33345 .6256 .32457 Mtetra
.591 .719 .933 r
.6256 .32457 .63253 .33345 .64654 .33093 .63965 .3218 Mtetra
.608 .721 .925 r
.63965 .3218 .64654 .33093 .66059 .32711 .65377 .31856 Mtetra
.662 .76 .922 r
.65377 .31856 .66059 .32711 .67464 .32155 .66789 .31356 Mtetra
.669 .779 .931 r
.66789 .31356 .67464 .32155 .68877 .31628 .68208 .30831 Mtetra
.626 .764 .945 r
.68208 .30831 .68877 .31628 .70304 .31235 .6964 .30434 Mtetra
.575 .742 .955 r
.6964 .30434 .70304 .31235 .71745 .30943 .71088 .30171 Mtetra
.489 .71 .968 r
.71088 .30171 .71745 .30943 .73208 .30842 .72558 .30091 Mtetra
.355 .644 .964 r
.72558 .30091 .73208 .30842 .74707 .31078 .74056 .30254 Mtetra
.406 .651 .958 r
.74056 .30254 .74707 .31078 .76226 .31406 .75564 .30364 Mtetra
.659 .72 .894 r
.75564 .30364 .76226 .31406 .77711 .31114 .77036 .29852 Mtetra
.759 .718 .814 r
.77036 .29852 .77711 .31114 .79142 .30076 .78468 .28765 Mtetra
.716 .693 .827 r
.78468 .28765 .79142 .30076 .80591 .29208 .79924 .27924 Mtetra
.531 .623 .888 r
.14373 .4859 .15177 .49661 .16313 .49634 .15513 .48537 Mtetra
.399 .555 .893 r
.15513 .48537 .16313 .49634 .17435 .49808 .16631 .48747 Mtetra
.594 .653 .878 r
.16631 .48747 .17435 .49808 .18627 .49388 .17804 .48528 Mtetra
.752 .743 .844 r
.17804 .48528 .18627 .49388 .19885 .48355 .19045 .47697 Mtetra
.794 .792 .851 r
.19045 .47697 .19885 .48355 .21147 .47291 .20306 .46697 Mtetra
.769 .811 .887 r
.20306 .46697 .21147 .47291 .22384 .46499 .2155 .4588 Mtetra
.719 .802 .916 r
.2155 .4588 .22384 .46499 .23605 .45926 .22778 .45267 Mtetra
.685 .786 .927 r
.22778 .45267 .23605 .45926 .24822 .45453 .24001 .44765 Mtetra
.669 .775 .929 r
.24001 .44765 .24822 .45453 .26041 .45016 .25225 .44309 Mtetra
.662 .769 .929 r
.25225 .44309 .26041 .45016 .27264 .4459 .26452 .43873 Mtetra
.659 .767 .929 r
.26452 .43873 .27264 .4459 .28493 .44168 .27685 .43443 Mtetra
.662 .766 .927 r
.27685 .43443 .28493 .44168 .29726 .43751 .28923 .43004 Mtetra
.661 .761 .924 r
.28923 .43004 .29726 .43751 .30966 .4333 .30168 .42566 Mtetra
.659 .756 .922 r
.30168 .42566 .30966 .4333 .32213 .42882 .31417 .42132 Mtetra
.657 .76 .926 r
.31417 .42132 .32213 .42882 .33466 .42426 .32672 .41702 Mtetra
.656 .769 .933 r
.32672 .41702 .33466 .42426 .34723 .42002 .33933 .41272 Mtetra
.674 .773 .925 r
.33933 .41272 .34723 .42002 .35986 .41578 .35203 .40786 Mtetra
.685 .76 .909 r
.35203 .40786 .35986 .41578 .37257 .41098 .3648 .40259 Mtetra
.658 .741 .911 r
.3648 .40259 .37257 .41098 .38533 .40639 .37759 .39816 Mtetra
.624 .735 .926 r
.37759 .39816 .38533 .40639 .39811 .4027 .39039 .39473 Mtetra
.652 .752 .923 r
.39039 .39473 .39811 .4027 .41096 .39893 .4033 .39045 Mtetra
.699 .754 .894 r
.4033 .39045 .41096 .39893 .42392 .39381 .41632 .38453 Mtetra
.701 .736 .878 r
.41632 .38453 .42392 .39381 .43696 .38781 .42941 .37832 Mtetra
.666 .721 .89 r
.42941 .37832 .43696 .38781 .45003 .38233 .4425 .37346 Mtetra
.615 .719 .92 r
.4425 .37346 .45003 .38233 .46314 .37815 .45562 .37025 Mtetra
.571 .73 .949 r
.45562 .37025 .46314 .37815 .47629 .37492 .4688 .368 Mtetra
.593 .768 .963 r
.4688 .368 .47629 .37492 .48952 .37182 .48207 .36499 Mtetra
.648 .792 .951 r
.48207 .36499 .48952 .37182 .50282 .36862 .49543 .36058 Mtetra
.634 .753 .934 r
.49543 .36058 .50282 .36862 .5162 .36538 .50885 .35666 Mtetra
.637 .736 .92 r
.50885 .35666 .5162 .36538 .52966 .36157 .52235 .35267 Mtetra
.626 .729 .921 r
.52235 .35267 .52966 .36157 .54318 .357 .53592 .34899 Mtetra
.636 .758 .936 r
.53592 .34899 .54318 .357 .55677 .35162 .54956 .34493 Mtetra
.676 .811 .947 r
.54956 .34493 .55677 .35162 .5704 .3454 .56326 .33956 Mtetra
.697 .844 .953 r
.56326 .33956 .5704 .3454 .58408 .33925 .577 .33344 Mtetra
.7 .847 .953 r
.577 .33344 .58408 .33925 .59784 .33373 .59081 .32722 Mtetra
.692 .825 .946 r
.59081 .32722 .59784 .33373 .61167 .32866 .60467 .32128 Mtetra
.653 .787 .946 r
.60467 .32128 .61167 .32866 .6256 .32457 .61863 .31654 Mtetra
.6 .749 .949 r
.61863 .31654 .6256 .32457 .63965 .3218 .63271 .31334 Mtetra
.607 .741 .94 r
.63271 .31334 .63965 .3218 .65377 .31856 .64688 .31 Mtetra
.654 .758 .926 r
.64688 .31 .65377 .31856 .66789 .31356 .66107 .30524 Mtetra
.661 .769 .929 r
.66107 .30524 .66789 .31356 .68208 .30831 .67532 .30022 Mtetra
.619 .76 .946 r
.67532 .30022 .68208 .30831 .6964 .30434 .6897 .29639 Mtetra
.561 .74 .96 r
.6897 .29639 .6964 .30434 .71088 .30171 .70425 .294 Mtetra
.478 .708 .97 r
.70425 .294 .71088 .30171 .72558 .30091 .71901 .29335 Mtetra
.4 .671 .97 r
.71901 .29335 .72558 .30091 .74056 .30254 .73398 .29412 Mtetra
.514 .707 .958 r
.73398 .29412 .74056 .30254 .75564 .30364 .74894 .29292 Mtetra
.708 .736 .873 r
.74894 .29292 .75564 .30364 .77036 .29852 .76355 .28564 Mtetra
.762 .717 .81 r
.76355 .28564 .77036 .29852 .78468 .28765 .77789 .27446 Mtetra
.709 .69 .83 r
.77789 .27446 .78468 .28765 .79924 .27924 .79252 .26639 Mtetra
.548 .639 .893 r
.1356 .47552 .14373 .4859 .15513 .48537 .14705 .47451 Mtetra
.396 .557 .897 r
.14705 .47451 .15513 .48537 .16631 .48747 .15824 .47657 Mtetra
.524 .619 .888 r
.15824 .47657 .16631 .48747 .17804 .48528 .16978 .47618 Mtetra
.705 .725 .866 r
.16978 .47618 .17804 .48528 .19045 .47697 .182 .47012 Mtetra
.778 .788 .861 r
.182 .47012 .19045 .47697 .20306 .46697 .19456 .46102 Mtetra
.772 .812 .885 r
.19456 .46102 .20306 .46697 .2155 .4588 .20707 .45267 Mtetra
.731 .806 .911 r
.20707 .45267 .2155 .4588 .22778 .45267 .21943 .44609 Mtetra
.694 .79 .924 r
.21943 .44609 .22778 .45267 .24001 .44765 .23172 .44076 Mtetra
.675 .778 .928 r
.23172 .44076 .24001 .44765 .25225 .44309 .24401 .436 Mtetra
.667 .771 .928 r
.24401 .436 .25225 .44309 .26452 .43873 .25634 .43146 Mtetra
.663 .766 .927 r
.25634 .43146 .26452 .43873 .27685 .43443 .26871 .42702 Mtetra
.659 .762 .926 r
.26871 .42702 .27685 .43443 .28923 .43004 .28112 .42268 Mtetra
.66 .765 .927 r
.28112 .42268 .28923 .43004 .30168 .42566 .2936 .41827 Mtetra
.666 .767 .925 r
.2936 .41827 .30168 .42566 .31417 .42132 .30615 .41368 Mtetra
.665 .761 .921 r
.30615 .41368 .31417 .42132 .32672 .41702 .31875 .40908 Mtetra
.662 .753 .918 r
.31875 .40908 .32672 .41702 .33933 .41272 .33141 .40458 Mtetra
.667 .75 .912 r
.33141 .40458 .33933 .41272 .35203 .40786 .34413 .39987 Mtetra
.666 .755 .916 r
.34413 .39987 .35203 .40786 .3648 .40259 .35691 .39518 Mtetra
.636 .763 .939 r
.35691 .39518 .3648 .40259 .37759 .39816 .36971 .39132 Mtetra
.621 .776 .955 r
.36971 .39132 .37759 .39816 .39039 .39473 .38256 .38776 Mtetra
.669 .787 .937 r
.38256 .38776 .39039 .39473 .4033 .39045 .39553 .38291 Mtetra
.707 .782 .91 r
.39553 .38291 .4033 .39045 .41632 .38453 .40861 .37676 Mtetra
.695 .774 .912 r
.40861 .37676 .41632 .38453 .42941 .37832 .42172 .37099 Mtetra
.644 .773 .942 r
.42172 .37099 .42941 .37832 .4425 .37346 .43484 .3668 Mtetra
.569 .768 .972 r
.43484 .3668 .4425 .37346 .45562 .37025 .44799 .36425 Mtetra
.495 .759 .989 r
.44799 .36425 .45562 .37025 .4688 .368 .46119 .36279 Mtetra
.538 .804 .995 r
.46119 .36279 .4688 .368 .48207 .36499 .47451 .36023 Mtetra
.748 .879 .939 r
.47451 .36023 .48207 .36499 .49543 .36058 .48796 .35254 Mtetra
.767 .792 .873 r
.48796 .35254 .49543 .36058 .50885 .35666 .50147 .34346 Mtetra
.665 .654 .83 r
.50147 .34346 .50885 .35666 .52235 .35267 .51499 .33793 Mtetra
.565 .583 .83 r
.51499 .33793 .52235 .35267 .53592 .34899 .52858 .33648 Mtetra
.585 .632 .864 r
.52858 .33648 .53592 .34899 .54956 .34493 .54225 .3342 Mtetra
.636 .692 .886 r
.54225 .3342 .54956 .34493 .56326 .33956 .556 .33013 Mtetra
.663 .734 .903 r
.556 .33013 .56326 .33956 .577 .33344 .56981 .32513 Mtetra
.675 .768 .921 r
.56981 .32513 .577 .33344 .59081 .32722 .58368 .31976 Mtetra
.676 .794 .937 r
.58368 .31976 .59081 .32722 .60467 .32128 .59761 .3143 Mtetra
.654 .802 .954 r
.59761 .3143 .60467 .32128 .61863 .31654 .61163 .30944 Mtetra
.616 .786 .963 r
.61163 .30944 .61863 .31654 .63271 .31334 .62574 .30558 Mtetra
.622 .769 .951 r
.62574 .30558 .63271 .31334 .64688 .31 .63994 .30165 Mtetra
.655 .766 .932 r
.63994 .30165 .64688 .31 .66107 .30524 .65417 .29681 Mtetra
.652 .764 .932 r
.65417 .29681 .66107 .30524 .67532 .30022 .66849 .29204 Mtetra
.608 .755 .949 r
.66849 .29204 .67532 .30022 .6897 .29639 .68294 .28849 Mtetra
.546 .737 .964 r
.68294 .28849 .6897 .29639 .70425 .294 .69756 .28641 Mtetra
.474 .711 .973 r
.69756 .28641 .70425 .294 .71901 .29335 .71237 .28573 Mtetra
.462 .705 .973 r
.71237 .28573 .71901 .29335 .73398 .29412 .72731 .28527 Mtetra
.614 .744 .938 r
.72731 .28527 .73398 .29412 .74894 .29292 .74215 .28154 Mtetra
.74 .736 .848 r
.74215 .28154 .74894 .29292 .76355 .28564 .75667 .27244 Mtetra
.757 .711 .809 r
.75667 .27244 .76355 .28564 .77789 .27446 .77108 .26143 Mtetra
.7 .691 .838 r
.77108 .26143 .77789 .27446 .79252 .26639 .7858 .25386 Mtetra
.572 .664 .901 r
.12733 .46572 .1356 .47552 .14705 .47451 .13887 .46402 Mtetra
.426 .583 .905 r
.13887 .46402 .14705 .47451 .15824 .47657 .15014 .4654 Mtetra
.464 .586 .891 r
.15014 .4654 .15824 .47657 .16978 .47618 .16155 .46628 Mtetra
.636 .688 .882 r
.16155 .46628 .16978 .47618 .182 .47012 .17352 .46269 Mtetra
.748 .773 .873 r
.17352 .46269 .182 .47012 .19456 .46102 .18598 .455 Mtetra
.77 .812 .886 r
.18598 .455 .19456 .46102 .20707 .45267 .19853 .44665 Mtetra
.742 .812 .908 r
.19853 .44665 .20707 .45267 .21943 .44609 .21099 .43962 Mtetra
.705 .796 .921 r
.21099 .43962 .21943 .44609 .23172 .44076 .22335 .43387 Mtetra
.682 .781 .926 r
.22335 .43387 .23172 .44076 .24401 .436 .2357 .42886 Mtetra
.67 .773 .927 r
.2357 .42886 .24401 .436 .25634 .43146 .24807 .4242 Mtetra
.664 .769 .927 r
.24807 .4242 .25634 .43146 .26871 .42702 .26048 .41967 Mtetra
.665 .768 .926 r
.26048 .41967 .26871 .42702 .28112 .42268 .27295 .41509 Mtetra
.663 .762 .923 r
.27295 .41509 .28112 .42268 .2936 .41827 .28547 .41058 Mtetra
.66 .759 .923 r
.28547 .41058 .2936 .41827 .30615 .41368 .29804 .40612 Mtetra
.66 .764 .926 r
.29804 .40612 .30615 .41368 .31875 .40908 .31068 .40165 Mtetra
.666 .77 .927 r
.31068 .40165 .31875 .40908 .33141 .40458 .32338 .39696 Mtetra
.673 .768 .921 r
.32338 .39696 .33141 .40458 .34413 .39987 .33615 .39204 Mtetra
.667 .761 .921 r
.33615 .39204 .34413 .39987 .35691 .39518 .34898 .38728 Mtetra
.646 .754 .928 r
.34898 .38728 .35691 .39518 .36971 .39132 .36182 .38313 Mtetra
.645 .747 .923 r
.36182 .38313 .36971 .39132 .38256 .38776 .37473 .37901 Mtetra
.664 .739 .906 r
.37473 .37901 .38256 .38776 .39553 .38291 .38774 .37426 Mtetra
.678 .747 .903 r
.38774 .37426 .39553 .38291 .40861 .37676 .40082 .369 Mtetra
.671 .77 .925 r
.40082 .369 .40861 .37676 .42172 .37099 .41395 .36403 Mtetra
.655 .789 .946 r
.41395 .36403 .42172 .37099 .43484 .3668 .42712 .35945 Mtetra
.625 .769 .949 r
.42712 .35945 .43484 .3668 .44799 .36425 .44034 .35571 Mtetra
.618 .734 .929 r
.44034 .35571 .44799 .36425 .46119 .36279 .45362 .35226 Mtetra
.624 .689 .89 r
.45362 .35226 .46119 .36279 .47451 .36023 .46698 .34867 Mtetra
.669 .686 .857 r
.46698 .34867 .47451 .36023 .48796 .35254 .48044 .34327 Mtetra
.849 .775 .78 r
.48044 .34327 .48796 .35254 .50147 .34346 .49407 .32678 Mtetra
.551 .548 .804 r
.49407 .32678 .50147 .34346 .51499 .33793 .50758 .32588 Mtetra
.501 .6 .884 r
.50758 .32588 .51499 .33793 .52858 .33648 .52118 .32605 Mtetra
.568 .67 .908 r
.52118 .32605 .52858 .33648 .54225 .3342 .53489 .3241 Mtetra
.626 .705 .902 r
.53489 .3241 .54225 .3342 .556 .33013 .54868 .32033 Mtetra
.659 .726 .898 r
.54868 .32033 .556 .33013 .56981 .32513 .56253 .31541 Mtetra
.651 .726 .904 r
.56253 .31541 .56981 .32513 .58368 .31976 .57646 .31077 Mtetra
.636 .74 .923 r
.57646 .31077 .58368 .31976 .59761 .3143 .59047 .30658 Mtetra
.621 .77 .952 r
.59047 .30658 .59761 .3143 .61163 .30944 .60456 .30269 Mtetra
.627 .803 .967 r
.60456 .30269 .61163 .30944 .62574 .30558 .61872 .29842 Mtetra
.653 .801 .954 r
.61872 .29842 .62574 .30558 .63994 .30165 .63293 .29351 Mtetra
.663 .777 .934 r
.63293 .29351 .63994 .30165 .65417 .29681 .64721 .28834 Mtetra
.639 .76 .936 r
.64721 .28834 .65417 .29681 .66849 .29204 .6616 .28392 Mtetra
.59 .752 .955 r
.6616 .28392 .66849 .29204 .68294 .28849 .67612 .28076 Mtetra
.529 .736 .97 r
.67612 .28076 .68294 .28849 .69756 .28641 .69081 .27892 Mtetra
.487 .724 .976 r
.69081 .27892 .69756 .28641 .71237 .28573 .70565 .27785 Mtetra
.549 .744 .967 r
.70565 .27785 .71237 .28573 .72731 .28527 .72053 .27556 Mtetra
.69 .755 .901 r
.72053 .27556 .72731 .28527 .74215 .28154 .73524 .2692 Mtetra
.751 .724 .827 r
.73524 .2692 .74215 .28154 .75667 .27244 .74973 .25902 Mtetra
.742 .703 .814 r
.74973 .25902 .75667 .27244 .77108 .26143 .76425 .24884 Mtetra
.689 .696 .851 r
.76425 .24884 .77108 .26143 .7858 .25386 .77908 .24192 Mtetra
.6 .694 .909 r
.11891 .45662 .12733 .46572 .13887 .46402 .13056 .4541 Mtetra
.486 .628 .915 r
.13056 .4541 .13887 .46402 .15014 .4654 .14198 .4542 Mtetra
.444 .578 .893 r
.14198 .4542 .15014 .4654 .16155 .46628 .15335 .45541 Mtetra
.554 .637 .887 r
.15335 .45541 .16155 .46628 .17352 .46269 .16509 .45417 Mtetra
.694 .74 .886 r
.16509 .45417 .17352 .46269 .18598 .455 .17735 .4486 Mtetra
.757 .803 .89 r
.17735 .4486 .18598 .455 .19853 .44665 .1899 .44077 Mtetra
.751 .818 .905 r
.1899 .44077 .19853 .44665 .21099 .43962 .20244 .43334 Mtetra
.719 .805 .919 r
.20244 .43334 .21099 .43962 .22335 .43387 .21489 .42711 Mtetra
.691 .788 .925 r
.21489 .42711 .22335 .43387 .2357 .42886 .2273 .42178 Mtetra
.676 .777 .926 r
.2273 .42178 .2357 .42886 .24807 .4242 .23973 .41687 Mtetra
.669 .77 .926 r
.23973 .41687 .24807 .4242 .26048 .41967 .25219 .41218 Mtetra
.662 .765 .926 r
.25219 .41218 .26048 .41967 .27295 .41509 .26469 .40767 Mtetra
.663 .768 .928 r
.26469 .40767 .27295 .41509 .28547 .41058 .27724 .4031 Mtetra
.666 .768 .926 r
.27724 .4031 .28547 .41058 .29804 .40612 .28987 .39842 Mtetra
.667 .763 .922 r
.28987 .39842 .29804 .40612 .31068 .40165 .30256 .39367 Mtetra
.669 .758 .917 r
.30256 .39367 .31068 .40165 .32338 .39696 .3153 .38888 Mtetra
.664 .754 .917 r
.3153 .38888 .32338 .39696 .33615 .39204 .3281 .38418 Mtetra
.651 .758 .928 r
.3281 .38418 .33615 .39204 .34898 .38728 .34093 .37989 Mtetra
.641 .769 .94 r
.34093 .37989 .34898 .38728 .36182 .38313 .35382 .37581 Mtetra
.654 .776 .938 r
.35382 .37581 .36182 .38313 .37473 .37901 .36678 .37133 Mtetra
.661 .769 .93 r
.36678 .37133 .37473 .37901 .38774 .37426 .37982 .36666 Mtetra
.65 .769 .936 r
.37982 .36666 .38774 .37426 .40082 .369 .39291 .36228 Mtetra
.647 .795 .953 r
.39291 .36228 .40082 .369 .41395 .36403 .40606 .35787 Mtetra
.667 .818 .956 r
.40606 .35787 .41395 .36403 .42712 .35945 .4193 .35283 Mtetra
.674 .808 .947 r
.4193 .35283 .42712 .35945 .44034 .35571 .43261 .3476 Mtetra
.667 .765 .923 r
.43261 .3476 .44034 .35571 .45362 .35226 .44597 .34262 Mtetra
.668 .727 .894 r
.44597 .34262 .45362 .35226 .46698 .34867 .4594 .33752 Mtetra
.687 .702 .859 r
.4594 .33752 .46698 .34867 .48044 .34327 .4729 .33139 Mtetra
.709 .698 .837 r
.4729 .33139 .48044 .34327 .49407 .32678 .48647 .32395 Mtetra
.572 .892 .987 r
.48647 .32395 .49407 .32678 .50758 .32588 .50007 .31945 Mtetra
.523 .765 .985 r
.50007 .31945 .50758 .32588 .52118 .32605 .51372 .31748 Mtetra
.574 .724 .944 r
.51372 .31748 .52118 .32605 .53489 .3241 .52747 .31501 Mtetra
.638 .736 .92 r
.52747 .31501 .53489 .3241 .54868 .32033 .5413 .31079 Mtetra
.663 .735 .904 r
.5413 .31079 .54868 .32033 .56253 .31541 .55519 .30573 Mtetra
.631 .721 .912 r
.55519 .30573 .56253 .31541 .57646 .31077 .56917 .30172 Mtetra
.582 .718 .936 r
.56917 .30172 .57646 .31077 .59047 .30658 .58325 .29905 Mtetra
.585 .764 .964 r
.58325 .29905 .59047 .30658 .60456 .30269 .59742 .29596 Mtetra
.647 .813 .963 r
.59742 .29596 .60456 .30269 .61872 .29842 .61162 .2911 Mtetra
.681 .808 .943 r
.61162 .2911 .61872 .29842 .63293 .29351 .62586 .2853 Mtetra
.664 .778 .934 r
.62586 .2853 .63293 .29351 .64721 .28834 .6402 .28006 Mtetra
.623 .762 .946 r
.6402 .28006 .64721 .28834 .6616 .28392 .65465 .27603 Mtetra
.57 .752 .963 r
.65465 .27603 .6616 .28392 .67612 .28076 .66925 .27326 Mtetra
.523 .743 .975 r
.66925 .27326 .67612 .28076 .69081 .27892 .684 .27141 Mtetra
.537 .751 .975 r
.684 .27141 .69081 .27892 .70565 .27785 .69883 .26923 Mtetra
.646 .767 .937 r
.69883 .26923 .70565 .27785 .72053 .27556 .71361 .26442 Mtetra
.73 .74 .859 r
.71361 .26442 .72053 .27556 .73524 .2692 .72822 .25589 Mtetra
.743 .706 .817 r
.72822 .25589 .73524 .2692 .74973 .25902 .74276 .24575 Mtetra
.72 .698 .828 r
.74276 .24575 .74973 .25902 .76425 .24884 .75744 .23696 Mtetra
.677 .706 .869 r
.75744 .23696 .76425 .24884 .77908 .24192 .77237 .2307 Mtetra
.626 .72 .914 r
.11033 .44817 .11891 .45662 .13056 .4541 .1221 .44489 Mtetra
.554 .677 .92 r
.1221 .44489 .13056 .4541 .14198 .4542 .13371 .44342 Mtetra
.477 .605 .901 r
.13371 .44342 .14198 .4542 .15335 .45541 .14518 .44383 Mtetra
.493 .595 .884 r
.14518 .44383 .15335 .45541 .16509 .45417 .15675 .44407 Mtetra
.611 .679 .89 r
.15675 .44407 .16509 .45417 .17735 .4486 .16875 .44119 Mtetra
.718 .774 .897 r
.16875 .44119 .17735 .4486 .1899 .44077 .18118 .43481 Mtetra
.75 .817 .905 r
.18118 .43481 .1899 .44077 .20244 .43334 .19377 .42735 Mtetra
.733 .817 .917 r
.19377 .42735 .20244 .43334 .21489 .42711 .20632 .42058 Mtetra
.705 .799 .924 r
.20632 .42058 .21489 .42711 .2273 .42178 .21881 .41476 Mtetra
.682 .782 .926 r
.21881 .41476 .2273 .42178 .23973 .41687 .23129 .40964 Mtetra
.673 .775 .927 r
.23129 .40964 .23973 .41687 .25219 .41218 .2438 .40479 Mtetra
.67 .772 .926 r
.2438 .40479 .25219 .41218 .26469 .40767 .25636 .4 Mtetra
.665 .764 .924 r
.25636 .4 .26469 .40767 .27724 .4031 .26896 .39535 Mtetra
.66 .761 .925 r
.26896 .39535 .27724 .4031 .28987 .39842 .28161 .39082 Mtetra
.661 .767 .928 r
.28161 .39082 .28987 .39842 .30256 .39367 .29432 .38622 Mtetra
.672 .775 .927 r
.29432 .38622 .30256 .39367 .3153 .38888 .30711 .38129 Mtetra
.675 .773 .924 r
.30711 .38129 .3153 .38888 .3281 .38418 .31997 .37624 Mtetra
.657 .759 .925 r
.31997 .37624 .3281 .38418 .34093 .37989 .33285 .37171 Mtetra
.644 .75 .926 r
.33285 .37171 .34093 .37989 .35382 .37581 .34578 .36757 Mtetra
.655 .753 .922 r
.34578 .36757 .35382 .37581 .36678 .37133 .35878 .36306 Mtetra
.661 .755 .919 r
.35878 .36306 .36678 .37133 .37982 .36666 .37186 .35834 Mtetra
.64 .748 .927 r
.37186 .35834 .37982 .36666 .39291 .36228 .38498 .35424 Mtetra
.63 .753 .936 r
.38498 .35424 .39291 .36228 .40606 .35787 .39815 .35039 Mtetra
.657 .779 .938 r
.39815 .35039 .40606 .35787 .4193 .35283 .41142 .3457 Mtetra
.688 .799 .934 r
.41142 .3457 .4193 .35283 .43261 .3476 .42479 .34005 Mtetra
.692 .789 .925 r
.42479 .34005 .43261 .3476 .44597 .34262 .43822 .33422 Mtetra
.684 .765 .913 r
.43822 .33422 .44597 .34262 .4594 .33752 .4517 .3286 Mtetra
.676 .751 .907 r
.4517 .3286 .4594 .33752 .4729 .33139 .46523 .3232 Mtetra
.66 .765 .928 r
.46523 .3232 .4729 .33139 .48647 .32395 .47882 .31834 Mtetra
.616 .828 .982 r
.47882 .31834 .48647 .32395 .50007 .31945 .49247 .31418 Mtetra
.584 .829 .991 r
.49247 .31418 .50007 .31945 .51372 .31748 .50618 .31055 Mtetra
.613 .789 .966 r
.50618 .31055 .51372 .31748 .52747 .31501 .51998 .30674 Mtetra
.645 .763 .934 r
.51998 .30674 .52747 .31501 .5413 .31079 .53386 .30221 Mtetra
.649 .757 .929 r
.53386 .30221 .5413 .31079 .55519 .30573 .5478 .29757 Mtetra
.603 .753 .949 r
.5478 .29757 .55519 .30573 .56917 .30172 .56183 .29416 Mtetra
.548 .748 .969 r
.56183 .29416 .56917 .30172 .58325 .29905 .57597 .29188 Mtetra
.585 .777 .971 r
.57597 .29188 .58325 .29905 .59742 .29596 .59019 .28865 Mtetra
.667 .805 .949 r
.59019 .28865 .59742 .29596 .61162 .2911 .60443 .28326 Mtetra
.691 .799 .932 r
.60443 .28326 .61162 .2911 .62586 .2853 .61873 .27711 Mtetra
.656 .778 .939 r
.61873 .27711 .62586 .2853 .6402 .28006 .63312 .27207 Mtetra
.601 .764 .957 r
.63312 .27207 .6402 .28006 .65465 .27603 .64765 .26851 Mtetra
.556 .759 .972 r
.64765 .26851 .65465 .27603 .66925 .27326 .66232 .2659 Mtetra
.552 .764 .976 r
.66232 .2659 .66925 .27326 .684 .27141 .67708 .2633 Mtetra
.627 .775 .951 r
.67708 .2633 .684 .27141 .69883 .26923 .69185 .25896 Mtetra
.711 .753 .885 r
.69185 .25896 .69883 .26923 .71361 .26442 .70653 .25157 Mtetra
.734 .711 .829 r
.70653 .25157 .71361 .26442 .72822 .25589 .72113 .24216 Mtetra
.721 .692 .822 r
.72113 .24216 .72822 .25589 .74276 .24575 .7358 .23317 Mtetra
.696 .702 .851 r
.7358 .23317 .74276 .24575 .75744 .23696 .75064 .22588 Mtetra
.667 .721 .889 r
.75064 .22588 .75744 .23696 .77237 .2307 .76566 .22013 Mtetra
.643 .738 .918 r
.10162 .44014 .11033 .44817 .1221 .44489 .11348 .43633 Mtetra
.607 .714 .921 r
.11348 .43633 .1221 .44489 .13371 .44342 .12527 .43349 Mtetra
.543 .657 .91 r
.12527 .43349 .13371 .44342 .14518 .44383 .13694 .43231 Mtetra
.494 .599 .887 r
.13694 .43231 .14518 .44383 .15675 .44407 .14852 .43247 Mtetra
.53 .614 .881 r
.14852 .43247 .15675 .44407 .16875 .44119 .16028 .43181 Mtetra
.638 .708 .897 r
.16028 .43181 .16875 .44119 .18118 .43481 .17246 .42804 Mtetra
.724 .795 .908 r
.17246 .42804 .18118 .43481 .19377 .42735 .18499 .42151 Mtetra
.74 .823 .916 r
.18499 .42151 .19377 .42735 .20632 .42058 .19761 .41446 Mtetra
.72 .814 .924 r
.19761 .41446 .20632 .42058 .21881 .41476 .2102 .4081 Mtetra
.698 .797 .926 r
.2102 .4081 .21881 .41476 .23129 .40964 .22277 .40245 Mtetra
.68 .78 .926 r
.22277 .40245 .23129 .40964 .2438 .40479 .23534 .39735 Mtetra
.668 .771 .927 r
.23534 .39735 .2438 .40479 .25636 .4 .24793 .39259 Mtetra
.667 .773 .929 r
.24793 .39259 .25636 .4 .26896 .39535 .26057 .38782 Mtetra
.668 .771 .927 r
.26057 .38782 .26896 .39535 .28161 .39082 .27328 .383 Mtetra
.666 .764 .923 r
.27328 .383 .28161 .39082 .29432 .38622 .28604 .37824 Mtetra
.667 .761 .92 r
.28604 .37824 .29432 .38622 .30711 .38129 .29886 .37341 Mtetra
.671 .766 .921 r
.29886 .37341 .30711 .38129 .31997 .37624 .31176 .36843 Mtetra
.659 .765 .928 r
.31176 .36843 .31997 .37624 .33285 .37171 .32468 .36381 Mtetra
.638 .757 .935 r
.32468 .36381 .33285 .37171 .34578 .36757 .33764 .35978 Mtetra
.639 .762 .937 r
.33764 .35978 .34578 .36757 .35878 .36306 .35066 .35569 Mtetra
.652 .779 .941 r
.35066 .35569 .35878 .36306 .37186 .35834 .36377 .35116 Mtetra
.647 .784 .947 r
.36377 .35116 .37186 .35834 .38498 .35424 .37694 .34674 Mtetra
.633 .772 .947 r
.37694 .34674 .38498 .35424 .39815 .35039 .39016 .34272 Mtetra
.644 .771 .941 r
.39016 .34272 .39815 .35039 .41142 .3457 .40346 .33838 Mtetra
.673 .791 .937 r
.40346 .33838 .41142 .3457 .42479 .34005 .41686 .33314 Mtetra
.692 .809 .937 r
.41686 .33314 .42479 .34005 .43822 .33422 .43034 .32727 Mtetra
.688 .808 .939 r
.43034 .32727 .43822 .33422 .4517 .3286 .44388 .3215 Mtetra
.666 .799 .946 r
.44388 .3215 .4517 .3286 .46523 .3232 .45746 .3164 Mtetra
.639 .8 .96 r
.45746 .3164 .46523 .3232 .47882 .31834 .47109 .31196 Mtetra
.62 .808 .972 r
.47109 .31196 .47882 .31834 .49247 .31418 .48479 .30786 Mtetra
.627 .814 .972 r
.48479 .30786 .49247 .31418 .50618 .31055 .49857 .30355 Mtetra
.638 .798 .96 r
.49857 .30355 .50618 .31055 .51998 .30674 .51242 .29907 Mtetra
.642 .781 .948 r
.51242 .29907 .51998 .30674 .53386 .30221 .52634 .29454 Mtetra
.628 .777 .953 r
.52634 .29454 .53386 .30221 .5478 .29757 .54034 .29038 Mtetra
.579 .774 .972 r
.54034 .29038 .5478 .29757 .56183 .29416 .55443 .2873 Mtetra
.547 .772 .981 r
.55443 .2873 .56183 .29416 .57597 .29188 .56862 .28476 Mtetra
.61 .79 .968 r
.56862 .28476 .57597 .29188 .59019 .28865 .58287 .28087 Mtetra
.68 .798 .937 r
.58287 .28087 .59019 .28865 .60443 .28326 .59717 .27505 Mtetra
.683 .788 .929 r
.59717 .27505 .60443 .28326 .61873 .27711 .61152 .2691 Mtetra
.636 .778 .949 r
.61152 .2691 .61873 .27711 .63312 .27207 .62599 .26457 Mtetra
.587 .774 .969 r
.62599 .26457 .63312 .27207 .64765 .26851 .64059 .2612 Mtetra
.58 .779 .973 r
.64059 .2612 .64765 .26851 .66232 .2659 .65528 .2579 Mtetra
.634 .782 .952 r
.65528 .2579 .66232 .2659 .67708 .2633 .67001 .25333 Mtetra
.702 .757 .895 r
.67001 .25333 .67708 .2633 .69185 .25896 .68469 .2464 Mtetra
.724 .713 .839 r
.68469 .2464 .69185 .25896 .70653 .25157 .69934 .23767 Mtetra
.714 .687 .822 r
.69934 .23767 .70653 .25157 .72113 .24216 .71403 .229 Mtetra
.694 .691 .843 r
.71403 .229 .72113 .24216 .7358 .23317 .72886 .22161 Mtetra
.675 .715 .879 r
.72886 .22161 .7358 .23317 .75064 .22588 .74383 .21545 Mtetra
.66 .735 .905 r
.74383 .21545 .75064 .22588 .76566 .22013 .75893 .20998 Mtetra
.652 .747 .919 r
.0928 .4323 .10162 .44014 .11348 .43633 .10472 .42821 Mtetra
.638 .737 .92 r
.10472 .42821 .11348 .43633 .12527 .43349 .11665 .42449 Mtetra
.603 .704 .915 r
.11665 .42449 .12527 .43349 .13694 .43231 .12852 .42173 Mtetra
.548 .646 .898 r
.12852 .42173 .13694 .43231 .14852 .43247 .14027 .42046 Mtetra
.513 .599 .877 r
.14027 .42046 .14852 .43247 .16028 .43181 .15199 .42021 Mtetra
.549 .625 .88 r
.15199 .42021 .16028 .43181 .17246 .42804 .1639 .41901 Mtetra
.643 .721 .904 r
.1639 .41901 .17246 .42804 .18499 .42151 .17619 .41502 Mtetra
.719 .805 .918 r
.17619 .41502 .18499 .42151 .19761 .41446 .18878 .40865 Mtetra
.731 .826 .924 r
.18878 .40865 .19761 .41446 .2102 .4081 .20146 .40187 Mtetra
.711 .813 .929 r
.20146 .40187 .2102 .4081 .22277 .40245 .21411 .39576 Mtetra
.694 .799 .93 r
.21411 .39576 .22277 .40245 .23534 .39735 .22676 .39018 Mtetra
.682 .784 .928 r
.22676 .39018 .23534 .39735 .24793 .39259 .23943 .38494 Mtetra
.669 .769 .925 r
.23943 .38494 .24793 .39259 .26057 .38782 .25212 .38008 Mtetra
.663 .766 .927 r
.25212 .38008 .26057 .38782 .27328 .383 .26486 .37539 Mtetra
.661 .77 .931 r
.26486 .37539 .27328 .383 .28604 .37824 .27765 .37074 Mtetra
.665 .775 .931 r
.27765 .37074 .28604 .37824 .29886 .37341 .29051 .36592 Mtetra
.676 .779 .928 r
.29051 .36592 .29886 .37341 .31176 .36843 .30345 .36075 Mtetra
.677 .776 .924 r
.30345 .36075 .31176 .36843 .32468 .36381 .31646 .35551 Mtetra
.659 .755 .921 r
.31646 .35551 .32468 .36381 .33764 .35978 .32948 .35081 Mtetra
.638 .732 .917 r
.32948 .35081 .33764 .35978 .35066 .35569 .34254 .34674 Mtetra
.632 .732 .92 r
.34254 .34674 .35066 .35569 .36377 .35116 .35565 .34284 Mtetra
.631 .749 .933 r
.35565 .34284 .36377 .35116 .37694 .34674 .36884 .33891 Mtetra
.626 .762 .944 r
.36884 .33891 .37694 .34674 .39016 .34272 .38209 .33504 Mtetra
.629 .768 .947 r
.38209 .33504 .39016 .34272 .40346 .33838 .39542 .33106 Mtetra
.647 .786 .948 r
.39542 .33106 .40346 .33838 .41686 .33314 .40884 .32651 Mtetra
.668 .813 .953 r
.40884 .32651 .41686 .33314 .43034 .32727 .42236 .32132 Mtetra
.673 .835 .961 r
.42236 .32132 .43034 .32727 .44388 .3215 .43594 .31586 Mtetra
.661 .842 .97 r
.43594 .31586 .44388 .3215 .45746 .3164 .44958 .31062 Mtetra
.647 .836 .973 r
.44958 .31062 .45746 .3164 .47109 .31196 .46327 .30573 Mtetra
.646 .823 .968 r
.46327 .30573 .47109 .31196 .48479 .30786 .47704 .30092 Mtetra
.643 .802 .959 r
.47704 .30092 .48479 .30786 .49857 .30355 .49087 .29627 Mtetra
.636 .791 .957 r
.49087 .29627 .49857 .30355 .51242 .29907 .50477 .29185 Mtetra
.629 .792 .96 r
.50477 .29185 .51242 .29907 .52634 .29454 .51875 .28756 Mtetra
.608 .793 .97 r
.51875 .28756 .52634 .29454 .54034 .29038 .5328 .28371 Mtetra
.569 .788 .982 r
.5328 .28371 .54034 .29038 .55443 .2873 .54695 .28063 Mtetra
.57 .789 .982 r
.54695 .28063 .55443 .2873 .56862 .28476 .56118 .27749 Mtetra
.636 .798 .96 r
.56118 .27749 .56862 .28476 .58287 .28087 .57548 .27288 Mtetra
.681 .794 .935 r
.57548 .27288 .58287 .28087 .59717 .27505 .58983 .26699 Mtetra
.668 .789 .939 r
.58983 .26699 .59717 .27505 .61152 .2691 .60426 .26149 Mtetra
.627 .789 .959 r
.60426 .26149 .61152 .2691 .62599 .26457 .61879 .25709 Mtetra
.618 .79 .964 r
.61879 .25709 .62599 .26457 .64059 .2612 .63341 .25288 Mtetra
.659 .783 .94 r
.63341 .25288 .64059 .2612 .65528 .2579 .64808 .24759 Mtetra
.701 .75 .889 r
.64808 .24759 .65528 .2579 .67001 .25333 .66275 .2406 Mtetra
.713 .706 .842 r
.66275 .2406 .67001 .25333 .68469 .2464 .67741 .23239 Mtetra
.703 .681 .826 r
.67741 .23239 .68469 .2464 .69934 .23767 .69213 .22426 Mtetra
.688 .685 .842 r
.69213 .22426 .69934 .23767 .71403 .229 .70696 .21713 Mtetra
.673 .709 .874 r
.70696 .21713 .71403 .229 .72886 .22161 .72192 .21099 Mtetra
.663 .733 .902 r
.72192 .21099 .72886 .22161 .74383 .21545 .73699 .20539 Mtetra
.657 .745 .915 r
.73699 .20539 .74383 .21545 .75893 .20998 .75215 .2 Mtetra
.655 .75 .92 r
.08389 .42449 .0928 .4323 .10472 .42821 .09585 .42028 Mtetra
.651 .747 .92 r
.09585 .42028 .10472 .42821 .11665 .42449 .10786 .41615 Mtetra
.638 .734 .918 r
.10786 .41615 .11665 .42449 .12852 .42173 .11987 .41239 Mtetra
.607 .7 .909 r
.11987 .41239 .12852 .42173 .14027 .42046 .13184 .40947 Mtetra
.561 .645 .89 r
.13184 .40947 .14027 .42046 .15199 .42021 .14373 .40785 Mtetra
.531 .603 .871 r
.14373 .40785 .15199 .42021 .1639 .41901 .15558 .40714 Mtetra
.553 .624 .877 r
.15558 .40714 .1639 .41901 .17619 .41502 .1676 .40578 Mtetra
.631 .714 .907 r
.1676 .40578 .17619 .41502 .18878 .40865 .17993 .40212 Mtetra
.706 .805 .926 r
.17993 .40212 .18878 .40865 .20146 .40187 .19257 .39616 Mtetra
.726 .831 .93 r
.19257 .39616 .20146 .40187 .21411 .39576 .20532 .38949 Mtetra
.708 .815 .931 r
.20532 .38949 .21411 .39576 .22676 .39018 .21806 .38341 Mtetra
.688 .798 .933 r
.21806 .38341 .22676 .39018 .23943 .38494 .23079 .37794 Mtetra
.681 .791 .933 r
.23079 .37794 .23943 .38494 .25212 .38008 .24356 .37269 Mtetra
.676 .78 .929 r
.24356 .37269 .25212 .38008 .26486 .37539 .25637 .36755 Mtetra
.669 .768 .924 r
.25637 .36755 .26486 .37539 .27765 .37074 .26921 .3626 Mtetra
.66 .759 .923 r
.26921 .3626 .27765 .37074 .29051 .36592 .2821 .35791 Mtetra
.659 .763 .927 r
.2821 .35791 .29051 .36592 .30345 .36075 .29505 .35322 Mtetra
.667 .779 .933 r
.29505 .35322 .30345 .36075 .31646 .35551 .30808 .34827 Mtetra
.67 .789 .938 r
.30808 .34827 .31646 .35551 .32948 .35081 .32117 .34318 Mtetra
.661 .777 .935 r
.32117 .34318 .32948 .35081 .34254 .34674 .33431 .33837 Mtetra
.645 .753 .928 r
.33431 .33837 .34254 .34674 .35565 .34284 .34748 .33403 Mtetra
.63 .738 .925 r
.34748 .33403 .35565 .34284 .36884 .33891 .3607 .3301 Mtetra
.619 .735 .929 r
.3607 .3301 .36884 .33891 .38209 .33504 .37398 .32647 Mtetra
.613 .74 .936 r
.37398 .32647 .38209 .33504 .39542 .33106 .38733 .32296 Mtetra
.618 .756 .944 r
.38733 .32296 .39542 .33106 .40884 .32651 .40076 .31925 Mtetra
.632 .786 .955 r
.40076 .31925 .40884 .32651 .42236 .32132 .41429 .31502 Mtetra
.648 .82 .966 r
.41429 .31502 .42236 .32132 .43594 .31586 .4279 .31021 Mtetra
.658 .843 .971 r
.4279 .31021 .43594 .31586 .44958 .31062 .4416 .305 Mtetra
.66 .846 .971 r
.4416 .305 .44958 .31062 .46327 .30573 .45536 .29969 Mtetra
.652 .833 .97 r
.45536 .29969 .46327 .30573 .47704 .30092 .46919 .29465 Mtetra
.64 .823 .971 r
.46919 .29465 .47704 .30092 .49087 .29627 .48308 .2899 Mtetra
.632 .819 .972 r
.48308 .2899 .49087 .29627 .50477 .29185 .49704 .28533 Mtetra
.62 .812 .974 r
.49704 .28533 .50477 .29185 .51875 .28756 .51107 .28106 Mtetra
.588 .802 .981 r
.51107 .28106 .51875 .28756 .5328 .28371 .52518 .27748 Mtetra
.56 .8 .989 r
.52518 .27748 .5328 .28371 .54695 .28063 .53938 .27437 Mtetra
.595 .814 .984 r
.53938 .27437 .54695 .28063 .56118 .27749 .55367 .27049 Mtetra
.664 .818 .957 r
.55367 .27049 .56118 .27749 .57548 .27288 .56801 .26503 Mtetra
.688 .803 .936 r
.56801 .26503 .57548 .27288 .58983 .26699 .58242 .25883 Mtetra
.673 .791 .937 r
.58242 .25883 .58983 .26699 .60426 .26149 .5969 .25312 Mtetra
.664 .783 .937 r
.5969 .25312 .60426 .26149 .61879 .25709 .61146 .24766 Mtetra
.685 .764 .912 r
.61146 .24766 .61879 .25709 .63341 .25288 .62606 .24145 Mtetra
.701 .726 .869 r
.62606 .24145 .63341 .25288 .64808 .24759 .6407 .23421 Mtetra
.7 .69 .837 r
.6407 .23421 .64808 .24759 .66275 .2406 .65538 .22649 Mtetra
.69 .674 .83 r
.65538 .22649 .66275 .2406 .67741 .23239 .67012 .21905 Mtetra
.678 .683 .847 r
.67012 .21905 .67741 .23239 .69213 .22426 .68496 .21238 Mtetra
.668 .708 .877 r
.68496 .21238 .69213 .22426 .70696 .21713 .69991 .20643 Mtetra
.661 .731 .902 r
.69991 .20643 .70696 .21713 .72192 .21099 .71496 .20086 Mtetra
.657 .745 .914 r
.71496 .20086 .72192 .21099 .73699 .20539 .7301 .19544 Mtetra
.656 .75 .919 r
.7301 .19544 .73699 .20539 .75215 .2 .74532 .19003 Mtetra
.656 .751 .92 r
.0749 .41664 .08389 .42449 .09585 .42028 .0869 .41236 Mtetra
.655 .75 .92 r
.0869 .41236 .09585 .42028 .10786 .41615 .09895 .40809 Mtetra
.652 .747 .919 r
.09895 .40809 .10786 .41615 .11987 .41239 .11104 .40389 Mtetra
.641 .734 .916 r
.11104 .40389 .11987 .41239 .13184 .40947 .12316 .39999 Mtetra
.617 .702 .906 r
.12316 .39999 .13184 .40947 .14373 .40785 .13525 .39675 Mtetra
.58 .653 .886 r
.13525 .39675 .14373 .40785 .15558 .40714 .14729 .39457 Mtetra
.55 .61 .866 r
.14729 .39457 .15558 .40714 .1676 .40578 .15929 .39331 Mtetra
.553 .614 .868 r
.15929 .39331 .1676 .40578 .17993 .40212 .17139 .39195 Mtetra
.604 .685 .9 r
.17139 .39195 .17993 .40212 .19257 .39616 .18373 .38902 Mtetra
.677 .785 .931 r
.18373 .38902 .19257 .39616 .20532 .38949 .19637 .3839 Mtetra
.718 .837 .938 r
.19637 .3839 .20532 .38949 .21806 .38341 .20919 .37747 Mtetra
.714 .828 .935 r
.20919 .37747 .21806 .38341 .23079 .37794 .22205 .37113 Mtetra
.691 .801 .933 r
.22205 .37113 .23079 .37794 .24356 .37269 .23488 .3655 Mtetra
.675 .788 .934 r
.23488 .3655 .24356 .37269 .25637 .36755 .24773 .36036 Mtetra
.671 .788 .937 r
.24773 .36036 .25637 .36755 .26921 .3626 .26063 .35531 Mtetra
.672 .787 .935 r
.26063 .35531 .26921 .3626 .2821 .35791 .27359 .35022 Mtetra
.669 .776 .93 r
.27359 .35022 .2821 .35791 .29505 .35322 .2866 .3452 Mtetra
.667 .768 .926 r
.2866 .3452 .29505 .35322 .30808 .34827 .29966 .34022 Mtetra
.667 .768 .925 r
.29966 .34022 .30808 .34827 .32117 .34318 .3128 .33519 Mtetra
.668 .771 .927 r
.3128 .33519 .32117 .34318 .33431 .33837 .32599 .33012 Mtetra
.662 .764 .925 r
.32599 .33012 .33431 .33837 .34748 .33403 .33924 .3252 Mtetra
.651 .747 .92 r
.33924 .3252 .34748 .33403 .3607 .3301 .35253 .32061 Mtetra
.637 .726 .913 r
.35253 .32061 .3607 .3301 .37398 .32647 .36587 .31643 Mtetra
.624 .709 .907 r
.36587 .31643 .37398 .32647 .38733 .32296 .37926 .31262 Mtetra
.617 .7 .904 r
.37926 .31262 .38733 .32296 .40076 .31925 .39272 .30902 Mtetra
.618 .704 .907 r
.39272 .30902 .40076 .31925 .41429 .31502 .40626 .30537 Mtetra
.625 .722 .917 r
.40626 .30537 .41429 .31502 .4279 .31021 .41988 .30147 Mtetra
.633 .75 .932 r
.41988 .30147 .4279 .31021 .4416 .305 .43359 .29726 Mtetra
.636 .779 .95 r
.43359 .29726 .4416 .305 .45536 .29969 .44738 .29285 Mtetra
.637 .806 .964 r
.44738 .29285 .45536 .29969 .46919 .29465 .46125 .28828 Mtetra
.633 .82 .972 r
.46125 .28828 .46919 .29465 .48308 .2899 .47519 .28367 Mtetra
.621 .822 .978 r
.47519 .28367 .48308 .2899 .49704 .28533 .48921 .27928 Mtetra
.593 .818 .986 r
.48921 .27928 .49704 .28533 .51107 .28106 .5033 .27544 Mtetra
.566 .822 .993 r
.5033 .27544 .51107 .28106 .52518 .27748 .51747 .27194 Mtetra
.596 .837 .99 r
.51747 .27194 .52518 .27748 .53938 .27437 .53173 .26779 Mtetra
.67 .833 .961 r
.53173 .26779 .53938 .27437 .55367 .27049 .54606 .26207 Mtetra
.708 .794 .918 r
.54606 .26207 .55367 .27049 .56801 .26503 .56044 .25514 Mtetra
.704 .758 .894 r
.56044 .25514 .56801 .26503 .58242 .25883 .57489 .24814 Mtetra
.693 .737 .885 r
.57489 .24814 .58242 .25883 .5969 .25312 .58939 .24144 Mtetra
.692 .717 .868 r
.58939 .24144 .5969 .25312 .61146 .24766 .60396 .23456 Mtetra
.691 .691 .845 r
.60396 .23456 .61146 .24766 .62606 .24145 .61858 .22736 Mtetra
.683 .671 .832 r
.61858 .22736 .62606 .24145 .6407 .23421 .63326 .22029 Mtetra
.675 .671 .839 r
.63326 .22029 .6407 .23421 .65538 .22649 .64801 .21366 Mtetra
.669 .689 .86 r
.64801 .21366 .65538 .22649 .67012 .21905 .66286 .20752 Mtetra
.663 .714 .886 r
.66286 .20752 .67012 .21905 .68496 .21238 .6778 .2018 Mtetra
.659 .734 .905 r
.6778 .2018 .68496 .21238 .69991 .20643 .69283 .1963 Mtetra
.657 .746 .915 r
.69283 .1963 .69991 .20643 .71496 .20086 .70795 .19087 Mtetra
.656 .75 .919 r
.70795 .19087 .71496 .20086 .7301 .19544 .72315 .18544 Mtetra
.656 .751 .92 r
.72315 .18544 .7301 .19544 .74532 .19003 .73843 .17999 Mtetra
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Mtetra
.07786 .40441 .0869 .41236 .09895 .40809 .08995 .40007 Mtetra
.655 .75 .92 r
.08995 .40007 .09895 .40809 .11104 .40389 .10209 .39574 Mtetra
.653 .747 .919 r
.10209 .39574 .11104 .40389 .12316 .39999 .11428 .39144 Mtetra
.646 .736 .915 r
.11428 .39144 .12316 .39999 .13525 .39675 .1265 .38734 Mtetra
.629 .711 .905 r
.1265 .38734 .13525 .39675 .14729 .39457 .13873 .38369 Mtetra
.602 .669 .886 r
.13873 .38369 .14729 .39457 .15929 .39331 .15093 .38082 Mtetra
.574 .625 .865 r
.15093 .38082 .15929 .39331 .17139 .39195 .16311 .3788 Mtetra
.56 .607 .857 r
.16311 .3788 .17139 .39195 .18373 .38902 .17531 .3772 Mtetra
.578 .642 .878 r
.17531 .3772 .18373 .38902 .19637 .3839 .18766 .37501 Mtetra
.629 .729 .92 r
.18766 .37501 .19637 .3839 .20919 .37747 .20024 .37126 Mtetra
.684 .817 .946 r
.20024 .37126 .20919 .37747 .22205 .37113 .21306 .36581 Mtetra
.712 .848 .947 r
.21306 .36581 .22205 .37113 .23488 .3655 .22601 .35947 Mtetra
.707 .828 .94 r
.22601 .35947 .23488 .3655 .24773 .36036 .239 .35327 Mtetra
.688 .797 .932 r
.239 .35327 .24773 .36036 .26063 .35531 .25198 .34766 Mtetra
.671 .779 .93 r
.25198 .34766 .26063 .35531 .27359 .35022 .26498 .34255 Mtetra
.663 .777 .934 r
.26498 .34255 .27359 .35022 .2866 .3452 .27802 .33766 Mtetra
.66 .781 .938 r
.27802 .33766 .2866 .3452 .29966 .34022 .29112 .33281 Mtetra
.661 .786 .941 r
.29112 .33281 .29966 .34022 .3128 .33519 .30428 .32791 Mtetra
.663 .791 .943 r
.30428 .32791 .3128 .33519 .32599 .33012 .31752 .32292 Mtetra
.665 .795 .944 r
.31752 .32292 .32599 .33012 .33924 .3252 .33082 .31785 Mtetra
.663 .792 .943 r
.33082 .31785 .33924 .3252 .35253 .32061 .34418 .31281 Mtetra
.657 .779 .938 r
.34418 .31281 .35253 .32061 .36587 .31643 .3576 .30794 Mtetra
.647 .758 .93 r
.3576 .30794 .36587 .31643 .37926 .31262 .37107 .30337 Mtetra
.636 .736 .921 r
.37107 .30337 .37926 .31262 .39272 .30902 .38459 .29913 Mtetra
.626 .718 .913 r
.38459 .29913 .39272 .30902 .40626 .30537 .39817 .29519 Mtetra
.621 .71 .909 r
.39817 .29519 .40626 .30537 .41988 .30147 .41183 .29137 Mtetra
.621 .713 .912 r
.41183 .29137 .41988 .30147 .43359 .29726 .42556 .28752 Mtetra
.626 .725 .918 r
.42556 .28752 .43359 .29726 .44738 .29285 .43938 .28349 Mtetra
.627 .736 .926 r
.43938 .28349 .44738 .29285 .46125 .28828 .45328 .2794 Mtetra
.622 .747 .937 r
.45328 .2794 .46125 .28828 .47519 .28367 .46726 .2754 Mtetra
.611 .761 .951 r
.46726 .2754 .47519 .28367 .48921 .27928 .48132 .27159 Mtetra
.613 .78 .961 r
.48132 .27159 .48921 .27928 .5033 .27544 .49546 .26761 Mtetra
.649 .79 .949 r
.49546 .26761 .5033 .27544 .51747 .27194 .50969 .26265 Mtetra
.693 .767 .909 r
.50969 .26265 .51747 .27194 .53173 .26779 .52399 .25621 Mtetra
.707 .722 .861 r
.52399 .25621 .53173 .26779 .54606 .26207 .53835 .24868 Mtetra
.698 .686 .835 r
.53835 .24868 .54606 .26207 .56044 .25514 .55277 .24108 Mtetra
.685 .671 .83 r
.55277 .24108 .56044 .25514 .57489 .24814 .56724 .23395 Mtetra
.677 .666 .832 r
.56724 .23395 .57489 .24814 .58939 .24144 .58178 .22716 Mtetra
.672 .663 .833 r
.58178 .22716 .58939 .24144 .60396 .23456 .59639 .22057 Mtetra
.667 .666 .84 r
.59639 .22057 .60396 .23456 .61858 .22736 .61107 .21431 Mtetra
.663 .682 .858 r
.61107 .21431 .61858 .22736 .63326 .22029 .62583 .20839 Mtetra
.661 .705 .88 r
.62583 .20839 .63326 .22029 .64801 .21366 .64067 .2027 Mtetra
.659 .726 .898 r
.64067 .2027 .64801 .21366 .66286 .20752 .65559 .19716 Mtetra
.657 .74 .911 r
.65559 .19716 .66286 .20752 .6778 .2018 .6706 .19171 Mtetra
.656 .747 .917 r
.6706 .19171 .6778 .2018 .69283 .1963 .6857 .18628 Mtetra
.656 .75 .919 r
.6857 .18628 .69283 .1963 .70795 .19087 .70087 .18083 Mtetra
.656 .751 .92 r
.70087 .18083 .70795 .19087 .72315 .18544 .71612 .17535 Mtetra
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Mtetra
.656 .752 .92 r
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Mtetra
.656 .751 .92 r
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Mtetra
.08086 .39201 .08995 .40007 .10209 .39574 .09304 .38761 Mtetra
.655 .751 .92 r
.09304 .38761 .10209 .39574 .11428 .39144 .10527 .38321 Mtetra
.654 .749 .919 r
.10527 .38321 .11428 .39144 .1265 .38734 .11756 .37881 Mtetra
.65 .741 .916 r
.11756 .37881 .1265 .38734 .13873 .38369 .12989 .37451 Mtetra
.641 .723 .908 r
.12989 .37451 .13873 .38369 .15093 .38082 .14225 .37046 Mtetra
.623 .691 .892 r
.14225 .37046 .15093 .38082 .16311 .3788 .15462 .36689 Mtetra
.602 .65 .871 r
.15462 .36689 .16311 .3788 .17531 .3772 .16698 .36396 Mtetra
.582 .618 .853 r
.16698 .36396 .17531 .3772 .18766 .37501 .17935 .36161 Mtetra
.575 .613 .853 r
.17935 .36161 .18766 .37501 .20024 .37126 .19178 .35948 Mtetra
.589 .651 .879 r
.19178 .35948 .20024 .37126 .21306 .36581 .20433 .35688 Mtetra
.625 .731 .923 r
.20433 .35688 .21306 .36581 .22601 .35947 .21706 .35314 Mtetra
.666 .814 .954 r
.21706 .35314 .22601 .35947 .239 .35327 .22999 .34811 Mtetra
.692 .853 .96 r
.22999 .34811 .239 .35327 .25198 .34766 .24305 .34222 Mtetra
.699 .848 .954 r
.24305 .34222 .25198 .34766 .26498 .34255 .25618 .33613 Mtetra
.692 .82 .944 r
.25618 .33613 .26498 .34255 .27802 .33766 .26934 .33027 Mtetra
.68 .792 .934 r
.26934 .33027 .27802 .33766 .29112 .33281 .28253 .32478 Mtetra
.669 .773 .928 r
.28253 .32478 .29112 .33281 .30428 .32791 .29576 .31961 Mtetra
.662 .765 .927 r
.29576 .31961 .30428 .32791 .31752 .32292 .30903 .31463 Mtetra
.659 .766 .929 r
.30903 .31463 .31752 .32292 .33082 .31785 .32236 .30973 Mtetra
.658 .771 .933 r
.32236 .30973 .33082 .31785 .34418 .31281 .33575 .30482 Mtetra
.658 .776 .936 r
.33575 .30482 .34418 .31281 .3576 .30794 .34922 .29989 Mtetra
.657 .775 .936 r
.34922 .29989 .3576 .30794 .37107 .30337 .36275 .29498 Mtetra
.653 .766 .932 r
.36275 .29498 .37107 .30337 .38459 .29913 .37634 .29015 Mtetra
.648 .75 .924 r
.37634 .29015 .38459 .29913 .39817 .29519 .38999 .28547 Mtetra
.64 .731 .914 r
.38999 .28547 .39817 .29519 .41183 .29137 .40371 .281 Mtetra
.632 .713 .905 r
.40371 .281 .41183 .29137 .42556 .28752 .41749 .27677 Mtetra
.624 .702 .901 r
.41749 .27677 .42556 .28752 .43938 .28349 .43135 .27278 Mtetra
.619 .702 .904 r
.43135 .27278 .43938 .28349 .45328 .2794 .44528 .2689 Mtetra
.624 .71 .908 r
.44528 .2689 .45328 .2794 .46726 .2754 .45929 .26486 Mtetra
.642 .717 .902 r
.45929 .26486 .46726 .2754 .48132 .27159 .4734 .26017 Mtetra
.669 .71 .878 r
.4734 .26017 .48132 .27159 .49546 .26761 .4876 .25438 Mtetra
.685 .683 .842 r
.4876 .25438 .49546 .26761 .50969 .26265 .50187 .24749 Mtetra
.684 .653 .813 r
.50187 .24749 .50969 .26265 .52399 .25621 .5162 .24008 Mtetra
.674 .635 .803 r
.5162 .24008 .52399 .25621 .53835 .24868 .53059 .23294 Mtetra
.664 .637 .813 r
.53059 .23294 .53835 .24868 .55277 .24108 .54504 .22643 Mtetra
.659 .651 .831 r
.54504 .22643 .55277 .24108 .56724 .23395 .55956 .22039 Mtetra
.659 .67 .85 r
.55956 .22039 .56724 .23395 .58178 .22716 .57415 .21457 Mtetra
.658 .689 .868 r
.57415 .21457 .58178 .22716 .59639 .22057 .58881 .20894 Mtetra
.657 .709 .886 r
.58881 .20894 .59639 .22057 .61107 .21431 .60356 .20346 Mtetra
.657 .727 .901 r
.60356 .20346 .61107 .21431 .62583 .20839 .61839 .198 Mtetra
.657 .739 .91 r
.61839 .198 .62583 .20839 .64067 .2027 .63329 .19255 Mtetra
.656 .746 .916 r
.63329 .19255 .64067 .2027 .65559 .19716 .64828 .18711 Mtetra
.656 .749 .919 r
.64828 .18711 .65559 .19716 .6706 .19171 .66334 .18167 Mtetra
.656 .751 .92 r
.66334 .18167 .6706 .19171 .6857 .18628 .67849 .17619 Mtetra
.67849 .17619 .6857 .18628 .70087 .18083 .69372 .1707 Mtetra
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Mtetra
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Mtetra
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Mtetra
.656 .752 .92 r
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Mtetra
.656 .751 .92 r
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Mtetra
.656 .752 .92 r
.0839 .37944 .09304 .38761 .10527 .38321 .09617 .37498 Mtetra
.655 .751 .92 r
.09617 .37498 .10527 .38321 .11756 .37881 .10849 .37051 Mtetra
.655 .75 .92 r
.10849 .37051 .11756 .37881 .12989 .37451 .12088 .36602 Mtetra
.653 .746 .918 r
.12088 .36602 .12989 .37451 .14225 .37046 .13332 .36157 Mtetra
.65 .736 .912 r
.13332 .36157 .14225 .37046 .15462 .36689 .14581 .3572 Mtetra
.64 .715 .901 r
.14581 .3572 .15462 .36689 .16698 .36396 .15833 .35307 Mtetra
.627 .684 .884 r
.15833 .35307 .16698 .36396 .17935 .36161 .17087 .3493 Mtetra
.611 .65 .864 r
.17087 .3493 .17935 .36161 .19178 .35948 .18343 .34595 Mtetra
.599 .623 .847 r
.18343 .34595 .19178 .35948 .20433 .35688 .19603 .34297 Mtetra
.591 .614 .844 r
.19603 .34297 .20433 .35688 .21706 .35314 .20868 .34021 Mtetra
.595 .634 .86 r
.20868 .34021 .21706 .35314 .22999 .34811 .22141 .33736 Mtetra
.612 .686 .896 r
.22141 .33736 .22999 .34811 .24305 .34222 .23427 .33397 Mtetra
.636 .757 .936 r
.23427 .33397 .24305 .34222 .25618 .33613 .24727 .32981 Mtetra
.656 .817 .961 r
.24727 .32981 .25618 .33613 .26934 .33027 .2604 .32492 Mtetra
.667 .848 .969 r
.2604 .32492 .26934 .33027 .28253 .32478 .27363 .31956 Mtetra
.672 .854 .969 r
.27363 .31956 .28253 .32478 .29576 .31961 .28693 .31402 Mtetra
.672 .845 .966 r
.28693 .31402 .29576 .31961 .30903 .31463 .3003 .3085 Mtetra
.669 .83 .961 r
.3003 .3085 .30903 .31463 .32236 .30973 .31371 .30311 Mtetra
.664 .817 .957 r
.31371 .30311 .32236 .30973 .33575 .30482 .32717 .29789 Mtetra
.659 .807 .954 r
.32717 .29789 .33575 .30482 .34922 .29989 .34069 .29281 Mtetra
.654 .803 .954 r
.34069 .29281 .34922 .29989 .36275 .29498 .35427 .28784 Mtetra
.649 .802 .956 r
.35427 .28784 .36275 .29498 .37634 .29015 .36791 .28298 Mtetra
.645 .801 .958 r
.36791 .28298 .37634 .29015 .38999 .28547 .38162 .27822 Mtetra
.642 .798 .958 r
.38162 .27822 .38999 .28547 .40371 .281 .3954 .27352 Mtetra
.642 .793 .955 r
.3954 .27352 .40371 .281 .41749 .27677 .40925 .2688 Mtetra
.65 .784 .945 r
.40925 .2688 .41749 .27677 .43135 .27278 .42318 .26386 Mtetra
.664 .765 .925 r
.42318 .26386 .43135 .27278 .44528 .2689 .43719 .25851 Mtetra
.678 .735 .894 r
.43719 .25851 .44528 .2689 .45929 .26486 .45129 .25254 Mtetra
.684 .698 .858 r
.45129 .25254 .45929 .26486 .4734 .26017 .46547 .24595 Mtetra
.679 .665 .829 r
.46547 .24595 .4734 .26017 .4876 .25438 .47971 .23906 Mtetra
.67 .645 .816 r
.47971 .23906 .4876 .25438 .50187 .24749 .494 .23235 Mtetra
.66 .644 .822 r
.494 .23235 .50187 .24749 .5162 .24008 .50836 .22616 Mtetra
.655 .661 .844 r
.50836 .22616 .5162 .24008 .53059 .23294 .52278 .22046 Mtetra
.655 .688 .869 r
.52278 .22046 .53059 .23294 .54504 .22643 .53727 .21499 Mtetra
.657 .712 .888 r
.53727 .21499 .54504 .22643 .55956 .22039 .55184 .20953 Mtetra
.657 .726 .9 r
.55184 .20953 .55956 .22039 .57415 .21457 .56648 .20412 Mtetra
.655 .735 .909 r
.56648 .20412 .57415 .21457 .58881 .20894 .58121 .19877 Mtetra
.655 .744 .915 r
.58121 .19877 .58881 .20894 .60356 .20346 .59601 .19339 Mtetra
.657 .748 .917 r
.59601 .19339 .60356 .20346 .61839 .198 .61089 .18796 Mtetra
.656 .75 .919 r
.61089 .18796 .61839 .198 .63329 .19255 .62585 .1825 Mtetra
.656 .751 .92 r
.62585 .1825 .63329 .19255 .64828 .18711 .64089 .17704 Mtetra
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17154 Mtetra
.65601 .17154 .66334 .18167 .67849 .17619 .67121 .16602 Mtetra
.67121 .16602 .67849 .17619 .69372 .1707 .6865 .16046 Mtetra
.6865 .16046 .69372 .1707 .70903 .16517 .70187 .15488 Mtetra
.656 .752 .92 r
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14926 Mtetra
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Mtetra
.656 .751 .92 r
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Mtetra
.656 .752 .92 r
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Mtetra
.656 .751 .92 r
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .3667 Mtetra
.656 .752 .92 r
.08698 .3667 .09617 .37498 .10849 .37051 .09934 .36217 Mtetra
.656 .751 .92 r
.09934 .36217 .10849 .37051 .12088 .36602 .11176 .35764 Mtetra
.11176 .35764 .12088 .36602 .13332 .36157 .12424 .35307 Mtetra
.655 .749 .919 r
.12424 .35307 .13332 .36157 .14581 .3572 .13678 .34852 Mtetra
.654 .745 .917 r
.13678 .34852 .14581 .3572 .15833 .35307 .14938 .34395 Mtetra
.651 .734 .91 r
.14938 .34395 .15833 .35307 .17087 .3493 .16204 .33946 Mtetra
.645 .716 .9 r
.16204 .33946 .17087 .3493 .18343 .34595 .17473 .3351 Mtetra
.635 .691 .885 r
.17473 .3351 .18343 .34595 .19603 .34297 .18747 .33098 Mtetra
.627 .666 .868 r
.18747 .33098 .19603 .34297 .20868 .34021 .20025 .32705 Mtetra
.619 .642 .851 r
.20025 .32705 .20868 .34021 .22141 .33736 .21309 .32327 Mtetra
.613 .624 .838 r
.21309 .32327 .22141 .33736 .23427 .33397 .22598 .31964 Mtetra
.609 .619 .836 r
.22598 .31964 .23427 .33397 .24727 .32981 .23893 .31612 Mtetra
.611 .632 .847 r
.23893 .31612 .24727 .32981 .2604 .32492 .25196 .31253 Mtetra
.62 .66 .868 r
.25196 .31253 .2604 .32492 .27363 .31956 .26509 .30872 Mtetra
.632 .698 .893 r
.26509 .30872 .27363 .31956 .28693 .31402 .27831 .30458 Mtetra
.643 .735 .916 r
.27831 .30458 .28693 .31402 .3003 .3085 .29163 .3001 Mtetra
.651 .765 .933 r
.29163 .3001 .3003 .3085 .31371 .30311 .30504 .29534 Mtetra
.656 .784 .943 r
.30504 .29534 .31371 .30311 .32717 .29789 .31853 .29038 Mtetra
.659 .794 .946 r
.31853 .29038 .32717 .29789 .34069 .29281 .3321 .28528 Mtetra
.662 .795 .946 r
.3321 .28528 .34069 .29281 .35427 .28784 .34574 .28008 Mtetra
.666 .791 .941 r
.34574 .28008 .35427 .28784 .36791 .28298 .35945 .27475 Mtetra
.67 .781 .933 r
.35945 .27475 .36791 .28298 .38162 .27822 .37324 .26927 Mtetra
.676 .766 .919 r
.37324 .26927 .38162 .27822 .3954 .27352 .3871 .26356 Mtetra
.68 .744 .899 r
.3871 .26356 .3954 .27352 .40925 .2688 .40104 .25759 Mtetra
.681 .718 .877 r
.40104 .25759 .40925 .2688 .42318 .26386 .41505 .25137 Mtetra
.679 .693 .856 r
.41505 .25137 .42318 .26386 .43719 .25851 .42913 .24498 Mtetra
.673 .673 .842 r
.42913 .24498 .43719 .25851 .45129 .25254 .44327 .23859 Mtetra
.666 .664 .839 r
.44327 .23859 .45129 .25254 .46547 .24595 .45747 .23244 Mtetra
.66 .669 .848 r
.45747 .23244 .46547 .24595 .47971 .23906 .47172 .22663 Mtetra
.656 .689 .869 r
.47172 .22663 .47971 .23906 .494 .23235 .48604 .22113 Mtetra
.657 .715 .891 r
.48604 .22113 .494 .23235 .50836 .22616 .50043 .21573 Mtetra
.659 .735 .906 r
.50043 .21573 .50836 .22616 .52278 .22046 .5149 .2103 Mtetra
.659 .743 .912 r
.5149 .2103 .52278 .22046 .53727 .21499 .52944 .20485 Mtetra
.655 .743 .914 r
.52944 .20485 .53727 .21499 .55184 .20953 .54406 .19951 Mtetra
.653 .746 .918 r
.54406 .19951 .55184 .20953 .56648 .20412 .55875 .19421 Mtetra
.655 .751 .92 r
.55875 .19421 .56648 .20412 .58121 .19877 .57353 .18882 Mtetra
.657 .752 .92 r
.57353 .18882 .58121 .19877 .59601 .19339 .58838 .18335 Mtetra
.656 .751 .919 r
.58838 .18335 .59601 .19339 .61089 .18796 .60332 .17788 Mtetra
.655 .751 .92 r
.60332 .17788 .61089 .18796 .62585 .1825 .61833 .1724 Mtetra
.656 .752 .92 r
.61833 .1724 .62585 .1825 .64089 .17704 .63343 .16687 Mtetra
.656 .751 .92 r
.63343 .16687 .64089 .17704 .65601 .17154 .6486 .16132 Mtetra
.6486 .16132 .65601 .17154 .67121 .16602 .66386 .15574 Mtetra
.66386 .15574 .67121 .16602 .6865 .16046 .6792 .15014 Mtetra
.656 .752 .92 r
.6792 .15014 .6865 .16046 .70187 .15488 .69463 .14449 Mtetra
.656 .751 .92 r
.69463 .14449 .70187 .15488 .71732 .14926 .71014 .13882 Mtetra
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Mtetra
.656 .752 .92 r
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36738 Mtetra
.656 .751 .92 r
.05311 .36738 .06244 .37567 .07468 .37119 .06538 .36287 Mtetra
.656 .752 .92 r
.06538 .36287 .07468 .37119 .08698 .3667 .07772 .35833 Mtetra
.656 .751 .92 r
.07772 .35833 .08698 .3667 .09934 .36217 .09011 .35378 Mtetra
.656 .752 .92 r
.09011 .35378 .09934 .36217 .11176 .35764 .10256 .34919 Mtetra
.656 .751 .92 r
.10256 .34919 .11176 .35764 .12424 .35307 .11508 .34459 Mtetra
.11508 .34459 .12424 .35307 .13678 .34852 .12766 .33995 Mtetra
.655 .75 .92 r
.12766 .33995 .13678 .34852 .14938 .34395 .14029 .33531 Mtetra
.655 .749 .919 r
.14029 .33531 .14938 .34395 .16204 .33946 .153 .33066 Mtetra
.655 .746 .917 r
.153 .33066 .16204 .33946 .17473 .3351 .16576 .32599 Mtetra
.654 .74 .912 r
.16576 .32599 .17473 .3351 .18747 .33098 .17859 .32129 Mtetra
.65 .726 .904 r
.17859 .32129 .18747 .33098 .20025 .32705 .19146 .31668 Mtetra
.645 .709 .894 r
.19146 .31668 .20025 .32705 .21309 .32327 .2044 .3122 Mtetra
.64 .693 .884 r
.2044 .3122 .21309 .32327 .22598 .31964 .21738 .3078 Mtetra
.638 .678 .871 r
.21738 .3078 .22598 .31964 .23893 .31612 .23044 .30339 Mtetra
.635 .661 .858 r
.23044 .30339 .23893 .31612 .25196 .31253 .24356 .29895 Mtetra
.633 .645 .845 r
.24356 .29895 .25196 .31253 .26509 .30872 .25676 .29449 Mtetra
.631 .635 .836 r
.25676 .29449 .26509 .30872 .27831 .30458 .27002 .29002 Mtetra
.631 .63 .831 r
.27002 .29002 .27831 .30458 .29163 .3001 .28336 .28548 Mtetra
.632 .631 .831 r
.28336 .28548 .29163 .3001 .30504 .29534 .29677 .28085 Mtetra
.636 .635 .833 r
.29677 .28085 .30504 .29534 .31853 .29038 .31027 .27606 Mtetra
.64 .641 .835 r
.31027 .27606 .31853 .29038 .3321 .28528 .32384 .27109 Mtetra
.645 .646 .836 r
.32384 .27109 .3321 .28528 .34574 .28008 .3375 .26592 Mtetra
.649 .649 .836 r
.3375 .26592 .34574 .28008 .35945 .27475 .35124 .26057 Mtetra
.652 .651 .836 r
.35124 .26057 .35945 .27475 .37324 .26927 .36505 .25506 Mtetra
.654 .652 .836 r
.36505 .25506 .37324 .26927 .3871 .26356 .37893 .24946 Mtetra
.654 .655 .838 r
.37893 .24946 .3871 .26356 .40104 .25759 .39288 .24382 Mtetra
.655 .661 .844 r
.39288 .24382 .40104 .25759 .41505 .25137 .40689 .23822 Mtetra
.654 .673 .855 r
.40689 .23822 .41505 .25137 .42913 .24498 .42097 .23271 Mtetra
.655 .691 .871 r
.42097 .23271 .42913 .24498 .44327 .23859 .43512 .22731 Mtetra
.657 .713 .889 r
.43512 .22731 .44327 .23859 .45747 .23244 .44933 .22194 Mtetra
.659 .732 .904 r
.44933 .22194 .45747 .23244 .47172 .22663 .46362 .21653 Mtetra
.661 .743 .911 r
.46362 .21653 .47172 .22663 .48604 .22113 .47799 .21106 Mtetra
.659 .744 .913 r
.47799 .21106 .48604 .22113 .50043 .21573 .49243 .20562 Mtetra
.655 .743 .915 r
.49243 .20562 .50043 .21573 .5149 .2103 .50694 .20029 Mtetra
.652 .746 .918 r
.50694 .20029 .5149 .2103 .52944 .20485 .52153 .19504 Mtetra
.654 .753 .922 r
.52153 .19504 .52944 .20485 .54406 .19951 .5362 .18969 Mtetra
.658 .755 .922 r
.5362 .18969 .54406 .19951 .55875 .19421 .55095 .18421 Mtetra
.657 .752 .92 r
.55095 .18421 .55875 .19421 .57353 .18882 .56578 .1787 Mtetra
.655 .75 .919 r
.56578 .1787 .57353 .18882 .58838 .18335 .58068 .17323 Mtetra
.655 .751 .92 r
.58068 .17323 .58838 .18335 .60332 .17788 .59567 .16774 Mtetra
.656 .752 .92 r
.59567 .16774 .60332 .17788 .61833 .1724 .61074 .16218 Mtetra
.656 .751 .92 r
.61074 .16218 .61833 .1724 .63343 .16687 .62589 .1566 Mtetra
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Mtetra
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Mtetra
.656 .752 .92 r
.65644 .14536 .66386 .15574 .6792 .15014 .67184 .13969 Mtetra
.656 .751 .92 r
.67184 .13969 .6792 .15014 .69463 .14449 .68732 .134 Mtetra
.656 .752 .92 r
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12826 Mtetra
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Mtetra
.656 .751 .92 r
.03145 .36357 .0409 .37188 .05311 .36738 .04369 .35903 Mtetra
.656 .752 .92 r
.04369 .35903 .05311 .36738 .06538 .36287 .056 .35447 Mtetra
.656 .751 .92 r
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Mtetra
.656 .752 .92 r
.06836 .3499 .07772 .35833 .09011 .35378 .08079 .34529 Mtetra
.656 .751 .92 r
.08079 .34529 .09011 .35378 .10256 .34919 .09328 .34067 Mtetra
.656 .752 .92 r
.09328 .34067 .10256 .34919 .11508 .34459 .10583 .33602 Mtetra
.656 .751 .92 r
.10583 .33602 .11508 .34459 .12766 .33995 .11844 .33135 Mtetra
.656 .752 .92 r
.11844 .33135 .12766 .33995 .14029 .33531 .13112 .32665 Mtetra
.656 .751 .92 r
.13112 .32665 .14029 .33531 .153 .33066 .14385 .32193 Mtetra
.14385 .32193 .153 .33066 .16576 .32599 .15666 .31719 Mtetra
.654 .75 .92 r
.15666 .31719 .16576 .32599 .17859 .32129 .16952 .31247 Mtetra
.655 .75 .92 r
.16952 .31247 .17859 .32129 .19146 .31668 .18245 .3077 Mtetra
.656 .747 .917 r
.18245 .3077 .19146 .31668 .2044 .3122 .19545 .30286 Mtetra
.656 .74 .912 r
.19545 .30286 .2044 .3122 .21738 .3078 .20851 .29801 Mtetra
.651 .729 .906 r
.20851 .29801 .21738 .3078 .23044 .30339 .22163 .29325 Mtetra
.647 .72 .902 r
.22163 .29325 .23044 .30339 .24356 .29895 .2348 .2886 Mtetra
.644 .715 .9 r
.2348 .2886 .24356 .29895 .25676 .29449 .24803 .28402 Mtetra
.643 .714 .899 r
.24803 .28402 .25676 .29449 .27002 .29002 .26134 .27944 Mtetra
.644 .712 .897 r
.26134 .27944 .27002 .29002 .28336 .28548 .27471 .2748 Mtetra
.645 .712 .896 r
.27471 .2748 .28336 .28548 .29677 .28085 .28816 .27009 Mtetra
.647 .712 .895 r
.28816 .27009 .29677 .28085 .31027 .27606 .30169 .26528 Mtetra
.65 .713 .894 r
.30169 .26528 .31027 .27606 .32384 .27109 .3153 .26036 Mtetra
.652 .716 .895 r
.3153 .26036 .32384 .27109 .3375 .26592 .32898 .25533 Mtetra
.655 .722 .898 r
.32898 .25533 .3375 .26592 .35124 .26057 .34274 .25018 Mtetra
.658 .728 .901 r
.34274 .25018 .35124 .26057 .36505 .25506 .35657 .24492 Mtetra
.661 .736 .905 r
.35657 .24492 .36505 .25506 .37893 .24946 .37048 .23955 Mtetra
.663 .744 .91 r
.37048 .23955 .37893 .24946 .39288 .24382 .38446 .2341 Mtetra
.665 .75 .914 r
.38446 .2341 .39288 .24382 .40689 .23822 .39852 .2286 Mtetra
.666 .754 .916 r
.39852 .2286 .40689 .23822 .42097 .23271 .41264 .22304 Mtetra
.41264 .22304 .42097 .23271 .43512 .22731 .42684 .21745 Mtetra
.663 .749 .915 r
.42684 .21745 .43512 .22731 .44933 .22194 .44111 .21193 Mtetra
.659 .746 .914 r
.44111 .21193 .44933 .22194 .46362 .21653 .45544 .20651 Mtetra
.654 .745 .917 r
.45544 .20651 .46362 .21653 .47799 .21106 .46985 .20122 Mtetra
.653 .75 .921 r
.46985 .20122 .47799 .21106 .49243 .20562 .48434 .19594 Mtetra
.656 .756 .924 r
.48434 .19594 .49243 .20562 .50694 .20029 .4989 .19055 Mtetra
.659 .757 .923 r
.4989 .19055 .50694 .20029 .52153 .19504 .51355 .18504 Mtetra
.658 .752 .919 r
.51355 .18504 .52153 .19504 .5362 .18969 .52827 .17952 Mtetra
.655 .748 .918 r
.52827 .17952 .5362 .18969 .55095 .18421 .54307 .17406 Mtetra
.655 .75 .92 r
.54307 .17406 .55095 .18421 .56578 .1787 .55795 .16859 Mtetra
.656 .752 .921 r
.55795 .16859 .56578 .1787 .58068 .17323 .57291 .16305 Mtetra
.57291 .16305 .58068 .17323 .59567 .16774 .58795 .15746 Mtetra
.656 .751 .92 r
.58795 .15746 .59567 .16774 .61074 .16218 .60307 .15186 Mtetra
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Mtetra
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Mtetra
.656 .752 .92 r
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13487 Mtetra
.656 .751 .92 r
.64894 .13487 .65644 .14536 .67184 .13969 .66439 .12915 Mtetra
.656 .752 .92 r
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Mtetra
.656 .751 .92 r
.67994 .12339 .68732 .134 .70289 .12826 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10615 .22812 m
.11084 .23271 L
s
[(-0.2)] .09678 .21894 1 .97894 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60315 .03351 m
.60692 .03888 L
s
[(0.2)] .5956 .02278 .70296 1 Mshowa
.125 Mabswid
.16338 .20571 m
.16614 .20852 L
s
.22191 .18279 m
.22461 .18566 L
s
.28179 .15935 m
.28443 .16227 L
s
.40578 .1108 m
.40829 .11384 L
s
.47 .08565 m
.47243 .08875 L
s
.53577 .0599 m
.53812 .06306 L
s
.05019 .25004 m
.05305 .25274 L
s
.67219 .00648 m
.67437 .00976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00f03oool2000000@0oooo0P0000030?ooo`<00000>P3oool00=L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000i0?ooo`00Y@3oool2000000@0
oooo0P0000030?ooo`@000008`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000003T0oooo002T0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool05`3oool2
000000D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000j0?ooo`00Y03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0>@3oool00:@0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool2000000/0oooo
0P00000:0?ooo`<00000>@3oool00:@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool300000580oooo002U0?ooo`80
00002P3oool2000000d0oooo0`0000080?ooo`040000003oool0oooo00000540oooo002n0?ooo`80
00002`3oool010000000oooo0?ooo`00001A0?ooo`00^`3oool3000000d0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`00^@3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1=0?ooo`00]P3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1=0?ooo`00]03oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1<0?ooo`00/@3oool4000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`00[`3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04/0oooo002/0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04X0oooo002Y0?ooo`<00000803oool00`000000oooo0?ooo`030?ooo`800000
C03oool00:L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B@3o
ool00:@0oooo0`00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool0
0:80oooo0P00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool009l0
oooo0`0000000`3oool000000?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A`3oool009d0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
AP3oool009X0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3o
ool009P0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3oool0
09D0oooo0`00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool009<0
oooo0P00000g0?ooo`030000003oool0oooo00X0oooo0P0000150?ooo`00T03oool3000003T0oooo
00<000000?ooo`3oool02P3oool2000004D0oooo002>0?ooo`80000000<0oooo0000003oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0480oooo002;0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo001Y0?ooo`8000007P3oool20000
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`00J03oool010000000
oooo0?ooo`00000J0?ooo`<00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0400oooo001X0?ooo`040000003oool0oooo000001P0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool006P0oooo00@000000?ooo`3oool000005@3oool30000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o0?ooo`00J03oool010000000
oooo0?ooo`00000C0?ooo`800000C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03h0oooo001Y0?ooo`8000004@3oool3000000030?ooo`000000oooo04/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`00NP3oool200000540oooo00<000000?ooo`3oool0
3`3oool2000003l0oooo001g0?ooo`<00000C`3oool40:O0j`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?03oool007D0oooo0P00001@0?ooo`H0Yl3[00<000000:O0j`3oool04@3oool0
0`000000oooo0?ooo`0l0?ooo`00LP3oool300000500oooo202W`>/00`000000Yl3[0?ooo`0B0?oo
o`030000003oool0oooo00`0oooo0P0000040?ooo`8000001@3oool3000001l0oooo001_0?ooo`<0
0000D@3oool:0:O0j`030000002W`>/0Yl3[0180oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo001]0?ooo`<00000D@3oool<0:O0j`04
0000002W`>/0Yl3[0:O0ja80oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000008
0?ooo`D000007`3oool006X0oooo0`0000030?ooo`030000003oool0oooo04X0oooo402W`>/01000
0000Yl3[0:O0j`2W`>/C0?ooo`030000003oool0oooo00<0oooo100000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000803oool006P0oooo0P00001A0?oooa80Yl3[00<0
00000:O0j`2W`>/00P2W`>/B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000P0?ooo`00I@3oool300000500oooo5@2W`>/00`000000Yl3[0:O0
j`030:O0ja80oooo00<000000?ooo`3oool02@3oool2000000/0oooo0P00000P0?ooo`00H`3oool2
000004l0oooo6@2W`>/00`000000Yl3[0:O0j`040:O0ja00oooo0`00000i0?ooo`00H03oool30000
04l0oooo702W`>/00`000000Yl3[0:O0j`040:O0ja40oooo00<000000?ooo`3oool0=`3oool005h0
oooo0P00001@0?oooah0Yl3[00<000000:O0j`2W`>/0102W`>/B0?ooo`030000003oool0oooo03H0
oooo001K0?ooo`<0000000<0oooo0000003oool0B`3ooolR0:O0j`030000002W`>/0Yl3[00D0Yl3[
4P3oool00`000000oooo0?ooo`0e0?ooo`00F@3oool2000004l0oooo902W`>/00`000000Yl3[0:O0
j`060:O0ja40oooo00<000000?ooo`3oool0=@3oool005H0oooo0`00001?0?ooobH0Yl3[00<00000
0:O0j`2W`>/01P2W`>/B0?ooo`030000003oool0oooo03@0oooo001D0?ooo`800000CP3oool50:No
jbD0Yl3[00<000000:O0j`2W`>/01`2W`>/B0?ooo`030000003oool0oooo03<0oooo001A0?ooo`<0
0000C03oool?0:Nojal0Yl3[00<000000:O0j`2W`>/0202W`>/A0?ooo`030000003oool0oooo03<0
oooo001?0?ooo`800000C@3oool30:S0j`L0Yko[0`2X`>/50:Nojah0Yl3[00<000000:O0j`2W`>/0
202W`>/B0?ooo`030000003oool0oooo0380oooo001<0?ooo`@00000C03oool60:S0j`@0Yko[1P2X
`>/30:Noj`80Z<3[1`2W`>/30:Noj`D0Yl3[1P2W_n/40:O0j`@0Yko[00<000000:Noj`2W`>/02@2W
`>/@0?ooo`030000003oool0000003<0oooo000M0?ooo`800000103oool2000000<0oooo1000000N
0?ooo`800000C@3oool40:S1k0H0Z<3[1@2X`N`:0:S0j`@0Yl3[1P2W_n/20:O0j`<0YkkZ1@2W_n/2
0:O0j`<0YkoZ0`2W_n/00`000000Yko[0:Noj`040:Noj`D0Yl3[4P3oool00`000000oooo0?ooo`0a
0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01`0oooo0`00001=
0?ooo`<0Yl7/102X`N`30:S0j`<0Yl3/1@2X`N`50:O0j`D0Z<3[102X_nX50:Noj`H0YkkZ102W_n/6
0:NojP80Yko[00<000000:RnjP2X_^X01@2W_n/20:O0j`<0Yko[4P3oool00`000000oooo0?ooo`0`
0?ooo`00703oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01T0oooo0P00001>
0?ooo`H0Yl7/102X`N`60:O0k080Z<7/0`2W_^/50:O0j`80Z<3[0`2W_^X40:RojPD0Z;gX1@2W_^X5
0:Rmj@D0YkoZ0P2X_^X010000000Z;kZ0:RnjP2X_^X:0:Noja80oooo00<000000?ooo`3oool0;`3o
ool001H0oooo100000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool05@3o
ool3000004`0oooo1@2W_n/50:O1k0D0Y[k[1@2W`>`60:Nnj`@0Yl3[1P2W_^X20:RojP80Z;[V1@2X
_NP20:NnjP<0Z;WU1@2X_NT50:Rki`030:RnjP000000Z;kZ0080Z;kZ1@2X_^T50:Noja80oooo00<0
00000?ooo`3oool0;`3oool001`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00000C0?ooo`<00000C@3oool30:NnjPD0Yko[1@2W_^X50:Jnj`D0YkkY1@2W_^/50:Nlj0D0YkkZ
1@2X^^H40:Rmj0H0Z;WU0P2X_NT30:VfhPD0Z;_W00<000000:RnjP2Y^nH00P2Y^nH50:Rnj@D0Z;kZ
4P3oool00`000000oooo0?ooo`0^0?ooo`007@3oool2000000X0oooo0P00000B0?ooo`@00000C03o
ool60:NnjP80Yko[0`2X_^T50:NnjP80Y[k[0`2X_^T50:Nnj@D0Z;WV1@2W_>P50:RehP@0Z;[V1@2Y
]>450:Rii@H0ZKKR102X^nL00`000000ZK_V0:VkiP030:VkiP80Z;kY0`2Y^nH50:RnjQ80oooo00<0
00000?ooo`3oool0;@3oool003/0oooo0P00001<0?ooo`D0Z;kY1@2W_^X60:Rnj@@0YkkZ1P2X_^T2
0:Nnj@<0Z;KS1@2X^NH20:Nlj0<0Z;3N1@2X]N820:RjiP80ZJkK1@2Y]>420:Rii@<0Zk3L1@2Y]^84
0:^eh0030000002Y^nH0ZK_V00T0ZK_V102X_^XB0?ooo`030000003oool0oooo02d0oooo000h0?oo
o`<00000C03oool30:VojPD0Z;kY1@2Y_^T50:Rnj@D0Z;cW1@2X_^T60:Rfh`@0Z;WV1P2X/=h40:Re
hPD0ZJkK102Y]>460:^`g080ZKKR0`2][]P40:^eh0030000002Y^nH0ZK_V00<0[;GO1@2Y^nH50:Rl
ia40oooo0P00000^0?ooo`00=@3oool3000004d0oooo1P2Y_nX20:Rnj@<0Z;_W1@2Y_^T20:Rnj@<0
Z;OT1@2X_>L50:N`gPD0Z;KS1@2XZmT50:R`gPD0ZZ[G102Y[]/50:b[ePD0Zk3L1P2][]P30:^eh003
0000002/]Ml0[;GO00@0[;GO0P2Y^nH30:bgh@D0Z;cW4@3oool00`000000oooo0?ooo`0/0?ooo`00
<`3oool2000004`0oooo1P2Z`NX40:VojPH0Z;_W102Y_^T60:Rgi080Z;cW0`2WZMP50:N`gP80Z;KS
0`2XY]@50:R[f@80Z;3N0`2/ZMD50:ZZe`80ZJkK0P2^Zm@50:b[eP80Zk3L0`2`[=@50:f^f0<0/:oG
00<000000;2_e`2/]Ml0102/]Ml60:bgh@80Z;cW0`2Z^><A0?ooo`030000003oool0oooo02/0oooo
000`0?ooo`<00000C@3oool80:[1jP@0Z;KS1@2X^nL50:N`gPD0Z;OT1@2WZMP50:N`gPD0Z:KD1@2X
ZmT50:bYe@D0ZZ[G102^Zm@50:b[ePD0/:cD102][]P20;>^d`80/:oG00<000000;2_e`2`[mL00P2/
]Ml30;6`e`D0[;OQ1P2Z^><A0?ooo`030000003oool0oooo02X0oooo000^0?ooo`<00000C@3oool8
0:[1jP<0Yk3N102X]^<20:Rki`<0Z:_I1@2W/=h20:Rgi0<0Z:CB1@2WZMP20:N`gP<0ZJ?@1@2XY]@2
0:R[f@<0[J[D1@2/ZMD20:ZZe`<0/;3H102^Zm@20:b[eP<0/k3F1@2`[=@20:f^f0<0/jkC0P2`[mL0
0`000000/:oG0;2_e`060;6`e`80[;OQ0`2b/mT50:Zhha40oooo00<000000?ooo`3oool0:P3oool0
02/0oooo0`0000030?ooo`030000003oool0oooo04H0oooo1@2Z_nT50:[1jPH0Yk3N0`2X]^<60:R[
f@@0Yk3N1@2XY=850:NYf0D0ZJ?@1@2XY]@50:fZe0D0[:WE1@2`/=P40:j[e0D0/k3F1@2`[=@60;>^
d`030;2_e`000000]ZoB0080]ZoB1@2a/=L60;:cf@80Z[SS0`2]]=hA0?ooo`030000003oool0oooo
02T0oooo000Y0?ooo`800000B`3oool50:Vnj0D0Z[oY1@2W[=X50:N`gP@0ZZWF1@2XZmT50:^Ud0D0
Z:CB0P2WZMP30:bRc@D0ZJ?@0P2XY]@30:n[e0D0[J[D0P2/ZMD30;6ggPD0/;3H0P2^Zm@20;>igPD0
/k3F0P2`[=@30;Jde`D0/jkC00<0]ZoB0000002f[m800`2f[m820;6`e`<0^;7B1@2b/mT50:fdgQ80
oooo00<000000?ooo`3oool0:03oool002H0oooo0`00001<0?ooo`80ZKcW1@2Y_^P20:Zoj@<0YjWH
1@2W[=X20:N`gP<0[:cG102ZZMH30:R[f@80[J[D102[YM050:RTdPD0[:;=1@2YXm050:n[e0D0[J[D
1@2a]mh50;2`f0@0/kWN1@2c/=H60;Jde`80/jkC0`2i]]H00`000000]ZoB0;J_dP020;J_dPH0^;7B
0P2b/mT30;Rbd`@0[KCN4P3oool00`000000oooo0?ooo`0X0?ooo`00903oool2000004d0oooo1@2Y
_>L40:Vnj0D0YjWH1@2W[=X50:b/e`D0ZZWF1@2]Z]@40:^Ud080Z:CB0`2_Ym050:bRc@80ZJ?@0`2b
[mD50:n[e080[J[D0`2a_>850;6ggP80/;3H0`2_`nT40;>igP80/k3F0`2c_n<50;Jde`@0^KKF0P00
00030;J_dP80^kKD1@2h/M850;Rbd`80[KCN0`2`/]TA0?ooo`800000:@3oool00240oooo0`00001;
0?ooo`D0Z;[V102Y_>L50:NWePD0YjWH0P2W[=X30:faf`D0[:cG0P2ZZMH30:nbf`D0[J[D0`2[YM05
0:nWd0D0[:;=1@2b[mD50:n[e0H0/KcR102a]mh60:o3j@<0/kWN1P2c_n<20;Jde`<0/l7U0`000002
0;VfeP030000002f[m80^kKD0080^kKD102h/M820;jdd@@0^;;C1P2`/]TB0?ooo`030000003oool0
oooo02H0oooo000O0?ooo`<00000B`3oool30:Nhi@D0Z;[V0P2Y_>L20:NVePD0YjOF102WZMP50:fa
f`D0[:cG1@2_/]/50:fZe0@0[jkG1@2_Ym020:bRc@<0];SL1@2b[mD20:n[e0<0]<;T1@2a_>850:W8
k`D0[l?Y102Xb?050;>oh`80/l7U0`0000050;VfeP030000002k]]@0^kKD00<0^kKD0P2h/M830;jd
d@<0^;;C0P2m/m050;2bfA80oooo00<000000?ooo`3oool09P3oool001d0oooo0P00001<0?ooo`H0
YkSU102X^^H50:NVeP@0YjOF1@2^]n050:faf`80[:cG0`2]_>@50:nbf`80[J[D0`2[]N030:n^e`D0
[jO@1@2d^=`50;:_e@H0]<;T0P2a_>830:c:k`D0ZLS_1@2Nb_H40:S8l0<0X/Sc0`0000040;?1i@80
^KKF0`2f`>800`000000^kKD0;^fe0020;^fe0H0_[CA00<0^;;C0;fcd02m/m000P2m/m020;2bf@<0
/k3F4P3oool00`000000oooo0?ooo`0<0?ooo`800000103oool2000000<0oooo1000000:0?ooo`00
5@3oool5000000<0oooo0P0000180?ooo`D0Y[OU1@2W^>D50:JVePD0YjKF0P2WYmH20:jniPD0[[OP
102]/M/60:fli0@0[k;K1@2[]N040:n^e`80[jO@0`2aa>P50;Bhg080/ZoE0`2ebn/50;C2i0H0[<[_
1@2PbOD409k:mP@0U<Oi0`0000030:;8l`@0/l7U1P2f`>800`000000^kKD0;Zmf`020;Zmf`D0_[CA
1@2m/m050;>`eQ<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00/0oooo000G0?ooo`030000003oool0oooo00<0oooo0`0000140?ooo`@0Y[KT
1@2V]nD20:Nhi@P0YZKF102WY]H50:jniP@0[[OP1@2Y`n`50:fli0D0Y;OV1@2[]N030:n^e`H0/LCX
102d^=`60;G;j`D0/<g_0`2/b^l30:_9l0D0X<We102Fa_P00`2DaoT000000000000209C7n@@0X/Sc
1@2Pa_<50;K0hP030;Zmf`000000^[gK00<0^[gK0P2n]=430<2id`<0_K?@0P31]/l50;>`eQ80oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00X0
oooo000G0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000@@3oool30:Ffi@@0
Y[KT102V]nD:0:JVePD0[LC[1@2^_^H40:K8l@D0ZL?/1@2O]NP50:BgiP@0ZkGP1@2Vb_840;74j0D0
ZmGf0`2ebn/30:WAm0D0/<g_1P2[bO050:;7lP0409K6n00000000000000000@0U<Oi1@2=`oT50:36
l`D0YLC_00<000000;Zmf`2j_M/00P2j_M/50<2id`80_K?@0`31]/l50;>`eQ<0oooo00<000000?oo
o`3oool00`3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`09
0?ooo`003`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03`0oooo1P2U]^D40:Jfi0@0YJGF1`2VY]H30:_7kPD0[LC[0P2^_^H30:C;
m0@0Y/Sa1@2N/nL509nej0@0Y;OV1@2LaoH50:K:lP@0V=Km1@2[eOH60:WAm0D0[/__0`2[bO030:k9
k@80X/Ob0`00000409W3m0@0S/;h1@2=`oT508W0n@D0YLC_00<000000;Zmf`2``NH00P2``NH40<2i
d`H0`KK?0P2c/=H30;F`e1<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000X0oooo000G0?ooo`030000003oool0oooo0080oooo0P000004
0?ooo`030000003oool0oooo03P0oooo2@2U]^D50:>Te@@0YJGF102VY]H60:_7kP@0[LC[1P2Tbo@4
09nciPD0W[?W102O]NP509c2l`D0W<Of1@2@d_h409SFo@D0V=3k0`2YdO@30:;<m@D0[/__102^bNd3
000000030:;7lP2Wao00YlO`00D0VL?d102>`_P508Fnn@D0RL3i102Ua>l00`2``NH000000;31iP02
0;31iP<0`;WC0P2m_=T50<6fc`H0]K3D4@3oool2000000/0oooo0P00000:0?ooo`8000002`3oool0
01H0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool50:Bf
i@L0YKKU0P2RX]D40:>Te@D0YJGF1@2Zb_040:_7kPD0Y<ce0`2Tbo@30:6fi`@0Wk?V102N/nL509no
k`D0W<;c1@2GdO`5093BoPD0Slcm102Hd?/60:;<m@80[/__0`2^c>l300000080[/W]1@2Wao0509o3
lP@0TL3f1@25__T408W0n@D0S;kg00<0/<7V0000002``NH00P2``NH01030^M<0_KcI0;flf@2m_=T4
0<6fc`80`kO?1@2e/=@C0?ooo`030000003oool0oooo0240oooo000L0?ooo`030000003oool0oooo
00D0oooo0P00000_0?ooo`D0Y;KV1@2T]^D40:Ffi@@0XZ;E1@2SY=D20:FUeP<0ZL_b1@2Zb_040:G=
m@D0Y<ce1P2Q]^L409nciP@0X;c]1@2O_nl509kBnPD0Um7l1P2FcO/80979n`D0X/ce0P2^c>l30000
00030:k<k`2`c>h0/<c^00<0/<c^0P2Wao030:W7k`D0Wl?b102A`?H508Nln0@0O;Wi1@2<__L01000
0000/<7V0;31iP2``NH50;flf@80`KK?1033]ll20;F`e0<0]k7C4`3oool00`000000oooo0?ooo`0P
0?ooo`00703oool2000000P0oooo00<000000?ooo`3oool0:`3oool20:BgiPD0Y;KV102T]^D50:6Q
e0@0XZ;E102SY=D60:W;lPD0Y/gd102UcOD50:>kj@D0XKKW1@2P^N/40:2lk@80Wko_0`2RdOP509kB
nPH0W/oi1@2KboP80979n`<0W<[g0`0000020:k<k`<0Z/kb102`c>h60:W7k`80Wl?b0`2S`^l409O0
m0D0Qkch101l^OT408bnm`0309fnl0000000WKk`0080WKk`102m_=T60<>gc`D0]k7C4`3oool00`00
0000oooo0?ooo`0P0?ooo`00703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02P0
oooo1@2T]nH40:BfiPX0XJ7D0`2RX]D50:S;lP<0ZL_b0`2WcO@50:K=m0D0YKo/102S^nT509jfj@D0
X;W[0`2P_>d60:;An0H0XM7h1@2Qb_D509_;n0@0U<Kh0`2<aO/3000000<0W<[g1P2Zc_840:k>l@D0
ZLO_1P2S`^l409O0m0D0Rkcf101i]_T407Jdn@0409fnl0000000WKk`09fnl080_KcI0`2e_=l40<>g
c`80`[O@1@2g/M<C0?ooo`030000003oool0oooo01l0oooo000K0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool08`3oool50:FhiPD0Y;OV102QX]H90:6Qe0D0YlSa102Xbo860:O=m0D0
YlC^1@2U_n`409jej0D0W[KY102P^N/60:?>mP@0Xm;h0`2QdOP30:;:m0D0XL[e1@2Pa_<309C6n0<0
00000`2<_oP409G6n0<0Z/kb0`2Ud?H40:k>l@D0ZLK_1@2S`^l509_1lP@0Rkcf101i]_T407Jdn@80
WKk`00<0000009fnl02e_=l01@2e_=l20<>gc`<0`[O@1@2g/M<D0?ooo`030000003oool0oooo01h0
oooo000K0?ooo`800000303oool00`000000oooo0?ooo`0O0?ooo`@0Y[[W1@2U^>H50::Uf0@0XJ;F
1P2QXM@30:K3kPD0YlSa1@2Xc_@30:O=m080Z<K_1@2Wa>h50:2gj@@0W[GX102N]^T50:;7l`<0Xlkf
0`2VeOP40:?Bn0H0X/[d1@2Tao850:36l`8000000P2J`?8508bon0@0ULKh1P2Ud?H40:O=m0D0ZLK_
1@2V`nh509_1lP@0Skge101j]OP406J[n00408>dm@000000PkCe08>dm@D0]KcO1P32]m020;Nad`<0
^;;C4`3oool00`000000oooo0?ooo`0N0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01X0oooo1@2W_NT40:Jji`<0YKSV0P2RZM/40::Uf0D0XJ;F0`2QXM@60:K3kPD0ZM7d
1@2Xc_@50:S6k`80YlC^0`2R_>/50:2gj@<0W[GX1@2R_nh50:;7l`H0Y]Gh102TcOD30:;:m0<0Xlce
1@2Tao801@2V`Nd00000000000000000Y/7]00@0V/3b1@2D]nl509G3mPD0X<gg102WcO@50:O4kPD0
Y/?^1@2N`_8408nmm@@0N[Gh101VZoP01023]?D0000008>dm@23]?D20;Flg`<0Z;ST1@32]m050;Rb
da@0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0H0?ooo`80YkoZ1@2W_NT40:Jji`D0XZWK102RYMP40:6ReP@0Y;cZ0`2V`nh30:_DmPD0
ZM7d2@2Xa^l60::lj`@0X;OY1@2O^>X40::okPH0Z=Sh1@2Ud_L40:C=m@H0Xlce0P2U`nl3000000D0
Y/7]102Q^>T509Bgk`D0W/Gc102PcOL509o4l`D0YlC^1@2Ya>d409k2lPD0Tkgd101m]OL405ZTmP03
06NVm@000000IjKe00D0Z;ST1032]m020<2gd@@0^;;C4`3oool2000001l0oooo000K0?ooo`800000
3`3oool00`000000oooo0?ooo`0E0?ooo`D0YkoZ102W_NT50:>]gPD0XZWK0`2RYMP50:6bi0@0Y;cZ
1P2[e?H50:S5kPD0Z<K_1@2U`^h40::lj`D0W[CX1@2O^>X50:SGn0D0YMKi1@2Ud_L60:3@n080W<Wg
0`0000040:G3k`80Y/7]0`2Y_>L40:6hj@80U;O_0`2R_N`509k5l`@0WLWf1@2Oa?<50:O2k@D0ZLC]
102P`o4509>mm0@0OKGg101JY?H00`000000IjKe06NVm@050:Rhi080`[O@1030]m420;Rbd`80^kGD
503oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0140oooo102W_n/50:NojP@0Xk7R1@2S[Mh40::Yf`@0WZSN1@2Q/^@50:cHm`<0ZmCf0`2X
a>d40:S5kPD0Z<O`1@2U`^h409fci`D0W[CX0P2O^>X30:GAm`<0Z=Oh0P2YeoP50:GFn@H0W/kh0`2E
e?d3000000<0W<Wg102U`nl60:Vli`<0XKSY1P2R_N`50:O=m0@0WLWf1@2K_O050:O2k@D0ZlO^102P
`o4509Jnl`@0P;Og0`1@W_D0101WY_D0000006NVm@1WY_D40:Rhi0H0`;OA1@2k]M@D0?ooo`030000
003oool0oooo01/0oooo00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0303oool90:Noj`D0YKGT102S/N840:>]gPD0W:7H102N
Z=h20:6bi0<0[=[h1@2/f?L60:S4k@@0ZL[a1@2Xao0509nej0@0WK?W102N]>P60:GAm`D0ZMOh1@2S
c?D309k>n080WM?k0`00000309GDo@<0W<Wg1@2S_>/50:Vli`@0Y[WW0`2R_N`30:g;k`D0Ylgd102I
_o8509^ml080Yl;]0`2Y`^`40:_7kPD0X<?a1@2F__<4082gm`<0D9ke00@0BiC`0000001;U?00BiC`
102H/>P40<2gd@80_kKA102k]M@D0?ooo`030000003oool0oooo01/0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool2000001<0oooo00<000000?ooo`3o
ool02P3oool20:O0j`D0Yko[102V^NL50:Fei0@0Xk7R102KW]H509bQf0<0WZSN1P2/f_P50:W3k@<0
Z<C]0`2Zbo440:W:l@D0XkWY1@2O]NP309fci`H0XLWd1P2/eOH50:[<lP@0Xlce00@0WM?k00000000
000000000P2Mdo/508G3o0<0T[Wa1@2S_>/50:Rii@@0Y[WW1P2]bnl50:O9lP@0VKob102K_O060:W2
k0@0ZlW_1@2P`o4509_0lP@0P[Wh0`13Uo80101;U?00000004^Dl01;U?0409R`j080`;OA0`2o]]43
0;^ee080_[WD503oool00`000000oooo0?ooo`0J0?ooo`001`3oool010000000oooo0?ooo`00000;
0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`070?ooo`D0Yl3[0`2W
_n/20:Nmj@@0Y[WW102U]N@509bOeP<0VikF1@2LXMP60:[In0D0ZlG]102Y`nd60:[;l@@0Y[o[1@2S
^NT409nej0@0W/7a0`2QbO@30:_@l`<0[=Gf0`2`c_050:[<lP050:S3k@00000000000000002X`nd0
1@2Bi?`508G3o0<0T[Wa1@2P]>H50:Rii@@0[<C[0`2]bnl30;7ClP@0YlWb1@2G^>h409^hk0<0ZL;/
0`2^an`40:_9k`D0Wl3`102K`?8408:in0@0@iOb00<0000002eoj00]OnP0102H/>P50;nfd@80^kGD
102n^M@D0?ooo`030000003oool0oooo01T0oooo00000`3oool000000000000200000080oooo00@0
00000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`X0Yl3[1@2W_NT40:Jii`@0WZCI102LWmH409^NeP80W:7H0`2WdOH30:[In0<0[/[_
1@2[aNd40:W:l@<0Z/_a0`2Y`n`40:Joj`@0XkWY1@2L_Nl409k1l@H0Zm3c1P2`c_020:g0j0<00000
0`2X`nd30;FbeP@0T^Cl1025`o`4096[j0D0X;CV0P2X^ND30:Vki`@0[<C[1P2ado840:;2l0D0UkS^
102K^>`50:k7k0D0Z<Wa1@2O`?040:35lP@0Pkci0`0aS>h0100]OnP0000002eoj00]OnP408RUj0@0
_kKA1P2n^M@D0?ooo`030000003oool0oooo01T0oooo00070?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool00`3oool2000001H0oooo00<000000:O0j`2W`>/01`2W`>/50:NnjP@0
YkgY1@2PZ]h309jTf@D0W9oF0`2KW]H60:OAmPH0[/[_1@2YbO040:W:l@H0ZL?/102V_n/409jlk@D0
W;g_1@2UbO830:_@l`80/Lo_0`2`c_020:o3j@800000102]`>P50;FbeP030=W6a`2=S<d0SHc=0080
SHc=1020VN84096[j0@0X;CV1@2Y^nL20:c4j`<0/mSc0`2ado830:[:l0@0X/;`102G^>h50:2jj`<0
[/O/0P2adO050:S9l@D0XL7_102PaO8408>ln@<0<Hc^00<03fOK0000000]OnP01028YNP20;nfd@<0
_kC?102n^M@20<BneA<0oooo0P00000J0?ooo`00203oool2000000X0oooo0`0000030?ooo`030000
003oool0oooo0180oooo2P2W`>/50:Noj`@0YkkZ102R/>850:2ZgP<0WZCI102LWmH60:;1k`D0/M7a
0`2^b^l20:S7l0D0ZLW`1@2[aNd40:W3k0D0XKc/102N_>d50:74lPD0YLWb1@2acnl0102_`nT00000
0000000000020:o3j@80[L3X0`2_/m/30;FbeP80fLK71@2=S<d3082IhP@0TJ_X1@2R/N840:Vki`H0
/mSc1P2Zb_030:;2l0D0U[?[1@2P^^/50;7Al0D0XLWd102Q`Nl50:C?mP@0Okkk0`0IN^D00`0?Im/0
000008RUj00308RUj0H0_kC?0P2n^M@30<BneAD0oooo00<000000?ooo`3oool05`3oool001T0oooo
00<000000?ooo`3oool04P3oool70:O0j`X0Yko[102U]nH40::`hP@0X:[N0`2NY=T509b_i@<0X/7_
0`2bfO@50;7Al@D0Z<O`1@2Za>`50:_5k@@0YL3]1@2Q_>`40:33l@D0XLCb1P2/b^l0102abN`00000
0000000000050:o3j@H0[k?K00<0]K;F0=W6a`3Ia/L00P3Ia/L408f<c@@0T9GD102EXMd50::ahPD0
/]Sc1@2^dO<30:[:l0<0Y<_d0`2L^nh509Jcj`D0Z<[a0P2adO030:KRn`D0XLWd102SdOP50:C?mP@0
Okkk0`0IN^D00`0000003fOK07ZIi@0307ZIi@D0_kC?1@34_]DE0?ooo`030000003oool0oooo01L0
oooo000I0?ooo`8000004@3oool:0:O0j`D0Yko[1@2V^nP40:FgiP@0X[3R102GWMP309RRg0D0W:oU
1P2bfO@50:W6k`<0Z<O`0P2Za>d50:[4k0D0ZLK_102U`>d50:6okP@0X<?a1@2TaO030:c:k`<00000
102abN`50:^ji0D0[k?K1@3Ia/L50:ZWe0<0T9GD1@2EXMd20::ahP<0[Lob0`2bf?<20;;LmPD0[]7c
1@2Tbo@409bkkPD0UL?g102Xb_460:KRn`D0SM?n102SdOP509WMoP@0LKon00D0063E01Uji@0IN^D0
000000mWf`0307ZIi@@0_kC?0P33]Ld30<Bne@80blKE5@3oool00`000000oooo0?ooo`0F0?ooo`00
6@3oool00`000000oooo0?ooo`0=0?ooo`h0Yl3[0`2W_n/20:NnjPD0Y[_X0`2U]nH509VOf0<0UigH
102HX]`309b_i@@0/M[e102[anh50:W6k`D0Z/C]0`2Za>`20:_9l0D0ZLK_102Q^n/50:6okPD0X/Gb
0`2TaO03000000@0/<c_102Z`n`50:^ji080[k?K0`2[[m/30=W6a`80a<[O102ZYm@4092Ee0@0UJ7M
1P2]co850;;LmPH0Wmkl0`2Tbo@508C>o`D0UL?g1@2BjoH506_Dn@@0SM?n1P26h_/506[Gm080>Zob
0`00H=D00`00C/`0000007ZIi@0307ZIi@80_kC?1033]Ld00`34_]D0blKE0<_6e@020<_6eAD0oooo
00<000000?ooo`3oool05@3oool001T0oooo00<000000?ooo`3oool02@3ooolC0:O0j`D0YkkZ102V
^nP409bVg@@0VIoH102GWMP409RRg0@0/M[e0`2`c>h40:_7kPD0ZlK^1@2Za>d50:_9l0D0Xk_Z102Q
^n/50:G8lP@0X/Gb0`0000020:S7l0<0/<c_0`2/c_840:[3k0@0Zk[T1P2[[m/0103Ia/L0a<[O0<C:
g`34b]l50:ZWe0<0T9GD1P2R`^l60:oVn@D0QnSc1P1VdOP3073Fn`@0Q<ko1@1Ze_H6067DkP@0JmCi
1@1Uc_X506CBm@H0A<;X0P00K;P2001Pe@03000f_0000000LHkP0080LHkP1P33]Ld40<_6e@80dlkE
503oool00`000000oooo0?ooo`0E0?ooo`006@3oool2000000L0oooo4P2W`>/50:Noj`D0YkkZ102P
[n8309bVg@D0VIoH0`2GWMP60:[@m0H0/<c^1@2/bNl40:_6kPH0Z/O^102X`N/50:>kjP80XK_[0`2V
ao040:G8lP<000000P2Q`>l40:S7l0H0[<kb0`2Z`n`509n`h`D0ZjoK1@34b]l40:ZWe0@0X;[[0`2R
`^l409oYn`D0GMG=1P1ec_l509>]j0@0Nk7f101Q_?d308GHo`<0[/CZ102>]o8509blk`<0Oloo0P2W
`^d308WAo`<0/Lo_101Ra_d01P1P000006bh001Pe@00=[`00000001>c0<0LHkP1033]Ld20<Vhb@80
blKE103Cc]DD0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo00<0oooo
5`2W`>/40:Noj`D0XkOV102P[n8309bVg@@0VIoH1@2O^n`30:[@m080]=?`0`2`c>h30:_9k`D0[<W_
102X`nd30:[7kP<0[LK/102X`N/40:>kjPH0Y/O`0`0000000`2S_nd0XL3_0:70k`030:70k`@0Z]7d
1@2/c_8409jkk@D0Wk3S0P2[[m/30;oQl0@0a<[O1@2S_>/40:2jj`@0WnWk1@2M`o8408k9o0D0WjWN
102C[NP509jYgP@0VKc`1P2^a>X40:B[g0D0W;c_1@2W`^d40;7?k`80a<kR1026_?P01@008:D0H000
000f_000=[`0000000@0LHkP0P33]Ld30<Vhb@D0dlkE0P3Je]@D0?ooo`030000003oool0oooo01<0
oooo000H0?ooo`030000003oool0oooo00<0oooo6@2W`>/40:Jlj@D0XkOV0`2P[n8309bVg@D0UZKQ
1@2O^n`50;CCl0H0ZlW_1@2X`^`40:S3k@H0[LK/0`2X`N/50:?3k`80Y/O`0`0000000`2Y`N/0Xko]
0:>ok@020:>ok@D0YL_c102ZdO@509o4lP@0W[_]102O/><60;oQl0@0X/3_1@2S_>/508[Vn0<0Y;g[
1@2M`o840:FZfPD0WjWN102TY]L509jYgP80VKc`0P2kbnH30:k4jP<0ZZWF102TZm`50;O1h@80Yl;]
102l`ml50<C>hP@0Q[ch00D0022U060000008jl003Jl000000030728f`D0bKS900@0dkg50=?>e@3C
c]D0dlkE0`3Je]@C0?ooo`8000005@3oool001P0oooo00@000000?ooo`000000oooo602W`>/40:Nn
j`@0Y[cY102S]nH409BNfP<0TicJ1@2FY^460;KIlPD0[<W_0`2[bNl20:_4k0D0Z<;/1@2]and40:g6
k0D0Xl7_0`2S`nl2000000D0ZL7[102Va>l50:G;l`@0YlWb1@2Oa?8507k2o@@0RLgn1@2Ub_<40:;0
k`H0M=oa0`2X^nL40:Bmj`D0ZJgJ102UZ]X209nYgP<0YjKE102TY]L409jYgPD0^l_V1P2ZZMH20:B[
g080^/7O102g`N450;c3g`80b<_L0P34c^830<K9g0@0SJCT00@0022U09LR00008jl00000101`R=/3
0<Vhb@<0dkg500<0dlkE0=[Fe03Je]@00P3Je]@20=kKdQ<0oooo00<000000?ooo`3oool01P3oool2
000000X0oooo000H0?ooo`030000002W`>/0Yl3[01L0Yl3[0`2W_n/40:Nnj`@0Y[cY102JY]h309BN
fP@0TicJ0`2FY^430:oAlP<0]]Wb0P2`cNh50:c9k`D0ZlC/0P2X`^`30:[6kPD0[LO]102X`nd40:?1
k`<000000P2W`>`30:W1j`<0ZLC^102Va>l50:_5k0@0YlWb1P2Aa?P407k2o@@0UlCf1@2Ub_<206?G
j`@0J]Sc0P2Z^nH50:Rki`@0Zk3K1@2Y[MX30:FZfPD0YjKE102TY]L50;K3i0<0^l_V0P2e^M`50:ZY
ePD0^/7O0P2g`N420;bog0<0_<?O0`38bm`60<K9g0<0SJCT00D002Vc000PY@008jl002>_00000003
0728f`<0bKS90`3C_LD40=[Fe0<0g]_B00<0hMkB0?ooo`3oool04@3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000T0oooo000A0?ooo`8000001@3oool00`000000oooo0:O0j`0E
0:O0j`H0Yko[0P2W_^/20:Bij0@0Wk3T102JY]h309BNfP@0TicJ1P2_dO850;3=kPD0[LO]102[a>`6
0:[6kPD0ZlC[102X`nd300000080Y;o]102W`>`60:W4kP80Y/C_0P2]_nL50:_5k0D0Y<Ga1@2M^>/4
09:jlP@0UlCf0P1Ne>L6087IoPD0Z[_V0P2X^nL30:Z_g0@0Zk3K102Y[MX40:NUe0D0YjKE0P2TY]L2
0:fgh@D0]/?T1@2e^M`20:ZYeP<0/KSN102j`Ml50;bog0@0b<_L0P3<dMd50<K9g0<0SJCT0P00:K<0
10008:D002>_000S[`0000030728f`030<Vhb@3C_LD0dkg50080dkg500<0g/Fo0=[Fe03Je]@00`3N
fm820>7NdQ<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`00403o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01L0Yl3[102W_n/50:Bij0@0Wk3T
0`2JY]h309BNfPH0XK[[1P2fdnl50:k:kP@0[LO]1@2YaNh30:[6kP80Z/;[1@2[a>/3000000030:S2
k02T_nd0Y;o]00<0Y;o]102Wa_050:W4kPD0[KoW1@2aa^T30:C5l@80Z[SS1@2M^>/409:jlP80GMCW
1@2@e?h50:VjiP@0Z[_V1@2Z[m`40:^`f`D0YZ?C102WYM@40:NVe@D0[KOQ0P2f`n@30;g=iP@0]KWL
1@2a^=h20;[1g`<0^l;P0`2l_m`20<;8h080b<_L103<dMd20<K9g0<0]kGH0`26S]@00`05>[`002Vc
09LR0002000S[`030000001hRML0N8WG00@0dkg50`3NaKl30=kKdP<0hMkB00<0hMoC0?ooo`3oool0
4@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo000@0?ooo`040000
003oool0oooo000000@0oooo0P0000020?oooaL0Yl3[102V_NX50:Bij0<0Wk3T102?Vm/409>Th0<0
XK[[0P2ge_030;KCk`<0/<c^1@2^b^h40:W4k@D0ZLG^1@2Z`^/01@2/aN`00000000000000000[<G/
00@0Z<;/1@2Ta?040:O6l0D0ZKgW0`2]_nL20;C8j0D0/LKY1@2Z^><409fhj`80JMW_1@2Ld_/50:Ng
i0@0ZK[V1@2X[M/40:Z_g0D0YZCC102VXm<40:NUe0D0Zk?O102]]n450;g=iPD0YjgK102a^=h60;_2
h0D0`/SP1@3<dMd50;Nef0<0QXkD0P05>[`01000:K<001JU000S[`00000307R9e`<0dkg50`3NaKl0
0`3XcKX0g]_B0>7NdP020>7NdP<0hMoC4`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000T0oooo000@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3o
oolB0:O0j`D0Yko[102V_NX509Z[hP<0TYoM102?Vm/409>Th0D0]mK`1P2`c>h50:_4k0@0ZLC]1@2Z
`n`20:[2j`<000001@2/aN`40:K2k@D0Y<C`102U_n`50:Vmi`D0]<SX1@2c_>040:Zhh`<0Q>Cg1@2V
e?P40:Nch@D0YkOT102XZ]T50:R]f`80ZZoL0P2XY]@40:JTd`@0YZ?C1@2[]N040:^cg`H0^MG^102X
[=/50:N]f`80/KSN0P2jb^H30;_2h0<0^<CS0P32b>030<C@h`80c=7M0`37cMl40;Nef0@0QXkD0P05
>[`0102M<P0001JU000S[`00000307R9e`040=>ma@3NaKl0g/Fo0=k5_`80j<fj0`3Qg]830>7Od`80
h>3D4P3oool2000000@0oooo0P00000:0?ooo`00403oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00D0oooo4P2W`>/40:Noj`@0XKKW102JZn8409:Og@<0Si_K1@2]b>h30;OFl0<0
]M3^0`2`c>h20:k8k@D0ZlC/102[aNd30:[3k0<00000102/a^d50:W1jP@0Y/;]1@2U`Nd40:Fok0D0
ZlW_0`2db>P20;;1i0D0/kcP0P2JkOH60:gKm`@0Z;3N102W/n420:Ngi0<0Z:WG102XZ]T40:R]f`@0
Z:KD1@2VY=<20:JSd`80Z[KR1@2[]N020:^cg`80[loa0`2ieNh30:jgh0@0Z:cK102W[M/50;[:iPD0
^<CS1@34d><60<O=g`@0XIc@0`25RLl300Dj_004000>WP005ZD0N8WG00000080N8WG0`3NaKl30>S=
^P80kmBf0`3Qgm<30>3Pe140oooo0`00000@0?ooo`004@3oool2000000@0oooo0P0000070?oooa80
Yl3[102U_>X40:6fi`@0VZ_R0`2BWmd509Z_iP@0[LS^1P2ed>h50:k8k@D0Z/G]0`2[aNd3000000<0
ZLC]0`2/a^d20:_2jPD0ZL7Z1@2Z`^/40:G1k@D0W/Kd102[bNl50;;1i0<0/kcP0P2Ll?820:_Qn@<0
[M_g0`2X[]`40:R`gP<0Yk?Q1P2XZML30:RZf@D0ZJWF102XY]@40:JTd`D0Z[KR102[]N050:o?l@H0
[[OP0`2X[=/50;C:j`80^/[V0`2a`>D30;S4h`80^lgX0`34d><20<GEiP<0algO0`2a/mX30:6Ld0@0
QHW?00<07do800Dj_02M<P000P005ZD01029T]H0000008VBeP29T]H20=k5_`80j<fj0`3_e;H00`3d
fK<0hMoC0>3Pe0020>3Pe0<0g^;G4@3oool00`000000oooo0?ooo`0>0?ooo`005`3oool00`000000
oooo0?ooo`070?ooo`d0Yl3[1@2W_n/40:FljP@0XKKW0`2JZn8408fMgPD0VZoV1@2ie>h50;7<kP<0
[/S]0`2[aNd30:[5k@<000000`2X`^`40:W4k@D0Zl;Z0`2Y`NX20:c4j`D0Z/;[102R`o0509k6m0@0
Y/3/1@2b`N@209c`lPD0Zn7i1@2X[]`40:R`gP@0ZJSF1@2XZML40:Z[e`D0ZJWF0`2XY]@50:VehP@0
Z[KR1P2Zanl40;;5j0D0[[OP102Z_nT40;C:j`H0/L3U1@2kcNP50<GEiPD0/K?J102QW=0408F9c`06
01m?b005>[`000jN000FY@29T]H000000P29T]H0103NaKl0j<fj0>S=^P3XcKX20>oD]P80m=Vc0`3P
h=@30=kRe`80g>?J4@3oool00`000000oooo0?ooo`0=0?ooo`005`3oool00`000000oooo0?ooo`08
0?ooo`T0Yl3[2@2W_n/30:FljPD0U:OR0`2<W=d408fMgP80VZoV0`2dc^d30;WDkP<0]]3]102ac>h5
0:_5k@<000000P2Z`n`50:S2k0@0Z/?/1@2[`^X50:c4j`D0Z/7Z102R`o0509nlk@@0Y/3/0P2<jo46
0:CTo0@0YjcK102X[]`50:ZYeP@0ZJSF0P2XZML30:^^f@@0ZZ_G102YZMH40:Rdh@D0ZKGR102Ya>d3
0:[7k`<0/<c^102baNP50:Bbh`@0Z[oY102a`nL30;70i@<0]<WZ0P2kcNP30;cCj`<0aMGV0P2lbnD4
0;6cfP@0XIc@1025RLl201m?b00609db00003Yh0RI;F08VBeP000000RI;F0`3XcKX30>oD]P80m=Vc
0P3fg[830=kRe`<0g>?J4P3oool00`000000oooo0?ooo`0<0?ooo`005`3oool2000000T0oooo2P2W
`>/50:Noj`@0Y;_Z102M/nL409BWhP<0S9cM0`2=WMh60;C>k@H0]]3]102^and20:_5k@8000000P2[
aNd40:[3k0D0Z/C]102Z`n`50:[5k@<0[<C[0P2Z_nT50:[1jP@0Z;gY1@2O_>d408CRnP<0XnKk2@2W
[=/20:R^g080ZZ_H1@2ZZMH30:VXePD0ZjkI102ZZmL50:Vdh@@0Z;CQ1@2Za^h40:W4k@D0/<c^0P2b
aNP30:B^gP@0Y;;S0P2Z_nT30;;;k0@0/L?W1@2dbNX60;cCj`D0_<_U0`2a/mX40:6Ld0D0SIKH00<0
<FGE01m?b0001iP00`2OXmP010000000Wj?H0>S=^P3XcKX20>oD]P<0m=Vc0P3fg[800`3fh[@0g^;G
0=cSfP020=cSfP80f>CN4@3oool00`000000oooo0?ooo`0<0?ooo`005`3oool00`000000oooo0?oo
o`0:0?ooo`T0Yl3[0`2W_n/20:Joj`@0Y;_Z102M/nL309BWhP<0S9cM1@2Q]^P30;C>k@80^m?/0`2f
d>d30;;<k@80[/O]0`0000050:_5k@D0ZLC]102Za>d40:S3k@D0Z/G]1@2Z_nT50:o2j0@0Z;gY1P2G
fOh20:?Vn`@0ZJoL202W[=/40:Z[f0D0ZZWF102//M`50:^^f@80ZZ_G0P2Z]n<50:Vdh@80Z;CQ0P2Z
bO040:[6kPD0[<_`102`c>h60:B^gP<0Y;;S1P2bbn`40:k4jP<0]<WZ0P2fcN`30;cCj`<0_MK/102l
bnD409^Id@@0VYS@102=U]P2035Ue@8000NH0`2OXmP00`000000Wj?H0>oD]P020>oD]P80m=Vc0P3f
g[820?KR]0<0g>?J103Hi=hA0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0
oooo00`0oooo2@2W`>/50:Joj`<0Y;_Z1@2?YN<308NJgP<0SIoP1@2Q]^P50;_Ck0@0//c]0`000004
0:c6k@<0ZlG]0P2Y`nd50:W4k@@0Z<;/102X`nd50:W0j`<0Z[oY0P2/aN`50:o2j0D0ZLod102YkOP3
0:fihP@0ZJoL102W[=/40:V]fP@0ZZ_H0P2ZZMH30:bfh0@0[;7L102[[]T50:Zgh`@0ZKCQ1@2ZbO04
0:S6k`D0[<_`102X/Mh50:B^gP@0/<k`0`2bbn`30:^oj0@0[/CZ1@2fcN`50;gFk0D0YJWI0`2KVM45
09ZHd0<0SIKH0`0aIMD20007V080Wj?H00@000000;Nkg@2g^md0kmBf0`3dfK<20?KN/P80m^:d0P3e
i[P40=STgP80dnCS4@3oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000h0oooo102W`>/5
0:Noj`@0Y[o[102K/nP408nUh`@0Qi[N0`2=Wn060;S>j`@0^=3/0`0000030:k8k@D0[<K]1@2Y`nd5
0:W3k0@0Z<;/1@2Z`^/40:W0j`D0[<G/0P2_`^P30:c8kP<0ZLod0`2Xlo<60:fihP<0ZJoL1@2X/=h4
0:V]fP<0ZZ_H1P2/]^030:bag0D0Z[[U102Z]n<50:S:l@80Z/W`0`2W`^d40:S6k`D0ZkKQ102X/Mh5
0:_:l0@0/<k`1@2[_nP50;;;k080]/g/102ie^l40;;1i@@0YJWI102KVM4409ZHd0<0SIKH100aIMD0
1P001iP0]k_M0;Nkg@2g^md000000;Nkg@<0m=Vc0P3fg[820?KR]0<0mNJh00<0lnVm0=STgP3Hi=h0
0P3Ci><20<kSi`l0oooo0P00000<0?ooo`005P3oool00`000000oooo0?ooo`0>0?ooo`D0Yl3[102W
_n/50:>kj`<0Vk?X102?YN<308NJgPD0Y;SW0`2hc^/20;gBjP<000000`2dc>`40:k8k@D0ZlG]0`2Y
`nd20:[4k@D0ZL?/102Za>`50:[2j`@0YlC^102/aN`60:c8kP80Z??c102`an/50:fihP@0Y[;Q1@2X
/=h30:V]fP@0Z[WT1@2/]^040:Vnj0D0Z[[U102Vb_840:S:l@H0Yl;]102/^nD50:^fh@@0Yl;]102[
b_050:boj0<0ZkoX0P2_bNd40;;;k0@0^MK_0`2hdNd40;;1i@<0YJWI102KVM450::Xf`<0U:GR0`0m
Lmd00`000i<000NH0;Nkg@020;Nkg@040000003;e>40m=Vc0?CI/`80m]jb0P3fh[@20?GV^080lnVm
0`3Ci><30<kSia40oooo00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0403o
ool40:O0j`@0Y[o[1@2S^n/309^cj0<0SjGS102<Wn450:Bhi`050;gBjP00000000000000002md^X0
1P2dc>`50:g6k@@0ZlG]1@2Za>d50:S3k@@0Z/C/1@2X`^d40:O4kPD0Yl;]1@2Kl?820;7Fl`@0/<O[
1@2S/N840:Jbh@@0Z;3N102W^^L40:Zii0D0Yko[102Y_^P50:G8lP@0Y/[b102W_n/30:O2k@<0ZkkW
102/^nD20:^fh@<0Y[cY102W`^d40:g3jPD0[;oX1@2_bNd50;?@k`D0^=7]102b`ND30:FYf@D0VYgE
102RZ=/409BUhP<0?G?M00D000>C0007V02g^md0bmCQ000000020<_Dh@80m]jb0P3fh[@20?GV^0<0
lnVm00<0l>c30<kSi`3>hnL00P3>hnL20<OPjQ40oooo00<000000?ooo`3oool0203oool001H0oooo
0P00000B0?ooo`@0Yko[102V_n/509ZdjP<0S:GU0`23VN0408bOh@80Y;SW0`0000030;gBjP<0^m7Z
0`2dc>`20;39k0D0[LK]102Ya>d30:[4k@L0Z<?]102X`N`50:S2k@@0Yl3[0`2W`^d409WZn@D0/MKc
102P[n850:>ahP<0Y[;Q1@2T^NP40:Nji`@0YKo/1@2W_n/40:C5l@@0YLSb1@2W_NT40:Noj`H0ZkkW
0`2/^nD50:Jlj@D0[LO]102]`nX50:c6k@80[lW]0`2_bnh30;?@k`80]]K`102hdNd509bMe0<0UYKA
1@2JWMD30::Xf`D0TZWV00@0A7WO03ecg@0mLmd000>C0`3;e>400`000000e^GR0=KUhP030?KR]080
mNJh0P3cjKd20?3/``80kNk91@37h>X@0?ooo`030000003oool0oooo00P0oooo000F0?ooo`030000
003oool0oooo0180oooo102W_n/50:>lj`@0V[CZ0`2<YND308>Ih080S9oQ0`0000040;W;j0H0^m7Z
1@2`bN`50:_5k@@0ZLC]1P2X`nd40:W2k0@0Z<7/1@2Z`^/40:O0j`80VN[i1P2ci_L40:6_h@@0X:oR
102S/N840::fiP@0Y;WX1@2T_N/40:Fok0D0Y<;^102TaO440:Nlj0D0YkgY102Z_nT50:^ni`@0Y[WV
0`2V_>T20:c:l0D0[LO]102Y`n`40:c6k@H0[l_^1@2fe_040:R`gP@0W9gD102FU]4409ZMe@@0YkKS
1@2BZNH204Aig`06000OZ`005iX0bmCQ0<_Dh@3FiN8000000`3HkN820?GV^0<0lnVm00D0l>c30>g^
b@3]k/T0kNk90>S^d@020<OPjP<0`M_]3`3oool2000000T0oooo00030?ooo`800000103oool20000
00@0oooo0P0000040?ooo`030000003oool0oooo01@0oooo1@2V_n/40:>lj`<0V[CZ0`2<YND208>I
h0<000000`2S]ND30;W;j0<0_m7W1P2hc^/40:k7k@D0ZlG]102Ya>d30:S3k@<0ZLC]102Y`^`40:[4
k@D0Z/;[102Sg_`30;7am@D0Y[GS102Q[n430:2_hPD0X[?T102R]^H40:BljPD0Y;g[102T_n`50:C2
kP@0Yk_W102W_>P50:Voj@@0Z[oY1@2X^ND40:JiiPD0[<[`1@2Y_nX40:W3k0D0[/S]1@2ceO850;;6
j@@0Z;3N102LWM@309JFd@D0YK;Q102W]^<409:YiP<0A7WO00L001n[0=KUhP3FiN80e^GR0=S]hP00
0000f>gR0080f>oR0`3cjKd20?3/``80kNk90P3Xk]440<7Kk@80^]K^2`3oool3000000030?ooo`00
0000oooo00P0oooo00020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0E0?ooo`D0Y[o[102K]^/308^Xj080OYWS0P00000208NMh@D0XkGU
102odNL30<3Ai`<0^<k[0P2dbn/40:k7k@D0Z/G]2P2Ya>d40:O3k@@0Z/C]1P2WcoD20;7am@@0[/?Z
1@2V]N<30:6_h@@0X[3R1@2R/n@40:Fjj0@0Y;cZ1@2U_>X40:Bok0D0Z;[W102W^nL40:Vnj@D0ZKoY
102X^^H40:Rii@H0ZL[a102Y_^T40:VojPD0[LS^0`2^b>d20:oAlP<0/mGb0P2cd_040;;6j@@0Z;3N
102LWM@409fVg0@0YK;Q1@2U]nH408bWi`0504Qlh@14NMl0A7WO000OZ`00=;@00P3HkN800`000000
f>oR0=S_hP030=W_h@80l>c30P3]k/T20>S^d@<0h^kH1@2je^h60?ooo`@00000103oool00`000000
oooo0?ooo`070?ooo`000P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?oo
o`8000005`3oool50:Blj`@0VkK[00@0RjSX00000000000000000P1nVN<308NMh@H0]lKU1P30dNL5
0;C;j`D0[<O]102ZaNd40:S4k@<0ZLC]0`2W`^d40:O3k@D0YlK_0`2WcoD20:[bm@80]]Wb102^`nX4
0:Jeh`P0X[3R1@2U^^L40:Fjj0@0Y[_X1@2U_>X40:Rki`@0Z;[W1@2Y_nT40:Vnj@D0ZK_W102X^^H4
0:S8l@<0ZL[a0`2Y_nT40:Vnj@@0[<S_1@2]b>h50:oAlPD0/m;`102MWM<409JEd0@0UYWD102MY]`2
0:Fbh@80ZK[V1@2U]nH308bWi`<0B7cQ00<003_0000OZ`00F]800P3Hkn8010000000fNoQ0=W_h@3I
kn420=c^gP80kNk90P3Xk]430>;^f080fNcQ0P2je^h30;C?kP80oooo0`0000080?ooo`030000003o
ool0oooo00L0oooo00020?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003o
ool0oooo01P0oooo102T_>/0102K]^/0000000000000000208^Xj0<0OYWS1@2L[N<30;O6i@80`LgS
0`30dNL30;g?j0<0]<_[0P2ab^`50:c7k@@0ZLC]102Xa>d60:O2k@@0Z<C]1@2Wa^l20:[bm@D0]]Wb
102O[^840:2_hP@0X[3R102U^NL50:Fji`@0Yk_W102V^nP50:Rli`@0Z;_W102X_nX50:Voj@@0ZKgX
102Y^nL50:O6l0@0Z<Sa1@2Y_nT20:Vnj@<0Z/S_102/b>l50:c<l0D0/]Gb1@2X[md309fMd`@0UYG@
102FVM@409fVg0D0ZK[V102U]nH308bWi`@0B7cQ00L02eK@001JdP00F]8005[B0=W_h@000000fNoQ
0080g>kN0P3Nk]`20>S^d@<0h^kH0`3Ik>450;C?kP800000303oool00`000000oooo0?ooo`060?oo
o`000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06@3oool0102P^>T0000000000000000308f]j`<0NY[V0`1nV>8509b]h`D0`LgS1P2mcnP5
0;7:k0D0ZlK]102Ya>d50:S3k@D0Z<C^102Xa>d40:SYnP@0^>ce102Q/^D409n^hP@0X:oR102S]nH4
0:Fii`D0Yk_X102W^nL20:Jkj080Z;gX1@2X_>L20:Rki`80Z;o[102X_nX50:Rnj@@0ZKgX102WaNl5
0:O6l0@0Z/3Z102Y_nT60:[8k`@0ZlS_0`2/c?020:oDl`<0/]Gb0P2_`NP40:R_g@@0WIgC102FUM03
09JIe0D0YkWV102Y^^H50:2ei`<0QZCX0`1=On4200]Fd0<0:H3X00<0g>kN0000003Lk]h00P3Nk]`2
0>3_fP80hO3I0`3Ik>430<oVi`80]<o^0`2_bNh=0?ooo`030000003oool0oooo00H0oooo00030?oo
o`8000002P3oool3000000<0oooo0P00000H0?ooo`<00000102P^>T308f]j`<0NY[V0`1nV>8209b]
h`<0/KgR0`31cN<40<G?hPD0^lkY1@2_bNd40:_6k@@0Z<C^0`2X`nd30:O4kP@0Z<C^1@2Wf?T20;S/
m@D0Z<3[102Q/^D309n^hPD0XKCV102S]nH20:Fii`80Y[_X1@2W^nP30:Nki`D0Z;gX102X_>L50:Ro
j`@0Z;kZ1@2X_^T40:O4kP@0YlG_1@2Y`N/40:[0jPD0ZLK_1@2Za^h40:_8k`D0[mCc1@2_`NP40:R_
g@<0WIgC102FUM040:>ci0@0YkWV1@2W^^L40:2ei`@0QZCX0`1=On400`0^Kmd02eK@02V0j00202V0
j0030000003Nk]`0g^kL0080h>oJ0`3Ql=T00`3QlMX0cnKW0<oVi`030<oVi`D0[lW^3@3oool00`00
0000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0E0?ooo`<00000103oool30:2hj@<0
SJg[0`1jV^H307jHhPH0/KgR1`35cn830;_>j@80^<gZ1@2_bNd40:W6kP@0Z<C^1P2Wa>h50:O;l`@0
/_;e0`2df?<40:S0j`<0XK;U102N/ND50:6diP<0XkOV1@2V^nP40:Nkj0@0YkkY102X_NP50:Noj`80
Z;o[0`2W_nX40:RnjPD0Yl?^102Wa>h40:W2k0@0ZL7[1@2XaNh30:W6k`80Z/G^102Za^h50:gCm0D0
/<k_102_`NP40:R_g@@0Ui[E102LYmh40:>ci0@0Yk_X1@2W^^L409^bj0<0P:3W101=On4202i_g@<0
GJ7d00<000000>3_fP3PkmX00`3Ql=T20>7afP040=gbg@3?i^L0cnKW0<oVi`<0`mg/102[aNd<0?oo
o`030000003oool0oooo00H0oooo000D0?ooo`030000003oool0oooo0180oooo0`0000070?ooo`@0
VK7X0`1lX>X3076Ci0@0SJ?S0`2a_N820;o5g`L0aLoR1@2hcNX50:g8kP@0ZLK^1@2Wa>h50:O6l0<0
Yl_c0`2^j_T60;CHl`<0Z<3[102L[n@409jai@@0XKCV102U^nT40:Jkj0D0Y[kZ102W_^T80:Noj`H0
YkoZ0P2X_^X60:O3kPD0Z<;/102Y`^`40:S4kPD0Z<G^1@2ZaNh50:_@l`@0[]?c102`c^l509bId0@0
UiG?102GV]D309bWgPT0Yk_X1@2T^NL409^bj0<0P:3W0`1DPn8302i_g@<0Qk[g00@000000>7`f@3Q
l=T0hO3I0P3QlMX30=gbg@<0`mg/0`2hdnh40:_5k@/0oooo00<000000?ooo`3oool01P3oool001@0
oooo0P00000@0?ooo`<000002`3oool409Vaj0<0O:3Z0`1aTn@408fSh`D0_lGO1035cn830<C?h`<0
^<gZ0P2ec>/50:g8kP@0Z<K_0`2Wa>h20:O5k`D0YlK`102^j_T30;[/m@D0W[CX0`2J[^D409b_i0@0
XKSY102S^^T40:Fkj@@0YKk[102V_^X50:Jok0P0Yko[1@2W_nX50:O3kP@0Z<;]1@2X`^`40:S3k@@0
Z<C^1@2YaNh50:[>l`80Zm3c0`2]e?@40:kCl`@0Xj?E102LVM0409NEc`@0Ui[E202W^nP50:Jkj0@0
Y;WW102K/^P3082Pi`@0E8?R0`1@QnH30:K=m0040000002VcO@0hO7J0>7afP<0gO;M0P3Fl>@50;SC
kPD0ZL;/2P3oool00`000000oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`<0
00003`3oool309Vaj0<0O:3Z0`1aTn@50::`h@<0_lGO0`37bM`60<C?h`D0]Lc[1@2[b>l40:S6k`D0
YlG_1P2Zf_P20;[/m@@0ZLO_1@2N]>P309Z^i@@0WKCX102Q^>T40:>jj@@0Y;g[102U_^/40:Fok0D0
Y[o/102V_n/40:Noj`H0Y/;^102W`^d90:S2k@@0Z<?]1`2YaNh20:W;lP@0Z/kc1P2]e?@40:VagP@0
Xj?E102LVM0309NEc`D0YKWW102W^nP40:Nlj@D0Y[_X102Q]nP409J^j0<0NicW0`1NRN@40527iP80
Y/gd00<000000;gLk`2mg>l00`3Ml]d20=K`i080c>W[0`2hdnh20:o:k@@0ZL;/2P3oool00`000000
oooo0?ooo`060?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`8000004`3oool409:YiP80KIGW
0`1fU^@50::`h@@0alWL0`3;b]T30<C?h`<0`loS1@2bc>d40:_8k`D0YlK_1P2WcO@40;K`m@80]n;e
102Yanl409jdj0@0V[3W102M]>P30:6hj@D0Xkc[102T_N/40:Fnk0@0YKo/1@2V_n`40:Joj`D0Y/;^
3@2W`^d40:S2k@D0Z<K_102YaNh50:W;lPD0Zm?e1@2]_nL40:VagP<0Xj?E102LVM040:2`h`@0YKWW
2@2W_>T50:Fjj0@0XKOX0`2F[^P407^Li`<0GXWT0`1aW^d30;gLk`030000003<inT0c>OY0080e_3T
1@3<jN/50:o:k@@0Z<7[2P3oool00`000000oooo0?ooo`050?ooo`00503oool00`000000oooo0?oo
o`070?ooo`<000005P3oool409:YiP80KIGW0`1fU^@30::`h@80];WM0P37bM`50<_:f@@0`loS0P32
cn@50;;<k@D0Z<S`102Vb?830:O=m0@0/>Kh1@2gh_D409N`j0@0UjkV102J/>L309fdj0@0X[_[1@2S
_>/80:Fnk0@0Y/3/1@2V_n`70:K2kP80Y/7]3@2W`^d80:S6k`H0Z<Wa1@2Zd_D40:g9kP@0[KoW102Y
/Mh409VIdP@0VZ?K102P/><40:Jkj0@0YkcY1@2V^nP40:Fjj0@0XKOX102@ZnP307RJiP@0GXWT101a
W^d20<cWj@030000003DknD0e>oU0080e??U0P3<jN/30;kMk`D0ZlC/0`2X`N/:0?ooo`030000003o
ool0oooo00D0oooo000C0?ooo`<000001@3oool3000001T0oooo1@2<Xn@00`1US^D0MYKT07JFi002
07JFi0D0];WM1@3;b]T30<g:e`D0`/oT1P2`c>l40:K9lP@0Y/Sb1@2`i_P30;[`m0@0W[k_102G/>P3
09N^iPD0WKO[0`2Q^^/40::kj`D0Y;k/102U_^`40:G0k@@0Y/3/1@2U`^h40:K2kPD0Y/7]102W`nd5
0:O2k@@0YlG_102Xa^l50:S8l@D0ZM7e0P2Zd_D30:_?l`@0[LW^102MUld409ZEcP@0VIWB0`2JXm/5
0:Nmj@@0Y[_X102W_>T50:Jkj0@0XkWX102N]>P4092[j0<0N9[V0`1/TnH5092fl080e>oU00@00000
0=Cci@3DlnD0e??U0`2ngNl30;??k`@0ZlC/102W`>/90?ooo`030000003oool0oooo00D0oooo000C
0?ooo`030000003oool0oooo0080oooo0`00000N0?ooo`@0S:?T00<0IHkU08JNh`26W^<00P26W^<3
0;Big@80`;kH0`3;b]T30<g:e`80clWD0`32cn@30<7?i@<0/<c_0P2/cO440:K9lPH0ZMOh0P2jl?@5
0:kKm`<0W[k_0`2G/>P409RcjPD0WKO[0`2Q^^/40:>nk0@0Y;k/1@2T`>d40:G0k@P0YL;^1P2V`Nd4
0:K3kP@0Yl?]2@2WaNl50:O7l0@0Z=3e102YdOD50:_?l`D0XI_>0`2MUld409ZEcP@0VIWB102X_nX4
0:Nmj@D0YkkZ102W_>T50:Fkj@@0XkWX0`2N]>P4092[j0@0N9[V0`1/TnH2092fl0<0[Lga00@0e??U
0000003DlnD0e??U0P3>l>X50;??k`D0Z<7/102W`>/80?ooo`030000003oool0oooo00D0oooo000C
0?ooo`030000003oool00000008000008P3oool308bSi080IHkU1026W^<50<2nf0@0cL[G103?bM@6
0<7?i@D0[<ga1@2TcoH40;?]m`@0]_3e102C_?<308n^j`<0TjkY102H/nX509nkk@<0XKg/102S_^`9
0:C0k@@0YL7^102U`^h50:K1k@D0Y/C^102V`nh40:K5k`@0YlG_1`2Wao030:O?m@@0Z=3e1@2Yd_D4
0:BQdP@0XI_>102MUld309ZEcPD0Y[gZ102X_nX40:JmjPD0YkkZ102V_>T40:Fkj@@0XkWX102J/NP4
08^Vi`@0NIWU0P1nXNT40:g=l@<0`^;_00<000000<k`jP3>l>X00`33i>l40:c6k@@0Z<7/1@2W`>/7
0?ooo`030000003oool0oooo00D0oooo000C0?ooo`<000009@3oool308NOh`80IXkT102HYn030<2n
f0@0b;oB103?bM@20=78dPL0`LoU1@2Yco@50:SQn`<0]_3e102Ofo`409>ll`<0Sjk[0`2C[^T409bi
k@D0Wk_]0`2Q_N`40:>ok@@0Y<3]1@2T`Nd40:G1kPD0YL7]102Ua>l40:K4kPD0Y/C_102VaNl80:O7
l0H0Yloe1@2WdoL40:JVeP<0Y:7B1@2QVlh309fGc@@0X[KW102V_NX50:Jkj0@0Y[gZ1@2V^nT40:Jl
j@<0YK_Y1@2Q]nP409Zaj0<0RjKW101iVND407jQj@@0`^;_0P3=l>/00`000000`nC_0<?Tk`030;KD
l0@0[<K]102X`>/40:O0j`L0oooo00<000000?ooo`3oool01@3oool001@0oooo00<000000?ooo`3o
ool09@3oool308NOh`80IXkT102HYn050<RodP80cKo<0P3?bM@40=78dPL0`LoU0`2Yco@30:OGn0@0
[O7f102Sl?H309oKo0<0Tkcc102<[nd309Jdk@@0W;W]1@2P_^h40::okP<0Xko]1@2T`>h40:C1k@D0
YL7]302Ua>l50:K4k`@0Y/Oa102Wao050:K?m@D0Y]?g1@2X[=X40:JVeP<0Y:7B102QVlh409n/h@@0
X[KW102V^^P50:Jkj0@0YkcY102V^nT50:Fkj@<0Y;WX102Q]nP409Zaj0<0RjKW101iVND509Jfk@80
`^;_00@0cO3[0<ccj`3<ln/000001@2fe?050:W2k0@0Z<3[102W`>/70?ooo`030000003oool0oooo
00@0oooo000;0?ooo`D000001@3oool2000002D0oooo0`27Wn<306J>i080V:OP0P2W[M`30<RodP@0
cKo<103Ab=840=;6cPD0`LoU102WeoP30:kWn@<0Xo3f1023fOl307Vkn`<0PJka102<[nd309Jdk@@0
WKg_1@2P_^h40:;0k`@0Xl3^102T`^l40:C2kPD0Y<C`102Ua>l40:G3k`@0YLC_1@2Vb?440:K7l@D0
YLof1@2UdoP40:R_g@@0Z:cJ102VY]H30:BQdPD0WZCI102O[>440:Rmj0@0Y[[X1@2X_nX40:Nlj@@0
Y[gY102U^nT40:Bij0@0W[CX102E[NL308NRiP@0P9kV102F]^d00`3=l>/0c??[0<ccj`020<ccj`03
0<?Yl0000000`nW`00@0[LS]102Y`^`90:O0j`H0oooo00<000000?ooo`3oool0103oool000d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`<0QIgS0P1/T>@50:N]g0030<Ro
dP3=_l`0cKo<0080cKo<0P3A_LL20=78dP@0d/K>0P3C`/T30<7?i@<0`loS0P2^ioT40;Wbl`80`N[a
0`2mb^D206Jbn`<0NK_k0`21[_4308b_k@@0Uk_`102M_Nl50:31l0@0X/3_102R`o040:C2k`@0Xl?`
1@2Ta?040:C4k`@0YL?_102UbO840:K8l@D0Y<kf1P2SdoP40:Rag`@0Z:oM0`2X[=X509nJc`<0WYkC
102NY=T209n/h@<0ZL7[102X_NP40:O0j`@0Z;oZ1@2V_NX40:Jmj@<0YK_Y1@2R^NP409jdj0<0UJgW
1027X^H4082NiP<0/=3a1P33jO000`2feo4000000;KGl@030:g8k@D0Z<3[2@2W`>/50?ooo`030000
003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08`3o
ool308FMh`80K93T102W[M`40<foc0@0dKg7103Ba/h40=?2b@@0`loS0`3:cmh20=G>dP80`N[a1P2m
b^D306Jbn`80FZGg0`1g[_D408bflP<0Uk_`102L`?450:31l0@0XL?a202R`o040:?3l0D0Y<G`102T
a>l40:C:m0@0YLWb1@2Sc_L50:;Bn@D0Yk7O102X/Ml30:R_g@@0X9W=102OV/l409jNd`<0WZCI1@2Y
`N/50:Jnj`@0Yl3[102V^nT40:JmjPD0YK[X0`2T^^T40::ij0D0V[7W0`2@Z>D408NQi0@0SZ_Y0`33
jO030<Sck@@0]]Oa00<000000:W2k02Y`^`00P2Y`^`40:S0j`T0Yl3[1@3oool00`000000oooo0?oo
o`040?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo0`25WN<3
06b@i0@0/k7F0P3=_l`40=6ma`80dk[10P3Ba/h40=?2b@<0eKg2103:cmh30=G>dP80flK400@0g;bj
0;g:i@2mb^D0_L[U0`2g[]0307BKj@80EYgc0`1g[_D408Vmn0<0U/3d102L`?4509k3lP@0XL?a102Q
a?440:;3l0@0XlKb102TaO060:;;m@<0Y<[d1@2RcoL50:7An@@0YZoM102W/Ml40:Rag`@0XIS;0`2P
VLd409nJc`@0WYkC1@2Xa>d40:Fkj@@0Y[k[1@2V^nP40:Jkj@@0Y[cY102U^^P40:Bjj@@0X;KX102J
/NL4092Xi@<0Qj7T1@2Ua>l40<Sck@80`^_a0`2]b>h00`000000[LS^0:W2k0030:W2k0d0Yl3[103o
ool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0:0?ooo`8000008`3oool3
08>Ni0<0LiGU102c/MH40=6ma`@0dk[1103C`/T40=Fm`P030=Jh^`3:cmh0b/oN00<0eLkB0P3Ka/@3
0=bl^PH0]jk@0`1dVnT305JMl`<0K[;i0`29_OP309K0m0@0VLCe102N`o8509o6m0@0XLCa102QbO@4
0:?6lPD0X<gg1@2NcoT40:3?n0D0X=3h102VZm/40:J_g@<0Yk7O1@2RV</30:6Hb`@0X9W=0`2OV/l5
0:O4kPD0Y[WW102U^nT40:Nmj@@0Y[_X1@2W_^X40:Jlj@<0YK[X1@2S^NP40:2fj0<0V[7W102@Z>D4
08jWiP<0YLC_0`2li?<30<;[l@80]MOa0`2]b>h00`000000Z<3[0:S0j`030:S0j``0Yl3[103oool0
0`000000oooo0?ooo`040?ooo`00303oool2000000h0oooo00<000000?ooo`3oool08@3oool308>N
i0<0LiGU0P2c/MH20;^bd080dKg71@3C^/400`3E]k/0dl;90=?2b@040=Fm`P<0e[Rk0`3Ec]830=_6
a0<0g;bj00<0fkNe0;N^d02g[]000P2g[]020;RUa@<0TYGC0`1hVnL307:`n0<0P<3l102@aOX309W4
m@D0V/Wh102Oa_@509g;m`<0XLWd1@2McOP409c?nP@0W/oi1@2Pc?L50:FVeP@0YZ_K0`2V[md40:BI
bP@0XYS;102QV</30:2Ic@D0Y/C^102W^NH40:Jii`D0Z;oZ102W_NT40:Noj`@0YkkZ1@2U_>T30:Fk
j@@0XkWX1@2M/nL309J[i@@0SZCT102>YnH30;cTl`<0`oC_1@2eeo430:W2k0030000002X`>/0Z<3[
0080Z<3[3@2W`>/30?ooo`030000003oool0oooo00@0oooo000M0?ooo`030000003oool0oooo0200
oooo0`23W^@307>Ei@D0^k;@1@3C^/430=Fg^`@0eKg2103F^;/20=Vd]0<0flK40`3L_;X30=^g]@80
]jk@0`2hYLD409:Ed`<0N9_W0`1b/?P30830o0@0QlGl102AbO/4097;n`@0V<cj1@2FcO/909[>nP<0
W<oj1@2QaO840:FQdP@0YJKF102VZm/40:FJbP<0Y9W:102RV</40:6Hb`D0Y/;^202W^NH40:S2k0@0
Z;oZ1@2V_^X40:Noj`@0YK_X102U_>T40:Fkj@@0XKOX102M/nL409J[i@<0SZCT1@2P_Nh40<?dk`80
_^_c1@2/anh30:W2k0030000002W`>/0Yl3[00h0Yl3[103oool00`000000oooo0?ooo`030?ooo`00
7P3oool00`000000oooo0?ooo`0P0?ooo`<0OYoX0`1fV>H30;^bd080`K;<103C^/430=Fg^`030=Jc
]P3E_L80eKg200@0e[Rk0`3I];@00`3M]:h0flK40=_6a0030=bl^P<0fkNe1@2hYLD409:Ed`@0VYWB
0`2>Y^D408Fim`<0QlGl1@2>aOX3097;n`D0U<Wi102FcO/509_8m`@0XZkP102Q^n/40:FMc@@0YJ7B
0`2UY]H50:JLb`<0YI[:102TVLX30::Hb`D0Y/3/1@2X^^H40:NiiP@0Yl;]102X`^`40:Jlj@@0Y[kZ
1@2V^nP40:Fkj0@0YK[X102S^>P40:6gj0<0WK?W1@2BY^<3096Wi0<0X;g^0`2gi?D30;k[l`80/]?a
102/anh30:O0j`030000002W`>/0Yl3[0100Yl3[0P3oool00`000000oooo0?ooo`030?ooo`007`3o
ool200000240oooo0`1nWnP307JHiP030;^bd031//`0`K;<0080`K;<0P3C^/430=Fg^`<0e[>f103F
^;/30=Vd]0<0gKB^0`3L_;X40=^g]@030=Zg]P2hYLD0^:G50080^:G51@2VVlX409ZIdP<0SZKU102K
YM`409:fl0@0WJcR102G_O840:2/g`@0WK_^1@2SXmD40::^h0@0Yi_:102UWLd30:FQdP@0Z9o=102V
W</40:FJbP<0Y9W:1@2V_n/40:Rki`@0Z;[V2@2W`^d40:Jjj0@0Y[cY102W_>T40:Jkj0D0Y[gY102U
^^P30:>hj0D0Wk?V0`2I[>@409:Vh`@0TJOT0`2gi?D30;kdl0D0/]?a102X`N`30:O0j`030000002W
`>/0Yl3[0100Yl3[00<0oooo0000003oool0103oool00240oooo00<000000?ooo`3oool07`3oool2
07BPk@<0MYSV1P31//`40=Fg^`<0e[>f00@0ek6b0=Jh^`3F^;/0e[Rk0`3I];@30=fd[P030>:fZ`3L
_;X0g;bj00<0fkNe0`3J]kH20;RUa@80^jS6102VVlX409ZIdP@0YIk?102KYM`40:BQdP@0WJcR102T
XM840:2/g`@0YYk=102SXmD20::^h0<0ZIg:0`2WVlX40:FMc@@0Zj?@0`2XWld40:JLb`@0YI[:1@2W
`>/80:Rki`@0Y/7]102W`^d50:Nji`@0Y[[X102X_nX40:Nlj@@0Y[kZ102V_NT40:Fjj0@0XkSX102O
/nH409V/i0<0TZKS1@2P_Nd00`2nm?00^nOd0;_Wm0030;_Wm0D0ZlG]102X`N`30:O0j`030000002W
`>/0Yl3[00l0Yl3[00<0oooo0000003oool0103oool00280oooo00<000000?ooo`3oool07`3oool2
07BPk@<0LYWY1031//`20<Bbb080eKNk103F/kH20=Na/P040=Jh^`3I];@0fKBd0=Vd]0@0gKB^0P3R
]Z/40=^g]@<0f[Nf1@2kZ<H30:JKbPD0[:7;102UW/l40:bQc0@0Y:7B102[Wl`40:BQdP80X:cO0P2[
WlX40:JNc@<0Xj?E1@2YWLX40:NKbP80YIg=0P2]Z]@30:^Sd0@0Z9o=0`2VW</50:S1k0D0Yk_W102X
^nL40:O1k0@0Y/7]202W^^L50:O1k0@0Z;oZ102V_NX40:JnjPP0Y;WX102S^>P409^]h`@0UZOR0`2D
Z><30:2mk@040;KXmP2km?80^oCb0;_dlP@0[lk`102[aNd80:O0j`030000002W`>/0Yl3[00l0Yl3[
00<000000?ooo`3oool00`3oool002<0oooo00<000000?ooo`3oool07P3oool307BPk@<0LYWY0P31
//`40<Bbb0040=Fg^`3F/kH0e[>f0=Jc]P<0ek6b103I];@30=fd[P<0h[J[00<0i[^Z0=^g]@3K]kD0
103J]kH00`3H^[/0^jS60;^XaP020;^XaP@0[jK?102/XL/20:FNc`<0/ZO>102/XL`20:BQdP80/JK=
102[Wl`30:BQdP@0Zio:102VW/d40:jSc0@0ZIg:102WVlX40:fZe0@0Zj?@0`2XWld50:S3k@@0Yk[W
102W^nL50:O0k0@0Yl7/102W^nL40:Nji`P0Yl7/1@2U^nP40:JmjP@0YKWW1`2T^NP509nai@@0VjgS
0`2FYn8409BXh`040;KXmP2km?80^oCb0;_dlP<0]]od102_c_040:S1j`L0Yl3[00<000000:O0j`2W
`>/03`2W`>/00`000000oooo0?ooo`030?ooo`00903oool2000001l0oooo0`1PW_8205jDk0H0a;;8
103F/kH30=Na/P030=Va/03I];@0fKBd00@0gKB^0`3R]Z/20>JkZP040=^g]@3J]kH0f[Nf0=Zg]P<0
f;Zk0P2kZ<H20;V_c`@0[jK?0`2/XL/50;:WcP@0[:7<102aY/d40:^Oc0@0/JK=102[WlX20:JNc@80
/ZcC102^Xl`30:VMbPD0[k;K102]Z]@30:^Sd0D0Z<C^102W^NH40:Nji`P0Yl3/1@2X_>P40:Nki`P0
Yl7/102V^^L40:Fkj0D0Y[_X0`2U^NL50:Fjj0<0XkKV102O/ND409^]h`@0Uj[S0`2Sa?020;C`mPD0
]]od1@2Y`n`30:S1j`P0Yl3[00<000000:O0j`2W`>/02`2W`>/30?ooo`030000003oool0oooo00<0
oooo000V0?ooo`030000003oool0oooo01d0oooo0`1PW_8205jDk0@0a;;80P36//L20=Jc]P@0ek6b
0P3I/K00103I];@0gKB^0=fd[P3M]:h30>:fZ`<0i[^Z103J]kH30=Rj^`@0^Jo?102_Y/l40;6^e@@0
/ZO>0P2/XL`30;B_d`@0/JK=0P2[Wl`20;Bae@@0/JK=0`2[WlX40;:/d`@0[Z?<102_^n840:nbf`@0
[J[D1@2Wa>h80:NiiP@0Yl7/102W`>`40:Nlj0@0Z;cX1@2W`>`40:O1k0@0Yk[W102V^^L40:NnjP@0
Y[_X102U_>T40:Fjj0@0XkKV102L[N8409RVh0@0Uj[S0`2dl?H30;S`m0@0[<W^102Y`n`<0:O0j`03
0000002W`>/0Yl3[00H0Yl3[203oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo
0?ooo`0N0?ooo`0403ZCl@1NU>`0GYC/05jDk080a;;81036//L0103F/kH0ek6b0=Na/P3G/K830=Va
/0@0gKB^0`3R]Z/30>JkZP030>Ro[03J]kH0f[Nf00@0f;Zk00<0eK_10;V_c`2i[ll00P2i[ll20:nV
c`80ZjoK102a[]D30;:WcPD0]:oC102aY/d50;Bae@<0/JK=102c]]`40;:/d`80[Z?<0P2]_nL40:nk
hP<0[k;K1@2V`nh90:NiiP@0Yl;/102W`N`80:Nlj0@0Yko[102W`>`80:Nji`D0Yko[102W_^X40:Fk
j@@0YKcY0`2U^^P509nai0@0W:gR0`2HY^050:SDm`030;S`m02ae?80/MCb00<0/MCb0`2/bNh50:S0
j`/0Yl3[00<000000:O0j`2W`>/00`2W`>/;0?ooo`030000003oool0oooo0080oooo000X0?ooo`03
0000003oool0oooo01h0oooo00<0>Y?a02]oj00[OnP01P36//L40=Na/P<0fK6`00<0g;B_0=fd[P3M
]:h00`3R]Z/40>JkZP80j;n/103H^[/30=Fk`@<0^Jo?1@2[[m/30;6^e@@0/KKL102d[m<50;:hgP@0
];7E102__><40;>fg0<0/ZcC1@2]_nL30:nkhPD0Y[o/102X^^H40:NiiPD0Yl;]0`2W`^`90:Nlj0P0
Yko[102W^nL40:Nji`@0Yl3/102W_n/50:Fij0@0YK_Y102T]ND30::ci@@0Wk7T102L[N8409^bj0<0
Z=Cg00<0/OCb0;GTmP2ei?H0102ae?850:S1k0l0Yl3[00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`020?ooo`00:@3oool200000200oooo0P0[OnP40<Jba`80aKC:0P3G/K840=Va/080g;B_
00@0gKB^0>:fZ`3R]Z/0h[J[0`3V^jX30>Ro[0040>S3/03H^[/0f;Zk0=Rj^`<0eK_1102f/]H40:^_
f`@0ZKKR102a]]`40:bji0@0/[SN1@2Z_>H40:nlh`<0/kKL1@2Y_nT40:Nji`@0YKcY102Y_>P40:Rj
iPP0Yl;]102W^nL40:Nlj0T0Yko[102X_>P40:Nki`@0Y[o/102W`>`40:JhiP@0YKWX1@2V^NH40:Be
i@<0X[?U102LZ=h409RUgP@0Vk;X00<0/OCb0;GTmP2ei?H00`2ei?H40:W4kA40Yl3[0`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo01h0
oooo00@005S102]oj036//L0a[;71035]<X0103G/K80fK6`0=Va/03I/K030=bd[`@0h[J[0`3V^jX2
0>Ro[0<0j<>`00<0f;Zk0=Fk`@3E^l400P3E^l400`3A^l@0][;F0;JbeP020;JbeP@0Yk;Q102Y]^84
0:RiiP@0[;[T102X^nL40:ZliPD0YkcX102W_>T40:Rli`@0Yk[W102Y_nT40:Vlj0@0Yl7/102W`^d4
0:Nji`@0Yk_W202W_n/50:Nlj0@0Z;cX102V_n/40:Jok0@0Y[WV102V^>H40:Nlj@@0Y[WV102T]ND4
0:6_hP@0W:SN0`2HYMh40:[Zn@80/_;e1@2/b^l@0:O0j`P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0N0?ooo`03001H`@35]<X0aKC:
00@0aKC:103I/K030=bd[`030>6k/@3R]Z/0h[J[00<0i[^Z0`3X_j`30>S3/0@0eK_10`3A^l@20;Jb
eP80][?F102W/^440:Jgi@@0Z;WV102W^nL40:Rki`@0Z;cX102W_>P50:Vnj@<0Z;cW1@2X`>/40:Vo
j@@0Y[o[102W`N`40:Rji`@0Yk[W102X`>/40:Noj`P0YkcX1@2W_^X30:Joj`D0Yk[V102V^NH40:Nn
jP@0YkcY102S]ND40:>di@<0XJoR102LZ=h50:;;m@030;;bm@2`e?<0/=Cc00<0/=Cc102X`N`<0:O0
j`/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`000000
oooo0?ooo`0O0?ooo`<0aKC:0`30^M<20=Va/0@0g;B_0P3Q^k40103R]Z/0i[^Z0>JkZP3V^jX20>Ro
[0@0j<>`00<0i/Bd0=Fk`@3E^l40103A^l@50;JceP@0ZKCP102V]nD40:Nji`@0Yk_W202X_>P40:Rn
j@@0ZKkY102W_nX40:S0j`D0Y[cY102V_n/40:Rki`@0Z;[W102X`N`40:S0j`P0YkcX202W_^X40:Nj
i`@0Yk[V1@2V_n/30:NnjPD0Y;CT102S]ND30:>di@@0VjCK102K[^D40:KclP80/^;g1@2Ya>d30:S1
k0T0Yl3[3`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000^0?ooo`03
0000003oool0oooo01l0oooo1P30^M<0103I/K00g;B_0=bd[`3L]:l30>6k/@<0i[^Z0`3X_j`30>S3
/0<0i/Bd103A^l@20=2ja@<0][?F0P2j]=@40:Vdh0@0Z;ST102W^^L40:Rki`@0Z;cX102W_>P40:Rn
j@@0YkcY102W_nX40:Nkj0@0Y[cY1@2Y_NP30:Rki`T0Z<7/102W^nL40:Nlj0P0YkkZ102W^nP40:Nj
i`@0Y[k[102V_n/40:Fdh`@0Y;CT1@2S[=h309jUfP@0VjCK0P2K[^D30:7/n@030;;Rm`2[bNl0ZlW_
0080ZlW_102Ya>d40:O1k0@0Yl3[503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0040oooo000_0?ooo`800000803oool50<2id`@0g;B_0`3Q^k400`3U`k@0i[^Z0>JkZP020>Ro[0@0
j<>`0`3Va;@00`3Sa;P0dK_40=6ka0040=2ja@D0^[CD0P2Y]>020:jegP@0Z;ST102X^^H40:Rki`@0
Z;cW102W_>P40:Rlj0@0YkcY102X_>P40:Nkj0@0ZKkY102Y_NP40:O0k0@0Z<7/1@2W^^L30:Nki`D0
Z;oZ102W_^X40:Nlj0@0Yk_X102V_NX40:Jnj`@0Y[GS102U]><40:Fch`@0XjcN102NYMX309^Tf`03
0:7/n@2^k_L0[^kg0080[^kg0P2]d?840:_9k`@0Yl3[102W`N`H0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool07P3oool20<2id`<0/[oT
0P3L]:l40>6k/@80iL>d0`3X_j`30>S3/0<0i/Bd0`3Sa;P50=2ja@030<njaP2j]=@0^[CD0080^[CD
1@2^]Mh40:^hh`@0Z;[V102Y^nH40:Rli`@0ZKcX102X_>P40:Vnj0@0Z;cX102Y_nX40:Vnj@@0YkkZ
102W`>`40:RjiP@0Yk[W102X_n/40:RojPP0YkcX1@2W_NT40:JmjP@0YkOT102V]N<40:FhiP@0YK?S
0`2S[=h409jUfP<0X=Cj0`2Pl_440:g@lPD0Z;o[0`2W`>/L0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00@3oool00380oooo00<000000?ooo`3oool07@3oool60;:oi0040=bd[`3Q
^k40hK^a0>6k/@<0iL>d0P3XbkT40>S3/080i/Bd103Sa;P0103Pa;`0d;[50=2ja@3@^/D30<njaP80
^[CD0P2m]]<30:jegP80/KKL102[^><40:Zji@@0ZK_V102Y_>L40:Vlj0@0ZKgX102Y_^P40:Rnj@@0
ZKoZ102W_>P40:NnjP@0Z;_W102X^^H40:S0j`@0Z;o[102W^nP40:Nlj0@0YkcY102W_NT50:Nhi@<0
YkOT1@2U^^P40:FhiP<0YK?S102LYmh409fhj`030:3bl@2^f?H0[]Sf00<0[]Sf102Y`N/40:Rojb00
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`00<`3oool00`000000oooo
0?ooo`0N0?ooo`@0/[oT103Q^k420>G3]0<0j<^i00<0jM2m0>S3/03X`k000`3Va;@30>?4^0<0h<Bl
00<0d;[50<njaP3?^/H00P3?^/H50;ffd`D0/KKL102]^>440:Zji@@0Z[_V202Y_>L40:Vmj0@0Z;cX
102X_^T40:Rki`@0YkcX102Y_>L40:Rki`P0Z<3[1@2W^^L30:Nkj0D0YkgY0`2W_>T40:NiiP@0YkSU
202U^^P50:6Re@<0WZ;G102LYmh00`2Bk^l0[^;i0:kRn@030:kRn@@0Z/G]102Y`N/T0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00@3oool003@0oooo0P00000O0?ooo`@0RL3i0P3Q
^k430>G3]080j<^i0`3Yd;d30>K4]0<0hlBh103Pa;`40<njaP80ck_70`2m]]<20;nfd@<0/KKL0P2e
]]T40:fhh@@0[;WS202Z^nH80:Vli`@0Z;cX102Y_>L40:Rki`@0ZKkX102Y_>L40:Roj`D0Z;WV102X
^^H40:Rnj@@0Z;gY102W^^H40:Nji`<0YkWV102V^NL40:Fjj0@0XjGG102QX]D309jRe`@0T^Wh0P2X
joT50:_:l0<0Z/G]:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0040oooo000f
0?ooo`030000003oool0oooo01h0oooo0`29`?T00`3Q^k40iL>d0>G3]0030>S;^@<0jM2m0P3We<<4
0>?4^0<0h<Bl0P3Ma/420<njaP@0ck_71@2o]]440;Fff@80[KSQ0`2`]mh30:bih`D0Zk_U0`2Z^nH5
0:ZliP<0ZKcW1@2Z_NL30:Vli`D0ZKoY0`2Y_^P50:Nnj@@0ZKWU102X^NH50:RojP<0Z;kY1@2W^NH3
0:NjiPD0YkSU0`2V^>H40:Jii`@0YJWI102SYML30:6Re@D0VM_n00<0Z>_i0:[>l`2Zc_<00P2Zc_<4
0:_:l2`0oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool003L0oooo00<000000?oo
o`3oool07P3oool203^Wm@<0iL>d0P3XbkT30>W@_@<0imC300<0i=S:0>?4^03Sa;P00`3Pa;`30=g6
`@D0ck_70P3>_<T20;nfd@<0`[O@0`2e]]T50;2ggP@0[[WR202[^nD40:ZliPP0Z[gW1@2Y_NP30:Vo
j@D0Z;_W102Y^nH40:Vii@P0Z;oZ102X^>D40:NiiP@0Z;SU102W^>D30:JhiPD0YZgL0`2UZMT40:>U
e`D0W/Se00<0Vnoe0:[Bm@2Zd_D00`2Zd_D30:[>lc00oooo00<000000?ooo`3oool01P3oool10000
0040oooo0@3oool003P0oooo00<000000?ooo`3oool07P3oool303^Wm@<0j<^i0`3Yd;d20>OD``<0
i=S:0`3Pa;`40=g6`@040=[8b03?^lL0ck_70<nka`<0c[c91@32]m040;Rfe`<0/;ON0P2c]]`40:ji
hP@0[;[S102[^nD40:ZkiP@0Z[gW1@2Y^nL40:ZkiP@0Z;[V102Z_NL40:VkiP@0Z;kY102X_nX40:Rg
i0@0Z;SU102X^ND40:Rhi@@0Yk7O0`2W/=h40:J]g0<0YJWI1@2P]nT208S[k0@0ZMKg>03oool00`00
0000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>@3oool200000280oooo00@006nm0>W@_@3Y
d;d0jM2m0`3We<<20>CHbP<0g]cD103Ma/430=[8b0@0c[c90P3>_l`30<:gd080`kS?102h]]L50;>f
g0@0/;OO102/^^<40:bji0@0Z[_V1@2Z^^D40:^liP@0Z[_V202Z_NL40:Rlj0@0Z;kY102X]^<40:Rg
i0@0ZK[V102X^ND80:Nag`<0Yk3N102SZ=X40:6^h00307WTi@2XfOT0Z=Wi00<0Z=Wi>`3oool00`00
0000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00>`3oool00`000000oooo0?ooo`0Q0?ooo`04
001U[P3We<<0imC30>OD``80i=S:0`3Ng=@20=CQh@80gLK1103Jb<P00`3FcM40c[c90<jlb@040<jo
c0030<:gd033^<l0`kS?0080`kS?102k]]@30;>fg080][GH102`]ml40:jhh@P0[;[T0`2Z^^D20:^k
i@@0ZkcV102Z^nH40:Zmi`@0Z;WU102X_>P40:VfhP@0Z;KS102Y^nH40:VjiP@0YjoN1`2W/Ml40:BV
e`@0XjSJ0P2Q[^00101bhND0Y]cj0:KLnP2Vg?Xo0?ooo`030000003oool0oooo00@0oooo0@000001
0?ooo`40oooo000l0?ooo`030000003oool0oooo0280oooo00<0Fk7k0>CHbP3Tf<X00`3Ng=@40=CQ
h@@0f/S80`3FcM450<joc0@0`kS?0P34^m440;^fe0D0][GH102b]M/40:jhh@@0[KWR102/^^@50:^k
i@@0Z[SS102Z^nH40:Vgh`<0Z;WU1@2Z]n830:VfhPP0ZK_V1@2W[M/30:N_gP@0Yk7O102UYMH40:BV
e`<0XjSJ00<0L^7U0:KLnP2Vg?X0@`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool10?oo
o`00?@3oool00`000000oooo0?ooo`0S0?ooo`<0M;[l103DhN420<3Ul@80f/S80`3FcM420<kEgP<0
c[o<0P3<a=<20<>hc`@0a;_A0P2k]]@20;fgd`<0][GH0P2h]MH40;:ef`@0/;GM102]^N850:bhhP@0
[;KP0`2Z^><50:^fh@<0ZKOS102[^><40:ZghP@0Z[WU102Y^nH40:NZf0@0YjgK0`2W[mh50:JVe@<0
YJGF102TY]L00`1ch>X0Xmol0?ooo`170?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40
oooo000n0?ooo`8000009@3oool308Nnn@D0`>Ga0`3FcM440<kEgPD0c<CC1@34^m450;fgd`D0^;GF
0P2b]M/20;Fde`@0/;GM102_]Md20:bhhP<0[kCM0`2/]^040:ffg`@0ZkKQ102/^>840:^hh`@0ZKCQ
102Z^ND40:RWe@@0Yj[H0P2W[M/20:Z[f0<0Z:OF102VY]D507WQlP0309oPo@3oool0oooo04T0oooo
00<000000?ooo`3oool00`3oool100000040oooo00100?ooo`030000003oool0oooo02<0oooo102D
`?D204>RmP<0V>7m103>eMh20;cNl0<0c<CC0P38cMh30<Bkd@80a<;H0`2m]m<20;nkeP@0^;GF1@2e
]=L40;>cf0<0[kGM1@2_]=d40:jcg0@0[KKO102//mh40:bhhP@0ZJkK102Y]>440:VUd`@0Z:OE0`2W
Z]P50:Z[f0<0Z:OF1@1ihO800`2Kh?d0oooo0?ooo`1=0?ooo`030000003oool0oooo0080oooo0@00
00010?ooo`00@@3oool00`000000oooo0?ooo`0S0?ooo`@0WL3a0`1c]OX305;5m@D0_=k`1@38cMh5
0<C2f0D0_k_F102k^=H20;Fde`<0^;KG0`2c/mP40;:bf@<0[kCM0P2`/=P40:jcg0@0[JkI102//mh4
0:^ZeP@0ZJkK102/Ym<40:VUd`<0Z:OE102//]`40:Z[f00307COk`2Gg?h0Umcn00<0UmcnD`3oool0
1@000000oooo0?ooo`3oool000000040oooo00120?ooo`030000003oool0oooo02@0oooo0`2M`?44
08jlm@80C:Wi00<007Bm08gLo`2=g?l00`2=g?l40;SJl@<0a<;H0P2ocnH30;nkeP80_lSQ0`2k^=H5
0;Rfe`@0][CH102b/]T50;2`f080[[?L0P2`[mH40:f^f@@0[ZcE102[Z]H40:n_f0@0[:OC0`2YYM<4
0:jli0@0[;;L00<0J]_X09KIoP2FfOh00`2FfOiG0?ooo`040000003oool0oooo00000040oooo0013
0?ooo`8000009@3oool40:?0kP<0S[ce1@1n^_T0100]Wo00>;K[03Rfj`0h]^/30;SJl@D0_loV102o
b>420;^heP80_<CP0`2h]]L20;[4h@@0][CH102e]MT40;2`f0D0/:oF0P2][]T20;Bgg0@0[ZcE0P2[
Z]H20;>oh`<0[joH102/Ym<40:k<k`<0[[cT0P1LeN0509OEoEX0oooo00@000000?ooo`3oool00000
0@3oool004D0oooo00<000000?ooo`3oool08`3oool40:G0k0@0W;k`102G__<206jho0<01I7D0`21
fOh40:3No0<0_lSQ1@2la>050;[4h@80][CH0P2ib>H40;Fef@@0][_M102`[mH40;Bgg0@0[ZcE102c
_n<30:n_f0D0Y]kk0`2^c>l2053>fP0404c;g02Id?/0VM3k09W@nel0oooo00<000000?ooo`000000
0@3oool004H0oooo00<000000?ooo`3oool08`3oool40:G0k0D0Xko]0`2G__<309:nm@@0IKOl00@0
9:?X0:3No02Pg_`0X=kl2@2ZgOT40;[4h@D0^LSV102deO440;Jkg@@0]Lo]0`2d]m`50;3Hm@<0/koS
1@29i?T205G>j@@0WL[g0`2KcOUS0?ooo`4000000@3oool100000000A`3oool00`000000oooo0?oo
o`0S0?ooo`D0Yl3/102V`>`30::okP<0T[ke1@2@_oH306Fio@<0;J_[0`1Bao830:[Mn@D0X>3l1024
go`40;CEl@@0VN?m0`2ecnd508gTn`<0/=Se0P1Ne>L01018an80OM;o07gBo`1md_l509o8m6X0oooo
0P00000004P0oooo0P00000U0?ooo`@0Yl3[1`2V`>`80:6ok`@0TKof0`1]_Od407[1o@<0C;_g0`0o
_^T308COo0D0ELg]1@17`^`507?<o`@0UlSh102S`o040:76lVd0oooo0P00000004X0oooo00<00000
0?ooo`3oool08`3oool70:O0j`P0Y/3/102Q_nl40:;0kP<0U/3d1@2L`O8308[3nPD0V<;e0`25a_d5
09W4mP@0X/;_0`2Na?<40:C1kP@0Xl?`L03oool200000000B`3oool00`000000oooo0?ooo`0R0?oo
o`d0Yl3[2`2V`>`40:?0k@@0YL3/102Q`Nl40:G0k@@0XL7`102U`>d30:;2k`D0Y[o/0`2T`Ni_0?oo
o`@000000P3oool004`0oooo00<000000?ooo`3oool08`3ooolD0:O0j`<0Y/3/102W`>`40:G0k0@0
Y/3/102U`>d40:K0k0<0YL3]1@2W_n]a0?ooo`@000001P3oool004d0oooo0P00000T0?oooaL0Yl3[
102W`>`50:O0j`<0Y/3/302W`>]`0?ooo`@000002P3oool004l0oooo00<000000?ooo`3oool08P3o
ool[0:O0jfl0oooo1000000>0?ooo`00D03oool00`000000oooo0?ooo`0S0?ooobH0Yl3[KP3oool4
00000180oooo001A0?ooo`030000003oool0oooo02<0oooo8P2W`>]^0?ooo`<000005P3oool00580
oooo0P00000T0?oooah0Yl3[K@3oool4000001T0oooo001D0?ooo`030000003oool0oooo0280oooo
5`2W`>]_0?ooo`@000007@3oool005D0oooo00<000000?ooo`3oool08@3ooolD0:O0jfh0oooo1000
000Q0?ooo`00EP3oool00`000000oooo0?ooo`0R0?ooo`l0Yl3[K@3oool4000002D0oooo001G0?oo
o`8000008`3oool;0:O0jf`0oooo1000000Y0?ooo`00F@3oool00`000000oooo0?ooo`0Q0?ooo`@0
Yl3[K`3oool3000002d0oooo001J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
JP3oool400000300oooo001K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3o
ool4000003@0oooo001L0?ooo`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000>03oool0
05h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000?03oool005l0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000@03oool00600oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`<00000A03oool00640oooo0P00
000L0?ooo`030000003oool0oooo05<0oooo100000170?ooo`00H`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo04l0oooo1000001;0?ooo`00I03oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo04/0oooo1000001?0?ooo`00I@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo04L0oooo1000001C0?ooo`00IP3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04<0oooo1000001G0?ooo`00I`3oool2000001H0oooo00<000000?ooo`3oool0@03o
ool3000005/0oooo001Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool4
000005h0oooo001Z0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool40000
0680oooo001[0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool4000006H0
oooo001/0?ooo`800000403oool00`000000oooo0?ooo`0a0?ooo`@00000JP3oool006h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`@00000KP3oool006l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0Z0?ooo`<00000LP3oool00700oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`@00000M@3oool00740oooo0P00000;0?ooo`03
0000003oool0oooo0280oooo1000001i0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01h0oooo1000001m0?ooo`00M03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01X0oooo100000210?ooo`00M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01H0oooo100000250?ooo`00MP3oool2000000H0oooo00<000000?ooo`3oool04`3oool30000
08T0oooo001h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4000008`0
oooo001i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000900oooo
001j0?ooo`050000003oool0oooo0?ooo`0000002@3oool4000009@0oooo001k0?ooo`80000000<0
oooo0000003oool0103oool4000009P0oooo001m0?ooo`80000000<0oooo0000000000000P00002L
0?ooo`00OP3oool200000:00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0701872, 0.0272061, \
0.0035637, 0.0035637}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The solution of the PDE from a specified equation and initial/boundary \
values is a multistep process that makes extensive use of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s symbolic and numerical capabilities along with automatic algorithm \
selection.  Here are some of the key steps in the process:"
}], "Text"],

Cell[" Derivative orders are determined in each dimension.", "BulletedList"],

Cell["\<\
 Boundary/initial values are analyzed to determine which variable \
should be temporal.\
\>", "BulletedList"],

Cell["\<\
 Equations are discretized in space giving a system of first order \
ODEs in time.  The spatial grid is determined by an error estimate based on \
the initial conditions.\
\>", "BulletedList"],

Cell[" Boundary conditions are incorporated into the ODEs.", "BulletedList"],

Cell["\<\
 ODEs are solved using a solver that switches between explicit and \
implicit methods automatically depending on stiffness.  If the stiff implicit \
method gets used, the Jacobian is computed as a sparse matrix and a direct \
sparse solver is used to solve the necessary linear equations.\
\>", \
"BulletedList"],

Cell["\<\
 The data produced during the solution process is collected into an \
InterpolatingFunction.\
\>", "BulletedList"],

Cell["\<\
Define a function that will find the position of the wave crest for \
a given time.\
\>", "MathCaption"],

Cell[BoxData[
    \(Crest[t_]\  := \ 
      Module[{max\  = \ 
            FindMaximum[
              sol[\[Lambda], \ Mean[{\[Phi]\_1, \ \[Phi]\_2}], \ 
                t], \ {\[Lambda], \  .25\ t/7200}]}, {t, \ \ \[Lambda]\  /. \ 
            max[\([2]\)], \ max[\([1]\)]}]\)], "Input",
  CellLabel->"In[50]:="],

Cell["\<\
Find the positions of the wave crests for part of the simulation.\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(crests\  = \ Table[Crest[t], {t, \ T/5, \ 9\ T/10, \ T/20}]\)], "Input",\

  CellLabel->"In[51]:="],

Cell[BoxData[
    \({{1440, 0.04675442855551441`, 0.4993371730542802`}, {1800, 
        0.05844575694776054`, 0.5008256409122642`}, {2160, 
        0.0694131724968317`, 0.5019735950984853`}, {2520, 
        0.08036081338241742`, 0.5015759981223131`}, {2880, 
        0.09249015584806965`, 0.5023093629297414`}, {3240, 
        0.10403322006566665`, 0.5024770038539439`}, {3600, 
        0.11548363280824533`, 0.501349371196772`}, {3960, 
        0.12721894167709266`, 0.5016213642687652`}, {4320, 
        0.13898844625282936`, 0.5014580437683888`}, {4680, 
        0.15076456347900175`, 0.5007234292180398`}, {5040, 
        0.16266493193893095`, 0.49831480324456245`}, {5400, 
        0.17458283645181605`, 0.49612367632055754`}, {5760, 
        0.18614202663209753`, 0.4942519389056456`}, {6120, 
        0.19768525201160198`, 0.49057513086742816`}, {6480, 
        0.20904079985830706`, 0.4847998713555991`}}\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell["Make a plot of the crest position versus latitude.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[crests[\([All, {2, 3}]\)], \ 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.25057 5.86852 -16.1279 33.2975 [
[.04286 .50834 -12 -9 ]
[.04286 .50834 12 0 ]
[.18957 .50834 -15 -9 ]
[.18957 .50834 15 0 ]
[.483 .50834 -15 -9 ]
[.483 .50834 15 0 ]
[.62971 .50834 -12 -9 ]
[.62971 .50834 12 0 ]
[.77642 .50834 -15 -9 ]
[.77642 .50834 15 0 ]
[.92313 .50834 -9 -9 ]
[.92313 .50834 9 0 ]
[.32378 .02138 -30 -4.5 ]
[.32378 .02138 0 4.5 ]
[.32378 .10462 -36 -4.5 ]
[.32378 .10462 0 4.5 ]
[.32378 .18787 -24 -4.5 ]
[.32378 .18787 0 4.5 ]
[.32378 .27111 -36 -4.5 ]
[.32378 .27111 0 4.5 ]
[.32378 .35435 -30 -4.5 ]
[.32378 .35435 0 4.5 ]
[.32378 .4376 -36 -4.5 ]
[.32378 .4376 0 4.5 ]
[.32378 .60408 -36 -4.5 ]
[.32378 .60408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04286 .52084 m
.04286 .52709 L
s
[(0.05)] .04286 .50834 0 1 Mshowa
.18957 .52084 m
.18957 .52709 L
s
[(0.075)] .18957 .50834 0 1 Mshowa
.483 .52084 m
.483 .52709 L
s
[(0.125)] .483 .50834 0 1 Mshowa
.62971 .52084 m
.62971 .52709 L
s
[(0.15)] .62971 .50834 0 1 Mshowa
.77642 .52084 m
.77642 .52709 L
s
[(0.175)] .77642 .50834 0 1 Mshowa
.92313 .52084 m
.92313 .52709 L
s
[(0.2)] .92313 .50834 0 1 Mshowa
.125 Mabswid
.0722 .52084 m
.0722 .52459 L
s
.10154 .52084 m
.10154 .52459 L
s
.13088 .52084 m
.13088 .52459 L
s
.16023 .52084 m
.16023 .52459 L
s
.21891 .52084 m
.21891 .52459 L
s
.24825 .52084 m
.24825 .52459 L
s
.2776 .52084 m
.2776 .52459 L
s
.30694 .52084 m
.30694 .52459 L
s
.36562 .52084 m
.36562 .52459 L
s
.39497 .52084 m
.39497 .52459 L
s
.42431 .52084 m
.42431 .52459 L
s
.45365 .52084 m
.45365 .52459 L
s
.51234 .52084 m
.51234 .52459 L
s
.54168 .52084 m
.54168 .52459 L
s
.57102 .52084 m
.57102 .52459 L
s
.60037 .52084 m
.60037 .52459 L
s
.65905 .52084 m
.65905 .52459 L
s
.68839 .52084 m
.68839 .52459 L
s
.71774 .52084 m
.71774 .52459 L
s
.74708 .52084 m
.74708 .52459 L
s
.80576 .52084 m
.80576 .52459 L
s
.83511 .52084 m
.83511 .52459 L
s
.86445 .52084 m
.86445 .52459 L
s
.89379 .52084 m
.89379 .52459 L
s
.01351 .52084 m
.01351 .52459 L
s
.95248 .52084 m
.95248 .52459 L
s
.98182 .52084 m
.98182 .52459 L
s
.25 Mabswid
0 .52084 m
1 .52084 L
s
.33628 .02138 m
.34253 .02138 L
s
[(0.485)] .32378 .02138 1 0 Mshowa
.33628 .10462 m
.34253 .10462 L
s
[(0.4875)] .32378 .10462 1 0 Mshowa
.33628 .18787 m
.34253 .18787 L
s
[(0.49)] .32378 .18787 1 0 Mshowa
.33628 .27111 m
.34253 .27111 L
s
[(0.4925)] .32378 .27111 1 0 Mshowa
.33628 .35435 m
.34253 .35435 L
s
[(0.495)] .32378 .35435 1 0 Mshowa
.33628 .4376 m
.34253 .4376 L
s
[(0.4975)] .32378 .4376 1 0 Mshowa
.33628 .60408 m
.34253 .60408 L
s
[(0.5025)] .32378 .60408 1 0 Mshowa
.125 Mabswid
.33628 .03803 m
.34003 .03803 L
s
.33628 .05468 m
.34003 .05468 L
s
.33628 .07133 m
.34003 .07133 L
s
.33628 .08797 m
.34003 .08797 L
s
.33628 .12127 m
.34003 .12127 L
s
.33628 .13792 m
.34003 .13792 L
s
.33628 .15457 m
.34003 .15457 L
s
.33628 .17122 m
.34003 .17122 L
s
.33628 .20451 m
.34003 .20451 L
s
.33628 .22116 m
.34003 .22116 L
s
.33628 .23781 m
.34003 .23781 L
s
.33628 .25446 m
.34003 .25446 L
s
.33628 .28776 m
.34003 .28776 L
s
.33628 .30441 m
.34003 .30441 L
s
.33628 .32106 m
.34003 .32106 L
s
.33628 .3377 m
.34003 .3377 L
s
.33628 .371 m
.34003 .371 L
s
.33628 .38765 m
.34003 .38765 L
s
.33628 .4043 m
.34003 .4043 L
s
.33628 .42095 m
.34003 .42095 L
s
.33628 .45425 m
.34003 .45425 L
s
.33628 .47089 m
.34003 .47089 L
s
.33628 .48754 m
.34003 .48754 L
s
.33628 .50419 m
.34003 .50419 L
s
.33628 .53749 m
.34003 .53749 L
s
.33628 .55414 m
.34003 .55414 L
s
.33628 .57079 m
.34003 .57079 L
s
.33628 .58744 m
.34003 .58744 L
s
.33628 .00473 m
.34003 .00473 L
s
.25 Mabswid
.33628 0 m
.33628 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .49877 m
.09242 .54833 L
.15678 .58656 L
.22103 .57332 L
.29221 .59774 L
.35995 .60332 L
.42715 .56577 L
.49602 .57483 L
.56509 .56939 L
.6342 .54493 L
.70403 .46473 L
.77397 .39177 L
.84181 .32945 L
.90955 .20702 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oH03oool0
0`000000oooo0?ooo`2m0?ooo`00H03oool200000;h0oooo001P0?ooo`030000003oool0oooo0;d0
oooo001P0?ooo`030000003oool0oooo0;d0oooo00110?ooo`800000103oool2000000D0oooo0`00
00020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`060?ooo`00@03oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool01P3oool00400oooo00@000000?ooo`3oool00000203oool500000005
0?ooo`000000oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`<00000/`3oool00`00
0000oooo0?ooo`070?ooo`00@03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000<0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0
oooo00L0oooo00100?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`0000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`070?ooo`00@@3oool2000000/0oooo0P0000030?ooo`800000103oool3
000000@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`080?ooo`00H03oool20000
0;<0oooo00<000000?ooo`3oool0203oool00600oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`080?ooo`00H03oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo00T0oooo
001P0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool02@3oool00600oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`090?ooo`00H03oool200000;40oooo00<000000?oo
o`3oool02P3oool00600oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0:0?ooo`00
H03oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00X0oooo001P0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool02`3oool00600oooo00<000000?ooo`3oool0[`3oool0
0`000000oooo0?ooo`0;0?ooo`00H03oool200000:l0oooo00<000000?ooo`3oool0303oool00600
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0<0?ooo`00H03oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo00`0oooo001P0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool03@3oool00600oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0=
0?ooo`00H03oool200000:h0oooo00<000000?ooo`3oool03@3oool00600oooo00<000000?ooo`3o
ool0[03oool00`000000oooo0?ooo`0>0?ooo`00>`3oool2000000@0oooo0P0000050?ooo`<00000
0P3oool2000000D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0
[03oool00`000000oooo0?ooo`0>0?ooo`00>P3oool010000000oooo0?ooo`00000;0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo
00h0oooo000j0?ooo`040000003oool0oooo000000P0oooo1@0000001@3oool000000?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<00000Z`3oool0
0`000000oooo0?ooo`0?0?ooo`00>P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo
0?ooo`2[0?ooo`030000003oool0oooo00l0oooo000j0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
00l0oooo000k0?ooo`8000002`3oool2000000<0oooo0P0000030?ooo`@000000`3oool3000000@0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0@0?ooo`00H03oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo0100oooo001P0?ooo`800000Z`3oool00`000000oooo0?oo
o`0@0?ooo`00H03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0140oooo001P0?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool04@3oool00600oooo00<000000?ooo`3o
ool0Z@3oool00`000000oooo0?ooo`0A0?ooo`00H03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo0180oooo001P0?ooo`800000Z@3oool00`000000oooo0?ooo`0B0?ooo`00H03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0180oooo001P0?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool04`3oool00600oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`0C0?ooo`00H03oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo01<0oooo
001P0?ooo`800000Y`3oool00`000000oooo0?ooo`0D0?ooo`00H03oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo01@0oooo001P0?ooo`030000003oool0oooo0:D0oooo00<000000?oo
o`3oool05@3oool00600oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0E0?ooo`00
H03oool200000:H0oooo00<000000?ooo`3oool05@3oool00600oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0F0?ooo`00H03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo01H0oooo00170?ooo`800000103oool2000000D0oooo0`000000103oool00000000000000005
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool05P3oool004H0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0X`3oool00`000000oooo0?ooo`0G0?ooo`00AP3oool010000000oooo0?ooo`000008
0?ooo`D000000P3oool3000000@0oooo0`00002S0?ooo`030000003oool0oooo01L0oooo00160?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool05`3oool004H0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0H0?ooo`00A`3oool2000000/0oooo
0P0000030?ooo`<00000103oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo01P0oooo
001P0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0603oool00600oooo0P00002R
0?ooo`030000003oool0oooo01T0oooo001P0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool06@3oool00600oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0J0?ooo`00
H03oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo01X0oooo001P0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool06`3oool00600oooo0P00002P0?ooo`030000003oool0
oooo01/0oooo001P0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0703oool00600
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0L0?ooo`00H03oool00`000000oooo
0?ooo`2M0?ooo`030000003oool0oooo01d0oooo001P0?ooo`800000WP3oool00`000000oooo0?oo
o`0M0?ooo`00H03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo01h0oooo001P0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool07P3oool00600oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0O0?ooo`00H03oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0200oooo001P0?ooo`800000V`3oool00`000000oooo0?ooo`0P0?ooo`00H03oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
09T0oooo00<000000?ooo`3oool08@3oool003/0oooo0P0000040?ooo`8000001@3oool300000004
0?ooo`0000000000000000<0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo0280oooo000j0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0280oooo000j0?ooo`040000003oool0
oooo000000P0oooo1@0000020?ooo`<000000`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo0`00002G0?ooo`030000003oool0oooo02<0oooo000j0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool08`3oool003X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0903oool003/0oooo0P00000;0?oo
o`8000000`3oool3000000<0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo02@0oooo001P0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool09@3oool00600oooo0P00002F0?ooo`030000003oool0oooo02D0oooo001P0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool09P3oool00600oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`0W0?ooo`00H03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
02L0oooo001P0?ooo`800000T`3oool00`000000oooo0?ooo`0X0?ooo`00H03oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo02P0oooo001P0?ooo`030000003oool0oooo0940oooo00<0
00000?ooo`3oool0:@3oool00600oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0Y
0?ooo`00H03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo02X0oooo001P0?ooo`80
0000T@3oool00`000000oooo0?ooo`0Z0?ooo`00H03oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo02/0oooo001P0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0:`3o
ool00600oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`00H03oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02d0oooo001P0?ooo`800000S@3oool00`000000
oooo0?ooo`0^0?ooo`00H03oool00`000000oooo0?ooo`2:0?ooo`800000<@3oool00600oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0a0?ooo`00@@3oool2000000@0oooo0P000005
0?ooo`<0000000@0oooo0000000000000000103oool2000000D0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`0b0?ooo`00@03oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0c0?ooo`00@03oool010000000oooo0?oo
o`0000080?ooo`D000000P3oool3000000D0oooo00<000000?ooo`3oool00P3oool3000008H0oooo
00<000000?ooo`3oool0=03oool00400oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0=@3oool00400oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`230?ooo`800000>03oool00440oooo0P00000;0?ooo`8000000`3oool30000
00<0oooo0`0000040?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0>03oool00600
oooo0P0000220?ooo`030000003oool0oooo03T0oooo001P0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0>P3oool00600oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`0k0?ooo`00H03oool00`000000oooo0?ooo`1m0?ooo`800000?P3oool00600oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`0n0?ooo`00H03oool2000007`0oooo00<000000?ooo`3o
ool0?`3oool00600oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`100?ooo`00H03o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0440oooo001P0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0@P3oool00600oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`130?ooo`00H03oool2000007L0oooo00<000000?ooo`3oool0A03oool00600oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`150?ooo`00H03oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo04H0oooo001P0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0A`3oool00600oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`180?oo
o`00H03oool200000780oooo00<000000?ooo`3oool0B@3oool00600oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`1:0?ooo`00>`3oool2000000@0oooo0P0000050?ooo`<0000000@0
oooo00000000000000001@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo04X0oooo000j0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3o
ool0B`3oool003X0oooo00@000000?ooo`3oool00000203oool500000080oooo0`0000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000006h0oooo00<000000?ooo`3o
ool0C03oool003X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0C@3oool003X0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0CP3oool003/0oooo0P00000;0?ooo`8000000`3oool300000080oooo100000030?ooo`<00000
103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04l0oooo001P0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0D03oool00600oooo0P00001Z0?ooo`030000003oool0
oooo0540oooo001P0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0DP3oool00600
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1C0?ooo`00H03oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo05@0oooo001P0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0E@3oool00600oooo0P00001U0?ooo`030000003oool0oooo05H0oooo001P0?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0E`3oool00600oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`1G0?ooo`000`3oool2000000@0oooo0P0000040?ooo`800000
103oool200000180oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
0P3oool2000001d0oooo00<000000?ooo`3oool06P3oool2000000@0oooo0P0000030?ooo`D00000
00<0oooo0000000000000P0000030?ooo`8000004`3oool2000000@0oooo0P0000030?ooo`D00000
0P3oool2000000L0oooo00<000000?ooo`3oool02@3oool2000000@0oooo0P0000030?ooo`D00000
0`3oool00`000000oooo0?ooo`020?ooo`8000005P3oool2000000@0oooo0P0000030?ooo`@00000
403oool00080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01T0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00@000000?ooo`3oool000004@3oool010000000oooo0?ooo`00000:0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool04@3oool00080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool2000001X0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0180oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0@0?ooo`000P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00000A0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3o
ool2000001d0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool200000180oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2
000001D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0?0?ooo`000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00@00000
0?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000000C0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000002P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000F0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000403oool000<0oooo0P0000020?ooo`03
0000003oool0oooo00D0oooo0P0000040?ooo`<000004@3oool2000000X0oooo0P0000030?ooo`@0
00000`3oool3000001`0oooo00<000000?ooo`3oool06P3oool2000000X0oooo0P0000040?ooo`80
0000103oool300000180oooo0P00000:0?ooo`800000103oool3000000030?ooo`000000oooo00l0
oooo0P00000:0?ooo`8000000`3oool4000000<0oooo0`00000E0?ooo`8000002P3oool200000140
oooo00080?ooo`800000EP3oool2000005d0oooo00<000000?ooo`3oool0GP3oool000X0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo05h0oooo000;
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1O
0?ooo`00303oool200000580oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1P0?oo
o`003P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0H@3oool00?l00000800000010?ooo`00103oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
000=0?ooo`030000003oool0oooo0080oooo0P00000R0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01D0oooo000D
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1U
0?ooo`005@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0I@3oool001H0oooo0P0000180?ooo`800000E@3oool00`000000oooo0?ooo`1V0?ooo`00
603oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
I`3oool001T0oooo0P0000150?ooo`030000003oool0oooo0540oooo0P00001Z0?ooo`006`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo04h0oooo0`00001/0?ooo`00703oool20000
0480oooo00<000000?ooo`3oool0C03oool2000006l0oooo000N0?ooo`800000@03oool2000004X0
oooo0`00001a0?ooo`00803oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo04H0oooo
0`00001d0?ooo`008@3oool2000003d0oooo00<000000?ooo`3oool0A03oool2000007L0oooo000S
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool05`3oool4000002H0oooo0`00001i
0?ooo`00903oool2000003X0oooo0P00000F0?ooo`800000103oool6000001X0oooo1P00001l0?oo
o`009P3oool2000001D0oooo1000000O0?ooo`030000003oool0oooo01<0oooo0P00000<0?ooo`L0
00002@3oool:00000880oooo000X0?ooo`030000003oool0oooo00h0oooo100000040?ooo`<00000
703oool00`000000oooo0?ooo`0A0?ooo`8000005@3oool9000008`0oooo000Y0?ooo`8000002@3o
ool5000000/0oooo0`00000I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0ZP3o
ool002/0oooo0P0000030?ooo`@000004`3oool3000001H0oooo00<000000?ooo`3oool03P3oool2
00000:d0oooo000]0?ooo`<000006P3oool3000001<0oooo0P00000=0?ooo`800000[`3oool004d0
oooo0`00000@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0[`3oool00500oooo
0`00000=0?ooo`030000003oool0oooo00T0oooo0P00002b0?ooo`00>`3oool2000000@0oooo0P00
00040?ooo`800000103oool2000000<0oooo2@0000050?ooo`030000003oool0oooo00L0oooo0P00
002d0?ooo`00>P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`/000001@3oool200000;H0
oooo000j0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool800000;P0oooo000j0?oo
o`040000003oool0oooo000000T0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0_@3oool003X0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;d0
oooo000k0?ooo`8000002P3oool3000000<0oooo0P0000040?ooo`800000103oool3000000@0oooo
00<000000?ooo`3oool0_@3oool00600oooo00<000000?ooo`3oool0_@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.0422352, 0.484358, \
0.000596951, 0.00010521}}]
}, Open  ]],

Cell["Make a plot of the crest position versus time.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[crests[\([All, {1, 2}]\)]];\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.248299 0.000188964 -0.154693 3.62419 [
[.31859 .19523 -12 -9 ]
[.31859 .19523 12 0 ]
[.50756 .19523 -12 -9 ]
[.50756 .19523 12 0 ]
[.69652 .19523 -12 -9 ]
[.69652 .19523 12 0 ]
[.88549 .19523 -12 -9 ]
[.88549 .19523 12 0 ]
[.11713 .02652 -24 -4.5 ]
[.11713 .02652 0 4.5 ]
[.11713 .11712 -30 -4.5 ]
[.11713 .11712 0 4.5 ]
[.11713 .29833 -30 -4.5 ]
[.11713 .29833 0 4.5 ]
[.11713 .38894 -24 -4.5 ]
[.11713 .38894 0 4.5 ]
[.11713 .47954 -30 -4.5 ]
[.11713 .47954 0 4.5 ]
[.11713 .57015 -18 -4.5 ]
[.11713 .57015 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.31859 .20773 m
.31859 .21398 L
s
[(3000)] .31859 .19523 0 1 Mshowa
.50756 .20773 m
.50756 .21398 L
s
[(4000)] .50756 .19523 0 1 Mshowa
.69652 .20773 m
.69652 .21398 L
s
[(5000)] .69652 .19523 0 1 Mshowa
.88549 .20773 m
.88549 .21398 L
s
[(6000)] .88549 .19523 0 1 Mshowa
.125 Mabswid
.16742 .20773 m
.16742 .21148 L
s
.20522 .20773 m
.20522 .21148 L
s
.24301 .20773 m
.24301 .21148 L
s
.2808 .20773 m
.2808 .21148 L
s
.35639 .20773 m
.35639 .21148 L
s
.39418 .20773 m
.39418 .21148 L
s
.43197 .20773 m
.43197 .21148 L
s
.46977 .20773 m
.46977 .21148 L
s
.54535 .20773 m
.54535 .21148 L
s
.58314 .20773 m
.58314 .21148 L
s
.62094 .20773 m
.62094 .21148 L
s
.65873 .20773 m
.65873 .21148 L
s
.73432 .20773 m
.73432 .21148 L
s
.77211 .20773 m
.77211 .21148 L
s
.8099 .20773 m
.8099 .21148 L
s
.84769 .20773 m
.84769 .21148 L
s
.09184 .20773 m
.09184 .21148 L
s
.05404 .20773 m
.05404 .21148 L
s
.01625 .20773 m
.01625 .21148 L
s
.92328 .20773 m
.92328 .21148 L
s
.96107 .20773 m
.96107 .21148 L
s
.99887 .20773 m
.99887 .21148 L
s
.25 Mabswid
0 .20773 m
1 .20773 L
s
.12963 .02652 m
.13588 .02652 L
s
[(0.05)] .11713 .02652 1 0 Mshowa
.12963 .11712 m
.13588 .11712 L
s
[(0.075)] .11713 .11712 1 0 Mshowa
.12963 .29833 m
.13588 .29833 L
s
[(0.125)] .11713 .29833 1 0 Mshowa
.12963 .38894 m
.13588 .38894 L
s
[(0.15)] .11713 .38894 1 0 Mshowa
.12963 .47954 m
.13588 .47954 L
s
[(0.175)] .11713 .47954 1 0 Mshowa
.12963 .57015 m
.13588 .57015 L
s
[(0.2)] .11713 .57015 1 0 Mshowa
.125 Mabswid
.12963 .04464 m
.13338 .04464 L
s
.12963 .06276 m
.13338 .06276 L
s
.12963 .08088 m
.13338 .08088 L
s
.12963 .099 m
.13338 .099 L
s
.12963 .13524 m
.13338 .13524 L
s
.12963 .15336 m
.13338 .15336 L
s
.12963 .17148 m
.13338 .17148 L
s
.12963 .18961 m
.13338 .18961 L
s
.12963 .22585 m
.13338 .22585 L
s
.12963 .24397 m
.13338 .24397 L
s
.12963 .26209 m
.13338 .26209 L
s
.12963 .28021 m
.13338 .28021 L
s
.12963 .31645 m
.13338 .31645 L
s
.12963 .33457 m
.13338 .33457 L
s
.12963 .35269 m
.13338 .35269 L
s
.12963 .37081 m
.13338 .37081 L
s
.12963 .40706 m
.13338 .40706 L
s
.12963 .42518 m
.13338 .42518 L
s
.12963 .4433 m
.13338 .4433 L
s
.12963 .46142 m
.13338 .46142 L
s
.12963 .49766 m
.13338 .49766 L
s
.12963 .51578 m
.13338 .51578 L
s
.12963 .5339 m
.13338 .5339 L
s
.12963 .55202 m
.13338 .55202 L
s
.12963 .0084 m
.13338 .0084 L
s
.12963 .58827 m
.13338 .58827 L
s
.12963 .60639 m
.13338 .60639 L
s
.25 Mabswid
.12963 0 m
.12963 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 Mdot
.09184 .05712 Mdot
.15986 .09689 Mdot
.22789 .13673 Mdot
.29592 .18059 Mdot
.36395 .22238 Mdot
.43197 .26383 Mdot
.5 .30633 Mdot
.56803 .34903 Mdot
.63605 .39174 Mdot
.70408 .43484 Mdot
.77211 .47807 Mdot
.84014 .52006 Mdot
.90816 .56176 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o9@3oool0
0`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0
oooo00060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0n03oool000H0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`3h0?ooo`002`3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool0n03oool000X0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0n03oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00<0oooo0`00003h0?ooo`002P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P0000060?ooo`030000003oool0oooo
0?P0oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?P0oooo000;0?ooo`8000002P3oool20000
00@0oooo0`0000050?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0
oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<00000
0?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool001X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3h0?ooo`006P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?P0oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool0
02D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo
00<000000?ooo`3oool0n03oool002D0oooo0P00003i0?ooo`009@3oool00`000000oooo0?ooo`3h
0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`00
9@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?00oooo000U0?ooo`8000001P3o
ool00`000000oooo0?ooo`3`0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`00
0000oooo0?ooo`3h0?ooo`001@3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`3h0?ooo`00103oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0n03oool000@0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool300000?P0oooo00040?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3o
ool0n03oool000@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3h
0?ooo`001@3oool2000000X0oooo0P0000030?ooo`@000000`3oool3000000D0oooo00<000000?oo
o`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo0P00000I0?ooo`030000
003oool0oooo0=d0oooo000U0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0g@3o
ool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0
oooo00<000000?ooo`3oool0n03oool002D0oooo0P00003i0?ooo`009@3oool00`000000oooo0?oo
o`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?oo
o`009@3oool00`000000oooo0?ooo`0Y0?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
00008`3oool300000080oooo0P0000040?ooo`800000103oool200000280oooo0P0000040?ooo`80
0000103oool2000000@0oooo0P00000Q0?ooo`<00000103oool2000000@0oooo0P0000040?ooo`80
00006@3oool002D0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000S0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000803oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000H0?ooo`009@3oool2000002/0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0N0?ooo`D0000000D0oooo0000003oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000008`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0N0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001P0oooo000U0?ooo`03
0000003oool0oooo02/0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool07P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000Q0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000803oool3000000<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001P0oooo000U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00P0000001@3oool000000?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Q0?ooo`03
0000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000240oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000008@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000H0?ooo`009@3oool00`000000oooo0?ooo`0Y0?ooo`80000000@0
oooo0000003oool0oooo0P0000040?ooo`800000103oool2000002<0oooo0P0000030?ooo`800000
103oool2000000@0oooo0P00000R0?ooo`<000000`3oool2000000@0oooo0P0000040?ooo`800000
8P3oool3000000<0oooo0P0000040?ooo`800000103oool2000001T0oooo000U0?ooo`030000003o
ool0oooo0?P0oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool002D0
oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<0
00000?ooo`3oool0n03oool00?l00000800000010?ooo`001@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo0@0000010?ooo`009@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0]P3oool002D0oooo0P0000100?ooo`030000003oool0
oooo0;H0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0
oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U
0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3o
ool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03o
ool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo0P00001D0?ooo`030000003oool0oooo
0:80oooo000U0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0XP3oool002D0oooo
00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<00000
0?ooo`3oool0n03oool002D0oooo0P00003i0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`00
9@3oool00`000000oooo0?ooo`3h0?ooo`001@3oool2000000@0oooo0P0000030?ooo`D0000000<0
oooo0000000000000P0000030?ooo`8000001P3oool00`000000oooo0?ooo`3h0?ooo`00103oool0
10000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0?P0oooo00040?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo0`00003h0?ooo`00103oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0n03oool000@0oooo
00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0S`3oool0
00D0oooo0P00000:0?ooo`800000103oool2000000@0oooo0`0000050?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0S`3oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo
0P00003i0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h
0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`00
9@3oool200000?T0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0
oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0N`3oool002D0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`1k0?ooo`009@3oool200000?T0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?oo
o`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000
003oool0oooo0?P0oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool0
02D0oooo00<000000?ooo`3oool0n03oool000/0oooo0P0000040?ooo`8000000`3oool500000080
oooo0P0000060?ooo`030000003oool0oooo0?P0oooo000:0?ooo`040000003oool0oooo000000X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0n03oool000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo0`00002=0?ooo`030000003oool0oooo06P0oooo000:0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`1X0?ooo`002P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3h0?oo
o`002`3oool2000000X0oooo0P0000040?ooo`<000001@3oool00`000000oooo0?ooo`3h0?ooo`00
9@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0oooo000U0?ooo`030000003oool0
oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0
oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`800000n@3oool002D0oooo00<00000
0?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3o
ool0X@3oool00`000000oooo0?ooo`1D0?ooo`009@3oool00`000000oooo0?ooo`2Q0?ooo`030000
003oool0oooo05@0oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool0
02D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo
00<000000?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo0P00003i
0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`00
1@3oool2000000@0oooo0P0000030?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`800000
1P3oool00`000000oooo0?ooo`3h0?ooo`00103oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`110?ooo`00103oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`<00000]03oool00`000000oooo0?ooo`110?ooo`00103oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P0000060?oo
o`030000003oool0oooo0?P0oooo00040?ooo`040000003oool0oooo000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`3h0?ooo`001@3oool2000000X0oooo0P0000030?ooo`@000000`3oool3000000D0oooo00<00000
0?ooo`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo0P00003i0?ooo`00
9@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool0
0`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0
oooo000U0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;@3oool002D0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0]0?ooo`009@3oool00`000000oooo0?ooo`3h
0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool200000?T0oooo000U0?ooo`030000
003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0
oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0oooo000U0?ooo`030000003oool0oooo0?P0
oooo000U0?ooo`800000n@3oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo00<00000
0?ooo`3oool0f`3oool00`000000oooo0?ooo`0J0?ooo`004@3oool2000000@0oooo0P0000030?oo
o`@000001@3oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo01X0oooo000@0?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3h0?oo
o`00403oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo0`00003h0?oo
o`00403oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0n03oool00100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0?P0oooo000A0?ooo`8000002P3oool2000000H0oooo00<000000?oo
o`3oool0n03oool002D0oooo00<000000?ooo`3oool0n03oool002D0oooo0P00003i0?ooo`009@3o
ool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`00
0000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo00H0
oooo000U0?ooo`800000l03oool00`000000oooo0?ooo`060?ooo`009@3oool00`000000oooo0?oo
o`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?ooo`009@3oool00`000000oooo0?ooo`3h0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {1307.44, 0.0426826, 18.4848, \
0.000963791}}]
}, Open  ]],

Cell[TextData[{
  "Load a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package of commands for computing distances on the globe based on a geoid \
model."
}], "MathCaption"],

Cell[BoxData[
    \(Needs["\<Vincenty`\>"]\)], "Input",
  CellLabel->"In[37]:="],

Cell["Get the average speed of the wave from the simulation.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vd\  = \ 
      VincentyDistance[{\[Lambda]\_e, \ crests[\([1, 2]\)]}/
          Degree, \ {\[Lambda]\_e, \ crests[\([\(-1\), 2]\)]}/
          Degree]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({1.0358711379934696`*^6, {90, 270}}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(First[vd]/\((T \((9/10\  - \ 1/5)\))\)\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(205.52998769711698`\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["Convert to km/h", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%*3600/1000\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(739.9079557096211`\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[{
  "Please note that this is a simplified model of the propagation phase.  The \
NOAA Tsunami modelling code may take several hours to do a realistic ",
  ButtonBox["model ",
    ButtonData:>{
      URL[ 
      "file:///C:/Web/RD_HTML/RKnapp/Talks/India/Data/TITOV-INDO2004.mov"], 
      None},
    ButtonStyle->"Hyperlink"],
  "of a tsunami. "
}], "Text"],

Cell[TextData[{
  "It should be worth noting that scientists at NOAA did make use of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in doing the research that went into the Pacific early warning system."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Scalability\ and\ Numerical\ Linear\ Algebra\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
One aspect of the solution of PDEs is the requirement for robust, \
fast, and scalable numerical linear algebra.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s dense numerical linear algebra is based on LAPACK (Linear Algebra \
Package) and BLAS (Basic Linear Algebra Subroutines) that allow optimization \
of some basic procedures such as matrix- matrix multiplication to optimize \
processor throughput.  By making a careful choice of libraries on the \
different platforms supported by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", we make sure that dense linear algebra scales as well as is robustly \
possible.  "
}], "Text"],

Cell["\<\
One way to check the effectiveness on a particular task is to use a \
scale invariant measure.  For many numerical tasks, such a measure is \
floating point operations per second (FLOPS).  A given processor will have a \
maximum (theoretical) speed in FLOPS.  The closer you get to this on a \
particular problem, the better.\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70902 
%%ImageSize: 850 602.664 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.397834 0.47619 [
[ 0 0 0 0 ]
[ 1 .70902 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.103532 0.97619 0.692136 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000463897 0.0147151 5.93423e-05 [
[.02381 -0.0125 -6.4375 -18 ]
[.02381 -0.0125 6.4375 0 ]
[.25576 -0.0125 -15.3125 -18 ]
[.25576 -0.0125 15.3125 0 ]
[.48771 -0.0125 -19.75 -18 ]
[.48771 -0.0125 19.75 0 ]
[.71966 -0.0125 -19.75 -18 ]
[.71966 -0.0125 19.75 0 ]
[.9516 -0.0125 -19.75 -18 ]
[.9516 -0.0125 19.75 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -60.0625 -36 ]
[.5 -0.0125 60.0625 -18 ]
[-0.0125 .01472 -12.875 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .1334 -39.5 -9 ]
[-0.0125 .1334 0 9 ]
[-0.0125 .25208 -39.5 -9 ]
[-0.0125 .25208 0 9 ]
[-0.0125 .37077 -39.5 -9 ]
[-0.0125 .37077 0 9 ]
[-0.0125 .48945 -39.5 -9 ]
[-0.0125 .48945 0 9 ]
[-0.0125 .60814 -48.375 -9 ]
[-0.0125 .60814 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -118.875 -9 ]
[-0.01875 .30902 -48.375 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -156.875 0 ]
[.5 .63053 156.875 18 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.25576 0 m
.25576 .61803 L
s
.48771 0 m
.48771 .61803 L
s
.71966 0 m
.71966 .61803 L
s
.9516 0 m
.9516 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .1334 m
1 .1334 L
s
0 .25208 m
1 .25208 L
s
0 .37077 m
1 .37077 L
s
0 .48945 m
1 .48945 L
s
0 .60814 m
1 .60814 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.4375 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25576 0 m
.25576 .00625 L
s
gsave
.25576 -0.0125 -76.3125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.48771 0 m
.48771 .00625 L
s
gsave
.48771 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.71966 0 m
.71966 .00625 L
s
gsave
.71966 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
.9516 0 m
.9516 .00625 L
s
gsave
.9516 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.125 Mabswid
.0702 0 m
.0702 .00375 L
s
.11659 0 m
.11659 .00375 L
s
.16298 0 m
.16298 .00375 L
s
.20937 0 m
.20937 .00375 L
s
.30215 0 m
.30215 .00375 L
s
.34854 0 m
.34854 .00375 L
s
.39493 0 m
.39493 .00375 L
s
.44132 0 m
.44132 .00375 L
s
.5341 0 m
.5341 .00375 L
s
.58049 0 m
.58049 .00375 L
s
.62688 0 m
.62688 .00375 L
s
.67327 0 m
.67327 .00375 L
s
.76605 0 m
.76605 .00375 L
s
.81243 0 m
.81243 .00375 L
s
.85882 0 m
.85882 .00375 L
s
.90521 0 m
.90521 .00375 L
s
.99799 0 m
.99799 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -121.062 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vector) show
125.938 17.000 moveto
(Length) show
179.125 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -73.875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .1334 m
.00625 .1334 L
s
gsave
-0.0125 .1334 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
0 .25208 m
.00625 .25208 L
s
gsave
-0.0125 .25208 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
0 .37077 m
.00625 .37077 L
s
gsave
-0.0125 .37077 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
0 .48945 m
.00625 .48945 L
s
gsave
-0.0125 .48945 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
0 .60814 m
.00625 .60814 L
s
gsave
-0.0125 .60814 -109.375 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04439 m
.00375 .04439 L
s
0 .07406 m
.00375 .07406 L
s
0 .10373 m
.00375 .10373 L
s
0 .16307 m
.00375 .16307 L
s
0 .19274 m
.00375 .19274 L
s
0 .22241 m
.00375 .22241 L
s
0 .28176 m
.00375 .28176 L
s
0 .31143 m
.00375 .31143 L
s
0 .3411 m
.00375 .3411 L
s
0 .40044 m
.00375 .40044 L
s
0 .43011 m
.00375 .43011 L
s
0 .45978 m
.00375 .45978 L
s
0 .51912 m
.00375 .51912 L
s
0 .5488 m
.00375 .5488 L
s
0 .57847 m
.00375 .57847 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -179.875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MFLOPS) show
129.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.25576 .61178 m
.25576 .61803 L
s
.48771 .61178 m
.48771 .61803 L
s
.71966 .61178 m
.71966 .61803 L
s
.9516 .61178 m
.9516 .61803 L
s
.125 Mabswid
.0702 .61428 m
.0702 .61803 L
s
.11659 .61428 m
.11659 .61803 L
s
.16298 .61428 m
.16298 .61803 L
s
.20937 .61428 m
.20937 .61803 L
s
.30215 .61428 m
.30215 .61803 L
s
.34854 .61428 m
.34854 .61803 L
s
.39493 .61428 m
.39493 .61803 L
s
.44132 .61428 m
.44132 .61803 L
s
.5341 .61428 m
.5341 .61803 L
s
.58049 .61428 m
.58049 .61803 L
s
.62688 .61428 m
.62688 .61803 L
s
.67327 .61428 m
.67327 .61803 L
s
.76605 .61428 m
.76605 .61803 L
s
.81243 .61428 m
.81243 .61803 L
s
.85882 .61428 m
.85882 .61803 L
s
.90521 .61428 m
.90521 .61803 L
s
.99799 .61428 m
.99799 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1334 m
1 .1334 L
s
.99375 .25208 m
1 .25208 L
s
.99375 .37077 m
1 .37077 L
s
.99375 .48945 m
1 .48945 L
s
.99375 .60814 m
1 .60814 L
s
.125 Mabswid
.99625 .04439 m
1 .04439 L
s
.99625 .07406 m
1 .07406 L
s
.99625 .10373 m
1 .10373 L
s
.99625 .16307 m
1 .16307 L
s
.99625 .19274 m
1 .19274 L
s
.99625 .22241 m
1 .22241 L
s
.99625 .28176 m
1 .28176 L
s
.99625 .31143 m
1 .31143 L
s
.99625 .3411 m
1 .3411 L
s
.99625 .40044 m
1 .40044 L
s
.99625 .43011 m
1 .43011 L
s
.99625 .45978 m
1 .45978 L
s
.99625 .51912 m
1 .51912 L
s
.99625 .5488 m
1 .5488 L
s
.99625 .57847 m
1 .57847 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -217.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MFLOPS) show
138.375 17.000 moveto
(on) show
162.312 17.000 moveto
(a) show
175.625 17.000 moveto
(900) show
206.688 17.000 moveto
(MHz) show
243.938 17.000 moveto
(4) show
252.812 17.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
263.625 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(way) show
302.688 17.000 moveto
(Itanium) show
363.875 17.000 moveto
(2) show
372.750 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .4 .4 r
.004 w
.08087 .2115 m
.08319 .31861 L
.08551 .29571 L
.09339 .26415 L
.13978 .39451 L
.14025 .38078 L
.14257 .44397 L
.14489 .33884 L
.18617 .453 L
.23256 .43741 L
.25901 .46724 L
.26132 .50901 L
.26364 .49457 L
.27895 .49615 L
.32534 .52041 L
.37173 .4851 L
.41812 .56351 L
.46451 .57193 L
.49652 .55502 L
.49884 .58959 L
.50116 .56189 L
.5109 .54362 L
.55729 .59964 L
.60368 .58946 L
.65007 .58755 L
.69646 .59364 L
.74285 .58185 L
.78924 .59612 L
.83563 .59835 L
.88202 .60212 L
.92841 .60332 L
.97155 .55057 L
.97387 .59663 L
.97619 .53301 L
s
.4 .4 1 r
.08087 .16327 m
.08319 .2471 L
.08551 .21592 L
.09339 .23186 L
.13978 .26791 L
.14025 .26071 L
.14257 .29355 L
.14489 .26404 L
.18617 .28579 L
.23256 .30312 L
.25901 .29755 L
.26132 .32841 L
.26364 .29937 L
.27895 .2995 L
.32534 .31272 L
.37173 .32545 L
.41812 .327 L
.46451 .32763 L
.49652 .32235 L
.49884 .34342 L
.50116 .30897 L
.5109 .31924 L
.55729 .33285 L
.60368 .33333 L
.65007 .33589 L
.69646 .3369 L
.74285 .33798 L
.78924 .34065 L
.83563 .34417 L
.88202 .34244 L
.92841 .34712 L
.97155 .32733 L
.97387 .35224 L
.97619 .31962 L
s
.4 .8 .4 r
.08087 .13994 m
.08319 .16521 L
.08551 .14304 L
.09339 .15246 L
.13978 .1594 L
.14025 .15707 L
.14257 .17865 L
.14489 .15877 L
.18617 .16551 L
.23256 .17158 L
.25901 .16849 L
.26132 .18288 L
.26364 .16334 L
.27895 .16907 L
.32534 .17365 L
.37173 .17748 L
.41812 .17875 L
.46451 .18064 L
.49652 .17566 L
.49884 .18848 L
.50116 .17217 L
.5109 .17699 L
.55729 .18184 L
.60368 .18366 L
.65007 .18337 L
.69646 .18452 L
.74285 .18209 L
.78924 .18458 L
.83563 .18478 L
.88202 .18432 L
.92841 .18617 L
.97155 .17779 L
.97387 .1907 L
.97619 .17527 L
s
.8 .4 .8 r
.08087 .0275 m
.08319 .02797 L
.08551 .02761 L
.09339 .02764 L
.13978 .02742 L
.14025 .02742 L
.14257 .02698 L
.14489 .02744 L
.18617 .02546 L
.23256 .02299 L
.25901 .0221 L
.26132 .02266 L
.26364 .02212 L
.27895 .02186 L
.32534 .02184 L
.37173 .02181 L
.41812 .02186 L
.46451 .02185 L
.49652 .02185 L
.49884 .02202 L
.50116 .02185 L
.5109 .02187 L
.55729 .02187 L
.60368 .02188 L
.65007 .02189 L
.69646 .0219 L
.74285 .0219 L
.78924 .02191 L
.83563 .02191 L
.88202 .02191 L
.92841 .02192 L
.97155 .02191 L
.97387 .02208 L
.97619 .02191 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.22381 .01688 m
.22381 .08355 L
.89048 .08355 L
.89048 .01688 L
F
1 g
.22381 .01688 m
.22381 .08355 L
.89048 .08355 L
.89048 .01688 L
F
0 g
.001 w
[ ] 0 setdash
.22381 .01688 m
.89048 .01688 L
.89048 .08355 L
.22381 .08355 L
.22381 .01688 L
s
% Start of sub-graphic
p
0.22381 0.0168814 0.890476 0.083548 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0206612 0.206612 0.00423729 0.0423729 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0371901 0.00762712 0.243802 0.05 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .4 .4 r
.21371 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.1405 .05339 -100.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
76.312 17.000 moveto
(Threads) show
138.375 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.27686 0.00762712 0.483471 0.05 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .4 1 r
.21371 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38017 .05339 -100.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
76.312 17.000 moveto
(Threads) show
138.375 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.516529 0.00762712 0.72314 0.05 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .8 .4 r
.21371 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.61983 .05339 -96.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
76.312 17.000 moveto
(Thread) show
129.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.756198 0.00762712 0.96281 0.05 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.8 .4 .8 r
.21371 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.8595 .05339 -80.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
85.188 17.000 moveto
(.1) show
98.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .70902 L
0 .70902 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{850, 602.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=B0002FR000`400?l00000o`00003ooooooooo
ooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00
ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomE
ooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooo
oooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooo
oooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo
002nooooool00000o`00000h000005kooooo002nooooo`0300000?oooooooooo0?oooooooooooold
ooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldoooo
o`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`03
00000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`030000
0?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oo
oooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooo
oooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo
05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05co
oooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo
002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002n
ooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002noooo
o`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`03
00000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`030000
0?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oo
oooooooo03kooooo7@3oIVI[oooooad0IVKoJ_oooolM06K<IV_ooooo7@3<I/a0ooooo`0300000?oo
oooooooo05cooooo002nooooo`0300000?oooooooooo03kooooo7@3oIVI[oooooad0IVKoJ_oooolM
06K<IV_ooooo7@3<I/a0ooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo
03kooooo7@3oIVI[oooooad0IVKoJ_oooolM06K<IV_ooooo7@3<I/a0ooooo`0300000?oooooooooo
05cooooo002nooooo`0300000?oooooooooo03kooooo7@3oIVI[oooooad0IVKoJ_oooolM06K<IV_o
oooo7@3<I/a0ooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo03kooooo
7@3oIVI[oooooad0IVKoJ_oooolM06K<IV_ooooo7@3<I/a0ooooo`0300000?oooooooooo05cooooo
002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002n
ooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002noooo
o`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`03
00000?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`030000
0?oooooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oo
oooooooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooo
oooo0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo
0?ooooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?oo
ooooooooooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?oooooo
ooooooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?oooooooooo
ooldooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?oooooooooooold
ooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldoooo
o`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`03
00000?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`030000
0?oooooooooo05cooooo002nooooo`0300000?oooooooooo0?ooooooooooooldooooo`0300000?oo
oooooooo05cooooo002nooooo`0300000?oooooooooo02_ooooo0_l0000:ooooo`;o00001?ooool2
o`0000Cooooo0_l00002ooooo`;o00001Oooool01_o<c<coA4A4o`000?l0003o8B4QojVYZ@?ooooo
00Koc<c<odA4A?l0003o0000oeEEEOo^k^h2o`0000?ooooo00GoZJVYoa0@4?l0003o410@olc<c002
o`0000?ooooo00OoMgMgoa0@4?l0003o0000oa0@4?mgMgOok^k^03_ooooo2?l00008ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool01_o<c<coA4A4o`000?l0003o8B4QojVY
Z@?ooooo00Koc<c<odA4A?l0003o0000oeEEEOo^k^h2o`0000?ooooo00GoZJVYoa0@4?l0003o410@
olc<c002o`0000?ooooo00OoMgMgoa0@4?l0003o0000oa0@4?mgMgOok^k^04Cooooo0_l0000:oooo
o`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool01_o<c<coA4A4o`000?l0003o
8B4QojVYZ@?ooooo00Koc<c<odA4A?l0003o0000oeEEEOo^k^h2o`0000?ooooo00GoZJVYoa0@4?l0
003o410@olc<c002o`0005[ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_l00002oooo
o`;o00001Oooool2o`00047ooooo00<00000ooooooooool0G?ooool00;kooooo00<00000oooooooo
ool0:oooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`03
olc<c?l0003o000000Co000000CoZJVYoooooooooooo<S8b1ol00002ooooo`03olc<c?l0003o0000
00Go00000_ooool00omVIVKo0000o`000004o`000003oeEEEOoooooooooo03Wooooo00?o8B4Qo`00
0?l000001Ol00008ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool00oo<
c<co0000o`000004o`000004ojVYZOoooooooooooc8b<POo00000_ooool00oo<c<co0000o`000005
o`0000;ooooo00?oIVIVo`000?l000001?l000000omEEEGoooooooooo`12ooooo`;o00002_ooool2
o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo00?oc<c<o`000?l000001?l00000
1?nYZJWooooooooooolb<S87o`0000;ooooo00?oc<c<o`000?l000001Ol0001Jooooo`;o00000ooo
ool2o`000003oooooolQ8B7o000000Ko00000_ooool2o`0000Gooooo0_l00011ooooo`0300000?oo
oooooooo05cooooo002nooooo`0300000?oooooooooo02Kooooo2?l00009ooooo`;o00001?ooool2
o`0000Cooooo0_l00002ooooo`;o00001?ooool02?m4A4Co0000oeEEEOo^k^koooooogMgMol0003o
410@0_ooool2o`000004okZj^_oooooogMgMoeEEE@;o00000_ooool00om4A4Co0000odA4A002onk^
kP03odA4A?l0003o000000;ooooo0_l000001?nHV9SooooooooooooMgMd2o`0003_ooooo00CoIVIV
o`000?l0003oc<c<3?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo00So
A4A4o`000?mEEEGok^k^oooooomgMgOo0000oa0@40;ooooo0_l000001?nj^[[oooooomgMgOmEEED2
o`0000;ooooo00?oA4A4o`000?m4A4@00_o^k^h00om4A4Co0000o`000002ooooo`;o000000CoV9RH
oooooooooooogMgM0_l00014ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`;o00000_oo
ool2o`0000Cooooo00SoA4A4o`000?mEEEGok^k^oooooomgMgOo0000oa0@40;ooooo0_l000001?nj
^[[oooooomgMgOmEEED2o`0000;ooooo00?oA4A4o`000?m4A4@00_o^k^h00om4A4Co0000o`00001E
ooooo`So00001Oooool01?mVIVKo0000o`000?o<c<`=ooooo`;o0000@Oooool00`00003ooooooooo
o`1Looooo`00__ooool00`00003oooooooooo`0Vooooo`So00002Oooool2o`0000Cooooo0_l00004
ooooo`;o00000_ooool2o`0000Cooooo0_l000000oo^k^koooooooooo`05ooooo`03oc8b<_l0003o
^[Zj00;ooooo00?ok^k^o`000?l000000_ooool2o`000004omgMgOooooooooooomgMg@;o00001?oo
ool01_o<c<coQhN7ofIVI_l@413o0000oa0@43_ooooo00Gok^k^ob4Q8Ol0003o0000ohN7Q`0;oooo
o`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`000003onk^k_oooooooooo
00Gooooo00?o<S8bo`000?nj^[X00_ooool00oo^k^ko0000o`000002ooooo`;o000000CogMgMoooo
oooooooogMgM0_l00004ooooo`06olc<c?n7QhOoIVIVoa0@4?l0003o410@A?ooool2o`0000[ooooo
0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o000000?ok^k^ooooooooool0
1Oooool00olb<S;o0000okZj^P02ooooo`03onk^k_l0003o000000;ooooo0_l000001?oMgMgooooo
oooooooMgMd2o`0005Gooooo2?l00005ooooo`05onk^k_lQ8B7o0000o`000?n7QhL03?ooool2o`00
047ooooo00<00000ooooooooool0G?ooool00;kooooo00<00000ooooooooool09_ooool00olQ8B7o
0000ojVYZ@02ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Co
oooo2?l00002ooooo`06omgMgOm4A4Co0000o`000?lb<S;oIVIV0_l00002ooooo`;o00001?ooool2
o`0000;ooooo00?oZJVYoa0@4?l000001?l000000onHV9Soooooooooo`0jooooo`06onk^k_lb<S;o
0000o`000?mEEEGok^k^2Oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo
2?l00002ooooo`06omgMgOm4A4Co0000o`000?lb<S;oIVIV0_l00002ooooo`;o00001?ooool2o`00
00;ooooo00?oZJVYoa0@4?l000001?l000000onHV9Soooooooooo`12ooooo`;o00002_ooool2o`00
00Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo2?l00002ooooo`06omgMgOm4A4Co0000
o`000?lb<S;oIVIV0_l00002ooooo`;o00001?ooool2o`0005Gooooo00?o8B4Qo`000?nYZJT00_oo
ool2o`0000Oooooo00Kok^k^oc8b<_l0003o0000oeEEEOo^k^h:ooooo`;o0000@Oooool00`00003o
ooooooooo`1Looooo`00__ooool00`00003oooooooooo`0Vooooo`05olc<c?l0003o410@onk^k_oo
ool00_l0000:ooooo`;o00001?ooool2o`000004omgMgOooooooooooooooo`;o00000_ooool2o`00
0004omgMgOooooooooooooooo`;o000000CogMgMooooooooooook^k^0_l00005ooooo`;o^[Zj00?o
IVIVo`000?l000000_ooool2o`000004omgMgOooooooooooomgMg@;o00000_ooool2o`000004ob4Q
8OmVIVKoQhN7okZj^T3ooooo00GoQhN7o`000?l0003o8B4Qonk^kP08ooooo`;o00001?ooool2o`00
0004omgMgOooooooooooooooo`;o00000_ooool2o`000004omgMgOooooooooooooooo`;o000000Co
gMgMooooooooooook^k^0_l00005ooooo`;o^[Zj00?oIVIVo`000?l000000_ooool2o`000004omgM
gOooooooooooomgMg@;o00000_ooool2o`000004ob4Q8OmVIVKoQhN7okZj^TKooooo0_l0000:oooo
o`;o00001?ooool2o`000004omgMgOooooooooooooooo`;o00000_ooool2o`000004omgMgOoooooo
ooooooooo`;o000000CogMgMooooooooooook^k^0_l00005ooooo`;o^[Zj00?oIVIVo`000?l00000
0_ooool2o`000004omgMgOooooooooooomgMg@;o0000EOooool01Oo<c<co0000oa0@4?o^k^kooooo
00;o00002Oooool01On7QhOo0000o`000?lQ8B7ok^k^00Wooooo0_l00011ooooo`0300000?oooooo
oooo05cooooo002nooooo`0300000?oooooooooo02Oooooo00CoMgMgo`000?mgMgOooooo0_l0000:
ooooo`;o00001?ooool2o`000004oeEEEOo^k^koooooogMgM`;o00000_ooool2o`000007oeEEEOo^
k^kooooooooooom4A4Co0000oeEEE@02onk^kP03oeEEEOl0003oA4A400;ooooo0_l000001?n7QhOo
oooooooooonj^[X2o`0000;ooooo00?oA4A4o`000?m4A4@00_o^k^h00om4A4Co0000o`000002oooo
o`;o000000Co^[ZjooooooooooooQhN70_l0000oooooo`04olc<c?l0003o0000ofIVIPSooooo0_l0
0004ooooo`;o000000CoEEEEonk^k_ooooooMgMg0_l00002ooooo`;o000000OoEEEEonk^k_oooooo
ooooodA4A?l0003oEEEE00;ok^k^00?oEEEEo`000?m4A4@00_ooool2o`000004ohN7Qooooooooooo
okZj^P;o00000_ooool00om4A4Co0000odA4A002onk^kP03odA4A?l0003o000000;ooooo0_l00000
1?nj^[[ooooooooooon7QhL2o`0004Cooooo0_l0000:ooooo`;o00001?ooool2o`000004oeEEEOo^
k^koooooogMgM`;o00000_ooool2o`000007oeEEEOo^k^kooooooooooom4A4Co0000oeEEE@02onk^
kP03oeEEEOl0003oA4A400;ooooo0_l000001?n7QhOooooooooooonj^[X2o`0000;ooooo00?oA4A4
o`000?m4A4@00_o^k^h00om4A4Co0000o`00001Fooooo`04ogMgMol0003oMgMgooooo`;o00002_oo
ool01?o<c<co0000o`000?mVIVH9ooooo`;o0000@Oooool00`00003oooooooooo`1Looooo`00__oo
ool00`00003oooooooooo`0Xooooo`03oa0@4?l0003ogMgM00;o00002_ooool2o`0000Cooooo1ol0
00000omEEEGoooooooooo`05o`000003ooooooo<c<co000000Go000000Coc<c<ooooooooooooIVIV
1_l000001?mVIVKoooooooooooo<c<`7o`0000;ooooo00?oIVIVo`000?l000001?l000000omgMgOo
ooooooooo`0nooooo`03okZj^_l0003o000000Sooooo0_l00004ooooo`Oo000000?oEEEEoooooooo
ool01Ol000000oooooooc<c<o`000005o`000004olc<c?ooooooooooofIVIPKo000000CoIVIVoooo
ooooooooc<c<1ol00002ooooo`03ofIVI_l0003o000000Co000000?oMgMgooooooooool0@_ooool2
o`0000[ooooo0_l00004ooooo`Oo000000?oEEEEooooooooool01Ol000000oooooooc<c<o`000005
o`000004olc<c?ooooooooooofIVIPKo000000CoIVIVooooooooooooc<c<1ol0001Gooooo`03oa0@
4?l0003ogMgM00;o00002oooool00onj^[[o0000o`000009ooooo`;o0000@Oooool00`00003ooooo
ooooo`1Looooo`00__ooool00`00003oooooooooo`0Xooooo`03okZj^_l0003o<S8b00;o00002_oo
ool2o`0000Cooooo0_l000001_o<c<co8B4Qo`000?l0003oEEEEonk^kP;ooooo0_l000000oo<c<co
8B4Qo`000002ooooo`06olc<c?m4A4Co0000o`000?m4A4Coc<c<1?ooool01_mgMgOo8B4Qo`000?l0
003o8B4QoiRHV0Cooooo00Go^[Zjob4Q8Ol0003o410@ojVYZ@02o`0000?ooooo00KoMgMgoa0@4?l0
003o0000ob4Q8OmgMgLlooooo`;o000000Cok^k^oooooooooooooooo0_l00008ooooo`;o00001?oo
ool2o`000006olc<c?lQ8B7o0000o`000?mEEEGok^k^0_ooool2o`000003olc<c?lQ8B7o000000;o
oooo00Koc<c<odA4A?l0003o0000odA4A?o<c<`4ooooo`06ogMgMolQ8B7o0000o`000?lQ8B7oV9RH
1?ooool01Onj^[[o8B4Qo`000?l@413oZJVY00;o00000oooool01_mgMgOo410@o`000?l0003o8B4Q
ogMgMd;ooooo1Ol0000:ooooo`;o00001?ooool2o`000006olc<c?lQ8B7o0000o`000?mEEEGok^k^
0_ooool2o`000003olc<c?lQ8B7o000000;ooooo00Koc<c<odA4A?l0003o0000odA4A?o<c<`4oooo
o`06ogMgMolQ8B7o0000o`000?lQ8B7oV9RH1?ooool01Onj^[[o8B4Qo`000?l@413oZJVY00;o0000
Eoooool00onj^[[o0000oc8b<P02o`0000Kooooo0_l000001?o^k^koooooooooooooool2o`0000Ko
oooo1Ol00011ooooo`0300000?oooooooooo05cooooo002nooooo`0300000?oooooooooo02Wooooo
00CoIVIVo`000?l0003o00002_ooool2o`0000Cooooo0_l0000Xooooo`;o0000AOooool02?lb<S;o
0000ofIVI_o^k^kooooooeEEEOl0003o8B4Q2?ooool2o`0000Cooooo0_l0000Xooooo`;o0000Booo
ool5o`0000[ooooo0_l00004ooooo`;o0000:?ooool2o`0005Sooooo00CoIVIVo`000?l0003o0000
1_ooool02?lb<S;o0000ofIVI_o^k^kooooooeEEEOl0003o8B4Q1_ooool5o`00047ooooo00<00000
ooooooooool0G?ooool00;kooooo00<00000ooooooooool0:Oooool01?o^k^ko410@o`000?l00007
ooooo`So000000?oooooo`000?l00000:?ooool2o`0004Gooooo00?oZJVYo`000?l000001?l00000
0onYZJWoooooooooo`03ooooo`So000000?oooooo`000?l00000:?ooool2o`0004cooooo00Coc<c<
oc8b<_l0003o00001oooool8o`000003ooooool0003o000002Sooooo0_l0001Hooooo`04onk^k_l@
413o0000o`0000Kooooo00?oZJVYo`000?l000001?l000000onYZJWoooooooooo`05ooooo`04olc<
c?lb<S;o0000o`00047ooooo00<00000ooooooooool0G?ooool00;kooooo00<00000ooooooooool0
:_ooool00onj^[[o0000o`000007ooooo`So000000?oooooo`000?l00000:?ooool2o`0004Kooooo
00KoZJVYob4Q8Ol0003o0000odA4A?nj^[X6ooooo`So000000?oooooo`000?l00000:?ooool2o`00
04gooooo00?ogMgMo`000?l000001oooool8o`000003ooooool0003o000002Sooooo0_l0001Ioooo
o`03okZj^_l0003o000000Oooooo00KoZJVYob4Q8Ol0003o0000odA4A?nj^[X9ooooo`03omgMgOl0
003o0000047ooooo00<00000ooooooooool0G?ooool00;kooooo00<00000ooooooooool0oooooooo
ooooocCooooo00<00000ooooooooool0G?ooool00;kooooo00<00000ooooooooool0oooooooooooo
ocCooooo00<00000ooooooooool0G?ooool00;kooooo00<00000ooooooooool0ooooooooooooocCo
oooo00<00000ooooooooool0G?ooool00;kooooo00<00000ooooooooool0ooooooooooooocCooooo
00<00000ooooooooool0G?ooool00;kooooo00<00000ooooooooool0ooooooooooooocCooooo00<0
0000ooooooooool0G?ooool00;kooooo00<00000ooooooooool0ooooooooooooocCooooo00<00000
ooooooooool0G?ooool00;kooooo00<00000ooooooooool0ooooooooooooocCooooo00<00000oooo
ooooool0G?ooool00;kooooo00<00000ooooooooool0ooooooooooooocCooooo00<00000oooooooo
ool0G?ooool00;kooooo00<00000ooooooooool0ooooooooooooocCooooo00<00000ooooooooool0
G?ooool00;koooooo`00003o000003P00000G_ooool00?oooooooooooooooooooeGooooo003ooooo
oooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo
003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooo
oeGooooo003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooo
oooooooooeGooooo003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oo
oooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOoo
ool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00oooooooooooooooo
ooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00oooooooo
ooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00
ooooooooooooooooooooEOooool00?ooooooooooool@ooooo`06ogMgMol@413o0000o`000?lQ8B7o
V9RHooooooloooooo`00ooooooooooooo`oooooo00?oMgMgo`000?l000001?l000000omgMgOooooo
ooooo`3ooooooccooooo003ooooooooooooo3oooool2o`000006ojVYZOooooook^k^ogMgMol0003o
410@oooooolnooooo`00ooooooneooooo`?o00001_ooool01_o<c<coA4A4o`000?l0003o8B4QojVY
Z@Cooooo00Ko^[Zjob4Q8Ol0003o0000ob4Q8OnHV9P3ooooo`03ogMgMol0003o000000?ooooo00?o
gMgMoeEEEOl000000_l000000omEEEGogMgMooooo`02ooooo`;o00003_ooool8o`0000;ooooo00Ko
c<c<odA4A?l0003o0000ob4Q8OnYZJT3ooooo`;o00001?ooool2o`0000?ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@02o`0000;ooooo00?oMgMgo`000?l000000_ooool2o`0000Cooooo0_l0003ooooo
oboooooo003ooooookCooooo00Goc<c<o`000?l0003o0000olc<c004ooooo`03olc<c?l0003o0000
00Co000000CoZJVYoooooooooooo^[Zj1_l000000omVIVKoooooooooo`03o`0000;ooooo00?ok^k^
o`000?l000001Ol000000oo^k^koooooooooo`02o`0000kooooo2?l000000oooooooc<c<o`000005
o`000003ojVYZOoooooooooo00;o00001?ooool2o`0000;ooooo00?o^[Zjo`000?l000001Ol00002
ooooo`?o00000_ooool2o`0000Cooooo0_l0003ooooooboooooo003ooooookCooooo00GoQhN7o`00
0?l0003o0000ohN7Q`04ooooo`08odA4A?l0003oEEEEonk^k_ooooooMgMgo`000?l@4102ooooo`06
odA4A?l0003oEEEEonk^k_ooooooZJVY0_l00002ooooo`;o00000oooool02OmEEEGo0000ob4Q8OoM
gMgoooooomgMgOlQ8B7o0000oeEEE@02ooooo`;o00003_ooool2o`0000Oooooo00SoA4A4o`000?mE
EEGok^k^oooooomgMgOo0000oa0@40;ooooo0_l00004ooooo`;o00000_ooool00om4A4Co0000odA4
A002onk^kP03oeEEEOl0003o000000;ooooo0_l00003ooooo`;o00001?ooool2o`000?oooooo;ooo
ool00?oooooo]?ooool01Olb<S;o0000oeEEEOl0003o<S8b00Cooooo0_l000000oo^k^kooooooooo
o`05ooooo`;o000000?ok^k^ooooooooool01Oooool2o`0000?ooooo0_l000001OoMgMgooooooooo
oooooooogMgM00;o00000_ooool2o`0000kooooo0_l00007ooooo`;o000000?ok^k^ooooooooool0
1Oooool2o`0000Cooooo0_l00002ooooo`;o000000CogMgMoooooooooooogMgM0_l00002ooooo`;o
00000oooool2o`0000Cooooo0_l0003ooooooboooooo003ooooookCooooo0_l000000ooMgMgo0000
o`000004ooooo`So00000_ooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo
0_l0000>ooooo`;o00001oooool8o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo
0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0003ooooooboooooo003ooooook?ooooo00Oo
^[Zjo`000?lQ8B7oooooob4Q8Ol0003oZJVY00?ooooo0_l000001?oMgMgoooooooooooo^k^h2o`00
00;ooooo0_l000000oo^k^koooooooooo`05ooooo`;o00000oooool2o`000005omgMgOoooooooooo
oooooooMgMd00_l00002ooooo`;o000000?ogMgMooooooooool02oooool2o`0000Oooooo0_l00000
1?oMgMgoooooooooooo^k^h2o`0000;ooooo0_l000001?o^k^koooooooooooooool2o`0000;ooooo
0_l000001?oMgMgooooooooooooMgMd2o`0000;ooooo0_l00003ooooo`;o000000CogMgMoooooooo
oooooooo0_l0003ooooooboooooo003ooooook?ooooo00OoIVIVo`000?mgMgOoooooogMgMol0003o
IVIV00?ooooo00?oA4A4o`000?mEEED00_o^k^h00omEEEGo0000odA4A002ooooo`06oeEEEOl0003o
EEEEonk^k_ooooooQhN70_l00002ooooo`;o00000oooool02OmEEEGo0000ob4Q8OoMgMgoooooomgM
gOlQ8B7o0000oeEEE@02ooooo`;o000000?oEEEEonk^k_ooool02oooool2o`0000Oooooo00?oA4A4
o`000?mEEED00_o^k^h00omEEEGo0000odA4A002ooooo`;o000000CoEEEEonk^k_ooooooQhN70_l0
0002ooooo`03oeEEEOl0003oEEEE00;ok^k^00?oA4A4o`000?l000000_ooool2o`0000?ooooo0_l0
00001?mEEEGok^k^oooooomgMgL2o`000?oooooo;oooool00?oooooo/oooool01olQ8B7o0000okZj
^_oooooo^[Zjo`000?l@41000oooool00oo<c<co0000o`000004o`000004olc<c?ooooooooooolc<
c0Ko000000?oMgMgooooool000000ol00002ooooo`03onk^k_l0003o000000Go000000?ok^k^oooo
ooooool01Ol0000;ooooo`;o00001oooool00oo<c<co0000o`000004o`000003olc<c?oooooooooo
00Oo000000CoA4A4ooooooooooooc<c<1ol000000ooooooo0000o`000002o`0000;ooooo1ol00000
0omEEEGoooooooooo`3oooooobgooooo003ooooook;ooooo00?ok^k^o`000?l000000oooool2o`00
0006omgMgOooooooooooooooooo<c<coA4A40_l000000om4A4Coc<c<ooooo`03ooooo`06olc<c?m4
A4Co0000o`000?lQ8B7oMgMg0_ooool4o`0000?ooooo00?ogMgMoeEEEOl000000_l000000omEEEGo
gMgMooooo`02ooooo`;o000000?oc<c<ob4Q8Ol000002oooool2o`0000Sooooo00Koc<c<odA4A?l0
003o0000odA4A?o<c<`3ooooo`;o000000Koc<c<oc8b<_l0003o0000oeEEEOo^k^h3ooooo`05ojVY
ZOlQ8B7o0000oa0@4?nj^[X00_l000000ooooooo0000o`000002o`0000;ooooo0_l000001_o<c<co
8B4Qo`000?l0003oEEEEonk^k_oooooo;oooool00?oooooo/_ooool00onHV9So0000odA4A003oooo
o`03odA4A?l0003oV9RH01Kooooo0_l0000Nooooo`;o00009Oooool2o`0000?ooooo0_l0003ooooo
ocGooooo003ooooook;ooooo00?oEEEEo`000?n7QhL00oooool00on7QhOo0000odA4A00Fooooo`;o
00007_ooool2o`0002Gooooo0_l00003ooooo`;o0000ooooooleooooo`00oooooonbooooo`03oa0@
4?l0003oc<c<00?ooooo00?ogMgMo`000?l00000=_ooool2o`0002[ooooo0_l0003oooooocGooooo
003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooo
oeGooooo003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooo
oooooooooeGooooo002Tooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<S_ooool01_nHV9So8B4Q
o`000?l0003oA4A4olc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb
<S;o0000o`000?lb<S;oc<c<Q?ooool2o`0000Cooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3
ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<
c7oooooo0_l00004ooooo`06oiRHV?lQ8B7o0000o`000?m4A4Coc<c<0oooool01_o<c<co<S8bo`00
0?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<ajooooo`So00000_ooool0
1_o<c<co<S8bo`000?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3oooo
o`06olc<c?lb<S;o0000o`000?lb<S;oc<c<9oooool00:?ooooo00?ogMgMo`000?l000001?l00000
0ooMgMgoooooooooo`2:ooooo`03ogMgMol0003o000000Co000000?oc<c<oooooooMgMd01_l00000
0ooMgMgoooooomgMg@06o`000003omgMgOoooooooooo087ooooo0_l00003ooooo`03omgMgOl0003o
000000Co000000?ogMgMoooooooMgMd01_l000000ooMgMgoooooomgMg@06o`000003omgMgOoooooo
oooo07cooooo0_l00003ooooo`03ogMgMol0003o000000Co000000?oc<c<oooooooMgMd01_l00000
0ooMgMgoooooomgMg@06o`000003omgMgOoooooooooo07Oooooo00?o8B4Qo`000?l000001Ol00000
0ooooooogMgMo`000005o`000003omgMgOoooooogMgM00Ko000000?ogMgMoooooooMgMd01_l00000
0ooMgMgoooooooooo`0Tooooo`00Xoooool00omVIVKo0000odA4A002onk^kP03odA4A?l0003oIVIV
08cooooo0_l000002_n7QhOoooooonk^k_mEEEGo0000odA4A?ooooooIVIVo`000?m4A4@2onk^kP07
odA4A?l0003oIVIVoooooomVIVKo0000odA4A002onk^kP03odA4A?l0003oIVIV08?ooooo0_l00003
ooooo`03ofIVI_l0003oA4A400;ok^k^00OoA4A4o`000?mVIVKoooooofIVI_l0003oA4A400;ok^k^
00OoA4A4o`000?mVIVKoooooofIVI_l0003oA4A400;ok^k^00?oA4A4o`000?mVIVH0O_ooool2o`00
00?ooooo0_l000002_n7QhOoooooonk^k_mEEEGo0000odA4A?ooooooIVIVo`000?m4A4@2onk^kP07
odA4A?l0003oIVIVoooooomVIVKo0000odA4A002onk^kP03odA4A?l0003oIVIV07Wooooo00CoIVIV
o`000?l0003oc<c<1Oooool00omVIVKo0000odA4A002onk^kP07odA4A?l0003oIVIVoooooomVIVKo
0000odA4A002onk^kP07odA4A?l0003oIVIVoooooomVIVKo0000odA4A002onk^kP03odA4A?l0003o
IVIV02Kooooo002Sooooo`03oc8b<_l0003o^[Zj00;ooooo00?o^[Zjo`000?lb<S80TOooool01oo^
k^ko0000o`000?oooooo<S8bo`000?nj^[X00_ooool01onj^[[o0000oc8b<_oooooo<S8bo`000?nj
^[X00_ooool00onj^[[o0000oc8b<P23ooooo`;o00000oooool00olb<S;o0000okZj^P02ooooo`07
okZj^_l0003o<S8boooooolb<S;o0000okZj^P02ooooo`07okZj^_l0003o<S8boooooolb<S;o0000
okZj^P02ooooo`03okZj^_l0003o<S8b07kooooo0_l00008ooooo`07onk^k_l0003o0000oooooolb
<S;o0000okZj^P02ooooo`07okZj^_l0003o<S8boooooolb<S;o0000okZj^P02ooooo`03okZj^_l0
003o<S8b07Wooooo00Gok^k^ob4Q8Ol0003o0000ohN7Q`04ooooo`03oc8b<_l0003o^[Zj00;ooooo
00Oo^[Zjo`000?lb<S;ooooooc8b<_l0003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0
003o^[Zj00;ooooo00?o^[Zjo`000?lb<S809_ooool00:?ooooo0_l000001?o^k^kooooooooooooo
ool2o`00097ooooo00Cok^k^o`000?l0003ooooo0_l000001?o^k^koooooooooooooool2o`000004
ooooool0003o0000onk^kP?ooooo0_l00023ooooo`;o00000oooool2o`000004onk^k_oooooooooo
ooooo`;o000000Coooooo`000?l0003ok^k^0oooool2o`000004ooooool0003o0000onk^kP?ooooo
0_l0001nooooo`;o00002?ooool01?o^k^ko0000o`000?ooool2o`000004onk^k_oooooooooooooo
o`;o000000Coooooo`000?l0003ok^k^0oooool2o`0007[ooooo00Kok^k^oc8b<_l0003o0000oeEE
EOo^k^h2ooooo`;o000000Cok^k^oooooooooooooooo0_l000001?oooooo0000o`000?o^k^h3oooo
o`;o000000Coooooo`000?l0003ok^k^0oooool2o`0002Kooooo002Sooooo`;o00001?ooool2o`00
08_ooooo00[o^[Zjo`000?l0003oEEEEooooooo^k^koEEEEo`000?lQ8B7ooooo0_l00004ooooo`;o
000000?oooooo`000?l000001?ooool2o`0008?ooooo0_l00003ooooo`;o00001?ooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000O_ooool2o`0000;o
oooo00[o^[Zjo`000?l0003oEEEEooooooo^k^koEEEEo`000?lQ8B7ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0007cooooo00KoQhN7o`000?l0003o8B4Qonk^k_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`00
02Kooooo002Sooooo`;o00001?ooool2o`0008cooooo1ol000001?nYZJWoooooo`000?l00004oooo
o`;o000000?oooooo`000?l000001?ooool2o`0008?ooooo0_l00003ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000O_ooool2o`00
00?ooooo1ol000001?nYZJWoooooo`000?l00004ooooo`;o000000?oooooo`000?l000001?ooool2
o`0007gooooo00Goc<c<o`000?l0003oIVIVooooo`02o`0000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000001?ooool2o`0002Kooooo002Sooooo`;o00001?ooool2
o`0008cooooo00?o8B4Qo`000?m4A4@00_l000001?lQ8B7oZJVYooooooooool2o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o0000Poooool2o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l0001nooooo`;o00000ooo
ool00olQ8B7o0000odA4A002o`000004ob4Q8OnYZJWoooooooooo`;o00001?ooool2o`000003oooo
ool0003o000000Cooooo0_l0001nooooo`04okZj^_l0003o0000ooooo`;o00001?ooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00009_ooool00:?ooooo
00?o<S8bo`000?nj^[X00_ooool00onj^[[o0000oc8b<P2<ooooo`03odA4A?l0003oV9RH00Kooooo
00?o<S8bo`000?nj^[X00_ooool01onj^[[o0000oc8b<_oooooo<S8bo`000?nj^[X00_ooool00onj
^[[o0000oc8b<P20ooooo`Go00000oooool00olb<S;o0000okZj^P02ooooo`07okZj^_l0003o<S8b
oooooolb<S;o0000okZj^P02ooooo`07okZj^_l0003o<S8boooooolb<S;o0000okZj^P02ooooo`03
okZj^_l0003o<S8b07_ooooo1Ol00003ooooo`03odA4A?l0003oV9RH00Kooooo00?o<S8bo`000?nj
^[X00_ooool01onj^[[o0000oc8b<_oooooo<S8bo`000?nj^[X00_ooool00onj^[[o0000oc8b<P1i
ooooo`;o000000Cok^k^oooooooooooooooo0_l000001?oooooo<S8bo`000?nj^[X2ooooo`07okZj
^_l0003o<S8boooooolb<S;o0000okZj^P02ooooo`07okZj^_l0003o<S8boooooolb<S;o0000okZj
^P02ooooo`03okZj^_l0003o<S8b02Kooooo002Sooooo`03ofIVI_l0003oA4A400;ok^k^00?oA4A4
o`000?mVIVH0S?ooool00omgMgOo0000ogMgM`06ooooo`03ofIVI_l0003oA4A400;ok^k^00OoA4A4
o`000?mVIVKoooooofIVI_l0003oA4A400;ok^k^00?oA4A4o`000?mVIVH0P?ooool5o`0000?ooooo
00?oIVIVo`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`000?m4A4@00_o^k^h01om4
A4Co0000ofIVI_ooooooIVIVo`000?m4A4@00_o^k^h00om4A4Co0000ofIVIP1kooooo`Go00000ooo
ool00omgMgOo0000ogMgM`06ooooo`03ofIVI_l0003oA4A400;ok^k^00OoA4A4o`000?mVIVKooooo
ofIVI_l0003oA4A400;ok^k^00?oA4A4o`000?mVIVH0NOooool03?lb<S;o0000ofIVI_o^k^kooooo
oeEEEOl0003o8B4QoooooomVIVKo0000odA4A0;ok^k^00OoA4A4o`000?mVIVKoooooofIVI_l0003o
A4A400;ok^k^00OoA4A4o`000?mVIVKoooooofIVI_l0003oA4A400;ok^k^00?oA4A4o`000?mVIVH0
9_ooool00:?ooooo00?ogMgMo`000?l000001?l000000ooMgMgoooooooooo`2:ooooo`03okZj^_l0
003o000000Go000000?oooooomgMgOl000001Ol000000ooMgMgoooooomgMg@06o`000003omgMgOoo
oooooooo07oooooo00Coc<c<oc8b<_l0003o00000oooool00ooMgMgo0000o`000004o`000003omgM
gOoooooogMgM00Ko000000?ogMgMoooooooMgMd01_l000000ooMgMgoooooooooo`1jooooo`04olc<
c?lb<S;o0000o`0000?ooooo00?o^[Zjo`000?l000001Ol000000ooooooogMgMo`000005o`000003
omgMgOoooooogMgM00Ko000000?ogMgMooooooooool0Moooool00onYZJWo0000o`000004o`000003
ojVYZOoooooogMgM00Ko000000?ogMgMoooooooMgMd01_l000000ooMgMgoooooomgMg@06o`000003
omgMgOoooooooooo02Cooooo002Tooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<SOooool00ooM
gMgo0000o`000005o`0000;ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb
<S;o0000o`000?lb<S;oc<c<Poooool00ooMgMgo0000o`000004ooooo`06olc<c?lb<S;o0000o`00
0?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b<_l0003o
0000oc8b<_o<c<anooooo`03omgMgOl0003o000000?ooooo00?ogMgMo`000?l000001Ol00002oooo
o`06olc<c?lb<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c7_o
oooo00KoZJVYob4Q8Ol0003o0000odA4A?nj^[X3ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<
0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<
c<`Wooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooo
oooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003o
oooooooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGo
oooo002Gooooool00000o`00002X000001Gooooo002Gooooo`0300000?oooooooooo00kooooo00?o
0000ooooooooool07?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<0
0000ooooooooool07?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<0
0000ooooooooool07?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<0
0000ooooooooool07?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01cooooo00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01cooooo00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo0P00
000Eooooo`00Uoooool00`00003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<00000
ooooooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01cooooo00<00000
ooooooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0Mooooo`8000005Oooool009Oooooo00<00000oooo
ooooool03_ooool00ol0003oooooooooo`0Looooo`0300000?oooooooooo01cooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01cooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool07?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool07?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<00000oooo
ooooool07?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<00000oooo
ooooool07?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<00000oooo
ooooool07Oooool2000001Gooooo002Gooooo`0300000?oooooooooo00kooooo00?o0000oooooooo
ool0VOooool00`00003oooooooooo`2Jooooo`0300000?oooooooooo09[ooooo00<00000oooooooo
ool0V_ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`030000
0?oooooooooo00kooooo00?o0000ooooooooool0VOooool00`00003oooooooooo`2Jooooo`030000
0?oooooooooo09[ooooo00<00000ooooooooool0V_ooool00`00003oooooooooo`0Nooooo`030000
0?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOoo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo0025ooooo`06olc<c?lb<S;o
0000o`000?lb<S;oc<c<3?ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Q?ooool00ooMgMgo0000o`00
0004o`000003omgMgOoooooooooo00Wooooo00<00000ooooooooool03_ooool00omoOgoooooooooo
o`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool008Cooooo00?oIVIV
o`000?m4A4@00_o^k^h00om4A4Co0000ofIVIP0;ooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo0024oooo
o`03oc8b<_l0003o^[Zj00;ooooo00?o^[Zjo`000?lb<S802oooool600000?ooOgmooomoOgnMogmo
O`D000005Oooool008Cooooo0_l000001?o^k^koooooooooooooool2o`0000_ooooo00<00000oooo
ooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooo
ooooool04oooool008Cooooo0_l00004ooooo`;o00002oooool00`00003oooooooooo`0>ooooo`03
ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00
Q?ooool2o`0000Cooooo0_l0000;ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo0024ooooo`;o00001?oo
ool2o`0000_ooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo01kooooo00<00000ooooooooool04oooool008Cooooo00?o<S8bo`000?nj^[X00_ooool0
0onj^[[o0000oc8b<P0;ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0T_oooooo
0<aVc?40c6K<3oooool00`00003oooooooooo`0Cooooo`00Q?ooool00omVIVKo0000odA4A002onk^
kP03odA4A?l0003oIVIV00_ooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`21oooo
ool0c6K<o`3<I/`30<aVc0oooooo00<00000ooooooooool04oooool008Cooooo00?ogMgMo`000?l0
00001?l000000ooMgMgoooooooooo`09ooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool0LOoooolR0<aVc0Kooooo00?oOgmoooooooooool00P3<I/bHooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?o
oooo0025ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<3?ooool00`00003oooooooooo`0>oooo
o`03ogmoOooooooooooo05_ooooo9`3<I/`Gooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooo
ooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Roooooe00
c6K<9oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`030000
0?oooooooooo00kooooo00?oOgmoooooooooool08_oooolj0<aVc3gooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
7_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooo
oooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool0
0`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo
09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003o
ooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003o
ooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003ooooooooo
o`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooooooo
o`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>oooo
o`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Coooo
o`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool4000000gooooo00?oOgmoooooooooool0
VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`0Kooooo`@000005Oooool009Oooooo00<00000ooooooooool03_oo
ool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04ooo
ool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omo
Ogooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oo
oooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01ko
oooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooo
ooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<0
0000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<0
0000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2I
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000oooo
ooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooo
ooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool0
4oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool0
0omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool0
09Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoo
ooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo
00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo
00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooooooo
o`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000
ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000
ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Ioooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000oooooooo
ool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooooooo
ool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo1000000=ooooo`03ogmoOooo
oooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool06oooool4000001Gooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooo
oooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00ko
oooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?o
oooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?o
Ogmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002G
ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0N
ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooo
ooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`03
00000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`03
00000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oo
oooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo
00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo
01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Goooo
o`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Noooo
o`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`030000
0?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`030000
0?oooooooooo01?ooooo002Gooooo`@000003Oooool00omoOgooooooooooo`2Iooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo01_ooooo1000000Eooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooo
oooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00
003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wo
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003ooooo
ooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooo
ooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>
ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03
ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00
Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
7_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooo
oooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool0
0`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo
09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003o
ooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003o
ooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003ooooooooo
o`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooooooo
o`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool07_ooool00`00003oooooooooo`0Cooooo`00J_ooool8o`0000;ooooo00Koc<c<oc8b
<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co
<S8bo`000?l0003o<S8bolc<c0_ooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2I
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006[ooooo00?o8B4Qo`00
0?l000001Ol000000ooooooogMgMo`000005o`000003omgMgOoooooogMgM00Ko000000?ogMgMoooo
oooMgMd01_l000000ooMgMgoooooooooo`08ooooo`0300000?oooooooooo00kooooo00?oOgmooooo
ooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Zooooo`04
ofIVI_l0003o0000olc<c0Gooooo00?oIVIVo`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_oooooo
IVIVo`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`000?m4A4@00_o^k^h00om4A4Co
0000ofIVIP0:ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Zooooo`05onk^k_lQ8B7o0000o`000?n7
QhL01?ooool00olb<S;o0000okZj^P02ooooo`07okZj^_l0003o<S8boooooolb<S;o0000okZj^P02
ooooo`07okZj^_l0003o<S8boooooolb<S;o0000okZj^P02ooooo`03okZj^_l0003o<S8b00[ooooo
1P00003oogmoOoooOgmoWOmoOgl5000001Gooooo001[ooooo`06onk^k_lb<S;o0000o`000?mEEEGo
k^k^0_ooool2o`000004onk^k_ooooooooooooooo`;o000000Coooooo`000?l0003ok^k^0oooool2
o`000004ooooool0003o0000onk^kP?ooooo0_l0000:ooooo`0300000?oooooooooo00kooooo00?o
Ogmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001]
ooooo`06ohN7Qol0003o0000ob4Q8Oo^k^kooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
001^ooooo`05olc<c?l0003o0000ofIVI_ooool00_l00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
001_ooooo`04okZj^_l0003o0000ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000004ooooo`;o00002_ooool00`00003oooooooooo`0>ooooo`03ogmo
Oooooooooooo02;ooooo0P1Vc6Ieooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool0
4oooool006[ooooo0_l000001?o^k^koooooooooooooool2o`000004oooooolb<S;o0000okZj^P;o
oooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b
<_l0003o^[Zj00;ooooo00?o^[Zjo`000?lb<S802_ooool00`00003oooooooooo`0>ooooo`03ogmo
Oooooooooooo02;ooooo0P1Vc6Ieooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool0
4oooool006[ooooo00co<S8bo`000?mVIVKok^k^oooooomEEEGo0000ob4Q8OooooooIVIVo`000?m4
A4@2onk^kP07odA4A?l0003oIVIVoooooomVIVKo0000odA4A002onk^kP07odA4A?l0003oIVIVoooo
oomVIVKo0000odA4A002onk^kP03odA4A?l0003oIVIV00[ooooo00<00000ooooooooool03_ooool0
0omoOgooooooooooo`0Rooooo`80I/aV00?ooooo06K<IP1Vc6H0L_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0N
ooooo`0300000?oooooooooo01?ooooo001Zooooo`03ojVYZOl0003o000000Co000000?oZJVYoooo
oooMgMd01_l000000ooMgMgoooooomgMg@06o`000003omgMgOoooooogMgM00Ko000000?ogMgMoooo
ooooool02?ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo0P1Vc6H00ooo
ool0I/aV06K<IP1booooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006_o
oooo00KoZJVYob4Q8Ol0003o0000odA4A?nj^[X3ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<
0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<
c<`;ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool206K<IP04ooooo`1V
c6H0I/aV06K<IW7ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uooo
ool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo1`1Vc6I`ooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool0
0omoOgooooooooooo`0Sooooo`L0I/aVKoooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooo
oooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool406K<
IP04ooooo`1Vc6H0I/aV06K<IVkooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo101Vc6H2oooo
o`<0I/aVKOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`03
00000?oooooooooo00kooooo00?oOgmoooooooooool08oooool406K<IP?ooooo1`1Vc6IXooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`0Sooooo`@0I/aV1?ooool>06K<IV3ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
7_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooo
oooooooo02?ooooo0`1Vc6H:oooooa00I/aVFOooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool3
06K<IQ;ooooo401Vc6H2ooooo`80I/aVCOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooo
oooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool306K<
IQWooooo3@1Vc6H00oooool0I/aV06K<IP0406K<ITKooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00
003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?o
oooo0`1Vc6HQooooo`D0I/aV00?ooooo06K<IP1Vc6H02`1Vc6Hoooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01ko
oooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooo
ooooo`0Tooooo`80I/aV9?ooool206K<IP03ooooo`1Vc6H0I/aV00?ooooo3`1Vc6Hhooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo1000000=ooooo`03ogmoOooo
oooooooo02;ooooo0P1VI_l206K<IRCooooo1@1Vc6H:ooooo`l0I/aV<Oooool00omoOgoooooooooo
o`02ooooo`<0I/aVUOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool06oooool4000001Gooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool08_ooool206IVo`80I/aV9Oooool406K<IQ7ooooo3P1Vc6H[ooooo`03ogmoOooooooo
oooo00;ooooo1P1Vc6JBooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo
00kooooo00?oOgmoooooooooool08_ooool206IVo`80I/aV9Oooool406K<IQSooooo3P1Vc6HToooo
o`03ogmoOooooooooooo00;ooooo201Vc6J@ooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`03
00000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool206IVobOooooo101Vc6HNooooo`h0
I/aV7Oooool506K<IP03ooooo`1Vc6H0I/aV00?ooooo1P1Vc6J=ooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?o
oooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool206IVobOooooo
101Vc6HUooooo`d0I/aV4Oooool>06K<IPGooooo2P1Vc6J7ooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool206IVobOooooo0`1V
c6H/ooooo`h0I/aV1?ooool=06K<IP03ogmoOoooool0I/aV00<0I/aV2OoooolB06K<IWcooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<0
0000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0R
ooooo`80IVKo9oooool306K<IS;ooooo4`1Vc6H6ooooo`03ogmoOoooool0I/aV00<0I/aV3ooooolG
06K<IW7ooooo00?oOgmoooooooooool01Oooool306K<IY;ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo
00kooooo00?oOgmoooooooooool08_ooool206IVobOooooo0`1Vc6Hiooooo`H0I/aV3?ooool00omo
Ogoooooo06K<IP0306K<IQ[ooooo6@1Vc6ITooooo`03ogmoOooooooooooo00Gooooo1P1Vc6J?oooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Coooo
o`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo0P1VI_lXooooo`80
I/aVBoooool00omoOgoooooo06K<IP0306K<IRGooooo7@1Vc6IEooooo`03ogmoOoooool0I/aV00@0
I/aV00?ooooo06K<IP1Vc6H01P1Vc6J=ooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool03Oooool206K<IPoooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`0Rooooo`80IVKo:?ooool206K<IT_ooooo00?oOgmoooooo`1Vc6H0
0`1Vc6HbooooobP0I/aV>_ooool:06K<IP03ooooo`1Vc6H0I/aV00?ooooo2@1Vc6J7ooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool03Oooool206K<IPoooooo00<00000ooooooooool0
4oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Rooooo`80IVKo:?oo
ool206K<IT_ooooo00?oOgmoooooooooool00`1Vc6I1oooooc00I/aV7_ooool;06K<IP;ooooo0P1V
c6H00oooool0I/aV06K<IP05oooooa80I/aVO?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo00Oooooo1@1Vc6H00oooool0I/aV06K<IP0?ooooo`0300000?oooooooooo01?ooooo002G
ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool206IVobSooooo0P1Vc6I;
ooooo`03ogmoOooooooooooo00<0I/aVFOoooolX06K<IPWooooo2`1Vc6H2ooooo`03ogmoOooooooo
oooo00;ooooo1@1Vc6H;oooooaH0I/aVL_ooool00omoOgooooooooooo`2Jooooo`04ogmoOooooooo
ooooooooo`h0I/aV3oooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>
ooooo`03ogmoOooooooooooo02;ooooo0P1VI_meooooo`03ogmoOooooooooooo0080I/aVLOoooolP
06K<IPOooooo00?oOgmoooooooooool00oooool406K<IQKooooo601Vc6IUooooo`03ogmoOooooooo
oooo09Sooooo3@1Vc6H2ooooo`@0I/aV4?ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo0P1VI_meooooo`03ogmoOooooooooooo
0080I/aVPOooool;06K<IPcooooo00?oOgmoooooooooool00oooool306K<IR7ooooo7P1Vc6HFoooo
ob40I/aV7_oooolQ06K<IWCooooo3@1Vc6H8ooooo`@0I/aV4?ooool00`00003oooooooooo`0Coooo
o`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo0P1VI_meooooo`03
ogmoOooooooooooo0080I/aVV?ooool00omoOgooooooooooo`03ooooo`<0I/aV;_oooooU06K<IQ3o
oooo3@1Vc6H00oooooooOgmoooooo`0;ooooo`@0I/aV4?ooool00`00003oooooooooo`0Cooooo`00
Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo0`1VI_mdooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool00oooool306K<ISkooooo601Vc6HOooooob00I/aV
7ooooomf06K<IPOooooo00?oOgmoooooooooool02_ooool406K<IQ3ooooo00<00000ooooooooool0
4oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`80IVKoM?oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00?ooooo0`1Vc6JDooooo`03ogmoOooo
oooooooo07_ooooo4P1Vc6H=ooooo`03ogmoOooooooooooo00_ooooo0`1Vc6H@ooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool2
06IVogCooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`04ooooo`80I/aVU?ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00_ooooo0P1Vc6HAooooo`0300000?oooooo
oooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool206IV
ogCooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`04ooooo`80I/aVU?ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo00_ooooo0P1Vc6HAooooo`0300000?oooooooooo
01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool206IVogCo
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool02oooool206K<IQ7ooooo00<00000ooooooooool04oooool009Oooooo
1000000=ooooo`03ogmoOooooooooooo02?ooooo0P1VI_mdooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01_ooooo
1000000Eooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P1V
I_mdooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000
ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`80IVKoM?ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0N
ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooo
ooooool08oooool206IVogCooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Coooo
o`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P1VI_mdooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`0Sooooo`80IVKoM?ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`030000
0?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08ooo
ool206IVogCooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P1VI_mdooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omo
Ogooooooooooo`0Sooooo`80IVKoM?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo
01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool206IVogCo
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003ooooo
ooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P1VI_mdooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo
00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooooooo
o`0Sooooo`80IVKoM?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002G
ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool206IVogCooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>oooo
o`03ogmoOooooooooooo02;ooooo00<0ofIV06IVo`1VI_l0M?ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Noooo
o`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool08_ooool00`3oIVH0IVKo06IVo`1dooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooooooo
ool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Rooooo`030?mV
IP1VI_l0IVKo0080IVKoL_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool00`3oIVH0IVKo06IV
o`0206IVog;ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo00<0ofIV06IVo`1VI_l00`1VI_ma
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000oooo
ooooool03_ooool00omoOgooooooooooo`0Rooooo`030?mVIP1VI_l0IVKo00<0IVKoLOooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00ko
oooo00?oOgmoooooooooool08_ooool00`3oIVH0IVKo06IVo`0406IVog3ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool4000000gooooo00?oOgmoooooooooool0
8_ooool00`3oIVH0IVKo06IVo`0406IVog3ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool06oooool4000001Gooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool00`3oIVH0IVKo06IV
o`0506IVofoooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo00<0ofIV06IVo`1VI_l00P1VI_l0
1?ooool0IVKo06IVo`1VI_m^ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04ooo
ool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Rooooo`030?mVIP1VI_l0
IVKo0080IVKo0_ooool206IVofkooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo00<0ofIV06IV
o`1VI_l00P1VI_l2ooooo`<0IVKoKOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo
01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08_ooool20?mVIP<0
IVKo0oooool206IVofgooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00
Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo0P3oIVH306IVo`?ooooo
101VI_m[ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<0
0000ooooooooool03_ooool00omoOgooooooooooo`0Rooooo`80ofIV0`1VI_l4ooooo`@0IVKoJ_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool08_ooool20?mVIP80IVKo1oooool306IVofWooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>oooo
o`03ogmoOooooooooooo02;ooooo0P3oIVH206IVo`Sooooo0`1VI_mXooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoo
ooooooooo`0Rooooo`80ofIV0P1VI_l9ooooo`@0IVKoI_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`03
00000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
8_ooool20?mVIP80IVKo2_ooool406IVofGooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooo
ooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02;ooooo0P3o
IVH206IVo`cooooo0`1VI_mTooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04ooo
ool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`030?mVIP1VI_l0
IVKo00gooooo0`1VI_mSooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool0
09Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`030?mVIP1VI_l0IVKo
00kooooo101VI_mQooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oo
oooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`030?mVIP1VI_l0IVKo00oo
oooo101VI_mPooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo
00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`030?mVIP1VI_l0IVKo017ooooo
0`1VI_mOooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006oooooo0_l0
0003ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8b
olc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`;ooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool08oooool00`3oIVH0IVKo06IVo`0Booooo`<0IVKoG_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`0Nooooo`0300000?oooooooooo01?ooooo001_ooooo`;o00000_ooool00ooMgMgo0000o`00
0004o`000003omgMgOoooooogMgM00Ko000000?ogMgMoooooooMgMd01_l000000ooMgMgooooooooo
o`08ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool00`3oIVH0IVKo06IV
o`0Cooooo`@0IVKoG?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Z
ooooo`So000000CoooooofIVI_l0003oA4A40_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`000?m4
A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`000?m4A4@00_o^k^h00om4A4Co0000ofIVIP0:
ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool20?mVIQGooooo101VI_mK
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006[ooooo2?l000001?oo
oooo<S8bo`000?nj^[X2ooooo`07okZj^_l0003o<S8boooooolb<S;o0000okZj^P02ooooo`07okZj
^_l0003o<S8boooooolb<S;o0000okZj^P02ooooo`03okZj^_l0003o<S8b00[ooooo1P00000aogmo
O`80ofIV5omoOgl306IVooooOgmooomoOgm@ogmoO`D000005Oooool006[ooooo00?o8B4Qo`000?nY
ZJT00_ooool2o`0000;ooooo0_l000001?o^k^koooooooooooooool2o`000004ooooool0003o0000
onk^kP?ooooo0_l000001?oooooo0000o`000?o^k^h3ooooo`;o00002_ooool00`00003ooooooooo
o`0>ooooo`03ogmoOooooooooooo02?ooooo0P3oIVHHooooo`<0IVKoFOooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`0Nooooo`0300000?oooooooooo01?ooooo001Zooooo`05olc<c?l0003o410@onk^k_ooool00_l0
0002ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00002_ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P3o
IVHIooooo`<0IVKoF?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001[
ooooo`04ogMgMol0003oMgMgooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo00<00000ooooooooool03_oo
ool00omoOgooooooooooo`0Sooooo`80ofIV6_ooool406IVoeKooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_oo
ool00`00003oooooooooo`0Cooooo`00K?ooool00ol@413o0000omgMg@02o`0000;ooooo0_l00004
ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l0000:
ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool20?mVIQ_ooooo101VI_mE
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006cooooo00?o^[Zjo`00
0?lb<S800_l00002ooooo`03oc8b<_l0003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0
003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0003o^[Zj00;ooooo00?o^[Zjo`000?lb
<S802_ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P3oIVHMooooo`<0
IVKoE?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001]ooooo`04ofIV
I_l0003o0000o`0000;ooooo00?oIVIVo`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIV
o`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`000?m4A4@00_o^k^h00om4A4Co0000
ofIVIP0:ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool20?mVIQkooooo
0`1VI_l4ooooo`80IVKoCOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
001]ooooo`04onk^k_l@413o0000o`0000;ooooo00?ogMgMo`000?l000001?l000000ooMgMgooooo
omgMg@06o`000003omgMgOoooooogMgM00Ko000000?ogMgMooooooooool02?ooool00`00003ooooo
ooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P3oIVHOooooo`@0IVKo0_ooool206IVodgooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00K_ooool00onj^[[o0000o`00
0003ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8b
olc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`;ooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool08oooool20?mVIPKooooo0P3oIVHHooooo`@0IVKo00Cooooo06IVo`1VI_oo
oooo0`1VI_m9ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo
00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`80ofIV1_ooool20?mVIQ[ooooo
1@1VI_l00oooool0IVKo06IVo`0306IVodOooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooo
ooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P3o
IVH6ooooo`<0ofIV6_ooool406IVo`03ooooo`1VI_l0IVKo00D0IVKoAOooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool08oooool20?mVIPGooooo103oIVHKooooo`<0IVKo00?ooooo06IVo`1VI_l00_ooool5
06IVod?ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P3oIVH5ooooo`@0ofIV7?ooool506IV
o`Cooooo101VI_m2ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oo
oooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`80ofIV1Oooool50?mVIQco
oooo101VI_l6ooooo`@0IVKo@?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?o
oooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool08oooool20?mVIPCooooo
0`3oIVH00oooool0ofIV0?mVIP0Looooo`@0IVKo1oooool506IVockooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
7_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooo
oooooooo02?ooooo0P3oIVH4ooooo`80ofIV0_ooool20?mVIQcooooo101VI_l9ooooo`D0IVKo??oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool08oooool20?mVIPCooooo0P3oIVH2ooooo`<0ofIV6oooool4
06IVo`_ooooo1@1VI_ljooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool0
09Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`80ofIV1?ooool20?mV
IP?ooooo0P3oIVHKooooo`@0IVKo3Oooool506IVocSooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00
003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?o
oooo0P3oIVH3ooooo`<0ofIV0oooool20?mVIQ_ooooo101VI_l?ooooo`D0IVKo=_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool08oooool20?mVIP?ooooo0P3oIVH4ooooo`<0ofIV6_ooool406IVoa7ooooo
101VI_leooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo1000
000=ooooo`03ogmoOooooooooooo02?ooooo0P3oIVH3ooooo`80ofIV1Oooool20?mVIQ[ooooo0`1V
I_lDooooo`@0IVKo<oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Kooooo`@000005Oooool009Oooooo00<00000
ooooooooool03_ooool00omoOgooooooooooo`0Sooooo`80ofIV0_ooool30?mVIPGooooo0P3oIVHJ
ooooo`<0IVKo5Oooool506IVoc7ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P3oIVH2oooo
o`80ofIV1_ooool30?mVIQWooooo0`1VI_lGooooo`D0IVKo;oooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Noooo
o`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool08oooool20?mVIP;ooooo0P3oIVH7ooooo`80ofIV6Oooool306IVoaWooooo1@1VI_l]ooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`0Sooooo`80ofIV0_ooool20?mVIPOooooo0P3oIVHJooooo`80IVKo
6oooool606IVob[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uooo
ool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo0P3oIVH01?ooool0ofIV0?mV
IP3oIVH7ooooo`<0ofIV6Oooool206IVoagooooo1`1VI_lWooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo
00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooooooo
o`0Sooooo`80ofIV00?ooooo0?mVIP3oIVH02Oooool20?mVIQWooooo0P1VI_lPooooo`L0IVKo9?oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool08oooool20?mVIP03ooooo`3oIVH0ofIV00Wooooo0`3oIVHH
ooooo`80IVKo8oooool706IVob7ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02?ooooo1@3oIVH:oooo
o`80ofIV6?ooool206IVobKooooo1`1VI_lNooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooo
ooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Tooooo`<0
ofIV2oooool20?mVIQSooooo0P1VI_lYooooo`L0IVKo6oooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`03
00000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
9?ooool30?mVIP_ooooo0`3oIVI5ooooo`L0IVKo6?ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`030000
0?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool09?oo
ool30?mVIPcooooo0P3oIVI8ooooo`L0IVKo5?ooool506IVoiWooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04ooo
ool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Tooooo`<0ofIV3?ooool2
0?mVIT_ooooo1`1VI_l;ooooo`/0IVKo00?ooooo06IVo`1VI_l0301VI_n:ooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooo
oooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool09?ooool30?mV
IPcooooo0`3oIVI=ooooo`L0IVKo0_ooool=06IVo`05ogmoOoooool0IVKo06IVooooool04@1VI_n7
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0N
ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooo
ooooool09?ooool30?mVIPgooooo0P3oIVI@ooooo`d0IVKo1_ooool01OmoOgoooooo06IVo`1VI_oo
oooo0080IVKo2oooool806IVoh?ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool001Oooooo0_l00002oooo
o`03oa0@4?l0003o8B4Q00;ooooo0_l00002ooooo`;o00001oooool8o`0000?ooooo00?o^[ZjodA4
A?l000000_l000000om4A4Co^[Zjooooo`03ooooo`;o00002_ooool00oo^k^koIVIVob4Q8@02o`00
0003oa0@4?mEEEGogMgM043ooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Toooo
o`<0ofIV3Oooool20?mVIU?ooooo101VI_l<ooooo`05ogmoOoooool0IVKo06IVooooool00P1VI_l>
ooooo`P0IVKoP?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool07_ooool00`00003oooooooooo`0Cooooo`005oooool2o`000003ooooooo^k^ko0000
00;o000000Cok^k^ooooool0003o00000_ooool2o`0000Oooooo2?l00002ooooo`03oiRHV?l0003o
000000Go000000CoV9RHoooooooooooooooo0_l00009ooooo`03olc<c?l0003o000000Ko000000?o
c<c<ooooooooool0?Oooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02Cooooo0`3o
IVH=ooooo`<0ofIVH_ooool01OmoOgoooooo06IVo`1VI_oooooo0080IVKo4_ooool806IVogcooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo
00<00000ooooooooool04oooool001Oooooo0_l000000oooooooZJVYo`000002o`000004ojVYZOoo
oooo0000o`0000;ooooo0_l00007ooooo`;o00001oooool02?oMgMgo0000o`000?mVIVKogMgMoooo
oooMgMgoIVIV0_l000000oo<c<coooooooooo`02o`0000Wooooo00CoA4A4o`000?lQ8B7oc<c<0_oo
ool01?oMgMgoEEEEo`000?lQ8B4oooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
9?ooool30?mVIPkooooo0P3oIVIRooooo`05ogmoOoooool0IVKo06IVooooool00P1VI_lEooooo`T0
IVKoN?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool07_ooool00`00003oooooooooo`0Cooooo`005oooool2o`000007oooooomgMgOo0000odA4A?l0
003oMgMgooooo`02o`0000;ooooo0_l00007ooooo`;o00001oooool00omEEEGo0000odA4A005oooo
o`03odA4A?l0003oEEEE00;ooooo0_l00009ooooo`;o000000?ogMgMooooooooool00oooool2o`00
03oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Tooooo`<0ofIV3_ooool20?mV
IV;ooooo00?oOgmoooooo`1VI_l0101VI_lIooooo`P0IVKoMOooool00omoOgooooooooooo`05oooo
o`80IVKoToooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooo
ooooool04oooool001Oooooo0_l000001ooooooo<S8bo`000?o<c<co0000oc8b<_ooool00_l00002
ooooo`;o00001oooool2o`0000Oooooo00?o410@o`000?o<c<`01Oooool00oo<c<co0000oa0@4002
ooooo`Ko000000?o<S8bojVYZOooool02?ooool01?nj^[[oEEEEo`000?l0000oooooo`0300000?oo
oooooooo00kooooo00?oOgmoooooooooool09?ooool20?mVIPoooooo0`3oIVIQooooo`03ogmoOooo
ool0IVKo00<0IVKo7_ooool806IVog7ooooo00?oOgmoooooooooool01Oooool306IVoi;ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo000G
ooooo`;o000000Ooooooo`000?lQ8B7oooooob4Q8Ol0003ooooo00;o00000_ooool7o`0000;ooooo
0_l00007ooooo`;o00001oooool2o`0000;ooooo2?l000002?nYZJWoooooooooooooooooc<c<ogMg
Molb<S;o410@1?l000000omgMgOoooooooooo`0mooooo`@000003Oooool00omoOgooooooooooo`0T
ooooo`80ofIV4?ooool20?mVIV7ooooo00?oOgmoooooo`1VI_l00`1VI_lQooooo`P0IVKoK_ooool0
0omoOgooooooooooo`05ooooo`@0IVKoTOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo01_ooooo1000000Eooooo`005oooool2o`000007olc<c?l0003oIVIVoooooomgMgOo0000olc<
c002o`0000;ooooo1ol00002ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00000ooo
ool01?o^k^koEEEEo`000?lQ8B42ooooo`03oiRHV?l0003o000000?o000000?o<S8bofIVI_nj^[X0
@?ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02Cooooo0P3oIVH@ooooo`80ofIV
HOooool00omoOgoooooo06IVo`0306IVobGooooo201VI_mZooooo`03ogmoOooooooooooo00Gooooo
1@1VI_n@ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooo
ooooo`0Cooooo`005oooool2o`000007ohN7Qol0003o^[Zjoooooonj^[[o0000ohN7Q`02o`0000;o
oooo0_l00007ooooo`;o00001oooool00ol@413o0000olc<c005ooooo`03olc<c?l0003o410@00;o
oooo0_l00004ooooo`03onk^k_l0003o000000;ooooo00Go410@o`000?m4A4CoZJVYomgMg@14oooo
o`0300000?oooooooooo00kooooo00?oOgmoooooooooool09?ooool20?mVIQ3ooooo0`3oIVIPoooo
o`03ogmoOoooool0IVKo00<0IVKo:?ooool806IVofOooooo00?oOgmoooooooooool01Oooool206IV
o`04ooooo`1VI_l0IVKo06IVohoooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0N
ooooo`0300000?oooooooooo01?ooooo000Gooooo`;o000000?oA4A4o`000?ooool00_ooool01?l0
003oEEEEo`000?l00002ooooo`;o00001oooool2o`0000Oooooo00?oEEEEo`000?m4A4@01Oooool0
0om4A4Co0000oeEEE@02ooooo`;o00001?ooool00oo^k^ko0000o`000002ooooo`;o00001Oooool0
0ooMgMgo0000o`00000oooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool09?ooool2
0?mVIQ7ooooo0P3oIVIPooooo`03ogmoOooooooooooo00<0IVKo;?ooool806IVof?ooooo00?oOgmo
ooooooooool01Oooool206IVo`;ooooo0`1VI_n>ooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool07_ooool00`00003oooooooooo`0Cooooo`005oooool2o`000003oa0@4?m4A4Cooooo
00;ooooo00CoA4A4oa0@4?l0003o00000_ooool2o`0000Oooooo0_l00007ooooo`08olc<c?l0003o
0000ofIVI_oMgMgoooooomgMgOmVIVH2o`000003olc<c?oooooooooo00;o00000oooool01?o^k^ko
EEEEo`000?lQ8B42ooooo`04ob4Q8Ol0003oEEEEomgMg@;ooooo00CoZJVYob4Q8Ol0003oEEEE?ooo
ool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo02Cooooo0P3oIVHAooooo`<0ofIVGooo
ool00omoOgooooooooooo`0306IVoboooooo201VI_mPooooo`03ogmoOooooooooooo00Gooooo0P1V
I_l3ooooo`<0IVKoSOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<0
0000ooooooooool04oooool001Oooooo0ol000001OnHV9SoooooooooooooooooQhN700?o00000_oo
ool8o`000003ooooool0003o000000Sooooo00?oV9RHo`000?l000001Ol000001?nHV9Sooooooooo
ooooool8o`000004ojVYZOoooooooooookZj^POo000000?o410@omgMgOooool0?_ooool00`00003o
ooooooooo`0>ooooo`03ogmoOooooooooooo02Cooooo0P3oIVHBooooo`80ofIVGoooool00omoOgoo
ooooooooo`0306IVoc?ooooo201VI_mLooooo`03ogmoOooooooooooo00Gooooo0P1VI_l4ooooo`D0
IVKoR_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooooooo
ool04oooool001Oooooo0ol000001OoMgMgoooooooooooooooooc<c<00?o00000_ooool8o`000003
ooooool0003o000000Wooooo00?o^[ZjodA4A?l000000_l000000om4A4Co^[Zjooooo`03ooooo`Ko
000000?o8B4QojVYZOooool00oooool00oo<c<coEEEEoa0@4002o`000003ob4Q8OmgMgOok^k^043o
oooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0Tooooo`80ofIV4_ooool20?mVIUoo
oooo00?oOgmoooooooooool00`1VI_lfooooo`P0IVKoFOooool00omoOgooooooooooo`05ooooo`80
IVKo1Oooool706IVohOooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0=ooooo`80
IVKo3oooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmo
Oooooooooooo03Sooooo0`3oIVINooooo`03ogmoOooooooooooo00<0IVKo>_ooool706IVoeKooooo
00?oOgmoooooo`1VI_l0101VI_l00oooool0IVKo06IVo`08ooooo`L0IVKoQ?ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo00gooooo0P1VI_l?ooooo`0300000?oooooooooo01?ooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0>Oooool20?mVIUkooooo00?o
Ogmoooooooooool00`1VI_lmooooo`P0IVKoCoooool:06IVo`03ooooo`1VI_l0IVKo00_ooooo1`1V
I_n1ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool03Oooool206IVo`oooooo00<0
0000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0i
ooooo`80ofIVG_ooool00omoOgooooooooooo`0206IVod7ooooo201VI_m7ooooo`/0IVKo0_ooool2
06IVo`03ooooo`1VI_l0IVKo00kooooo1`1VI_mnooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool03Oooool206IVo`oooooo00<00000ooooooooool04oooool009Oooooo00<00000oooo
ooooool03_ooool00omoOgooooooooooo`0iooooo`<0ofIVGOooool00omoOgooooooooooo`0206IV
odGooooo5P1VI_l`ooooo`/0IVKo0_ooool00omoOgooooooooooo`02ooooo`80IVKo00?ooooo06IV
o`1VI_l04Oooool706IVog_ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0=oooo
o`80IVKo3oooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03
ogmoOooooooooooo03[ooooo0P3oIVIMooooo`03ogmoOooooooooooo0080IVKoB?oooom906IVo`Oo
oooo00?oOgmoooooooooool00_ooool506IVoaCooooo1`1VI_mhooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool02Oooool306IVo`03ooooo`1VI_l0IVKo00oooooo00<00000oooooooo
ool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0jooooo`80ofIV
GOooool00omoOgooooooooooo`0206IVoe[ooooo<P1VI_l<ooooo`03ogmoOooooooooooo00;ooooo
101VI_lHooooo`L0IVKoMOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00Oooooo
201VI_l?ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?o
Ogmoooooooooool0>_ooool30?mVIUcooooo00?oOgmoooooooooool00P1VI_nHooooo`03ogmoOooo
oooooooo00?ooooo0`1VI_lKooooo`L0IVKoL_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo00Cooooo2P1VI_l@ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0>oooool20?mVIUcooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`03ooooo`<0IVKo7_ooool706IVofoooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`02ooooo`H0IVKo0_ooool406IVoa3ooooo00<00000ooooooooool04oooool0
09Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0kooooo`80ofIVG?ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo00?ooooo0`1VI_lQooooobh0IVKoAOooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo00D0IVKo1Oooool406IVoa3ooooo00<00000oooo
ooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0kooooo`<0
ofIVFoooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00?ooooo0`1VI_lTooooocX0
IVKo=_ooool00omoOgooooooooooo`2Jooooo`H0IVKo1oooool406IVoa3ooooo00<00000oooooooo
ool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`0looooo`80ofIV
Foooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00?ooooo0`1VI_m>ooooodP0IVKo
VOooool606IVo`Wooooo101VI_l@ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oo
oooooooo00kooooo00?oOgmoooooooooool0??ooool20?mVIU_ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`03ooooo`<0IVKoGOoooom@06IVoh3ooooo1@1VI_l<ooooo`@0IVKo4?oo
ool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooo
oooo03cooooo0`3oIVH>ooooo`80ofIVB_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo00?ooooo0`1VI_nDooooo`03ogmoO`1VI_l0IVKo02D0IVKoK_ooool606IVo`03oooooomoOgoo
oooo00_ooooo101VI_l@ooooo`0300000?oooooooooo01?ooooo002Gooooo`@000003Oooool00omo
Ogooooooooooo`0mooooo`80ofIV3_ooool20?mVIT[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`04ooooo`80IVKoU?ooool00omoOgooooooooooo`0Eooooob00IVKoG?ooool606IV
o`?ooooo00?oOgmoooooooooool02_ooool406IVo`gooooo1000000Eooooo`00Uoooool00`00003o
ooooooooo`0>ooooo`03ogmoOooooooooooo03gooooo0P3oIVH>ooooo`<0ofIVBOooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo00Cooooo0P1VI_nDooooo`03ogmoOooooooooooo02Co
oooo8@1VI_lFoooooaH0IVKo7_ooool506IVo`Kooooo00?oOgmoooooooooool02oooool306IVoa3o
oooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooo
ooooo`0mooooo`<0ofIV3Oooool30?mVITWooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`04ooooo`80IVKoU?ooool00omoOgooooooooooo`0dooooodP0IVKo4?ooool606IVo`Sooooo
00?oOgmoooooooooool02oooool306IVoa3ooooo00<00000ooooooooool04oooool009Oooooo00<0
0000ooooooooool03_ooool00omoOgooooooooooo`0nooooo`80ofIV3Oooool30?mVITWooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`04ooooo`80IVKoU?ooool00omoOgoooooooooo
o`14oooooaP0IVKo5?oooolF06IVo`Cooooo1P1VI_l:ooooo`03ogmoOooooooooooo00_ooooo0`1V
I_l@ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0?_ooool30?mVIPcooooo103oIVI8ooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`1koooooa80IVKo3Oooool00omoOgooooooooooo`0;
ooooo`80IVKo4Oooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>oooo
o`03ogmoOooooooooooo03oooooo0P3oIVH<ooooo`@0ofIVB?ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0QOooool606IVo`oooooo00?oOgmooooo
ooooool02oooool206IVoa7ooooo00<00000ooooooooool04oooool009Oooooo00<00000oooooooo
ool03_ooool00omoOgooooooooooo`0oooooo`80ofIV3?ooool40?mVITSooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool02oooool206IVoa7ooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`0oooooo`<0ofIV2oooool50?mVITOooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
2oooool206IVoa7ooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_oo
ool00omoOgooooooooooo`10ooooo`80ofIV2oooool20?mVIP03ooooo`3oIVH0ofIV04Oooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool02oooool206IVoa7ooooo00<00000ooooooooool04oooool009Oooooo00<00000
ooooooooool03_ooool00omoOgooooooooooo`10ooooo`80ofIV2oooool20?mVIP03ooooo`3oIVH0
ofIV04Oooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool02oooool206IVoa7ooooo00<00000ooooooooool04oooool0
09Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`10ooooo`<0ofIV2_ooool20?mV
IP04ooooo`3oIVH0ofIV0?mVITKooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo047ooooo0P3oIVH:oooo
o`80ofIV0_ooool20?mVITKooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Coooo
o`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo047ooooo0P3oIVH:ooooo`80
ofIV0_ooool30?mVITGooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00
Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo047ooooo0`3oIVH9ooooo`80ofIV
0oooool20?mVITGooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uooo
ool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04;ooooo0P3oIVH9ooooo`80ofIV0ooo
ool20?mVITGooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04;ooooo0P3oIVH9ooooo`80ofIV0oooool3
0?mVITCooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo04;ooooo0`3oIVH8ooooo`80ofIV1?ooool20?mV
ITCooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Joooool01_o^k^ko
A4A4o`000?l0003o8B4QokZj^P?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3ooooo`06olc<
c?lb<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0_ooooo00<0
0000ooooooooool03_ooool00omoOgooooooooooo`13ooooo`80ofIV2?ooool20?mVIPCooooo0P3o
IVI4ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006[ooooo00?ok^k^
ob4Q8Ol000001?l000000oo<c<coooooomgMg@06o`000003omgMgOoooooogMgM00Ko000000?ogMgM
oooooooMgMd01_l000000ooMgMgoooooooooo`08ooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0@oooool20?mVIPSooooo0P3oIVH4ooooo`<0ofIV@oooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0N
ooooo`0300000?oooooooooo01?ooooo001Zooooo`03ohN7Qol0003oEEEE00;ok^k^00OoEEEEo`00
0?m4A4CoooooofIVI_l0003oA4A400;ok^k^00OoA4A4o`000?mVIVKoooooofIVI_l0003oA4A400;o
k^k^00OoA4A4o`000?mVIVKoooooofIVI_l0003oA4A400;ok^k^00?oA4A4o`000?mVIVH02_ooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04?ooooo0`3oIVH7ooooo`80ofIV1Oooool2
0?mVIT?ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00J_ooool00olb
<S;o0000onk^kP02ooooo`07onk^k_l0003o0000oooooolb<S;o0000okZj^P02ooooo`07okZj^_l0
003o<S8boooooolb<S;o0000okZj^P02ooooo`07okZj^_l0003o<S8boooooolb<S;o0000okZj^P02
ooooo`03okZj^_l0003o<S8b00[ooooo1P00001BogmoO`80ofIV1omoOgl20?mVIPGoOgmo0P3oIVKo
ogmoOoooOgmo>OmoOgl5000001Gooooo001Zooooo`;o000000Cok^k^ooooooooooook^k^0_l00000
1?oooooo0000o`000?o^k^h3ooooo`;o000000Coooooo`000?l0003ok^k^0oooool2o`000004oooo
ool0003o0000onk^kP?ooooo0_l0000:ooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool0A?ooool30?mVIPKooooo0P3oIVH5ooooo`<0ofIV@_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`03
00000?oooooooooo01?ooooo001Zooooo`;o000000OoEEEEonk^k_o^k^koEEEEo`000?lQ8B7ooooo
00;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00002_ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04Gooooo0P3oIVH6oooo
o`80ofIV1_ooool20?mVIT;ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Coooo
o`00J_ooool7o`000004ojVYZOoooooo0000o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo00<00000ooooooooool03_ooool00omo
Ogooooooooooo`15ooooo`80ofIV1_ooool20?mVIPKooooo0`3oIVI1ooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
01kooooo00<00000ooooooooool04oooool006[ooooo0_l000001On7QhOo410@o`000?lQ8B7oZJVY
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00Cooooo0_l0000:ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0AOooool30?mV
IPGooooo0P3oIVH7ooooo`80ofIV@Oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo
01?ooooo001Zooooo`03odA4A?l0003oZJVY00Kooooo00?o<S8bo`000?nj^[X00_ooool01onj^[[o
0000oc8b<_oooooo<S8bo`000?nj^[X00_ooool01onj^[[o0000oc8b<_oooooo<S8bo`000?nj^[X0
0_ooool00onj^[[o0000oc8b<P0:ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
A_ooool20?mVIPGooooo0P3oIVH7ooooo`80ofIV@Oooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`030000
0?oooooooooo01?ooooo001Zooooo`06oiRHV?l0003o8B4QomgMgOooooooV9RH0_l000001?oooooo
IVIVo`000?m4A4@2onk^kP07odA4A?l0003oIVIVoooooomVIVKo0000odA4A002onk^kP07odA4A?l0
003oIVIVoooooomVIVKo0000odA4A002onk^kP03odA4A?l0003oIVIV00[ooooo00<00000oooooooo
ool03_ooool00omoOgooooooooooo`16ooooo`80ofIV1Oooool20?mVIPOooooo0`3oIVI0ooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006_ooooo00?o8B4Qo`000?l00000
0ol000000omgMgOoooooomgMg@06o`000003omgMgOoooooogMgM00Ko000000?ogMgMoooooooMgMd0
1_l000000ooMgMgoooooooooo`08ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
A_ooool30?mVIP04ooooo`3oIVH0ofIVooooo`80ofIV2?ooool20?mVIT3ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool07_ooool00`00003oooooooooo`0Cooooo`00Joooool01_o^k^koIVIVo`000?l0003o410@ogMg
M`?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb<S;o0000o`000?lb<S;o
c<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0_ooooo00<00000ooooooooool03_ooool0
0omoOgooooooooooo`17ooooo`80ofIV00Cooooo0?mVIP3oIVKooooo0P3oIVH8ooooo`80ofIV@?oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0Aoooool20?mVIP04ooooo`3oIVH0ofIVooooo`80ofIV2?oo
ool30?mVISoooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04Oooooo1@3oIVH00oooool0ofIV0?mVIP09
ooooo`80ofIV?oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Goooo
o`0300000?oooooooooo00kooooo00?oOgmoooooooooool0B?ooool40?mVIP03ooooo`3oIVH0ofIV
00Wooooo0P3oIVHoooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oo
oooo00<00000ooooooooool03_ooool00omoOgooooooooooo`18ooooo`@0ofIV00?ooooo0?mVIP3o
IVH02Oooool30?mVISkooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00
Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04Sooooo103oIVH00oooool0ofIV
0?mVIP0:ooooo`80ofIV?_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0BOooool30?mVIP03ooooo`3o
IVH0ofIV00[ooooo0`3oIVHmooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04ooo
ool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`19ooooo`H0ofIV2oooool2
0?mVISgooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo04Wooooo1@3oIVH<ooooo`80ofIV?Oooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00ko
oooo00?oOgmoooooooooool0B_ooool40?mVIPcooooo0`3oIVHlooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01ko
oooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooo
ooooo`1:ooooo`@0ofIV3Oooool20?mVIScooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooo
ooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04[ooooo103o
IVH=ooooo`80ofIV??ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002G
ooooo`@000003Oooool00omoOgooooooooooo`1;ooooo`<0ofIV3Oooool30?mVIS_ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool06oooool4000001Gooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooo
ooooool0Boooool30?mVIPkooooo0P3oIVHkooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooo
ooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1;ooooo`<0
ofIV3_ooool20?mVIS_ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00
Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04_ooooo0`3oIVH>ooooo`<0ofIV
>_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oo
oooooooo00kooooo00?oOgmoooooooooool0Boooool30?mVIPoooooo0P3oIVHjooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool0
0omoOgooooooooooo`1;ooooo`<0ofIV3oooool30?mVISWooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool0
0`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo
04_ooooo0`3oIVH@ooooo`80ofIV>Oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo
01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0Boooool30?mVIQ3o
oooo0P3oIVHiooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo
00<00000ooooooooool03_ooool00omoOgooooooooooo`1;ooooo`<0ofIV4?ooool30?mVISSooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003ooooooooo
o`0>ooooo`03ogmoOooooooooooo04_ooooo0`3oIVHAooooo`80ofIV>?ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0Boooool30?mVIQ7ooooo0P3oIVHhooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000
ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1;oooo
o`<0ofIV4Oooool30?mVISOooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Coooo
o`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04_ooooo0`3oIVHBooooo`80
ofIV=oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`030000
0?oooooooooo00kooooo00?oOgmoooooooooool0Boooool30?mVIQ;ooooo0P3oIVHgooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_oo
ool00omoOgooooooooooo`1;ooooo`<0ofIV4_ooool30?mVISKooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_oo
ool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooo
oooo04_ooooo0`3oIVHCooooo`80ofIV=_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooo
oooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0Boooool30?mV
IQ?ooooo0`3oIVHeooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oo
oooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1;ooooo`<0ofIV5?ooool20?mVISGo
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003ooooo
ooooo`0>ooooo`03ogmoOooooooooooo04_ooooo0`3oIVHDooooo`80ofIV=Oooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?o
Ogmoooooooooool0Boooool30?mVIQCooooo0`3oIVHdooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<0
0000ooooooooool04oooool009Oooooo1000000=ooooo`03ogmoOooooooooooo04_ooooo0`3oIVHE
ooooo`80ofIV=?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`0Kooooo`@000005Oooool009Oooooo00<00000oooo
ooooool03_ooool00omoOgooooooooooo`1<ooooo`80ofIV5Oooool20?mVISCooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03
ogmoOooooooooooo04cooooo0P3oIVHEooooo`<0ofIV<oooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`03
00000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
C?ooool20?mVIQKooooo0P3oIVHcooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool0
4oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1<ooooo`80ofIV5_oo
ool20?mVIS?ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04cooooo0P3oIVHFooooo`<0ofIV8Oooool3
0?mVIPkooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo04cooooo0P3oIVHGooooo`80ofIV7_ooool60?mV
IPkooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003o
ooooooooo`0>ooooo`03ogmoOooooooooooo04cooooo0P3oIVHGooooo`<0ofIV6_ooool:0?mVIPgo
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003ooooo
ooooo`0>ooooo`03ogmoOooooooooooo04cooooo0P3oIVHHooooo`80ofIV5oooool70?mVIPCooooo
0`3oIVH<ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<0
0000ooooooooool03_ooool00omoOgooooooooooo`1<ooooo`80ofIV6?ooool20?mVIQCooooo1`3o
IVH8ooooo`<0ofIV2oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002G
ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0C?ooool20?mVIQSooooo0`3oIVH@
ooooo`L0ofIV3?ooool30?mVIP[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2J
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo04cooooo0P3oIVHIoooo
o`80ofIV3Oooool70?mVIQ3ooooo0`3oIVH9ooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooo
ooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1Wooooo`80
ofIV2_ooool70?mVIQCooooo0`3oIVH8ooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000oooooooo
ool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1Wooooo`<0ofIV
1_ooool70?mVIQSooooo0`3oIVH7ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool0
4oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1Xooooo`80ofIV0ooo
ool70?mVIQcooooo0`3oIVH6ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04ooo
ool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`1Xooooo`T0ofIV8?ooool3
0?mVIPGooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo06Sooooo1P3oIVHTooooo`80ofIV1Oooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00ko
oooo00?oOgmoooooooooool0JOooool20?mVIROooooo0`3oIVH4ooooo`03ogmoOooooooooooo09[o
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01ko
oooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooo
ooooo`2Cooooo`<0ofIV0oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0U?ooool30?mVIP;ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool4000000gooooo00?oOgmo
ooooooooool0UOooool30?mVIP03oooooomoOgoooooo09_ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01_ooooo1000000Eooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo09Kooooo0`3oIVH00omoOgooooooooooo`2Joooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Noooo
o`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool0Uoooool30?mVIYcooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`2Hooooo`<0ofIVVoooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uooo
ool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo0`3oIVJJooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
1?moOgl0ofIV0?mVIP3oIVJIooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool01?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
1?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool01?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
1?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool01?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
1?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool01?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
1?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool01?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
1?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool01?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooo
oooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oo
oooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool0
1?moOgoooooo0?mVIP3oIVJIooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001[ooooo`06oiRHV?lQ8B7o
0000o`000?lQ8B7oZJVY0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b
<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb<S;o0000o`000?lb<S;oc<c<2oooool00`00003o
ooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00CoOgmoooooo`3oIVH0ofIVBOooool30?mV
ITgooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
01kooooo00<00000ooooooooool04oooool006[ooooo00?oQhN7o`000?l000001?l000000onHV9So
ooooomgMg@06o`000003omgMgOoooooogMgM00Ko000000?ogMgMoooooooMgMd01_l000000ooMgMgo
ooooooooo`08ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool01?moOgoo
oooo0?mVIP3oIVI8ooooo`@0ofIVCOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00J_ooool00ol@413o
0000ogMgM`02ooooo`07ogMgMol0003o410@oooooomVIVKo0000odA4A002onk^kP07odA4A?l0003o
IVIVoooooomVIVKo0000odA4A002onk^kP07odA4A?l0003oIVIVoooooomVIVKo0000odA4A002onk^
kP03odA4A?l0003oIVIV00[ooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Ioooo
o`03ogmoOoooool0ofIV0080ofIVA_ooool60?mVITcooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006[o
oooo0_l00004ooooo`;o000000Cooooooc8b<_l0003o^[Zj0_ooool01onj^[[o0000oc8b<_oooooo
<S8bo`000?nj^[X00_ooool01onj^[[o0000oc8b<_oooooo<S8bo`000?nj^[X00_ooool00onj^[[o
0000oc8b<P0:ooooo`H00000Z_moOgl20?mVITCoOgmo103oIVH2ogmoO`80ofIVoomoOgnTogmoO`D0
00005Oooool006[ooooo00?o410@o`000?mgMgL00_ooool01?mgMgOo0000ob4Q8Oooool2o`000004
onk^k_ooooooooooooooo`;o000000Coooooo`000?l0003ok^k^0oooool2o`000004ooooool0003o
0000onk^kP?ooooo0_l0000:ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOoo
ool00omoOgooooooooooo`020?mVIT?ooooo103oIVH3ooooo`<0ofIVBoooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooooooo
o`0Cooooo`00J_ooool00onHV9So0000o`000004o`000004ojVYZOoooooo0000o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo00<0
0000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo0080ofIV@_oo
ool30?mVIPKooooo0`3oIVI:ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Zooooo`03olc<c?l0003o
000000Co000000Coc<c<ooooool0003o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o00002_ooool00`00003oooooooooo`0>ooooo`03ogmoOooo
oooooooo09Wooooo00?oOgmoooooooooool02@3oIVHiooooo`@0ofIV2?ooool20?mVIT[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<0
0000ooooooooool04oooool006[ooooo00?o<S8bo`000?mgMgL00_ooool01?mgMgOo0000ob4Q8Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000[ooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooo
oooooooo00l0ofIV<_ooool40?mVIPWooooo0`3oIVI9ooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Z
ooooo`;o00001?ooool2o`000004oooooolb<S;o0000okZj^P;ooooo00Oo^[Zjo`000?lb<S;ooooo
oc8b<_l0003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0003o^[Zj00;ooooo00?o^[Zj
o`000?lb<S802_ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmo
ooooooooool0103oIVH4ooooo`T0ofIV;oooool30?mVIPcooooo0P3oIVI9ooooo`03ogmoOooooooo
oooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooo
oooo01?ooooo001Zooooo`03oa0@4?l0003oMgMg00;ooooo00OoMgMgo`000?l@413oooooofIVI_l0
003oA4A400;ok^k^00OoA4A4o`000?mVIVKoooooofIVI_l0003oA4A400;ok^k^00OoA4A4o`000?mV
IVKoooooofIVI_l0003oA4A400;ok^k^00?oA4A4o`000?mVIVH02_ooool00`00003oooooooooo`0>
ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0103oIVH:ooooo`D0ofIV:oooool4
0?mVIPgooooo0`3oIVI8ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Zooooo`03ohN7Qol0003o0000
00Co000000?oV9RHoooooooMgMd01_l000000ooMgMgoooooomgMg@06o`000003omgMgOoooooogMgM
00Ko000000?ogMgMooooooooool02?ooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo
09Wooooo00?oOgmoooooooooool00`3oIVH=ooooo`D0ofIV:?ooool40?mVIPoooooo0`3oIVI7oooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Noooo
o`0300000?oooooooooo01?ooooo001[ooooo`06ojVYZOlQ8B7o0000o`000?lQ8B7oZJVY0oooool0
1_o<c<co<S8bo`000?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3oooo
o`06olc<c?lb<S;o0000o`000?lb<S;oc<c<2oooool00`00003oooooooooo`0>ooooo`03ogmoOooo
oooooooo09Wooooo00?oOgmoooooooooool00`3oIVH?ooooo`D0ofIV9?ooool40?mVIQ;ooooo0P3o
IVI7ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0VOooool00omoOgooooooooooo`030?mVIQ7ooooo1@3oIVHQooooo`@0ofIV4oooool3
0?mVITKooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooo
oooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omo
Ogooooooooooo`2Iooooo`03ogmoOooooooooooo00<0ofIV4oooool50?mVIQkooooo0`3oIVHFoooo
o`80ofIVA_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03
ogmoOooooooooooo09Wooooo00?oOgmoooooooooool00`3oIVHEooooo`D0ofIV6_ooool40?mVIQOo
oooo0`3oIVI5ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool0VOooool00omoOgooooooooooo`020?mVIQSooooo1@3oIVHGooooo`@0ofIV
6Oooool20?mVITGooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmo
Oooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_oo
ool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo0080ofIV6_ooool50?mVIQCooooo0`3o
IVHKooooo`<0ofIVA?ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>
ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool00P3oIVHLooooo`D0ofIV4?ooool4
0?mVIQgooooo0`3oIVI3ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo
00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`0Pooooo`D0ofIV3Oooool40?mV
IQoooooo0P3oIVI3ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00ko
oooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`0Rooooo`D0ofIV2_ooool30?mVIR7o
oooo0`3oIVI2ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool0VOooool00omoOgooooooooooo`0Tooooo`D0ofIV1_ooool40?mVIR?ooooo
0P3oIVI2ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooo
ooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?o
Ogmoooooooooool0VOooool00omoOgooooooooooo`0Vooooo`D0ofIV0oooool40?mVIRCooooo0`3o
IVI1ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0VOooool00omoOgooooooooooo`0Xooooo`P0ofIV9oooool30?mVIT3ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000
ooooooooool04oooool009Oooooo1000000=ooooo`03ogmoOooooooooooo09Wooooo00?oOgmooooo
ooooool0:_ooool50?mVIRWooooo0P3oIVI0ooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`0Kooooo`@000005Oooool009Oooooo00<00000oooooooo
ool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo02cooooo0P3oIVHZooooo`<0
ofIV?oooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmo
Oooooooooooo09Wooooo00?oOgmoooooooooool0FOooool20?mVISoooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool0
4oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooo
oooooooo05Wooooo0`3oIVHnooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`1Jooooo`<0ofIV?Oooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool0
0`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo
09Wooooo00?oOgmoooooooooool0Foooool20?mVISgooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oo
oooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo05_o
oooo0`3oIVHlooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`0Nooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo
00?oOgmoooooooooool0VOooool00omoOgooooooooooo`1Looooo`80ofIV??ooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool07_ooool00`00003ooooo
ooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?o
Ogmoooooooooool0G?ooool30?mVIS_ooooo00?oOgmoooooooooool0V_ooool00omoOgoooooooooo
o`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool009Oooooo00<00000
ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo05gooooo0P3oIVHk
ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0=
ooooo`80ofIV3oooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>oooo
o`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0GOooool30?mVIS[ooooo00?oOgmooooo
ooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00gooooo0P3oIVH?oooo
o`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool0VOooool00omoOgooooooooooo`1Nooooo`<0ofIV>Oooool00omoOgooooooooooo`2Jooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool03Oooool20?mVIPoooooo00<00000oooooooo
ool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmo
Oooooooooooo05oooooo0P3oIVHiooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`0=ooooo`80ofIV3oooool00`00003oooooooooo`0Cooooo`00Uooo
ool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0Gooo
ool30?mVISSooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo00gooooo0P3oIVH?ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooo
oooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`1Pooooo`80ofIV>?ooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool03Oooool2
0?mVIPoooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omo
Ogooooooooooo`2Iooooo`03ogmoOooooooooooo063ooooo0`3oIVHgooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0=ooooo`80ofIV3oooool00`00
003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wo
oooo00?oOgmoooooooooool0HOooool30?mVISKooooo00?oOgmoooooooooool03?ooool20?mVIXco
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0=ooooo`80ofIV3oooool00`00003o
ooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo
00?oOgmoooooooooool0H_ooool20?mVISKooooo00?oOgmoooooooooool03?ooool20?mVIXcooooo
00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0=ooooo`80ofIV3oooool00`00003ooooo
ooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?o
Ogmoooooooooool0H_ooool30?mVISGooooo00?oOgmoooooooooool02oooool40?mVIX_ooooo00?o
Ogmoooooooooool0V_ooool00omoOgooooooooooo`0=ooooo`80ofIV3oooool00`00003ooooooooo
o`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmo
ooooooooool0Hoooool20?mVISGooooo00?oOgmoooooooooool02oooool50?mVIX[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`0=ooooo`80ofIV3oooool00`00003oooooooooo`0C
ooooo`00Uoooool4000000gooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`1Soooo
o`<0ofIV=?ooool00omoOgooooooooooo`0:ooooo`<0ofIV00Cooooo0?mVIP3oIVH0ofIVROooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00gooooo0P3oIVH<ooooo`@000005Oooool0
09Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo
06Cooooo0P3oIVHdooooo`03ogmoOooooooooooo00[ooooo0P3oIVH3ooooo`<0ofIVR?ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo00[ooooo1@3oIVH?ooooo`0300000?oooooooooo
01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgoo
ooooooooo`1Tooooo`<0ofIV<oooool00omoOgooooooooooo`09ooooo`<0ofIV1?ooool20?mVIXSo
oooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0:ooooo`@0ofIV4?ooool00`00003o
ooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo
00?oOgmoooooooooool0IOooool30?mVIS;ooooo00?oOgmoooooooooool02?ooool30?mVIPGooooo
0`3oIVJ7ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool02Oooool50?mVIQ3ooooo
00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgoooooooooo
o`2Iooooo`03ogmoOooooooooooo06Kooooo0P3oIVHbooooo`04ogmoOoooooooooooooooo`<0ofIV
1?ooool20?mVIPOooooo0`3oIVJ6ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
2?ooool60?mVIQ3ooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_oo
ool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo06Kooooo0`3oIVHaooooo`03ogmoOooo
ool0ofIV00@0ofIV0oooool30?mVIPSooooo0`3oIVJ5ooooo`03ogmoOooooooooooo09[ooooo00?o
Ogmoooooooooool01oooool70?mVIQ3ooooo00<00000ooooooooool04oooool009Oooooo00<00000
ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo06Oooooo0P3oIVHa
ooooo`L0ofIV0oooool20?mVIP[ooooo0`3oIVJ4ooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool01_ooool30?mVIP03ooooo`3oIVH0ofIV0080ofIV4?ooool00`00003oooooooooo`0C
ooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmooooo
ooooool0Ioooool30?mVIRkooooo1@3oIVH2ooooo`80ofIV0_ooool30?mVIP_ooooo0`3oIVJ3oooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool01Oooool30?mVIP;ooooo103oIVH@oooo
o`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool0VOooool00omoOgooooooooooo`1Xooooo`<0ofIV:oooool50?mVIPCooooo0P3oIVH2ooooo`80
ofIV3Oooool20?mVIX?ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`05ooooo`80
ofIV0oooool40?mVIQ3ooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo06Wooooo0P3oIVHYooooo`D0ofIV
00?oooooogmoOoooool00oooool20?mVIP04ooooo`3oIVH0ofIV0?mVIPgooooo0`3oIVJ2ooooo`03
ogmoOooooooooooo09[ooooo00?oOgmoooooooooool01?ooool30?mVIP?ooooo103oIVH@ooooo`03
00000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
VOooool00omoOgooooooooooo`1Yooooo`H0ofIV9?ooool40?mVIP?ooooo00?oOgmoooooooooool0
0_ooool20?mVIP03ooooo`3oIVH0ofIV00oooooo0`3oIVJ1ooooo`03ogmoOooooooooooo09[ooooo
00?oOgmoooooooooool00oooool30?mVIPCooooo103oIVH@ooooo`0300000?oooooooooo01?ooooo
002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgoooooooooo
o`1Zooooo``0ofIV6oooool40?mVIPGooooo00?oOgmoooooooooool00_ooool50?mVIQ3ooooo0`3o
IVJ0ooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool00_ooool30?mVIPGooooo103o
IVH@ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmo
ooooooooool0VOooool00omoOgooooooooooo`1^ooooo`h0ofIV4oooool50?mVIPKooooo00?oOgmo
ooooooooool00oooool40?mVIQ7ooooo0`3oIVIoooooo`03ogmoOooooooooooo09[ooooo00CoOgmo
oooooooooooooooo0`3oIVH6ooooo`@0ofIV4?ooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0MOooool=
0?mVIP_ooooo1@3oIVH8ooooo`03ogmoOooooooooooo00?ooooo103oIVHBooooo`80ofIVOoooool0
0omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00<0ofIV1oooool40?mVIQ3ooooo00<00000
ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Ioooo
o`03ogmoOooooooooooo07_ooooo3P3oIVH2ooooo`D0ofIV2_ooool00omoOgooooooooooo`03oooo
o`@0ofIV4_ooool30?mVIWkooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`020?mV
IPSooooo103oIVH@ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00ko
oooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`21ooooo`d0ofIV3?ooool00omoOgoo
ooooooooo`03ooooo`@0ofIV4oooool30?mVIWgooooo00?oOgmoooooooooool0V_ooool00omoOgoo
oooo0?mVIP020?mVIPSooooo103oIVH@ooooo`0300000?oooooooooo01?ooooo002Gooooo`030000
0?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`28ooooo`@0ofIV
3_ooool00omoOgooooooooooo`03ooooo`@0ofIV5?ooool30?mVIWcooooo00?oOgmoooooooooool0
V_ooool01?moOgl0ofIV0?mVIP3oIVH9ooooo`@0ofIV4?ooool00`00003oooooooooo`0Cooooo`00
Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`03ooooo`@0ofIV5Oooool30?mVIW_ooooo00?oOgmoooooooooool0
V_ooool30?mVIP[ooooo103oIVH@ooooo`0300000?oooooooooo01?ooooo002Gooooo`0300000?oo
oooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooo
oooooooo00?ooooo103oIVHFooooo`<0ofIVN_ooool00omoOgooooooooooo`2Iooooo`<0ofIV3?oo
ool30?mVIQ3ooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool0
0omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool00oooool4
0?mVIQOooooo0P3oIVIjooooo`03ogmoOooooooooooo09Sooooo0`3oIVH=ooooo`<0ofIV4?ooool0
0`00003oooooooooo`0Cooooo`00Uoooool4000000gooooo00?oOgmoooooooooool0VOooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo00?ooooo0`3oIVHHooooo`<0ofIVNOooool00omo
Ogooooooooooo`2Hooooo`80ofIV00?oOgmoooooooooool02oooool30?mVIPgooooo1000000Eoooo
o`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmooooooooo
ool0V_ooool00omoOgooooooooooo`03ooooo`<0ofIV6Oooool30?mVIWSooooo00?oOgmooooooooo
ool0Uoooool30?mVIP03ogmoOooooooooooo00_ooooo0`3oIVH@ooooo`0300000?oooooooooo01?o
oooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOooool00omoOgoooooo
ooooo`2Jooooo`03ogmoOooooooooooo00?ooooo0`3oIVHJooooo`<0ofIVMoooool00omoOgoooooo
ooooo`0:ooooo`H0ofIVQ_ooool30?mVIP03oooooomoOgoooooo00cooooo0`3oIVH@ooooo`030000
0?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0VOoo
ool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00Cooooo0P3oIVHKooooo`<0ofIVM_oo
ool00omoOgooooooooooo`06ooooo`d0ofIVP_ooool30?mVIP;ooooo00?oOgmoooooooooool02ooo
ool20?mVIQ7ooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool0
0omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool01?ooool2
0?mVIQcooooo0P3oIVIfooooo`03ogmoOooooooooooo00;ooooo2@3oIVH4ooooo`L0ofIVO_ooool3
0?mVIP?ooooo00?oOgmoooooooooool02oooool20?mVIQ7ooooo00<00000ooooooooool04oooool0
09Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo
09[ooooo00?oOgmoooooooooool01?ooool20?mVIQcooooo0`3oIVIeooooo`03ogmoO`3oIVH0ofIV
00L0ofIV2oooool70?mVIW[ooooo0`3oIVH4ooooo`03ogmoOooooooooooo00_ooooo0P3oIVHAoooo
o`0300000?oooooooooo01?ooooo002Gooooo`0300000?oooooooooo00kooooo00?oOgmooooooooo
ool0VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo00Cooooo0P3oIVHMooooo`<0
ofIV=OoooolE0?mVIRSooooo203oIVHBooooo`L0ofIVMoooool20?mVIPGooooo00?oOgmooooooooo
ool02oooool20?mVIQ7ooooo00<00000ooooooooool04oooool009Oooooo00<00000ooooooooool0
3_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
1?ooool20?mVIQkooooo0`3oIVHRooooobl0ofIV7?ooool80?mVIQWooooo1`3oIVIcooooo`<0ofIV
1Oooool00omoOgooooooooooo`0;ooooo`80ofIV4Oooool00`00003oooooooooo`0Cooooo`00Uooo
ool00`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_oo
ool00omoOgooooooooooo`04ooooo`80ofIV7oooool30?mVIQcooooo603oIVHCoooooa40ofIV4?oo
ool90?mVIP03oooooomoOgoooooo01cooooo1`3oIVI_ooooo`<0ofIV1_ooool00omoOgoooooooooo
o`0;ooooo`80ofIV4Oooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>
ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0V
ooooo`<0ofIV5oooool:0?mVIRgooooo4@3oIVH4ooooo`T0ofIV1Oooool00omoOgooooooooooo`0N
ooooo`L0ofIVJoooool30?mVIPOooooo00?oOgmoooooooooool02oooool20?mVIQ7ooooo00<00000
ooooooooool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Ioooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool09oooool20?mVIQ;ooooo2P3oIVHjoooo
oa80ofIV2Oooool00omoOgooooooooooo`0Qooooo`L0ofIVIoooool30?mVIPSooooo00?oOgmooooo
ooooool02oooool20?mVIQ7ooooo00<00000ooooooooool04oooool009Oooooo00<00000oooooooo
ool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmooooooooo
ool09oooool30?mVIPcooooo2`3oIVI6ooooo`H0ofIV3Oooool00omoOgooooooooooo`0Tooooo`L0
ofIVHoooool30?mVIPWooooo00?oOgmoooooooooool02oooool20?mVIQ7ooooo00<00000oooooooo
ool04oooool009Oooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmo
Oooooooooooo09[ooooo00?oOgmoooooooooool0:?ooool30?mVIPOooooo2P3oIVINooooo`03ogmo
Oooooooooooo02Oooooo5P3oIVIAooooo`80ofIV2_ooool00omoOgooooooooooo`0;ooooo`80ofIV
4Oooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003oooooooooo`0>ooooo`03ogmoOooo
oooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`0Yooooo`<0ofIV00?o
oooo0?mVIP3oIVH0203oIVISooooo`03ogmoOooooooooooo02[ooooo:03oIVHkooooo`<0ofIV2_oo
ool00omoOgooooooooooo`0;ooooo`80ofIV4Oooool00`00003oooooooooo`0Cooooo`00Uoooool0
0`00003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool0
0omoOgooooooooooo`0Zooooo`T0ofIVIoooool00omoOgooooooooooo`0looooob40ofIV;oooool3
0?mVIP_ooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00
003oooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`0[ooooo`<0ofIVK?ooool00omoOgooooooooooo`1AoooooaH0ofIV9?ooool30?mV
IPcooooo00?oOgmoooooooooool07_ooool00`00003oooooooooo`0Cooooo`00Uoooool00`00003o
ooooooooo`0>ooooo`03ogmoOooooooooooo09Wooooo00?oOgmoooooooooool0V_ooool00omoOgoo
ooooooooo`2Jooooo`03ogmoOooooooooooo05cooooo803oIVH>ooooo`<0ofIV3Oooool00omoOgoo
ooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Uooooo`;o00001?ooool01_o<c<co<S8b
o`000?l0003o<S8bolc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb
<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0_ooooo00<00000
ooooooooool03_ooool00omoOgooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmo
ooooooooool0V_ooool00omoOgooooooooooo`1VooooobH0ofIV3_ooool00omoOgooooooooooo`0N
ooooo`0300000?oooooooooo01?ooooo001Uooooo`;o00000oooool00ooMgMgo0000o`000004o`00
0003omgMgOoooooogMgM00Ko000000?ogMgMoooooooMgMd01_l000000ooMgMgoooooomgMg@06o`00
0003omgMgOoooooooooo00Sooooo00<00000ooooooooool03_ooool00omoOgooooooooooo`2Ioooo
o`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omoOgooooooooooo`1koooo
oa00ofIV3oooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Uooooo`;o
00000oooool00omVIVKo0000odA4A002onk^kP07odA4A?l0003oIVIVoooooomVIVKo0000odA4A002
onk^kP07odA4A?l0003oIVIVoooooomVIVKo0000odA4A002onk^kP07odA4A?l0003oIVIVoooooomV
IVKo0000odA4A002onk^kP03odA4A?l0003oIVIV00[ooooo00<00000ooooooooool03_ooool00omo
Ogooooooooooo`2Iooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0V_ooool00omo
Ogooooooooooo`2Jooooo`03ogmoOooooooooooo01kooooo00<00000ooooooooool04oooool006Go
oooo0_l00003ooooo`03oc8b<_l0003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0003o
^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;o
oooooc8b<_l0003o^[Zj00;ooooo00?o^[Zjo`000?lb<S802_ooool600000?ooOgmooomoOgnMogmo
O`D000005Oooool006Gooooo0_l00003ooooo`;o000000Cok^k^oooooooooooooooo0_l000001?oo
oooo0000o`000?o^k^h3ooooo`;o000000Coooooo`000?l0003ok^k^0oooool2o`000004ooooool0
003o0000onk^kP?ooooo0_l0000:ooooo`0300000?oooooooooo00kooooo00?oOgmoooooooooool0
VOooool00omoOgooooooooooo`2Jooooo`03ogmoOooooooooooo09[ooooo00?oOgmoooooooooool0
V_ooool00omoOgooooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001Uooooo`;o00000ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`0300000?oooooooooo00kooooo00<0
0000ooooooooool0VOooool00`00003oooooooooo`2Jooooo`0300000?oooooooooo09[ooooo00<0
0000ooooooooool0V_ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01?ooooo001U
ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`0300000?oooooo
oooo00kooooo00<00000ooooooooool0VOooool00`00003oooooooooo`2Jooooo`0300000?oooooo
oooo09[ooooo00<00000ooooooooool0V_ooool00`00003oooooooooo`0Nooooo`0300000?oooooo
oooo01?ooooo001Uooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l0000:oooo
o`0300000?oooooooooo00kooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Loooo
o`0300000?oooooooooo01gooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Loooo
o`0300000?oooooooooo01gooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Moooo
o`0300000?oooooooooo01cooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Moooo
o`0300000?oooooooooo01cooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Loooo
o`0300000?oooooooooo01cooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Loooo
o`0300000?oooooooooo01cooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Loooo
o`0300000?oooooooooo01gooooo0P00000Eooooo`00H_ooool5o`0000?ooooo00?o<S8bo`000?nj
^[X00_ooool01onj^[[o0000oc8b<_oooooo<S8bo`000?nj^[X00_ooool01onj^[[o0000oc8b<_oo
oooo<S8bo`000?nj^[X00_ooool01onj^[[o0000oc8b<_oooooo<S8bo`000?nj^[X00_ooool00onj
^[[o0000oc8b<P0:ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool07?ooool00`00
003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000ooooooooool07?ooool00`00
003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000ooooooooool07?ooool00`00
003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<00000ooooooooool07?ooool00`00
003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00<00000ooooooooool07Oooool00`00
003oooooooooo`0Looooo`0300000?oooooooooo01cooooo00<00000ooooooooool07Oooool00`00
003oooooooooo`0Looooo`0300000?oooooooooo01cooooo00<00000ooooooooool07Oooool00`00
003oooooooooo`0Looooo`0300000?oooooooooo01gooooo0P00000Eooooo`00H_ooool5o`0000?o
oooo00?oIVIVo`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`000?m4A4@00_o^k^h0
1om4A4Co0000ofIVI_ooooooIVIVo`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`00
0?m4A4@00_o^k^h00om4A4Co0000ofIVIP0:ooooool00000o`00002X000001Gooooo001Sooooo`04
olc<c?lb<S;o0000o`0000?ooooo00?ogMgMo`000?l000001?l000000ooMgMgoooooomgMg@06o`00
0003omgMgOoooooogMgM00Ko000000?ogMgMoooooooMgMd01_l000000ooMgMgoooooooooo`3ooooo
ooooooooaOooool006Cooooo00?ogMgMo`000?l000001?ooool01_o<c<co<S8bo`000?l0003o<S8b
olc<c0?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb<S;o0000o`000?lb
<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c?ooooooooooooo8ooooo`00oooooooo
ooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00
ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomE
ooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooo
oooooomEooooo`00oooooooooooooc7ooooo0_l000000ol@413o^[Zjooooo`3ooooooaoooooo003o
oooooooooooo<Oooool4o`000003onk^k_oooooooooo0?oooooo7Oooool00?oooooooooooolcoooo
o`03ogMgMol0003oEEEE0?oooooo7oooool00?ooooooDOooool2o`0000;ooooo00?o410@o`000?lQ
8B400_ooool2o`0000;ooooo0_l00007ooooo`So00000oooool00onj^[[oA4A4o`000002o`000003
odA4A?nj^[[ooooo00?ooooo0_l0000:ooooo`03onk^k_mVIVKo8B4Q00;o000000?o410@oeEEEOoM
gMd03?ooool00ooMgMgoEEEEo`000002o`000003oeEEEOoMgMgooooo00;ooooo0_l00004ooooo`;o
00001Oooool01_o<c<coA4A4o`000?l0003oEEEEonk^kP;o00001Oooool01_nHV9So8B4Qo`000?l0
003oEEEEonk^kP?ooooo00Koc<c<oc8b<_l0003o0000oc8b<_o<c<`3ooooo`06olc<c?lb<S;o0000
o`000?lb<S;oc<c<1oooool2o`0000;ooooo00?o410@o`000?lQ8B400_ooool2o`0000;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000001Ol0000<ooooo`;o00003_ooool01_m4A4Co0000o`00
0?o^k^koooooonk^kP;o000000KoEEEEooooooooooooooooolc<c?m4A4@2o`000004oeEEEOo^k^ko
0000o`0000?ooooo00Gok^k^o`000?l0003o0000onk^kP0:ooooo`;o00000_ooool00omgMgOo0000
o`000002ooooo`06olc<c?m4A4Co0000o`000?mEEEGok^k^0_l00002ooooo`;o00001?ooool2o`00
00;ooooo0_l00002ooooo`06onk^k_mEEEGo0000o`000?lb<S;oc<c<0_l00002ooooo`;o00000ooo
ool2o`0000?ooooo0_l00006ooooo`So0000c_ooool00?ooooooDOooool2o`000003ooooooo^k^ko
000000;o000000Cok^k^ooooool0003o00000_ooool2o`0000Oooooo2?l00002ooooo`03oiRHV?l0
003o000000Go000000CoV9RHoooooooooooooooo0_l00009ooooo`03olc<c?l0003o000000Ko0000
00?oc<c<ooooooooool02?ooool00oo^k^ko0000o`000005o`000003onk^k_oooooooooo00;o0000
1?ooool2o`0000Gooooo00?o<S8bo`000?l000001Ol00004ooooo`03ogMgMol0003o000000?o0000
00Co8B4QoooooooooooogMgM1_l000000ooMgMgoooooomgMg@06o`000003omgMgOoooooooooo00Co
oooo0_l000000oooooook^k^o`000002o`000004onk^k_oooooo0000o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000001Ol0000<ooooo`;o00003_ooool3o`000003okZj^_ooooooZJVY
00;o000000Go410@oooooooooooooooooc8b<P07o`0000?ooooo00GoZJVYo`000?l0003o0000ojVY
Z@0:ooooo`;o00000_ooool3o`0000;ooooo00?o<S8bo`000?l000001Ol00002ooooo`;o00001?oo
ool2o`0000;ooooo0_l00002ooooo`03oeEEEOl0003o000000Go00000_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001_ooool00olQ8B7o0000o`000005o`000<kooooo003ooooooe7ooooo0_l00000
0oooooooZJVYo`000002o`000004ojVYZOoooooo0000o`0000;ooooo0_l00007ooooo`;o00001ooo
ool02?oMgMgo0000o`000?mVIVKogMgMoooooooMgMgoIVIV0_l000000oo<c<coooooooooo`02o`00
00Wooooo00CoA4A4o`000?lQ8B7oc<c<0_ooool01?oMgMgoEEEEo`000?lQ8B4:ooooo`09oeEEEOl0
003o8B4QomgMgOoooooogMgMob4Q8Ol0003oEEEE00;ooooo0_l00004ooooo`;o00001Oooool2o`00
0004okZj^_oooooogMgMoeEEE@;o00001?ooool2o`00000:oiRHV?oooooogMgMob4Q8Ol0003oV9RH
oooooomVIVKo0000odA4A0;ok^k^00OoA4A4o`000?mVIVKoooooofIVI_l0003oA4A400;ok^k^00?o
A4A4o`000?mVIVH01_ooool2o`000003oooooonYZJWo000000;o000000CoZJVYooooool0003o0000
0_ooool2o`0000Gooooo0_l000001OooooooEEEEo`000?lQ8B7ok^k^00[ooooo2?l0000<ooooo`07
olc<c?l0003o0000o`000?mgMgOoooooogMgM`03o`000003onk^k_oooooooooo00;o000000Co^[Zj
oooooooMgMgoEEEE0_l00003ooooo`05ofIVI_l0003o410@o`000?mVIVH02_ooool2o`0000;ooooo
0_l00003ooooo`;o000000Co^[ZjoooooooMgMgoEEEE0_l00002ooooo`;o00001?ooool2o`0000;o
oooo0_l00002ooooo`;o000000CoQhN7ooooooo^k^koEEEE0_l00002ooooo`;o00000oooool2o`00
00?ooooo0_l00006ooooo`04ofIVI_l0003o0000olc<c=;ooooo003ooooooe7ooooo0_l000001ooo
ooooMgMgo`000?m4A4Co0000ogMgMoooool00_l00002ooooo`;o00001oooool2o`0000Oooooo00?o
EEEEo`000?m4A4@01Oooool00om4A4Co0000oeEEE@02ooooo`;o00002Oooool2o`000003omgMgOoo
oooooooo00?ooooo0_l0000:ooooo`;o000000GogMgMooooooooooooooooomgMg@02o`0000;ooooo
0_l00004ooooo`;o00001Oooool00olb<S;o0000okZj^P02ooooo`03onk^k_l0003o000000Wooooo
00OoZJVYo`000?m4A4Cooooooc8b<_l0003o^[Zj00;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0
003o^[Zj00;ooooo00?o^[Zjo`000?lb<S801_ooool2o`000007oooooomgMgOo0000odA4A?l0003o
MgMgooooo`02o`0000;ooooo0_l00005ooooo`;o00000_ooool00omEEEGo0000odA4A00:ooooo`So
00000_ooool9o`00000<oooooonHV9So0000ofIVI_l0003o<S8boooooolb<S;o0000ofIVI_l0003o
ZJVY0_ooool00olb<S;o0000okZj^P02ooooo`03onk^k_l0003o000000?ooooo00Go410@o`000?nH
V9So0000oa0@400:ooooo`;o00000_ooool2o`0000?ooooo00?o<S8bo`000?nj^[X00_ooool00oo^
k^ko0000o`000002ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool00oo^
k^ko0000o`000002ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`05onk^k_lQ8B7o0000
o`000?n7QhL0dOooool00?ooooooDOooool2o`000007oooooolb<S;o0000olc<c?l0003o<S8boooo
o`02o`0000;ooooo0_l00007ooooo`;o00001oooool00ol@413o0000olc<c005ooooo`03olc<c?l0
003o410@00;ooooo1_l000000olb<S;oZJVYooooo`08ooooo`04okZj^_mEEEGo0000o`0000[ooooo
0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`06omgMgOm4A4Co0000o`000?lb
<S;oIVIV0_l00005ooooo`05ojVYZOlQ8B7o0000oa0@4?nHV9P00_l000001?oooooo0000o`000?o^
k^h3ooooo`;o000000Coooooo`000?l0003ok^k^0oooool2o`0000Kooooo0_l000001ooooooo<S8b
o`000?o<c<co0000oc8b<_ooool00_l00002ooooo`;o00001Oooool2o`0000?ooooo00?oEEEEo`00
0?mEEED02Oooool00olQ8B7o0000ojVYZ@02ooooo`;o00000oooool9o`000004oooooomEEEGo0000
olc<c0;o000000Koooooo`000?l0003oc<c<o`000?mVIVH2ooooo`06omgMgOm4A4Co0000o`000?lb
<S;oIVIV0_l00002ooooo`04omgMgOl0003o0000ooooo`;o000000?ogMgMooooooooool01oooool2
o`0000;ooooo0_l00003ooooo`06omgMgOm4A4Co0000o`000?lb<S;oIVIV0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000Oooooo00Kok^k^oc8b<_l0003o0000oeEEEOo^k^k?ooooo`00oooooomAooooo`;o
000000Ooooooo`000?lQ8B7oooooob4Q8Ol0003ooooo00;o00000_ooool7o`0000;ooooo0_l00007
ooooo`;o00001oooool2o`0000;ooooo2?l000002?nYZJWoooooooooooooooooc<c<ogMgMolb<S;o
410@1?l000000omgMgOoooooooooo`08ooooo`;o000000GogMgMooooooooooooooooomgMg@02o`00
00;ooooo0_l000001?o^k^koooooooooooooool2o`0000Sooooo0_nj^[X00omVIVKo0000o`000004
ooooo`03ojVYZOl0003o000000Go000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000Cooooo0_l00006ooooo`;o000000Ooooooo`000?lQ8B7oooooob4Q8Ol0003ooooo00;o0000
0_ooool9o`0000Cooooo00?oA4A4o`000?mEEED02?ooool01Oo<c<co0000oa0@4?o^k^kooooo00;o
00003Oooool02olQ8B7o0000oooooolQ8B7o0000ogMgMol0003o8B4Qooooool0003o8B4Q00Gooooo
0_nj^[X00omVIVKo0000o`000002ooooo`07oiRHV?l0003oA4A4oooooom4A4Co0000oiRHV009oooo
o`;o00000_ooool2o`0000Kooooo0_nj^[X00omVIVKo0000o`000002ooooo`;o000000Cok^k^oooo
oooooooooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o000000?ok^k^
ooooooooool00_l000000oo^k^koooooooooo`02o`0000Wooooo00GoQhN7o`000?l0003o8B4Qonk^
kP3>ooooo`00oooooomAooooo`;o000000Ooc<c<o`000?mVIVKoooooogMgMol0003oc<c<00;o0000
0_ooool7o`0000;ooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`04onk^
k_mEEEGo0000ob4Q8@;ooooo00?oV9RHo`000?l000000ol000000olb<S;oIVIVokZj^P0;ooooo`09
oeEEEOl0003o8B4QomgMgOoooooogMgMob4Q8Ol0003oEEEE00;ooooo0_l000001?mEEEGok^k^oooo
oon7QhL2o`0000Gooooo0_l000001?n7QhOooooooooooonj^[X2o`0000Cooooo00Ko8B4Qo`000?mE
EEGoooooonk^k_mEEED2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004
ooooo`;o00001_ooool2o`000007olc<c?l0003oIVIVoooooomgMgOo0000olc<c002o`0000;ooooo
2Ol00004ooooo`04onk^k_lQ8B7o0000oeEEE@Sooooo00CoMgMgo`000?mgMgOooooo0_l0000<oooo
o`05onk^k_l0003o8B4QoooooomVIVH00ol000001?mVIVKoooooob4Q8Ol00002ooooo`;o000000Co
QhN7oooooooooooo^[Zj0_l00002ooooo`07oeEEEOl0003oQhN7oooooon7QhOo0000oeEEE@09oooo
o`;o00000_ooool2o`0000?ooooo0_l000001?n7QhOooooooooooonj^[X2o`0000;ooooo0_l00000
1?mEEEGok^k^oooooon7QhL2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000omEEEGoooooojVYZ@02o`000003oeEEEOooooooZJVY00;o00002_ooool01?o<c<co0000o`00
0?mVIVK>ooooo`00oooooomAooooo`;o000000OoQhN7o`000?nj^[[ooooookZj^_l0003oQhN700;o
00000_ooool2o`0000Oooooo0_l00007ooooo`03oa0@4?l0003oc<c<00Gooooo00?oc<c<o`000?l@
41000_ooool2o`0000Cooooo00?ok^k^o`000?l000000_ooool01Ol@413o0000odA4A?nYZJWogMgM
00oooooo00?ok^k^o`000?l000001Ol000000oo^k^koooooooooo`07o`000003odA4A?oooooooooo
00?ooooo00?oIVIVo`000?l000001?l000000omVIVKoooooooooo`02ooooo`;o000000Cok^k^oooo
ooooooook^k^0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Kooooo0_l000001on7QhOo0000okZj^_oooooo^[Zjo`000?n7QhL00_l00002ooooo`;o0000
1Oooool2o`000003ooooool0003o000000Go00002Oooool00ol@413o0000omgMg@02o`0000cooooo
00Go^[Zjo`000?m4A4CoooooojVYZ@03o`000007ojVYZOooooooA4A4o`000?nj^[[oooooofIVIP06
o`00000:ofIVI_oooooooooooa0@4?l0003oc<c<ooooooo<c<co0000oa0@40Wooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo00?oIVIVo`000?l000001?l000000omVIVKoooooooooo`07o`00
0003odA4A?oooooooooo00;o00000_ooool2o`0000Cooooo0_l00002ooooo`Ko000000?o410@o`00
0?l000000_l000000olb<S;oooooooooo`09ooooo`03okZj^_l0003o00000<kooooo003ooooooe7o
oooo0_l000000om4A4Co0000ooooo`02ooooo`04o`000?mEEEGo0000o`0000;ooooo0_l00007oooo
o`;o00001oooool00omEEEGo0000odA4A005ooooo`03odA4A?l0003oEEEE00;ooooo0_l00004oooo
o`03onk^k_l0003o000000;ooooo0_l00005ooooo`03omgMgOl0003o000000_ooooo00?ogMgMoeEE
EOl000000_l000000omEEEGogMgMooooo`02ooooo`;o000000Koc<c<oc8b<_l0003o0000oeEEEOo^
k^h6ooooo`06ogMgMolQ8B7o0000o`000?lQ8B7oV9RH1Oooool2o`00000:onk^k_ooooooooooonk^
k_l0003o<S8boooooolb<S;o0000okZj^P;ooooo00Oo^[Zjo`000?lb<S;ooooooc8b<_l0003o^[Zj
00;ooooo00?o^[Zjo`000?lb<S801_ooool2o`000003odA4A?l0003ooooo00;ooooo00Co0000oeEE
EOl0003o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005o`0000Wooooo00?o^[Zj
o`000?lb<S800_l0000<ooooo`05ogMgMol0003oMgMgooooooo^k^h00ol000001Oo^k^koooooogMg
Mol0003oMgMg00;ooooo00KoMgMgob4Q8Ol0003o0000ob4Q8OnHV9P2ooooo`03omgMgOl0003o0000
00?ooooo0_l000000ooMgMgoooooooooo`06ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`06ogMgMolQ8B7o0000o`000?lQ8B7oV9RH0oooool2o`000006olc<c?lb<S;o0000o`000?mEEEGo
k^k^0_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`00000:olc<c?l@413o0000ob4Q
8Oo<c<coV9RHoa0@4?l0003o<S8bolc<c0Kooooo0_l000001?o^k^koooooooooooooool2o`000<ko
oooo003ooooooe7ooooo0_l000000ol@413oA4A4ooooo`02ooooo`04odA4A?l@413o0000o`0000;o
oooo0_l00007ooooo`;o00001oooool02?o<c<co0000o`000?mVIVKogMgMoooooooMgMgoIVIV0_l0
00000oo<c<coooooooooo`02o`0000?ooooo00Cok^k^oeEEEOl0003o8B4Q0_ooool01?lQ8B7o0000
oeEEEOoMgMd2ooooo`04ojVYZOlQ8B7o0000oeEEEBkooooo00?oA4A4o`000?mEEED00_o^k^h01omE
EEGo0000ogMgMoooooooIVIVo`000?m4A4@00_o^k^h01om4A4Co0000ofIVI_ooooooIVIVo`000?m4
A4@00_o^k^h00om4A4Co0000ofIVIP06ooooo`;o000000?o410@odA4A?ooool00_ooool01?m4A4Co
410@o`000?l00002ooooo`;o00001Oooool2o`0001;ooooo00CoIVIVo`000?l0003o0000=?ooool2
o`0000;ooooo0_l0000gooooo`08oc8b<_l0003oIVIVonk^k_ooooooEEEEo`000?lQ8B7>ooooo`00
oooooomAooooo`?o000000GoV9RHooooooooooooooooohN7Q`03o`0000;ooooo2?l000000ooooooo
0000o`000008ooooo`03oiRHV?l0003o000000Go000000CoV9RHoooooooooooooooo2?l000001?nY
ZJWooooooooooonj^[X7o`000003oa0@4?oMgMgooooo02gooooo00?oc<c<o`000?l000001?l00000
0oo^k^koooooomgMg@06o`000003omgMgOoooooogMgM00Ko000000?ogMgMooooooooool01?ooool3
o`000005oiRHV?oooooooooooooooon7QhL00ol00002ooooo`;o00001Oooool2o`0001;ooooo00Co
k^k^oa0@4?l0003o0000=?ooool2o`0000;ooooo0_l0000Gooooo`;o00007_ooool00onYZJWo0000
o`000004o`000003ojVYZOoooooooooo0<cooooo003ooooooe7ooooo0ol000001OoMgMgooooooooo
ooooooooc<c<00?o00000_ooool8o`000003ooooool0003o000000Wooooo00?o^[ZjodA4A?l00000
0_l000000om4A4Co^[Zjooooo`03ooooo`Ko000000?o8B4QojVYZOooool00oooool00oo<c<coEEEE
oa0@4002o`000003ob4Q8OmgMgOok^k^033ooooo00Koc<c<oc8b<_l0003o0000odA4A?oMgMd3oooo
o`06olc<c?lb<S;o0000o`000?lb<S;oc<c<0oooool01_o<c<co<S8bo`000?l0003o<S8bolc<c0Oo
oooo0ol000001OoMgMgoooooooooooooooooc<c<00?o00000_ooool2o`0000Gooooo0_l0000Coooo
o`03okZj^_l0003o000003Cooooo0_l0000Kooooo`;o00007oooool01_nYZJWo8B4Qo`000?l0003o
A4A4okZj^/oooooo003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOooool00?oo
oooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00ooooooooooooooooooooEOoo
ool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00oooooooooooooooo
ooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00oooooooo
ooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomEooooo`00
ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooooooooomE
ooooo`00ooooooooooooooooooooEOooool00?oooooooooooooooooooeGooooo003ooooooooooooo
oooooomEooooo`00ooooooooooooooooooooEOooool00001\
\>"],
  ImageRangeCache->{{{0, 1273.5}, {902.438, 0}} -> {-1.05059, -0.83546, \
0.00247489, 0.00247489}, {{30.5625, 1242.75}, {770.625, 21.375}} -> \
{-535.753, -3675.79, 3.18707, 24.9143}, {{285.188, 1133.63}, {880.875, \
795.938}} -> {-1.72719, -0.699797, 0.00855697, 0.0417242}, {{316.688, 492}, \
{874.313, 838.313}} -> {-22.4664, -2.55732, 0.0833342, 0.0833342}, {{520.125, \
695.25}, {874.313, 838.313}} -> {-33.7634, -2.55732, 0.0833342, 0.0833342}, \
{{723.375, 898.688}, {874.313, 838.313}} -> {-45.0603, -2.55732, 0.0833342, \
0.0833342}, {{926.813, 1101.94}, {874.313, 838.313}} -> {-56.3573, -2.55732, \
0.0833342, 0.0833342}}],

Cell[TextData[{
  "A consequence of careful library selection is that computation on large \
problems will run as fast or faster with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as with specialized programs or dedicated numerical systems:"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 600 370.82 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.666667 0.166667 0.014668 0.0117761 [
[.16667 -0.0125 -12.0313 -15.8125 ]
[.16667 -0.0125 12.0313 0 ]
[.33333 -0.0125 -15.375 -15.8125 ]
[.33333 -0.0125 15.375 0 ]
[.5 -0.0125 -15.375 -15.8125 ]
[.5 -0.0125 15.375 0 ]
[.66667 -0.0125 -15.375 -15.8125 ]
[.66667 -0.0125 15.375 0 ]
[.83333 -0.0125 -15.375 -15.8125 ]
[.83333 -0.0125 15.375 0 ]
[1 -0.0125 -15.375 -15.8125 ]
[1 -0.0125 15.375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -33.2813 -31.625 ]
[.5 -0.0125 33.2813 -15.8125 ]
[-0.0125 .01467 -10.6875 -7.90625 ]
[-0.0125 .01467 0 7.90625 ]
[-0.0125 .13243 -17.375 -7.90625 ]
[-0.0125 .13243 0 7.90625 ]
[-0.0125 .25019 -17.375 -7.90625 ]
[-0.0125 .25019 0 7.90625 ]
[-0.0125 .36795 -17.375 -7.90625 ]
[-0.0125 .36795 0 7.90625 ]
[-0.0125 .48571 -17.375 -7.90625 ]
[-0.0125 .48571 0 7.90625 ]
[-0.0125 .60347 -17.375 -7.90625 ]
[-0.0125 .60347 0 7.90625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -33.1875 -27 ]
[-0.01875 .30902 -17.375 27 ]
[.5 .63053 -81.5 0 ]
[.5 .63053 81.5 41.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -73.0313 -19.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(750) show
83.063 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -76.375 -19.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(1000) show
89.750 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -76.375 -19.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(1300) show
89.750 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -76.375 -19.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(1700) show
89.750 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -76.375 -19.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(2000) show
89.750 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -76.375 -19.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(3000) show
89.750 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -94.2813 -35.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(Matrix) show
101.563 16.188 moveto
(Size) show
125.563 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01467 m
.00625 .01467 L
s
gsave
-0.0125 .01467 -71.6875 -11.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13243 m
.00625 .13243 L
s
gsave
-0.0125 .13243 -78.375 -11.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .25019 m
.00625 .25019 L
s
gsave
-0.0125 .25019 -78.375 -11.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .36795 m
.00625 .36795 L
s
gsave
-0.0125 .36795 -78.375 -11.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .48571 m
.00625 .48571 L
s
gsave
-0.0125 .48571 -78.375 -11.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .60347 m
.00625 .60347 L
s
gsave
-0.0125 .60347 -78.375 -11.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03822 m
.00375 .03822 L
s
0 .06177 m
.00375 .06177 L
s
0 .08532 m
.00375 .08532 L
s
0 .10888 m
.00375 .10888 L
s
0 .15598 m
.00375 .15598 L
s
0 .17953 m
.00375 .17953 L
s
0 .20309 m
.00375 .20309 L
s
0 .22664 m
.00375 .22664 L
s
0 .27374 m
.00375 .27374 L
s
0 .29729 m
.00375 .29729 L
s
0 .32085 m
.00375 .32085 L
s
0 .3444 m
.00375 .3444 L
s
0 .3915 m
.00375 .3915 L
s
0 .41505 m
.00375 .41505 L
s
0 .43861 m
.00375 .43861 L
s
0 .46216 m
.00375 .46216 L
s
0 .50926 m
.00375 .50926 L
s
0 .53282 m
.00375 .53282 L
s
0 .55637 m
.00375 .55637 L
s
0 .57992 m
.00375 .57992 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -113.281 -11.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
88 11.9063 translate
90 rotate
-88 -11.9063 translate
0 23.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(Seconds) show
113.000 16.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -142.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 49.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.188 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.500 0.500 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.500 0.500 0.500 setrgbcolor
(TIMING) show
116.188 15.188 moveto
(COMPARISONS) show
221.875 15.188 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.500 0.500 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 41.438 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 41.438 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dot) show
109.625 41.438 moveto
(Product) show
200.188 41.438 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.400 0.400 0.400 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .3 0 r
.01 w
0 .01683 m
.16667 .0201 L
.33333 .02516 L
.5 .04039 L
.66667 .07037 L
.83333 .09646 L
1 .30677 L
s
0 g
.0001 w
-0.5 .01472 -1.875 0 Mabsadd m
-0.5 .01472 0 2.5 Mabsadd L
-0.5 .01472 1.875 0 Mabsadd L
-0.5 .01472 0 -2.5 Mabsadd L
-0.5 .01472 -1.875 0 Mabsadd L closepath F
-0.33333 .01503 -1.875 0 Mabsadd m
-0.33333 .01503 0 2.5 Mabsadd L
-0.33333 .01503 1.875 0 Mabsadd L
-0.33333 .01503 0 -2.5 Mabsadd L
-0.33333 .01503 -1.875 0 Mabsadd L closepath F
-0.16667 .01527 -1.875 0 Mabsadd m
-0.16667 .01527 0 2.5 Mabsadd L
-0.16667 .01527 1.875 0 Mabsadd L
-0.16667 .01527 0 -2.5 Mabsadd L
-0.16667 .01527 -1.875 0 Mabsadd L closepath F
0 .01683 -1.875 0 Mabsadd m
0 .01683 0 2.5 Mabsadd L
0 .01683 1.875 0 Mabsadd L
0 .01683 0 -2.5 Mabsadd L
0 .01683 -1.875 0 Mabsadd L closepath F
.16667 .0201 -1.875 0 Mabsadd m
.16667 .0201 0 2.5 Mabsadd L
.16667 .0201 1.875 0 Mabsadd L
.16667 .0201 0 -2.5 Mabsadd L
.16667 .0201 -1.875 0 Mabsadd L closepath F
.33333 .02516 -1.875 0 Mabsadd m
.33333 .02516 0 2.5 Mabsadd L
.33333 .02516 1.875 0 Mabsadd L
.33333 .02516 0 -2.5 Mabsadd L
.33333 .02516 -1.875 0 Mabsadd L closepath F
.5 .04039 -1.875 0 Mabsadd m
.5 .04039 0 2.5 Mabsadd L
.5 .04039 1.875 0 Mabsadd L
.5 .04039 0 -2.5 Mabsadd L
.5 .04039 -1.875 0 Mabsadd L closepath F
.66667 .07037 -1.875 0 Mabsadd m
.66667 .07037 0 2.5 Mabsadd L
.66667 .07037 1.875 0 Mabsadd L
.66667 .07037 0 -2.5 Mabsadd L
.66667 .07037 -1.875 0 Mabsadd L closepath F
.83333 .09646 -1.875 0 Mabsadd m
.83333 .09646 0 2.5 Mabsadd L
.83333 .09646 1.875 0 Mabsadd L
.83333 .09646 0 -2.5 Mabsadd L
.83333 .09646 -1.875 0 Mabsadd L closepath F
1 .30677 -1.875 0 Mabsadd m
1 .30677 0 2.5 Mabsadd L
1 .30677 1.875 0 Mabsadd L
1 .30677 0 -2.5 Mabsadd L
1 .30677 -1.875 0 Mabsadd L closepath F
.7 .7 .7 r
.01 w
0 .01761 m
.16667 .02341 L
.33333 .03537 L
.5 .05962 L
.66667 .11578 L
.83333 .18037 L
1 .60332 L
s
0 g
.0001 w
-0.5 .01472 0 2.5 Mabsadd m
-0.5 .01472 -0.56518 .7779 Mabsadd L
-0.5 .01472 -2.37764 .77254 Mabsadd L
-0.5 .01472 -0.91448 -0.29713 Mabsadd L
-0.5 .01472 -1.46946 -2.02254 Mabsadd L
-0.5 .01472 0 -0.96154 Mabsadd L
-0.5 .01472 1.46946 -2.02254 Mabsadd L
-0.5 .01472 .91448 -0.29713 Mabsadd L
-0.5 .01472 2.37764 .77254 Mabsadd L
-0.5 .01472 .56518 .7779 Mabsadd L
-0.5 .01472 0 2.5 Mabsadd L closepath F
-0.33333 .01517 0 2.5 Mabsadd m
-0.33333 .01517 -0.56518 .7779 Mabsadd L
-0.33333 .01517 -2.37764 .77254 Mabsadd L
-0.33333 .01517 -0.91448 -0.29713 Mabsadd L
-0.33333 .01517 -1.46946 -2.02254 Mabsadd L
-0.33333 .01517 0 -0.96154 Mabsadd L
-0.33333 .01517 1.46946 -2.02254 Mabsadd L
-0.33333 .01517 .91448 -0.29713 Mabsadd L
-0.33333 .01517 2.37764 .77254 Mabsadd L
-0.33333 .01517 .56518 .7779 Mabsadd L
-0.33333 .01517 0 2.5 Mabsadd L closepath F
-0.16667 .0159 0 2.5 Mabsadd m
-0.16667 .0159 -0.56518 .7779 Mabsadd L
-0.16667 .0159 -2.37764 .77254 Mabsadd L
-0.16667 .0159 -0.91448 -0.29713 Mabsadd L
-0.16667 .0159 -1.46946 -2.02254 Mabsadd L
-0.16667 .0159 0 -0.96154 Mabsadd L
-0.16667 .0159 1.46946 -2.02254 Mabsadd L
-0.16667 .0159 .91448 -0.29713 Mabsadd L
-0.16667 .0159 2.37764 .77254 Mabsadd L
-0.16667 .0159 .56518 .7779 Mabsadd L
-0.16667 .0159 0 2.5 Mabsadd L closepath F
0 .01761 0 2.5 Mabsadd m
0 .01761 -0.56518 .7779 Mabsadd L
0 .01761 -2.37764 .77254 Mabsadd L
0 .01761 -0.91448 -0.29713 Mabsadd L
0 .01761 -1.46946 -2.02254 Mabsadd L
0 .01761 0 -0.96154 Mabsadd L
0 .01761 1.46946 -2.02254 Mabsadd L
0 .01761 .91448 -0.29713 Mabsadd L
0 .01761 2.37764 .77254 Mabsadd L
0 .01761 .56518 .7779 Mabsadd L
0 .01761 0 2.5 Mabsadd L closepath F
.16667 .02341 0 2.5 Mabsadd m
.16667 .02341 -0.56518 .7779 Mabsadd L
.16667 .02341 -2.37764 .77254 Mabsadd L
.16667 .02341 -0.91448 -0.29713 Mabsadd L
.16667 .02341 -1.46946 -2.02254 Mabsadd L
.16667 .02341 0 -0.96154 Mabsadd L
.16667 .02341 1.46946 -2.02254 Mabsadd L
.16667 .02341 .91448 -0.29713 Mabsadd L
.16667 .02341 2.37764 .77254 Mabsadd L
.16667 .02341 .56518 .7779 Mabsadd L
.16667 .02341 0 2.5 Mabsadd L closepath F
.33333 .03537 0 2.5 Mabsadd m
.33333 .03537 -0.56518 .7779 Mabsadd L
.33333 .03537 -2.37764 .77254 Mabsadd L
.33333 .03537 -0.91448 -0.29713 Mabsadd L
.33333 .03537 -1.46946 -2.02254 Mabsadd L
.33333 .03537 0 -0.96154 Mabsadd L
.33333 .03537 1.46946 -2.02254 Mabsadd L
.33333 .03537 .91448 -0.29713 Mabsadd L
.33333 .03537 2.37764 .77254 Mabsadd L
.33333 .03537 .56518 .7779 Mabsadd L
.33333 .03537 0 2.5 Mabsadd L closepath F
.5 .05962 0 2.5 Mabsadd m
.5 .05962 -0.56518 .7779 Mabsadd L
.5 .05962 -2.37764 .77254 Mabsadd L
.5 .05962 -0.91448 -0.29713 Mabsadd L
.5 .05962 -1.46946 -2.02254 Mabsadd L
.5 .05962 0 -0.96154 Mabsadd L
.5 .05962 1.46946 -2.02254 Mabsadd L
.5 .05962 .91448 -0.29713 Mabsadd L
.5 .05962 2.37764 .77254 Mabsadd L
.5 .05962 .56518 .7779 Mabsadd L
.5 .05962 0 2.5 Mabsadd L closepath F
.66667 .11578 0 2.5 Mabsadd m
.66667 .11578 -0.56518 .7779 Mabsadd L
.66667 .11578 -2.37764 .77254 Mabsadd L
.66667 .11578 -0.91448 -0.29713 Mabsadd L
.66667 .11578 -1.46946 -2.02254 Mabsadd L
.66667 .11578 0 -0.96154 Mabsadd L
.66667 .11578 1.46946 -2.02254 Mabsadd L
.66667 .11578 .91448 -0.29713 Mabsadd L
.66667 .11578 2.37764 .77254 Mabsadd L
.66667 .11578 .56518 .7779 Mabsadd L
.66667 .11578 0 2.5 Mabsadd L closepath F
.83333 .18037 0 2.5 Mabsadd m
.83333 .18037 -0.56518 .7779 Mabsadd L
.83333 .18037 -2.37764 .77254 Mabsadd L
.83333 .18037 -0.91448 -0.29713 Mabsadd L
.83333 .18037 -1.46946 -2.02254 Mabsadd L
.83333 .18037 0 -0.96154 Mabsadd L
.83333 .18037 1.46946 -2.02254 Mabsadd L
.83333 .18037 .91448 -0.29713 Mabsadd L
.83333 .18037 2.37764 .77254 Mabsadd L
.83333 .18037 .56518 .7779 Mabsadd L
.83333 .18037 0 2.5 Mabsadd L closepath F
1 .60332 0 2.5 Mabsadd m
1 .60332 -0.56518 .7779 Mabsadd L
1 .60332 -2.37764 .77254 Mabsadd L
1 .60332 -0.91448 -0.29713 Mabsadd L
1 .60332 -1.46946 -2.02254 Mabsadd L
1 .60332 0 -0.96154 Mabsadd L
1 .60332 1.46946 -2.02254 Mabsadd L
1 .60332 .91448 -0.29713 Mabsadd L
1 .60332 2.37764 .77254 Mabsadd L
1 .60332 .56518 .7779 Mabsadd L
1 .60332 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
.21429 .28521 m
.21429 .47568 L
.5 .47568 L
.5 .28521 L
F
1 g
.21429 .28521 m
.21429 .47568 L
.5 .47568 L
.5 .28521 L
F
.7 .7 .7 r
.005 w
[ ] 0 setdash
.21429 .28521 m
.5 .28521 L
.5 .47568 L
.21429 .47568 L
.21429 .28521 L
s
% Start of sub-graphic
p
0.214286 0.285207 0.5 0.475684 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.026455 0.26455 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.047619 0.35119 0.312169 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.7 .7 .7 r
.06233 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
0 g
.00062 w
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .17989 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Matlab) show
90.688 12.813 moveto
(6.5) show
101.813 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.354497 0.35119 0.619048 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .3 0 r
.06233 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
0 g
.00062 w
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .48677 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Helvetica-BoldItalic
%%IncludeFont: Helvetica-BoldItalic
/Helvetica-BoldItalic findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Mathematica) show
113.563 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
118.000 12.813 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 370.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001LR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oooaX0oooo0P1VIVH01@3oool0gMgM
06IVIP3MgMd0oooo0080IVIV00D0oooo0>?Sh`2DU9@0U9BD0=7Ad@0206IVIP050?ooo`3Shn<0IVIV
0;2`/03oool00P1VIVH30?ooo`80IVIV00<0lO7a06IVIP2`/;000P3oool00`2`/;00IVIV0>g]k@02
0?ooo`060?7al@32`/80IVIV06IVIP2DU9@0b/[:0P3oool206IVIP030?ooo`1VIVH0IVIV00<0IVIV
0P3oool0103AdM40U9BD06IVIP2j^[[o0?ooo`@0oooo003o0?oooaX0oooo0P1VIVH01@3oool0`/;2
06IVIP32`/80oooo0080IVIV00D0oooo09BDU01VIVH0lO7a0=gMg@0206IVIP030?ooo`1VIVH0IVIV
0080oooo0P1VIVH30?ooo`80IVIV00L0oooo0=7Ad@1VIVH0hn?S0=gMg@1VIVH0b/[:00<0oooo00P0
Y:BT06IVIP3Xj>P0oooo0>g]k@1VIVH0^[Zj0?ooo`80IVIV00@0oooo0;Zj^P1VIVH0kNg]0`3oool0
1P3AdM40IVIV0=gMg@3alO40IVIV0;Zj^_l0oooo0`3oool00?l0oooo6P3oool206IVIP050?ooo`2D
U9@0IVIV09BDU03oool00P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV00<0oooo06IVIP1VIVH0
0P3oool206IVIP<0oooo0P1VIVH20?ooo`0509BDU02TY:@0U9BD09BDU03fm_H01`3oool0103MgMd0
IVIV06IVIP3oool206IVIP040?ooo`3fm_H0IVIV0;2`/0<0oooo00<0U9BD06IVIP3oool0o`3oool6
0?ooo`00o`3ooolJ0?ooo`80IVIV00D0lO7a06IVIP32`/80IVIV0?7al@0206IVIP050?ooo`3Shn<0
IVIV0<;2`P3alO400P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV0`3oool206IVIP80oooo00@0
gMgM06IVIP1VIVH0dM7A1P3oool01P3Shn<0Y:BT06IVIP1VIVH0^[Zj0?ooo`80IVIV0P3oool00`3G
emL0IVIV0=gMg@020?ooo`H0IVIVo`3oool30?ooo`00o`3ooolJ0?ooo`80IVIV00D0hn?S06IVIP3]
kNd0IVIV0>?Sh`0206IVIP80oooo00<0kNg]0=7Ad@2`/;000P1VIVH00`3oool0IVIV06IVIP020?oo
o`80IVIV0`3oool206IVIP80oooo00@0Y:BT09BDU02DU9@0Y:BT103oool00`3alO40Y:BT06IVIP02
06IVIP030;Zj^P3oool0oooo0080IVIV0`3oool01P2TY:@0U9BD0?KfmP3oool0U9BD06IVIP80oooo
00<0IVIV0:BTY03oool0o`3oool20?ooo`00o`3ooolJ0?ooo`80IVIV00D0b/[:0:BTY03oool0Y:BT
0<[:bP0206IVIP080?ooo`2`/;00j>SX0?ooo`3alO40IVIV09BDU03oool206IVIP80oooo0P1VIVH0
0`3Xj>P0oooo0?ooo`0206IVIP070?ooo`3GemL0IVIV0=gMg@3GemL0IVIV0=OGe`030?ooo`050;Zj
^P1VIVH0IVIV0;2`/03]kNd00`3oool206IVIP<0oooo00X0j>SX06IVIP32`/80oooo0=OGe`1VIVH0
gMgM0>?Sh`1VIVH0emOGo`3oool30?ooo`00o`3ooolJ0?ooo`80IVIV00D0Y:BT0<[:bP3oool0`/;2
0:BTY00206IVIP030?ooo`3alO40^[Zj0080IVIV00<0Y:BT0>SXj01VIVH00`1VIVH01P3oool0IVIV
06IVIP2j^[X0/;2`0?ooo`80IVIV00<0lO7a06IVIP2`/;000P3oool00`2`/;00IVIV0?7al@020?oo
o`80IVIV00<0gMgM0?ooo`3oool00`3oool206IVIP030?ooo`1VIVH0IVIV00<0IVIV0P3oool0103A
dM40IVIV06IVIP3AdM7o0?ooo`@0oooo003o0?oooaX0oooo0`1VIVH00`3Shn<0oooo0=gMg@0306IV
IPP0oooo0P1VIVHC0?ooo`070;Zj^P1VIVH0lO7a0?ooo`3Xj>P0IVIV0:BTY03o0?oooa<0oooo003o
0?oooaX0oooo0`1VIVH00`3fm_H0oooo0>g]k@0306IVIPP0oooo00<0kNg]0;Zj^P3oool01P3oool2
06IVIP/0oooo00L0b/[:09BDU01VIVH0IVIV0<;2`P3alO40oooo0080IVIVo`3oool@0?ooo`00o`3o
oooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo002N0?oo
o`80IVIV103oool01@3alO40^[Zj06IVIP1VIVH0dM7A00<0oooo00@0b/[:06IVIP1VIVH0b/[:=@3o
ool206IVIP<0oooo00@0b/[:06IVIP1VIVH0b/[:0`3oool0103:b/X0IVIV06IVIP3:b/X30?ooo`04
0<[:bP1VIVH0IVIV0<[:bS80oooo0P1VIVH20?ooo`050?7al@2j^[X0IVIV09BDU03AdM400`3oool0
103:b/X0IVIV06IVIP3:b/X30?ooo`040<[:bP1VIVH0IVIV0<[:bS40oooo0P1VIVH30?ooo`80IVIV
1@3oool0103:b/X0IVIV06IVIP3:b/X30?ooo`040<[:bP1VIVH0IVIV0<[:bRh0oooo00<0U9BD06IV
IP1VIVH00`1VIVH20?ooo`040<[:bP1VIVH0IVIV0<[:bP<0oooo00@0b/[:06IVIP1VIVH0b/[:0`3o
ool0103:b/X0IVIV06IVIP3:b/X_0?ooo`050?7al@2j^[X0IVIV09BDU03AdM400`3oool0103:b/X0
IVIV06IVIP3:b/X30?ooo`040<[:bP1VIVH0IVIV0<[:bP<0oooo00@0b/[:06IVIP1VIVH0b/[:>P3o
ool009h0oooo00<0Y:BT06IVIP3fm_H00`3oool02@2`/;00IVIV0?7al@3Shn<0IVIV0=7Ad@3oool0
dM7A06IVIP020>?Sh`0306IVIP3:b/X0oooo03<0oooo0P1VIVH20?ooo`090=7Ad@1VIVH0hn?S0>?S
h`1VIVH0b/[:0?ooo`3AdM40IVIV0080hn?S00D0IVIV0<[:bP3oool0dM7A06IVIP020>?Sh`0306IV
IP3:b/X0oooo0300oooo0P1VIVH20?ooo`090;Zj^P1VIVH0lO7a0=gMg@1VIVH0dM7A0?ooo`3AdM40
IVIV0080hn?S00D0IVIV0<[:bP3oool0dM7A06IVIP020>?Sh`0306IVIP3:b/X0oooo02l0oooo0P1V
IVH30?ooo`030:BTY01VIVH0m_Kf00<0oooo00T0dM7A06IVIP3Shn<0hn?S06IVIP3:b/X0oooo0=7A
d@1VIVH00P3Shn<00`1VIVH0b/[:0?ooo`0/0?ooo`030<[:bP2DU9@0lO7a00@0oooo00T0dM7A06IV
IP3Shn<0hn?S06IVIP3:b/X0oooo0=7Ad@1VIVH00P3Shn<01@1VIVH0b/[:0?ooo`3AdM40IVIV0080
hn?S00<0IVIV0<[:bP3oool0;@3oool02@2j^[X0IVIV0?7al@3MgMd0IVIV0=7Ad@3oool0dM7A06IV
IP020>?Sh`0506IVIP3:b/X0oooo0=7Ad@1VIVH00P3Shn<01@1VIVH0b/[:0?ooo`3AdM40IVIV0080
hn?S00<0IVIV0<[:bP3oool0>03oool009h0oooo00<0b/[:06IVIP3Xj>P01`3oool01@1VIVH0U9BD
0?ooo`2`/;00IVIV0080oooo00<0IVIV0:BTY03oool0<`3oool206IVIP80oooo00T0/;2`06IVIP3o
ool0oooo06IVIP2TY:@0oooo0;2`/01VIVH00P3oool01@1VIVH0Y:BT0?ooo`2`/;00IVIV0080oooo
00<0IVIV0:BTY03oool0<03oool206IVIPH0oooo00D0IVIV09BDU03oool0/;2`06IVIP020?ooo`05
06IVIP2TY:@0oooo0;2`/01VIVH00P3oool00`1VIVH0Y:BT0?ooo`0_0?ooo`80IVIV0`3oool00`3:
b/X0IVIV0>SXj0030?ooo`090;2`/01VIVH0oooo0?ooo`1VIVH0Y:BT0?ooo`2`/;00IVIV0080oooo
00<0IVIV0:BTY03oool0;@3oool209BDU0060>SXj03oool0oooo0?ooo`2`/;00IVIV0P3oool01@1V
IVH0Y:BT0?ooo`2`/;00IVIV0080oooo00D0IVIV0:BTY03oool0/;2`06IVIP020?ooo`0306IVIP2T
Y:@0oooo0340oooo00D0IVIV09BDU03oool0/;2`06IVIP020?ooo`0506IVIP2TY:@0oooo0;2`/01V
IVH00P3oool01@1VIVH0Y:BT0?ooo`2`/;00IVIV0080oooo00<0IVIV0:BTY03oool0>03oool009h0
oooo00<0j>SX06IVIP3AdM401`3oool206IVIP030?ooo`1VIVH0IVIV0080oooo0P1VIVHd0?ooo`80
IVIV0P3oool206IVIP80oooo0P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV00<0oooo06IVIP1V
IVH00P3oool206IVIS40oooo0P1VIVH60?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool206IVIP03
0?ooo`1VIVH0IVIV0080oooo0P1VIVH`0?ooo`80IVIV0`3oool00`3Xj>P0IVIV0=7Ad@030?ooo`80
IVIV0P3oool206IVIP030?ooo`1VIVH0IVIV0080oooo0P1VIVH^0?ooo`040?7al@2DU9@0IVIV0=gM
g@80oooo0P1VIVH20?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool206IVIP030?ooo`1VIVH0IVIV
0080oooo0P1VIVHb0?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool206IVIP030?ooo`1VIVH0IVIV
0080oooo0P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV>@3oool009l0oooo0P2DU9@30?ooo`07
0;Zj^P2DU9@0lO7a0=gMg@1VIVH0`/;20?ooo`0206IVIP80oooo0P1VIVHd0?ooo`80IVIV0P3oool2
06IVIP80oooo0P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool2
06IVIS40oooo0P1VIVH50?ooo`040=gMg@1VIVH0`/;20?ooo`80IVIV0P3oool206IVIP030?ooo`1V
IVH0IVIV0080oooo0P1VIVH`0?ooo`80IVIV103oool209BDU0<0oooo0P1VIVH20?ooo`80IVIV00<0
oooo06IVIP1VIVH00P3oool206IVIRl0oooo00D0j>SX06IVIP1VIVH0j>SX0?ooo`0206IVIP80oooo
0P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool206IVIS40oooo
00@0gMgM06IVIP32`/80oooo0P1VIVH20?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool206IVIP03
0?ooo`1VIVH0IVIV0080oooo0P1VIVHi0?ooo`00W`3oool00`3GemL0IVIV0=OGe`020?ooo`050;Zj
^P1VIVH0U9BD06IVIP2j^[X00P3oool206IVIP80oooo0P1VIVHb0?ooo`040;Zj^P3oool0IVIV06IV
IP80oooo0P1VIVH20?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool206IVIP030?ooo`1VIVH0IVIV
0080oooo0P1VIVH_0?ooo`040;Zj^P3oool0IVIV06IVIP@0oooo00D0Y:BT06IVIP2TY:@0m_Kf0?oo
o`0206IVIP80oooo0P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV;P3oool0102j^[X0oooo06IV
IP1VIVH40?ooo`030=OGe`1VIVH0emOG0080oooo0P1VIVH20?ooo`80IVIV00<0oooo06IVIP1VIVH0
0P3oool206IVIS00oooo00@0gMgM06IVIP2TY:@0oooo0P1VIVH20?ooo`80IVIV00<0oooo06IVIP1V
IVH00P3oool206IVIP030?ooo`1VIVH0IVIV0080oooo0P1VIVH`0?ooo`050:BTY01VIVH0Y:BT0?Kf
mP3oool00P1VIVH20?ooo`80IVIV00<0oooo06IVIP1VIVH00P3oool206IVIP030?ooo`1VIVH0IVIV
0080oooo0P1VIVHi0?ooo`00X03oool01`2TY:@0IVIV0?7al@3oool0emOG06IVIP3MgMd0103oool0
1P2TY:@0IVIV0?ooo`3oool0IVIV0:BTY380oooo00@0IVIV0;2`/01VIVH0IVIV0P3oool02@2TY:@0
IVIV0?ooo`3oool0IVIV0:BTY03oool0Y:BT06IVIP020?ooo`0506IVIP2TY:@0oooo0:BTY01VIVH0
0P3oool00`1VIVH0Y:BT0?ooo`0^0?ooo`0406IVIP2`/;00IVIV06IVIPD0oooo00H0kNg]06IVIP2`
/;00oooo0:BTY01VIVH20?ooo`0506IVIP2TY:@0oooo0:BTY01VIVH00P3oool00`1VIVH0Y:BT0?oo
o`0]0?ooo`0406IVIP2`/;00IVIV06IVIPD0oooo00H0Y:BT06IVIP3alO40oooo0:BTY01VIVH20?oo
o`0506IVIP2TY:@0oooo0:BTY01VIVH00P3oool00`1VIVH0Y:BT0?ooo`0`0?ooo`80IVIV00<0oooo
0:BTY01VIVH00P3oool01@1VIVH0Y:BT0?ooo`2TY:@0IVIV0080oooo00D0IVIV0:BTY03oool0Y:BT
06IVIP020?ooo`0306IVIP2TY:@0oooo0300oooo00H0kNg]06IVIP2`/;00oooo0:BTY01VIVH20?oo
o`0506IVIP2TY:@0oooo0:BTY01VIVH00P3oool01@1VIVH0Y:BT0?ooo`2TY:@0IVIV0080oooo00<0
IVIV0:BTY03oool0>03oool00:00oooo00L0j>SX06IVIP2j^[X0oooo0>SXj01VIVH0`/;200@0oooo
00H0b/[:06IVIP3Shn<0hn?S06IVIP3:b/Xb0?ooo`040?7al@2j^[X0IVIV06IVIP80oooo00T0b/[:
06IVIP3Shn<0hn?S06IVIP3:b/X0oooo0<[:bP1VIVH00P3Shn<01@1VIVH0b/[:0?ooo`3:b/X0IVIV
0080hn?S00<0IVIV0<[:bP3oool0;P3oool0103alO40^[Zj06IVIP1VIVH20?ooo`090<;2`P1VIVH0
lO7a0?7al@1VIVH0U9BD0?ooo`3:b/X0IVIV0080hn?S00D0IVIV0<[:bP3oool0b/[:06IVIP020>?S
h`0306IVIP3:b/X0oooo02d0oooo00@0lO7a0;Zj^P1VIVH0IVIV1@3oool01P3Xj>P0IVIV0;Zj^P3o
ool0b/[:06IVIP80hn?S00D0IVIV0<[:bP3oool0b/[:06IVIP020>?Sh`0306IVIP3:b/X0oooo02`0
oooo00T0Y:BT06IVIP3alO40lO7a06IVIP2j^[X0oooo0<[:bP1VIVH00P3Shn<01@1VIVH0b/[:0?oo
o`3:b/X0IVIV0080hn?S00D0IVIV0<[:bP3oool0b/[:06IVIP020>?Sh`0306IVIP3:b/X0oooo02d0
oooo00T0`/;206IVIP3alO40lO7a06IVIP2DU9@0oooo0<[:bP1VIVH00P3Shn<01@1VIVH0b/[:0?oo
o`3:b/X0IVIV0080hn?S00D0IVIV0<[:bP3oool0b/[:06IVIP020>?Sh`0306IVIP3:b/X0oooo03P0
oooo002M0?ooo`H0IVIV00<0oooo0?KfmP1VIVH0101VIVH20?ooo`040<[:bP1VIVH0IVIV0<[:bSD0
oooo00<0`/;206IVIP3oool00P3oool0103:b/X0IVIV06IVIP3:b/X30?ooo`040<[:bP1VIVH0IVIV
0<[:bP<0oooo00@0b/[:06IVIP1VIVH0b/[:<P3oool01P32`/80IVIV0?ooo`3oool0lO7a0<;2`P80
IVIV00D0^[Zj0?7al@3oool0oooo0<[:bP0206IVIP050<[:bP3oool0oooo0?ooo`3:b/X00P1VIVH0
0`3:b/X0oooo0?ooo`0_0?ooo`040<;2`P1VIVH0oooo0?ooo`H0IVIV0P3oool0103:b/X0IVIV06IV
IP3:b/X30?ooo`040<[:bP1VIVH0IVIV0<[:bRh0oooo00D0lO7a0;2`/01VIVH0IVIV0<;2`P030?oo
o`040<[:bP1VIVH0IVIV0<[:bP<0oooo00@0b/[:06IVIP1VIVH0b/[:0`3oool0103:b/X0IVIV06IV
IP3:b/X_0?ooo`060?7al@32`/80IVIV06IVIP2j^[X0lO7a0P3oool0103:b/X0IVIV06IVIP3:b/X3
0?ooo`040<[:bP1VIVH0IVIV0<[:bP<0oooo00@0b/[:06IVIP1VIVH0b/[:>P3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oo
oeX0oooo001O0?ooool00000]00000160?ooo`00G`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`140?ooo`00G`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`140?ooo`00DP3oool0103:b/X0IVIV06IVIP3:b/X90?ooo`030000003o
ool0oooo0?l0oooom`3oool00540oooo00H0dM7A06IVIP3Shn<0hn?S06IVIP3:b/X80?ooo`030000
003oool0oooo0?l0oooom`3oool00540oooo00H0/;2`06IVIP3oool0oooo06IVIP2TY:@80?ooo`03
0000003oool0oooo0?l0oooom`3oool00540oooo0P1VIVH20?ooo`80IVIV203oool00`000000/k>c
0;>c/`0E0;>c/c00od`0o`3ooonb0?ooo`00D@3oool206IVIP80oooo0P1VIVH80?ooo`030000002c
/k<0/k>c02d0/k>c5`3oC002000002@0od`0o`3ooon=0?ooo`00D@3oool206IVIP80oooo0P1VIVH8
0?ooo`800000AP2c/k<2000004L0od`0o`3ooomY0?ooo`00D@3oool01P2TY:@0IVIV0?ooo`3oool0
IVIV0:BTY0P0ooooA`2c/k<2000000h0/k>c>@3oC002000000X0od`0o`3ooomN0?ooo`00D@3oool0
1P3:b/X0IVIV0>?Sh`3Shn<0IVIV0<[:bPP0oooo00<000000?ooo`3oool05@3oool^0;>c/`D00000
6`2c/k<Y0?m<00<00000503oC03o0?oooe@0oooo001B0?ooo`040<[:bP1VIVH0IVIV0<[:bPT0oooo
00<000000?ooo`3oool0;@3ooolH0;>c/`030000002c/k<0/k>c02T0/k>c703oC002000001h0od`0
o`3ooom:0?ooo`00G`3oool00`000000oooo0?ooo`150?oooc/0/k>c3P3oool00`000000od`00?m<
000W0?m<0?l0oooo?`3oool005l0oooo00<000000?ooo`3oool0E03ooolj0;>c/`/0oooo:@3oC03o
0?ooocD0oooo001O0?ooo`030000003oool0oooo06<0oooo:P2c/k<2000000L0/k>c3@3ooolY0?m<
0?l0oooo:`3oool005l0oooo00<000000?ooo`3oool0L@3ooolL0;>c/`030000002c/k<0/k>c00d0
/k>c403ooolY0?m<0?l0oooo8@3oool005l0oooo0P0000210?ooo`/0/k>c1@00000D0;>c/a@0oooo
7@3oC002000000H0od`0o`3ooolJ0?ooo`00G`3oool00`000000oooo0?ooo`2>0?oooad0/k>c5`3o
oolB0?m<00@000002P3oC03o0?oooaD0oooo001O0?ooo`030000003oool0oooo09H0oooo702c/k<J
0?ooo`T0od`00`00000@0?m<0?l0oooo3`3oool005l0oooo00<000000?ooo`3oool0W@3ooolM0;>c
/a`0oooo00<000000?m<003oC000503oC03o0?ooo`X0oooo001O0?ooo`030000003oool0oooo0:@0
oooo7@2c/k<K0?oooaL0od`0o`3oool40?ooo`00G`3oool00`000000oooo0?ooo`2[0?oooad0/k>c
6@3ooolG0?m<0?h0oooo001O0?ooo`030000003oool0oooo0;80oooo7@2c/k<H0?oooaL0od`0n03o
ool005l0oooo00<000000?ooo`3oool0^P3ooolL0;>c/aH0oooo5`3oC03c0?ooo`00G`3oool00`00
0000oooo0?ooo`310?oooa@0/k>c0P0000030;>c/aP0oooo5`3oC03]0?ooo`00G`3oool00`000000
oooo0?ooo`380?ooo`d0/k>c0P0000060;>c/aX0oooo5`3oC03X0?ooo`00G`3oool200000=00oooo
1@2c/k<4000000P0/k>c7@3ooolG0?m<0>80oooo001O0?ooo`030000003oool0oooo0=H0oooo00<0
00000;>c/`2c/k<02P2c/k<O0?oooaL0od`0g@3oool005l0oooo00<000000?ooo`3oool0f@3oool<
0;>c/b<0oooo5`3oC03G0?ooo`00G`3oool00`000000oooo0?ooo`3L0?ooo``0/k>c9@3ooolA0?m<
00030000003oC000od`000D0od`0d03oool005l0oooo00<000000?ooo`3oool0g`3oool<0;>c/bP0
oooo2P3oC003000000`0od`0bP3oool005l0oooo00<000000?ooo`3oool0hP3oool<0;>c/bX0oooo
1P3oC002000001<0od`0``3oool005l0oooo00<000000?ooo`3oool0i03oool=0;>c/bd0oooo00<0
00000?m<003oC0006@3oC02l0?ooo`00G`3oool00`000000oooo0?ooo`3W0?ooo`d0/k>c<@3ooolK
0?m<0;H0oooo001O0?ooo`030000003oool0oooo0>X0oooo3@2c/k<d0?oooa`0od`0[`3oool005l0
oooo00<000000?ooo`3oool0k@3oool=0;>c/cP0oooo6`3oC02Y0?ooo`00G`3oool00`000000oooo
0?ooo`3`0?ooo``0/k>c?@3ooolK0?m<0:80oooo001O0?ooo`800000m03oool<0;>c/d00oooo703o
C02K0?ooo`00G`3oool00`000000oooo0?ooo`3f0?ooo``0/k>cA03ooolK0?m<09D0oooo001O0?oo
o`030000003oool0oooo0?T0oooo302c/k=70?oooa`0od`0SP3oool005l0oooo00<000000?ooo`3o
ool0n`3oool=0;>c/d/0oooo4`3oC002000000030?m<003oool0oooo08/0oooo001O0?ooo`030000
003oool0oooo0?h0oooo3@2c/k=?0?ooo`/0od`0100000000`3oC000oooo0?ooo`2:0?ooo`00G`3o
ool00`000000oooo0?ooo`3o0?ooo`80oooo3@2c/k=B0?ooo`H0od`00`0000020?m<08/0oooo001O
0?ooo`030000003oool0oooo0?l0oooo1@3oool=0;>c/eD0oooo00<0od`00000003oC0000`3oC02:
0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo302c/k=D0?ooo`H0od`0R@3oool005l0
oooo00<000000?ooo`3oool0o`3oool;0?ooo``0/k>cDP3oool50?m<08T0oooo001O0?ooo`030000
003oool0oooo0?l0oooo3P3oool<0;>c/e00oooo1@3oC0280?ooo`00G`3oool200000?l0oooo4P3o
ool<0;>c/dh0oooo1@3oC0270?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooa<0oooo3@2c/k=;
0?ooo`H0od`0QP3oool005l0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`P0/k>c0`0000020;>c
/dT0oooo1@3oC0260?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooaT0oooo1@2c/k<2000000D0
/k>cB03oool50?m<08D0oooo001O0?ooo`030000003oool0oooo0?l0oooo703oool00`2c/k<00000
00000003000000H0/k>cAP3oool50?m<08@0oooo001O0?ooo`030000003oool0oooo0?l0oooo7`3o
ool;0;>c/d@0oooo1P3oC0230?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooob80oooo2`2c/k=2
0?ooo`H0od`0PP3oool004d0oooo0P1VIVH30?ooo`040<[:bP1VIVH0IVIV0<[:bPT0oooo00<00000
0?ooo`3oool0o`3ooolT0?ooo``0/k>c@03oool50?m<0880oooo001=0?ooo`80IVIV0P3oool01P3A
dM40IVIV0>?Sh`3Shn<0IVIV0<[:bPP0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`/0/k>c?`3o
ool50?m<0840oooo001=0?ooo`80IVIV0P3oool01P2`/;00IVIV0?ooo`3oool0IVIV0:BTY0P0oooo
00<000000?ooo`3oool0o`3ooolY0?ooo``0/k>c?@3oool50?m<0800oooo001=0?ooo`80IVIV0P3o
ool206IVIP80oooo0P1VIVH80?ooo`<00000o`3oool/0?ooo`/0/k>c>`3oool60?m<07l0oooo001=
0?ooo`80IVIV0P3oool206IVIP80oooo0P1VIVH80?ooo`030000003oool0oooo0?l0oooo;`3oool;
0;>c/cT0oooo1@3oC01o0?ooo`00B`3oool0102j^[X0oooo06IVIP1VIVH20?ooo`80IVIV0P3oool2
06IVIPP0oooo00<000000?ooo`3oool0o`3ooola0?ooo``0/k>c=`3oool50?m<07h0oooo001;0?oo
o`0406IVIP2`/;00IVIV06IVIP80oooo00H0Y:BT06IVIP3oool0oooo06IVIP2TY:@80?ooo`030000
003oool0oooo0?l0oooo=03oool;0;>c/cH0oooo1@3oC01m0?ooo`00B`3oool0103alO40^[Zj06IV
IP1VIVH20?ooo`060<[:bP1VIVH0hn?S0>?Sh`1VIVH0b/[:203oool00`000000oooo0?ooo`3o0?oo
ocH0oooo302c/k<c0?ooo`H0od`0O03oool004d0oooo00<0`/;206IVIP3oool00P3oool0103:b/X0
IVIV06IVIP3:b/X90?ooo`030000003oool0oooo0?l0oooo>@3oool;0;>c/c80oooo1P3oC01k0?oo
o`00G`3oool00`000000oooo0?ooo`3o0?oooc`0oooo2`2c/k<`0?ooo`D0od`0N`3oool005l0oooo
00<000000?ooo`3oool0o`3oooln0?ooo``0/k>c;P3oool50?m<07X0oooo001O0?ooo`030000003o
ool0oooo0?l0oooo@@3oool;0;>c/bd0oooo1@3oC01i0?ooo`00G`3oool00`000000oooo0?ooo`3o
0?oood<0oooo302c/k<Z0?ooo`H0od`0N03oool005l0oooo0P00003o0?ooodL0oooo302c/k<X0?oo
o`H0od`0M`3oool005l0oooo00<000000?ooo`3oool0o`3ooom90?ooo`/0/k>c9`3oool50?m<07L0
oooo001O0?ooo`030000003oool0oooo0?l0ooooB`3oool<0;>c/bD0oooo1@3oC01f0?ooo`00G`3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo2`2c/k<T0?ooo`D0od`0M@3oool005l0oooo00<00000
0?ooo`3oool0o`3ooomA0?ooo`/0/k>c8@3oool60?m<07@0oooo001O0?ooo`030000003oool0oooo
0?l0ooooD`3oool<0;>c/al0oooo1@3oC01d0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooeH0
oooo2`2c/k<N0?ooo`D0od`0L`3oool005l0oooo00<000000?ooo`3oool0o`3ooomH0?ooo``0/k>c
703oool50?m<0780oooo001O0?ooo`030000003oool0oooo0?l0ooooF`3oool;0;>c/aX0oooo1P3o
C01a0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooeh0oooo2`2c/k<H0?ooo`H0od`0L03oool0
05l0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`L0/k>c0P0000000`2c/k<0oooo0?ooo`0F0?oo
o`D0od`0L03oool005l0oooo0P00003o0?ooof@0oooo102c/k<200000080/k>c603oool50?m<06l0
oooo001O0?ooo`030000003oool0oooo0?l0ooooI@3oool5000000030;>c/`3oool0oooo01L0oooo
1@3oC01^0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooofL0oooo1@2c/k<H0?ooo`H0od`0K@3o
ool005l0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`D0/k>c6@3oool50?m<06d0oooo001O0?oo
o`030000003oool0oooo0?l0ooooJ03oool40;>c/aX0oooo1@3oC01/0?ooo`00G`3oool00`000000
oooo0?ooo`3o0?ooofP0oooo1@2c/k<J0?ooo`D0od`0J`3oool005l0oooo00<000000?ooo`3oool0
o`3ooomX0?ooo`D0/k>c6P3oool60?m<06X0oooo001O0?ooo`030000003oool0oooo0?l0ooooJ@3o
ool50;>c/aX0oooo1P3oC01Y0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooofT0oooo1@2c/k<K
0?ooo`D0od`0J@3oool005l0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`@0/k>c703oool50?m<
06P0oooo001O0?ooo`800000o`3ooom[0?ooo`D0/k>c703oool50?m<06L0oooo001O0?ooo`030000
003oool0oooo0?l0ooooJP3oool50;>c/a`0oooo1P3oC01V0?ooo`00G`3oool00`000000oooo0?oo
o`3o0?ooof/0oooo1@2c/k<L0?ooo`H0od`0I@3oool005l0oooo00<000000?ooo`3oool0o`3ooom[
0?ooo`D0/k>c7@3oool50?m<06D0oooo001O0?ooo`030000003oool0oooo0?l0ooooK03oool40;>c
/ah0oooo1@3oC01T0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooof`0oooo1@2c/k<N0?ooo`D0
od`0H`3oool005l0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`D0/k>c7P3oool60?m<0680oooo
001O0?ooo`030000003oool0oooo0?l0ooooK@3oool50;>c/ah0oooo1@3oC01R0?ooo`00G`3oool0
0`000000oooo0?ooo`3o0?ooofd0oooo1@2c/k<O0?ooo`D0od`0H@3oool005l0oooo00<000000?oo
o`3oool0o`3ooom^0?ooo`@0/k>c803oool50?m<0600oooo001O0?ooo`800000o`3ooom_0?ooo`D0
/k>c7`3oool60?m<05l0oooo001O0?ooo`030000003oool0oooo0?l0ooooKP3oool50;>c/b00oooo
1P3oC01N0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooofl0oooo1@2c/k<P0?ooo`D0od`0GP3o
ool005l0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`D0/k>c8@3oool50?m<05d0oooo001O0?oo
o`030000003oool0oooo0?l0ooooL03oool40;>c/b80oooo1@3oC01L0?ooo`00G`3oool00`000000
oooo0?ooo`3o0?ooog00oooo1@2c/k<Q0?ooo`H0od`0F`3oool005l0oooo00<000000?ooo`3oool0
o`3ooom`0?ooo`D0/k>c8P3oool50?m<05/0oooo001:0?ooo`0309BDU01VIVH0IVIV00<0IVIV0P3o
ool0103:b/X0IVIV06IVIP3:b/X90?ooo`030000003oool0oooo0?l0ooooL@3oool40;>c/b<0oooo
1@3oC01J0?ooo`00BP3oool00`3:b/X0U9BD0?7al@040?ooo`060=7Ad@1VIVH0hn?S0>?Sh`1VIVH0
b/[:203oool00`000000oooo0?ooo`3o0?ooog40oooo1@2c/k<S0?ooo`D0od`0F@3oool004/0oooo
0P2DU9@01P3Xj>P0oooo0?ooo`3oool0/;2`06IVIP80oooo00<0IVIV0:BTY03oool01`3oool00`00
0000oooo0?ooo`3o0?ooog40oooo1@2c/k<S0?ooo`H0od`0F03oool004/0oooo00@0lO7a09BDU01V
IVH0gMgM0P3oool206IVIP80oooo0P1VIVH80?ooo`<00000o`3ooomb0?ooo`D0/k>c8`3oool60?m<
05L0oooo001<0?ooo`050>SXj01VIVH0IVIV0>SXj03oool00P1VIVH20?ooo`80IVIV203oool00`00
0000oooo0?ooo`3o0?ooog80oooo1@2c/k<T0?ooo`D0od`0E`3oool003X0oooo00@0^[Zj06IVIP2j
^[X0lO7a0P3oool00`2TY:@0lO7a0?ooo`0:0?ooo`040=gMg@1VIVH0Y:BT0?ooo`80IVIV0P3oool2
06IVIPP0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`@0/k>c9@3oool50?m<05H0oooo000i0?oo
o`050<[:bP1VIVH0IVIV06IVIP2TY:@00P3oool00`1VIVH0`/;20?ooo`0;0?ooo`80IVIV00<0oooo
0:BTY01VIVH00P3oool00`1VIVH0Y:BT0?ooo`070?ooo`030000003oool0oooo0?l0ooooL`3oool5
0;>c/bD0oooo1@3oC01E0?ooo`00>@3oool00`2DU9@0lO7a0=gMg@0206IVIP040>?Sh`3oool0j>SX
06IVIPP0oooo00T0Y:BT06IVIP3alO40lO7a06IVIP2j^[X0oooo0<[:bP1VIVH00P3Shn<00`1VIVH0
b/[:0?ooo`070?ooo`030000003oool0oooo0?l0ooooL`3oool50;>c/bD0oooo1P3oC01D0?ooo`00
>@3oool01P1VIVH0oooo0?ooo`2`/;00IVIV0:BTY080oooo00<0IVIV0?ooo`3oool01P3oool01@3a
lO40/;2`06IVIP1VIVH0`/;200<0oooo00@0b/[:06IVIP1VIVH0b/[:2@3oool00`000000oooo0?oo
o`3o0?ooog@0oooo1@2c/k<U0?ooo`H0od`0D`3oool003T0oooo00@0IVIV0>SXj03oool0kNg]0P1V
IVH00`3MgMd0kNg]09BDU00M0?ooo`030000003oool0oooo0?l0ooooM03oool50;>c/bH0oooo1@3o
C01C0?ooo`00>@3oool01@32`/80IVIV0?ooo`3oool0^[Zj00<0IVIV00<0b/[:0?ooo`3oool06`3o
ool00`000000oooo0?ooo`3o0?ooogD0oooo102c/k<W0?ooo`D0od`0DP3oool003T0oooo00<0lO7a
0:BTY03oool00P3oool00`2j^[X0IVIV0;Zj^P0N0?ooo`030000003oool0oooo0?l0ooooM@3oool5
0;>c/bL0oooo1@3oC01A0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooogD0oooo1@2c/k<W0?oo
o`H0od`0D03oool003`0oooo00D0emOG09BDU01VIVH0U9BD0=7Ad@0N0?ooo`800000o`3ooomg0?oo
o`D0/k>c9`3oool50?m<0500oooo000k0?ooo`030=7Ad@1VIVH0IVIV00<0IVIV00<0dM7A0?ooo`3o
ool06`3oool00`000000oooo0?ooo`3o0?ooogH0oooo1@2c/k<X0?ooo`D0od`0C`3oool003/0oooo
00L0IVIV0=gMg@3oool0IVIV0?ooo`3MgMd0U9BD01d0oooo00<000000?ooo`3oool0o`3ooomg0?oo
o`@0/k>c:@3oool50?m<04h0oooo000k0?ooo`0706IVIP3Shn<0oooo06IVIP3oool0lO7a06IVIP0M
0?ooo`030000003oool0oooo0?l0ooooM`3oool50;>c/bP0oooo1P3oC01=0?ooo`00>`3oool01`3A
dM40IVIV06IVIP1VIVH0oooo06IVIP2j^[X07@3oool00`000000oooo0?ooo`3o0?ooogL0oooo1@2c
/k<Y0?ooo`H0od`0C03oool003`0oooo00D0emOG0:BTY01VIVH0oooo0;Zj^P0N0?ooo`030000003o
ool0oooo0?l0ooooN03oool50;>c/bT0oooo1@3oC01<0?ooo`00G`3oool00`000000oooo0?ooo`0M
0?ooojd0/k>c[@3oool50;>c/bX0oooo1@3oC01;0?ooo`00?03oool01@3AdM40U9BD06IVIP2DU9@0
dM7A01h0oooo00<000000?ooo`3oool07@3ooon]0;>c/jh0oooo102c/k<[0?ooo`D0od`0BP3oool0
03/0oooo00<0dM7A06IVIP1VIVH00`1VIVH00`3AdM40oooo0?ooo`0K0?ooo`030000003oool0oooo
01d0oooo0P2c/k>Y0?ooo`80/k>c[P3oool50;>c/bX0oooo1P3oC0190?ooo`00>`3oool00`2DU9@0
gMgM0?ooo`020?ooo`030=gMg@1VIVH0oooo01`0oooo00<000000?ooo`3oool07@3oool20;>c/jT0
oooo0P2c/k>^0?ooo`D0/k>c:`3oool60?m<04P0oooo000k0?ooo`0306IVIP3alO40oooo0080oooo
00<0lO7a06IVIP3oool0703oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/jl0oooo
102c/k</0?ooo`D0od`0B03oool003/0oooo00<0^[Zj06IVIP3oool00P3oool00`1VIVH0^[Zj0?oo
o`0L0?ooo`8000007P3oool20;>c/jT0oooo0P2c/k>_0?ooo`D0/k>c;03oool50?m<04L0oooo000k
0?ooo`030?7al@2j^[X0oooo0080oooo00<0/;2`0?7al@3oool0703oool00`000000oooo0?ooo`0M
0?ooo`80/k>cZ@3oool20;>c/jl0oooo1@2c/k<]0?ooo`@0od`0A`3oool005l0oooo00<000000?oo
o`3oool07@3oool20;>c/jT0oooo0P2c/k>`0?ooo`D0/k>c;03oool40?m<04L0oooo000l0?ooo`05
0=OGe`2TY:@0IVIV0:BTY03GemL07P3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c
/k00oooo1@2c/k<]0?ooo`80od`000<000000?ooo`3oool0A@3oool003/0oooo00<0dM7A06IVIP1V
IVH00`1VIVH00`3AdM40oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80
/k>c/@3oool40;>c/bh0oooo0P0000170?ooo`00>`3oool00`2DU9@0gMgM0?ooo`020?ooo`030=gM
g@2DU9@0oooo01`0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k>a0?ooo`D0/k>c
;P3oool00`000000oooo0?ooo`150?ooo`00>`3oool00`1VIVH0gMgM0?ooo`020?ooo`030=gMg@2D
U9@0oooo01`0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k>a0?ooo`D0/k>c;P3o
ool00`3oC000oooo0?ooo`150?ooo`00>`3oool00`3AdM40IVIV06IVIP0306IVIP030=7Ad@3oool0
oooo01/0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k>b0?ooo`D0/k>cM@3oool0
03`0oooo00D0emOG0:BTY01VIVH0Y:BT0=OGe`0N0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y
0?ooo`80/k>c/P3oool50;>c/gD0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?oo
o`80/k>c/`3oool40;>c/gD0oooo000k0?ooo`L0IVIV7@3oool2000001h0oooo0P2c/k>Y0?ooo`80
/k>c/`3oool50;>c/g@0oooo000k0?ooo`L0IVIV7@3oool00`000000oooo0?ooo`0M0?ooo`80/k>c
Z@3oool20;>c/k<0oooo1@2c/k=d0?ooo`00>`3oool00`3Shn<0emOG0?ooo`0Q0?ooo`030000003o
ool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>c]03oool50;>c/g<0oooo000k0?ooo`030;2`/03alO40
oooo0240oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k>d0?ooo`D0/k>cL`3oool0
03/0oooo00<0U9BD06IVIP1VIVH0101VIVHM0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?oo
o`80/k>c]@3oool40;>c/g<0oooo000k0?ooo`030>?Sh`2DU9@0IVIV00@0IVIV7@3oool00`000000
oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kD0oooo1@2c/k=b0?ooo`00G`3oool00`000000oooo
0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kD0oooo1@2c/k=b0?ooo`00?03oool01@3:b/X0U9BD06IV
IP2DU9@0b/[:01h0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k>f0?ooo`D0/k>c
L@3oool003/0oooo00<0^[Zj06IVIP1VIVH00`1VIVH00`2j^[X0oooo0?ooo`0K0?ooo`030000003o
ool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>c]P3oool50;>c/g40oooo000k0?ooo`030:BTY03MgMd0
oooo0080oooo00<0gMgM09BDU03oool0703oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool2
0;>c/kL0oooo102c/k=a0?ooo`00>`3oool00`3Shn<0b/[:0?ooo`020?ooo`030=OGe`3MgMd0oooo
01`0oooo0P00000N0?ooo`80/k>cZ@3oool20;>c/kL0oooo1@2c/k=`0?ooo`00>@3oool906IVIQd0
oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k>g0?ooo`D0/k>cL03oool003T0oooo
2@1VIVHM0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>c^03oool40;>c/g00oooo
001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>c^03oool50;>c/fl0oooo000k
0?ooo`070?7al@2TY:@0U9BD0>?Sh`3oool0/;2`0?KfmP0M0?ooo`030000003oool0oooo01d0oooo
0P2c/k>Y0?ooo`80/k>c^03oool50;>c/fl0oooo000k0?ooo`070;2`/01VIVH0IVIV09BDU03oool0
IVIV0<;2`P0M0?ooo`030000003oool0oooo01d0oooo0P2c/k<Q0?ooo`8000008P3oool01P000000
oooo0000003oool000000?ooo`<000000P3oool3000000050?ooo`00000000000000003oool00`00
00050?ooo`80000000<0oooo0000003oool00`0000110?ooo`80/k>c^@3oool50;>c/fh0oooo000k
0?ooo`0706IVIP3oool0/;2`06IVIP3Xj>P0lO7a06IVIP0M0?ooo`030000003oool0oooo01d0oooo
0P2c/k<;0?oooaH0/k>c00<000000;>c/`2c/k<0502c/k<=0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo00000011
0?ooo`80/k>c^@3oool50;>c/fh0oooo000k0?ooo`0706IVIP3alO40hn?S06IVIP3:b/X0m_Kf06IV
IP080?ooo`050?7al@2j^[X0IVIV09BDU03AdM400`3oool0103:b/X0IVIV06IVIP3:b/X90?ooo`03
0000003oool0oooo01d0oooo0P2c/k<;0?oooa@0/k>c1@00000D0;>c/`d0oooo0P0000000`3oool0
0000000000020?ooo`8000000P3oool00`000000oooo000000020?ooo`80000000D0oooo0000003o
ool0oooo000000030?ooo`<000001@3oool00`000000oooo0?ooo`0o0?ooo`80/k>c^P3oool40;>c
/fh0oooo000k0?ooo`040;Zj^P1VIVH0oooo09BDU080IVIV00<0/;2`0?ooo`3oool01P3oool02@2j
^[X0IVIV0?7al@3MgMd0IVIV0=7Ad@3oool0dM7A06IVIP020>?Sh`0306IVIP3:b/X0oooo00L0oooo
00<000000?ooo`3oool07@3oool20;>c/dD0oooo0P0000001`3oool000000000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001@3oool300000440oooo0P2c/k>j0?ooo`D0/k>cK@3oool003/0oooo
00L0lO7a0;2`/03oool0hn?S09BDU02TY:@0lO7a00`0oooo00D0IVIV09BDU03oool0/;2`06IVIP02
0?ooo`0306IVIP2TY:@0oooo00L0oooo00<000000?ooo`3oool07@3oool20;>c/dD0oooo0P000000
103oool000000000003oool3000000030?ooo`00000000000080000000D0oooo0000000000000000
0?ooo`03000000@0oooo00<000000?ooo`0000000`3oool200000480oooo0P2c/k>j0?ooo`D0/k>c
K@3oool004h0oooo0P1VIVH00`3oool0IVIV06IVIP020?ooo`80IVIV203oool3000001d0oooo0P2c
/k=50?ooo`80000000<0oooo0000000000001P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo00D0oooo0P0000040?ooo`800000@@3oool20;>c/k/0oooo1@2c/k=/0?ooo`00C@3oool0
103MgMd0IVIV0<;2`P3oool206IVIP80oooo0P1VIVH80?ooo`030000003oool0oooo01d0oooo0P2c
/k=@0?ooo`030000003oool0oooo05H0oooo0P2c/k>k0?ooo`D0/k>cK03oool004`0oooo00D0Y:BT
06IVIP2TY:@0m_Kf0?ooo`0206IVIP80oooo0P1VIVH80?ooo`030000003oool0oooo01d0oooo0P2c
/k>Y0?ooo`80/k>c_03oool40;>c/f`0oooo001=0?ooo`060>g]k@1VIVH0/;2`0?ooo`2TY:@0IVIV
0P3oool00`1VIVH0Y:BT0?ooo`070?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>c
_03oool50;>c/f/0oooo001:0?ooo`090<;2`P1VIVH0lO7a0?7al@1VIVH0U9BD0?ooo`3:b/X0IVIV
0080hn?S00<0IVIV0<[:bP3oool01`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c
/k`0oooo1@2c/k=[0?ooo`00BP3oool01P3alO40`/;206IVIP1VIVH0^[Zj0?7al@80oooo00@0b/[:
06IVIP1VIVH0b/[:2@3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kd0oooo1@2c
/k=Z0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kd0oooo1@2c/k=Z
0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kh0oooo102c/k=Z0?oo
o`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kh0oooo1@2c/k=Y0?ooo`00
G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kh0oooo1@2c/k=Y0?ooo`00G`3o
ool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/kl0oooo1@2c/k=X0?ooo`00G`3oool2
000001h0oooo0P2c/k>Y0?ooo`80/k>c_`3oool50;>c/fP0oooo001O0?ooo`030000003oool0oooo
01d0oooo0P2c/k>Y0?ooo`80/k>c`03oool40;>c/fP0oooo001O0?ooo`030000003oool0oooo01d0
oooo0P2c/k>Y0?ooo`80/k>c`03oool50;>c/fL0oooo001O0?ooo`030000003oool0oooo01d0oooo
0P2c/k>Y0?ooo`80/k>c`03oool50;>c/fL0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c
/k>Y0?ooo`80/k>c`@3oool40;>c/fL0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y
0?ooo`80/k>c`@3oool50;>c/fH0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?oo
o`80/k>c`@3oool50;>c/fH0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80
/k>c`P3oool50;>c/fD0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>c
`P3oool50;>c/fD0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>c``3o
ool40;>c/fD0oooo001O0?ooo`8000007P3oool20;>c/jT0oooo0P2c/k?30?ooo`D0/k>cI03oool0
05l0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?30?ooo`D0/k>cI03oool005l0
oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?40?ooo`D0/k>cH`3oool005l0oooo
00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?40?ooo`D0/k>cH`3oool005l0oooo00<0
00000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?50?ooo`@0/k>cH`3oool005l0oooo00<00000
0?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?50?ooo`D0/k>cHP3oool005l0oooo00<000000?oo
o`3oool07@3oool20;>c/jT0oooo0P2c/k?50?ooo`D0/k>cHP3oool005l0oooo00<000000?ooo`3o
ool07@3oool20;>c/jT0oooo0P2c/k?60?ooo`D0/k>cH@3oool005l0oooo00<000000?ooo`3oool0
7@3oool20;>c/jT0oooo0P2c/k?60?ooo`D0/k>cH@3oool005l0oooo00<000000?ooo`3oool07@3o
ool20;>c/jT0oooo0P2c/k?70?ooo`@0/k>cH@3oool005l0oooo0P00000N0?ooo`80/k>cZ@3oool2
0;>c/lL0oooo1@2c/k=P0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c
/lL0oooo1@2c/k=P0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lP0
oooo1@2c/k=O0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lP0oooo
1@2c/k=O0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lT0oooo102c
/k=O0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lT0oooo1@2c/k=N
0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lT0oooo1@2c/k=N0?oo
o`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lX0oooo102c/k=N0?ooo`00
G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lX0oooo1@2c/k=M0?ooo`00G`3o
ool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/lX0oooo1@2c/k=M0?ooo`00G`3oool2
000001h0oooo0P2c/k>Y0?ooo`80/k>cb`3oool50;>c/e`0oooo001O0?ooo`030000003oool0oooo
01d0oooo0P2c/k>Y0?ooo`80/k>cb`3oool50;>c/e`0oooo001O0?ooo`030000003oool0oooo01d0
oooo0P2c/k>Y0?ooo`80/k>cc03oool40;>c/e`0oooo001O0?ooo`030000003oool0oooo01d0oooo
0P2c/k>Y0?ooo`80/k>cc03oool50;>c/e/0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c
/k>Y0?ooo`80/k>cc03oool50;>c/e/0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y
0?ooo`80/k>cc@3oool50;>c/eX0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k<R0?oo
o`030000003oool0oooo01l0oooo00H000000?ooo`000000oooo0000003oool300000080oooo0`00
00020?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool3
00000080oooo0`0000020?ooo`80000000@0oooo00000000000000001@3oool300000300oooo0P2c
/k?=0?ooo`D0/k>cFP3oool004d0oooo0P1VIVH30?ooo`040<[:bP1VIVH0IVIV0<[:bPT0oooo00<0
00000?ooo`3oool07@3oool20;>c/b40oooo0P00000Q0?ooo`<0000000H0oooo0000003oool00000
0?ooo`0000020?ooo`030000003oool000000080oooo00D000000?ooo`3oool000000?ooo`020000
00040?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo00000002
0?ooo`060000003oool000000000003oool000001@3oool00`000000oooo0000000`0?ooo`80/k>c
cP3oool40;>c/eX0oooo001=0?ooo`80IVIV0P3oool01P3AdM40IVIV0>?Sh`3Shn<0IVIV0<[:bPP0
oooo00<000000?ooo`3oool07@3oool20;>c/`/0oooo5@3oC003000001D0od`0303oool200000003
0?ooo`00000000000080oooo0`000000103oool000000?ooo`0000020?ooo`030000003oool0oooo
00@0000000@0oooo0000003oool000000`3oool3000000040?ooo`000000oooo00000080oooo00@0
00000?ooo`3oool0oooo0`0000060?ooo`030000003oool0oooo02h0oooo0P2c/k?>0?ooo`D0/k>c
F@3oool004X0oooo1P1VIVH00`3oool0/;2`06IVIP020?ooo`0306IVIP2TY:@0oooo00L0oooo00<0
00000?ooo`3oool07@3oool20;>c/`/0oooo5P3oC002000001D0od`0303oool2000000040?ooo`00
00000000000000<0oooo00<000000?ooo`0000000P3oool01`000000oooo000000000000oooo0000
003oool01@0000000`3oool000000?ooo`030?ooo`030000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo0080oooo0`00000`0?ooo`80/k>ccP3oool5
0;>c/eT0oooo001:0?ooo`030;Zj^P3]kNd0oooo0080IVIV0P3oool206IVIP80oooo0P1VIVH80?oo
o`030000003oool0oooo01d0oooo0P2c/k=40?ooo`8000000P3oool6000000030?ooo`0000000000
00@000000`3oool2000000050?ooo`00000000000?ooo`0000000P3oool4000000030?ooo`000000
0000008000000P3oool6000000@0oooo0P00000a0?ooo`80/k>cc`3oool50;>c/eP0oooo001:0?oo
o`030?7al@2`/;00oooo0080IVIV0P3oool206IVIP80oooo0P1VIVH80?ooo`<000007@3oool20;>c
/dD0oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo0280oooo0P00000`0?oo
o`80/k>cc`3oool50;>c/eP0oooo001;0?ooo`040<[:bP3Shn<0IVIV06IVIP80oooo0P1VIVH20?oo
o`80IVIV203oool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/m00oooo102c/k=H0?oo
o`00B`3oool0103fm_H0Y:BT06IVIP1VIVH20?ooo`060:BTY01VIVH0oooo0?ooo`1VIVH0Y:BT203o
ool00`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/m00oooo1@2c/k=G0?ooo`00C03oool0
0`3GemL0IVIV06IVIP020?ooo`060<[:bP1VIVH0hn?S0>?Sh`1VIVH0b/[:203oool00`000000oooo
0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/m00oooo1@2c/k=G0?ooo`00C@3oool00`2DU9@0IVIV0?oo
o`020?ooo`040<[:bP1VIVH0IVIV0<[:bPT0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo
0P2c/k?A0?ooo`D0/k>cEP3oool005l0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c
/k?A0?ooo`D0/k>cEP3oool005l0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?B
0?ooo`@0/k>cEP3oool005l0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?B0?oo
o`D0/k>cE@3oool005l0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?B0?ooo`D0
/k>cE@3oool005l0oooo00<000000?ooo`3oool07@3oool20;>c/jT0oooo0P2c/k?C0?ooo`@0/k>c
E@3oool005l0oooo0P00000N0?ooo`80/k>cZ@3oool20;>c/m<0oooo1@2c/k=D0?ooo`00G`3oool0
0`000000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/m<0oooo1@2c/k=D0?ooo`00G`3oool00`00
0000oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/m@0oooo1@2c/k=C0?ooo`00G`3oool00`000000
oooo0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/m@0oooo1@2c/k=C0?ooo`00G`3oool00`000000oooo
0?ooo`0M0?ooo`80/k>cZ@3oool20;>c/mD0oooo102c/k=C0?ooo`00G`3oool00`000000oooo0?oo
o`0M0?ooo`80/k>cZ@3oool20;>c/mD0oooo1@2c/k=B0?ooo`00G`3oool00`000000oooo0?ooo`0M
0?ooo`80/k>cZ@3oool20;>c/mD0oooo1@2c/k=B0?ooo`00G`3oool00`000000oooo0?ooo`0M0?oo
o`80/k>cZ@3oool20;>c/mH0oooo1@2c/k=A0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80
/k>cZ@3oool20;>c/mH0oooo1@2c/k=A0?ooo`00G`3oool00`000000oooo0?ooo`0M0?ooo`80/k>c
Z@3oool20;>c/mL0oooo102c/k=A0?ooo`00G`3oool2000001h0oooo0P2c/k>Y0?ooo`80/k>ce`3o
ool50;>c/e00oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>ce`3oool5
0;>c/e00oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>cf03oool50;>c
/dl0oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>cf03oool50;>c/dl0
oooo001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>cf@3oool40;>c/dl0oooo
001O0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>cf@3oool50;>c/dh0oooo001O
0?ooo`030000003oool0oooo01d0oooo0P2c/k>Y0?ooo`80/k>cf@3oool50;>c/dh0oooo001O0?oo
o`030000003oool0oooo01d0oooo[@2c/k?J0?ooo`D0/k>cC@3oool005l0oooo00<000000?ooo`3o
ool07@3ooon]0;>c/mX0oooo1@2c/k==0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooojH0oooo
102c/k==0?ooo`00G`3oool200000?l0ooooY`3oool50;>c/d`0oooo001O0?ooo`030000003oool0
oooo0?l0ooooYP3oool50;>c/d`0oooo001O0?ooo`030000003oool0oooo0?l0ooooY`3oool40;>c
/d`0oooo001O0?ooo`030000003oool0oooo0?l0ooooY`3oool50;>c/d/0oooo001O0?ooo`030000
003oool0oooo0?l0ooooY`3oool50;>c/d/0oooo001O0?ooo`030000003oool0oooo0?l0ooooZ03o
ool50;>c/dX0oooo001O0?ooo`030000003oool0oooo0?l0ooooZ03oool50;>c/dX0oooo001O0?oo
o`030000003oool0oooo0?l0ooooZ@3oool40;>c/dX0oooo001O0?ooo`030000003oool0oooo0?l0
ooooZ@3oool50;>c/dT0oooo001O0?ooo`030000003oool0oooo0?l0ooooZ@3oool50;>c/dT0oooo
001O0?ooo`030000003oool0oooo0?l0ooooZP3oool50;>c/dP0oooo001O0?ooo`800000o`3ooon[
0?ooo`D0/k>cB03oool005l0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`@0/k>cB03oool005l0
oooo00<000000?ooo`3oool0o`3ooon[0?ooo`D0/k>cA`3oool005l0oooo00<000000?ooo`3oool0
o`3ooon[0?ooo`D0/k>cA`3oool005l0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`@0/k>cA`3o
ool005l0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`@0/k>cA`3oool004X0oooo00D0lO7a0;Zj
^P1VIVH0IVIV0=7Ad@030?ooo`040<[:bP1VIVH0IVIV0<[:bPT0oooo00<000000?ooo`3oool0o`3o
oon]0?ooo`<0/k>cA`3oool004X0oooo00T0/;2`06IVIP3alO40hn?S06IVIP3AdM40oooo0=7Ad@1V
IVH00P3Shn<00`1VIVH0b/[:0?ooo`070?ooo`030000003oool0oooo0?l0oooo[@3oool30;>c/dL0
oooo001>0?ooo`0506IVIP2DU9@0oooo0;2`/01VIVH00P3oool00`1VIVH0Y:BT0?ooo`070?ooo`03
0000003oool0oooo0?l0oooo[@3oool30;>c/dL0oooo001>0?ooo`80IVIV00<0oooo06IVIP1VIVH0
0P3oool206IVIPP0oooo00<000000?ooo`3oool0o`3ooon^0?ooo`030;>c/`000000oooo04H0oooo
001:0?ooo`070;Zj^P2DU9@0lO7a0=gMg@1VIVH0`/;20?ooo`0206IVIP80oooo0P1VIVH80?ooo`<0
0000o`3ooon^0?ooo`800000A`3oool004X0oooo00D0^[Zj06IVIP2DU9@0IVIV0;Zj^P020?ooo`80
IVIV0P3oool206IVIPP0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`030;>c/`3oool0oooo04D0
oooo001:0?ooo`030=OGe`1VIVH0gMgM00@0oooo00H0Y:BT06IVIP3oool0oooo06IVIP2TY:@80?oo
o`030000003oool0oooo0?l0oooo[`3oool00`2c/k<0oooo0?ooo`150?ooo`00BP3oool00`3Xj>P0
IVIV0<;2`P040?ooo`060<[:bP1VIVH0hn?S0>?Sh`1VIVH0b/[:203oool00`000000oooo0?ooo`3o
0?ooooL0oooo001:0?ooo`030?KfmP1VIVH0IVIV00<0IVIV0P3oool0103:b/X0IVIV06IVIP3:b/X9
0?ooo`030000003oool0oooo0?l0oooom`3oool005l0oooo00<000000?ooo`3oool0o`3oooog0?oo
o`00G`3oool00`000000oooo0?ooo`3o0?ooooL0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oo
oeX0oooo003Z0?ooo`P0000000<0O7al0:NWY`3`l?00203oool00`3@d=00VYZJ04e=C@0200000003
09ZJVP3@d=00oooo00H0oooo00@0S8b<000000000000VYZJ2P3oool3000000d0oooo0`0000080?oo
o`030=3@d02JVYX0CDe=0080000000<0VYZJ0=3@d03oool01P3oool01`3YjNT0VYZJ000000000000
O7al0;fm_@3oool00`0000050?ooo`070>7Qh@2JVYX000000000001lO7`0alO70?ooo`03000000D0
oooo00<0l?3`0:NWY`1=CDd00P0000000`2<S8`0d=3@0?ooo`050?ooo`0408b<S0000000000009ZJ
V^L0oooo003Z0?ooo`/0000000<0d=3@0?ooo`3oool0103oool00`1lO7`000000000000500000003
09ZJVP3oool0oooo00<0oooo00D0VYZJ000000000000000007alO00:0?ooo`<000003@3oool30000
00L0oooo00<0O7al0000000000001@0000000`2JVYX0oooo0?ooo`030?ooo`030=WIf@0000000000
00@0000000@0S8b<0000000000000000103oool00`3YjNT0000000000004000000040:NWY`000000
0000000000@0oooo00<0fMWI04e=C@0000001@0000000`2WYjL0oooo0?ooo`020?ooo`0509ZJVP00
000000000000001lO7`0i`3oool00>X0oooo300000000`3@d=00oooo0?ooo`020?ooo`0307alO000
0000000000L0000000<0VYZJ0?ooo`3oool00P3oool01@1=CDd00000000000000000YjNW00X0oooo
0`00000=0?ooo`<000001P3oool00`1lO7`00000000000070000000309ZJVP3oool0oooo0080oooo
00<0CDe=000000000000200000040?ooo`0309ZJVP000000000000P00000103oool00`1=CDd00000
00000006000000050;fm_@3oool0oooo0?ooo`1=CDd00`0000000`2WYjL0oooo0?ooo`3U0?ooo`00
jP3oool3000000D0oooo00D0fMWI08b<S0000000000004e=C@030?ooo`090=3@d000000000000000
002m_Kd0l?3`0?ooo`3`l?00/[:b00<0000000@0d=3@0?ooo`3oool0oooo0`0000000`3oool0l?3`
0?ooo`090?ooo`<000003@3oool3000000D0oooo00T0d=3@00000000000000000;fm_@3`l?00oooo
0?3`l02b/[800`000000103@d=00oooo0?ooo`2m_Kd20000000604e=C@3@d=00oooo0?ooo`37alL0
CDe=0`0000040?ooo`0404e=C@00000000000:NWY`80oooo00<0fMWI04e=C@0000000P0000030?oo
o`080;fm_@000000000004e=C@3QhN40oooo0?3`l01lO7`20000000406QXJ03oool0oooo0?ooo`<0
000000<0oooo0?3`l03oool0iP3oool00>X0oooo0`0000070?ooo`0407alO000000000000=3@d080
oooo00@0S8b<000000000000_Kfm1@3oool0102WYjL000000000002JVYX30?ooo`<00000303oool3
000000d0oooo0`0000050?ooo`0408b<S000000000000;fm_@D0oooo00@0YjNW000000000000VYZJ
0P3oool0102<S8`000000000003@d=040?ooo`040<O7a`0000000000000000@0oooo0`0000001@3`
l?00oooo0?ooo`3oool0fMWI00<000000`3oool0101lO7`000000000003@d=030?ooo`040?3`l01X
J6P0/[:b0>WYj@<0oooo0`00003Y0?ooo`00jP3oool3000000L0oooo00@0d=3@000000000000VYZJ
0P3oool3000000030?3`l03oool0oooo00<0oooo00@0jNWY000000000000CDe=0`3oool3000000`0
oooo0`00000=0?ooo`<000001@3oool3000000030?3`l03oool0oooo00<0oooo00@0jNWY00000000
0000CDe=0P3oool3000000H0oooo0`0000040?ooo`<000001@3oool3000000<0oooo0`00000;0?oo
o`<00000j@3oool00>X0oooo0`0000070?ooo`040?3`l0000000000006QXJ080oooo0`0000070?oo
o`<000000`3oool3000000`0oooo200000000`1lO7`0YjNW0?3`l0050?ooo`<000001@3oool30000
00L0oooo0`0000020?ooo`<000001P3oool3000000@0oooo0`0000050?ooo`<000000`3oool30000
00/0oooo0`00003Y0?ooo`00jP3oool3000000P0oooo0`0000020?ooo`<0000000<0l?3`0?ooo`3o
ool00`3oool0103YjNT000000000000000030?ooo`<00000303oool;000000030=3@d03oool0oooo
0080oooo0`0000000`3`l?00oooo0?ooo`020?ooo`<0000000<0l?3`0?ooo`3oool00`3oool0103Y
jNT000000000000000020?ooo`<000001P3oool3000000@0oooo0`0000050?ooo`<000000`3oool3
000000/0oooo0`00003Y0?ooo`00jP3oool3000000P0oooo0`0000020?ooo`0409ZJVP0000000000
0;fm_@D0oooo00@0YjNW000000000000VYZJ0`3oool3000000`0oooo30000000103QhN40oooo0?oo
o`3oool3000000030=3@d03oool0oooo0080oooo00@0VYZJ000000000000_Kfm1@3oool0102WYjL0
00000000002JVYX20?ooo`0408b<S000000000000=3@d0@0oooo00@0d=3@0000000000000000103o
ool3000000D0oooo0`0000030?ooo`0408b<S000000000000=3@d0<0oooo00@0l?3`06QXJ02b/[80
jNWY0`3oool300000>T0oooo003Z0?ooo`<00000203oool300000080oooo00T0d=3@000000000000
00000;fm_@3`l?00oooo0?3`l02b/[800`000000103@d=00oooo0?ooo`3oool3000000`0oooo0`00
00050?ooo`050=3@d01=CDd000000000002JVYX00`3oool30000000307alO03`l?00oooo0080oooo
00T0d=3@00000000000000000;fm_@3`l?00oooo0?3`l02b/[800`000000103@d=00oooo0?ooo`37
alL20000000604e=C@3@d=00oooo0?ooo`3@d=00CDe=0`0000040?ooo`<000001@3oool3000000<0
oooo00P0_Kfm000000000000CDe=0>7Qh@3oool0l?3`07alO080000000@0J6QX0?ooo`3oool0oooo
0`00003Y0?ooo`00jP3oool3000000L0oooo00@0l?3`000000000000J6QX0`3oool00`2<S8`00000
000000070000000308b<S03oool0oooo00L000002P3oool3000000H0oooo00@0hN7Q000000000000
CDe=0`3oool6000000040<O7a`3oool0oooo08b<S0T0000000<0S8b<0?ooo`3oool00P3oool00`1=
CDd0000000000008000000@0oooo0`0000050?ooo`<00000103oool00`1=CDd00000000000060000
00030=3@d03oool0000000H00000i`3oool00>X0oooo0`0000070?ooo`040=3@d0000000000009ZJ
VP@0oooo00<0O7al0000000000001@000000102<S8`0oooo0?ooo`3oool7000000X0oooo0`000007
0?ooo`<000000`3oool30000000406QXJ0000000000007alO0<0oooo00<0O7al0000000000001@00
00000`2<S8`0oooo0?ooo`030?ooo`030=WIf@000000000000@0000000@0O7al0000000000000000
103oool3000000D0oooo0`0000040?ooo`030>WYj@1=CDd0000000D0000000<0YjNW0?ooo`3oool0
1`00003W0?ooo`00jP3oool3000000L0oooo00@0J6QX000000000000d=3@1@3oool00`3@d=00VYZJ
000000020000000309ZJVP3@d=00oooo00<0oooo1`00000:0?ooo`<000001P3oool0103QhN400000
0000000000030?ooo`<0000000@0jNWY06QXJ0000000YjNW103oool00`3@d=00VYZJ000000020000
000309ZJVP3@d=00oooo00H0oooo00L0jNWY09ZJVP1=CDd0000006QXJ02m_Kd0oooo00<00000103o
ool3000000D0oooo0`0000050?ooo`030?3`l02WYjL0J6QX0080000000<0O7al0=3@d03oool00P3o
ool700000>L0oooo003Z0?ooo`<00000103oool00`3`l?00d=3@06QXJ0020000000304e=C@3oool0
oooo0140oooo0`00000<0?ooo`<000001@3oool01@3@d=00CDe=000000000000VYZJ02<0oooo0`00
000P0?ooo`<00000j@3oool00>X0oooo300000000`3IfMT0oooo0?ooo`0A0?ooo`<00000303oool<
000000030=WIf@3oool0oooo0240oooo0`00000P0?ooo`<00000j@3oool00>X0oooo2`0000000`3@
d=00oooo0?ooo`0B0?ooo`030=WIf@1=CDd0000000`0oooo2`0000000`2WYjL0oooo0?ooo`0R0?oo
o`<00000803oool00`3IfMT0CDe=0000003Y0?ooo`00jP3oool80000000307alO02WYjL0jNWY01L0
oooo00<0VYZJ0?ooo`3oool02P3oool80000000304e=C@2<S8`0d=3@02D0oooo0`00000R0?ooo`03
09ZJVP3oool0oooo0>L0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00>/0oooo0P1oOgl40?ooo`80Ogmo0P3oool207moO`80oooo00<0inOW07moO`3WinL0
0P3oool207moO`80oooo0P1oOgl20?ooo`80Ogmo0`3oool00`3Rh^80Ogmo07moO`040?ooo`050=kN
gP2c/k<0Ogmo0:FUY@3Cdm<02P3oool01@3Cdm<0Ogmo07moO`2m_Kd0jn_[00D0oooo00D0dm?C0:FU
Y@1oOgl0YJFU0=?Cd`040?ooo`80Ogmo0P3oool00`3WinL0Ogmo0>OWi`020?ooo`80Ogmo0P3oool2
07moO`H0oooo00<0/k>c07moO`3dm?@00`3oool0103dm?@0Ogmo0;>c/`3oool207moO`<0oooo00D0
moOg0:FUY@1oOgl0c<c<0?ooo`0207moO`<0oooo00D0g]kN0:FUY@1oOgl0YJFU0=?Cd`050?ooo`05
0=?Cd`2UYJD0Ogmo0:FUY@3Cdm<0103oool207moO`<0oooo00<0h^;R07moO`1oOgl00`3oool01@3N
g]h0YJFU07moO`2UYJD0dm?C0=<0oooo003[0?ooo`80Ogmo103oool207moO`80oooo0P1oOgl20?oo
o`030<c<c01oOgl0c<c<0080oooo0P1oOgl20?ooo`80Ogmo0P3oool207moO`<0oooo00<0YJFU07mo
O`1oOgl00`3oool00`2m_Kd0Ogmo07moO`0307moO`030:FUY@3Rh^80oooo00H0oooo00<0YJFU07mo
O`1oOgl00`1oOgl01@3[jn/0oooo0?ooo`3oool0_Kfm00D0Ogmo00@0_Kfm0?ooo`3oool0oooo0P1o
Ogl20?ooo`030<c<c01oOgl0c<c<0080oooo0P1oOgl20?ooo`80Ogmo1P3oool00`3Hf=P0Ogmo0>;R
hP030?ooo`040>;RhP1oOgl0f=SH0?ooo`80Ogmo0`3oool00`3<c<`0Ogmo0:FUY@020?ooo`80Ogmo
0P3oool00`3Ng]h0Ogmo07moO`0307moO`050=?Cd`3oool0oooo0?ooo`2m_Kd01@1oOgl0102m_Kd0
oooo0?ooo`3oool207moO`<0oooo00<0YJFU07moO`1oOgl00P3oool00`3Ng]h0Ogmo07moO`0307mo
O`030=?Cd`3oool0oooo0=00oooo003[0?ooo`80Ogmo103oool207moO`80oooo0P1oOgl20?ooo`<0
Ogmo0P3oool207moO`80oooo0P1oOgl20?ooo`80Ogmo0P3oool0103Hf=P0Ogmo07moO`1oOgl20?oo
o`040=?Cd`1oOgl0YJFU0?3`l080oooo00<0l?3`07moO`1oOgl01P3oool0203Hf=P0Ogmo0;fm_@3g
moL0oooo0<c<c01oOgl0/k>c0P3oool02@3Ng]h0Ogmo0;fm_@3`l?00oooo0?3`l02m_Kd0Ogmo0=kN
gP020?ooo`80Ogmo0P3oool307moO`80oooo0P1oOgl20?ooo`80Ogmo1P3oool00`3dm?@0Ogmo07mo
O`0507moO`040?Cdm03oool0Ogmo07moO`80oooo00@0jn_[07moO`1oOgl0inOW0P3oool207moO`80
oooo00D0YJFU07moO`3[jn/0oooo0?Cdm00207moO`80oooo00T0g]kN07moO`2m_Kd0l?3`0?ooo`3`
l?00_Kfm07moO`3Ng]h00P3oool207moO`80oooo00@0f=SH07moO`1oOgl0Ogmo0P3oool01@2UYJD0
Ogmo0>_[j`3oool0m?Cd0080OgmodP3oool00>/0oooo0P1oOgl40?ooo`80Ogmo0P3oool207moO`07
0?ooo`3WinL0Ogmo0<G5a@1oOgl0inOW0?ooo`0207moO`80oooo0P1oOgl20?ooo`80Ogmo00@0oooo
0?Ogm`1oOgl0_Kfm0P1oOgl20?ooo`030;>c/`1oOgl0jn_[0080oooo101oOgl60?ooo`030;>c/`1o
Ogl0m?Cd0080oooo00<0moOg0<G5a@3`l?000P3oool00`2c/k<0Ogmo0>_[j`030?ooo`030>_[j`1o
Ogl0/k>c0080oooo0P1oOgl01`3oool0inOW07moO`35aLD0Ogmo0>OWi`3oool00P1oOgl20?ooo`80
Ogmo1`3oool00`2c/k<0Ogmo07moO`0307moO`030;>c/`3oool0oooo0080Ogmo00D0oooo0?Cdm02U
YJD0Ogmo0=SHf0030?ooo`80Ogmo1@3oool0103dm?@0h^;R07moO`1oOgl20?ooo`030;>c/`1oOgl0
jn_[00<0oooo00<0jn_[07moO`2c/k<00P3oool207moO`040?ooo`3gmoL0Ogmo0;fm_@80Ogmo1@3o
ool0103dm?@0h^;R07moO`1oOgoB0?ooo`00j`3oool207moO`@0oooo0P1oOgl20?ooo`80Ogmo00L0
oooo0<c<c01oOgl0moOg07moO`3<c<`0oooo0080Ogmo0P3oool207moO`80oooo0P1oOgl0103oool0
aLG507moO`3`l?0207moO`80oooo0P1oOgl30?ooo`@0Ogmo1P3oool207moO`P0oooo0P1oOgl50?oo
o`80Ogmo0P3oool207moO`070?ooo`3<c<`0Ogmo0?Ogm`1oOgl0c<c<0?ooo`0207moO`80oooo1@1o
Ogl02`3Cdm<0oooo0?ooo`3oool0f=SH07moO`3WinL0oooo0>OWi`1oOgl0f=SH0080oooo1@1oOgl0
0`2c/k<0inOW0?ooo`020?ooo`80Ogmo0`3oool00`3Hf=P0/k>c07moO`0207moO`030=SHf03oool0
oooo0080Ogmo1@3oool207moO`80oooo0P1oOgl0103oool0aLG507moO`3`l?0207moO`<0oooo00<0
f=SH0;>c/`1oOgl00P1oOgl00`3Hf=P0oooo0?ooo`3@0?ooo`00j`3oool207moO`@0oooo0P1oOgl2
0?ooo`80Ogmo00L0oooo07moO`3<c<`0oooo0<c<c01oOgl0oooo0080Ogmo0P3oool207moO`80oooo
0P1oOgl0103[jn/0Ogmo0<c<c03oool207moO`80oooo0P1oOgl=0?ooo`80Ogmo203oool207moO`D0
oooo0P1oOgl20?ooo`80Ogmo00L0oooo07moO`3<c<`0oooo0<c<c01oOgl0oooo0080Ogmo0P3oool6
07moO`0:0=?Cd`3oool0oooo0>_[j`1oOgl0c<c<0?ooo`3<c<`0Ogmo0?3`l080oooo1`1oOgl00`3N
g]h0oooo0?ooo`0207moO`80oooo00<0dm?C07moO`1oOgl00P1oOgl0103Hf=P0oooo0?ooo`3oool2
07moO`D0oooo0P1oOgl20?ooo`80Ogmo00@0jn_[07moO`3<c<`0oooo0P1oOgl20?ooo`030=?Cd`1o
Ogl0Ogmo0080Ogmo00<0f=SH0?ooo`3oool0d@3oool00>/0oooo0P1oOgl40?ooo`80Ogmo0P3oool2
07moO`070>OWi`1oOgl0inOW0?ooo`3WinL0Ogmo0>OWi`0207moO`80oooo0P1oOgl20?ooo`80Ogmo
00@0/k>c0:FUY@3gmoL0oooo0P1oOgl20?ooo`030;>c/`1oOgl0l?3`00<0oooo00<0moOg0<G5a@3`
l?001P3oool00`2m_Kd0Ogmo0?Cdm0020?ooo`030?Ogm`35aLD0l?3`0080oooo00<0/k>c07moO`3`
l?000`3oool00`3`l?00Ogmo0;>c/`020?ooo`80Ogmo00L0inOW07moO`3WinL0oooo0>OWi`1oOgl0
inOW0080Ogmo0P3oool207moO`80oooo00<0l?3`07moO`1oOgl00`3oool01@2UYJD0Ogmo0?Ogm`1o
Ogl0YJFU00<0oooo0P1oOgl30?ooo`030?3`l01oOgl0/k>c0080oooo0P1oOgl20?ooo`030:FUY@1o
Ogl0h^;R00H0oooo00<0/k>c07moO`3`l?000`3oool00`3`l?00Ogmo0;>c/`020?ooo`80Ogmo00@0
/k>c0:FUY@3gmoL0oooo0P1oOgl20?ooo`030:FUY@1oOgl0h^;R0=H0oooo003[0?ooo`80Ogmo103o
ool207moO`80oooo0P1oOgl00`35aLD0Ogmo0?ooo`020?ooo`0407moO`35aLD0Ogmo07moO`80oooo
0P1oOgl20?ooo`<0Ogmo00<0g]kN0?ooo`3oool00P1oOgl20?ooo`090=?Cd`1oOgl0YJFU0?3`l03o
ool0moOg0;fm_@1oOgl0/k>c00H0oooo00P0g]kN07moO`2m_Kd0moOg0?ooo`3<c<`0Ogmo0;>c/`80
oooo00T0g]kN07moO`2m_Kd0m?Cd0?ooo`3dm?@0_Kfm07moO`3Ng]h00P3oool207moO`030<G5a@1o
Ogl0oooo0080oooo00@0Ogmo0<G5a@1oOgl0Ogmo0P3oool207moO`80oooo00<0l?3`07moO`1oOgl0
0`3oool01@3Cdm<0Ogmo0<G5a@1oOgl0dm?C00<0oooo0P1oOgl30?ooo`030?Cdm01oOgl0Ogmo0080
oooo0P1oOgl20?ooo`80Ogmo00D0m?Cd0?ooo`3[jn/0Ogmo0:FUY@020?ooo`090=kNgP1oOgl0_Kfm
0?Cdm03oool0m?Cd0;fm_@1oOgl0g]kN0080oooo0`1oOgl00`3Ng]h0oooo0?ooo`0207moO`80oooo
0P1oOgl01@3dm?@0oooo0>_[j`1oOgl0YJFU0=80oooo003X0?ooo`P0Ogmo00<0oooo07moO`1oOgl0
0P3oool307moO`050<c<c03oool0oooo0?ooo`3<c<`00`1oOgl20?ooo`80Ogmo0P3oool207moO`04
0;>c/`3oool0oooo0?ooo`80Ogmo0`3oool00`2m_Kd0Ogmo07moO`0407moO`030>_[j`3oool0oooo
00D0oooo00<0_Kfm07moO`1oOgl00`1oOgl01@3[jn/0oooo0?ooo`3oool0_Kfm00D0Ogmo00@0_Kfm
0?ooo`3oool0oooo0`1oOgl01@3<c<`0oooo0?ooo`3oool0c<c<00<0Ogmo0P3oool607moO`050<c<
c03oool0oooo0?ooo`3[jn/00`1oOgl0103[jn/0oooo0?ooo`3oool707moO`030<c<c03oool0oooo
0080Ogmo0P3oool00`3Cdm<0Ogmo07moO`0307moO`050=SHf03oool0oooo0?ooo`2m_Kd01@1oOgl0
102m_Kd0oooo0?ooo`3oool207moO`040;>c/`3oool0oooo0?ooo`80Ogmo0P3oool00`3Cdm<0Ogmo
07moO`0307moO`030=SHf03oool0oooo0=00oooo003X0?ooo`P0Ogmo00<0oooo07moO`1oOgl00P3o
ool307moO`050>OWi`3oool0oooo0?ooo`3WinL00`1oOgl20?ooo`80Ogmo0P3oool207moO`040>OW
i`3oool0oooo0?ooo`80Ogmo103oool01P3Ng]h0/k>c07moO`1oOgl0_Kfm0>_[j`T0oooo00D0dm?C
0:FUY@1oOgl0_Kfm0>_[j`050?ooo`050=?Cd`2UYJD0Ogmo0:FUY@3Cdm<0103oool307moO`050>OW
i`3oool0oooo0?ooo`3WinL00`1oOgl20?ooo`D0Ogmo00<0c<c<0?ooo`3oool00`3oool207moO`03
0:FUY@3oool0oooo0080oooo1P1oOgl0103<c<`0oooo0?ooo`3oool207moO`<0oooo00D0dm?C0:FU
Y@1oOgl0YJFU0=SHf0050?ooo`050=?Cd`2UYJD0Ogmo0:FUY@3Cdm<0103oool207moO`040>OWi`3o
ool0oooo0?ooo`80Ogmo0`3oool01@3Cdm<0YJFU07moO`2UYJD0f=SH0=<0oooo003o0?ooool0oooo
FP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0
ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ
0?ooo`00o`3ooooo0?oooeX0oooo0000\
\>"],
  ImageRangeCache->{{{72.1875, 551.188}, {483.375, 187.75}} -> {-1.36838, \
0.175331, 0.00351219, 0.00351219}, {{83.875, 539.438}, {476.313, 194.75}} -> \
{1.43486, 35.6971, 0.0138248, 0.195663}, {{175, 311.688}, {346.938, 255.813}} -> \
{-4.40187, 1.31902, 0.0196656, 0.0221238}, {{182.313, 223}, {340.375, \
304.25}} -> {-11.2198, 1.47752, 0.0442911, 0.0442911}, {{182.313, 223}, \
{298.438, 262.313}} -> {-11.2198, -0.844299, 0.0442911, 0.0442911}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Scalability\ and\ Numerical\ Linear\ Algebra\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
The complexity of dense numerical linear algebra increases quickly \
enough so that even if computers become much faster over the next decades, \
eventually there will be a size that is impractical to compute with.  \
Fortunately, many matrices that come up in applications have special \
structure or are sparse.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " supports sparse matrices and more through SparseArray's.  They can be \
read in from standard file formats or specified via a pattern based syntax."
}], "Text"],

Cell["\<\
Define S to be a sparse matrix with -2 on the diagonal, 1 on the \
sub- and super-diagonals and 0 everywhere else.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\  = \ 25;\)\), "\[IndentingNewLine]", 
    \(S\  = \ 
      SparseArray[{{i_, \ i_} \[Rule] \(-2. \), \ {i_, \ j_}\  /; \ 
              Abs[i\  - \ j]\  \[Equal] \ 1 \[Rule] 1. }, {n, n}]\)}], "Input",\

  CellLabel->"In[70]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          InterpretationBox[\("<"\[InvisibleSpace]73\[InvisibleSpace]">"\),
            SequenceForm[ "<", 73, ">"],
            Editable->False], ",", \({25, 25}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell["Show S formatted as an ordinary matrix.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[S]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), 
              "1.`", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), "1.`", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "1.`", \(-2.`\), 
              "1.`"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "1.`", \(-2.`\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ 
          SparseArray[ 
          Automatic, {25, 25}, 0, {1, {{0, 2, 5, 8, 11, 14, 17, 20, 23, 26, 
            29, 32, 35, 38, 41, 44, 47, 50, 53, 56, 59, 62, 65, 68, 71, 
            73}, {{1}, {2}, {1}, {3}, {2}, {3}, {2}, {4}, {3}, {5}, {4}, {
            5}, {4}, {6}, {5}, {7}, {6}, {7}, {6}, {8}, {7}, {9}, {8}, {10}, {
            9}, {8}, {9}, {11}, {10}, {12}, {11}, {10}, {12}, {11}, {13}, {
            14}, {13}, {12}, {14}, {13}, {15}, {16}, {15}, {14}, {16}, {15}, {
            17}, {18}, {17}, {16}, {18}, {17}, {19}, {18}, {20}, {19}, {20}, {
            19}, {21}, {20}, {22}, {21}, {22}, {21}, {23}, {22}, {24}, {23}, {
            24}, {23}, {25}, {24}, {25}}}, {-2.0, 1.0, 1.0, 1.0, -2.0, -2.0, 
            1.0, 1.0, 1.0, 1.0, -2.0, -2.0, 1.0, 1.0, 1.0, 1.0, -2.0, -2.0, 
            1.0, 1.0, 1.0, 1.0, -2.0, 1.0, -2.0, 1.0, 1.0, 1.0, -2.0, 
            1.0, -2.0, 1.0, -2.0, 1.0, 1.0, 1.0, -2.0, 1.0, -2.0, 1.0, 1.0, 
            1.0, -2.0, 1.0, -2.0, 1.0, 1.0, 1.0, -2.0, 1.0, -2.0, 1.0, 1.0, 
            1.0, 1.0, -2.0, -2.0, 1.0, 1.0, 1.0, 1.0, -2.0, -2.0, 1.0, 1.0, 
            1.0, 1.0, -2.0, -2.0, 1.0, 1.0, 1.0, -2.0}}]]]]], "Output",
  CellLabel->"Out[72]//MatrixForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Scalability\ and\ Numerical\ Linear\ Algebra\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
It is possible to explore a simple eigenfunction computation using \
this.\
\>", "Text"],

Cell["Define a potential function p.", "MathCaption"],

Cell[BoxData[
    \(\(p[x_]\  := \ If[x\  < \  .5, \ 1, \ 0];\)\)], "Input",
  CellLabel->"In[73]:="],

Cell["\<\
Consider the boundary value problem\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], " ", "+", \(\(p(x)\)\ y\)}], " ", 
          "\[LongEqual]", \(\(-\[Lambda]\)\ y\)}], 
        ";", \(y(0) \[LongEqual] y(1) \[LongEqual] 0\)}], 
      TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "The matrix S is effectively the discretization of the differential \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`y''\)]],
  " on a grid with spacing ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(n + 1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Compute a (diagonal) matrix representing the discretization of the \
potential on a uniform grid with ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " points on [0,1]"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(P\  = \ 
      SparseArray[{{i_, i_} \[RuleDelayed] \ p[i/\((n + 1)\)]}, {n, 
          n}]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          InterpretationBox[\("<"\[InvisibleSpace]25\[InvisibleSpace]">"\),
            SequenceForm[ "<", 25, ">"],
            Editable->False], ",", \({25, 25}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[74]="]
}, Open  ]],

Cell["\<\
It is easy to find the eigenvalues; the corresponding eigenvectors \
are approximations to the eigenfunctions.\
\>", "Text"],

Cell[TextData[{
  "Compute the eigenvalues of the matrix that approximates the differential \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`\((D\^2 + \ p(x))\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[S\ \((n + 1)\)^2\  + \ P]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \({\(-2693.687200934925`\), \(-2664.2086517076013`\), \
\(-2615.681106588135`\), \(-2548.6354136700943`\), \(-2464.21288271628`\), \
\(-2363.486061426931`\), \(-2248.0804039844775`\), \(-2119.523306264494`\), \
\(-1979.8442441397033`\), \(-1830.9256957975049`\), \(-1675.0932623250187`\), \
\(-1514.4655586818567`\), \(-1351.538460652989`\), \(-1188.5344431223352`\), \
\(-1027.9836588747328`\), \(-872.0743062361992`\), \(-723.2326766858736`\), \
\(-583.4766963605833`\), \(-454.9965159611361`\), \(-339.5139426163444`\), \
\(-238.86403501001934`\), \(-154.3645945621577`\), \(-87.3958035720932`\), \
\(-38.79137932435696`\), \(-9.389698784156884`\)}\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell["\<\
Compute the eigenvector corresponding to the last eigenvalue, \
-9.3897.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v\  = \ Last[Eigenvectors[S\ \((n + 1)\)^2\  + \ P]]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({0.03430941602688111`, 0.06809151770763851`, 0.10082709518907869`, 
      0.132013023042862`, 0.16116999298983867`, 0.18784988056964208`, 
      0.21164263253441826`, 0.23218256911174087`, 0.24915400427485837`, 
      0.26229609764022094`, 0.27140686342164605`, 0.2763462748259947`, 
      0.27703841617773106`, 0.2738824698378274`, 0.266922272175382`, 
      0.2562545009411769`, 0.24202733240531185`, 0.2244383831759277`, 
      0.20373196528733473`, 0.180195692684611`, 0.15415648624089467`, 
      0.12597603279802738`, 0.09604576130486932`, 0.06478140583516132`, 
      0.03261723100508883`}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell["\<\
Make a plot of the difference in the computed eigenfunction with \
the sine function.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(grid\  = \ 
        Table[i/\((1. \  + \ n)\), \ {i, \ n}];\)\), "\[IndentingNewLine]", 
    \(\(sine\  = \ Sin[\[Pi]\ grid];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[
        Transpose[{grid, \ 
            sine\  - \ v\ Norm[sine]\ Sign[Max[v]]}]];\)\)}], "Input",
  CellLabel->"In[77]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.990476 0.315548 20.6366 [
[.2219 .30305 -9 -9 ]
[.2219 .30305 9 0 ]
[.42 .30305 -9 -9 ]
[.42 .30305 9 0 ]
[.6181 .30305 -9 -9 ]
[.6181 .30305 9 0 ]
[.81619 .30305 -9 -9 ]
[.81619 .30305 9 0 ]
[.01131 .006 -36 -4.5 ]
[.01131 .006 0 4.5 ]
[.01131 .10918 -30 -4.5 ]
[.01131 .10918 0 4.5 ]
[.01131 .21236 -36 -4.5 ]
[.01131 .21236 0 4.5 ]
[.01131 .41873 -30 -4.5 ]
[.01131 .41873 0 4.5 ]
[.01131 .52191 -24 -4.5 ]
[.01131 .52191 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2219 .31555 m
.2219 .3218 L
s
[(0.2)] .2219 .30305 0 1 Mshowa
.42 .31555 m
.42 .3218 L
s
[(0.4)] .42 .30305 0 1 Mshowa
.6181 .31555 m
.6181 .3218 L
s
[(0.6)] .6181 .30305 0 1 Mshowa
.81619 .31555 m
.81619 .3218 L
s
[(0.8)] .81619 .30305 0 1 Mshowa
.125 Mabswid
.07333 .31555 m
.07333 .3193 L
s
.12286 .31555 m
.12286 .3193 L
s
.17238 .31555 m
.17238 .3193 L
s
.27143 .31555 m
.27143 .3193 L
s
.32095 .31555 m
.32095 .3193 L
s
.37048 .31555 m
.37048 .3193 L
s
.46952 .31555 m
.46952 .3193 L
s
.51905 .31555 m
.51905 .3193 L
s
.56857 .31555 m
.56857 .3193 L
s
.66762 .31555 m
.66762 .3193 L
s
.71714 .31555 m
.71714 .3193 L
s
.76667 .31555 m
.76667 .3193 L
s
.86571 .31555 m
.86571 .3193 L
s
.91524 .31555 m
.91524 .3193 L
s
.96476 .31555 m
.96476 .3193 L
s
.25 Mabswid
0 .31555 m
1 .31555 L
s
.02381 .006 m
.03006 .006 L
s
[(-0.015)] .01131 .006 1 0 Mshowa
.02381 .10918 m
.03006 .10918 L
s
[(-0.01)] .01131 .10918 1 0 Mshowa
.02381 .21236 m
.03006 .21236 L
s
[(-0.005)] .01131 .21236 1 0 Mshowa
.02381 .41873 m
.03006 .41873 L
s
[(0.005)] .01131 .41873 1 0 Mshowa
.02381 .52191 m
.03006 .52191 L
s
[(0.01)] .01131 .52191 1 0 Mshowa
.125 Mabswid
.02381 .02664 m
.02756 .02664 L
s
.02381 .04727 m
.02756 .04727 L
s
.02381 .06791 m
.02756 .06791 L
s
.02381 .08854 m
.02756 .08854 L
s
.02381 .12982 m
.02756 .12982 L
s
.02381 .15045 m
.02756 .15045 L
s
.02381 .17109 m
.02756 .17109 L
s
.02381 .19173 m
.02756 .19173 L
s
.02381 .233 m
.02756 .233 L
s
.02381 .25364 m
.02756 .25364 L
s
.02381 .27427 m
.02756 .27427 L
s
.02381 .29491 m
.02756 .29491 L
s
.02381 .33618 m
.02756 .33618 L
s
.02381 .35682 m
.02756 .35682 L
s
.02381 .37746 m
.02756 .37746 L
s
.02381 .39809 m
.02756 .39809 L
s
.02381 .43937 m
.02756 .43937 L
s
.02381 .46 m
.02756 .46 L
s
.02381 .48064 m
.02756 .48064 L
s
.02381 .50128 m
.02756 .50128 L
s
.02381 .54255 m
.02756 .54255 L
s
.02381 .56319 m
.02756 .56319 L
s
.02381 .58382 m
.02756 .58382 L
s
.02381 .60446 m
.02756 .60446 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.0619 .25018 Mdot
.1 .18777 Mdot
.1381 .13121 Mdot
.17619 .08325 Mdot
.21429 .04641 Mdot
.25238 .02293 Mdot
.29048 .01472 Mdot
.32857 .02329 Mdot
.36667 .04972 Mdot
.40476 .09462 Mdot
.44286 .1581 Mdot
.48095 .23977 Mdot
.51905 .33874 Mdot
.55714 .4231 Mdot
.59524 .49178 Mdot
.63333 .54415 Mdot
.67143 .57999 Mdot
.70952 .5995 Mdot
.74762 .60332 Mdot
.78571 .59245 Mdot
.82381 .56826 Mdot
.8619 .53244 Mdot
.9 .48698 Mdot
.9381 .43406 Mdot
.97619 .37609 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000040?ooo`8000000`3oool500000080oooo0P0000050?oo
o`030000003oool0oooo0?H0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3f0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000
m`3oool000030?ooo`0000000000008000000P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`2c0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0/`3oool000P0oooo0P00000:0?ooo`80
0000103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`2Y0?ooo`009`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0Z@3oool002L0oooo0P00003g0?ooo`009`3oool0
0`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000
oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0<H0oooo
000W0?ooo`800000;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0:00oooo000W
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0X03oool002L0oooo00<000000?oo
o`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0
mP3oool002L0oooo0P00003g0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`00
0000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0=00oooo000W0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0d03oool002L0oooo0P00003g0?ooo`009`3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo09H0oooo000W0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool0UP3oool000h0oooo0P0000040?ooo`800000103oool2000000<0oooo1@0000030?ooo`030000
003oool0oooo0?H0oooo000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo000=0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`800000m`3oool000L0oooo100000020?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo000=0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?H0oooo000>0?ooo`8000002P3oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo0?H0oooo000W0?ooo`030000003oool0oooo0?H0oooo000W0?ooo`80
00006P3oool00`000000oooo0?ooo`3J0?ooo`009`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0=X0oooo000W0?ooo`030000003oool0oooo0?H0oooo000W0?ooo`030000003oool0
oooo0?H0oooo000W0?ooo`030000003oool0oooo0?H0oooo000W0?ooo`800000m`3oool002L0oooo
00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`2<0?ooo`009`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo08`0oooo000W0?oo
o`030000003oool0oooo0?H0oooo000W0?ooo`030000003oool0oooo0?H0oooo000W0?ooo`800000
m`3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool0
02L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3S0?ooo`009`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0><0oooo000W0?ooo`800000m`3oool002L0oooo00<0
00000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool000P0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3f0?oo
o`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?H0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo0P00003g0?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo0?ooo`3f0?ooo`001`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?H0oooo00080?ooo`800000
2P3oool2000000@0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`3f0?ooo`009`3o
ool00`000000oooo0?ooo`3f0?ooo`009`3oool200000?L0oooo000W0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0P`3oool002L0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`230?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0>d0oooo000W0?ooo`8000001`3oool00`000000oooo0?ooo`3]
0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`00
9`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool0
0`000000oooo0?ooo`0X0?ooo`800000103oool2000000<0oooo1000000S0?ooo`800000103oool2
000000D0oooo0`00000S0?ooo`800000103oool2000000<0oooo0`00000T0?ooo`800000103oool2
000000@0oooo0P00000Y0?ooo`009`3oool2000002P0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool08@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000280oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000X0?ooo`009`3oool00`000000oooo0?ooo`0W0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`00
00080?ooo`D000008P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000280
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000X0?ooo`009`3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool08@3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002<0oooo00@000000?ooo`3oool0
0000203oool3000002<0oooo00@000000?ooo`3oool000002@3oool2000002T0oooo000W0?ooo`03
0000003oool0oooo02L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000R
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`0000008`3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000X0?ooo`009`3oool00`000000oooo0?ooo`0X0?ooo`8000002P3oool2000002@0
oooo0P00000;0?ooo`800000903oool2000000X0oooo0`00000S0?ooo`8000002P3oool2000002T0
oooo000W0?ooo`800000m`3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<00000
0?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3o
ool0mP3oool00240ooooo`00000002L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`070?ooo`009`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02d0oooo000W0?oo
o`030000003oool0oooo0?H0oooo000W0?ooo`030000003oool0oooo0?H0oooo000W0?ooo`800000
m`3oool002L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`1i0?ooo`009`3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo07T0oooo000W0?ooo`030000003oool0oooo
0?H0oooo000W0?ooo`030000003oool0oooo0?H0oooo000W0?ooo`030000003oool0oooo0?H0oooo
000W0?ooo`800000m`3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?oo
o`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0
kP3oool00`000000oooo0?ooo`050?ooo`009`3oool200000>l0oooo00<000000?ooo`3oool01@3o
ool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0
oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo0P00
003g0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?oo
o`00203oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0?H0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0mP3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool200000?L0
oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo06l0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`1_0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103o
ool3000000@0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0i03oool0
0`000000oooo0?ooo`0?0?ooo`009`3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo
00l0oooo000W0?ooo`800000m`3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<0
00000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?oo
o`3oool0mP3oool002L0oooo0P00003g0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3o
ool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`00
0000oooo0?ooo`3f0?ooo`009`3oool200000?L0oooo000W0?ooo`030000003oool0oooo0=/0oooo
00<000000?ooo`3oool0603oool002L0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo01P0oooo000W0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0IP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo0P00003g0?ooo`00
9`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool0
0`000000oooo0?ooo`3f0?ooo`003P3oool2000000@0oooo0P0000040?ooo`8000000`3oool50000
00<0oooo00<000000?ooo`3oool0mP3oool000d0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3oool0
00d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo0P00003g0?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3f0?ooo`003@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0280oooo000>0?ooo`800000
2P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0
8P3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo0P00002H0?ooo`030000003oool0
oooo05`0oooo000W0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0G03oool002L0
oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<0
00000?ooo`3oool0mP3oool002L0oooo0P00003g0?ooo`009`3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo02`0oooo000W0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool0;03oool002L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`1B0?ooo`009`3oool200000:80oooo00<000000?ooo`3oool0DP3oool0
02L0oooo00<000000?ooo`3oool0mP3oool002L0oooo00<000000?ooo`3oool0_P3oool00`000000
oooo0?ooo`0e0?ooo`009`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo03D0oooo
000W0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0B@3oool002L0oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03l0oooo000W0?oo
o`800000]@3oool00`000000oooo0?ooo`0o0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`00
9`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.155794, -0.0174873, \
0.00397692, 0.000190877}}]
}, Open  ]],

Cell[TextData[{
  "It appears from the plot that the root of the difference between the sine \
function is shifted from .5.  It is easy to find this using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s FindRoot function."
}], "Text"],

Cell["\<\
Find the root of the difference between the approximate \
eigenfunction and the sine function.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[\(Interpolation[Transpose[{grid, sine\  - \ v\ Norm[sine]}]]\)[
        x], {x,  .4,  .6}]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \({x \[Rule] 0.49093560106708906`}\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Scalability\ and\ Numerical\ Linear\ Algebra\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
Sparse linear algebra makes it possible to scale the problem up to \
much larger size.\
\>", "Text"],

Cell["Redefine S  and P for a much larger computation size.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\  = \ 10^5;\)\), "\[IndentingNewLine]", 
    \(S\  = \ 
      SparseArray[{{i_, \ i_} \[Rule] \(-2. \), \ {i_, \ j_}\  /; \ 
              Abs[i\  - \ j]\  \[Equal] \ 1 \[Rule] 1. }, {n, n}]\)}], "Input",\

  CellLabel->"In[54]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          
          InterpretationBox[\("<"\[InvisibleSpace]299998\[InvisibleSpace]">"\)\
,
            SequenceForm[ "<", 299998, ">"],
            Editable->False], ",", \({100000, 100000}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(P\  = \ 
      SparseArray[{{i_, i_} \[RuleDelayed] \ p[i/\((n + 1)\)]}, {n, 
          n}]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          
          InterpretationBox[\("<"\[InvisibleSpace]100000\[InvisibleSpace]">"\)\
,
            SequenceForm[ "<", 100000, ">"],
            Editable->False], ",", \({100000, 100000}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell["\<\
Use an iterative method to compute the eigenvalue of the \
approximation to the differential operator closest to -9.39.\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[S\ \((n + 1)\)^2\  + \ P, \ 1, \ 
      Method \[Rule] {Arnoldi, \ Shift \[Rule] \(-9.39\)}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({\(-9.36327293358818`\)}\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["\<\
Use an iterative method to compute the eigenvector of the \
approximation to the differential operator closest to -9.39 and plot its \
difference from the sine function.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v\  = \ 
        First[Eigenvectors[S\ \((n + 1)\)^2\  + \ P, \ 1, \ 
            Method \[Rule] {Arnoldi, \ 
                Shift \[Rule] \(-9.39\)}]];\)\), "\[IndentingNewLine]", 
    \(\(grid\  = \ 
        Table[i/\((1. \  + \ n)\), \ {i, \ n}];\)\), "\[IndentingNewLine]", 
    \(\(sine\  = \ Sin[\[Pi]\ grid];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[
        Transpose[{grid, \ 
            sine\  - \ v\ Norm[sine]\ Sign[Max[v]]}]];\)\)}], "Input",
  CellLabel->"In[58]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.95239 0.307907 20.7127 [
[.21429 .29541 -9 -9 ]
[.21429 .29541 9 0 ]
[.40477 .29541 -9 -9 ]
[.40477 .29541 9 0 ]
[.59524 .29541 -9 -9 ]
[.59524 .29541 9 0 ]
[.78572 .29541 -9 -9 ]
[.78572 .29541 9 0 ]
[.9762 .29541 -3 -9 ]
[.9762 .29541 3 0 ]
[.01131 .10078 -30 -4.5 ]
[.01131 .10078 0 4.5 ]
[.01131 .20434 -36 -4.5 ]
[.01131 .20434 0 4.5 ]
[.01131 .41147 -30 -4.5 ]
[.01131 .41147 0 4.5 ]
[.01131 .51503 -24 -4.5 ]
[.01131 .51503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30791 m
.21429 .31416 L
s
[(0.2)] .21429 .29541 0 1 Mshowa
.40477 .30791 m
.40477 .31416 L
s
[(0.4)] .40477 .29541 0 1 Mshowa
.59524 .30791 m
.59524 .31416 L
s
[(0.6)] .59524 .29541 0 1 Mshowa
.78572 .30791 m
.78572 .31416 L
s
[(0.8)] .78572 .29541 0 1 Mshowa
.9762 .30791 m
.9762 .31416 L
s
[(1)] .9762 .29541 0 1 Mshowa
.125 Mabswid
.07143 .30791 m
.07143 .31166 L
s
.11905 .30791 m
.11905 .31166 L
s
.16667 .30791 m
.16667 .31166 L
s
.26191 .30791 m
.26191 .31166 L
s
.30953 .30791 m
.30953 .31166 L
s
.35715 .30791 m
.35715 .31166 L
s
.45239 .30791 m
.45239 .31166 L
s
.5 .30791 m
.5 .31166 L
s
.54762 .30791 m
.54762 .31166 L
s
.64286 .30791 m
.64286 .31166 L
s
.69048 .30791 m
.69048 .31166 L
s
.7381 .30791 m
.7381 .31166 L
s
.83334 .30791 m
.83334 .31166 L
s
.88096 .30791 m
.88096 .31166 L
s
.92858 .30791 m
.92858 .31166 L
s
.25 Mabswid
0 .30791 m
1 .30791 L
s
.02381 .10078 m
.03006 .10078 L
s
[(-0.01)] .01131 .10078 1 0 Mshowa
.02381 .20434 m
.03006 .20434 L
s
[(-0.005)] .01131 .20434 1 0 Mshowa
.02381 .41147 m
.03006 .41147 L
s
[(0.005)] .01131 .41147 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(0.01)] .01131 .51503 1 0 Mshowa
.125 Mabswid
.02381 .01793 m
.02756 .01793 L
s
.02381 .03864 m
.02756 .03864 L
s
.02381 .05935 m
.02756 .05935 L
s
.02381 .08007 m
.02756 .08007 L
s
.02381 .12149 m
.02756 .12149 L
s
.02381 .14221 m
.02756 .14221 L
s
.02381 .16292 m
.02756 .16292 L
s
.02381 .18363 m
.02756 .18363 L
s
.02381 .22506 m
.02756 .22506 L
s
.02381 .24577 m
.02756 .24577 L
s
.02381 .26648 m
.02756 .26648 L
s
.02381 .28719 m
.02756 .28719 L
s
.02381 .32862 m
.02756 .32862 L
s
.02381 .34933 m
.02756 .34933 L
s
.02381 .37004 m
.02756 .37004 L
s
.02381 .39076 m
.02756 .39076 L
s
.02381 .43218 m
.02756 .43218 L
s
.02381 .4529 m
.02756 .4529 L
s
.02381 .47361 m
.02756 .47361 L
s
.02381 .49432 m
.02756 .49432 L
s
.02381 .53575 m
.02756 .53575 L
s
.02381 .55646 m
.02756 .55646 L
s
.02381 .57717 m
.02756 .57717 L
s
.02381 .59788 m
.02756 .59788 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02382 .30789 Mdot
.02383 .30787 Mdot
.02384 .30786 Mdot
.02385 .30784 Mdot
.02386 .30782 Mdot
.02387 .30781 Mdot
.02388 .30779 Mdot
.02389 .30777 Mdot
.0239 .30776 Mdot
.0239 .30774 Mdot
.02391 .30773 Mdot
.02392 .30771 Mdot
.02393 .30769 Mdot
.02394 .30768 Mdot
.02395 .30766 Mdot
.02396 .30764 Mdot
.02397 .30763 Mdot
.02398 .30761 Mdot
.02399 .30759 Mdot
.024 .30758 Mdot
.02401 .30756 Mdot
.02402 .30754 Mdot
.02403 .30753 Mdot
.02404 .30751 Mdot
.02405 .30749 Mdot
.02406 .30748 Mdot
.02407 .30746 Mdot
.02408 .30745 Mdot
.02409 .30743 Mdot
.0241 .30741 Mdot
.0241 .3074 Mdot
.02411 .30738 Mdot
.02412 .30736 Mdot
.02413 .30735 Mdot
.02414 .30733 Mdot
.02415 .30731 Mdot
.02416 .3073 Mdot
.02417 .30728 Mdot
.02418 .30726 Mdot
.02419 .30725 Mdot
.0242 .30723 Mdot
.02421 .30721 Mdot
.02422 .3072 Mdot
.02423 .30718 Mdot
.02424 .30717 Mdot
.02425 .30715 Mdot
.02426 .30713 Mdot
.02427 .30712 Mdot
.02428 .3071 Mdot
.02429 .30708 Mdot
.0243 .30707 Mdot
.0243 .30705 Mdot
.02431 .30703 Mdot
.02432 .30702 Mdot
.02433 .307 Mdot
.02434 .30698 Mdot
.02435 .30697 Mdot
.02436 .30695 Mdot
.02437 .30693 Mdot
.02438 .30692 Mdot
.02439 .3069 Mdot
.0244 .30689 Mdot
.02441 .30687 Mdot
.02442 .30685 Mdot
.02443 .30684 Mdot
.02444 .30682 Mdot
.02445 .3068 Mdot
.02446 .30679 Mdot
.02447 .30677 Mdot
.02448 .30675 Mdot
.02449 .30674 Mdot
.0245 .30672 Mdot
.0245 .3067 Mdot
.02451 .30669 Mdot
.02452 .30667 Mdot
.02453 .30665 Mdot
.02454 .30664 Mdot
.02455 .30662 Mdot
.02456 .30661 Mdot
.02457 .30659 Mdot
.02458 .30657 Mdot
.02459 .30656 Mdot
.0246 .30654 Mdot
.02461 .30652 Mdot
.02462 .30651 Mdot
.02463 .30649 Mdot
.02464 .30647 Mdot
.02465 .30646 Mdot
.02466 .30644 Mdot
.02467 .30642 Mdot
.02468 .30641 Mdot
.02469 .30639 Mdot
.0247 .30637 Mdot
.0247 .30636 Mdot
.02471 .30634 Mdot
.02472 .30632 Mdot
.02473 .30631 Mdot
.02474 .30629 Mdot
.02475 .30628 Mdot
.02476 .30626 Mdot
.02477 .30624 Mdot
.02478 .30623 Mdot
.02479 .30621 Mdot
.0248 .30619 Mdot
.02481 .30618 Mdot
.02482 .30616 Mdot
.02483 .30614 Mdot
.02484 .30613 Mdot
.02485 .30611 Mdot
.02486 .30609 Mdot
.02487 .30608 Mdot
.02488 .30606 Mdot
.02489 .30604 Mdot
.0249 .30603 Mdot
.0249 .30601 Mdot
.02491 .306 Mdot
.02492 .30598 Mdot
.02493 .30596 Mdot
.02494 .30595 Mdot
.02495 .30593 Mdot
.02496 .30591 Mdot
.02497 .3059 Mdot
.02498 .30588 Mdot
.02499 .30586 Mdot
.025 .30585 Mdot
.02501 .30583 Mdot
.02502 .30581 Mdot
.02503 .3058 Mdot
.02504 .30578 Mdot
.02505 .30576 Mdot
.02506 .30575 Mdot
.02507 .30573 Mdot
.02508 .30572 Mdot
.02509 .3057 Mdot
.0251 .30568 Mdot
.0251 .30567 Mdot
.02511 .30565 Mdot
.02512 .30563 Mdot
.02513 .30562 Mdot
.02514 .3056 Mdot
.02515 .30558 Mdot
.02516 .30557 Mdot
.02517 .30555 Mdot
.02518 .30553 Mdot
.02519 .30552 Mdot
.0252 .3055 Mdot
.02521 .30548 Mdot
.02522 .30547 Mdot
.02523 .30545 Mdot
.02524 .30544 Mdot
.02525 .30542 Mdot
.02526 .3054 Mdot
.02527 .30539 Mdot
.02528 .30537 Mdot
.02529 .30535 Mdot
.0253 .30534 Mdot
.0253 .30532 Mdot
.02531 .3053 Mdot
.02532 .30529 Mdot
.02533 .30527 Mdot
.02534 .30525 Mdot
.02535 .30524 Mdot
.02536 .30522 Mdot
.02537 .3052 Mdot
.02538 .30519 Mdot
.02539 .30517 Mdot
.0254 .30516 Mdot
.02541 .30514 Mdot
.02542 .30512 Mdot
.02543 .30511 Mdot
.02544 .30509 Mdot
.02545 .30507 Mdot
.02546 .30506 Mdot
.02547 .30504 Mdot
.02548 .30502 Mdot
.02549 .30501 Mdot
.0255 .30499 Mdot
.0255 .30497 Mdot
.02551 .30496 Mdot
.02552 .30494 Mdot
.02553 .30492 Mdot
.02554 .30491 Mdot
.02555 .30489 Mdot
.02556 .30488 Mdot
.02557 .30486 Mdot
.02558 .30484 Mdot
.02559 .30483 Mdot
.0256 .30481 Mdot
.02561 .30479 Mdot
.02562 .30478 Mdot
.02563 .30476 Mdot
.02564 .30474 Mdot
.02565 .30473 Mdot
.02566 .30471 Mdot
.02567 .30469 Mdot
.02568 .30468 Mdot
.02569 .30466 Mdot
.0257 .30464 Mdot
.0257 .30463 Mdot
.02571 .30461 Mdot
.02572 .30459 Mdot
.02573 .30458 Mdot
.02574 .30456 Mdot
.02575 .30455 Mdot
.02576 .30453 Mdot
.02577 .30451 Mdot
.02578 .3045 Mdot
.02579 .30448 Mdot
.0258 .30446 Mdot
.02581 .30445 Mdot
.02582 .30443 Mdot
.02583 .30441 Mdot
.02584 .3044 Mdot
.02585 .30438 Mdot
.02586 .30436 Mdot
.02587 .30435 Mdot
.02588 .30433 Mdot
.02589 .30431 Mdot
.0259 .3043 Mdot
.0259 .30428 Mdot
.02591 .30427 Mdot
.02592 .30425 Mdot
.02593 .30423 Mdot
.02594 .30422 Mdot
.02595 .3042 Mdot
.02596 .30418 Mdot
.02597 .30417 Mdot
.02598 .30415 Mdot
.02599 .30413 Mdot
.026 .30412 Mdot
.02601 .3041 Mdot
.02602 .30408 Mdot
.02603 .30407 Mdot
.02604 .30405 Mdot
.02605 .30403 Mdot
.02606 .30402 Mdot
.02607 .304 Mdot
.02608 .30399 Mdot
.02609 .30397 Mdot
.0261 .30395 Mdot
.0261 .30394 Mdot
.02611 .30392 Mdot
.02612 .3039 Mdot
.02613 .30389 Mdot
.02614 .30387 Mdot
.02615 .30385 Mdot
.02616 .30384 Mdot
.02617 .30382 Mdot
.02618 .3038 Mdot
.02619 .30379 Mdot
.0262 .30377 Mdot
.02621 .30375 Mdot
.02622 .30374 Mdot
.02623 .30372 Mdot
.02624 .30371 Mdot
.02625 .30369 Mdot
.02626 .30367 Mdot
.02627 .30366 Mdot
.02628 .30364 Mdot
.02629 .30362 Mdot
.0263 .30361 Mdot
.0263 .30359 Mdot
.02631 .30357 Mdot
.02632 .30356 Mdot
.02633 .30354 Mdot
.02634 .30352 Mdot
.02635 .30351 Mdot
.02636 .30349 Mdot
.02637 .30347 Mdot
.02638 .30346 Mdot
.02639 .30344 Mdot
.0264 .30343 Mdot
.02641 .30341 Mdot
.02642 .30339 Mdot
.02643 .30338 Mdot
.02644 .30336 Mdot
.02645 .30334 Mdot
.02646 .30333 Mdot
.02647 .30331 Mdot
.02648 .30329 Mdot
.02649 .30328 Mdot
.0265 .30326 Mdot
.0265 .30324 Mdot
.02651 .30323 Mdot
.02652 .30321 Mdot
.02653 .30319 Mdot
.02654 .30318 Mdot
.02655 .30316 Mdot
.02656 .30315 Mdot
.02657 .30313 Mdot
.02658 .30311 Mdot
.02659 .3031 Mdot
.0266 .30308 Mdot
.02661 .30306 Mdot
.02662 .30305 Mdot
.02663 .30303 Mdot
.02664 .30301 Mdot
.02665 .303 Mdot
.02666 .30298 Mdot
.02667 .30296 Mdot
.02668 .30295 Mdot
.02669 .30293 Mdot
.0267 .30291 Mdot
.0267 .3029 Mdot
.02671 .30288 Mdot
.02672 .30286 Mdot
.02673 .30285 Mdot
.02674 .30283 Mdot
.02675 .30282 Mdot
.02676 .3028 Mdot
.02677 .30278 Mdot
.02678 .30277 Mdot
.02679 .30275 Mdot
.0268 .30273 Mdot
.02681 .30272 Mdot
.02682 .3027 Mdot
.02683 .30268 Mdot
.02684 .30267 Mdot
.02685 .30265 Mdot
.02686 .30263 Mdot
.02687 .30262 Mdot
.02688 .3026 Mdot
.02689 .30258 Mdot
.0269 .30257 Mdot
.0269 .30255 Mdot
.02691 .30254 Mdot
.02692 .30252 Mdot
.02693 .3025 Mdot
.02694 .30249 Mdot
.02695 .30247 Mdot
.02696 .30245 Mdot
.02697 .30244 Mdot
.02698 .30242 Mdot
.02699 .3024 Mdot
.027 .30239 Mdot
.02701 .30237 Mdot
.02702 .30235 Mdot
.02703 .30234 Mdot
.02704 .30232 Mdot
.02705 .3023 Mdot
.02706 .30229 Mdot
.02707 .30227 Mdot
.02708 .30226 Mdot
.02709 .30224 Mdot
.0271 .30222 Mdot
.0271 .30221 Mdot
.02711 .30219 Mdot
.02712 .30217 Mdot
.02713 .30216 Mdot
.02714 .30214 Mdot
.02715 .30212 Mdot
.02716 .30211 Mdot
.02717 .30209 Mdot
.02718 .30207 Mdot
.02719 .30206 Mdot
.0272 .30204 Mdot
.02721 .30202 Mdot
.02722 .30201 Mdot
.02723 .30199 Mdot
.02724 .30198 Mdot
.02725 .30196 Mdot
.02726 .30194 Mdot
.02727 .30193 Mdot
.02728 .30191 Mdot
.02729 .30189 Mdot
.0273 .30188 Mdot
.0273 .30186 Mdot
.02731 .30184 Mdot
.02732 .30183 Mdot
.02733 .30181 Mdot
.02734 .30179 Mdot
.02735 .30178 Mdot
.02736 .30176 Mdot
.02737 .30174 Mdot
.02738 .30173 Mdot
.02739 .30171 Mdot
.0274 .3017 Mdot
.02741 .30168 Mdot
.02742 .30166 Mdot
.02743 .30165 Mdot
.02744 .30163 Mdot
.02745 .30161 Mdot
.02746 .3016 Mdot
.02747 .30158 Mdot
.02748 .30156 Mdot
.02749 .30155 Mdot
.0275 .30153 Mdot
.0275 .30151 Mdot
.02751 .3015 Mdot
.02752 .30148 Mdot
.02753 .30146 Mdot
.02754 .30145 Mdot
.02755 .30143 Mdot
.02756 .30142 Mdot
.02757 .3014 Mdot
.02758 .30138 Mdot
.02759 .30137 Mdot
.0276 .30135 Mdot
.02761 .30133 Mdot
.02762 .30132 Mdot
.02763 .3013 Mdot
.02764 .30128 Mdot
.02765 .30127 Mdot
.02766 .30125 Mdot
.02767 .30123 Mdot
.02768 .30122 Mdot
.02769 .3012 Mdot
.0277 .30118 Mdot
.0277 .30117 Mdot
.02771 .30115 Mdot
.02772 .30114 Mdot
.02773 .30112 Mdot
.02774 .3011 Mdot
.02775 .30109 Mdot
.02776 .30107 Mdot
.02777 .30105 Mdot
.02778 .30104 Mdot
.02779 .30102 Mdot
.0278 .301 Mdot
.02781 .30099 Mdot
.02782 .30097 Mdot
.02783 .30095 Mdot
.02784 .30094 Mdot
.02785 .30092 Mdot
.02786 .3009 Mdot
.02787 .30089 Mdot
.02788 .30087 Mdot
.02789 .30086 Mdot
.0279 .30084 Mdot
.0279 .30082 Mdot
.02791 .30081 Mdot
.02792 .30079 Mdot
.02793 .30077 Mdot
.02794 .30076 Mdot
.02795 .30074 Mdot
.02796 .30072 Mdot
.02797 .30071 Mdot
.02798 .30069 Mdot
.02799 .30067 Mdot
.028 .30066 Mdot
.02801 .30064 Mdot
.02802 .30062 Mdot
.02803 .30061 Mdot
.02804 .30059 Mdot
.02805 .30058 Mdot
.02806 .30056 Mdot
.02807 .30054 Mdot
.02808 .30053 Mdot
.02809 .30051 Mdot
.0281 .30049 Mdot
.0281 .30048 Mdot
.02811 .30046 Mdot
.02812 .30044 Mdot
.02813 .30043 Mdot
.02814 .30041 Mdot
.02815 .30039 Mdot
.02816 .30038 Mdot
.02817 .30036 Mdot
.02818 .30034 Mdot
.02819 .30033 Mdot
.0282 .30031 Mdot
.02821 .3003 Mdot
.02822 .30028 Mdot
.02823 .30026 Mdot
.02824 .30025 Mdot
.02825 .30023 Mdot
.02826 .30021 Mdot
.02827 .3002 Mdot
.02828 .30018 Mdot
.02829 .30016 Mdot
.0283 .30015 Mdot
.0283 .30013 Mdot
.02831 .30011 Mdot
.02832 .3001 Mdot
.02833 .30008 Mdot
.02834 .30006 Mdot
.02835 .30005 Mdot
.02836 .30003 Mdot
.02837 .30001 Mdot
.02838 .3 Mdot
.02839 .29998 Mdot
.0284 .29997 Mdot
.02841 .29995 Mdot
.02842 .29993 Mdot
.02843 .29992 Mdot
.02844 .2999 Mdot
.02845 .29988 Mdot
.02846 .29987 Mdot
.02847 .29985 Mdot
.02848 .29983 Mdot
.02849 .29982 Mdot
.0285 .2998 Mdot
.0285 .29978 Mdot
.02851 .29977 Mdot
.02852 .29975 Mdot
.02853 .29973 Mdot
.02854 .29972 Mdot
.02855 .2997 Mdot
.02856 .29969 Mdot
.02857 .29967 Mdot
.02858 .29965 Mdot
.02859 .29964 Mdot
.0286 .29962 Mdot
.02861 .2996 Mdot
.02862 .29959 Mdot
.02863 .29957 Mdot
.02864 .29955 Mdot
.02865 .29954 Mdot
.02866 .29952 Mdot
.02867 .2995 Mdot
.02868 .29949 Mdot
.02869 .29947 Mdot
.0287 .29945 Mdot
.0287 .29944 Mdot
.02871 .29942 Mdot
.02872 .29941 Mdot
.02873 .29939 Mdot
.02874 .29937 Mdot
.02875 .29936 Mdot
.02876 .29934 Mdot
.02877 .29932 Mdot
.02878 .29931 Mdot
.02879 .29929 Mdot
.0288 .29927 Mdot
.02881 .29926 Mdot
.02882 .29924 Mdot
.02883 .29922 Mdot
.02884 .29921 Mdot
.02885 .29919 Mdot
.02886 .29917 Mdot
.02887 .29916 Mdot
.02888 .29914 Mdot
.02889 .29913 Mdot
.0289 .29911 Mdot
.0289 .29909 Mdot
.02891 .29908 Mdot
.02892 .29906 Mdot
.02893 .29904 Mdot
.02894 .29903 Mdot
.02895 .29901 Mdot
.02896 .29899 Mdot
.02897 .29898 Mdot
.02898 .29896 Mdot
.02899 .29894 Mdot
.029 .29893 Mdot
.02901 .29891 Mdot
.02902 .29889 Mdot
.02903 .29888 Mdot
.02904 .29886 Mdot
.02905 .29885 Mdot
.02906 .29883 Mdot
.02907 .29881 Mdot
.02908 .2988 Mdot
.02909 .29878 Mdot
.0291 .29876 Mdot
.0291 .29875 Mdot
.02911 .29873 Mdot
.02912 .29871 Mdot
.02913 .2987 Mdot
.02914 .29868 Mdot
.02915 .29866 Mdot
.02916 .29865 Mdot
.02917 .29863 Mdot
.02918 .29861 Mdot
.02919 .2986 Mdot
.0292 .29858 Mdot
.02921 .29857 Mdot
.02922 .29855 Mdot
.02923 .29853 Mdot
.02924 .29852 Mdot
.02925 .2985 Mdot
.02926 .29848 Mdot
.02927 .29847 Mdot
.02928 .29845 Mdot
.02929 .29843 Mdot
.0293 .29842 Mdot
.0293 .2984 Mdot
.02931 .29838 Mdot
.02932 .29837 Mdot
.02933 .29835 Mdot
.02934 .29833 Mdot
.02935 .29832 Mdot
.02936 .2983 Mdot
.02937 .29829 Mdot
.02938 .29827 Mdot
.02939 .29825 Mdot
.0294 .29824 Mdot
.02941 .29822 Mdot
.02942 .2982 Mdot
.02943 .29819 Mdot
.02944 .29817 Mdot
.02945 .29815 Mdot
.02946 .29814 Mdot
.02947 .29812 Mdot
.02948 .2981 Mdot
.02949 .29809 Mdot
.0295 .29807 Mdot
.0295 .29806 Mdot
.02951 .29804 Mdot
.02952 .29802 Mdot
.02953 .29801 Mdot
.02954 .29799 Mdot
.02955 .29797 Mdot
.02956 .29796 Mdot
.02957 .29794 Mdot
.02958 .29792 Mdot
.02959 .29791 Mdot
.0296 .29789 Mdot
.02961 .29787 Mdot
.02962 .29786 Mdot
.02963 .29784 Mdot
.02964 .29782 Mdot
.02965 .29781 Mdot
.02966 .29779 Mdot
.02967 .29778 Mdot
.02968 .29776 Mdot
.02969 .29774 Mdot
.0297 .29773 Mdot
.0297 .29771 Mdot
.02971 .29769 Mdot
.02972 .29768 Mdot
.02973 .29766 Mdot
.02974 .29764 Mdot
.02975 .29763 Mdot
.02976 .29761 Mdot
.02977 .29759 Mdot
.02978 .29758 Mdot
.02979 .29756 Mdot
.0298 .29754 Mdot
.02981 .29753 Mdot
.02982 .29751 Mdot
.02983 .2975 Mdot
.02984 .29748 Mdot
.02985 .29746 Mdot
.02986 .29745 Mdot
.02987 .29743 Mdot
.02988 .29741 Mdot
.02989 .2974 Mdot
.0299 .29738 Mdot
.0299 .29736 Mdot
.02991 .29735 Mdot
.02992 .29733 Mdot
.02993 .29731 Mdot
.02994 .2973 Mdot
.02995 .29728 Mdot
.02996 .29726 Mdot
.02997 .29725 Mdot
.02998 .29723 Mdot
.02999 .29722 Mdot
.03 .2972 Mdot
.03001 .29718 Mdot
.03002 .29717 Mdot
.03003 .29715 Mdot
.03004 .29713 Mdot
.03005 .29712 Mdot
.03006 .2971 Mdot
.03007 .29708 Mdot
.03008 .29707 Mdot
.03009 .29705 Mdot
.0301 .29703 Mdot
.0301 .29702 Mdot
.03011 .297 Mdot
.03012 .29698 Mdot
.03013 .29697 Mdot
.03014 .29695 Mdot
.03015 .29694 Mdot
.03016 .29692 Mdot
.03017 .2969 Mdot
.03018 .29689 Mdot
.03019 .29687 Mdot
.0302 .29685 Mdot
.03021 .29684 Mdot
.03022 .29682 Mdot
.03023 .2968 Mdot
.03024 .29679 Mdot
.03025 .29677 Mdot
.03026 .29675 Mdot
.03027 .29674 Mdot
.03028 .29672 Mdot
.03029 .2967 Mdot
.0303 .29669 Mdot
.0303 .29667 Mdot
.03031 .29666 Mdot
.03032 .29664 Mdot
.03033 .29662 Mdot
.03034 .29661 Mdot
.03035 .29659 Mdot
.03036 .29657 Mdot
.03037 .29656 Mdot
.03038 .29654 Mdot
.03039 .29652 Mdot
.0304 .29651 Mdot
.03041 .29649 Mdot
.03042 .29647 Mdot
.03043 .29646 Mdot
.03044 .29644 Mdot
.03045 .29642 Mdot
.03046 .29641 Mdot
.03047 .29639 Mdot
.03048 .29638 Mdot
.03049 .29636 Mdot
.0305 .29634 Mdot
.0305 .29633 Mdot
.03051 .29631 Mdot
.03052 .29629 Mdot
.03053 .29628 Mdot
.03054 .29626 Mdot
.03055 .29624 Mdot
.03056 .29623 Mdot
.03057 .29621 Mdot
.03058 .29619 Mdot
.03059 .29618 Mdot
.0306 .29616 Mdot
.03061 .29614 Mdot
.03062 .29613 Mdot
.03063 .29611 Mdot
.03064 .2961 Mdot
.03065 .29608 Mdot
.03066 .29606 Mdot
.03067 .29605 Mdot
.03068 .29603 Mdot
.03069 .29601 Mdot
.0307 .296 Mdot
.0307 .29598 Mdot
.03071 .29596 Mdot
.03072 .29595 Mdot
.03073 .29593 Mdot
.03074 .29591 Mdot
.03075 .2959 Mdot
.03076 .29588 Mdot
.03077 .29586 Mdot
.03078 .29585 Mdot
.03079 .29583 Mdot
.0308 .29582 Mdot
.03081 .2958 Mdot
.03082 .29578 Mdot
.03083 .29577 Mdot
.03084 .29575 Mdot
.03085 .29573 Mdot
.03086 .29572 Mdot
.03087 .2957 Mdot
.03088 .29568 Mdot
.03089 .29567 Mdot
.0309 .29565 Mdot
.0309 .29563 Mdot
.03091 .29562 Mdot
.03092 .2956 Mdot
.03093 .29559 Mdot
.03094 .29557 Mdot
.03095 .29555 Mdot
.03096 .29554 Mdot
.03097 .29552 Mdot
.03098 .2955 Mdot
.03099 .29549 Mdot
.031 .29547 Mdot
.03101 .29545 Mdot
.03102 .29544 Mdot
.03103 .29542 Mdot
.03104 .2954 Mdot
.03105 .29539 Mdot
.03106 .29537 Mdot
.03107 .29535 Mdot
.03108 .29534 Mdot
.03109 .29532 Mdot
.0311 .29531 Mdot
.0311 .29529 Mdot
.03111 .29527 Mdot
.03112 .29526 Mdot
.03113 .29524 Mdot
.03114 .29522 Mdot
.03115 .29521 Mdot
.03116 .29519 Mdot
.03117 .29517 Mdot
.03118 .29516 Mdot
.03119 .29514 Mdot
.0312 .29512 Mdot
.03121 .29511 Mdot
.03122 .29509 Mdot
.03123 .29507 Mdot
.03124 .29506 Mdot
.03125 .29504 Mdot
.03126 .29503 Mdot
.03127 .29501 Mdot
.03128 .29499 Mdot
.03129 .29498 Mdot
.0313 .29496 Mdot
.0313 .29494 Mdot
.03131 .29493 Mdot
.03132 .29491 Mdot
.03133 .29489 Mdot
.03134 .29488 Mdot
.03135 .29486 Mdot
.03136 .29484 Mdot
.03137 .29483 Mdot
.03138 .29481 Mdot
.03139 .29479 Mdot
.0314 .29478 Mdot
.03141 .29476 Mdot
.03142 .29475 Mdot
.03143 .29473 Mdot
.03144 .29471 Mdot
.03145 .2947 Mdot
.03146 .29468 Mdot
.03147 .29466 Mdot
.03148 .29465 Mdot
.03149 .29463 Mdot
.0315 .29461 Mdot
.0315 .2946 Mdot
.03151 .29458 Mdot
.03152 .29456 Mdot
.03153 .29455 Mdot
.03154 .29453 Mdot
.03155 .29452 Mdot
.03156 .2945 Mdot
.03157 .29448 Mdot
.03158 .29447 Mdot
.03159 .29445 Mdot
.0316 .29443 Mdot
.03161 .29442 Mdot
.03162 .2944 Mdot
.03163 .29438 Mdot
.03164 .29437 Mdot
.03165 .29435 Mdot
.03166 .29433 Mdot
.03167 .29432 Mdot
.03168 .2943 Mdot
.03169 .29428 Mdot
.0317 .29427 Mdot
.0317 .29425 Mdot
.03171 .29424 Mdot
.03172 .29422 Mdot
.03173 .2942 Mdot
.03174 .29419 Mdot
.03175 .29417 Mdot
.03176 .29415 Mdot
.03177 .29414 Mdot
.03178 .29412 Mdot
.03179 .2941 Mdot
.0318 .29409 Mdot
.03181 .29407 Mdot
.03182 .29405 Mdot
.03183 .29404 Mdot
.03184 .29402 Mdot
.03185 .294 Mdot
.03186 .29399 Mdot
.03187 .29397 Mdot
.03188 .29396 Mdot
.03189 .29394 Mdot
.0319 .29392 Mdot
.0319 .29391 Mdot
.03191 .29389 Mdot
.03192 .29387 Mdot
.03193 .29386 Mdot
.03194 .29384 Mdot
.03195 .29382 Mdot
.03196 .29381 Mdot
.03197 .29379 Mdot
.03198 .29377 Mdot
.03199 .29376 Mdot
.032 .29374 Mdot
.03201 .29372 Mdot
.03202 .29371 Mdot
.03203 .29369 Mdot
.03204 .29368 Mdot
.03205 .29366 Mdot
.03206 .29364 Mdot
.03207 .29363 Mdot
.03208 .29361 Mdot
.03209 .29359 Mdot
.0321 .29358 Mdot
.0321 .29356 Mdot
.03211 .29354 Mdot
.03212 .29353 Mdot
.03213 .29351 Mdot
.03214 .29349 Mdot
.03215 .29348 Mdot
.03216 .29346 Mdot
.03217 .29345 Mdot
.03218 .29343 Mdot
.03219 .29341 Mdot
.0322 .2934 Mdot
.03221 .29338 Mdot
.03222 .29336 Mdot
.03223 .29335 Mdot
.03224 .29333 Mdot
.03225 .29331 Mdot
.03226 .2933 Mdot
.03227 .29328 Mdot
.03228 .29326 Mdot
.03229 .29325 Mdot
.0323 .29323 Mdot
.0323 .29321 Mdot
.03231 .2932 Mdot
.03232 .29318 Mdot
.03233 .29317 Mdot
.03234 .29315 Mdot
.03235 .29313 Mdot
.03236 .29312 Mdot
.03237 .2931 Mdot
.03238 .29308 Mdot
.03239 .29307 Mdot
.0324 .29305 Mdot
.03241 .29303 Mdot
.03242 .29302 Mdot
.03243 .293 Mdot
.03244 .29298 Mdot
.03245 .29297 Mdot
.03246 .29295 Mdot
.03247 .29293 Mdot
.03248 .29292 Mdot
.03249 .2929 Mdot
.0325 .29289 Mdot
.0325 .29287 Mdot
.03251 .29285 Mdot
.03252 .29284 Mdot
.03253 .29282 Mdot
.03254 .2928 Mdot
.03255 .29279 Mdot
.03256 .29277 Mdot
.03257 .29275 Mdot
.03258 .29274 Mdot
.03259 .29272 Mdot
.0326 .2927 Mdot
.03261 .29269 Mdot
.03262 .29267 Mdot
.03263 .29266 Mdot
.03264 .29264 Mdot
.03265 .29262 Mdot
.03266 .29261 Mdot
.03267 .29259 Mdot
.03268 .29257 Mdot
.03269 .29256 Mdot
.0327 .29254 Mdot
.0327 .29252 Mdot
.03271 .29251 Mdot
.03272 .29249 Mdot
.03273 .29247 Mdot
.03274 .29246 Mdot
.03275 .29244 Mdot
.03276 .29242 Mdot
.03277 .29241 Mdot
.03278 .29239 Mdot
.03279 .29238 Mdot
.0328 .29236 Mdot
.03281 .29234 Mdot
.03282 .29233 Mdot
.03283 .29231 Mdot
.03284 .29229 Mdot
.03285 .29228 Mdot
.03286 .29226 Mdot
.03287 .29224 Mdot
.03288 .29223 Mdot
.03289 .29221 Mdot
.0329 .29219 Mdot
.0329 .29218 Mdot
.03291 .29216 Mdot
.03292 .29215 Mdot
.03293 .29213 Mdot
.03294 .29211 Mdot
.03295 .2921 Mdot
.03296 .29208 Mdot
.03297 .29206 Mdot
.03298 .29205 Mdot
.03299 .29203 Mdot
.033 .29201 Mdot
.03301 .292 Mdot
.03302 .29198 Mdot
.03303 .29196 Mdot
.03304 .29195 Mdot
.03305 .29193 Mdot
.03306 .29191 Mdot
.03307 .2919 Mdot
.03308 .29188 Mdot
.03309 .29187 Mdot
.0331 .29185 Mdot
.0331 .29183 Mdot
.03311 .29182 Mdot
.03312 .2918 Mdot
.03313 .29178 Mdot
.03314 .29177 Mdot
.03315 .29175 Mdot
.03316 .29173 Mdot
.03317 .29172 Mdot
.03318 .2917 Mdot
.03319 .29168 Mdot
.0332 .29167 Mdot
.03321 .29165 Mdot
.03322 .29163 Mdot
.03323 .29162 Mdot
.03324 .2916 Mdot
.03325 .29159 Mdot
.03326 .29157 Mdot
.03327 .29155 Mdot
.03328 .29154 Mdot
.03329 .29152 Mdot
.0333 .2915 Mdot
.0333 .29149 Mdot
.03331 .29147 Mdot
.03332 .29145 Mdot
.03333 .29144 Mdot
.03334 .29142 Mdot
.03335 .2914 Mdot
.03336 .29139 Mdot
.03337 .29137 Mdot
.03338 .29136 Mdot
.03339 .29134 Mdot
.0334 .29132 Mdot
.03341 .29131 Mdot
.03342 .29129 Mdot
.03343 .29127 Mdot
.03344 .29126 Mdot
.03345 .29124 Mdot
.03346 .29122 Mdot
.03347 .29121 Mdot
.03348 .29119 Mdot
.03349 .29117 Mdot
.0335 .29116 Mdot
.0335 .29114 Mdot
.03351 .29112 Mdot
.03352 .29111 Mdot
.03353 .29109 Mdot
.03354 .29108 Mdot
.03355 .29106 Mdot
.03356 .29104 Mdot
.03357 .29103 Mdot
.03358 .29101 Mdot
.03359 .29099 Mdot
.0336 .29098 Mdot
.03361 .29096 Mdot
.03362 .29094 Mdot
.03363 .29093 Mdot
.03364 .29091 Mdot
.03365 .29089 Mdot
.03366 .29088 Mdot
.03367 .29086 Mdot
.03368 .29085 Mdot
.03369 .29083 Mdot
.0337 .29081 Mdot
.0337 .2908 Mdot
.03371 .29078 Mdot
.03372 .29076 Mdot
.03373 .29075 Mdot
.03374 .29073 Mdot
.03375 .29071 Mdot
.03376 .2907 Mdot
.03377 .29068 Mdot
.03378 .29066 Mdot
.03379 .29065 Mdot
.0338 .29063 Mdot
.03381 .29061 Mdot
.03382 .2906 Mdot
.03383 .29058 Mdot
.03384 .29057 Mdot
.03385 .29055 Mdot
.03386 .29053 Mdot
.03387 .29052 Mdot
.03388 .2905 Mdot
.03389 .29048 Mdot
.0339 .29047 Mdot
.0339 .29045 Mdot
.03391 .29043 Mdot
.03392 .29042 Mdot
.03393 .2904 Mdot
.03394 .29038 Mdot
.03395 .29037 Mdot
.03396 .29035 Mdot
.03397 .29034 Mdot
.03398 .29032 Mdot
.03399 .2903 Mdot
.034 .29029 Mdot
.03401 .29027 Mdot
.03402 .29025 Mdot
.03403 .29024 Mdot
.03404 .29022 Mdot
.03405 .2902 Mdot
.03406 .29019 Mdot
.03407 .29017 Mdot
.03408 .29015 Mdot
.03409 .29014 Mdot
.0341 .29012 Mdot
.0341 .2901 Mdot
.03411 .29009 Mdot
.03412 .29007 Mdot
.03413 .29006 Mdot
.03414 .29004 Mdot
.03415 .29002 Mdot
.03416 .29001 Mdot
.03417 .28999 Mdot
.03418 .28997 Mdot
.03419 .28996 Mdot
.0342 .28994 Mdot
.03421 .28992 Mdot
.03422 .28991 Mdot
.03423 .28989 Mdot
.03424 .28987 Mdot
.03425 .28986 Mdot
.03426 .28984 Mdot
.03427 .28983 Mdot
.03428 .28981 Mdot
.03429 .28979 Mdot
.0343 .28978 Mdot
.0343 .28976 Mdot
.03431 .28974 Mdot
.03432 .28973 Mdot
.03433 .28971 Mdot
.03434 .28969 Mdot
.03435 .28968 Mdot
.03436 .28966 Mdot
.03437 .28964 Mdot
.03438 .28963 Mdot
.03439 .28961 Mdot
.0344 .2896 Mdot
.03441 .28958 Mdot
.03442 .28956 Mdot
.03443 .28955 Mdot
.03444 .28953 Mdot
.03445 .28951 Mdot
.03446 .2895 Mdot
.03447 .28948 Mdot
.03448 .28946 Mdot
.03449 .28945 Mdot
.0345 .28943 Mdot
.0345 .28941 Mdot
.03451 .2894 Mdot
.03452 .28938 Mdot
.03453 .28936 Mdot
.03454 .28935 Mdot
.03455 .28933 Mdot
.03456 .28932 Mdot
.03457 .2893 Mdot
.03458 .28928 Mdot
.03459 .28927 Mdot
.0346 .28925 Mdot
.03461 .28923 Mdot
.03462 .28922 Mdot
.03463 .2892 Mdot
.03464 .28918 Mdot
.03465 .28917 Mdot
.03466 .28915 Mdot
.03467 .28913 Mdot
.03468 .28912 Mdot
.03469 .2891 Mdot
.0347 .28909 Mdot
.0347 .28907 Mdot
.03471 .28905 Mdot
.03472 .28904 Mdot
.03473 .28902 Mdot
.03474 .289 Mdot
.03475 .28899 Mdot
.03476 .28897 Mdot
.03477 .28895 Mdot
.03478 .28894 Mdot
.03479 .28892 Mdot
.0348 .2889 Mdot
.03481 .28889 Mdot
.03482 .28887 Mdot
.03483 .28886 Mdot
.03484 .28884 Mdot
.03485 .28882 Mdot
.03486 .28881 Mdot
.03487 .28879 Mdot
.03488 .28877 Mdot
.03489 .28876 Mdot
.0349 .28874 Mdot
.0349 .28872 Mdot
.03491 .28871 Mdot
.03492 .28869 Mdot
.03493 .28867 Mdot
.03494 .28866 Mdot
.03495 .28864 Mdot
.03496 .28862 Mdot
.03497 .28861 Mdot
.03498 .28859 Mdot
.03499 .28858 Mdot
.035 .28856 Mdot
.03501 .28854 Mdot
.03502 .28853 Mdot
.03503 .28851 Mdot
.03504 .28849 Mdot
.03505 .28848 Mdot
.03506 .28846 Mdot
.03507 .28844 Mdot
.03508 .28843 Mdot
.03509 .28841 Mdot
.0351 .28839 Mdot
.0351 .28838 Mdot
.03511 .28836 Mdot
.03512 .28835 Mdot
.03513 .28833 Mdot
.03514 .28831 Mdot
.03515 .2883 Mdot
.03516 .28828 Mdot
.03517 .28826 Mdot
.03518 .28825 Mdot
.03519 .28823 Mdot
.0352 .28821 Mdot
.03521 .2882 Mdot
.03522 .28818 Mdot
.03523 .28816 Mdot
.03524 .28815 Mdot
.03525 .28813 Mdot
.03526 .28812 Mdot
.03527 .2881 Mdot
.03528 .28808 Mdot
.03529 .28807 Mdot
.0353 .28805 Mdot
.0353 .28803 Mdot
.03531 .28802 Mdot
.03532 .288 Mdot
.03533 .28798 Mdot
.03534 .28797 Mdot
.03535 .28795 Mdot
.03536 .28793 Mdot
.03537 .28792 Mdot
.03538 .2879 Mdot
.03539 .28788 Mdot
.0354 .28787 Mdot
.03541 .28785 Mdot
.03542 .28784 Mdot
.03543 .28782 Mdot
.03544 .2878 Mdot
.03545 .28779 Mdot
.03546 .28777 Mdot
.03547 .28775 Mdot
.03548 .28774 Mdot
.03549 .28772 Mdot
.0355 .2877 Mdot
.0355 .28769 Mdot
.03551 .28767 Mdot
.03552 .28765 Mdot
.03553 .28764 Mdot
.03554 .28762 Mdot
.03555 .28761 Mdot
.03556 .28759 Mdot
.03557 .28757 Mdot
.03558 .28756 Mdot
.03559 .28754 Mdot
.0356 .28752 Mdot
.03561 .28751 Mdot
.03562 .28749 Mdot
.03563 .28747 Mdot
.03564 .28746 Mdot
.03565 .28744 Mdot
.03566 .28742 Mdot
.03567 .28741 Mdot
.03568 .28739 Mdot
.03569 .28738 Mdot
.0357 .28736 Mdot
.0357 .28734 Mdot
.03571 .28733 Mdot
.03572 .28731 Mdot
.03573 .28729 Mdot
.03574 .28728 Mdot
.03575 .28726 Mdot
.03576 .28724 Mdot
.03577 .28723 Mdot
.03578 .28721 Mdot
.03579 .28719 Mdot
.0358 .28718 Mdot
.03581 .28716 Mdot
.03582 .28715 Mdot
.03583 .28713 Mdot
.03584 .28711 Mdot
.03585 .2871 Mdot
.03586 .28708 Mdot
.03587 .28706 Mdot
.03588 .28705 Mdot
.03589 .28703 Mdot
.0359 .28701 Mdot
.0359 .287 Mdot
.03591 .28698 Mdot
.03592 .28696 Mdot
.03593 .28695 Mdot
.03594 .28693 Mdot
.03595 .28691 Mdot
.03596 .2869 Mdot
.03597 .28688 Mdot
.03598 .28687 Mdot
.03599 .28685 Mdot
.036 .28683 Mdot
.03601 .28682 Mdot
.03602 .2868 Mdot
.03603 .28678 Mdot
.03604 .28677 Mdot
.03605 .28675 Mdot
.03606 .28673 Mdot
.03607 .28672 Mdot
.03608 .2867 Mdot
.03609 .28668 Mdot
.0361 .28667 Mdot
.0361 .28665 Mdot
.03611 .28664 Mdot
.03612 .28662 Mdot
.03613 .2866 Mdot
.03614 .28659 Mdot
.03615 .28657 Mdot
.03616 .28655 Mdot
.03617 .28654 Mdot
.03618 .28652 Mdot
.03619 .2865 Mdot
.0362 .28649 Mdot
.03621 .28647 Mdot
.03622 .28645 Mdot
.03623 .28644 Mdot
.03624 .28642 Mdot
.03625 .28641 Mdot
.03626 .28639 Mdot
.03627 .28637 Mdot
.03628 .28636 Mdot
.03629 .28634 Mdot
.0363 .28632 Mdot
.0363 .28631 Mdot
.03631 .28629 Mdot
.03632 .28627 Mdot
.03633 .28626 Mdot
.03634 .28624 Mdot
.03635 .28622 Mdot
.03636 .28621 Mdot
.03637 .28619 Mdot
.03638 .28618 Mdot
.03639 .28616 Mdot
.0364 .28614 Mdot
.03641 .28613 Mdot
.03642 .28611 Mdot
.03643 .28609 Mdot
.03644 .28608 Mdot
.03645 .28606 Mdot
.03646 .28604 Mdot
.03647 .28603 Mdot
.03648 .28601 Mdot
.03649 .28599 Mdot
.0365 .28598 Mdot
.0365 .28596 Mdot
.03651 .28595 Mdot
.03652 .28593 Mdot
.03653 .28591 Mdot
.03654 .2859 Mdot
.03655 .28588 Mdot
.03656 .28586 Mdot
.03657 .28585 Mdot
.03658 .28583 Mdot
.03659 .28581 Mdot
.0366 .2858 Mdot
.03661 .28578 Mdot
.03662 .28576 Mdot
.03663 .28575 Mdot
.03664 .28573 Mdot
.03665 .28572 Mdot
.03666 .2857 Mdot
.03667 .28568 Mdot
.03668 .28567 Mdot
.03669 .28565 Mdot
.0367 .28563 Mdot
.0367 .28562 Mdot
.03671 .2856 Mdot
.03672 .28558 Mdot
.03673 .28557 Mdot
.03674 .28555 Mdot
.03675 .28553 Mdot
.03676 .28552 Mdot
.03677 .2855 Mdot
.03678 .28549 Mdot
.03679 .28547 Mdot
.0368 .28545 Mdot
.03681 .28544 Mdot
.03682 .28542 Mdot
.03683 .2854 Mdot
.03684 .28539 Mdot
.03685 .28537 Mdot
.03686 .28535 Mdot
.03687 .28534 Mdot
.03688 .28532 Mdot
.03689 .2853 Mdot
.0369 .28529 Mdot
.0369 .28527 Mdot
.03691 .28526 Mdot
.03692 .28524 Mdot
.03693 .28522 Mdot
.03694 .28521 Mdot
.03695 .28519 Mdot
.03696 .28517 Mdot
.03697 .28516 Mdot
.03698 .28514 Mdot
.03699 .28512 Mdot
.037 .28511 Mdot
.03701 .28509 Mdot
.03702 .28507 Mdot
.03703 .28506 Mdot
.03704 .28504 Mdot
.03705 .28503 Mdot
.03706 .28501 Mdot
.03707 .28499 Mdot
.03708 .28498 Mdot
.03709 .28496 Mdot
.0371 .28494 Mdot
.0371 .28493 Mdot
.03711 .28491 Mdot
.03712 .28489 Mdot
.03713 .28488 Mdot
.03714 .28486 Mdot
.03715 .28484 Mdot
.03716 .28483 Mdot
.03717 .28481 Mdot
.03718 .2848 Mdot
.03719 .28478 Mdot
.0372 .28476 Mdot
.03721 .28475 Mdot
.03722 .28473 Mdot
.03723 .28471 Mdot
.03724 .2847 Mdot
.03725 .28468 Mdot
.03726 .28466 Mdot
.03727 .28465 Mdot
.03728 .28463 Mdot
.03729 .28461 Mdot
.0373 .2846 Mdot
.0373 .28458 Mdot
.03731 .28457 Mdot
.03732 .28455 Mdot
.03733 .28453 Mdot
.03734 .28452 Mdot
.03735 .2845 Mdot
.03736 .28448 Mdot
.03737 .28447 Mdot
.03738 .28445 Mdot
.03739 .28443 Mdot
.0374 .28442 Mdot
.03741 .2844 Mdot
.03742 .28438 Mdot
.03743 .28437 Mdot
.03744 .28435 Mdot
.03745 .28434 Mdot
.03746 .28432 Mdot
.03747 .2843 Mdot
.03748 .28429 Mdot
.03749 .28427 Mdot
.0375 .28425 Mdot
.0375 .28424 Mdot
.03751 .28422 Mdot
.03752 .2842 Mdot
.03753 .28419 Mdot
.03754 .28417 Mdot
.03755 .28415 Mdot
.03756 .28414 Mdot
.03757 .28412 Mdot
.03758 .28411 Mdot
.03759 .28409 Mdot
.0376 .28407 Mdot
.03761 .28406 Mdot
.03762 .28404 Mdot
.03763 .28402 Mdot
.03764 .28401 Mdot
.03765 .28399 Mdot
.03766 .28397 Mdot
.03767 .28396 Mdot
.03768 .28394 Mdot
.03769 .28392 Mdot
.0377 .28391 Mdot
.0377 .28389 Mdot
.03771 .28388 Mdot
.03772 .28386 Mdot
.03773 .28384 Mdot
.03774 .28383 Mdot
.03775 .28381 Mdot
.03776 .28379 Mdot
.03777 .28378 Mdot
.03778 .28376 Mdot
.03779 .28374 Mdot
.0378 .28373 Mdot
.03781 .28371 Mdot
.03782 .28369 Mdot
.03783 .28368 Mdot
.03784 .28366 Mdot
.03785 .28365 Mdot
.03786 .28363 Mdot
.03787 .28361 Mdot
.03788 .2836 Mdot
.03789 .28358 Mdot
.0379 .28356 Mdot
.0379 .28355 Mdot
.03791 .28353 Mdot
.03792 .28351 Mdot
.03793 .2835 Mdot
.03794 .28348 Mdot
.03795 .28346 Mdot
.03796 .28345 Mdot
.03797 .28343 Mdot
.03798 .28342 Mdot
.03799 .2834 Mdot
.038 .28338 Mdot
.03801 .28337 Mdot
.03802 .28335 Mdot
.03803 .28333 Mdot
.03804 .28332 Mdot
.03805 .2833 Mdot
.03806 .28328 Mdot
.03807 .28327 Mdot
.03808 .28325 Mdot
.03809 .28323 Mdot
.0381 .28322 Mdot
.0381 .2832 Mdot
.03811 .28319 Mdot
.03812 .28317 Mdot
.03813 .28315 Mdot
.03814 .28314 Mdot
.03815 .28312 Mdot
.03816 .2831 Mdot
.03817 .28309 Mdot
.03818 .28307 Mdot
.03819 .28305 Mdot
.0382 .28304 Mdot
.03821 .28302 Mdot
.03822 .283 Mdot
.03823 .28299 Mdot
.03824 .28297 Mdot
.03825 .28296 Mdot
.03826 .28294 Mdot
.03827 .28292 Mdot
.03828 .28291 Mdot
.03829 .28289 Mdot
.0383 .28287 Mdot
.0383 .28286 Mdot
.03831 .28284 Mdot
.03832 .28282 Mdot
.03833 .28281 Mdot
.03834 .28279 Mdot
.03835 .28277 Mdot
.03836 .28276 Mdot
.03837 .28274 Mdot
.03838 .28273 Mdot
.03839 .28271 Mdot
.0384 .28269 Mdot
.03841 .28268 Mdot
.03842 .28266 Mdot
.03843 .28264 Mdot
.03844 .28263 Mdot
.03845 .28261 Mdot
.03846 .28259 Mdot
.03847 .28258 Mdot
.03848 .28256 Mdot
.03849 .28254 Mdot
.0385 .28253 Mdot
.0385 .28251 Mdot
.03851 .2825 Mdot
.03852 .28248 Mdot
.03853 .28246 Mdot
.03854 .28245 Mdot
.03855 .28243 Mdot
.03856 .28241 Mdot
.03857 .2824 Mdot
.03858 .28238 Mdot
.03859 .28236 Mdot
.0386 .28235 Mdot
.03861 .28233 Mdot
.03862 .28232 Mdot
.03863 .2823 Mdot
.03864 .28228 Mdot
.03865 .28227 Mdot
.03866 .28225 Mdot
.03867 .28223 Mdot
.03868 .28222 Mdot
.03869 .2822 Mdot
.0387 .28218 Mdot
.0387 .28217 Mdot
.03871 .28215 Mdot
.03872 .28213 Mdot
.03873 .28212 Mdot
.03874 .2821 Mdot
.03875 .28209 Mdot
.03876 .28207 Mdot
.03877 .28205 Mdot
.03878 .28204 Mdot
.03879 .28202 Mdot
.0388 .282 Mdot
.03881 .28199 Mdot
.03882 .28197 Mdot
.03883 .28195 Mdot
.03884 .28194 Mdot
.03885 .28192 Mdot
.03886 .2819 Mdot
.03887 .28189 Mdot
.03888 .28187 Mdot
.03889 .28186 Mdot
.0389 .28184 Mdot
.0389 .28182 Mdot
.03891 .28181 Mdot
.03892 .28179 Mdot
.03893 .28177 Mdot
.03894 .28176 Mdot
.03895 .28174 Mdot
.03896 .28172 Mdot
.03897 .28171 Mdot
.03898 .28169 Mdot
.03899 .28167 Mdot
.039 .28166 Mdot
.03901 .28164 Mdot
.03902 .28163 Mdot
.03903 .28161 Mdot
.03904 .28159 Mdot
.03905 .28158 Mdot
.03906 .28156 Mdot
.03907 .28154 Mdot
.03908 .28153 Mdot
.03909 .28151 Mdot
.0391 .28149 Mdot
.0391 .28148 Mdot
.03911 .28146 Mdot
.03912 .28145 Mdot
.03913 .28143 Mdot
.03914 .28141 Mdot
.03915 .2814 Mdot
.03916 .28138 Mdot
.03917 .28136 Mdot
.03918 .28135 Mdot
.03919 .28133 Mdot
.0392 .28131 Mdot
.03921 .2813 Mdot
.03922 .28128 Mdot
.03923 .28126 Mdot
.03924 .28125 Mdot
.03925 .28123 Mdot
.03926 .28122 Mdot
.03927 .2812 Mdot
.03928 .28118 Mdot
.03929 .28117 Mdot
.0393 .28115 Mdot
.0393 .28113 Mdot
.03931 .28112 Mdot
.03932 .2811 Mdot
.03933 .28108 Mdot
.03934 .28107 Mdot
.03935 .28105 Mdot
.03936 .28103 Mdot
.03937 .28102 Mdot
.03938 .281 Mdot
.03939 .28099 Mdot
.0394 .28097 Mdot
.03941 .28095 Mdot
.03942 .28094 Mdot
.03943 .28092 Mdot
.03944 .2809 Mdot
.03945 .28089 Mdot
.03946 .28087 Mdot
.03947 .28085 Mdot
.03948 .28084 Mdot
.03949 .28082 Mdot
.0395 .2808 Mdot
.0395 .28079 Mdot
.03951 .28077 Mdot
.03952 .28076 Mdot
.03953 .28074 Mdot
.03954 .28072 Mdot
.03955 .28071 Mdot
.03956 .28069 Mdot
.03957 .28067 Mdot
.03958 .28066 Mdot
.03959 .28064 Mdot
.0396 .28062 Mdot
.03961 .28061 Mdot
.03962 .28059 Mdot
.03963 .28058 Mdot
.03964 .28056 Mdot
.03965 .28054 Mdot
.03966 .28053 Mdot
.03967 .28051 Mdot
.03968 .28049 Mdot
.03969 .28048 Mdot
.0397 .28046 Mdot
.0397 .28044 Mdot
.03971 .28043 Mdot
.03972 .28041 Mdot
.03973 .28039 Mdot
.03974 .28038 Mdot
.03975 .28036 Mdot
.03976 .28035 Mdot
.03977 .28033 Mdot
.03978 .28031 Mdot
.03979 .2803 Mdot
.0398 .28028 Mdot
.03981 .28026 Mdot
.03982 .28025 Mdot
.03983 .28023 Mdot
.03984 .28021 Mdot
.03985 .2802 Mdot
.03986 .28018 Mdot
.03987 .28017 Mdot
.03988 .28015 Mdot
.03989 .28013 Mdot
.0399 .28012 Mdot
.0399 .2801 Mdot
.03991 .28008 Mdot
.03992 .28007 Mdot
.03993 .28005 Mdot
.03994 .28003 Mdot
.03995 .28002 Mdot
.03996 .28 Mdot
.03997 .27998 Mdot
.03998 .27997 Mdot
.03999 .27995 Mdot
.04 .27994 Mdot
.04001 .27992 Mdot
.04002 .2799 Mdot
.04003 .27989 Mdot
.04004 .27987 Mdot
.04005 .27985 Mdot
.04006 .27984 Mdot
.04007 .27982 Mdot
.04008 .2798 Mdot
.04009 .27979 Mdot
.0401 .27977 Mdot
.0401 .27975 Mdot
.04011 .27974 Mdot
.04012 .27972 Mdot
.04013 .27971 Mdot
.04014 .27969 Mdot
.04015 .27967 Mdot
.04016 .27966 Mdot
.04017 .27964 Mdot
.04018 .27962 Mdot
.04019 .27961 Mdot
.0402 .27959 Mdot
.04021 .27957 Mdot
.04022 .27956 Mdot
.04023 .27954 Mdot
.04024 .27953 Mdot
.04025 .27951 Mdot
.04026 .27949 Mdot
.04027 .27948 Mdot
.04028 .27946 Mdot
.04029 .27944 Mdot
.0403 .27943 Mdot
.0403 .27941 Mdot
.04031 .27939 Mdot
.04032 .27938 Mdot
.04033 .27936 Mdot
.04034 .27934 Mdot
.04035 .27933 Mdot
.04036 .27931 Mdot
.04037 .2793 Mdot
.04038 .27928 Mdot
.04039 .27926 Mdot
.0404 .27925 Mdot
.04041 .27923 Mdot
.04042 .27921 Mdot
.04043 .2792 Mdot
.04044 .27918 Mdot
.04045 .27916 Mdot
.04046 .27915 Mdot
.04047 .27913 Mdot
.04048 .27912 Mdot
.04049 .2791 Mdot
.0405 .27908 Mdot
.0405 .27907 Mdot
.04051 .27905 Mdot
.04052 .27903 Mdot
.04053 .27902 Mdot
.04054 .279 Mdot
.04055 .27898 Mdot
.04056 .27897 Mdot
.04057 .27895 Mdot
.04058 .27893 Mdot
.04059 .27892 Mdot
.0406 .2789 Mdot
.04061 .27889 Mdot
.04062 .27887 Mdot
.04063 .27885 Mdot
.04064 .27884 Mdot
.04065 .27882 Mdot
.04066 .2788 Mdot
.04067 .27879 Mdot
.04068 .27877 Mdot
.04069 .27875 Mdot
.0407 .27874 Mdot
.0407 .27872 Mdot
.04071 .27871 Mdot
.04072 .27869 Mdot
.04073 .27867 Mdot
.04074 .27866 Mdot
.04075 .27864 Mdot
.04076 .27862 Mdot
.04077 .27861 Mdot
.04078 .27859 Mdot
.04079 .27857 Mdot
.0408 .27856 Mdot
.04081 .27854 Mdot
.04082 .27852 Mdot
.04083 .27851 Mdot
.04084 .27849 Mdot
.04085 .27848 Mdot
.04086 .27846 Mdot
.04087 .27844 Mdot
.04088 .27843 Mdot
.04089 .27841 Mdot
.0409 .27839 Mdot
.0409 .27838 Mdot
.04091 .27836 Mdot
.04092 .27834 Mdot
.04093 .27833 Mdot
.04094 .27831 Mdot
.04095 .2783 Mdot
.04096 .27828 Mdot
.04097 .27826 Mdot
.04098 .27825 Mdot
.04099 .27823 Mdot
.041 .27821 Mdot
.04101 .2782 Mdot
.04102 .27818 Mdot
.04103 .27816 Mdot
.04104 .27815 Mdot
.04105 .27813 Mdot
.04106 .27811 Mdot
.04107 .2781 Mdot
.04108 .27808 Mdot
.04109 .27807 Mdot
.0411 .27805 Mdot
.0411 .27803 Mdot
.04111 .27802 Mdot
.04112 .278 Mdot
.04113 .27798 Mdot
.04114 .27797 Mdot
.04115 .27795 Mdot
.04116 .27793 Mdot
.04117 .27792 Mdot
.04118 .2779 Mdot
.04119 .27789 Mdot
.0412 .27787 Mdot
.04121 .27785 Mdot
.04122 .27784 Mdot
.04123 .27782 Mdot
.04124 .2778 Mdot
.04125 .27779 Mdot
.04126 .27777 Mdot
.04127 .27775 Mdot
.04128 .27774 Mdot
.04129 .27772 Mdot
.0413 .2777 Mdot
.0413 .27769 Mdot
.04131 .27767 Mdot
.04132 .27766 Mdot
.04133 .27764 Mdot
.04134 .27762 Mdot
.04135 .27761 Mdot
.04136 .27759 Mdot
.04137 .27757 Mdot
.04138 .27756 Mdot
.04139 .27754 Mdot
.0414 .27752 Mdot
.04141 .27751 Mdot
.04142 .27749 Mdot
.04143 .27748 Mdot
.04144 .27746 Mdot
.04145 .27744 Mdot
.04146 .27743 Mdot
.04147 .27741 Mdot
.04148 .27739 Mdot
.04149 .27738 Mdot
.0415 .27736 Mdot
.0415 .27734 Mdot
.04151 .27733 Mdot
.04152 .27731 Mdot
.04153 .2773 Mdot
.04154 .27728 Mdot
.04155 .27726 Mdot
.04156 .27725 Mdot
.04157 .27723 Mdot
.04158 .27721 Mdot
.04159 .2772 Mdot
.0416 .27718 Mdot
.04161 .27716 Mdot
.04162 .27715 Mdot
.04163 .27713 Mdot
.04164 .27711 Mdot
.04165 .2771 Mdot
.04166 .27708 Mdot
.04167 .27707 Mdot
.04168 .27705 Mdot
.04169 .27703 Mdot
.0417 .27702 Mdot
.0417 .277 Mdot
.04171 .27698 Mdot
.04172 .27697 Mdot
.04173 .27695 Mdot
.04174 .27693 Mdot
.04175 .27692 Mdot
.04176 .2769 Mdot
.04177 .27689 Mdot
.04178 .27687 Mdot
.04179 .27685 Mdot
.0418 .27684 Mdot
.04181 .27682 Mdot
.04182 .2768 Mdot
.04183 .27679 Mdot
.04184 .27677 Mdot
.04185 .27675 Mdot
.04186 .27674 Mdot
.04187 .27672 Mdot
.04188 .2767 Mdot
.04189 .27669 Mdot
.0419 .27667 Mdot
.0419 .27666 Mdot
.04191 .27664 Mdot
.04192 .27662 Mdot
.04193 .27661 Mdot
.04194 .27659 Mdot
.04195 .27657 Mdot
.04196 .27656 Mdot
.04197 .27654 Mdot
.04198 .27652 Mdot
.04199 .27651 Mdot
.042 .27649 Mdot
.04201 .27648 Mdot
.04202 .27646 Mdot
.04203 .27644 Mdot
.04204 .27643 Mdot
.04205 .27641 Mdot
.04206 .27639 Mdot
.04207 .27638 Mdot
.04208 .27636 Mdot
.04209 .27634 Mdot
.0421 .27633 Mdot
.0421 .27631 Mdot
.04211 .2763 Mdot
.04212 .27628 Mdot
.04213 .27626 Mdot
.04214 .27625 Mdot
.04215 .27623 Mdot
.04216 .27621 Mdot
.04217 .2762 Mdot
.04218 .27618 Mdot
.04219 .27616 Mdot
.0422 .27615 Mdot
.04221 .27613 Mdot
.04222 .27611 Mdot
.04223 .2761 Mdot
.04224 .27608 Mdot
.04225 .27607 Mdot
.04226 .27605 Mdot
.04227 .27603 Mdot
.04228 .27602 Mdot
.04229 .276 Mdot
.0423 .27598 Mdot
.0423 .27597 Mdot
.04231 .27595 Mdot
.04232 .27593 Mdot
.04233 .27592 Mdot
.04234 .2759 Mdot
.04235 .27589 Mdot
.04236 .27587 Mdot
.04237 .27585 Mdot
.04238 .27584 Mdot
.04239 .27582 Mdot
.0424 .2758 Mdot
.04241 .27579 Mdot
.04242 .27577 Mdot
.04243 .27575 Mdot
.04244 .27574 Mdot
.04245 .27572 Mdot
.04246 .27571 Mdot
.04247 .27569 Mdot
.04248 .27567 Mdot
.04249 .27566 Mdot
.0425 .27564 Mdot
.0425 .27562 Mdot
.04251 .27561 Mdot
.04252 .27559 Mdot
.04253 .27557 Mdot
.04254 .27556 Mdot
.04255 .27554 Mdot
.04256 .27553 Mdot
.04257 .27551 Mdot
.04258 .27549 Mdot
.04259 .27548 Mdot
.0426 .27546 Mdot
.04261 .27544 Mdot
.04262 .27543 Mdot
.04263 .27541 Mdot
.04264 .27539 Mdot
.04265 .27538 Mdot
.04266 .27536 Mdot
.04267 .27534 Mdot
.04268 .27533 Mdot
.04269 .27531 Mdot
.0427 .2753 Mdot
.0427 .27528 Mdot
.04271 .27526 Mdot
.04272 .27525 Mdot
.04273 .27523 Mdot
.04274 .27521 Mdot
.04275 .2752 Mdot
.04276 .27518 Mdot
.04277 .27516 Mdot
.04278 .27515 Mdot
.04279 .27513 Mdot
.0428 .27512 Mdot
.04281 .2751 Mdot
.04282 .27508 Mdot
.04283 .27507 Mdot
.04284 .27505 Mdot
.04285 .27503 Mdot
.04286 .27502 Mdot
.04287 .275 Mdot
.04288 .27498 Mdot
.04289 .27497 Mdot
.0429 .27495 Mdot
.0429 .27494 Mdot
.04291 .27492 Mdot
.04292 .2749 Mdot
.04293 .27489 Mdot
.04294 .27487 Mdot
.04295 .27485 Mdot
.04296 .27484 Mdot
.04297 .27482 Mdot
.04298 .2748 Mdot
.04299 .27479 Mdot
.043 .27477 Mdot
.04301 .27476 Mdot
.04302 .27474 Mdot
.04303 .27472 Mdot
.04304 .27471 Mdot
.04305 .27469 Mdot
.04306 .27467 Mdot
.04307 .27466 Mdot
.04308 .27464 Mdot
.04309 .27462 Mdot
.0431 .27461 Mdot
.0431 .27459 Mdot
.04311 .27458 Mdot
.04312 .27456 Mdot
.04313 .27454 Mdot
.04314 .27453 Mdot
.04315 .27451 Mdot
.04316 .27449 Mdot
.04317 .27448 Mdot
.04318 .27446 Mdot
.04319 .27444 Mdot
.0432 .27443 Mdot
.04321 .27441 Mdot
.04322 .2744 Mdot
.04323 .27438 Mdot
.04324 .27436 Mdot
.04325 .27435 Mdot
.04326 .27433 Mdot
.04327 .27431 Mdot
.04328 .2743 Mdot
.04329 .27428 Mdot
.0433 .27426 Mdot
.0433 .27425 Mdot
.04331 .27423 Mdot
.04332 .27421 Mdot
.04333 .2742 Mdot
.04334 .27418 Mdot
.04335 .27417 Mdot
.04336 .27415 Mdot
.04337 .27413 Mdot
.04338 .27412 Mdot
.04339 .2741 Mdot
.0434 .27408 Mdot
.04341 .27407 Mdot
.04342 .27405 Mdot
.04343 .27403 Mdot
.04344 .27402 Mdot
.04345 .274 Mdot
.04346 .27399 Mdot
.04347 .27397 Mdot
.04348 .27395 Mdot
.04349 .27394 Mdot
.0435 .27392 Mdot
.0435 .2739 Mdot
.04351 .27389 Mdot
.04352 .27387 Mdot
.04353 .27385 Mdot
.04354 .27384 Mdot
.04355 .27382 Mdot
.04356 .27381 Mdot
.04357 .27379 Mdot
.04358 .27377 Mdot
.04359 .27376 Mdot
.0436 .27374 Mdot
.04361 .27372 Mdot
.04362 .27371 Mdot
.04363 .27369 Mdot
.04364 .27367 Mdot
.04365 .27366 Mdot
.04366 .27364 Mdot
.04367 .27363 Mdot
.04368 .27361 Mdot
.04369 .27359 Mdot
.0437 .27358 Mdot
.0437 .27356 Mdot
.04371 .27354 Mdot
.04372 .27353 Mdot
.04373 .27351 Mdot
.04374 .27349 Mdot
.04375 .27348 Mdot
.04376 .27346 Mdot
.04377 .27345 Mdot
.04378 .27343 Mdot
.04379 .27341 Mdot
.0438 .2734 Mdot
.04381 .27338 Mdot
.04382 .27336 Mdot
.04383 .27335 Mdot
.04384 .27333 Mdot
.04385 .27331 Mdot
.04386 .2733 Mdot
.04387 .27328 Mdot
.04388 .27327 Mdot
.04389 .27325 Mdot
.0439 .27323 Mdot
.0439 .27322 Mdot
.04391 .2732 Mdot
.04392 .27318 Mdot
.04393 .27317 Mdot
.04394 .27315 Mdot
.04395 .27313 Mdot
.04396 .27312 Mdot
.04397 .2731 Mdot
.04398 .27309 Mdot
.04399 .27307 Mdot
.044 .27305 Mdot
.04401 .27304 Mdot
.04402 .27302 Mdot
.04403 .273 Mdot
.04404 .27299 Mdot
.04405 .27297 Mdot
.04406 .27295 Mdot
.04407 .27294 Mdot
.04408 .27292 Mdot
.04409 .27291 Mdot
.0441 .27289 Mdot
.0441 .27287 Mdot
.04411 .27286 Mdot
.04412 .27284 Mdot
.04413 .27282 Mdot
.04414 .27281 Mdot
.04415 .27279 Mdot
.04416 .27277 Mdot
.04417 .27276 Mdot
.04418 .27274 Mdot
.04419 .27273 Mdot
.0442 .27271 Mdot
.04421 .27269 Mdot
.04422 .27268 Mdot
.04423 .27266 Mdot
.04424 .27264 Mdot
.04425 .27263 Mdot
.04426 .27261 Mdot
.04427 .27259 Mdot
.04428 .27258 Mdot
.04429 .27256 Mdot
.0443 .27255 Mdot
.0443 .27253 Mdot
.04431 .27251 Mdot
.04432 .2725 Mdot
.04433 .27248 Mdot
.04434 .27246 Mdot
.04435 .27245 Mdot
.04436 .27243 Mdot
.04437 .27241 Mdot
.04438 .2724 Mdot
.04439 .27238 Mdot
.0444 .27237 Mdot
.04441 .27235 Mdot
.04442 .27233 Mdot
.04443 .27232 Mdot
.04444 .2723 Mdot
.04445 .27228 Mdot
.04446 .27227 Mdot
.04447 .27225 Mdot
.04448 .27223 Mdot
.04449 .27222 Mdot
.0445 .2722 Mdot
.0445 .27219 Mdot
.04451 .27217 Mdot
.04452 .27215 Mdot
.04453 .27214 Mdot
.04454 .27212 Mdot
.04455 .2721 Mdot
.04456 .27209 Mdot
.04457 .27207 Mdot
.04458 .27205 Mdot
.04459 .27204 Mdot
.0446 .27202 Mdot
.04461 .27201 Mdot
.04462 .27199 Mdot
.04463 .27197 Mdot
.04464 .27196 Mdot
.04465 .27194 Mdot
.04466 .27192 Mdot
.04467 .27191 Mdot
.04468 .27189 Mdot
.04469 .27187 Mdot
.0447 .27186 Mdot
.0447 .27184 Mdot
.04471 .27183 Mdot
.04472 .27181 Mdot
.04473 .27179 Mdot
.04474 .27178 Mdot
.04475 .27176 Mdot
.04476 .27174 Mdot
.04477 .27173 Mdot
.04478 .27171 Mdot
.04479 .27169 Mdot
.0448 .27168 Mdot
.04481 .27166 Mdot
.04482 .27165 Mdot
.04483 .27163 Mdot
.04484 .27161 Mdot
.04485 .2716 Mdot
.04486 .27158 Mdot
.04487 .27156 Mdot
.04488 .27155 Mdot
.04489 .27153 Mdot
.0449 .27151 Mdot
.0449 .2715 Mdot
.04491 .27148 Mdot
.04492 .27147 Mdot
.04493 .27145 Mdot
.04494 .27143 Mdot
.04495 .27142 Mdot
.04496 .2714 Mdot
.04497 .27138 Mdot
.04498 .27137 Mdot
.04499 .27135 Mdot
.045 .27133 Mdot
.04501 .27132 Mdot
.04502 .2713 Mdot
.04503 .27129 Mdot
.04504 .27127 Mdot
.04505 .27125 Mdot
.04506 .27124 Mdot
.04507 .27122 Mdot
.04508 .2712 Mdot
.04509 .27119 Mdot
.0451 .27117 Mdot
.0451 .27115 Mdot
.04511 .27114 Mdot
.04512 .27112 Mdot
.04513 .27111 Mdot
.04514 .27109 Mdot
.04515 .27107 Mdot
.04516 .27106 Mdot
.04517 .27104 Mdot
.04518 .27102 Mdot
.04519 .27101 Mdot
.0452 .27099 Mdot
.04521 .27097 Mdot
.04522 .27096 Mdot
.04523 .27094 Mdot
.04524 .27093 Mdot
.04525 .27091 Mdot
.04526 .27089 Mdot
.04527 .27088 Mdot
.04528 .27086 Mdot
.04529 .27084 Mdot
.0453 .27083 Mdot
.0453 .27081 Mdot
.04531 .27079 Mdot
.04532 .27078 Mdot
.04533 .27076 Mdot
.04534 .27075 Mdot
.04535 .27073 Mdot
.04536 .27071 Mdot
.04537 .2707 Mdot
.04538 .27068 Mdot
.04539 .27066 Mdot
.0454 .27065 Mdot
.04541 .27063 Mdot
.04542 .27062 Mdot
.04543 .2706 Mdot
.04544 .27058 Mdot
.04545 .27057 Mdot
.04546 .27055 Mdot
.04547 .27053 Mdot
.04548 .27052 Mdot
.04549 .2705 Mdot
.0455 .27048 Mdot
.0455 .27047 Mdot
.04551 .27045 Mdot
.04552 .27044 Mdot
.04553 .27042 Mdot
.04554 .2704 Mdot
.04555 .27039 Mdot
.04556 .27037 Mdot
.04557 .27035 Mdot
.04558 .27034 Mdot
.04559 .27032 Mdot
.0456 .2703 Mdot
.04561 .27029 Mdot
.04562 .27027 Mdot
.04563 .27026 Mdot
.04564 .27024 Mdot
.04565 .27022 Mdot
.04566 .27021 Mdot
.04567 .27019 Mdot
.04568 .27017 Mdot
.04569 .27016 Mdot
.0457 .27014 Mdot
.0457 .27012 Mdot
.04571 .27011 Mdot
.04572 .27009 Mdot
.04573 .27008 Mdot
.04574 .27006 Mdot
.04575 .27004 Mdot
.04576 .27003 Mdot
.04577 .27001 Mdot
.04578 .26999 Mdot
.04579 .26998 Mdot
.0458 .26996 Mdot
.04581 .26994 Mdot
.04582 .26993 Mdot
.04583 .26991 Mdot
.04584 .2699 Mdot
.04585 .26988 Mdot
.04586 .26986 Mdot
.04587 .26985 Mdot
.04588 .26983 Mdot
.04589 .26981 Mdot
.0459 .2698 Mdot
.0459 .26978 Mdot
.04591 .26976 Mdot
.04592 .26975 Mdot
.04593 .26973 Mdot
.04594 .26972 Mdot
.04595 .2697 Mdot
.04596 .26968 Mdot
.04597 .26967 Mdot
.04598 .26965 Mdot
.04599 .26963 Mdot
.046 .26962 Mdot
.04601 .2696 Mdot
.04602 .26959 Mdot
.04603 .26957 Mdot
.04604 .26955 Mdot
.04605 .26954 Mdot
.04606 .26952 Mdot
.04607 .2695 Mdot
.04608 .26949 Mdot
.04609 .26947 Mdot
.0461 .26945 Mdot
.0461 .26944 Mdot
.04611 .26942 Mdot
.04612 .26941 Mdot
.04613 .26939 Mdot
.04614 .26937 Mdot
.04615 .26936 Mdot
.04616 .26934 Mdot
.04617 .26932 Mdot
.04618 .26931 Mdot
.04619 .26929 Mdot
.0462 .26927 Mdot
.04621 .26926 Mdot
.04622 .26924 Mdot
.04623 .26923 Mdot
.04624 .26921 Mdot
.04625 .26919 Mdot
.04626 .26918 Mdot
.04627 .26916 Mdot
.04628 .26914 Mdot
.04629 .26913 Mdot
.0463 .26911 Mdot
.0463 .26909 Mdot
.04631 .26908 Mdot
.04632 .26906 Mdot
.04633 .26905 Mdot
.04634 .26903 Mdot
.04635 .26901 Mdot
.04636 .269 Mdot
.04637 .26898 Mdot
.04638 .26896 Mdot
.04639 .26895 Mdot
.0464 .26893 Mdot
.04641 .26892 Mdot
.04642 .2689 Mdot
.04643 .26888 Mdot
.04644 .26887 Mdot
.04645 .26885 Mdot
.04646 .26883 Mdot
.04647 .26882 Mdot
.04648 .2688 Mdot
.04649 .26878 Mdot
.0465 .26877 Mdot
.0465 .26875 Mdot
.04651 .26874 Mdot
.04652 .26872 Mdot
.04653 .2687 Mdot
.04654 .26869 Mdot
.04655 .26867 Mdot
.04656 .26865 Mdot
.04657 .26864 Mdot
.04658 .26862 Mdot
.04659 .2686 Mdot
.0466 .26859 Mdot
.04661 .26857 Mdot
.04662 .26856 Mdot
.04663 .26854 Mdot
.04664 .26852 Mdot
.04665 .26851 Mdot
.04666 .26849 Mdot
.04667 .26847 Mdot
.04668 .26846 Mdot
.04669 .26844 Mdot
.0467 .26843 Mdot
.0467 .26841 Mdot
.04671 .26839 Mdot
.04672 .26838 Mdot
.04673 .26836 Mdot
.04674 .26834 Mdot
.04675 .26833 Mdot
.04676 .26831 Mdot
.04677 .26829 Mdot
.04678 .26828 Mdot
.04679 .26826 Mdot
.0468 .26825 Mdot
.04681 .26823 Mdot
.04682 .26821 Mdot
.04683 .2682 Mdot
.04684 .26818 Mdot
.04685 .26816 Mdot
.04686 .26815 Mdot
.04687 .26813 Mdot
.04688 .26811 Mdot
.04689 .2681 Mdot
.0469 .26808 Mdot
.0469 .26807 Mdot
.04691 .26805 Mdot
.04692 .26803 Mdot
.04693 .26802 Mdot
.04694 .268 Mdot
.04695 .26798 Mdot
.04696 .26797 Mdot
.04697 .26795 Mdot
.04698 .26794 Mdot
.04699 .26792 Mdot
.047 .2679 Mdot
.04701 .26789 Mdot
.04702 .26787 Mdot
.04703 .26785 Mdot
.04704 .26784 Mdot
.04705 .26782 Mdot
.04706 .2678 Mdot
.04707 .26779 Mdot
.04708 .26777 Mdot
.04709 .26776 Mdot
.0471 .26774 Mdot
.0471 .26772 Mdot
.04711 .26771 Mdot
.04712 .26769 Mdot
.04713 .26767 Mdot
.04714 .26766 Mdot
.04715 .26764 Mdot
.04716 .26762 Mdot
.04717 .26761 Mdot
.04718 .26759 Mdot
.04719 .26758 Mdot
.0472 .26756 Mdot
.04721 .26754 Mdot
.04722 .26753 Mdot
.04723 .26751 Mdot
.04724 .26749 Mdot
.04725 .26748 Mdot
.04726 .26746 Mdot
.04727 .26745 Mdot
.04728 .26743 Mdot
.04729 .26741 Mdot
.0473 .2674 Mdot
.0473 .26738 Mdot
.04731 .26736 Mdot
.04732 .26735 Mdot
.04733 .26733 Mdot
.04734 .26731 Mdot
.04735 .2673 Mdot
.04736 .26728 Mdot
.04737 .26727 Mdot
.04738 .26725 Mdot
.04739 .26723 Mdot
.0474 .26722 Mdot
.04741 .2672 Mdot
.04742 .26718 Mdot
.04743 .26717 Mdot
.04744 .26715 Mdot
.04745 .26713 Mdot
.04746 .26712 Mdot
.04747 .2671 Mdot
.04748 .26709 Mdot
.04749 .26707 Mdot
.0475 .26705 Mdot
.0475 .26704 Mdot
.04751 .26702 Mdot
.04752 .267 Mdot
.04753 .26699 Mdot
.04754 .26697 Mdot
.04755 .26696 Mdot
.04756 .26694 Mdot
.04757 .26692 Mdot
.04758 .26691 Mdot
.04759 .26689 Mdot
.0476 .26687 Mdot
.04761 .26686 Mdot
.04762 .26684 Mdot
.04763 .26682 Mdot
.04764 .26681 Mdot
.04765 .26679 Mdot
.04766 .26678 Mdot
.04767 .26676 Mdot
.04768 .26674 Mdot
.04769 .26673 Mdot
.0477 .26671 Mdot
.0477 .26669 Mdot
.04771 .26668 Mdot
.04772 .26666 Mdot
.04773 .26665 Mdot
.04774 .26663 Mdot
.04775 .26661 Mdot
.04776 .2666 Mdot
.04777 .26658 Mdot
.04778 .26656 Mdot
.04779 .26655 Mdot
.0478 .26653 Mdot
.04781 .26651 Mdot
.04782 .2665 Mdot
.04783 .26648 Mdot
.04784 .26647 Mdot
.04785 .26645 Mdot
.04786 .26643 Mdot
.04787 .26642 Mdot
.04788 .2664 Mdot
.04789 .26638 Mdot
.0479 .26637 Mdot
.0479 .26635 Mdot
.04791 .26634 Mdot
.04792 .26632 Mdot
.04793 .2663 Mdot
.04794 .26629 Mdot
.04795 .26627 Mdot
.04796 .26625 Mdot
.04797 .26624 Mdot
.04798 .26622 Mdot
.04799 .2662 Mdot
.048 .26619 Mdot
.04801 .26617 Mdot
.04802 .26616 Mdot
.04803 .26614 Mdot
.04804 .26612 Mdot
.04805 .26611 Mdot
.04806 .26609 Mdot
.04807 .26607 Mdot
.04808 .26606 Mdot
.04809 .26604 Mdot
.0481 .26603 Mdot
.0481 .26601 Mdot
.04811 .26599 Mdot
.04812 .26598 Mdot
.04813 .26596 Mdot
.04814 .26594 Mdot
.04815 .26593 Mdot
.04816 .26591 Mdot
.04817 .26589 Mdot
.04818 .26588 Mdot
.04819 .26586 Mdot
.0482 .26585 Mdot
.04821 .26583 Mdot
.04822 .26581 Mdot
.04823 .2658 Mdot
.04824 .26578 Mdot
.04825 .26576 Mdot
.04826 .26575 Mdot
.04827 .26573 Mdot
.04828 .26572 Mdot
.04829 .2657 Mdot
.0483 .26568 Mdot
.0483 .26567 Mdot
.04831 .26565 Mdot
.04832 .26563 Mdot
.04833 .26562 Mdot
.04834 .2656 Mdot
.04835 .26558 Mdot
.04836 .26557 Mdot
.04837 .26555 Mdot
.04838 .26554 Mdot
.04839 .26552 Mdot
.0484 .2655 Mdot
.04841 .26549 Mdot
.04842 .26547 Mdot
.04843 .26545 Mdot
.04844 .26544 Mdot
.04845 .26542 Mdot
.04846 .26541 Mdot
.04847 .26539 Mdot
.04848 .26537 Mdot
.04849 .26536 Mdot
.0485 .26534 Mdot
.0485 .26532 Mdot
.04851 .26531 Mdot
.04852 .26529 Mdot
.04853 .26527 Mdot
.04854 .26526 Mdot
.04855 .26524 Mdot
.04856 .26523 Mdot
.04857 .26521 Mdot
.04858 .26519 Mdot
.04859 .26518 Mdot
.0486 .26516 Mdot
.04861 .26514 Mdot
.04862 .26513 Mdot
.04863 .26511 Mdot
.04864 .2651 Mdot
.04865 .26508 Mdot
.04866 .26506 Mdot
.04867 .26505 Mdot
.04868 .26503 Mdot
.04869 .26501 Mdot
.0487 .265 Mdot
.0487 .26498 Mdot
.04871 .26496 Mdot
.04872 .26495 Mdot
.04873 .26493 Mdot
.04874 .26492 Mdot
.04875 .2649 Mdot
.04876 .26488 Mdot
.04877 .26487 Mdot
.04878 .26485 Mdot
.04879 .26483 Mdot
.0488 .26482 Mdot
.04881 .2648 Mdot
.04882 .26479 Mdot
.04883 .26477 Mdot
.04884 .26475 Mdot
.04885 .26474 Mdot
.04886 .26472 Mdot
.04887 .2647 Mdot
.04888 .26469 Mdot
.04889 .26467 Mdot
.0489 .26465 Mdot
.0489 .26464 Mdot
.04891 .26462 Mdot
.04892 .26461 Mdot
.04893 .26459 Mdot
.04894 .26457 Mdot
.04895 .26456 Mdot
.04896 .26454 Mdot
.04897 .26452 Mdot
.04898 .26451 Mdot
.04899 .26449 Mdot
.049 .26448 Mdot
.04901 .26446 Mdot
.04902 .26444 Mdot
.04903 .26443 Mdot
.04904 .26441 Mdot
.04905 .26439 Mdot
.04906 .26438 Mdot
.04907 .26436 Mdot
.04908 .26435 Mdot
.04909 .26433 Mdot
.0491 .26431 Mdot
.0491 .2643 Mdot
.04911 .26428 Mdot
.04912 .26426 Mdot
.04913 .26425 Mdot
.04914 .26423 Mdot
.04915 .26421 Mdot
.04916 .2642 Mdot
.04917 .26418 Mdot
.04918 .26417 Mdot
.04919 .26415 Mdot
.0492 .26413 Mdot
.04921 .26412 Mdot
.04922 .2641 Mdot
.04923 .26408 Mdot
.04924 .26407 Mdot
.04925 .26405 Mdot
.04926 .26404 Mdot
.04927 .26402 Mdot
.04928 .264 Mdot
.04929 .26399 Mdot
.0493 .26397 Mdot
.0493 .26395 Mdot
.04931 .26394 Mdot
.04932 .26392 Mdot
.04933 .2639 Mdot
.04934 .26389 Mdot
.04935 .26387 Mdot
.04936 .26386 Mdot
.04937 .26384 Mdot
.04938 .26382 Mdot
.04939 .26381 Mdot
.0494 .26379 Mdot
.04941 .26377 Mdot
.04942 .26376 Mdot
.04943 .26374 Mdot
.04944 .26373 Mdot
.04945 .26371 Mdot
.04946 .26369 Mdot
.04947 .26368 Mdot
.04948 .26366 Mdot
.04949 .26364 Mdot
.0495 .26363 Mdot
.0495 .26361 Mdot
.04951 .2636 Mdot
.04952 .26358 Mdot
.04953 .26356 Mdot
.04954 .26355 Mdot
.04955 .26353 Mdot
.04956 .26351 Mdot
.04957 .2635 Mdot
.04958 .26348 Mdot
.04959 .26346 Mdot
.0496 .26345 Mdot
.04961 .26343 Mdot
.04962 .26342 Mdot
.04963 .2634 Mdot
.04964 .26338 Mdot
.04965 .26337 Mdot
.04966 .26335 Mdot
.04967 .26333 Mdot
.04968 .26332 Mdot
.04969 .2633 Mdot
.0497 .26329 Mdot
.0497 .26327 Mdot
.04971 .26325 Mdot
.04972 .26324 Mdot
.04973 .26322 Mdot
.04974 .2632 Mdot
.04975 .26319 Mdot
.04976 .26317 Mdot
.04977 .26316 Mdot
.04978 .26314 Mdot
.04979 .26312 Mdot
.0498 .26311 Mdot
.04981 .26309 Mdot
.04982 .26307 Mdot
.04983 .26306 Mdot
.04984 .26304 Mdot
.04985 .26302 Mdot
.04986 .26301 Mdot
.04987 .26299 Mdot
.04988 .26298 Mdot
.04989 .26296 Mdot
.0499 .26294 Mdot
.0499 .26293 Mdot
.04991 .26291 Mdot
.04992 .26289 Mdot
.04993 .26288 Mdot
.04994 .26286 Mdot
.04995 .26285 Mdot
.04996 .26283 Mdot
.04997 .26281 Mdot
.04998 .2628 Mdot
.04999 .26278 Mdot
.05 .26276 Mdot
.05001 .26275 Mdot
.05002 .26273 Mdot
.05003 .26272 Mdot
.05004 .2627 Mdot
.05005 .26268 Mdot
.05006 .26267 Mdot
.05007 .26265 Mdot
.05008 .26263 Mdot
.05009 .26262 Mdot
.0501 .2626 Mdot
.0501 .26258 Mdot
.05011 .26257 Mdot
.05012 .26255 Mdot
.05013 .26254 Mdot
.05014 .26252 Mdot
.05015 .2625 Mdot
.05016 .26249 Mdot
.05017 .26247 Mdot
.05018 .26245 Mdot
.05019 .26244 Mdot
.0502 .26242 Mdot
.05021 .26241 Mdot
.05022 .26239 Mdot
.05023 .26237 Mdot
.05024 .26236 Mdot
.05025 .26234 Mdot
.05026 .26232 Mdot
.05027 .26231 Mdot
.05028 .26229 Mdot
.05029 .26228 Mdot
.0503 .26226 Mdot
.0503 .26224 Mdot
.05031 .26223 Mdot
.05032 .26221 Mdot
.05033 .26219 Mdot
.05034 .26218 Mdot
.05035 .26216 Mdot
.05036 .26215 Mdot
.05037 .26213 Mdot
.05038 .26211 Mdot
.05039 .2621 Mdot
.0504 .26208 Mdot
.05041 .26206 Mdot
.05042 .26205 Mdot
.05043 .26203 Mdot
.05044 .26201 Mdot
.05045 .262 Mdot
.05046 .26198 Mdot
.05047 .26197 Mdot
.05048 .26195 Mdot
.05049 .26193 Mdot
.0505 .26192 Mdot
.0505 .2619 Mdot
.05051 .26188 Mdot
.05052 .26187 Mdot
.05053 .26185 Mdot
.05054 .26184 Mdot
.05055 .26182 Mdot
.05056 .2618 Mdot
.05057 .26179 Mdot
.05058 .26177 Mdot
.05059 .26175 Mdot
.0506 .26174 Mdot
.05061 .26172 Mdot
.05062 .26171 Mdot
.05063 .26169 Mdot
.05064 .26167 Mdot
.05065 .26166 Mdot
.05066 .26164 Mdot
.05067 .26162 Mdot
.05068 .26161 Mdot
.05069 .26159 Mdot
.0507 .26158 Mdot
.0507 .26156 Mdot
.05071 .26154 Mdot
.05072 .26153 Mdot
.05073 .26151 Mdot
.05074 .26149 Mdot
.05075 .26148 Mdot
.05076 .26146 Mdot
.05077 .26144 Mdot
.05078 .26143 Mdot
.05079 .26141 Mdot
.0508 .2614 Mdot
.05081 .26138 Mdot
.05082 .26136 Mdot
.05083 .26135 Mdot
.05084 .26133 Mdot
.05085 .26131 Mdot
.05086 .2613 Mdot
.05087 .26128 Mdot
.05088 .26127 Mdot
.05089 .26125 Mdot
.0509 .26123 Mdot
.0509 .26122 Mdot
.05091 .2612 Mdot
.05092 .26118 Mdot
.05093 .26117 Mdot
.05094 .26115 Mdot
.05095 .26114 Mdot
.05096 .26112 Mdot
.05097 .2611 Mdot
.05098 .26109 Mdot
.05099 .26107 Mdot
.051 .26105 Mdot
.05101 .26104 Mdot
.05102 .26102 Mdot
.05103 .26101 Mdot
.05104 .26099 Mdot
.05105 .26097 Mdot
.05106 .26096 Mdot
.05107 .26094 Mdot
.05108 .26092 Mdot
.05109 .26091 Mdot
.0511 .26089 Mdot
.0511 .26088 Mdot
.05111 .26086 Mdot
.05112 .26084 Mdot
.05113 .26083 Mdot
.05114 .26081 Mdot
.05115 .26079 Mdot
.05116 .26078 Mdot
.05117 .26076 Mdot
.05118 .26074 Mdot
.05119 .26073 Mdot
.0512 .26071 Mdot
.05121 .2607 Mdot
.05122 .26068 Mdot
.05123 .26066 Mdot
.05124 .26065 Mdot
.05125 .26063 Mdot
.05126 .26061 Mdot
.05127 .2606 Mdot
.05128 .26058 Mdot
.05129 .26057 Mdot
.0513 .26055 Mdot
.0513 .26053 Mdot
.05131 .26052 Mdot
.05132 .2605 Mdot
.05133 .26048 Mdot
.05134 .26047 Mdot
.05135 .26045 Mdot
.05136 .26044 Mdot
.05137 .26042 Mdot
.05138 .2604 Mdot
.05139 .26039 Mdot
.0514 .26037 Mdot
.05141 .26035 Mdot
.05142 .26034 Mdot
.05143 .26032 Mdot
.05144 .26031 Mdot
.05145 .26029 Mdot
.05146 .26027 Mdot
.05147 .26026 Mdot
.05148 .26024 Mdot
.05149 .26022 Mdot
.0515 .26021 Mdot
.0515 .26019 Mdot
.05151 .26018 Mdot
.05152 .26016 Mdot
.05153 .26014 Mdot
.05154 .26013 Mdot
.05155 .26011 Mdot
.05156 .26009 Mdot
.05157 .26008 Mdot
.05158 .26006 Mdot
.05159 .26005 Mdot
.0516 .26003 Mdot
.05161 .26001 Mdot
.05162 .26 Mdot
.05163 .25998 Mdot
.05164 .25996 Mdot
.05165 .25995 Mdot
.05166 .25993 Mdot
.05167 .25992 Mdot
.05168 .2599 Mdot
.05169 .25988 Mdot
.0517 .25987 Mdot
.0517 .25985 Mdot
.05171 .25983 Mdot
.05172 .25982 Mdot
.05173 .2598 Mdot
.05174 .25979 Mdot
.05175 .25977 Mdot
.05176 .25975 Mdot
.05177 .25974 Mdot
.05178 .25972 Mdot
.05179 .2597 Mdot
.0518 .25969 Mdot
.05181 .25967 Mdot
.05182 .25965 Mdot
.05183 .25964 Mdot
.05184 .25962 Mdot
.05185 .25961 Mdot
.05186 .25959 Mdot
.05187 .25957 Mdot
.05188 .25956 Mdot
.05189 .25954 Mdot
.0519 .25952 Mdot
.0519 .25951 Mdot
.05191 .25949 Mdot
.05192 .25948 Mdot
.05193 .25946 Mdot
.05194 .25944 Mdot
.05195 .25943 Mdot
.05196 .25941 Mdot
.05197 .25939 Mdot
.05198 .25938 Mdot
.05199 .25936 Mdot
.052 .25935 Mdot
.05201 .25933 Mdot
.05202 .25931 Mdot
.05203 .2593 Mdot
.05204 .25928 Mdot
.05205 .25926 Mdot
.05206 .25925 Mdot
.05207 .25923 Mdot
.05208 .25922 Mdot
.05209 .2592 Mdot
.0521 .25918 Mdot
.0521 .25917 Mdot
.05211 .25915 Mdot
.05212 .25913 Mdot
.05213 .25912 Mdot
.05214 .2591 Mdot
.05215 .25909 Mdot
.05216 .25907 Mdot
.05217 .25905 Mdot
.05218 .25904 Mdot
.05219 .25902 Mdot
.0522 .259 Mdot
.05221 .25899 Mdot
.05222 .25897 Mdot
.05223 .25896 Mdot
.05224 .25894 Mdot
.05225 .25892 Mdot
.05226 .25891 Mdot
.05227 .25889 Mdot
.05228 .25887 Mdot
.05229 .25886 Mdot
.0523 .25884 Mdot
.0523 .25883 Mdot
.05231 .25881 Mdot
.05232 .25879 Mdot
.05233 .25878 Mdot
.05234 .25876 Mdot
.05235 .25874 Mdot
.05236 .25873 Mdot
.05237 .25871 Mdot
.05238 .2587 Mdot
.05239 .25868 Mdot
.0524 .25866 Mdot
.05241 .25865 Mdot
.05242 .25863 Mdot
.05243 .25861 Mdot
.05244 .2586 Mdot
.05245 .25858 Mdot
.05246 .25857 Mdot
.05247 .25855 Mdot
.05248 .25853 Mdot
.05249 .25852 Mdot
.0525 .2585 Mdot
.0525 .25848 Mdot
.05251 .25847 Mdot
.05252 .25845 Mdot
.05253 .25844 Mdot
.05254 .25842 Mdot
.05255 .2584 Mdot
.05256 .25839 Mdot
.05257 .25837 Mdot
.05258 .25835 Mdot
.05259 .25834 Mdot
.0526 .25832 Mdot
.05261 .25831 Mdot
.05262 .25829 Mdot
.05263 .25827 Mdot
.05264 .25826 Mdot
.05265 .25824 Mdot
.05266 .25822 Mdot
.05267 .25821 Mdot
.05268 .25819 Mdot
.05269 .25818 Mdot
.0527 .25816 Mdot
.0527 .25814 Mdot
.05271 .25813 Mdot
.05272 .25811 Mdot
.05273 .25809 Mdot
.05274 .25808 Mdot
.05275 .25806 Mdot
.05276 .25805 Mdot
.05277 .25803 Mdot
.05278 .25801 Mdot
.05279 .258 Mdot
.0528 .25798 Mdot
.05281 .25796 Mdot
.05282 .25795 Mdot
.05283 .25793 Mdot
.05284 .25792 Mdot
.05285 .2579 Mdot
.05286 .25788 Mdot
.05287 .25787 Mdot
.05288 .25785 Mdot
.05289 .25783 Mdot
.0529 .25782 Mdot
.0529 .2578 Mdot
.05291 .25779 Mdot
.05292 .25777 Mdot
.05293 .25775 Mdot
.05294 .25774 Mdot
.05295 .25772 Mdot
.05296 .2577 Mdot
.05297 .25769 Mdot
.05298 .25767 Mdot
.05299 .25766 Mdot
.053 .25764 Mdot
.05301 .25762 Mdot
.05302 .25761 Mdot
.05303 .25759 Mdot
.05304 .25757 Mdot
.05305 .25756 Mdot
.05306 .25754 Mdot
.05307 .25753 Mdot
.05308 .25751 Mdot
.05309 .25749 Mdot
.0531 .25748 Mdot
.0531 .25746 Mdot
.05311 .25744 Mdot
.05312 .25743 Mdot
.05313 .25741 Mdot
.05314 .2574 Mdot
.05315 .25738 Mdot
.05316 .25736 Mdot
.05317 .25735 Mdot
.05318 .25733 Mdot
.05319 .25731 Mdot
.0532 .2573 Mdot
.05321 .25728 Mdot
.05322 .25727 Mdot
.05323 .25725 Mdot
.05324 .25723 Mdot
.05325 .25722 Mdot
.05326 .2572 Mdot
.05327 .25718 Mdot
.05328 .25717 Mdot
.05329 .25715 Mdot
.0533 .25714 Mdot
.0533 .25712 Mdot
.05331 .2571 Mdot
.05332 .25709 Mdot
.05333 .25707 Mdot
.05334 .25705 Mdot
.05335 .25704 Mdot
.05336 .25702 Mdot
.05337 .25701 Mdot
.05338 .25699 Mdot
.05339 .25697 Mdot
.0534 .25696 Mdot
.05341 .25694 Mdot
.05342 .25692 Mdot
.05343 .25691 Mdot
.05344 .25689 Mdot
.05345 .25688 Mdot
.05346 .25686 Mdot
.05347 .25684 Mdot
.05348 .25683 Mdot
.05349 .25681 Mdot
.0535 .25679 Mdot
.0535 .25678 Mdot
.05351 .25676 Mdot
.05352 .25675 Mdot
.05353 .25673 Mdot
.05354 .25671 Mdot
.05355 .2567 Mdot
.05356 .25668 Mdot
.05357 .25666 Mdot
.05358 .25665 Mdot
.05359 .25663 Mdot
.0536 .25662 Mdot
.05361 .2566 Mdot
.05362 .25658 Mdot
.05363 .25657 Mdot
.05364 .25655 Mdot
.05365 .25653 Mdot
.05366 .25652 Mdot
.05367 .2565 Mdot
.05368 .25649 Mdot
.05369 .25647 Mdot
.0537 .25645 Mdot
.0537 .25644 Mdot
.05371 .25642 Mdot
.05372 .2564 Mdot
.05373 .25639 Mdot
.05374 .25637 Mdot
.05375 .25636 Mdot
.05376 .25634 Mdot
.05377 .25632 Mdot
.05378 .25631 Mdot
.05379 .25629 Mdot
.0538 .25627 Mdot
.05381 .25626 Mdot
.05382 .25624 Mdot
.05383 .25623 Mdot
.05384 .25621 Mdot
.05385 .25619 Mdot
.05386 .25618 Mdot
.05387 .25616 Mdot
.05388 .25615 Mdot
.05389 .25613 Mdot
.0539 .25611 Mdot
.0539 .2561 Mdot
.05391 .25608 Mdot
.05392 .25606 Mdot
.05393 .25605 Mdot
.05394 .25603 Mdot
.05395 .25602 Mdot
.05396 .256 Mdot
.05397 .25598 Mdot
.05398 .25597 Mdot
.05399 .25595 Mdot
.054 .25593 Mdot
.05401 .25592 Mdot
.05402 .2559 Mdot
.05403 .25589 Mdot
.05404 .25587 Mdot
.05405 .25585 Mdot
.05406 .25584 Mdot
.05407 .25582 Mdot
.05408 .2558 Mdot
.05409 .25579 Mdot
.0541 .25577 Mdot
.0541 .25576 Mdot
.05411 .25574 Mdot
.05412 .25572 Mdot
.05413 .25571 Mdot
.05414 .25569 Mdot
.05415 .25567 Mdot
.05416 .25566 Mdot
.05417 .25564 Mdot
.05418 .25563 Mdot
.05419 .25561 Mdot
.0542 .25559 Mdot
.05421 .25558 Mdot
.05422 .25556 Mdot
.05423 .25554 Mdot
.05424 .25553 Mdot
.05425 .25551 Mdot
.05426 .2555 Mdot
.05427 .25548 Mdot
.05428 .25546 Mdot
.05429 .25545 Mdot
.0543 .25543 Mdot
.0543 .25541 Mdot
.05431 .2554 Mdot
.05432 .25538 Mdot
.05433 .25537 Mdot
.05434 .25535 Mdot
.05435 .25533 Mdot
.05436 .25532 Mdot
.05437 .2553 Mdot
.05438 .25528 Mdot
.05439 .25527 Mdot
.0544 .25525 Mdot
.05441 .25524 Mdot
.05442 .25522 Mdot
.05443 .2552 Mdot
.05444 .25519 Mdot
.05445 .25517 Mdot
.05446 .25516 Mdot
.05447 .25514 Mdot
.05448 .25512 Mdot
.05449 .25511 Mdot
.0545 .25509 Mdot
.0545 .25507 Mdot
.05451 .25506 Mdot
.05452 .25504 Mdot
.05453 .25503 Mdot
.05454 .25501 Mdot
.05455 .25499 Mdot
.05456 .25498 Mdot
.05457 .25496 Mdot
.05458 .25494 Mdot
.05459 .25493 Mdot
.0546 .25491 Mdot
.05461 .2549 Mdot
.05462 .25488 Mdot
.05463 .25486 Mdot
.05464 .25485 Mdot
.05465 .25483 Mdot
.05466 .25481 Mdot
.05467 .2548 Mdot
.05468 .25478 Mdot
.05469 .25477 Mdot
.0547 .25475 Mdot
.0547 .25473 Mdot
.05471 .25472 Mdot
.05472 .2547 Mdot
.05473 .25468 Mdot
.05474 .25467 Mdot
.05475 .25465 Mdot
.05476 .25464 Mdot
.05477 .25462 Mdot
.05478 .2546 Mdot
.05479 .25459 Mdot
.0548 .25457 Mdot
.05481 .25456 Mdot
.05482 .25454 Mdot
.05483 .25452 Mdot
.05484 .25451 Mdot
.05485 .25449 Mdot
.05486 .25447 Mdot
.05487 .25446 Mdot
.05488 .25444 Mdot
.05489 .25443 Mdot
.0549 .25441 Mdot
.0549 .25439 Mdot
.05491 .25438 Mdot
.05492 .25436 Mdot
.05493 .25434 Mdot
.05494 .25433 Mdot
.05495 .25431 Mdot
.05496 .2543 Mdot
.05497 .25428 Mdot
.05498 .25426 Mdot
.05499 .25425 Mdot
.055 .25423 Mdot
.05501 .25421 Mdot
.05502 .2542 Mdot
.05503 .25418 Mdot
.05504 .25417 Mdot
.05505 .25415 Mdot
.05506 .25413 Mdot
.05507 .25412 Mdot
.05508 .2541 Mdot
.05509 .25408 Mdot
.0551 .25407 Mdot
.0551 .25405 Mdot
.05511 .25404 Mdot
.05512 .25402 Mdot
.05513 .254 Mdot
.05514 .25399 Mdot
.05515 .25397 Mdot
.05516 .25396 Mdot
.05517 .25394 Mdot
.05518 .25392 Mdot
.05519 .25391 Mdot
.0552 .25389 Mdot
.05521 .25387 Mdot
.05522 .25386 Mdot
.05523 .25384 Mdot
.05524 .25383 Mdot
.05525 .25381 Mdot
.05526 .25379 Mdot
.05527 .25378 Mdot
.05528 .25376 Mdot
.05529 .25374 Mdot
.0553 .25373 Mdot
.0553 .25371 Mdot
.05531 .2537 Mdot
.05532 .25368 Mdot
.05533 .25366 Mdot
.05534 .25365 Mdot
.05535 .25363 Mdot
.05536 .25361 Mdot
.05537 .2536 Mdot
.05538 .25358 Mdot
.05539 .25357 Mdot
.0554 .25355 Mdot
.05541 .25353 Mdot
.05542 .25352 Mdot
.05543 .2535 Mdot
.05544 .25349 Mdot
.05545 .25347 Mdot
.05546 .25345 Mdot
.05547 .25344 Mdot
.05548 .25342 Mdot
.05549 .2534 Mdot
.0555 .25339 Mdot
.0555 .25337 Mdot
.05551 .25336 Mdot
.05552 .25334 Mdot
.05553 .25332 Mdot
.05554 .25331 Mdot
.05555 .25329 Mdot
.05556 .25327 Mdot
.05557 .25326 Mdot
.05558 .25324 Mdot
.05559 .25323 Mdot
.0556 .25321 Mdot
.05561 .25319 Mdot
.05562 .25318 Mdot
.05563 .25316 Mdot
.05564 .25314 Mdot
.05565 .25313 Mdot
.05566 .25311 Mdot
.05567 .2531 Mdot
.05568 .25308 Mdot
.05569 .25306 Mdot
.0557 .25305 Mdot
.0557 .25303 Mdot
.05571 .25302 Mdot
.05572 .253 Mdot
.05573 .25298 Mdot
.05574 .25297 Mdot
.05575 .25295 Mdot
.05576 .25293 Mdot
.05577 .25292 Mdot
.05578 .2529 Mdot
.05579 .25289 Mdot
.0558 .25287 Mdot
.05581 .25285 Mdot
.05582 .25284 Mdot
.05583 .25282 Mdot
.05584 .2528 Mdot
.05585 .25279 Mdot
.05586 .25277 Mdot
.05587 .25276 Mdot
.05588 .25274 Mdot
.05589 .25272 Mdot
.0559 .25271 Mdot
.0559 .25269 Mdot
.05591 .25267 Mdot
.05592 .25266 Mdot
.05593 .25264 Mdot
.05594 .25263 Mdot
.05595 .25261 Mdot
.05596 .25259 Mdot
.05597 .25258 Mdot
.05598 .25256 Mdot
.05599 .25255 Mdot
.056 .25253 Mdot
.05601 .25251 Mdot
.05602 .2525 Mdot
.05603 .25248 Mdot
.05604 .25246 Mdot
.05605 .25245 Mdot
.05606 .25243 Mdot
.05607 .25242 Mdot
.05608 .2524 Mdot
.05609 .25238 Mdot
.0561 .25237 Mdot
.0561 .25235 Mdot
.05611 .25233 Mdot
.05612 .25232 Mdot
.05613 .2523 Mdot
.05614 .25229 Mdot
.05615 .25227 Mdot
.05616 .25225 Mdot
.05617 .25224 Mdot
.05618 .25222 Mdot
.05619 .25221 Mdot
.0562 .25219 Mdot
.05621 .25217 Mdot
.05622 .25216 Mdot
.05623 .25214 Mdot
.05624 .25212 Mdot
.05625 .25211 Mdot
.05626 .25209 Mdot
.05627 .25208 Mdot
.05628 .25206 Mdot
.05629 .25204 Mdot
.0563 .25203 Mdot
.0563 .25201 Mdot
.05631 .25199 Mdot
.05632 .25198 Mdot
.05633 .25196 Mdot
.05634 .25195 Mdot
.05635 .25193 Mdot
.05636 .25191 Mdot
.05637 .2519 Mdot
.05638 .25188 Mdot
.05639 .25187 Mdot
.0564 .25185 Mdot
.05641 .25183 Mdot
.05642 .25182 Mdot
.05643 .2518 Mdot
.05644 .25178 Mdot
.05645 .25177 Mdot
.05646 .25175 Mdot
.05647 .25174 Mdot
.05648 .25172 Mdot
.05649 .2517 Mdot
.0565 .25169 Mdot
.0565 .25167 Mdot
.05651 .25165 Mdot
.05652 .25164 Mdot
.05653 .25162 Mdot
.05654 .25161 Mdot
.05655 .25159 Mdot
.05656 .25157 Mdot
.05657 .25156 Mdot
.05658 .25154 Mdot
.05659 .25153 Mdot
.0566 .25151 Mdot
.05661 .25149 Mdot
.05662 .25148 Mdot
.05663 .25146 Mdot
.05664 .25144 Mdot
.05665 .25143 Mdot
.05666 .25141 Mdot
.05667 .2514 Mdot
.05668 .25138 Mdot
.05669 .25136 Mdot
.0567 .25135 Mdot
.0567 .25133 Mdot
.05671 .25131 Mdot
.05672 .2513 Mdot
.05673 .25128 Mdot
.05674 .25127 Mdot
.05675 .25125 Mdot
.05676 .25123 Mdot
.05677 .25122 Mdot
.05678 .2512 Mdot
.05679 .25119 Mdot
.0568 .25117 Mdot
.05681 .25115 Mdot
.05682 .25114 Mdot
.05683 .25112 Mdot
.05684 .2511 Mdot
.05685 .25109 Mdot
.05686 .25107 Mdot
.05687 .25106 Mdot
.05688 .25104 Mdot
.05689 .25102 Mdot
.0569 .25101 Mdot
.0569 .25099 Mdot
.05691 .25098 Mdot
.05692 .25096 Mdot
.05693 .25094 Mdot
.05694 .25093 Mdot
.05695 .25091 Mdot
.05696 .25089 Mdot
.05697 .25088 Mdot
.05698 .25086 Mdot
.05699 .25085 Mdot
.057 .25083 Mdot
.05701 .25081 Mdot
.05702 .2508 Mdot
.05703 .25078 Mdot
.05704 .25076 Mdot
.05705 .25075 Mdot
.05706 .25073 Mdot
.05707 .25072 Mdot
.05708 .2507 Mdot
.05709 .25068 Mdot
.0571 .25067 Mdot
.0571 .25065 Mdot
.05711 .25064 Mdot
.05712 .25062 Mdot
.05713 .2506 Mdot
.05714 .25059 Mdot
.05715 .25057 Mdot
.05716 .25055 Mdot
.05717 .25054 Mdot
.05718 .25052 Mdot
.05719 .25051 Mdot
.0572 .25049 Mdot
.05721 .25047 Mdot
.05722 .25046 Mdot
.05723 .25044 Mdot
.05724 .25042 Mdot
.05725 .25041 Mdot
.05726 .25039 Mdot
.05727 .25038 Mdot
.05728 .25036 Mdot
.05729 .25034 Mdot
.0573 .25033 Mdot
.0573 .25031 Mdot
.05731 .2503 Mdot
.05732 .25028 Mdot
.05733 .25026 Mdot
.05734 .25025 Mdot
.05735 .25023 Mdot
.05736 .25021 Mdot
.05737 .2502 Mdot
.05738 .25018 Mdot
.05739 .25017 Mdot
.0574 .25015 Mdot
.05741 .25013 Mdot
.05742 .25012 Mdot
.05743 .2501 Mdot
.05744 .25009 Mdot
.05745 .25007 Mdot
.05746 .25005 Mdot
.05747 .25004 Mdot
.05748 .25002 Mdot
.05749 .25 Mdot
.0575 .24999 Mdot
.0575 .24997 Mdot
.05751 .24996 Mdot
.05752 .24994 Mdot
.05753 .24992 Mdot
.05754 .24991 Mdot
.05755 .24989 Mdot
.05756 .24988 Mdot
.05757 .24986 Mdot
.05758 .24984 Mdot
.05759 .24983 Mdot
.0576 .24981 Mdot
.05761 .24979 Mdot
.05762 .24978 Mdot
.05763 .24976 Mdot
.05764 .24975 Mdot
.05765 .24973 Mdot
.05766 .24971 Mdot
.05767 .2497 Mdot
.05768 .24968 Mdot
.05769 .24966 Mdot
.0577 .24965 Mdot
.0577 .24963 Mdot
.05771 .24962 Mdot
.05772 .2496 Mdot
.05773 .24958 Mdot
.05774 .24957 Mdot
.05775 .24955 Mdot
.05776 .24954 Mdot
.05777 .24952 Mdot
.05778 .2495 Mdot
.05779 .24949 Mdot
.0578 .24947 Mdot
.05781 .24945 Mdot
.05782 .24944 Mdot
.05783 .24942 Mdot
.05784 .24941 Mdot
.05785 .24939 Mdot
.05786 .24937 Mdot
.05787 .24936 Mdot
.05788 .24934 Mdot
.05789 .24933 Mdot
.0579 .24931 Mdot
.0579 .24929 Mdot
.05791 .24928 Mdot
.05792 .24926 Mdot
.05793 .24924 Mdot
.05794 .24923 Mdot
.05795 .24921 Mdot
.05796 .2492 Mdot
.05797 .24918 Mdot
.05798 .24916 Mdot
.05799 .24915 Mdot
.058 .24913 Mdot
.05801 .24912 Mdot
.05802 .2491 Mdot
.05803 .24908 Mdot
.05804 .24907 Mdot
.05805 .24905 Mdot
.05806 .24903 Mdot
.05807 .24902 Mdot
.05808 .249 Mdot
.05809 .24899 Mdot
.0581 .24897 Mdot
.0581 .24895 Mdot
.05811 .24894 Mdot
.05812 .24892 Mdot
.05813 .24891 Mdot
.05814 .24889 Mdot
.05815 .24887 Mdot
.05816 .24886 Mdot
.05817 .24884 Mdot
.05818 .24882 Mdot
.05819 .24881 Mdot
.0582 .24879 Mdot
.05821 .24878 Mdot
.05822 .24876 Mdot
.05823 .24874 Mdot
.05824 .24873 Mdot
.05825 .24871 Mdot
.05826 .2487 Mdot
.05827 .24868 Mdot
.05828 .24866 Mdot
.05829 .24865 Mdot
.0583 .24863 Mdot
.0583 .24861 Mdot
.05831 .2486 Mdot
.05832 .24858 Mdot
.05833 .24857 Mdot
.05834 .24855 Mdot
.05835 .24853 Mdot
.05836 .24852 Mdot
.05837 .2485 Mdot
.05838 .24849 Mdot
.05839 .24847 Mdot
.0584 .24845 Mdot
.05841 .24844 Mdot
.05842 .24842 Mdot
.05843 .2484 Mdot
.05844 .24839 Mdot
.05845 .24837 Mdot
.05846 .24836 Mdot
.05847 .24834 Mdot
.05848 .24832 Mdot
.05849 .24831 Mdot
.0585 .24829 Mdot
.0585 .24828 Mdot
.05851 .24826 Mdot
.05852 .24824 Mdot
.05853 .24823 Mdot
.05854 .24821 Mdot
.05855 .24819 Mdot
.05856 .24818 Mdot
.05857 .24816 Mdot
.05858 .24815 Mdot
.05859 .24813 Mdot
.0586 .24811 Mdot
.05861 .2481 Mdot
.05862 .24808 Mdot
.05863 .24807 Mdot
.05864 .24805 Mdot
.05865 .24803 Mdot
.05866 .24802 Mdot
.05867 .248 Mdot
.05868 .24798 Mdot
.05869 .24797 Mdot
.0587 .24795 Mdot
.0587 .24794 Mdot
.05871 .24792 Mdot
.05872 .2479 Mdot
.05873 .24789 Mdot
.05874 .24787 Mdot
.05875 .24786 Mdot
.05876 .24784 Mdot
.05877 .24782 Mdot
.05878 .24781 Mdot
.05879 .24779 Mdot
.0588 .24777 Mdot
.05881 .24776 Mdot
.05882 .24774 Mdot
.05883 .24773 Mdot
.05884 .24771 Mdot
.05885 .24769 Mdot
.05886 .24768 Mdot
.05887 .24766 Mdot
.05888 .24765 Mdot
.05889 .24763 Mdot
.0589 .24761 Mdot
.0589 .2476 Mdot
.05891 .24758 Mdot
.05892 .24756 Mdot
.05893 .24755 Mdot
.05894 .24753 Mdot
.05895 .24752 Mdot
.05896 .2475 Mdot
.05897 .24748 Mdot
.05898 .24747 Mdot
.05899 .24745 Mdot
.059 .24744 Mdot
.05901 .24742 Mdot
.05902 .2474 Mdot
.05903 .24739 Mdot
.05904 .24737 Mdot
.05905 .24735 Mdot
.05906 .24734 Mdot
.05907 .24732 Mdot
.05908 .24731 Mdot
.05909 .24729 Mdot
.0591 .24727 Mdot
.0591 .24726 Mdot
.05911 .24724 Mdot
.05912 .24723 Mdot
.05913 .24721 Mdot
.05914 .24719 Mdot
.05915 .24718 Mdot
.05916 .24716 Mdot
.05917 .24715 Mdot
.05918 .24713 Mdot
.05919 .24711 Mdot
.0592 .2471 Mdot
.05921 .24708 Mdot
.05922 .24706 Mdot
.05923 .24705 Mdot
.05924 .24703 Mdot
.05925 .24702 Mdot
.05926 .247 Mdot
.05927 .24698 Mdot
.05928 .24697 Mdot
.05929 .24695 Mdot
.0593 .24694 Mdot
.0593 .24692 Mdot
.05931 .2469 Mdot
.05932 .24689 Mdot
.05933 .24687 Mdot
.05934 .24685 Mdot
.05935 .24684 Mdot
.05936 .24682 Mdot
.05937 .24681 Mdot
.05938 .24679 Mdot
.05939 .24677 Mdot
.0594 .24676 Mdot
.05941 .24674 Mdot
.05942 .24673 Mdot
.05943 .24671 Mdot
.05944 .24669 Mdot
.05945 .24668 Mdot
.05946 .24666 Mdot
.05947 .24664 Mdot
.05948 .24663 Mdot
.05949 .24661 Mdot
.0595 .2466 Mdot
.0595 .24658 Mdot
.05951 .24656 Mdot
.05952 .24655 Mdot
.05953 .24653 Mdot
.05954 .24652 Mdot
.05955 .2465 Mdot
.05956 .24648 Mdot
.05957 .24647 Mdot
.05958 .24645 Mdot
.05959 .24644 Mdot
.0596 .24642 Mdot
.05961 .2464 Mdot
.05962 .24639 Mdot
.05963 .24637 Mdot
.05964 .24635 Mdot
.05965 .24634 Mdot
.05966 .24632 Mdot
.05967 .24631 Mdot
.05968 .24629 Mdot
.05969 .24627 Mdot
.0597 .24626 Mdot
.0597 .24624 Mdot
.05971 .24623 Mdot
.05972 .24621 Mdot
.05973 .24619 Mdot
.05974 .24618 Mdot
.05975 .24616 Mdot
.05976 .24614 Mdot
.05977 .24613 Mdot
.05978 .24611 Mdot
.05979 .2461 Mdot
.0598 .24608 Mdot
.05981 .24606 Mdot
.05982 .24605 Mdot
.05983 .24603 Mdot
.05984 .24602 Mdot
.05985 .246 Mdot
.05986 .24598 Mdot
.05987 .24597 Mdot
.05988 .24595 Mdot
.05989 .24594 Mdot
.0599 .24592 Mdot
.0599 .2459 Mdot
.05991 .24589 Mdot
.05992 .24587 Mdot
.05993 .24585 Mdot
.05994 .24584 Mdot
.05995 .24582 Mdot
.05996 .24581 Mdot
.05997 .24579 Mdot
.05998 .24577 Mdot
.05999 .24576 Mdot
.06 .24574 Mdot
.06001 .24573 Mdot
.06002 .24571 Mdot
.06003 .24569 Mdot
.06004 .24568 Mdot
.06005 .24566 Mdot
.06006 .24564 Mdot
.06007 .24563 Mdot
.06008 .24561 Mdot
.06009 .2456 Mdot
.0601 .24558 Mdot
.0601 .24556 Mdot
.06011 .24555 Mdot
.06012 .24553 Mdot
.06013 .24552 Mdot
.06014 .2455 Mdot
.06015 .24548 Mdot
.06016 .24547 Mdot
.06017 .24545 Mdot
.06018 .24544 Mdot
.06019 .24542 Mdot
.0602 .2454 Mdot
.06021 .24539 Mdot
.06022 .24537 Mdot
.06023 .24535 Mdot
.06024 .24534 Mdot
.06025 .24532 Mdot
.06026 .24531 Mdot
.06027 .24529 Mdot
.06028 .24527 Mdot
.06029 .24526 Mdot
.0603 .24524 Mdot
.0603 .24523 Mdot
.06031 .24521 Mdot
.06032 .24519 Mdot
.06033 .24518 Mdot
.06034 .24516 Mdot
.06035 .24515 Mdot
.06036 .24513 Mdot
.06037 .24511 Mdot
.06038 .2451 Mdot
.06039 .24508 Mdot
.0604 .24506 Mdot
.06041 .24505 Mdot
.06042 .24503 Mdot
.06043 .24502 Mdot
.06044 .245 Mdot
.06045 .24498 Mdot
.06046 .24497 Mdot
.06047 .24495 Mdot
.06048 .24494 Mdot
.06049 .24492 Mdot
.0605 .2449 Mdot
.0605 .24489 Mdot
.06051 .24487 Mdot
.06052 .24486 Mdot
.06053 .24484 Mdot
.06054 .24482 Mdot
.06055 .24481 Mdot
.06056 .24479 Mdot
.06057 .24477 Mdot
.06058 .24476 Mdot
.06059 .24474 Mdot
.0606 .24473 Mdot
.06061 .24471 Mdot
.06062 .24469 Mdot
.06063 .24468 Mdot
.06064 .24466 Mdot
.06065 .24465 Mdot
.06066 .24463 Mdot
.06067 .24461 Mdot
.06068 .2446 Mdot
.06069 .24458 Mdot
.0607 .24457 Mdot
.0607 .24455 Mdot
.06071 .24453 Mdot
.06072 .24452 Mdot
.06073 .2445 Mdot
.06074 .24448 Mdot
.06075 .24447 Mdot
.06076 .24445 Mdot
.06077 .24444 Mdot
.06078 .24442 Mdot
.06079 .2444 Mdot
.0608 .24439 Mdot
.06081 .24437 Mdot
.06082 .24436 Mdot
.06083 .24434 Mdot
.06084 .24432 Mdot
.06085 .24431 Mdot
.06086 .24429 Mdot
.06087 .24428 Mdot
.06088 .24426 Mdot
.06089 .24424 Mdot
.0609 .24423 Mdot
.0609 .24421 Mdot
.06091 .24419 Mdot
.06092 .24418 Mdot
.06093 .24416 Mdot
.06094 .24415 Mdot
.06095 .24413 Mdot
.06096 .24411 Mdot
.06097 .2441 Mdot
.06098 .24408 Mdot
.06099 .24407 Mdot
.061 .24405 Mdot
.06101 .24403 Mdot
.06102 .24402 Mdot
.06103 .244 Mdot
.06104 .24399 Mdot
.06105 .24397 Mdot
.06106 .24395 Mdot
.06107 .24394 Mdot
.06108 .24392 Mdot
.06109 .2439 Mdot
.0611 .24389 Mdot
.0611 .24387 Mdot
.06111 .24386 Mdot
.06112 .24384 Mdot
.06113 .24382 Mdot
.06114 .24381 Mdot
.06115 .24379 Mdot
.06116 .24378 Mdot
.06117 .24376 Mdot
.06118 .24374 Mdot
.06119 .24373 Mdot
.0612 .24371 Mdot
.06121 .2437 Mdot
.06122 .24368 Mdot
.06123 .24366 Mdot
.06124 .24365 Mdot
.06125 .24363 Mdot
.06126 .24362 Mdot
.06127 .2436 Mdot
.06128 .24358 Mdot
.06129 .24357 Mdot
.0613 .24355 Mdot
.0613 .24353 Mdot
.06131 .24352 Mdot
.06132 .2435 Mdot
.06133 .24349 Mdot
.06134 .24347 Mdot
.06135 .24345 Mdot
.06136 .24344 Mdot
.06137 .24342 Mdot
.06138 .24341 Mdot
.06139 .24339 Mdot
.0614 .24337 Mdot
.06141 .24336 Mdot
.06142 .24334 Mdot
.06143 .24333 Mdot
.06144 .24331 Mdot
.06145 .24329 Mdot
.06146 .24328 Mdot
.06147 .24326 Mdot
.06148 .24324 Mdot
.06149 .24323 Mdot
.0615 .24321 Mdot
.0615 .2432 Mdot
.06151 .24318 Mdot
.06152 .24316 Mdot
.06153 .24315 Mdot
.06154 .24313 Mdot
.06155 .24312 Mdot
.06156 .2431 Mdot
.06157 .24308 Mdot
.06158 .24307 Mdot
.06159 .24305 Mdot
.0616 .24304 Mdot
.06161 .24302 Mdot
.06162 .243 Mdot
.06163 .24299 Mdot
.06164 .24297 Mdot
.06165 .24296 Mdot
.06166 .24294 Mdot
.06167 .24292 Mdot
.06168 .24291 Mdot
.06169 .24289 Mdot
.0617 .24287 Mdot
.0617 .24286 Mdot
.06171 .24284 Mdot
.06172 .24283 Mdot
.06173 .24281 Mdot
.06174 .24279 Mdot
.06175 .24278 Mdot
.06176 .24276 Mdot
.06177 .24275 Mdot
.06178 .24273 Mdot
.06179 .24271 Mdot
.0618 .2427 Mdot
.06181 .24268 Mdot
.06182 .24267 Mdot
.06183 .24265 Mdot
.06184 .24263 Mdot
.06185 .24262 Mdot
.06186 .2426 Mdot
.06187 .24259 Mdot
.06188 .24257 Mdot
.06189 .24255 Mdot
.0619 .24254 Mdot
.0619 .24252 Mdot
.06191 .2425 Mdot
.06192 .24249 Mdot
.06193 .24247 Mdot
.06194 .24246 Mdot
.06195 .24244 Mdot
.06196 .24242 Mdot
.06197 .24241 Mdot
.06198 .24239 Mdot
.06199 .24238 Mdot
.062 .24236 Mdot
.06201 .24234 Mdot
.06202 .24233 Mdot
.06203 .24231 Mdot
.06204 .2423 Mdot
.06205 .24228 Mdot
.06206 .24226 Mdot
.06207 .24225 Mdot
.06208 .24223 Mdot
.06209 .24222 Mdot
.0621 .2422 Mdot
.0621 .24218 Mdot
.06211 .24217 Mdot
.06212 .24215 Mdot
.06213 .24213 Mdot
.06214 .24212 Mdot
.06215 .2421 Mdot
.06216 .24209 Mdot
.06217 .24207 Mdot
.06218 .24205 Mdot
.06219 .24204 Mdot
.0622 .24202 Mdot
.06221 .24201 Mdot
.06222 .24199 Mdot
.06223 .24197 Mdot
.06224 .24196 Mdot
.06225 .24194 Mdot
.06226 .24193 Mdot
.06227 .24191 Mdot
.06228 .24189 Mdot
.06229 .24188 Mdot
.0623 .24186 Mdot
.0623 .24185 Mdot
.06231 .24183 Mdot
.06232 .24181 Mdot
.06233 .2418 Mdot
.06234 .24178 Mdot
.06235 .24177 Mdot
.06236 .24175 Mdot
.06237 .24173 Mdot
.06238 .24172 Mdot
.06239 .2417 Mdot
.0624 .24168 Mdot
.06241 .24167 Mdot
.06242 .24165 Mdot
.06243 .24164 Mdot
.06244 .24162 Mdot
.06245 .2416 Mdot
.06246 .24159 Mdot
.06247 .24157 Mdot
.06248 .24156 Mdot
.06249 .24154 Mdot
.0625 .24152 Mdot
.0625 .24151 Mdot
.06251 .24149 Mdot
.06252 .24148 Mdot
.06253 .24146 Mdot
.06254 .24144 Mdot
.06255 .24143 Mdot
.06256 .24141 Mdot
.06257 .2414 Mdot
.06258 .24138 Mdot
.06259 .24136 Mdot
.0626 .24135 Mdot
.06261 .24133 Mdot
.06262 .24132 Mdot
.06263 .2413 Mdot
.06264 .24128 Mdot
.06265 .24127 Mdot
.06266 .24125 Mdot
.06267 .24123 Mdot
.06268 .24122 Mdot
.06269 .2412 Mdot
.0627 .24119 Mdot
.0627 .24117 Mdot
.06271 .24115 Mdot
.06272 .24114 Mdot
.06273 .24112 Mdot
.06274 .24111 Mdot
.06275 .24109 Mdot
.06276 .24107 Mdot
.06277 .24106 Mdot
.06278 .24104 Mdot
.06279 .24103 Mdot
.0628 .24101 Mdot
.06281 .24099 Mdot
.06282 .24098 Mdot
.06283 .24096 Mdot
.06284 .24095 Mdot
.06285 .24093 Mdot
.06286 .24091 Mdot
.06287 .2409 Mdot
.06288 .24088 Mdot
.06289 .24087 Mdot
.0629 .24085 Mdot
.0629 .24083 Mdot
.06291 .24082 Mdot
.06292 .2408 Mdot
.06293 .24078 Mdot
.06294 .24077 Mdot
.06295 .24075 Mdot
.06296 .24074 Mdot
.06297 .24072 Mdot
.06298 .2407 Mdot
.06299 .24069 Mdot
.063 .24067 Mdot
.06301 .24066 Mdot
.06302 .24064 Mdot
.06303 .24062 Mdot
.06304 .24061 Mdot
.06305 .24059 Mdot
.06306 .24058 Mdot
.06307 .24056 Mdot
.06308 .24054 Mdot
.06309 .24053 Mdot
.0631 .24051 Mdot
.0631 .2405 Mdot
.06311 .24048 Mdot
.06312 .24046 Mdot
.06313 .24045 Mdot
.06314 .24043 Mdot
.06315 .24042 Mdot
.06316 .2404 Mdot
.06317 .24038 Mdot
.06318 .24037 Mdot
.06319 .24035 Mdot
.0632 .24034 Mdot
.06321 .24032 Mdot
.06322 .2403 Mdot
.06323 .24029 Mdot
.06324 .24027 Mdot
.06325 .24025 Mdot
.06326 .24024 Mdot
.06327 .24022 Mdot
.06328 .24021 Mdot
.06329 .24019 Mdot
.0633 .24017 Mdot
.0633 .24016 Mdot
.06331 .24014 Mdot
.06332 .24013 Mdot
.06333 .24011 Mdot
.06334 .24009 Mdot
.06335 .24008 Mdot
.06336 .24006 Mdot
.06337 .24005 Mdot
.06338 .24003 Mdot
.06339 .24001 Mdot
.0634 .24 Mdot
.06341 .23998 Mdot
.06342 .23997 Mdot
.06343 .23995 Mdot
.06344 .23993 Mdot
.06345 .23992 Mdot
.06346 .2399 Mdot
.06347 .23989 Mdot
.06348 .23987 Mdot
.06349 .23985 Mdot
.0635 .23984 Mdot
.0635 .23982 Mdot
.06351 .23981 Mdot
.06352 .23979 Mdot
.06353 .23977 Mdot
.06354 .23976 Mdot
.06355 .23974 Mdot
.06356 .23973 Mdot
.06357 .23971 Mdot
.06358 .23969 Mdot
.06359 .23968 Mdot
.0636 .23966 Mdot
.06361 .23964 Mdot
.06362 .23963 Mdot
.06363 .23961 Mdot
.06364 .2396 Mdot
.06365 .23958 Mdot
.06366 .23956 Mdot
.06367 .23955 Mdot
.06368 .23953 Mdot
.06369 .23952 Mdot
.0637 .2395 Mdot
.0637 .23948 Mdot
.06371 .23947 Mdot
.06372 .23945 Mdot
.06373 .23944 Mdot
.06374 .23942 Mdot
.06375 .2394 Mdot
.06376 .23939 Mdot
.06377 .23937 Mdot
.06378 .23936 Mdot
.06379 .23934 Mdot
.0638 .23932 Mdot
.06381 .23931 Mdot
.06382 .23929 Mdot
.06383 .23928 Mdot
.06384 .23926 Mdot
.06385 .23924 Mdot
.06386 .23923 Mdot
.06387 .23921 Mdot
.06388 .2392 Mdot
.06389 .23918 Mdot
.0639 .23916 Mdot
.0639 .23915 Mdot
.06391 .23913 Mdot
.06392 .23912 Mdot
.06393 .2391 Mdot
.06394 .23908 Mdot
.06395 .23907 Mdot
.06396 .23905 Mdot
.06397 .23904 Mdot
.06398 .23902 Mdot
.06399 .239 Mdot
.064 .23899 Mdot
.06401 .23897 Mdot
.06402 .23895 Mdot
.06403 .23894 Mdot
.06404 .23892 Mdot
.06405 .23891 Mdot
.06406 .23889 Mdot
.06407 .23887 Mdot
.06408 .23886 Mdot
.06409 .23884 Mdot
.0641 .23883 Mdot
.0641 .23881 Mdot
.06411 .23879 Mdot
.06412 .23878 Mdot
.06413 .23876 Mdot
.06414 .23875 Mdot
.06415 .23873 Mdot
.06416 .23871 Mdot
.06417 .2387 Mdot
.06418 .23868 Mdot
.06419 .23867 Mdot
.0642 .23865 Mdot
.06421 .23863 Mdot
.06422 .23862 Mdot
.06423 .2386 Mdot
.06424 .23859 Mdot
.06425 .23857 Mdot
.06426 .23855 Mdot
.06427 .23854 Mdot
.06428 .23852 Mdot
.06429 .23851 Mdot
.0643 .23849 Mdot
.0643 .23847 Mdot
.06431 .23846 Mdot
.06432 .23844 Mdot
.06433 .23843 Mdot
.06434 .23841 Mdot
.06435 .23839 Mdot
.06436 .23838 Mdot
.06437 .23836 Mdot
.06438 .23835 Mdot
.06439 .23833 Mdot
.0644 .23831 Mdot
.06441 .2383 Mdot
.06442 .23828 Mdot
.06443 .23827 Mdot
.06444 .23825 Mdot
.06445 .23823 Mdot
.06446 .23822 Mdot
.06447 .2382 Mdot
.06448 .23819 Mdot
.06449 .23817 Mdot
.0645 .23815 Mdot
.0645 .23814 Mdot
.06451 .23812 Mdot
.06452 .23811 Mdot
.06453 .23809 Mdot
.06454 .23807 Mdot
.06455 .23806 Mdot
.06456 .23804 Mdot
.06457 .23802 Mdot
.06458 .23801 Mdot
.06459 .23799 Mdot
.0646 .23798 Mdot
.06461 .23796 Mdot
.06462 .23794 Mdot
.06463 .23793 Mdot
.06464 .23791 Mdot
.06465 .2379 Mdot
.06466 .23788 Mdot
.06467 .23786 Mdot
.06468 .23785 Mdot
.06469 .23783 Mdot
.0647 .23782 Mdot
.0647 .2378 Mdot
.06471 .23778 Mdot
.06472 .23777 Mdot
.06473 .23775 Mdot
.06474 .23774 Mdot
.06475 .23772 Mdot
.06476 .2377 Mdot
.06477 .23769 Mdot
.06478 .23767 Mdot
.06479 .23766 Mdot
.0648 .23764 Mdot
.06481 .23762 Mdot
.06482 .23761 Mdot
.06483 .23759 Mdot
.06484 .23758 Mdot
.06485 .23756 Mdot
.06486 .23754 Mdot
.06487 .23753 Mdot
.06488 .23751 Mdot
.06489 .2375 Mdot
.0649 .23748 Mdot
.0649 .23746 Mdot
.06491 .23745 Mdot
.06492 .23743 Mdot
.06493 .23742 Mdot
.06494 .2374 Mdot
.06495 .23738 Mdot
.06496 .23737 Mdot
.06497 .23735 Mdot
.06498 .23734 Mdot
.06499 .23732 Mdot
.065 .2373 Mdot
.06501 .23729 Mdot
.06502 .23727 Mdot
.06503 .23726 Mdot
.06504 .23724 Mdot
.06505 .23722 Mdot
.06506 .23721 Mdot
.06507 .23719 Mdot
.06508 .23718 Mdot
.06509 .23716 Mdot
.0651 .23714 Mdot
.0651 .23713 Mdot
.06511 .23711 Mdot
.06512 .2371 Mdot
.06513 .23708 Mdot
.06514 .23706 Mdot
.06515 .23705 Mdot
.06516 .23703 Mdot
.06517 .23702 Mdot
.06518 .237 Mdot
.06519 .23698 Mdot
.0652 .23697 Mdot
.06521 .23695 Mdot
.06522 .23694 Mdot
.06523 .23692 Mdot
.06524 .2369 Mdot
.06525 .23689 Mdot
.06526 .23687 Mdot
.06527 .23686 Mdot
.06528 .23684 Mdot
.06529 .23682 Mdot
.0653 .23681 Mdot
.0653 .23679 Mdot
.06531 .23678 Mdot
.06532 .23676 Mdot
.06533 .23674 Mdot
.06534 .23673 Mdot
.06535 .23671 Mdot
.06536 .2367 Mdot
.06537 .23668 Mdot
.06538 .23666 Mdot
.06539 .23665 Mdot
.0654 .23663 Mdot
.06541 .23662 Mdot
.06542 .2366 Mdot
.06543 .23658 Mdot
.06544 .23657 Mdot
.06545 .23655 Mdot
.06546 .23654 Mdot
.06547 .23652 Mdot
.06548 .2365 Mdot
.06549 .23649 Mdot
.0655 .23647 Mdot
.0655 .23646 Mdot
.06551 .23644 Mdot
.06552 .23642 Mdot
.06553 .23641 Mdot
.06554 .23639 Mdot
.06555 .23638 Mdot
.06556 .23636 Mdot
.06557 .23634 Mdot
.06558 .23633 Mdot
.06559 .23631 Mdot
.0656 .2363 Mdot
.06561 .23628 Mdot
.06562 .23626 Mdot
.06563 .23625 Mdot
.06564 .23623 Mdot
.06565 .23622 Mdot
.06566 .2362 Mdot
.06567 .23618 Mdot
.06568 .23617 Mdot
.06569 .23615 Mdot
.0657 .23614 Mdot
.0657 .23612 Mdot
.06571 .2361 Mdot
.06572 .23609 Mdot
.06573 .23607 Mdot
.06574 .23606 Mdot
.06575 .23604 Mdot
.06576 .23602 Mdot
.06577 .23601 Mdot
.06578 .23599 Mdot
.06579 .23598 Mdot
.0658 .23596 Mdot
.06581 .23594 Mdot
.06582 .23593 Mdot
.06583 .23591 Mdot
.06584 .2359 Mdot
.06585 .23588 Mdot
.06586 .23586 Mdot
.06587 .23585 Mdot
.06588 .23583 Mdot
.06589 .23582 Mdot
.0659 .2358 Mdot
.0659 .23578 Mdot
.06591 .23577 Mdot
.06592 .23575 Mdot
.06593 .23574 Mdot
.06594 .23572 Mdot
.06595 .2357 Mdot
.06596 .23569 Mdot
.06597 .23567 Mdot
.06598 .23566 Mdot
.06599 .23564 Mdot
.066 .23562 Mdot
.06601 .23561 Mdot
.06602 .23559 Mdot
.06603 .23558 Mdot
.06604 .23556 Mdot
.06605 .23554 Mdot
.06606 .23553 Mdot
.06607 .23551 Mdot
.06608 .2355 Mdot
.06609 .23548 Mdot
.0661 .23546 Mdot
.0661 .23545 Mdot
.06611 .23543 Mdot
.06612 .23542 Mdot
.06613 .2354 Mdot
.06614 .23538 Mdot
.06615 .23537 Mdot
.06616 .23535 Mdot
.06617 .23534 Mdot
.06618 .23532 Mdot
.06619 .2353 Mdot
.0662 .23529 Mdot
.06621 .23527 Mdot
.06622 .23526 Mdot
.06623 .23524 Mdot
.06624 .23522 Mdot
.06625 .23521 Mdot
.06626 .23519 Mdot
.06627 .23518 Mdot
.06628 .23516 Mdot
.06629 .23514 Mdot
.0663 .23513 Mdot
.0663 .23511 Mdot
.06631 .2351 Mdot
.06632 .23508 Mdot
.06633 .23506 Mdot
.06634 .23505 Mdot
.06635 .23503 Mdot
.06636 .23502 Mdot
.06637 .235 Mdot
.06638 .23498 Mdot
.06639 .23497 Mdot
.0664 .23495 Mdot
.06641 .23494 Mdot
.06642 .23492 Mdot
.06643 .2349 Mdot
.06644 .23489 Mdot
.06645 .23487 Mdot
.06646 .23486 Mdot
.06647 .23484 Mdot
.06648 .23482 Mdot
.06649 .23481 Mdot
.0665 .23479 Mdot
.0665 .23478 Mdot
.06651 .23476 Mdot
.06652 .23474 Mdot
.06653 .23473 Mdot
.06654 .23471 Mdot
.06655 .2347 Mdot
.06656 .23468 Mdot
.06657 .23466 Mdot
.06658 .23465 Mdot
.06659 .23463 Mdot
.0666 .23462 Mdot
.06661 .2346 Mdot
.06662 .23458 Mdot
.06663 .23457 Mdot
.06664 .23455 Mdot
.06665 .23454 Mdot
.06666 .23452 Mdot
.06667 .2345 Mdot
.06668 .23449 Mdot
.06669 .23447 Mdot
.0667 .23446 Mdot
.0667 .23444 Mdot
.06671 .23442 Mdot
.06672 .23441 Mdot
.06673 .23439 Mdot
.06674 .23438 Mdot
.06675 .23436 Mdot
.06676 .23434 Mdot
.06677 .23433 Mdot
.06678 .23431 Mdot
.06679 .2343 Mdot
.0668 .23428 Mdot
.06681 .23426 Mdot
.06682 .23425 Mdot
.06683 .23423 Mdot
.06684 .23422 Mdot
.06685 .2342 Mdot
.06686 .23418 Mdot
.06687 .23417 Mdot
.06688 .23415 Mdot
.06689 .23414 Mdot
.0669 .23412 Mdot
.0669 .2341 Mdot
.06691 .23409 Mdot
.06692 .23407 Mdot
.06693 .23406 Mdot
.06694 .23404 Mdot
.06695 .23402 Mdot
.06696 .23401 Mdot
.06697 .23399 Mdot
.06698 .23398 Mdot
.06699 .23396 Mdot
.067 .23394 Mdot
.06701 .23393 Mdot
.06702 .23391 Mdot
.06703 .2339 Mdot
.06704 .23388 Mdot
.06705 .23386 Mdot
.06706 .23385 Mdot
.06707 .23383 Mdot
.06708 .23382 Mdot
.06709 .2338 Mdot
.0671 .23379 Mdot
.0671 .23377 Mdot
.06711 .23375 Mdot
.06712 .23374 Mdot
.06713 .23372 Mdot
.06714 .23371 Mdot
.06715 .23369 Mdot
.06716 .23367 Mdot
.06717 .23366 Mdot
.06718 .23364 Mdot
.06719 .23363 Mdot
.0672 .23361 Mdot
.06721 .23359 Mdot
.06722 .23358 Mdot
.06723 .23356 Mdot
.06724 .23355 Mdot
.06725 .23353 Mdot
.06726 .23351 Mdot
.06727 .2335 Mdot
.06728 .23348 Mdot
.06729 .23347 Mdot
.0673 .23345 Mdot
.0673 .23343 Mdot
.06731 .23342 Mdot
.06732 .2334 Mdot
.06733 .23339 Mdot
.06734 .23337 Mdot
.06735 .23335 Mdot
.06736 .23334 Mdot
.06737 .23332 Mdot
.06738 .23331 Mdot
.06739 .23329 Mdot
.0674 .23327 Mdot
.06741 .23326 Mdot
.06742 .23324 Mdot
.06743 .23323 Mdot
.06744 .23321 Mdot
.06745 .23319 Mdot
.06746 .23318 Mdot
.06747 .23316 Mdot
.06748 .23315 Mdot
.06749 .23313 Mdot
.0675 .23311 Mdot
.0675 .2331 Mdot
.06751 .23308 Mdot
.06752 .23307 Mdot
.06753 .23305 Mdot
.06754 .23303 Mdot
.06755 .23302 Mdot
.06756 .233 Mdot
.06757 .23299 Mdot
.06758 .23297 Mdot
.06759 .23295 Mdot
.0676 .23294 Mdot
.06761 .23292 Mdot
.06762 .23291 Mdot
.06763 .23289 Mdot
.06764 .23288 Mdot
.06765 .23286 Mdot
.06766 .23284 Mdot
.06767 .23283 Mdot
.06768 .23281 Mdot
.06769 .2328 Mdot
.0677 .23278 Mdot
.0677 .23276 Mdot
.06771 .23275 Mdot
.06772 .23273 Mdot
.06773 .23272 Mdot
.06774 .2327 Mdot
.06775 .23268 Mdot
.06776 .23267 Mdot
.06777 .23265 Mdot
.06778 .23264 Mdot
.06779 .23262 Mdot
.0678 .2326 Mdot
.06781 .23259 Mdot
.06782 .23257 Mdot
.06783 .23256 Mdot
.06784 .23254 Mdot
.06785 .23252 Mdot
.06786 .23251 Mdot
.06787 .23249 Mdot
.06788 .23248 Mdot
.06789 .23246 Mdot
.0679 .23244 Mdot
.0679 .23243 Mdot
.06791 .23241 Mdot
.06792 .2324 Mdot
.06793 .23238 Mdot
.06794 .23236 Mdot
.06795 .23235 Mdot
.06796 .23233 Mdot
.06797 .23232 Mdot
.06798 .2323 Mdot
.06799 .23228 Mdot
.068 .23227 Mdot
.06801 .23225 Mdot
.06802 .23224 Mdot
.06803 .23222 Mdot
.06804 .23221 Mdot
.06805 .23219 Mdot
.06806 .23217 Mdot
.06807 .23216 Mdot
.06808 .23214 Mdot
.06809 .23213 Mdot
.0681 .23211 Mdot
.0681 .23209 Mdot
.06811 .23208 Mdot
.06812 .23206 Mdot
.06813 .23205 Mdot
.06814 .23203 Mdot
.06815 .23201 Mdot
.06816 .232 Mdot
.06817 .23198 Mdot
.06818 .23197 Mdot
.06819 .23195 Mdot
.0682 .23193 Mdot
.06821 .23192 Mdot
.06822 .2319 Mdot
.06823 .23189 Mdot
.06824 .23187 Mdot
.06825 .23185 Mdot
.06826 .23184 Mdot
.06827 .23182 Mdot
.06828 .23181 Mdot
.06829 .23179 Mdot
.0683 .23177 Mdot
.0683 .23176 Mdot
.06831 .23174 Mdot
.06832 .23173 Mdot
.06833 .23171 Mdot
.06834 .23169 Mdot
.06835 .23168 Mdot
.06836 .23166 Mdot
.06837 .23165 Mdot
.06838 .23163 Mdot
.06839 .23162 Mdot
.0684 .2316 Mdot
.06841 .23158 Mdot
.06842 .23157 Mdot
.06843 .23155 Mdot
.06844 .23154 Mdot
.06845 .23152 Mdot
.06846 .2315 Mdot
.06847 .23149 Mdot
.06848 .23147 Mdot
.06849 .23146 Mdot
.0685 .23144 Mdot
.0685 .23142 Mdot
.06851 .23141 Mdot
.06852 .23139 Mdot
.06853 .23138 Mdot
.06854 .23136 Mdot
.06855 .23134 Mdot
.06856 .23133 Mdot
.06857 .23131 Mdot
.06858 .2313 Mdot
.06859 .23128 Mdot
.0686 .23126 Mdot
.06861 .23125 Mdot
.06862 .23123 Mdot
.06863 .23122 Mdot
.06864 .2312 Mdot
.06865 .23118 Mdot
.06866 .23117 Mdot
.06867 .23115 Mdot
.06868 .23114 Mdot
.06869 .23112 Mdot
.0687 .23111 Mdot
.0687 .23109 Mdot
.06871 .23107 Mdot
.06872 .23106 Mdot
.06873 .23104 Mdot
.06874 .23103 Mdot
.06875 .23101 Mdot
.06876 .23099 Mdot
.06877 .23098 Mdot
.06878 .23096 Mdot
.06879 .23095 Mdot
.0688 .23093 Mdot
.06881 .23091 Mdot
.06882 .2309 Mdot
.06883 .23088 Mdot
.06884 .23087 Mdot
.06885 .23085 Mdot
.06886 .23083 Mdot
.06887 .23082 Mdot
.06888 .2308 Mdot
.06889 .23079 Mdot
.0689 .23077 Mdot
.0689 .23075 Mdot
.06891 .23074 Mdot
.06892 .23072 Mdot
.06893 .23071 Mdot
.06894 .23069 Mdot
.06895 .23068 Mdot
.06896 .23066 Mdot
.06897 .23064 Mdot
.06898 .23063 Mdot
.06899 .23061 Mdot
.069 .2306 Mdot
.06901 .23058 Mdot
.06902 .23056 Mdot
.06903 .23055 Mdot
.06904 .23053 Mdot
.06905 .23052 Mdot
.06906 .2305 Mdot
.06907 .23048 Mdot
.06908 .23047 Mdot
.06909 .23045 Mdot
.0691 .23044 Mdot
.0691 .23042 Mdot
.06911 .2304 Mdot
.06912 .23039 Mdot
.06913 .23037 Mdot
.06914 .23036 Mdot
.06915 .23034 Mdot
.06916 .23032 Mdot
.06917 .23031 Mdot
.06918 .23029 Mdot
.06919 .23028 Mdot
.0692 .23026 Mdot
.06921 .23025 Mdot
.06922 .23023 Mdot
.06923 .23021 Mdot
.06924 .2302 Mdot
.06925 .23018 Mdot
.06926 .23017 Mdot
.06927 .23015 Mdot
.06928 .23013 Mdot
.06929 .23012 Mdot
.0693 .2301 Mdot
.0693 .23009 Mdot
.06931 .23007 Mdot
.06932 .23005 Mdot
.06933 .23004 Mdot
.06934 .23002 Mdot
.06935 .23001 Mdot
.06936 .22999 Mdot
.06937 .22997 Mdot
.06938 .22996 Mdot
.06939 .22994 Mdot
.0694 .22993 Mdot
.06941 .22991 Mdot
.06942 .22989 Mdot
.06943 .22988 Mdot
.06944 .22986 Mdot
.06945 .22985 Mdot
.06946 .22983 Mdot
.06947 .22982 Mdot
.06948 .2298 Mdot
.06949 .22978 Mdot
.0695 .22977 Mdot
.0695 .22975 Mdot
.06951 .22974 Mdot
.06952 .22972 Mdot
.06953 .2297 Mdot
.06954 .22969 Mdot
.06955 .22967 Mdot
.06956 .22966 Mdot
.06957 .22964 Mdot
.06958 .22962 Mdot
.06959 .22961 Mdot
.0696 .22959 Mdot
.06961 .22958 Mdot
.06962 .22956 Mdot
.06963 .22954 Mdot
.06964 .22953 Mdot
.06965 .22951 Mdot
.06966 .2295 Mdot
.06967 .22948 Mdot
.06968 .22947 Mdot
.06969 .22945 Mdot
.0697 .22943 Mdot
.0697 .22942 Mdot
.06971 .2294 Mdot
.06972 .22939 Mdot
.06973 .22937 Mdot
.06974 .22935 Mdot
.06975 .22934 Mdot
.06976 .22932 Mdot
.06977 .22931 Mdot
.06978 .22929 Mdot
.06979 .22927 Mdot
.0698 .22926 Mdot
.06981 .22924 Mdot
.06982 .22923 Mdot
.06983 .22921 Mdot
.06984 .22919 Mdot
.06985 .22918 Mdot
.06986 .22916 Mdot
.06987 .22915 Mdot
.06988 .22913 Mdot
.06989 .22912 Mdot
.0699 .2291 Mdot
.0699 .22908 Mdot
.06991 .22907 Mdot
.06992 .22905 Mdot
.06993 .22904 Mdot
.06994 .22902 Mdot
.06995 .229 Mdot
.06996 .22899 Mdot
.06997 .22897 Mdot
.06998 .22896 Mdot
.06999 .22894 Mdot
.07 .22892 Mdot
.07001 .22891 Mdot
.07002 .22889 Mdot
.07003 .22888 Mdot
.07004 .22886 Mdot
.07005 .22885 Mdot
.07006 .22883 Mdot
.07007 .22881 Mdot
.07008 .2288 Mdot
.07009 .22878 Mdot
.0701 .22877 Mdot
.0701 .22875 Mdot
.07011 .22873 Mdot
.07012 .22872 Mdot
.07013 .2287 Mdot
.07014 .22869 Mdot
.07015 .22867 Mdot
.07016 .22865 Mdot
.07017 .22864 Mdot
.07018 .22862 Mdot
.07019 .22861 Mdot
.0702 .22859 Mdot
.07021 .22857 Mdot
.07022 .22856 Mdot
.07023 .22854 Mdot
.07024 .22853 Mdot
.07025 .22851 Mdot
.07026 .2285 Mdot
.07027 .22848 Mdot
.07028 .22846 Mdot
.07029 .22845 Mdot
.0703 .22843 Mdot
.0703 .22842 Mdot
.07031 .2284 Mdot
.07032 .22838 Mdot
.07033 .22837 Mdot
.07034 .22835 Mdot
.07035 .22834 Mdot
.07036 .22832 Mdot
.07037 .2283 Mdot
.07038 .22829 Mdot
.07039 .22827 Mdot
.0704 .22826 Mdot
.07041 .22824 Mdot
.07042 .22823 Mdot
.07043 .22821 Mdot
.07044 .22819 Mdot
.07045 .22818 Mdot
.07046 .22816 Mdot
.07047 .22815 Mdot
.07048 .22813 Mdot
.07049 .22811 Mdot
.0705 .2281 Mdot
.0705 .22808 Mdot
.07051 .22807 Mdot
.07052 .22805 Mdot
.07053 .22803 Mdot
.07054 .22802 Mdot
.07055 .228 Mdot
.07056 .22799 Mdot
.07057 .22797 Mdot
.07058 .22796 Mdot
.07059 .22794 Mdot
.0706 .22792 Mdot
.07061 .22791 Mdot
.07062 .22789 Mdot
.07063 .22788 Mdot
.07064 .22786 Mdot
.07065 .22784 Mdot
.07066 .22783 Mdot
.07067 .22781 Mdot
.07068 .2278 Mdot
.07069 .22778 Mdot
.0707 .22776 Mdot
.0707 .22775 Mdot
.07071 .22773 Mdot
.07072 .22772 Mdot
.07073 .2277 Mdot
.07074 .22768 Mdot
.07075 .22767 Mdot
.07076 .22765 Mdot
.07077 .22764 Mdot
.07078 .22762 Mdot
.07079 .22761 Mdot
.0708 .22759 Mdot
.07081 .22757 Mdot
.07082 .22756 Mdot
.07083 .22754 Mdot
.07084 .22753 Mdot
.07085 .22751 Mdot
.07086 .22749 Mdot
.07087 .22748 Mdot
.07088 .22746 Mdot
.07089 .22745 Mdot
.0709 .22743 Mdot
.0709 .22742 Mdot
.07091 .2274 Mdot
.07092 .22738 Mdot
.07093 .22737 Mdot
.07094 .22735 Mdot
.07095 .22734 Mdot
.07096 .22732 Mdot
.07097 .2273 Mdot
.07098 .22729 Mdot
.07099 .22727 Mdot
.071 .22726 Mdot
.07101 .22724 Mdot
.07102 .22722 Mdot
.07103 .22721 Mdot
.07104 .22719 Mdot
.07105 .22718 Mdot
.07106 .22716 Mdot
.07107 .22715 Mdot
.07108 .22713 Mdot
.07109 .22711 Mdot
.0711 .2271 Mdot
.0711 .22708 Mdot
.07111 .22707 Mdot
.07112 .22705 Mdot
.07113 .22703 Mdot
.07114 .22702 Mdot
.07115 .227 Mdot
.07116 .22699 Mdot
.07117 .22697 Mdot
.07118 .22695 Mdot
.07119 .22694 Mdot
.0712 .22692 Mdot
.07121 .22691 Mdot
.07122 .22689 Mdot
.07123 .22688 Mdot
.07124 .22686 Mdot
.07125 .22684 Mdot
.07126 .22683 Mdot
.07127 .22681 Mdot
.07128 .2268 Mdot
.07129 .22678 Mdot
.0713 .22676 Mdot
.0713 .22675 Mdot
.07131 .22673 Mdot
.07132 .22672 Mdot
.07133 .2267 Mdot
.07134 .22668 Mdot
.07135 .22667 Mdot
.07136 .22665 Mdot
.07137 .22664 Mdot
.07138 .22662 Mdot
.07139 .22661 Mdot
.0714 .22659 Mdot
.07141 .22657 Mdot
.07142 .22656 Mdot
.07143 .22654 Mdot
.07144 .22653 Mdot
.07145 .22651 Mdot
.07146 .22649 Mdot
.07147 .22648 Mdot
.07148 .22646 Mdot
.07149 .22645 Mdot
.0715 .22643 Mdot
.0715 .22642 Mdot
.07151 .2264 Mdot
.07152 .22638 Mdot
.07153 .22637 Mdot
.07154 .22635 Mdot
.07155 .22634 Mdot
.07156 .22632 Mdot
.07157 .2263 Mdot
.07158 .22629 Mdot
.07159 .22627 Mdot
.0716 .22626 Mdot
.07161 .22624 Mdot
.07162 .22622 Mdot
.07163 .22621 Mdot
.07164 .22619 Mdot
.07165 .22618 Mdot
.07166 .22616 Mdot
.07167 .22615 Mdot
.07168 .22613 Mdot
.07169 .22611 Mdot
.0717 .2261 Mdot
.0717 .22608 Mdot
.07171 .22607 Mdot
.07172 .22605 Mdot
.07173 .22603 Mdot
.07174 .22602 Mdot
.07175 .226 Mdot
.07176 .22599 Mdot
.07177 .22597 Mdot
.07178 .22596 Mdot
.07179 .22594 Mdot
.0718 .22592 Mdot
.07181 .22591 Mdot
.07182 .22589 Mdot
.07183 .22588 Mdot
.07184 .22586 Mdot
.07185 .22584 Mdot
.07186 .22583 Mdot
.07187 .22581 Mdot
.07188 .2258 Mdot
.07189 .22578 Mdot
.0719 .22577 Mdot
.0719 .22575 Mdot
.07191 .22573 Mdot
.07192 .22572 Mdot
.07193 .2257 Mdot
.07194 .22569 Mdot
.07195 .22567 Mdot
.07196 .22565 Mdot
.07197 .22564 Mdot
.07198 .22562 Mdot
.07199 .22561 Mdot
.072 .22559 Mdot
.07201 .22557 Mdot
.07202 .22556 Mdot
.07203 .22554 Mdot
.07204 .22553 Mdot
.07205 .22551 Mdot
.07206 .2255 Mdot
.07207 .22548 Mdot
.07208 .22546 Mdot
.07209 .22545 Mdot
.0721 .22543 Mdot
.0721 .22542 Mdot
.07211 .2254 Mdot
.07212 .22538 Mdot
.07213 .22537 Mdot
.07214 .22535 Mdot
.07215 .22534 Mdot
.07216 .22532 Mdot
.07217 .22531 Mdot
.07218 .22529 Mdot
.07219 .22527 Mdot
.0722 .22526 Mdot
.07221 .22524 Mdot
.07222 .22523 Mdot
.07223 .22521 Mdot
.07224 .22519 Mdot
.07225 .22518 Mdot
.07226 .22516 Mdot
.07227 .22515 Mdot
.07228 .22513 Mdot
.07229 .22512 Mdot
.0723 .2251 Mdot
.0723 .22508 Mdot
.07231 .22507 Mdot
.07232 .22505 Mdot
.07233 .22504 Mdot
.07234 .22502 Mdot
.07235 .225 Mdot
.07236 .22499 Mdot
.07237 .22497 Mdot
.07238 .22496 Mdot
.07239 .22494 Mdot
.0724 .22493 Mdot
.07241 .22491 Mdot
.07242 .22489 Mdot
.07243 .22488 Mdot
.07244 .22486 Mdot
.07245 .22485 Mdot
.07246 .22483 Mdot
.07247 .22481 Mdot
.07248 .2248 Mdot
.07249 .22478 Mdot
.0725 .22477 Mdot
.0725 .22475 Mdot
.07251 .22474 Mdot
.07252 .22472 Mdot
.07253 .2247 Mdot
.07254 .22469 Mdot
.07255 .22467 Mdot
.07256 .22466 Mdot
.07257 .22464 Mdot
.07258 .22462 Mdot
.07259 .22461 Mdot
.0726 .22459 Mdot
.07261 .22458 Mdot
.07262 .22456 Mdot
.07263 .22455 Mdot
.07264 .22453 Mdot
.07265 .22451 Mdot
.07266 .2245 Mdot
.07267 .22448 Mdot
.07268 .22447 Mdot
.07269 .22445 Mdot
.0727 .22443 Mdot
.0727 .22442 Mdot
.07271 .2244 Mdot
.07272 .22439 Mdot
.07273 .22437 Mdot
.07274 .22436 Mdot
.07275 .22434 Mdot
.07276 .22432 Mdot
.07277 .22431 Mdot
.07278 .22429 Mdot
.07279 .22428 Mdot
.0728 .22426 Mdot
.07281 .22424 Mdot
.07282 .22423 Mdot
.07283 .22421 Mdot
.07284 .2242 Mdot
.07285 .22418 Mdot
.07286 .22417 Mdot
.07287 .22415 Mdot
.07288 .22413 Mdot
.07289 .22412 Mdot
.0729 .2241 Mdot
.0729 .22409 Mdot
.07291 .22407 Mdot
.07292 .22405 Mdot
.07293 .22404 Mdot
.07294 .22402 Mdot
.07295 .22401 Mdot
.07296 .22399 Mdot
.07297 .22398 Mdot
.07298 .22396 Mdot
.07299 .22394 Mdot
.073 .22393 Mdot
.07301 .22391 Mdot
.07302 .2239 Mdot
.07303 .22388 Mdot
.07304 .22386 Mdot
.07305 .22385 Mdot
.07306 .22383 Mdot
.07307 .22382 Mdot
.07308 .2238 Mdot
.07309 .22379 Mdot
.0731 .22377 Mdot
.0731 .22375 Mdot
.07311 .22374 Mdot
.07312 .22372 Mdot
.07313 .22371 Mdot
.07314 .22369 Mdot
.07315 .22367 Mdot
.07316 .22366 Mdot
.07317 .22364 Mdot
.07318 .22363 Mdot
.07319 .22361 Mdot
.0732 .2236 Mdot
.07321 .22358 Mdot
.07322 .22356 Mdot
.07323 .22355 Mdot
.07324 .22353 Mdot
.07325 .22352 Mdot
.07326 .2235 Mdot
.07327 .22348 Mdot
.07328 .22347 Mdot
.07329 .22345 Mdot
.0733 .22344 Mdot
.0733 .22342 Mdot
.07331 .22341 Mdot
.07332 .22339 Mdot
.07333 .22337 Mdot
.07334 .22336 Mdot
.07335 .22334 Mdot
.07336 .22333 Mdot
.07337 .22331 Mdot
.07338 .2233 Mdot
.07339 .22328 Mdot
.0734 .22326 Mdot
.07341 .22325 Mdot
.07342 .22323 Mdot
.07343 .22322 Mdot
.07344 .2232 Mdot
.07345 .22318 Mdot
.07346 .22317 Mdot
.07347 .22315 Mdot
.07348 .22314 Mdot
.07349 .22312 Mdot
.0735 .22311 Mdot
.0735 .22309 Mdot
.07351 .22307 Mdot
.07352 .22306 Mdot
.07353 .22304 Mdot
.07354 .22303 Mdot
.07355 .22301 Mdot
.07356 .22299 Mdot
.07357 .22298 Mdot
.07358 .22296 Mdot
.07359 .22295 Mdot
.0736 .22293 Mdot
.07361 .22292 Mdot
.07362 .2229 Mdot
.07363 .22288 Mdot
.07364 .22287 Mdot
.07365 .22285 Mdot
.07366 .22284 Mdot
.07367 .22282 Mdot
.07368 .2228 Mdot
.07369 .22279 Mdot
.0737 .22277 Mdot
.0737 .22276 Mdot
.07371 .22274 Mdot
.07372 .22273 Mdot
.07373 .22271 Mdot
.07374 .22269 Mdot
.07375 .22268 Mdot
.07376 .22266 Mdot
.07377 .22265 Mdot
.07378 .22263 Mdot
.07379 .22262 Mdot
.0738 .2226 Mdot
.07381 .22258 Mdot
.07382 .22257 Mdot
.07383 .22255 Mdot
.07384 .22254 Mdot
.07385 .22252 Mdot
.07386 .2225 Mdot
.07387 .22249 Mdot
.07388 .22247 Mdot
.07389 .22246 Mdot
.0739 .22244 Mdot
.0739 .22243 Mdot
.07391 .22241 Mdot
.07392 .22239 Mdot
.07393 .22238 Mdot
.07394 .22236 Mdot
.07395 .22235 Mdot
.07396 .22233 Mdot
.07397 .22232 Mdot
.07398 .2223 Mdot
.07399 .22228 Mdot
.074 .22227 Mdot
.07401 .22225 Mdot
.07402 .22224 Mdot
.07403 .22222 Mdot
.07404 .2222 Mdot
.07405 .22219 Mdot
.07406 .22217 Mdot
.07407 .22216 Mdot
.07408 .22214 Mdot
.07409 .22213 Mdot
.0741 .22211 Mdot
.0741 .22209 Mdot
.07411 .22208 Mdot
.07412 .22206 Mdot
.07413 .22205 Mdot
.07414 .22203 Mdot
.07415 .22201 Mdot
.07416 .222 Mdot
.07417 .22198 Mdot
.07418 .22197 Mdot
.07419 .22195 Mdot
.0742 .22194 Mdot
.07421 .22192 Mdot
.07422 .2219 Mdot
.07423 .22189 Mdot
.07424 .22187 Mdot
.07425 .22186 Mdot
.07426 .22184 Mdot
.07427 .22183 Mdot
.07428 .22181 Mdot
.07429 .22179 Mdot
.0743 .22178 Mdot
.0743 .22176 Mdot
.07431 .22175 Mdot
.07432 .22173 Mdot
.07433 .22171 Mdot
.07434 .2217 Mdot
.07435 .22168 Mdot
.07436 .22167 Mdot
.07437 .22165 Mdot
.07438 .22164 Mdot
.07439 .22162 Mdot
.0744 .2216 Mdot
.07441 .22159 Mdot
.07442 .22157 Mdot
.07443 .22156 Mdot
.07444 .22154 Mdot
.07445 .22153 Mdot
.07446 .22151 Mdot
.07447 .22149 Mdot
.07448 .22148 Mdot
.07449 .22146 Mdot
.0745 .22145 Mdot
.0745 .22143 Mdot
.07451 .22142 Mdot
.07452 .2214 Mdot
.07453 .22138 Mdot
.07454 .22137 Mdot
.07455 .22135 Mdot
.07456 .22134 Mdot
.07457 .22132 Mdot
.07458 .2213 Mdot
.07459 .22129 Mdot
.0746 .22127 Mdot
.07461 .22126 Mdot
.07462 .22124 Mdot
.07463 .22123 Mdot
.07464 .22121 Mdot
.07465 .22119 Mdot
.07466 .22118 Mdot
.07467 .22116 Mdot
.07468 .22115 Mdot
.07469 .22113 Mdot
.0747 .22112 Mdot
.0747 .2211 Mdot
.07471 .22108 Mdot
.07472 .22107 Mdot
.07473 .22105 Mdot
.07474 .22104 Mdot
.07475 .22102 Mdot
.07476 .221 Mdot
.07477 .22099 Mdot
.07478 .22097 Mdot
.07479 .22096 Mdot
.0748 .22094 Mdot
.07481 .22093 Mdot
.07482 .22091 Mdot
.07483 .22089 Mdot
.07484 .22088 Mdot
.07485 .22086 Mdot
.07486 .22085 Mdot
.07487 .22083 Mdot
.07488 .22082 Mdot
.07489 .2208 Mdot
.0749 .22078 Mdot
.0749 .22077 Mdot
.07491 .22075 Mdot
.07492 .22074 Mdot
.07493 .22072 Mdot
.07494 .22071 Mdot
.07495 .22069 Mdot
.07496 .22067 Mdot
.07497 .22066 Mdot
.07498 .22064 Mdot
.07499 .22063 Mdot
.075 .22061 Mdot
.07501 .22059 Mdot
.07502 .22058 Mdot
.07503 .22056 Mdot
.07504 .22055 Mdot
.07505 .22053 Mdot
.07506 .22052 Mdot
.07507 .2205 Mdot
.07508 .22048 Mdot
.07509 .22047 Mdot
.0751 .22045 Mdot
.0751 .22044 Mdot
.07511 .22042 Mdot
.07512 .22041 Mdot
.07513 .22039 Mdot
.07514 .22037 Mdot
.07515 .22036 Mdot
.07516 .22034 Mdot
.07517 .22033 Mdot
.07518 .22031 Mdot
.07519 .2203 Mdot
.0752 .22028 Mdot
.07521 .22026 Mdot
.07522 .22025 Mdot
.07523 .22023 Mdot
.07524 .22022 Mdot
.07525 .2202 Mdot
.07526 .22018 Mdot
.07527 .22017 Mdot
.07528 .22015 Mdot
.07529 .22014 Mdot
.0753 .22012 Mdot
.0753 .22011 Mdot
.07531 .22009 Mdot
.07532 .22007 Mdot
.07533 .22006 Mdot
.07534 .22004 Mdot
.07535 .22003 Mdot
.07536 .22001 Mdot
.07537 .22 Mdot
.07538 .21998 Mdot
.07539 .21996 Mdot
.0754 .21995 Mdot
.07541 .21993 Mdot
.07542 .21992 Mdot
.07543 .2199 Mdot
.07544 .21989 Mdot
.07545 .21987 Mdot
.07546 .21985 Mdot
.07547 .21984 Mdot
.07548 .21982 Mdot
.07549 .21981 Mdot
.0755 .21979 Mdot
.0755 .21978 Mdot
.07551 .21976 Mdot
.07552 .21974 Mdot
.07553 .21973 Mdot
.07554 .21971 Mdot
.07555 .2197 Mdot
.07556 .21968 Mdot
.07557 .21966 Mdot
.07558 .21965 Mdot
.07559 .21963 Mdot
.0756 .21962 Mdot
.07561 .2196 Mdot
.07562 .21959 Mdot
.07563 .21957 Mdot
.07564 .21955 Mdot
.07565 .21954 Mdot
.07566 .21952 Mdot
.07567 .21951 Mdot
.07568 .21949 Mdot
.07569 .21948 Mdot
.0757 .21946 Mdot
.0757 .21944 Mdot
.07571 .21943 Mdot
.07572 .21941 Mdot
.07573 .2194 Mdot
.07574 .21938 Mdot
.07575 .21937 Mdot
.07576 .21935 Mdot
.07577 .21933 Mdot
.07578 .21932 Mdot
.07579 .2193 Mdot
.0758 .21929 Mdot
.07581 .21927 Mdot
.07582 .21926 Mdot
.07583 .21924 Mdot
.07584 .21922 Mdot
.07585 .21921 Mdot
.07586 .21919 Mdot
.07587 .21918 Mdot
.07588 .21916 Mdot
.07589 .21914 Mdot
.0759 .21913 Mdot
.0759 .21911 Mdot
.07591 .2191 Mdot
.07592 .21908 Mdot
.07593 .21907 Mdot
.07594 .21905 Mdot
.07595 .21903 Mdot
.07596 .21902 Mdot
.07597 .219 Mdot
.07598 .21899 Mdot
.07599 .21897 Mdot
.076 .21896 Mdot
.07601 .21894 Mdot
.07602 .21892 Mdot
.07603 .21891 Mdot
.07604 .21889 Mdot
.07605 .21888 Mdot
.07606 .21886 Mdot
.07607 .21885 Mdot
.07608 .21883 Mdot
.07609 .21881 Mdot
.0761 .2188 Mdot
.0761 .21878 Mdot
.07611 .21877 Mdot
.07612 .21875 Mdot
.07613 .21874 Mdot
.07614 .21872 Mdot
.07615 .2187 Mdot
.07616 .21869 Mdot
.07617 .21867 Mdot
.07618 .21866 Mdot
.07619 .21864 Mdot
.0762 .21863 Mdot
.07621 .21861 Mdot
.07622 .21859 Mdot
.07623 .21858 Mdot
.07624 .21856 Mdot
.07625 .21855 Mdot
.07626 .21853 Mdot
.07627 .21852 Mdot
.07628 .2185 Mdot
.07629 .21848 Mdot
.0763 .21847 Mdot
.0763 .21845 Mdot
.07631 .21844 Mdot
.07632 .21842 Mdot
.07633 .21841 Mdot
.07634 .21839 Mdot
.07635 .21837 Mdot
.07636 .21836 Mdot
.07637 .21834 Mdot
.07638 .21833 Mdot
.07639 .21831 Mdot
.0764 .2183 Mdot
.07641 .21828 Mdot
.07642 .21826 Mdot
.07643 .21825 Mdot
.07644 .21823 Mdot
.07645 .21822 Mdot
.07646 .2182 Mdot
.07647 .21819 Mdot
.07648 .21817 Mdot
.07649 .21815 Mdot
.0765 .21814 Mdot
.0765 .21812 Mdot
.07651 .21811 Mdot
.07652 .21809 Mdot
.07653 .21807 Mdot
.07654 .21806 Mdot
.07655 .21804 Mdot
.07656 .21803 Mdot
.07657 .21801 Mdot
.07658 .218 Mdot
.07659 .21798 Mdot
.0766 .21796 Mdot
.07661 .21795 Mdot
.07662 .21793 Mdot
.07663 .21792 Mdot
.07664 .2179 Mdot
.07665 .21789 Mdot
.07666 .21787 Mdot
.07667 .21785 Mdot
.07668 .21784 Mdot
.07669 .21782 Mdot
.0767 .21781 Mdot
.0767 .21779 Mdot
.07671 .21778 Mdot
.07672 .21776 Mdot
.07673 .21774 Mdot
.07674 .21773 Mdot
.07675 .21771 Mdot
.07676 .2177 Mdot
.07677 .21768 Mdot
.07678 .21767 Mdot
.07679 .21765 Mdot
.0768 .21763 Mdot
.07681 .21762 Mdot
.07682 .2176 Mdot
.07683 .21759 Mdot
.07684 .21757 Mdot
.07685 .21756 Mdot
.07686 .21754 Mdot
.07687 .21752 Mdot
.07688 .21751 Mdot
.07689 .21749 Mdot
.0769 .21748 Mdot
.0769 .21746 Mdot
.07691 .21745 Mdot
.07692 .21743 Mdot
.07693 .21741 Mdot
.07694 .2174 Mdot
.07695 .21738 Mdot
.07696 .21737 Mdot
.07697 .21735 Mdot
.07698 .21734 Mdot
.07699 .21732 Mdot
.077 .2173 Mdot
.07701 .21729 Mdot
.07702 .21727 Mdot
.07703 .21726 Mdot
.07704 .21724 Mdot
.07705 .21723 Mdot
.07706 .21721 Mdot
.07707 .21719 Mdot
.07708 .21718 Mdot
.07709 .21716 Mdot
.0771 .21715 Mdot
.0771 .21713 Mdot
.07711 .21712 Mdot
.07712 .2171 Mdot
.07713 .21708 Mdot
.07714 .21707 Mdot
.07715 .21705 Mdot
.07716 .21704 Mdot
.07717 .21702 Mdot
.07718 .21701 Mdot
.07719 .21699 Mdot
.0772 .21697 Mdot
.07721 .21696 Mdot
.07722 .21694 Mdot
.07723 .21693 Mdot
.07724 .21691 Mdot
.07725 .2169 Mdot
.07726 .21688 Mdot
.07727 .21686 Mdot
.07728 .21685 Mdot
.07729 .21683 Mdot
.0773 .21682 Mdot
.0773 .2168 Mdot
.07731 .21679 Mdot
.07732 .21677 Mdot
.07733 .21675 Mdot
.07734 .21674 Mdot
.07735 .21672 Mdot
.07736 .21671 Mdot
.07737 .21669 Mdot
.07738 .21668 Mdot
.07739 .21666 Mdot
.0774 .21664 Mdot
.07741 .21663 Mdot
.07742 .21661 Mdot
.07743 .2166 Mdot
.07744 .21658 Mdot
.07745 .21657 Mdot
.07746 .21655 Mdot
.07747 .21654 Mdot
.07748 .21652 Mdot
.07749 .2165 Mdot
.0775 .21649 Mdot
.0775 .21647 Mdot
.07751 .21646 Mdot
.07752 .21644 Mdot
.07753 .21643 Mdot
.07754 .21641 Mdot
.07755 .21639 Mdot
.07756 .21638 Mdot
.07757 .21636 Mdot
.07758 .21635 Mdot
.07759 .21633 Mdot
.0776 .21632 Mdot
.07761 .2163 Mdot
.07762 .21628 Mdot
.07763 .21627 Mdot
.07764 .21625 Mdot
.07765 .21624 Mdot
.07766 .21622 Mdot
.07767 .21621 Mdot
.07768 .21619 Mdot
.07769 .21617 Mdot
.0777 .21616 Mdot
.0777 .21614 Mdot
.07771 .21613 Mdot
.07772 .21611 Mdot
.07773 .2161 Mdot
.07774 .21608 Mdot
.07775 .21606 Mdot
.07776 .21605 Mdot
.07777 .21603 Mdot
.07778 .21602 Mdot
.07779 .216 Mdot
.0778 .21599 Mdot
.07781 .21597 Mdot
.07782 .21595 Mdot
.07783 .21594 Mdot
.07784 .21592 Mdot
.07785 .21591 Mdot
.07786 .21589 Mdot
.07787 .21588 Mdot
.07788 .21586 Mdot
.07789 .21584 Mdot
.0779 .21583 Mdot
.0779 .21581 Mdot
.07791 .2158 Mdot
.07792 .21578 Mdot
.07793 .21577 Mdot
.07794 .21575 Mdot
.07795 .21573 Mdot
.07796 .21572 Mdot
.07797 .2157 Mdot
.07798 .21569 Mdot
.07799 .21567 Mdot
.078 .21566 Mdot
.07801 .21564 Mdot
.07802 .21562 Mdot
.07803 .21561 Mdot
.07804 .21559 Mdot
.07805 .21558 Mdot
.07806 .21556 Mdot
.07807 .21555 Mdot
.07808 .21553 Mdot
.07809 .21552 Mdot
.0781 .2155 Mdot
.0781 .21548 Mdot
.07811 .21547 Mdot
.07812 .21545 Mdot
.07813 .21544 Mdot
.07814 .21542 Mdot
.07815 .21541 Mdot
.07816 .21539 Mdot
.07817 .21537 Mdot
.07818 .21536 Mdot
.07819 .21534 Mdot
.0782 .21533 Mdot
.07821 .21531 Mdot
.07822 .2153 Mdot
.07823 .21528 Mdot
.07824 .21526 Mdot
.07825 .21525 Mdot
.07826 .21523 Mdot
.07827 .21522 Mdot
.07828 .2152 Mdot
.07829 .21519 Mdot
.0783 .21517 Mdot
.0783 .21515 Mdot
.07831 .21514 Mdot
.07832 .21512 Mdot
.07833 .21511 Mdot
.07834 .21509 Mdot
.07835 .21508 Mdot
.07836 .21506 Mdot
.07837 .21504 Mdot
.07838 .21503 Mdot
.07839 .21501 Mdot
.0784 .215 Mdot
.07841 .21498 Mdot
.07842 .21497 Mdot
.07843 .21495 Mdot
.07844 .21494 Mdot
.07845 .21492 Mdot
.07846 .2149 Mdot
.07847 .21489 Mdot
.07848 .21487 Mdot
.07849 .21486 Mdot
.0785 .21484 Mdot
.0785 .21483 Mdot
.07851 .21481 Mdot
.07852 .21479 Mdot
.07853 .21478 Mdot
.07854 .21476 Mdot
.07855 .21475 Mdot
.07856 .21473 Mdot
.07857 .21472 Mdot
.07858 .2147 Mdot
.07859 .21468 Mdot
.0786 .21467 Mdot
.07861 .21465 Mdot
.07862 .21464 Mdot
.07863 .21462 Mdot
.07864 .21461 Mdot
.07865 .21459 Mdot
.07866 .21457 Mdot
.07867 .21456 Mdot
.07868 .21454 Mdot
.07869 .21453 Mdot
.0787 .21451 Mdot
.0787 .2145 Mdot
.07871 .21448 Mdot
.07872 .21447 Mdot
.07873 .21445 Mdot
.07874 .21443 Mdot
.07875 .21442 Mdot
.07876 .2144 Mdot
.07877 .21439 Mdot
.07878 .21437 Mdot
.07879 .21436 Mdot
.0788 .21434 Mdot
.07881 .21432 Mdot
.07882 .21431 Mdot
.07883 .21429 Mdot
.07884 .21428 Mdot
.07885 .21426 Mdot
.07886 .21425 Mdot
.07887 .21423 Mdot
.07888 .21421 Mdot
.07889 .2142 Mdot
.0789 .21418 Mdot
.0789 .21417 Mdot
.07891 .21415 Mdot
.07892 .21414 Mdot
.07893 .21412 Mdot
.07894 .2141 Mdot
.07895 .21409 Mdot
.07896 .21407 Mdot
.07897 .21406 Mdot
.07898 .21404 Mdot
.07899 .21403 Mdot
.079 .21401 Mdot
.07901 .214 Mdot
.07902 .21398 Mdot
.07903 .21396 Mdot
.07904 .21395 Mdot
.07905 .21393 Mdot
.07906 .21392 Mdot
.07907 .2139 Mdot
.07908 .21389 Mdot
.07909 .21387 Mdot
.0791 .21385 Mdot
.0791 .21384 Mdot
.07911 .21382 Mdot
.07912 .21381 Mdot
.07913 .21379 Mdot
.07914 .21378 Mdot
.07915 .21376 Mdot
.07916 .21374 Mdot
.07917 .21373 Mdot
.07918 .21371 Mdot
.07919 .2137 Mdot
.0792 .21368 Mdot
.07921 .21367 Mdot
.07922 .21365 Mdot
.07923 .21364 Mdot
.07924 .21362 Mdot
.07925 .2136 Mdot
.07926 .21359 Mdot
.07927 .21357 Mdot
.07928 .21356 Mdot
.07929 .21354 Mdot
.0793 .21353 Mdot
.0793 .21351 Mdot
.07931 .21349 Mdot
.07932 .21348 Mdot
.07933 .21346 Mdot
.07934 .21345 Mdot
.07935 .21343 Mdot
.07936 .21342 Mdot
.07937 .2134 Mdot
.07938 .21338 Mdot
.07939 .21337 Mdot
.0794 .21335 Mdot
.07941 .21334 Mdot
.07942 .21332 Mdot
.07943 .21331 Mdot
.07944 .21329 Mdot
.07945 .21328 Mdot
.07946 .21326 Mdot
.07947 .21324 Mdot
.07948 .21323 Mdot
.07949 .21321 Mdot
.0795 .2132 Mdot
.0795 .21318 Mdot
.07951 .21317 Mdot
.07952 .21315 Mdot
.07953 .21313 Mdot
.07954 .21312 Mdot
.07955 .2131 Mdot
.07956 .21309 Mdot
.07957 .21307 Mdot
.07958 .21306 Mdot
.07959 .21304 Mdot
.0796 .21303 Mdot
.07961 .21301 Mdot
.07962 .21299 Mdot
.07963 .21298 Mdot
.07964 .21296 Mdot
.07965 .21295 Mdot
.07966 .21293 Mdot
.07967 .21292 Mdot
.07968 .2129 Mdot
.07969 .21288 Mdot
.0797 .21287 Mdot
.0797 .21285 Mdot
.07971 .21284 Mdot
.07972 .21282 Mdot
.07973 .21281 Mdot
.07974 .21279 Mdot
.07975 .21278 Mdot
.07976 .21276 Mdot
.07977 .21274 Mdot
.07978 .21273 Mdot
.07979 .21271 Mdot
.0798 .2127 Mdot
.07981 .21268 Mdot
.07982 .21267 Mdot
.07983 .21265 Mdot
.07984 .21263 Mdot
.07985 .21262 Mdot
.07986 .2126 Mdot
.07987 .21259 Mdot
.07988 .21257 Mdot
.07989 .21256 Mdot
.0799 .21254 Mdot
.0799 .21252 Mdot
.07991 .21251 Mdot
.07992 .21249 Mdot
.07993 .21248 Mdot
.07994 .21246 Mdot
.07995 .21245 Mdot
.07996 .21243 Mdot
.07997 .21242 Mdot
.07998 .2124 Mdot
.07999 .21238 Mdot
.08 .21237 Mdot
.08001 .21235 Mdot
.08002 .21234 Mdot
.08003 .21232 Mdot
.08004 .21231 Mdot
.08005 .21229 Mdot
.08006 .21227 Mdot
.08007 .21226 Mdot
.08008 .21224 Mdot
.08009 .21223 Mdot
.0801 .21221 Mdot
.0801 .2122 Mdot
.08011 .21218 Mdot
.08012 .21217 Mdot
.08013 .21215 Mdot
.08014 .21213 Mdot
.08015 .21212 Mdot
.08016 .2121 Mdot
.08017 .21209 Mdot
.08018 .21207 Mdot
.08019 .21206 Mdot
.0802 .21204 Mdot
.08021 .21202 Mdot
.08022 .21201 Mdot
.08023 .21199 Mdot
.08024 .21198 Mdot
.08025 .21196 Mdot
.08026 .21195 Mdot
.08027 .21193 Mdot
.08028 .21192 Mdot
.08029 .2119 Mdot
.0803 .21188 Mdot
.0803 .21187 Mdot
.08031 .21185 Mdot
.08032 .21184 Mdot
.08033 .21182 Mdot
.08034 .21181 Mdot
.08035 .21179 Mdot
.08036 .21178 Mdot
.08037 .21176 Mdot
.08038 .21174 Mdot
.08039 .21173 Mdot
.0804 .21171 Mdot
.08041 .2117 Mdot
.08042 .21168 Mdot
.08043 .21167 Mdot
.08044 .21165 Mdot
.08045 .21163 Mdot
.08046 .21162 Mdot
.08047 .2116 Mdot
.08048 .21159 Mdot
.08049 .21157 Mdot
.0805 .21156 Mdot
.0805 .21154 Mdot
.08051 .21153 Mdot
.08052 .21151 Mdot
.08053 .21149 Mdot
.08054 .21148 Mdot
.08055 .21146 Mdot
.08056 .21145 Mdot
.08057 .21143 Mdot
.08058 .21142 Mdot
.08059 .2114 Mdot
.0806 .21138 Mdot
.08061 .21137 Mdot
.08062 .21135 Mdot
.08063 .21134 Mdot
.08064 .21132 Mdot
.08065 .21131 Mdot
.08066 .21129 Mdot
.08067 .21128 Mdot
.08068 .21126 Mdot
.08069 .21124 Mdot
.0807 .21123 Mdot
.0807 .21121 Mdot
.08071 .2112 Mdot
.08072 .21118 Mdot
.08073 .21117 Mdot
.08074 .21115 Mdot
.08075 .21114 Mdot
.08076 .21112 Mdot
.08077 .2111 Mdot
.08078 .21109 Mdot
.08079 .21107 Mdot
.0808 .21106 Mdot
.08081 .21104 Mdot
.08082 .21103 Mdot
.08083 .21101 Mdot
.08084 .21099 Mdot
.08085 .21098 Mdot
.08086 .21096 Mdot
.08087 .21095 Mdot
.08088 .21093 Mdot
.08089 .21092 Mdot
.0809 .2109 Mdot
.0809 .21089 Mdot
.08091 .21087 Mdot
.08092 .21085 Mdot
.08093 .21084 Mdot
.08094 .21082 Mdot
.08095 .21081 Mdot
.08096 .21079 Mdot
.08097 .21078 Mdot
.08098 .21076 Mdot
.08099 .21075 Mdot
.081 .21073 Mdot
.08101 .21071 Mdot
.08102 .2107 Mdot
.08103 .21068 Mdot
.08104 .21067 Mdot
.08105 .21065 Mdot
.08106 .21064 Mdot
.08107 .21062 Mdot
.08108 .2106 Mdot
.08109 .21059 Mdot
.0811 .21057 Mdot
.0811 .21056 Mdot
.08111 .21054 Mdot
.08112 .21053 Mdot
.08113 .21051 Mdot
.08114 .2105 Mdot
.08115 .21048 Mdot
.08116 .21046 Mdot
.08117 .21045 Mdot
.08118 .21043 Mdot
.08119 .21042 Mdot
.0812 .2104 Mdot
.08121 .21039 Mdot
.08122 .21037 Mdot
.08123 .21036 Mdot
.08124 .21034 Mdot
.08125 .21032 Mdot
.08126 .21031 Mdot
.08127 .21029 Mdot
.08128 .21028 Mdot
.08129 .21026 Mdot
.0813 .21025 Mdot
.0813 .21023 Mdot
.08131 .21022 Mdot
.08132 .2102 Mdot
.08133 .21018 Mdot
.08134 .21017 Mdot
.08135 .21015 Mdot
.08136 .21014 Mdot
.08137 .21012 Mdot
.08138 .21011 Mdot
.08139 .21009 Mdot
.0814 .21007 Mdot
.08141 .21006 Mdot
.08142 .21004 Mdot
.08143 .21003 Mdot
.08144 .21001 Mdot
.08145 .21 Mdot
.08146 .20998 Mdot
.08147 .20997 Mdot
.08148 .20995 Mdot
.08149 .20993 Mdot
.0815 .20992 Mdot
.0815 .2099 Mdot
.08151 .20989 Mdot
.08152 .20987 Mdot
.08153 .20986 Mdot
.08154 .20984 Mdot
.08155 .20983 Mdot
.08156 .20981 Mdot
.08157 .20979 Mdot
.08158 .20978 Mdot
.08159 .20976 Mdot
.0816 .20975 Mdot
.08161 .20973 Mdot
.08162 .20972 Mdot
.08163 .2097 Mdot
.08164 .20969 Mdot
.08165 .20967 Mdot
.08166 .20965 Mdot
.08167 .20964 Mdot
.08168 .20962 Mdot
.08169 .20961 Mdot
.0817 .20959 Mdot
.0817 .20958 Mdot
.08171 .20956 Mdot
.08172 .20955 Mdot
.08173 .20953 Mdot
.08174 .20951 Mdot
.08175 .2095 Mdot
.08176 .20948 Mdot
.08177 .20947 Mdot
.08178 .20945 Mdot
.08179 .20944 Mdot
.0818 .20942 Mdot
.08181 .20941 Mdot
.08182 .20939 Mdot
.08183 .20937 Mdot
.08184 .20936 Mdot
.08185 .20934 Mdot
.08186 .20933 Mdot
.08187 .20931 Mdot
.08188 .2093 Mdot
.08189 .20928 Mdot
.0819 .20926 Mdot
.0819 .20925 Mdot
.08191 .20923 Mdot
.08192 .20922 Mdot
.08193 .2092 Mdot
.08194 .20919 Mdot
.08195 .20917 Mdot
.08196 .20916 Mdot
.08197 .20914 Mdot
.08198 .20912 Mdot
.08199 .20911 Mdot
.082 .20909 Mdot
.08201 .20908 Mdot
.08202 .20906 Mdot
.08203 .20905 Mdot
.08204 .20903 Mdot
.08205 .20902 Mdot
.08206 .209 Mdot
.08207 .20898 Mdot
.08208 .20897 Mdot
.08209 .20895 Mdot
.0821 .20894 Mdot
.0821 .20892 Mdot
.08211 .20891 Mdot
.08212 .20889 Mdot
.08213 .20888 Mdot
.08214 .20886 Mdot
.08215 .20884 Mdot
.08216 .20883 Mdot
.08217 .20881 Mdot
.08218 .2088 Mdot
.08219 .20878 Mdot
.0822 .20877 Mdot
.08221 .20875 Mdot
.08222 .20874 Mdot
.08223 .20872 Mdot
.08224 .2087 Mdot
.08225 .20869 Mdot
.08226 .20867 Mdot
.08227 .20866 Mdot
.08228 .20864 Mdot
.08229 .20863 Mdot
.0823 .20861 Mdot
.0823 .2086 Mdot
.08231 .20858 Mdot
.08232 .20856 Mdot
.08233 .20855 Mdot
.08234 .20853 Mdot
.08235 .20852 Mdot
.08236 .2085 Mdot
.08237 .20849 Mdot
.08238 .20847 Mdot
.08239 .20846 Mdot
.0824 .20844 Mdot
.08241 .20842 Mdot
.08242 .20841 Mdot
.08243 .20839 Mdot
.08244 .20838 Mdot
.08245 .20836 Mdot
.08246 .20835 Mdot
.08247 .20833 Mdot
.08248 .20832 Mdot
.08249 .2083 Mdot
.0825 .20828 Mdot
.0825 .20827 Mdot
.08251 .20825 Mdot
.08252 .20824 Mdot
.08253 .20822 Mdot
.08254 .20821 Mdot
.08255 .20819 Mdot
.08256 .20818 Mdot
.08257 .20816 Mdot
.08258 .20814 Mdot
.08259 .20813 Mdot
.0826 .20811 Mdot
.08261 .2081 Mdot
.08262 .20808 Mdot
.08263 .20807 Mdot
.08264 .20805 Mdot
.08265 .20804 Mdot
.08266 .20802 Mdot
.08267 .208 Mdot
.08268 .20799 Mdot
.08269 .20797 Mdot
.0827 .20796 Mdot
.0827 .20794 Mdot
.08271 .20793 Mdot
.08272 .20791 Mdot
.08273 .2079 Mdot
.08274 .20788 Mdot
.08275 .20787 Mdot
.08276 .20785 Mdot
.08277 .20783 Mdot
.08278 .20782 Mdot
.08279 .2078 Mdot
.0828 .20779 Mdot
.08281 .20777 Mdot
.08282 .20776 Mdot
.08283 .20774 Mdot
.08284 .20773 Mdot
.08285 .20771 Mdot
.08286 .20769 Mdot
.08287 .20768 Mdot
.08288 .20766 Mdot
.08289 .20765 Mdot
.0829 .20763 Mdot
.0829 .20762 Mdot
.08291 .2076 Mdot
.08292 .20759 Mdot
.08293 .20757 Mdot
.08294 .20755 Mdot
.08295 .20754 Mdot
.08296 .20752 Mdot
.08297 .20751 Mdot
.08298 .20749 Mdot
.08299 .20748 Mdot
.083 .20746 Mdot
.08301 .20745 Mdot
.08302 .20743 Mdot
.08303 .20741 Mdot
.08304 .2074 Mdot
.08305 .20738 Mdot
.08306 .20737 Mdot
.08307 .20735 Mdot
.08308 .20734 Mdot
.08309 .20732 Mdot
.0831 .20731 Mdot
.0831 .20729 Mdot
.08311 .20727 Mdot
.08312 .20726 Mdot
.08313 .20724 Mdot
.08314 .20723 Mdot
.08315 .20721 Mdot
.08316 .2072 Mdot
.08317 .20718 Mdot
.08318 .20717 Mdot
.08319 .20715 Mdot
.0832 .20714 Mdot
.08321 .20712 Mdot
.08322 .2071 Mdot
.08323 .20709 Mdot
.08324 .20707 Mdot
.08325 .20706 Mdot
.08326 .20704 Mdot
.08327 .20703 Mdot
.08328 .20701 Mdot
.08329 .207 Mdot
.0833 .20698 Mdot
.0833 .20696 Mdot
.08331 .20695 Mdot
.08332 .20693 Mdot
.08333 .20692 Mdot
.08334 .2069 Mdot
.08335 .20689 Mdot
.08336 .20687 Mdot
.08337 .20686 Mdot
.08338 .20684 Mdot
.08339 .20682 Mdot
.0834 .20681 Mdot
.08341 .20679 Mdot
.08342 .20678 Mdot
.08343 .20676 Mdot
.08344 .20675 Mdot
.08345 .20673 Mdot
.08346 .20672 Mdot
.08347 .2067 Mdot
.08348 .20668 Mdot
.08349 .20667 Mdot
.0835 .20665 Mdot
.0835 .20664 Mdot
.08351 .20662 Mdot
.08352 .20661 Mdot
.08353 .20659 Mdot
.08354 .20658 Mdot
.08355 .20656 Mdot
.08356 .20655 Mdot
.08357 .20653 Mdot
.08358 .20651 Mdot
.08359 .2065 Mdot
.0836 .20648 Mdot
.08361 .20647 Mdot
.08362 .20645 Mdot
.08363 .20644 Mdot
.08364 .20642 Mdot
.08365 .20641 Mdot
.08366 .20639 Mdot
.08367 .20637 Mdot
.08368 .20636 Mdot
.08369 .20634 Mdot
.0837 .20633 Mdot
.0837 .20631 Mdot
.08371 .2063 Mdot
.08372 .20628 Mdot
.08373 .20627 Mdot
.08374 .20625 Mdot
.08375 .20624 Mdot
.08376 .20622 Mdot
.08377 .2062 Mdot
.08378 .20619 Mdot
.08379 .20617 Mdot
.0838 .20616 Mdot
.08381 .20614 Mdot
.08382 .20613 Mdot
.08383 .20611 Mdot
.08384 .2061 Mdot
.08385 .20608 Mdot
.08386 .20606 Mdot
.08387 .20605 Mdot
.08388 .20603 Mdot
.08389 .20602 Mdot
.0839 .206 Mdot
.0839 .20599 Mdot
.08391 .20597 Mdot
.08392 .20596 Mdot
.08393 .20594 Mdot
.08394 .20592 Mdot
.08395 .20591 Mdot
.08396 .20589 Mdot
.08397 .20588 Mdot
.08398 .20586 Mdot
.08399 .20585 Mdot
.084 .20583 Mdot
.08401 .20582 Mdot
.08402 .2058 Mdot
.08403 .20579 Mdot
.08404 .20577 Mdot
.08405 .20575 Mdot
.08406 .20574 Mdot
.08407 .20572 Mdot
.08408 .20571 Mdot
.08409 .20569 Mdot
.0841 .20568 Mdot
.0841 .20566 Mdot
.08411 .20565 Mdot
.08412 .20563 Mdot
.08413 .20561 Mdot
.08414 .2056 Mdot
.08415 .20558 Mdot
.08416 .20557 Mdot
.08417 .20555 Mdot
.08418 .20554 Mdot
.08419 .20552 Mdot
.0842 .20551 Mdot
.08421 .20549 Mdot
.08422 .20548 Mdot
.08423 .20546 Mdot
.08424 .20544 Mdot
.08425 .20543 Mdot
.08426 .20541 Mdot
.08427 .2054 Mdot
.08428 .20538 Mdot
.08429 .20537 Mdot
.0843 .20535 Mdot
.0843 .20534 Mdot
.08431 .20532 Mdot
.08432 .20531 Mdot
.08433 .20529 Mdot
.08434 .20527 Mdot
.08435 .20526 Mdot
.08436 .20524 Mdot
.08437 .20523 Mdot
.08438 .20521 Mdot
.08439 .2052 Mdot
.0844 .20518 Mdot
.08441 .20517 Mdot
.08442 .20515 Mdot
.08443 .20513 Mdot
.08444 .20512 Mdot
.08445 .2051 Mdot
.08446 .20509 Mdot
.08447 .20507 Mdot
.08448 .20506 Mdot
.08449 .20504 Mdot
.0845 .20503 Mdot
.0845 .20501 Mdot
.08451 .205 Mdot
.08452 .20498 Mdot
.08453 .20496 Mdot
.08454 .20495 Mdot
.08455 .20493 Mdot
.08456 .20492 Mdot
.08457 .2049 Mdot
.08458 .20489 Mdot
.08459 .20487 Mdot
.0846 .20486 Mdot
.08461 .20484 Mdot
.08462 .20483 Mdot
.08463 .20481 Mdot
.08464 .20479 Mdot
.08465 .20478 Mdot
.08466 .20476 Mdot
.08467 .20475 Mdot
.08468 .20473 Mdot
.08469 .20472 Mdot
.0847 .2047 Mdot
.0847 .20469 Mdot
.08471 .20467 Mdot
.08472 .20465 Mdot
.08473 .20464 Mdot
.08474 .20462 Mdot
.08475 .20461 Mdot
.08476 .20459 Mdot
.08477 .20458 Mdot
.08478 .20456 Mdot
.08479 .20455 Mdot
.0848 .20453 Mdot
.08481 .20452 Mdot
.08482 .2045 Mdot
.08483 .20448 Mdot
.08484 .20447 Mdot
.08485 .20445 Mdot
.08486 .20444 Mdot
.08487 .20442 Mdot
.08488 .20441 Mdot
.08489 .20439 Mdot
.0849 .20438 Mdot
.0849 .20436 Mdot
.08491 .20435 Mdot
.08492 .20433 Mdot
.08493 .20431 Mdot
.08494 .2043 Mdot
.08495 .20428 Mdot
.08496 .20427 Mdot
.08497 .20425 Mdot
.08498 .20424 Mdot
.08499 .20422 Mdot
.085 .20421 Mdot
.08501 .20419 Mdot
.08502 .20418 Mdot
.08503 .20416 Mdot
.08504 .20414 Mdot
.08505 .20413 Mdot
.08506 .20411 Mdot
.08507 .2041 Mdot
.08508 .20408 Mdot
.08509 .20407 Mdot
.0851 .20405 Mdot
.0851 .20404 Mdot
.08511 .20402 Mdot
.08512 .20401 Mdot
.08513 .20399 Mdot
.08514 .20397 Mdot
.08515 .20396 Mdot
.08516 .20394 Mdot
.08517 .20393 Mdot
.08518 .20391 Mdot
.08519 .2039 Mdot
.0852 .20388 Mdot
.08521 .20387 Mdot
.08522 .20385 Mdot
.08523 .20383 Mdot
.08524 .20382 Mdot
.08525 .2038 Mdot
.08526 .20379 Mdot
.08527 .20377 Mdot
.08528 .20376 Mdot
.08529 .20374 Mdot
.0853 .20373 Mdot
.0853 .20371 Mdot
.08531 .2037 Mdot
.08532 .20368 Mdot
.08533 .20366 Mdot
.08534 .20365 Mdot
.08535 .20363 Mdot
.08536 .20362 Mdot
.08537 .2036 Mdot
.08538 .20359 Mdot
.08539 .20357 Mdot
.0854 .20356 Mdot
.08541 .20354 Mdot
.08542 .20353 Mdot
.08543 .20351 Mdot
.08544 .20349 Mdot
.08545 .20348 Mdot
.08546 .20346 Mdot
.08547 .20345 Mdot
.08548 .20343 Mdot
.08549 .20342 Mdot
.0855 .2034 Mdot
.0855 .20339 Mdot
.08551 .20337 Mdot
.08552 .20336 Mdot
.08553 .20334 Mdot
.08554 .20332 Mdot
.08555 .20331 Mdot
.08556 .20329 Mdot
.08557 .20328 Mdot
.08558 .20326 Mdot
.08559 .20325 Mdot
.0856 .20323 Mdot
.08561 .20322 Mdot
.08562 .2032 Mdot
.08563 .20319 Mdot
.08564 .20317 Mdot
.08565 .20315 Mdot
.08566 .20314 Mdot
.08567 .20312 Mdot
.08568 .20311 Mdot
.08569 .20309 Mdot
.0857 .20308 Mdot
.0857 .20306 Mdot
.08571 .20305 Mdot
.08572 .20303 Mdot
.08573 .20302 Mdot
.08574 .203 Mdot
.08575 .20299 Mdot
.08576 .20297 Mdot
.08577 .20295 Mdot
.08578 .20294 Mdot
.08579 .20292 Mdot
.0858 .20291 Mdot
.08581 .20289 Mdot
.08582 .20288 Mdot
.08583 .20286 Mdot
.08584 .20285 Mdot
.08585 .20283 Mdot
.08586 .20282 Mdot
.08587 .2028 Mdot
.08588 .20278 Mdot
.08589 .20277 Mdot
.0859 .20275 Mdot
.0859 .20274 Mdot
.08591 .20272 Mdot
.08592 .20271 Mdot
.08593 .20269 Mdot
.08594 .20268 Mdot
.08595 .20266 Mdot
.08596 .20265 Mdot
.08597 .20263 Mdot
.08598 .20261 Mdot
.08599 .2026 Mdot
.086 .20258 Mdot
.08601 .20257 Mdot
.08602 .20255 Mdot
.08603 .20254 Mdot
.08604 .20252 Mdot
.08605 .20251 Mdot
.08606 .20249 Mdot
.08607 .20248 Mdot
.08608 .20246 Mdot
.08609 .20244 Mdot
.0861 .20243 Mdot
.0861 .20241 Mdot
.08611 .2024 Mdot
.08612 .20238 Mdot
.08613 .20237 Mdot
.08614 .20235 Mdot
.08615 .20234 Mdot
.08616 .20232 Mdot
.08617 .20231 Mdot
.08618 .20229 Mdot
.08619 .20228 Mdot
.0862 .20226 Mdot
.08621 .20224 Mdot
.08622 .20223 Mdot
.08623 .20221 Mdot
.08624 .2022 Mdot
.08625 .20218 Mdot
.08626 .20217 Mdot
.08627 .20215 Mdot
.08628 .20214 Mdot
.08629 .20212 Mdot
.0863 .20211 Mdot
.0863 .20209 Mdot
.08631 .20207 Mdot
.08632 .20206 Mdot
.08633 .20204 Mdot
.08634 .20203 Mdot
.08635 .20201 Mdot
.08636 .202 Mdot
.08637 .20198 Mdot
.08638 .20197 Mdot
.08639 .20195 Mdot
.0864 .20194 Mdot
.08641 .20192 Mdot
.08642 .2019 Mdot
.08643 .20189 Mdot
.08644 .20187 Mdot
.08645 .20186 Mdot
.08646 .20184 Mdot
.08647 .20183 Mdot
.08648 .20181 Mdot
.08649 .2018 Mdot
.0865 .20178 Mdot
.0865 .20177 Mdot
.08651 .20175 Mdot
.08652 .20174 Mdot
.08653 .20172 Mdot
.08654 .2017 Mdot
.08655 .20169 Mdot
.08656 .20167 Mdot
.08657 .20166 Mdot
.08658 .20164 Mdot
.08659 .20163 Mdot
.0866 .20161 Mdot
.08661 .2016 Mdot
.08662 .20158 Mdot
.08663 .20157 Mdot
.08664 .20155 Mdot
.08665 .20153 Mdot
.08666 .20152 Mdot
.08667 .2015 Mdot
.08668 .20149 Mdot
.08669 .20147 Mdot
.0867 .20146 Mdot
.0867 .20144 Mdot
.08671 .20143 Mdot
.08672 .20141 Mdot
.08673 .2014 Mdot
.08674 .20138 Mdot
.08675 .20137 Mdot
.08676 .20135 Mdot
.08677 .20133 Mdot
.08678 .20132 Mdot
.08679 .2013 Mdot
.0868 .20129 Mdot
.08681 .20127 Mdot
.08682 .20126 Mdot
.08683 .20124 Mdot
.08684 .20123 Mdot
.08685 .20121 Mdot
.08686 .2012 Mdot
.08687 .20118 Mdot
.08688 .20117 Mdot
.08689 .20115 Mdot
.0869 .20113 Mdot
.0869 .20112 Mdot
.08691 .2011 Mdot
.08692 .20109 Mdot
.08693 .20107 Mdot
.08694 .20106 Mdot
.08695 .20104 Mdot
.08696 .20103 Mdot
.08697 .20101 Mdot
.08698 .201 Mdot
.08699 .20098 Mdot
.087 .20096 Mdot
.08701 .20095 Mdot
.08702 .20093 Mdot
.08703 .20092 Mdot
.08704 .2009 Mdot
.08705 .20089 Mdot
.08706 .20087 Mdot
.08707 .20086 Mdot
.08708 .20084 Mdot
.08709 .20083 Mdot
.0871 .20081 Mdot
.0871 .2008 Mdot
.08711 .20078 Mdot
.08712 .20076 Mdot
.08713 .20075 Mdot
.08714 .20073 Mdot
.08715 .20072 Mdot
.08716 .2007 Mdot
.08717 .20069 Mdot
.08718 .20067 Mdot
.08719 .20066 Mdot
.0872 .20064 Mdot
.08721 .20063 Mdot
.08722 .20061 Mdot
.08723 .2006 Mdot
.08724 .20058 Mdot
.08725 .20056 Mdot
.08726 .20055 Mdot
.08727 .20053 Mdot
.08728 .20052 Mdot
.08729 .2005 Mdot
.0873 .20049 Mdot
.0873 .20047 Mdot
.08731 .20046 Mdot
.08732 .20044 Mdot
.08733 .20043 Mdot
.08734 .20041 Mdot
.08735 .2004 Mdot
.08736 .20038 Mdot
.08737 .20036 Mdot
.08738 .20035 Mdot
.08739 .20033 Mdot
.0874 .20032 Mdot
.08741 .2003 Mdot
.08742 .20029 Mdot
.08743 .20027 Mdot
.08744 .20026 Mdot
.08745 .20024 Mdot
.08746 .20023 Mdot
.08747 .20021 Mdot
.08748 .2002 Mdot
.08749 .20018 Mdot
.0875 .20016 Mdot
.0875 .20015 Mdot
.08751 .20013 Mdot
.08752 .20012 Mdot
.08753 .2001 Mdot
.08754 .20009 Mdot
.08755 .20007 Mdot
.08756 .20006 Mdot
.08757 .20004 Mdot
.08758 .20003 Mdot
.08759 .20001 Mdot
.0876 .2 Mdot
.08761 .19998 Mdot
.08762 .19996 Mdot
.08763 .19995 Mdot
.08764 .19993 Mdot
.08765 .19992 Mdot
.08766 .1999 Mdot
.08767 .19989 Mdot
.08768 .19987 Mdot
.08769 .19986 Mdot
.0877 .19984 Mdot
.0877 .19983 Mdot
.08771 .19981 Mdot
.08772 .1998 Mdot
.08773 .19978 Mdot
.08774 .19976 Mdot
.08775 .19975 Mdot
.08776 .19973 Mdot
.08777 .19972 Mdot
.08778 .1997 Mdot
.08779 .19969 Mdot
.0878 .19967 Mdot
.08781 .19966 Mdot
.08782 .19964 Mdot
.08783 .19963 Mdot
.08784 .19961 Mdot
.08785 .1996 Mdot
.08786 .19958 Mdot
.08787 .19956 Mdot
.08788 .19955 Mdot
.08789 .19953 Mdot
.0879 .19952 Mdot
.0879 .1995 Mdot
.08791 .19949 Mdot
.08792 .19947 Mdot
.08793 .19946 Mdot
.08794 .19944 Mdot
.08795 .19943 Mdot
.08796 .19941 Mdot
.08797 .1994 Mdot
.08798 .19938 Mdot
.08799 .19936 Mdot
.088 .19935 Mdot
.08801 .19933 Mdot
.08802 .19932 Mdot
.08803 .1993 Mdot
.08804 .19929 Mdot
.08805 .19927 Mdot
.08806 .19926 Mdot
.08807 .19924 Mdot
.08808 .19923 Mdot
.08809 .19921 Mdot
.0881 .1992 Mdot
.0881 .19918 Mdot
.08811 .19917 Mdot
.08812 .19915 Mdot
.08813 .19913 Mdot
.08814 .19912 Mdot
.08815 .1991 Mdot
.08816 .19909 Mdot
.08817 .19907 Mdot
.08818 .19906 Mdot
.08819 .19904 Mdot
.0882 .19903 Mdot
.08821 .19901 Mdot
.08822 .199 Mdot
.08823 .19898 Mdot
.08824 .19897 Mdot
.08825 .19895 Mdot
.08826 .19893 Mdot
.08827 .19892 Mdot
.08828 .1989 Mdot
.08829 .19889 Mdot
.0883 .19887 Mdot
.0883 .19886 Mdot
.08831 .19884 Mdot
.08832 .19883 Mdot
.08833 .19881 Mdot
.08834 .1988 Mdot
.08835 .19878 Mdot
.08836 .19877 Mdot
.08837 .19875 Mdot
.08838 .19874 Mdot
.08839 .19872 Mdot
.0884 .1987 Mdot
.08841 .19869 Mdot
.08842 .19867 Mdot
.08843 .19866 Mdot
.08844 .19864 Mdot
.08845 .19863 Mdot
.08846 .19861 Mdot
.08847 .1986 Mdot
.08848 .19858 Mdot
.08849 .19857 Mdot
.0885 .19855 Mdot
.0885 .19854 Mdot
.08851 .19852 Mdot
.08852 .1985 Mdot
.08853 .19849 Mdot
.08854 .19847 Mdot
.08855 .19846 Mdot
.08856 .19844 Mdot
.08857 .19843 Mdot
.08858 .19841 Mdot
.08859 .1984 Mdot
.0886 .19838 Mdot
.08861 .19837 Mdot
.08862 .19835 Mdot
.08863 .19834 Mdot
.08864 .19832 Mdot
.08865 .19831 Mdot
.08866 .19829 Mdot
.08867 .19827 Mdot
.08868 .19826 Mdot
.08869 .19824 Mdot
.0887 .19823 Mdot
.0887 .19821 Mdot
.08871 .1982 Mdot
.08872 .19818 Mdot
.08873 .19817 Mdot
.08874 .19815 Mdot
.08875 .19814 Mdot
.08876 .19812 Mdot
.08877 .19811 Mdot
.08878 .19809 Mdot
.08879 .19808 Mdot
.0888 .19806 Mdot
.08881 .19804 Mdot
.08882 .19803 Mdot
.08883 .19801 Mdot
.08884 .198 Mdot
.08885 .19798 Mdot
.08886 .19797 Mdot
.08887 .19795 Mdot
.08888 .19794 Mdot
.08889 .19792 Mdot
.0889 .19791 Mdot
.0889 .19789 Mdot
.08891 .19788 Mdot
.08892 .19786 Mdot
.08893 .19785 Mdot
.08894 .19783 Mdot
.08895 .19781 Mdot
.08896 .1978 Mdot
.08897 .19778 Mdot
.08898 .19777 Mdot
.08899 .19775 Mdot
.089 .19774 Mdot
.08901 .19772 Mdot
.08902 .19771 Mdot
.08903 .19769 Mdot
.08904 .19768 Mdot
.08905 .19766 Mdot
.08906 .19765 Mdot
.08907 .19763 Mdot
.08908 .19762 Mdot
.08909 .1976 Mdot
.0891 .19758 Mdot
.0891 .19757 Mdot
.08911 .19755 Mdot
.08912 .19754 Mdot
.08913 .19752 Mdot
.08914 .19751 Mdot
.08915 .19749 Mdot
.08916 .19748 Mdot
.08917 .19746 Mdot
.08918 .19745 Mdot
.08919 .19743 Mdot
.0892 .19742 Mdot
.08921 .1974 Mdot
.08922 .19739 Mdot
.08923 .19737 Mdot
.08924 .19735 Mdot
.08925 .19734 Mdot
.08926 .19732 Mdot
.08927 .19731 Mdot
.08928 .19729 Mdot
.08929 .19728 Mdot
.0893 .19726 Mdot
.0893 .19725 Mdot
.08931 .19723 Mdot
.08932 .19722 Mdot
.08933 .1972 Mdot
.08934 .19719 Mdot
.08935 .19717 Mdot
.08936 .19716 Mdot
.08937 .19714 Mdot
.08938 .19712 Mdot
.08939 .19711 Mdot
.0894 .19709 Mdot
.08941 .19708 Mdot
.08942 .19706 Mdot
.08943 .19705 Mdot
.08944 .19703 Mdot
.08945 .19702 Mdot
.08946 .197 Mdot
.08947 .19699 Mdot
.08948 .19697 Mdot
.08949 .19696 Mdot
.0895 .19694 Mdot
.0895 .19693 Mdot
.08951 .19691 Mdot
.08952 .19689 Mdot
.08953 .19688 Mdot
.08954 .19686 Mdot
.08955 .19685 Mdot
.08956 .19683 Mdot
.08957 .19682 Mdot
.08958 .1968 Mdot
.08959 .19679 Mdot
.0896 .19677 Mdot
.08961 .19676 Mdot
.08962 .19674 Mdot
.08963 .19673 Mdot
.08964 .19671 Mdot
.08965 .1967 Mdot
.08966 .19668 Mdot
.08967 .19667 Mdot
.08968 .19665 Mdot
.08969 .19663 Mdot
.0897 .19662 Mdot
.0897 .1966 Mdot
.08971 .19659 Mdot
.08972 .19657 Mdot
.08973 .19656 Mdot
.08974 .19654 Mdot
.08975 .19653 Mdot
.08976 .19651 Mdot
.08977 .1965 Mdot
.08978 .19648 Mdot
.08979 .19647 Mdot
.0898 .19645 Mdot
.08981 .19644 Mdot
.08982 .19642 Mdot
.08983 .19641 Mdot
.08984 .19639 Mdot
.08985 .19637 Mdot
.08986 .19636 Mdot
.08987 .19634 Mdot
.08988 .19633 Mdot
.08989 .19631 Mdot
.0899 .1963 Mdot
.0899 .19628 Mdot
.08991 .19627 Mdot
.08992 .19625 Mdot
.08993 .19624 Mdot
.08994 .19622 Mdot
.08995 .19621 Mdot
.08996 .19619 Mdot
.08997 .19618 Mdot
.08998 .19616 Mdot
.08999 .19614 Mdot
.09 .19613 Mdot
.09001 .19611 Mdot
.09002 .1961 Mdot
.09003 .19608 Mdot
.09004 .19607 Mdot
.09005 .19605 Mdot
.09006 .19604 Mdot
.09007 .19602 Mdot
.09008 .19601 Mdot
.09009 .19599 Mdot
.0901 .19598 Mdot
.0901 .19596 Mdot
.09011 .19595 Mdot
.09012 .19593 Mdot
.09013 .19592 Mdot
.09014 .1959 Mdot
.09015 .19588 Mdot
.09016 .19587 Mdot
.09017 .19585 Mdot
.09018 .19584 Mdot
.09019 .19582 Mdot
.0902 .19581 Mdot
.09021 .19579 Mdot
.09022 .19578 Mdot
.09023 .19576 Mdot
.09024 .19575 Mdot
.09025 .19573 Mdot
.09026 .19572 Mdot
.09027 .1957 Mdot
.09028 .19569 Mdot
.09029 .19567 Mdot
.0903 .19566 Mdot
.0903 .19564 Mdot
.09031 .19563 Mdot
.09032 .19561 Mdot
.09033 .19559 Mdot
.09034 .19558 Mdot
.09035 .19556 Mdot
.09036 .19555 Mdot
.09037 .19553 Mdot
.09038 .19552 Mdot
.09039 .1955 Mdot
.0904 .19549 Mdot
.09041 .19547 Mdot
.09042 .19546 Mdot
.09043 .19544 Mdot
.09044 .19543 Mdot
.09045 .19541 Mdot
.09046 .1954 Mdot
.09047 .19538 Mdot
.09048 .19537 Mdot
.09049 .19535 Mdot
.0905 .19533 Mdot
.0905 .19532 Mdot
.09051 .1953 Mdot
.09052 .19529 Mdot
.09053 .19527 Mdot
.09054 .19526 Mdot
.09055 .19524 Mdot
.09056 .19523 Mdot
.09057 .19521 Mdot
.09058 .1952 Mdot
.09059 .19518 Mdot
.0906 .19517 Mdot
.09061 .19515 Mdot
.09062 .19514 Mdot
.09063 .19512 Mdot
.09064 .19511 Mdot
.09065 .19509 Mdot
.09066 .19507 Mdot
.09067 .19506 Mdot
.09068 .19504 Mdot
.09069 .19503 Mdot
.0907 .19501 Mdot
.0907 .195 Mdot
.09071 .19498 Mdot
.09072 .19497 Mdot
.09073 .19495 Mdot
.09074 .19494 Mdot
.09075 .19492 Mdot
.09076 .19491 Mdot
.09077 .19489 Mdot
.09078 .19488 Mdot
.09079 .19486 Mdot
.0908 .19485 Mdot
.09081 .19483 Mdot
.09082 .19482 Mdot
.09083 .1948 Mdot
.09084 .19478 Mdot
.09085 .19477 Mdot
.09086 .19475 Mdot
.09087 .19474 Mdot
.09088 .19472 Mdot
.09089 .19471 Mdot
.0909 .19469 Mdot
.0909 .19468 Mdot
.09091 .19466 Mdot
.09092 .19465 Mdot
.09093 .19463 Mdot
.09094 .19462 Mdot
.09095 .1946 Mdot
.09096 .19459 Mdot
.09097 .19457 Mdot
.09098 .19456 Mdot
.09099 .19454 Mdot
.091 .19453 Mdot
.09101 .19451 Mdot
.09102 .19449 Mdot
.09103 .19448 Mdot
.09104 .19446 Mdot
.09105 .19445 Mdot
.09106 .19443 Mdot
.09107 .19442 Mdot
.09108 .1944 Mdot
.09109 .19439 Mdot
.0911 .19437 Mdot
.0911 .19436 Mdot
.09111 .19434 Mdot
.09112 .19433 Mdot
.09113 .19431 Mdot
.09114 .1943 Mdot
.09115 .19428 Mdot
.09116 .19427 Mdot
.09117 .19425 Mdot
.09118 .19424 Mdot
.09119 .19422 Mdot
.0912 .1942 Mdot
.09121 .19419 Mdot
.09122 .19417 Mdot
.09123 .19416 Mdot
.09124 .19414 Mdot
.09125 .19413 Mdot
.09126 .19411 Mdot
.09127 .1941 Mdot
.09128 .19408 Mdot
.09129 .19407 Mdot
.0913 .19405 Mdot
.0913 .19404 Mdot
.09131 .19402 Mdot
.09132 .19401 Mdot
.09133 .19399 Mdot
.09134 .19398 Mdot
.09135 .19396 Mdot
.09136 .19395 Mdot
.09137 .19393 Mdot
.09138 .19392 Mdot
.09139 .1939 Mdot
.0914 .19388 Mdot
.09141 .19387 Mdot
.09142 .19385 Mdot
.09143 .19384 Mdot
.09144 .19382 Mdot
.09145 .19381 Mdot
.09146 .19379 Mdot
.09147 .19378 Mdot
.09148 .19376 Mdot
.09149 .19375 Mdot
.0915 .19373 Mdot
.0915 .19372 Mdot
.09151 .1937 Mdot
.09152 .19369 Mdot
.09153 .19367 Mdot
.09154 .19366 Mdot
.09155 .19364 Mdot
.09156 .19363 Mdot
.09157 .19361 Mdot
.09158 .19359 Mdot
.09159 .19358 Mdot
.0916 .19356 Mdot
.09161 .19355 Mdot
.09162 .19353 Mdot
.09163 .19352 Mdot
.09164 .1935 Mdot
.09165 .19349 Mdot
.09166 .19347 Mdot
.09167 .19346 Mdot
.09168 .19344 Mdot
.09169 .19343 Mdot
.0917 .19341 Mdot
.0917 .1934 Mdot
.09171 .19338 Mdot
.09172 .19337 Mdot
.09173 .19335 Mdot
.09174 .19334 Mdot
.09175 .19332 Mdot
.09176 .19331 Mdot
.09177 .19329 Mdot
.09178 .19327 Mdot
.09179 .19326 Mdot
.0918 .19324 Mdot
.09181 .19323 Mdot
.09182 .19321 Mdot
.09183 .1932 Mdot
.09184 .19318 Mdot
.09185 .19317 Mdot
.09186 .19315 Mdot
.09187 .19314 Mdot
.09188 .19312 Mdot
.09189 .19311 Mdot
.0919 .19309 Mdot
.0919 .19308 Mdot
.09191 .19306 Mdot
.09192 .19305 Mdot
.09193 .19303 Mdot
.09194 .19302 Mdot
.09195 .193 Mdot
.09196 .19299 Mdot
.09197 .19297 Mdot
.09198 .19296 Mdot
.09199 .19294 Mdot
.092 .19292 Mdot
.09201 .19291 Mdot
.09202 .19289 Mdot
.09203 .19288 Mdot
.09204 .19286 Mdot
.09205 .19285 Mdot
.09206 .19283 Mdot
.09207 .19282 Mdot
.09208 .1928 Mdot
.09209 .19279 Mdot
.0921 .19277 Mdot
.0921 .19276 Mdot
.09211 .19274 Mdot
.09212 .19273 Mdot
.09213 .19271 Mdot
.09214 .1927 Mdot
.09215 .19268 Mdot
.09216 .19267 Mdot
.09217 .19265 Mdot
.09218 .19264 Mdot
.09219 .19262 Mdot
.0922 .19261 Mdot
.09221 .19259 Mdot
.09222 .19257 Mdot
.09223 .19256 Mdot
.09224 .19254 Mdot
.09225 .19253 Mdot
.09226 .19251 Mdot
.09227 .1925 Mdot
.09228 .19248 Mdot
.09229 .19247 Mdot
.0923 .19245 Mdot
.0923 .19244 Mdot
.09231 .19242 Mdot
.09232 .19241 Mdot
.09233 .19239 Mdot
.09234 .19238 Mdot
.09235 .19236 Mdot
.09236 .19235 Mdot
.09237 .19233 Mdot
.09238 .19232 Mdot
.09239 .1923 Mdot
.0924 .19229 Mdot
.09241 .19227 Mdot
.09242 .19226 Mdot
.09243 .19224 Mdot
.09244 .19222 Mdot
.09245 .19221 Mdot
.09246 .19219 Mdot
.09247 .19218 Mdot
.09248 .19216 Mdot
.09249 .19215 Mdot
.0925 .19213 Mdot
.0925 .19212 Mdot
.09251 .1921 Mdot
.09252 .19209 Mdot
.09253 .19207 Mdot
.09254 .19206 Mdot
.09255 .19204 Mdot
.09256 .19203 Mdot
.09257 .19201 Mdot
.09258 .192 Mdot
.09259 .19198 Mdot
.0926 .19197 Mdot
.09261 .19195 Mdot
.09262 .19194 Mdot
.09263 .19192 Mdot
.09264 .19191 Mdot
.09265 .19189 Mdot
.09266 .19187 Mdot
.09267 .19186 Mdot
.09268 .19184 Mdot
.09269 .19183 Mdot
.0927 .19181 Mdot
.0927 .1918 Mdot
.09271 .19178 Mdot
.09272 .19177 Mdot
.09273 .19175 Mdot
.09274 .19174 Mdot
.09275 .19172 Mdot
.09276 .19171 Mdot
.09277 .19169 Mdot
.09278 .19168 Mdot
.09279 .19166 Mdot
.0928 .19165 Mdot
.09281 .19163 Mdot
.09282 .19162 Mdot
.09283 .1916 Mdot
.09284 .19159 Mdot
.09285 .19157 Mdot
.09286 .19156 Mdot
.09287 .19154 Mdot
.09288 .19153 Mdot
.09289 .19151 Mdot
.0929 .1915 Mdot
.0929 .19148 Mdot
.09291 .19146 Mdot
.09292 .19145 Mdot
.09293 .19143 Mdot
.09294 .19142 Mdot
.09295 .1914 Mdot
.09296 .19139 Mdot
.09297 .19137 Mdot
.09298 .19136 Mdot
.09299 .19134 Mdot
.093 .19133 Mdot
.09301 .19131 Mdot
.09302 .1913 Mdot
.09303 .19128 Mdot
.09304 .19127 Mdot
.09305 .19125 Mdot
.09306 .19124 Mdot
.09307 .19122 Mdot
.09308 .19121 Mdot
.09309 .19119 Mdot
.0931 .19118 Mdot
.0931 .19116 Mdot
.09311 .19115 Mdot
.09312 .19113 Mdot
.09313 .19112 Mdot
.09314 .1911 Mdot
.09315 .19108 Mdot
.09316 .19107 Mdot
.09317 .19105 Mdot
.09318 .19104 Mdot
.09319 .19102 Mdot
.0932 .19101 Mdot
.09321 .19099 Mdot
.09322 .19098 Mdot
.09323 .19096 Mdot
.09324 .19095 Mdot
.09325 .19093 Mdot
.09326 .19092 Mdot
.09327 .1909 Mdot
.09328 .19089 Mdot
.09329 .19087 Mdot
.0933 .19086 Mdot
.0933 .19084 Mdot
.09331 .19083 Mdot
.09332 .19081 Mdot
.09333 .1908 Mdot
.09334 .19078 Mdot
.09335 .19077 Mdot
.09336 .19075 Mdot
.09337 .19074 Mdot
.09338 .19072 Mdot
.09339 .19071 Mdot
.0934 .19069 Mdot
.09341 .19068 Mdot
.09342 .19066 Mdot
.09343 .19064 Mdot
.09344 .19063 Mdot
.09345 .19061 Mdot
.09346 .1906 Mdot
.09347 .19058 Mdot
.09348 .19057 Mdot
.09349 .19055 Mdot
.0935 .19054 Mdot
.0935 .19052 Mdot
.09351 .19051 Mdot
.09352 .19049 Mdot
.09353 .19048 Mdot
.09354 .19046 Mdot
.09355 .19045 Mdot
.09356 .19043 Mdot
.09357 .19042 Mdot
.09358 .1904 Mdot
.09359 .19039 Mdot
.0936 .19037 Mdot
.09361 .19036 Mdot
.09362 .19034 Mdot
.09363 .19033 Mdot
.09364 .19031 Mdot
.09365 .1903 Mdot
.09366 .19028 Mdot
.09367 .19027 Mdot
.09368 .19025 Mdot
.09369 .19024 Mdot
.0937 .19022 Mdot
.0937 .1902 Mdot
.09371 .19019 Mdot
.09372 .19017 Mdot
.09373 .19016 Mdot
.09374 .19014 Mdot
.09375 .19013 Mdot
.09376 .19011 Mdot
.09377 .1901 Mdot
.09378 .19008 Mdot
.09379 .19007 Mdot
.0938 .19005 Mdot
.09381 .19004 Mdot
.09382 .19002 Mdot
.09383 .19001 Mdot
.09384 .18999 Mdot
.09385 .18998 Mdot
.09386 .18996 Mdot
.09387 .18995 Mdot
.09388 .18993 Mdot
.09389 .18992 Mdot
.0939 .1899 Mdot
.0939 .18989 Mdot
.09391 .18987 Mdot
.09392 .18986 Mdot
.09393 .18984 Mdot
.09394 .18983 Mdot
.09395 .18981 Mdot
.09396 .1898 Mdot
.09397 .18978 Mdot
.09398 .18977 Mdot
.09399 .18975 Mdot
.094 .18974 Mdot
.09401 .18972 Mdot
.09402 .1897 Mdot
.09403 .18969 Mdot
.09404 .18967 Mdot
.09405 .18966 Mdot
.09406 .18964 Mdot
.09407 .18963 Mdot
.09408 .18961 Mdot
.09409 .1896 Mdot
.0941 .18958 Mdot
.0941 .18957 Mdot
.09411 .18955 Mdot
.09412 .18954 Mdot
.09413 .18952 Mdot
.09414 .18951 Mdot
.09415 .18949 Mdot
.09416 .18948 Mdot
.09417 .18946 Mdot
.09418 .18945 Mdot
.09419 .18943 Mdot
.0942 .18942 Mdot
.09421 .1894 Mdot
.09422 .18939 Mdot
.09423 .18937 Mdot
.09424 .18936 Mdot
.09425 .18934 Mdot
.09426 .18933 Mdot
.09427 .18931 Mdot
.09428 .1893 Mdot
.09429 .18928 Mdot
.0943 .18927 Mdot
.0943 .18925 Mdot
.09431 .18924 Mdot
.09432 .18922 Mdot
.09433 .18921 Mdot
.09434 .18919 Mdot
.09435 .18917 Mdot
.09436 .18916 Mdot
.09437 .18914 Mdot
.09438 .18913 Mdot
.09439 .18911 Mdot
.0944 .1891 Mdot
.09441 .18908 Mdot
.09442 .18907 Mdot
.09443 .18905 Mdot
.09444 .18904 Mdot
.09445 .18902 Mdot
.09446 .18901 Mdot
.09447 .18899 Mdot
.09448 .18898 Mdot
.09449 .18896 Mdot
.0945 .18895 Mdot
.0945 .18893 Mdot
.09451 .18892 Mdot
.09452 .1889 Mdot
.09453 .18889 Mdot
.09454 .18887 Mdot
.09455 .18886 Mdot
.09456 .18884 Mdot
.09457 .18883 Mdot
.09458 .18881 Mdot
.09459 .1888 Mdot
.0946 .18878 Mdot
.09461 .18877 Mdot
.09462 .18875 Mdot
.09463 .18874 Mdot
.09464 .18872 Mdot
.09465 .18871 Mdot
.09466 .18869 Mdot
.09467 .18868 Mdot
.09468 .18866 Mdot
.09469 .18865 Mdot
.0947 .18863 Mdot
.0947 .18861 Mdot
.09471 .1886 Mdot
.09472 .18858 Mdot
.09473 .18857 Mdot
.09474 .18855 Mdot
.09475 .18854 Mdot
.09476 .18852 Mdot
.09477 .18851 Mdot
.09478 .18849 Mdot
.09479 .18848 Mdot
.0948 .18846 Mdot
.09481 .18845 Mdot
.09482 .18843 Mdot
.09483 .18842 Mdot
.09484 .1884 Mdot
.09485 .18839 Mdot
.09486 .18837 Mdot
.09487 .18836 Mdot
.09488 .18834 Mdot
.09489 .18833 Mdot
.0949 .18831 Mdot
.0949 .1883 Mdot
.09491 .18828 Mdot
.09492 .18827 Mdot
.09493 .18825 Mdot
.09494 .18824 Mdot
.09495 .18822 Mdot
.09496 .18821 Mdot
.09497 .18819 Mdot
.09498 .18818 Mdot
.09499 .18816 Mdot
.095 .18815 Mdot
.09501 .18813 Mdot
.09502 .18812 Mdot
.09503 .1881 Mdot
.09504 .18809 Mdot
.09505 .18807 Mdot
.09506 .18806 Mdot
.09507 .18804 Mdot
.09508 .18803 Mdot
.09509 .18801 Mdot
.0951 .188 Mdot
.0951 .18798 Mdot
.09511 .18796 Mdot
.09512 .18795 Mdot
.09513 .18793 Mdot
.09514 .18792 Mdot
.09515 .1879 Mdot
.09516 .18789 Mdot
.09517 .18787 Mdot
.09518 .18786 Mdot
.09519 .18784 Mdot
.0952 .18783 Mdot
.09521 .18781 Mdot
.09522 .1878 Mdot
.09523 .18778 Mdot
.09524 .18777 Mdot
.09525 .18775 Mdot
.09526 .18774 Mdot
.09527 .18772 Mdot
.09528 .18771 Mdot
.09529 .18769 Mdot
.0953 .18768 Mdot
.0953 .18766 Mdot
.09531 .18765 Mdot
.09532 .18763 Mdot
.09533 .18762 Mdot
.09534 .1876 Mdot
.09535 .18759 Mdot
.09536 .18757 Mdot
.09537 .18756 Mdot
.09538 .18754 Mdot
.09539 .18753 Mdot
.0954 .18751 Mdot
.09541 .1875 Mdot
.09542 .18748 Mdot
.09543 .18747 Mdot
.09544 .18745 Mdot
.09545 .18744 Mdot
.09546 .18742 Mdot
.09547 .18741 Mdot
.09548 .18739 Mdot
.09549 .18738 Mdot
.0955 .18736 Mdot
.0955 .18735 Mdot
.09551 .18733 Mdot
.09552 .18732 Mdot
.09553 .1873 Mdot
.09554 .18729 Mdot
.09555 .18727 Mdot
.09556 .18726 Mdot
.09557 .18724 Mdot
.09558 .18722 Mdot
.09559 .18721 Mdot
.0956 .18719 Mdot
.09561 .18718 Mdot
.09562 .18716 Mdot
.09563 .18715 Mdot
.09564 .18713 Mdot
.09565 .18712 Mdot
.09566 .1871 Mdot
.09567 .18709 Mdot
.09568 .18707 Mdot
.09569 .18706 Mdot
.0957 .18704 Mdot
.0957 .18703 Mdot
.09571 .18701 Mdot
.09572 .187 Mdot
.09573 .18698 Mdot
.09574 .18697 Mdot
.09575 .18695 Mdot
.09576 .18694 Mdot
.09577 .18692 Mdot
.09578 .18691 Mdot
.09579 .18689 Mdot
.0958 .18688 Mdot
.09581 .18686 Mdot
.09582 .18685 Mdot
.09583 .18683 Mdot
.09584 .18682 Mdot
.09585 .1868 Mdot
.09586 .18679 Mdot
.09587 .18677 Mdot
.09588 .18676 Mdot
.09589 .18674 Mdot
.0959 .18673 Mdot
.0959 .18671 Mdot
.09591 .1867 Mdot
.09592 .18668 Mdot
.09593 .18667 Mdot
.09594 .18665 Mdot
.09595 .18664 Mdot
.09596 .18662 Mdot
.09597 .18661 Mdot
.09598 .18659 Mdot
.09599 .18658 Mdot
.096 .18656 Mdot
.09601 .18655 Mdot
.09602 .18653 Mdot
.09603 .18652 Mdot
.09604 .1865 Mdot
.09605 .18649 Mdot
.09606 .18647 Mdot
.09607 .18646 Mdot
.09608 .18644 Mdot
.09609 .18643 Mdot
.0961 .18641 Mdot
.0961 .1864 Mdot
.09611 .18638 Mdot
.09612 .18637 Mdot
.09613 .18635 Mdot
.09614 .18634 Mdot
.09615 .18632 Mdot
.09616 .1863 Mdot
.09617 .18629 Mdot
.09618 .18627 Mdot
.09619 .18626 Mdot
.0962 .18624 Mdot
.09621 .18623 Mdot
.09622 .18621 Mdot
.09623 .1862 Mdot
.09624 .18618 Mdot
.09625 .18617 Mdot
.09626 .18615 Mdot
.09627 .18614 Mdot
.09628 .18612 Mdot
.09629 .18611 Mdot
.0963 .18609 Mdot
.0963 .18608 Mdot
.09631 .18606 Mdot
.09632 .18605 Mdot
.09633 .18603 Mdot
.09634 .18602 Mdot
.09635 .186 Mdot
.09636 .18599 Mdot
.09637 .18597 Mdot
.09638 .18596 Mdot
.09639 .18594 Mdot
.0964 .18593 Mdot
.09641 .18591 Mdot
.09642 .1859 Mdot
.09643 .18588 Mdot
.09644 .18587 Mdot
.09645 .18585 Mdot
.09646 .18584 Mdot
.09647 .18582 Mdot
.09648 .18581 Mdot
.09649 .18579 Mdot
.0965 .18578 Mdot
.0965 .18576 Mdot
.09651 .18575 Mdot
.09652 .18573 Mdot
.09653 .18572 Mdot
.09654 .1857 Mdot
.09655 .18569 Mdot
.09656 .18567 Mdot
.09657 .18566 Mdot
.09658 .18564 Mdot
.09659 .18563 Mdot
.0966 .18561 Mdot
.09661 .1856 Mdot
.09662 .18558 Mdot
.09663 .18557 Mdot
.09664 .18555 Mdot
.09665 .18554 Mdot
.09666 .18552 Mdot
.09667 .18551 Mdot
.09668 .18549 Mdot
.09669 .18548 Mdot
.0967 .18546 Mdot
.0967 .18545 Mdot
.09671 .18543 Mdot
.09672 .18542 Mdot
.09673 .1854 Mdot
.09674 .18539 Mdot
.09675 .18537 Mdot
.09676 .18536 Mdot
.09677 .18534 Mdot
.09678 .18533 Mdot
.09679 .18531 Mdot
.0968 .1853 Mdot
.09681 .18528 Mdot
.09682 .18527 Mdot
.09683 .18525 Mdot
.09684 .18524 Mdot
.09685 .18522 Mdot
.09686 .18521 Mdot
.09687 .18519 Mdot
.09688 .18518 Mdot
.09689 .18516 Mdot
.0969 .18515 Mdot
.0969 .18513 Mdot
.09691 .18512 Mdot
.09692 .1851 Mdot
.09693 .18509 Mdot
.09694 .18507 Mdot
.09695 .18506 Mdot
.09696 .18504 Mdot
.09697 .18503 Mdot
.09698 .18501 Mdot
.09699 .185 Mdot
.097 .18498 Mdot
.09701 .18497 Mdot
.09702 .18495 Mdot
.09703 .18494 Mdot
.09704 .18492 Mdot
.09705 .18491 Mdot
.09706 .18489 Mdot
.09707 .18488 Mdot
.09708 .18486 Mdot
.09709 .18485 Mdot
.0971 .18483 Mdot
.0971 .18481 Mdot
.09711 .1848 Mdot
.09712 .18478 Mdot
.09713 .18477 Mdot
.09714 .18475 Mdot
.09715 .18474 Mdot
.09716 .18472 Mdot
.09717 .18471 Mdot
.09718 .18469 Mdot
.09719 .18468 Mdot
.0972 .18466 Mdot
.09721 .18465 Mdot
.09722 .18463 Mdot
.09723 .18462 Mdot
.09724 .1846 Mdot
.09725 .18459 Mdot
.09726 .18457 Mdot
.09727 .18456 Mdot
.09728 .18454 Mdot
.09729 .18453 Mdot
.0973 .18451 Mdot
.0973 .1845 Mdot
.09731 .18448 Mdot
.09732 .18447 Mdot
.09733 .18445 Mdot
.09734 .18444 Mdot
.09735 .18442 Mdot
.09736 .18441 Mdot
.09737 .18439 Mdot
.09738 .18438 Mdot
.09739 .18436 Mdot
.0974 .18435 Mdot
.09741 .18433 Mdot
.09742 .18432 Mdot
.09743 .1843 Mdot
.09744 .18429 Mdot
.09745 .18427 Mdot
.09746 .18426 Mdot
.09747 .18424 Mdot
.09748 .18423 Mdot
.09749 .18421 Mdot
.0975 .1842 Mdot
.0975 .18418 Mdot
.09751 .18417 Mdot
.09752 .18415 Mdot
.09753 .18414 Mdot
.09754 .18412 Mdot
.09755 .18411 Mdot
.09756 .18409 Mdot
.09757 .18408 Mdot
.09758 .18406 Mdot
.09759 .18405 Mdot
.0976 .18403 Mdot
.09761 .18402 Mdot
.09762 .184 Mdot
.09763 .18399 Mdot
.09764 .18397 Mdot
.09765 .18396 Mdot
.09766 .18394 Mdot
.09767 .18393 Mdot
.09768 .18391 Mdot
.09769 .1839 Mdot
.0977 .18388 Mdot
.0977 .18387 Mdot
.09771 .18385 Mdot
.09772 .18384 Mdot
.09773 .18382 Mdot
.09774 .18381 Mdot
.09775 .18379 Mdot
.09776 .18378 Mdot
.09777 .18376 Mdot
.09778 .18375 Mdot
.09779 .18373 Mdot
.0978 .18372 Mdot
.09781 .1837 Mdot
.09782 .18369 Mdot
.09783 .18367 Mdot
.09784 .18366 Mdot
.09785 .18364 Mdot
.09786 .18363 Mdot
.09787 .18361 Mdot
.09788 .1836 Mdot
.09789 .18358 Mdot
.0979 .18357 Mdot
.0979 .18355 Mdot
.09791 .18354 Mdot
.09792 .18352 Mdot
.09793 .18351 Mdot
.09794 .18349 Mdot
.09795 .18348 Mdot
.09796 .18346 Mdot
.09797 .18345 Mdot
.09798 .18343 Mdot
.09799 .18342 Mdot
.098 .1834 Mdot
.09801 .18339 Mdot
.09802 .18337 Mdot
.09803 .18336 Mdot
.09804 .18334 Mdot
.09805 .18333 Mdot
.09806 .18331 Mdot
.09807 .1833 Mdot
.09808 .18328 Mdot
.09809 .18327 Mdot
.0981 .18325 Mdot
.0981 .18324 Mdot
.09811 .18322 Mdot
.09812 .18321 Mdot
.09813 .18319 Mdot
.09814 .18318 Mdot
.09815 .18316 Mdot
.09816 .18315 Mdot
.09817 .18313 Mdot
.09818 .18312 Mdot
.09819 .1831 Mdot
.0982 .18309 Mdot
.09821 .18307 Mdot
.09822 .18306 Mdot
.09823 .18304 Mdot
.09824 .18303 Mdot
.09825 .18301 Mdot
.09826 .183 Mdot
.09827 .18298 Mdot
.09828 .18297 Mdot
.09829 .18295 Mdot
.0983 .18294 Mdot
.0983 .18292 Mdot
.09831 .18291 Mdot
.09832 .18289 Mdot
.09833 .18288 Mdot
.09834 .18286 Mdot
.09835 .18285 Mdot
.09836 .18283 Mdot
.09837 .18282 Mdot
.09838 .1828 Mdot
.09839 .18279 Mdot
.0984 .18277 Mdot
.09841 .18276 Mdot
.09842 .18274 Mdot
.09843 .18273 Mdot
.09844 .18271 Mdot
.09845 .1827 Mdot
.09846 .18268 Mdot
.09847 .18267 Mdot
.09848 .18265 Mdot
.09849 .18264 Mdot
.0985 .18262 Mdot
.0985 .18261 Mdot
.09851 .18259 Mdot
.09852 .18258 Mdot
.09853 .18256 Mdot
.09854 .18255 Mdot
.09855 .18253 Mdot
.09856 .18252 Mdot
.09857 .1825 Mdot
.09858 .18249 Mdot
.09859 .18247 Mdot
.0986 .18246 Mdot
.09861 .18244 Mdot
.09862 .18243 Mdot
.09863 .18241 Mdot
.09864 .1824 Mdot
.09865 .18238 Mdot
.09866 .18237 Mdot
.09867 .18235 Mdot
.09868 .18234 Mdot
.09869 .18232 Mdot
.0987 .18231 Mdot
.0987 .18229 Mdot
.09871 .18228 Mdot
.09872 .18226 Mdot
.09873 .18225 Mdot
.09874 .18223 Mdot
.09875 .18222 Mdot
.09876 .1822 Mdot
.09877 .18219 Mdot
.09878 .18218 Mdot
.09879 .18216 Mdot
.0988 .18215 Mdot
.09881 .18213 Mdot
.09882 .18212 Mdot
.09883 .1821 Mdot
.09884 .18209 Mdot
.09885 .18207 Mdot
.09886 .18206 Mdot
.09887 .18204 Mdot
.09888 .18203 Mdot
.09889 .18201 Mdot
.0989 .182 Mdot
.0989 .18198 Mdot
.09891 .18197 Mdot
.09892 .18195 Mdot
.09893 .18194 Mdot
.09894 .18192 Mdot
.09895 .18191 Mdot
.09896 .18189 Mdot
.09897 .18188 Mdot
.09898 .18186 Mdot
.09899 .18185 Mdot
.099 .18183 Mdot
.09901 .18182 Mdot
.09902 .1818 Mdot
.09903 .18179 Mdot
.09904 .18177 Mdot
.09905 .18176 Mdot
.09906 .18174 Mdot
.09907 .18173 Mdot
.09908 .18171 Mdot
.09909 .1817 Mdot
.0991 .18168 Mdot
.0991 .18167 Mdot
.09911 .18165 Mdot
.09912 .18164 Mdot
.09913 .18162 Mdot
.09914 .18161 Mdot
.09915 .18159 Mdot
.09916 .18158 Mdot
.09917 .18156 Mdot
.09918 .18155 Mdot
.09919 .18153 Mdot
.0992 .18152 Mdot
.09921 .1815 Mdot
.09922 .18149 Mdot
.09923 .18147 Mdot
.09924 .18146 Mdot
.09925 .18144 Mdot
.09926 .18143 Mdot
.09927 .18141 Mdot
.09928 .1814 Mdot
.09929 .18138 Mdot
.0993 .18137 Mdot
.0993 .18135 Mdot
.09931 .18134 Mdot
.09932 .18132 Mdot
.09933 .18131 Mdot
.09934 .18129 Mdot
.09935 .18128 Mdot
.09936 .18126 Mdot
.09937 .18125 Mdot
.09938 .18123 Mdot
.09939 .18122 Mdot
.0994 .1812 Mdot
.09941 .18119 Mdot
.09942 .18117 Mdot
.09943 .18116 Mdot
.09944 .18114 Mdot
.09945 .18113 Mdot
.09946 .18111 Mdot
.09947 .1811 Mdot
.09948 .18108 Mdot
.09949 .18107 Mdot
.0995 .18105 Mdot
.0995 .18104 Mdot
.09951 .18102 Mdot
.09952 .18101 Mdot
.09953 .18099 Mdot
.09954 .18098 Mdot
.09955 .18096 Mdot
.09956 .18095 Mdot
.09957 .18093 Mdot
.09958 .18092 Mdot
.09959 .1809 Mdot
.0996 .18089 Mdot
.09961 .18087 Mdot
.09962 .18086 Mdot
.09963 .18084 Mdot
.09964 .18083 Mdot
.09965 .18081 Mdot
.09966 .1808 Mdot
.09967 .18078 Mdot
.09968 .18077 Mdot
.09969 .18075 Mdot
.0997 .18074 Mdot
.0997 .18073 Mdot
.09971 .18071 Mdot
.09972 .1807 Mdot
.09973 .18068 Mdot
.09974 .18067 Mdot
.09975 .18065 Mdot
.09976 .18064 Mdot
.09977 .18062 Mdot
.09978 .18061 Mdot
.09979 .18059 Mdot
.0998 .18058 Mdot
.09981 .18056 Mdot
.09982 .18055 Mdot
.09983 .18053 Mdot
.09984 .18052 Mdot
.09985 .1805 Mdot
.09986 .18049 Mdot
.09987 .18047 Mdot
.09988 .18046 Mdot
.09989 .18044 Mdot
.0999 .18043 Mdot
.0999 .18041 Mdot
.09991 .1804 Mdot
.09992 .18038 Mdot
.09993 .18037 Mdot
.09994 .18035 Mdot
.09995 .18034 Mdot
.09996 .18032 Mdot
.09997 .18031 Mdot
.09998 .18029 Mdot
.09999 .18028 Mdot
.1 .18026 Mdot
.10001 .18025 Mdot
.10002 .18023 Mdot
.10003 .18022 Mdot
.10004 .1802 Mdot
.10005 .18019 Mdot
.10006 .18017 Mdot
.10007 .18016 Mdot
.10008 .18014 Mdot
.10009 .18013 Mdot
.1001 .18011 Mdot
.1001 .1801 Mdot
.10011 .18008 Mdot
.10012 .18007 Mdot
.10013 .18005 Mdot
.10014 .18004 Mdot
.10015 .18002 Mdot
.10016 .18001 Mdot
.10017 .17999 Mdot
.10018 .17998 Mdot
.10019 .17996 Mdot
.1002 .17995 Mdot
.10021 .17993 Mdot
.10022 .17992 Mdot
.10023 .1799 Mdot
.10024 .17989 Mdot
.10025 .17987 Mdot
.10026 .17986 Mdot
.10027 .17984 Mdot
.10028 .17983 Mdot
.10029 .17982 Mdot
.1003 .1798 Mdot
.1003 .17979 Mdot
.10031 .17977 Mdot
.10032 .17976 Mdot
.10033 .17974 Mdot
.10034 .17973 Mdot
.10035 .17971 Mdot
.10036 .1797 Mdot
.10037 .17968 Mdot
.10038 .17967 Mdot
.10039 .17965 Mdot
.1004 .17964 Mdot
.10041 .17962 Mdot
.10042 .17961 Mdot
.10043 .17959 Mdot
.10044 .17958 Mdot
.10045 .17956 Mdot
.10046 .17955 Mdot
.10047 .17953 Mdot
.10048 .17952 Mdot
.10049 .1795 Mdot
.1005 .17949 Mdot
.1005 .17947 Mdot
.10051 .17946 Mdot
.10052 .17944 Mdot
.10053 .17943 Mdot
.10054 .17941 Mdot
.10055 .1794 Mdot
.10056 .17938 Mdot
.10057 .17937 Mdot
.10058 .17935 Mdot
.10059 .17934 Mdot
.1006 .17932 Mdot
.10061 .17931 Mdot
.10062 .17929 Mdot
.10063 .17928 Mdot
.10064 .17926 Mdot
.10065 .17925 Mdot
.10066 .17923 Mdot
.10067 .17922 Mdot
.10068 .1792 Mdot
.10069 .17919 Mdot
.1007 .17917 Mdot
.1007 .17916 Mdot
.10071 .17914 Mdot
.10072 .17913 Mdot
.10073 .17911 Mdot
.10074 .1791 Mdot
.10075 .17909 Mdot
.10076 .17907 Mdot
.10077 .17906 Mdot
.10078 .17904 Mdot
.10079 .17903 Mdot
.1008 .17901 Mdot
.10081 .179 Mdot
.10082 .17898 Mdot
.10083 .17897 Mdot
.10084 .17895 Mdot
.10085 .17894 Mdot
.10086 .17892 Mdot
.10087 .17891 Mdot
.10088 .17889 Mdot
.10089 .17888 Mdot
.1009 .17886 Mdot
.1009 .17885 Mdot
.10091 .17883 Mdot
.10092 .17882 Mdot
.10093 .1788 Mdot
.10094 .17879 Mdot
.10095 .17877 Mdot
.10096 .17876 Mdot
.10097 .17874 Mdot
.10098 .17873 Mdot
.10099 .17871 Mdot
.101 .1787 Mdot
.10101 .17868 Mdot
.10102 .17867 Mdot
.10103 .17865 Mdot
.10104 .17864 Mdot
.10105 .17862 Mdot
.10106 .17861 Mdot
.10107 .17859 Mdot
.10108 .17858 Mdot
.10109 .17856 Mdot
.1011 .17855 Mdot
.1011 .17853 Mdot
.10111 .17852 Mdot
.10112 .1785 Mdot
.10113 .17849 Mdot
.10114 .17848 Mdot
.10115 .17846 Mdot
.10116 .17845 Mdot
.10117 .17843 Mdot
.10118 .17842 Mdot
.10119 .1784 Mdot
.1012 .17839 Mdot
.10121 .17837 Mdot
.10122 .17836 Mdot
.10123 .17834 Mdot
.10124 .17833 Mdot
.10125 .17831 Mdot
.10126 .1783 Mdot
.10127 .17828 Mdot
.10128 .17827 Mdot
.10129 .17825 Mdot
.1013 .17824 Mdot
.1013 .17822 Mdot
.10131 .17821 Mdot
.10132 .17819 Mdot
.10133 .17818 Mdot
.10134 .17816 Mdot
.10135 .17815 Mdot
.10136 .17813 Mdot
.10137 .17812 Mdot
.10138 .1781 Mdot
.10139 .17809 Mdot
.1014 .17807 Mdot
.10141 .17806 Mdot
.10142 .17804 Mdot
.10143 .17803 Mdot
.10144 .17801 Mdot
.10145 .178 Mdot
.10146 .17798 Mdot
.10147 .17797 Mdot
.10148 .17795 Mdot
.10149 .17794 Mdot
.1015 .17793 Mdot
.1015 .17791 Mdot
.10151 .1779 Mdot
.10152 .17788 Mdot
.10153 .17787 Mdot
.10154 .17785 Mdot
.10155 .17784 Mdot
.10156 .17782 Mdot
.10157 .17781 Mdot
.10158 .17779 Mdot
.10159 .17778 Mdot
.1016 .17776 Mdot
.10161 .17775 Mdot
.10162 .17773 Mdot
.10163 .17772 Mdot
.10164 .1777 Mdot
.10165 .17769 Mdot
.10166 .17767 Mdot
.10167 .17766 Mdot
.10168 .17764 Mdot
.10169 .17763 Mdot
.1017 .17761 Mdot
.1017 .1776 Mdot
.10171 .17758 Mdot
.10172 .17757 Mdot
.10173 .17755 Mdot
.10174 .17754 Mdot
.10175 .17752 Mdot
.10176 .17751 Mdot
.10177 .17749 Mdot
.10178 .17748 Mdot
.10179 .17746 Mdot
.1018 .17745 Mdot
.10181 .17744 Mdot
.10182 .17742 Mdot
.10183 .17741 Mdot
.10184 .17739 Mdot
.10185 .17738 Mdot
.10186 .17736 Mdot
.10187 .17735 Mdot
.10188 .17733 Mdot
.10189 .17732 Mdot
.1019 .1773 Mdot
.1019 .17729 Mdot
.10191 .17727 Mdot
.10192 .17726 Mdot
.10193 .17724 Mdot
.10194 .17723 Mdot
.10195 .17721 Mdot
.10196 .1772 Mdot
.10197 .17718 Mdot
.10198 .17717 Mdot
.10199 .17715 Mdot
.102 .17714 Mdot
.10201 .17712 Mdot
.10202 .17711 Mdot
.10203 .17709 Mdot
.10204 .17708 Mdot
.10205 .17706 Mdot
.10206 .17705 Mdot
.10207 .17703 Mdot
.10208 .17702 Mdot
.10209 .177 Mdot
.1021 .17699 Mdot
.1021 .17698 Mdot
.10211 .17696 Mdot
.10212 .17695 Mdot
.10213 .17693 Mdot
.10214 .17692 Mdot
.10215 .1769 Mdot
.10216 .17689 Mdot
.10217 .17687 Mdot
.10218 .17686 Mdot
.10219 .17684 Mdot
.1022 .17683 Mdot
.10221 .17681 Mdot
.10222 .1768 Mdot
.10223 .17678 Mdot
.10224 .17677 Mdot
.10225 .17675 Mdot
.10226 .17674 Mdot
.10227 .17672 Mdot
.10228 .17671 Mdot
.10229 .17669 Mdot
.1023 .17668 Mdot
.1023 .17666 Mdot
.10231 .17665 Mdot
.10232 .17663 Mdot
.10233 .17662 Mdot
.10234 .1766 Mdot
.10235 .17659 Mdot
.10236 .17657 Mdot
.10237 .17656 Mdot
.10238 .17655 Mdot
.10239 .17653 Mdot
.1024 .17652 Mdot
.10241 .1765 Mdot
.10242 .17649 Mdot
.10243 .17647 Mdot
.10244 .17646 Mdot
.10245 .17644 Mdot
.10246 .17643 Mdot
.10247 .17641 Mdot
.10248 .1764 Mdot
.10249 .17638 Mdot
.1025 .17637 Mdot
.1025 .17635 Mdot
.10251 .17634 Mdot
.10252 .17632 Mdot
.10253 .17631 Mdot
.10254 .17629 Mdot
.10255 .17628 Mdot
.10256 .17626 Mdot
.10257 .17625 Mdot
.10258 .17623 Mdot
.10259 .17622 Mdot
.1026 .1762 Mdot
.10261 .17619 Mdot
.10262 .17618 Mdot
.10263 .17616 Mdot
.10264 .17615 Mdot
.10265 .17613 Mdot
.10266 .17612 Mdot
.10267 .1761 Mdot
.10268 .17609 Mdot
.10269 .17607 Mdot
.1027 .17606 Mdot
.1027 .17604 Mdot
.10271 .17603 Mdot
.10272 .17601 Mdot
.10273 .176 Mdot
.10274 .17598 Mdot
.10275 .17597 Mdot
.10276 .17595 Mdot
.10277 .17594 Mdot
.10278 .17592 Mdot
.10279 .17591 Mdot
.1028 .17589 Mdot
.10281 .17588 Mdot
.10282 .17586 Mdot
.10283 .17585 Mdot
.10284 .17583 Mdot
.10285 .17582 Mdot
.10286 .1758 Mdot
.10287 .17579 Mdot
.10288 .17578 Mdot
.10289 .17576 Mdot
.1029 .17575 Mdot
.1029 .17573 Mdot
.10291 .17572 Mdot
.10292 .1757 Mdot
.10293 .17569 Mdot
.10294 .17567 Mdot
.10295 .17566 Mdot
.10296 .17564 Mdot
.10297 .17563 Mdot
.10298 .17561 Mdot
.10299 .1756 Mdot
.103 .17558 Mdot
.10301 .17557 Mdot
.10302 .17555 Mdot
.10303 .17554 Mdot
.10304 .17552 Mdot
.10305 .17551 Mdot
.10306 .17549 Mdot
.10307 .17548 Mdot
.10308 .17546 Mdot
.10309 .17545 Mdot
.1031 .17544 Mdot
.1031 .17542 Mdot
.10311 .17541 Mdot
.10312 .17539 Mdot
.10313 .17538 Mdot
.10314 .17536 Mdot
.10315 .17535 Mdot
.10316 .17533 Mdot
.10317 .17532 Mdot
.10318 .1753 Mdot
.10319 .17529 Mdot
.1032 .17527 Mdot
.10321 .17526 Mdot
.10322 .17524 Mdot
.10323 .17523 Mdot
.10324 .17521 Mdot
.10325 .1752 Mdot
.10326 .17518 Mdot
.10327 .17517 Mdot
.10328 .17515 Mdot
.10329 .17514 Mdot
.1033 .17512 Mdot
.1033 .17511 Mdot
.10331 .1751 Mdot
.10332 .17508 Mdot
.10333 .17507 Mdot
.10334 .17505 Mdot
.10335 .17504 Mdot
.10336 .17502 Mdot
.10337 .17501 Mdot
.10338 .17499 Mdot
.10339 .17498 Mdot
.1034 .17496 Mdot
.10341 .17495 Mdot
.10342 .17493 Mdot
.10343 .17492 Mdot
.10344 .1749 Mdot
.10345 .17489 Mdot
.10346 .17487 Mdot
.10347 .17486 Mdot
.10348 .17484 Mdot
.10349 .17483 Mdot
.1035 .17481 Mdot
.1035 .1748 Mdot
.10351 .17478 Mdot
.10352 .17477 Mdot
.10353 .17476 Mdot
.10354 .17474 Mdot
.10355 .17473 Mdot
.10356 .17471 Mdot
.10357 .1747 Mdot
.10358 .17468 Mdot
.10359 .17467 Mdot
.1036 .17465 Mdot
.10361 .17464 Mdot
.10362 .17462 Mdot
.10363 .17461 Mdot
.10364 .17459 Mdot
.10365 .17458 Mdot
.10366 .17456 Mdot
.10367 .17455 Mdot
.10368 .17453 Mdot
.10369 .17452 Mdot
.1037 .1745 Mdot
.1037 .17449 Mdot
.10371 .17447 Mdot
.10372 .17446 Mdot
.10373 .17445 Mdot
.10374 .17443 Mdot
.10375 .17442 Mdot
.10376 .1744 Mdot
.10377 .17439 Mdot
.10378 .17437 Mdot
.10379 .17436 Mdot
.1038 .17434 Mdot
.10381 .17433 Mdot
.10382 .17431 Mdot
.10383 .1743 Mdot
.10384 .17428 Mdot
.10385 .17427 Mdot
.10386 .17425 Mdot
.10387 .17424 Mdot
.10388 .17422 Mdot
.10389 .17421 Mdot
.1039 .17419 Mdot
.1039 .17418 Mdot
.10391 .17416 Mdot
.10392 .17415 Mdot
.10393 .17414 Mdot
.10394 .17412 Mdot
.10395 .17411 Mdot
.10396 .17409 Mdot
.10397 .17408 Mdot
.10398 .17406 Mdot
.10399 .17405 Mdot
.104 .17403 Mdot
.10401 .17402 Mdot
.10402 .174 Mdot
.10403 .17399 Mdot
.10404 .17397 Mdot
.10405 .17396 Mdot
.10406 .17394 Mdot
.10407 .17393 Mdot
.10408 .17391 Mdot
.10409 .1739 Mdot
.1041 .17388 Mdot
.1041 .17387 Mdot
.10411 .17385 Mdot
.10412 .17384 Mdot
.10413 .17383 Mdot
.10414 .17381 Mdot
.10415 .1738 Mdot
.10416 .17378 Mdot
.10417 .17377 Mdot
.10418 .17375 Mdot
.10419 .17374 Mdot
.1042 .17372 Mdot
.10421 .17371 Mdot
.10422 .17369 Mdot
.10423 .17368 Mdot
.10424 .17366 Mdot
.10425 .17365 Mdot
.10426 .17363 Mdot
.10427 .17362 Mdot
.10428 .1736 Mdot
.10429 .17359 Mdot
.1043 .17357 Mdot
.1043 .17356 Mdot
.10431 .17355 Mdot
.10432 .17353 Mdot
.10433 .17352 Mdot
.10434 .1735 Mdot
.10435 .17349 Mdot
.10436 .17347 Mdot
.10437 .17346 Mdot
.10438 .17344 Mdot
.10439 .17343 Mdot
.1044 .17341 Mdot
.10441 .1734 Mdot
.10442 .17338 Mdot
.10443 .17337 Mdot
.10444 .17335 Mdot
.10445 .17334 Mdot
.10446 .17332 Mdot
.10447 .17331 Mdot
.10448 .17329 Mdot
.10449 .17328 Mdot
.1045 .17327 Mdot
.1045 .17325 Mdot
.10451 .17324 Mdot
.10452 .17322 Mdot
.10453 .17321 Mdot
.10454 .17319 Mdot
.10455 .17318 Mdot
.10456 .17316 Mdot
.10457 .17315 Mdot
.10458 .17313 Mdot
.10459 .17312 Mdot
.1046 .1731 Mdot
.10461 .17309 Mdot
.10462 .17307 Mdot
.10463 .17306 Mdot
.10464 .17304 Mdot
.10465 .17303 Mdot
.10466 .17302 Mdot
.10467 .173 Mdot
.10468 .17299 Mdot
.10469 .17297 Mdot
.1047 .17296 Mdot
.1047 .17294 Mdot
.10471 .17293 Mdot
.10472 .17291 Mdot
.10473 .1729 Mdot
.10474 .17288 Mdot
.10475 .17287 Mdot
.10476 .17285 Mdot
.10477 .17284 Mdot
.10478 .17282 Mdot
.10479 .17281 Mdot
.1048 .17279 Mdot
.10481 .17278 Mdot
.10482 .17276 Mdot
.10483 .17275 Mdot
.10484 .17274 Mdot
.10485 .17272 Mdot
.10486 .17271 Mdot
.10487 .17269 Mdot
.10488 .17268 Mdot
.10489 .17266 Mdot
.1049 .17265 Mdot
.1049 .17263 Mdot
.10491 .17262 Mdot
.10492 .1726 Mdot
.10493 .17259 Mdot
.10494 .17257 Mdot
.10495 .17256 Mdot
.10496 .17254 Mdot
.10497 .17253 Mdot
.10498 .17251 Mdot
.10499 .1725 Mdot
.105 .17249 Mdot
.10501 .17247 Mdot
.10502 .17246 Mdot
.10503 .17244 Mdot
.10504 .17243 Mdot
.10505 .17241 Mdot
.10506 .1724 Mdot
.10507 .17238 Mdot
.10508 .17237 Mdot
.10509 .17235 Mdot
.1051 .17234 Mdot
.1051 .17232 Mdot
.10511 .17231 Mdot
.10512 .17229 Mdot
.10513 .17228 Mdot
.10514 .17226 Mdot
.10515 .17225 Mdot
.10516 .17224 Mdot
.10517 .17222 Mdot
.10518 .17221 Mdot
.10519 .17219 Mdot
.1052 .17218 Mdot
.10521 .17216 Mdot
.10522 .17215 Mdot
.10523 .17213 Mdot
.10524 .17212 Mdot
.10525 .1721 Mdot
.10526 .17209 Mdot
.10527 .17207 Mdot
.10528 .17206 Mdot
.10529 .17204 Mdot
.1053 .17203 Mdot
.1053 .17201 Mdot
.10531 .172 Mdot
.10532 .17199 Mdot
.10533 .17197 Mdot
.10534 .17196 Mdot
.10535 .17194 Mdot
.10536 .17193 Mdot
.10537 .17191 Mdot
.10538 .1719 Mdot
.10539 .17188 Mdot
.1054 .17187 Mdot
.10541 .17185 Mdot
.10542 .17184 Mdot
.10543 .17182 Mdot
.10544 .17181 Mdot
.10545 .17179 Mdot
.10546 .17178 Mdot
.10547 .17177 Mdot
.10548 .17175 Mdot
.10549 .17174 Mdot
.1055 .17172 Mdot
.1055 .17171 Mdot
.10551 .17169 Mdot
.10552 .17168 Mdot
.10553 .17166 Mdot
.10554 .17165 Mdot
.10555 .17163 Mdot
.10556 .17162 Mdot
.10557 .1716 Mdot
.10558 .17159 Mdot
.10559 .17157 Mdot
.1056 .17156 Mdot
.10561 .17154 Mdot
.10562 .17153 Mdot
.10563 .17152 Mdot
.10564 .1715 Mdot
.10565 .17149 Mdot
.10566 .17147 Mdot
.10567 .17146 Mdot
.10568 .17144 Mdot
.10569 .17143 Mdot
.1057 .17141 Mdot
.1057 .1714 Mdot
.10571 .17138 Mdot
.10572 .17137 Mdot
.10573 .17135 Mdot
.10574 .17134 Mdot
.10575 .17132 Mdot
.10576 .17131 Mdot
.10577 .1713 Mdot
.10578 .17128 Mdot
.10579 .17127 Mdot
.1058 .17125 Mdot
.10581 .17124 Mdot
.10582 .17122 Mdot
.10583 .17121 Mdot
.10584 .17119 Mdot
.10585 .17118 Mdot
.10586 .17116 Mdot
.10587 .17115 Mdot
.10588 .17113 Mdot
.10589 .17112 Mdot
.1059 .1711 Mdot
.1059 .17109 Mdot
.10591 .17108 Mdot
.10592 .17106 Mdot
.10593 .17105 Mdot
.10594 .17103 Mdot
.10595 .17102 Mdot
.10596 .171 Mdot
.10597 .17099 Mdot
.10598 .17097 Mdot
.10599 .17096 Mdot
.106 .17094 Mdot
.10601 .17093 Mdot
.10602 .17091 Mdot
.10603 .1709 Mdot
.10604 .17088 Mdot
.10605 .17087 Mdot
.10606 .17086 Mdot
.10607 .17084 Mdot
.10608 .17083 Mdot
.10609 .17081 Mdot
.1061 .1708 Mdot
.1061 .17078 Mdot
.10611 .17077 Mdot
.10612 .17075 Mdot
.10613 .17074 Mdot
.10614 .17072 Mdot
.10615 .17071 Mdot
.10616 .17069 Mdot
.10617 .17068 Mdot
.10618 .17066 Mdot
.10619 .17065 Mdot
.1062 .17064 Mdot
.10621 .17062 Mdot
.10622 .17061 Mdot
.10623 .17059 Mdot
.10624 .17058 Mdot
.10625 .17056 Mdot
.10626 .17055 Mdot
.10627 .17053 Mdot
.10628 .17052 Mdot
.10629 .1705 Mdot
.1063 .17049 Mdot
.1063 .17047 Mdot
.10631 .17046 Mdot
.10632 .17044 Mdot
.10633 .17043 Mdot
.10634 .17042 Mdot
.10635 .1704 Mdot
.10636 .17039 Mdot
.10637 .17037 Mdot
.10638 .17036 Mdot
.10639 .17034 Mdot
.1064 .17033 Mdot
.10641 .17031 Mdot
.10642 .1703 Mdot
.10643 .17028 Mdot
.10644 .17027 Mdot
.10645 .17025 Mdot
.10646 .17024 Mdot
.10647 .17023 Mdot
.10648 .17021 Mdot
.10649 .1702 Mdot
.1065 .17018 Mdot
.1065 .17017 Mdot
.10651 .17015 Mdot
.10652 .17014 Mdot
.10653 .17012 Mdot
.10654 .17011 Mdot
.10655 .17009 Mdot
.10656 .17008 Mdot
.10657 .17006 Mdot
.10658 .17005 Mdot
.10659 .17003 Mdot
.1066 .17002 Mdot
.10661 .17001 Mdot
.10662 .16999 Mdot
.10663 .16998 Mdot
.10664 .16996 Mdot
.10665 .16995 Mdot
.10666 .16993 Mdot
.10667 .16992 Mdot
.10668 .1699 Mdot
.10669 .16989 Mdot
.1067 .16987 Mdot
.1067 .16986 Mdot
.10671 .16984 Mdot
.10672 .16983 Mdot
.10673 .16982 Mdot
.10674 .1698 Mdot
.10675 .16979 Mdot
.10676 .16977 Mdot
.10677 .16976 Mdot
.10678 .16974 Mdot
.10679 .16973 Mdot
.1068 .16971 Mdot
.10681 .1697 Mdot
.10682 .16968 Mdot
.10683 .16967 Mdot
.10684 .16965 Mdot
.10685 .16964 Mdot
.10686 .16963 Mdot
.10687 .16961 Mdot
.10688 .1696 Mdot
.10689 .16958 Mdot
.1069 .16957 Mdot
.1069 .16955 Mdot
.10691 .16954 Mdot
.10692 .16952 Mdot
.10693 .16951 Mdot
.10694 .16949 Mdot
.10695 .16948 Mdot
.10696 .16946 Mdot
.10697 .16945 Mdot
.10698 .16944 Mdot
.10699 .16942 Mdot
.107 .16941 Mdot
.10701 .16939 Mdot
.10702 .16938 Mdot
.10703 .16936 Mdot
.10704 .16935 Mdot
.10705 .16933 Mdot
.10706 .16932 Mdot
.10707 .1693 Mdot
.10708 .16929 Mdot
.10709 .16927 Mdot
.1071 .16926 Mdot
.1071 .16924 Mdot
.10711 .16923 Mdot
.10712 .16922 Mdot
.10713 .1692 Mdot
.10714 .16919 Mdot
.10715 .16917 Mdot
.10716 .16916 Mdot
.10717 .16914 Mdot
.10718 .16913 Mdot
.10719 .16911 Mdot
.1072 .1691 Mdot
.10721 .16908 Mdot
.10722 .16907 Mdot
.10723 .16906 Mdot
.10724 .16904 Mdot
.10725 .16903 Mdot
.10726 .16901 Mdot
.10727 .169 Mdot
.10728 .16898 Mdot
.10729 .16897 Mdot
.1073 .16895 Mdot
.1073 .16894 Mdot
.10731 .16892 Mdot
.10732 .16891 Mdot
.10733 .16889 Mdot
.10734 .16888 Mdot
.10735 .16887 Mdot
.10736 .16885 Mdot
.10737 .16884 Mdot
.10738 .16882 Mdot
.10739 .16881 Mdot
.1074 .16879 Mdot
.10741 .16878 Mdot
.10742 .16876 Mdot
.10743 .16875 Mdot
.10744 .16873 Mdot
.10745 .16872 Mdot
.10746 .1687 Mdot
.10747 .16869 Mdot
.10748 .16868 Mdot
.10749 .16866 Mdot
.1075 .16865 Mdot
.1075 .16863 Mdot
.10751 .16862 Mdot
.10752 .1686 Mdot
.10753 .16859 Mdot
.10754 .16857 Mdot
.10755 .16856 Mdot
.10756 .16854 Mdot
.10757 .16853 Mdot
.10758 .16851 Mdot
.10759 .1685 Mdot
.1076 .16849 Mdot
.10761 .16847 Mdot
.10762 .16846 Mdot
.10763 .16844 Mdot
.10764 .16843 Mdot
.10765 .16841 Mdot
.10766 .1684 Mdot
.10767 .16838 Mdot
.10768 .16837 Mdot
.10769 .16835 Mdot
.1077 .16834 Mdot
.1077 .16833 Mdot
.10771 .16831 Mdot
.10772 .1683 Mdot
.10773 .16828 Mdot
.10774 .16827 Mdot
.10775 .16825 Mdot
.10776 .16824 Mdot
.10777 .16822 Mdot
.10778 .16821 Mdot
.10779 .16819 Mdot
.1078 .16818 Mdot
.10781 .16816 Mdot
.10782 .16815 Mdot
.10783 .16814 Mdot
.10784 .16812 Mdot
.10785 .16811 Mdot
.10786 .16809 Mdot
.10787 .16808 Mdot
.10788 .16806 Mdot
.10789 .16805 Mdot
.1079 .16803 Mdot
.1079 .16802 Mdot
.10791 .168 Mdot
.10792 .16799 Mdot
.10793 .16797 Mdot
.10794 .16796 Mdot
.10795 .16795 Mdot
.10796 .16793 Mdot
.10797 .16792 Mdot
.10798 .1679 Mdot
.10799 .16789 Mdot
.108 .16787 Mdot
.10801 .16786 Mdot
.10802 .16784 Mdot
.10803 .16783 Mdot
.10804 .16781 Mdot
.10805 .1678 Mdot
.10806 .16779 Mdot
.10807 .16777 Mdot
.10808 .16776 Mdot
.10809 .16774 Mdot
.1081 .16773 Mdot
.1081 .16771 Mdot
.10811 .1677 Mdot
.10812 .16768 Mdot
.10813 .16767 Mdot
.10814 .16765 Mdot
.10815 .16764 Mdot
.10816 .16763 Mdot
.10817 .16761 Mdot
.10818 .1676 Mdot
.10819 .16758 Mdot
.1082 .16757 Mdot
.10821 .16755 Mdot
.10822 .16754 Mdot
.10823 .16752 Mdot
.10824 .16751 Mdot
.10825 .16749 Mdot
.10826 .16748 Mdot
.10827 .16746 Mdot
.10828 .16745 Mdot
.10829 .16744 Mdot
.1083 .16742 Mdot
.1083 .16741 Mdot
.10831 .16739 Mdot
.10832 .16738 Mdot
.10833 .16736 Mdot
.10834 .16735 Mdot
.10835 .16733 Mdot
.10836 .16732 Mdot
.10837 .1673 Mdot
.10838 .16729 Mdot
.10839 .16728 Mdot
.1084 .16726 Mdot
.10841 .16725 Mdot
.10842 .16723 Mdot
.10843 .16722 Mdot
.10844 .1672 Mdot
.10845 .16719 Mdot
.10846 .16717 Mdot
.10847 .16716 Mdot
.10848 .16714 Mdot
.10849 .16713 Mdot
.1085 .16712 Mdot
.1085 .1671 Mdot
.10851 .16709 Mdot
.10852 .16707 Mdot
.10853 .16706 Mdot
.10854 .16704 Mdot
.10855 .16703 Mdot
.10856 .16701 Mdot
.10857 .167 Mdot
.10858 .16698 Mdot
.10859 .16697 Mdot
.1086 .16696 Mdot
.10861 .16694 Mdot
.10862 .16693 Mdot
.10863 .16691 Mdot
.10864 .1669 Mdot
.10865 .16688 Mdot
.10866 .16687 Mdot
.10867 .16685 Mdot
.10868 .16684 Mdot
.10869 .16682 Mdot
.1087 .16681 Mdot
.1087 .1668 Mdot
.10871 .16678 Mdot
.10872 .16677 Mdot
.10873 .16675 Mdot
.10874 .16674 Mdot
.10875 .16672 Mdot
.10876 .16671 Mdot
.10877 .16669 Mdot
.10878 .16668 Mdot
.10879 .16666 Mdot
.1088 .16665 Mdot
.10881 .16664 Mdot
.10882 .16662 Mdot
.10883 .16661 Mdot
.10884 .16659 Mdot
.10885 .16658 Mdot
.10886 .16656 Mdot
.10887 .16655 Mdot
.10888 .16653 Mdot
.10889 .16652 Mdot
.1089 .1665 Mdot
.1089 .16649 Mdot
.10891 .16648 Mdot
.10892 .16646 Mdot
.10893 .16645 Mdot
.10894 .16643 Mdot
.10895 .16642 Mdot
.10896 .1664 Mdot
.10897 .16639 Mdot
.10898 .16637 Mdot
.10899 .16636 Mdot
.109 .16634 Mdot
.10901 .16633 Mdot
.10902 .16632 Mdot
.10903 .1663 Mdot
.10904 .16629 Mdot
.10905 .16627 Mdot
.10906 .16626 Mdot
.10907 .16624 Mdot
.10908 .16623 Mdot
.10909 .16621 Mdot
.1091 .1662 Mdot
.1091 .16618 Mdot
.10911 .16617 Mdot
.10912 .16616 Mdot
.10913 .16614 Mdot
.10914 .16613 Mdot
.10915 .16611 Mdot
.10916 .1661 Mdot
.10917 .16608 Mdot
.10918 .16607 Mdot
.10919 .16605 Mdot
.1092 .16604 Mdot
.10921 .16603 Mdot
.10922 .16601 Mdot
.10923 .166 Mdot
.10924 .16598 Mdot
.10925 .16597 Mdot
.10926 .16595 Mdot
.10927 .16594 Mdot
.10928 .16592 Mdot
.10929 .16591 Mdot
.1093 .16589 Mdot
.1093 .16588 Mdot
.10931 .16587 Mdot
.10932 .16585 Mdot
.10933 .16584 Mdot
.10934 .16582 Mdot
.10935 .16581 Mdot
.10936 .16579 Mdot
.10937 .16578 Mdot
.10938 .16576 Mdot
.10939 .16575 Mdot
.1094 .16573 Mdot
.10941 .16572 Mdot
.10942 .16571 Mdot
.10943 .16569 Mdot
.10944 .16568 Mdot
.10945 .16566 Mdot
.10946 .16565 Mdot
.10947 .16563 Mdot
.10948 .16562 Mdot
.10949 .1656 Mdot
.1095 .16559 Mdot
.1095 .16558 Mdot
.10951 .16556 Mdot
.10952 .16555 Mdot
.10953 .16553 Mdot
.10954 .16552 Mdot
.10955 .1655 Mdot
.10956 .16549 Mdot
.10957 .16547 Mdot
.10958 .16546 Mdot
.10959 .16544 Mdot
.1096 .16543 Mdot
.10961 .16542 Mdot
.10962 .1654 Mdot
.10963 .16539 Mdot
.10964 .16537 Mdot
.10965 .16536 Mdot
.10966 .16534 Mdot
.10967 .16533 Mdot
.10968 .16531 Mdot
.10969 .1653 Mdot
.1097 .16529 Mdot
.1097 .16527 Mdot
.10971 .16526 Mdot
.10972 .16524 Mdot
.10973 .16523 Mdot
.10974 .16521 Mdot
.10975 .1652 Mdot
.10976 .16518 Mdot
.10977 .16517 Mdot
.10978 .16515 Mdot
.10979 .16514 Mdot
.1098 .16513 Mdot
.10981 .16511 Mdot
.10982 .1651 Mdot
.10983 .16508 Mdot
.10984 .16507 Mdot
.10985 .16505 Mdot
.10986 .16504 Mdot
.10987 .16502 Mdot
.10988 .16501 Mdot
.10989 .165 Mdot
.1099 .16498 Mdot
.1099 .16497 Mdot
.10991 .16495 Mdot
.10992 .16494 Mdot
.10993 .16492 Mdot
.10994 .16491 Mdot
.10995 .16489 Mdot
.10996 .16488 Mdot
.10997 .16486 Mdot
.10998 .16485 Mdot
.10999 .16484 Mdot
.11 .16482 Mdot
.11001 .16481 Mdot
.11002 .16479 Mdot
.11003 .16478 Mdot
.11004 .16476 Mdot
.11005 .16475 Mdot
.11006 .16473 Mdot
.11007 .16472 Mdot
.11008 .16471 Mdot
.11009 .16469 Mdot
.1101 .16468 Mdot
.1101 .16466 Mdot
.11011 .16465 Mdot
.11012 .16463 Mdot
.11013 .16462 Mdot
.11014 .1646 Mdot
.11015 .16459 Mdot
.11016 .16458 Mdot
.11017 .16456 Mdot
.11018 .16455 Mdot
.11019 .16453 Mdot
.1102 .16452 Mdot
.11021 .1645 Mdot
.11022 .16449 Mdot
.11023 .16447 Mdot
.11024 .16446 Mdot
.11025 .16444 Mdot
.11026 .16443 Mdot
.11027 .16442 Mdot
.11028 .1644 Mdot
.11029 .16439 Mdot
.1103 .16437 Mdot
.1103 .16436 Mdot
.11031 .16434 Mdot
.11032 .16433 Mdot
.11033 .16431 Mdot
.11034 .1643 Mdot
.11035 .16429 Mdot
.11036 .16427 Mdot
.11037 .16426 Mdot
.11038 .16424 Mdot
.11039 .16423 Mdot
.1104 .16421 Mdot
.11041 .1642 Mdot
.11042 .16418 Mdot
.11043 .16417 Mdot
.11044 .16416 Mdot
.11045 .16414 Mdot
.11046 .16413 Mdot
.11047 .16411 Mdot
.11048 .1641 Mdot
.11049 .16408 Mdot
.1105 .16407 Mdot
.1105 .16405 Mdot
.11051 .16404 Mdot
.11052 .16403 Mdot
.11053 .16401 Mdot
.11054 .164 Mdot
.11055 .16398 Mdot
.11056 .16397 Mdot
.11057 .16395 Mdot
.11058 .16394 Mdot
.11059 .16392 Mdot
.1106 .16391 Mdot
.11061 .1639 Mdot
.11062 .16388 Mdot
.11063 .16387 Mdot
.11064 .16385 Mdot
.11065 .16384 Mdot
.11066 .16382 Mdot
.11067 .16381 Mdot
.11068 .16379 Mdot
.11069 .16378 Mdot
.1107 .16377 Mdot
.1107 .16375 Mdot
.11071 .16374 Mdot
.11072 .16372 Mdot
.11073 .16371 Mdot
.11074 .16369 Mdot
.11075 .16368 Mdot
.11076 .16366 Mdot
.11077 .16365 Mdot
.11078 .16364 Mdot
.11079 .16362 Mdot
.1108 .16361 Mdot
.11081 .16359 Mdot
.11082 .16358 Mdot
.11083 .16356 Mdot
.11084 .16355 Mdot
.11085 .16353 Mdot
.11086 .16352 Mdot
.11087 .16351 Mdot
.11088 .16349 Mdot
.11089 .16348 Mdot
.1109 .16346 Mdot
.1109 .16345 Mdot
.11091 .16343 Mdot
.11092 .16342 Mdot
.11093 .1634 Mdot
.11094 .16339 Mdot
.11095 .16338 Mdot
.11096 .16336 Mdot
.11097 .16335 Mdot
.11098 .16333 Mdot
.11099 .16332 Mdot
.111 .1633 Mdot
.11101 .16329 Mdot
.11102 .16327 Mdot
.11103 .16326 Mdot
.11104 .16325 Mdot
.11105 .16323 Mdot
.11106 .16322 Mdot
.11107 .1632 Mdot
.11108 .16319 Mdot
.11109 .16317 Mdot
.1111 .16316 Mdot
.1111 .16314 Mdot
.11111 .16313 Mdot
.11112 .16312 Mdot
.11113 .1631 Mdot
.11114 .16309 Mdot
.11115 .16307 Mdot
.11116 .16306 Mdot
.11117 .16304 Mdot
.11118 .16303 Mdot
.11119 .16301 Mdot
.1112 .163 Mdot
.11121 .16299 Mdot
.11122 .16297 Mdot
.11123 .16296 Mdot
.11124 .16294 Mdot
.11125 .16293 Mdot
.11126 .16291 Mdot
.11127 .1629 Mdot
.11128 .16288 Mdot
.11129 .16287 Mdot
.1113 .16286 Mdot
.1113 .16284 Mdot
.11131 .16283 Mdot
.11132 .16281 Mdot
.11133 .1628 Mdot
.11134 .16278 Mdot
.11135 .16277 Mdot
.11136 .16275 Mdot
.11137 .16274 Mdot
.11138 .16273 Mdot
.11139 .16271 Mdot
.1114 .1627 Mdot
.11141 .16268 Mdot
.11142 .16267 Mdot
.11143 .16265 Mdot
.11144 .16264 Mdot
.11145 .16262 Mdot
.11146 .16261 Mdot
.11147 .1626 Mdot
.11148 .16258 Mdot
.11149 .16257 Mdot
.1115 .16255 Mdot
.1115 .16254 Mdot
.11151 .16252 Mdot
.11152 .16251 Mdot
.11153 .16249 Mdot
.11154 .16248 Mdot
.11155 .16247 Mdot
.11156 .16245 Mdot
.11157 .16244 Mdot
.11158 .16242 Mdot
.11159 .16241 Mdot
.1116 .16239 Mdot
.11161 .16238 Mdot
.11162 .16237 Mdot
.11163 .16235 Mdot
.11164 .16234 Mdot
.11165 .16232 Mdot
.11166 .16231 Mdot
.11167 .16229 Mdot
.11168 .16228 Mdot
.11169 .16226 Mdot
.1117 .16225 Mdot
.1117 .16224 Mdot
.11171 .16222 Mdot
.11172 .16221 Mdot
.11173 .16219 Mdot
.11174 .16218 Mdot
.11175 .16216 Mdot
.11176 .16215 Mdot
.11177 .16213 Mdot
.11178 .16212 Mdot
.11179 .16211 Mdot
.1118 .16209 Mdot
.11181 .16208 Mdot
.11182 .16206 Mdot
.11183 .16205 Mdot
.11184 .16203 Mdot
.11185 .16202 Mdot
.11186 .16201 Mdot
.11187 .16199 Mdot
.11188 .16198 Mdot
.11189 .16196 Mdot
.1119 .16195 Mdot
.1119 .16193 Mdot
.11191 .16192 Mdot
.11192 .1619 Mdot
.11193 .16189 Mdot
.11194 .16188 Mdot
.11195 .16186 Mdot
.11196 .16185 Mdot
.11197 .16183 Mdot
.11198 .16182 Mdot
.11199 .1618 Mdot
.112 .16179 Mdot
.11201 .16177 Mdot
.11202 .16176 Mdot
.11203 .16175 Mdot
.11204 .16173 Mdot
.11205 .16172 Mdot
.11206 .1617 Mdot
.11207 .16169 Mdot
.11208 .16167 Mdot
.11209 .16166 Mdot
.1121 .16165 Mdot
.1121 .16163 Mdot
.11211 .16162 Mdot
.11212 .1616 Mdot
.11213 .16159 Mdot
.11214 .16157 Mdot
.11215 .16156 Mdot
.11216 .16154 Mdot
.11217 .16153 Mdot
.11218 .16152 Mdot
.11219 .1615 Mdot
.1122 .16149 Mdot
.11221 .16147 Mdot
.11222 .16146 Mdot
.11223 .16144 Mdot
.11224 .16143 Mdot
.11225 .16141 Mdot
.11226 .1614 Mdot
.11227 .16139 Mdot
.11228 .16137 Mdot
.11229 .16136 Mdot
.1123 .16134 Mdot
.1123 .16133 Mdot
.11231 .16131 Mdot
.11232 .1613 Mdot
.11233 .16129 Mdot
.11234 .16127 Mdot
.11235 .16126 Mdot
.11236 .16124 Mdot
.11237 .16123 Mdot
.11238 .16121 Mdot
.11239 .1612 Mdot
.1124 .16118 Mdot
.11241 .16117 Mdot
.11242 .16116 Mdot
.11243 .16114 Mdot
.11244 .16113 Mdot
.11245 .16111 Mdot
.11246 .1611 Mdot
.11247 .16108 Mdot
.11248 .16107 Mdot
.11249 .16106 Mdot
.1125 .16104 Mdot
.1125 .16103 Mdot
.11251 .16101 Mdot
.11252 .161 Mdot
.11253 .16098 Mdot
.11254 .16097 Mdot
.11255 .16095 Mdot
.11256 .16094 Mdot
.11257 .16093 Mdot
.11258 .16091 Mdot
.11259 .1609 Mdot
.1126 .16088 Mdot
.11261 .16087 Mdot
.11262 .16085 Mdot
.11263 .16084 Mdot
.11264 .16083 Mdot
.11265 .16081 Mdot
.11266 .1608 Mdot
.11267 .16078 Mdot
.11268 .16077 Mdot
.11269 .16075 Mdot
.1127 .16074 Mdot
.1127 .16073 Mdot
.11271 .16071 Mdot
.11272 .1607 Mdot
.11273 .16068 Mdot
.11274 .16067 Mdot
.11275 .16065 Mdot
.11276 .16064 Mdot
.11277 .16062 Mdot
.11278 .16061 Mdot
.11279 .1606 Mdot
.1128 .16058 Mdot
.11281 .16057 Mdot
.11282 .16055 Mdot
.11283 .16054 Mdot
.11284 .16052 Mdot
.11285 .16051 Mdot
.11286 .1605 Mdot
.11287 .16048 Mdot
.11288 .16047 Mdot
.11289 .16045 Mdot
.1129 .16044 Mdot
.1129 .16042 Mdot
.11291 .16041 Mdot
.11292 .16039 Mdot
.11293 .16038 Mdot
.11294 .16037 Mdot
.11295 .16035 Mdot
.11296 .16034 Mdot
.11297 .16032 Mdot
.11298 .16031 Mdot
.11299 .16029 Mdot
.113 .16028 Mdot
.11301 .16027 Mdot
.11302 .16025 Mdot
.11303 .16024 Mdot
.11304 .16022 Mdot
.11305 .16021 Mdot
.11306 .16019 Mdot
.11307 .16018 Mdot
.11308 .16017 Mdot
.11309 .16015 Mdot
.1131 .16014 Mdot
.1131 .16012 Mdot
.11311 .16011 Mdot
.11312 .16009 Mdot
.11313 .16008 Mdot
.11314 .16007 Mdot
.11315 .16005 Mdot
.11316 .16004 Mdot
.11317 .16002 Mdot
.11318 .16001 Mdot
.11319 .15999 Mdot
.1132 .15998 Mdot
.11321 .15996 Mdot
.11322 .15995 Mdot
.11323 .15994 Mdot
.11324 .15992 Mdot
.11325 .15991 Mdot
.11326 .15989 Mdot
.11327 .15988 Mdot
.11328 .15986 Mdot
.11329 .15985 Mdot
.1133 .15984 Mdot
.1133 .15982 Mdot
.11331 .15981 Mdot
.11332 .15979 Mdot
.11333 .15978 Mdot
.11334 .15976 Mdot
.11335 .15975 Mdot
.11336 .15974 Mdot
.11337 .15972 Mdot
.11338 .15971 Mdot
.11339 .15969 Mdot
.1134 .15968 Mdot
.11341 .15966 Mdot
.11342 .15965 Mdot
.11343 .15964 Mdot
.11344 .15962 Mdot
.11345 .15961 Mdot
.11346 .15959 Mdot
.11347 .15958 Mdot
.11348 .15956 Mdot
.11349 .15955 Mdot
.1135 .15953 Mdot
.1135 .15952 Mdot
.11351 .15951 Mdot
.11352 .15949 Mdot
.11353 .15948 Mdot
.11354 .15946 Mdot
.11355 .15945 Mdot
.11356 .15943 Mdot
.11357 .15942 Mdot
.11358 .15941 Mdot
.11359 .15939 Mdot
.1136 .15938 Mdot
.11361 .15936 Mdot
.11362 .15935 Mdot
.11363 .15933 Mdot
.11364 .15932 Mdot
.11365 .15931 Mdot
.11366 .15929 Mdot
.11367 .15928 Mdot
.11368 .15926 Mdot
.11369 .15925 Mdot
.1137 .15923 Mdot
.1137 .15922 Mdot
.11371 .15921 Mdot
.11372 .15919 Mdot
.11373 .15918 Mdot
.11374 .15916 Mdot
.11375 .15915 Mdot
.11376 .15913 Mdot
.11377 .15912 Mdot
.11378 .15911 Mdot
.11379 .15909 Mdot
.1138 .15908 Mdot
.11381 .15906 Mdot
.11382 .15905 Mdot
.11383 .15903 Mdot
.11384 .15902 Mdot
.11385 .15901 Mdot
.11386 .15899 Mdot
.11387 .15898 Mdot
.11388 .15896 Mdot
.11389 .15895 Mdot
.1139 .15893 Mdot
.1139 .15892 Mdot
.11391 .15891 Mdot
.11392 .15889 Mdot
.11393 .15888 Mdot
.11394 .15886 Mdot
.11395 .15885 Mdot
.11396 .15883 Mdot
.11397 .15882 Mdot
.11398 .1588 Mdot
.11399 .15879 Mdot
.114 .15878 Mdot
.11401 .15876 Mdot
.11402 .15875 Mdot
.11403 .15873 Mdot
.11404 .15872 Mdot
.11405 .1587 Mdot
.11406 .15869 Mdot
.11407 .15868 Mdot
.11408 .15866 Mdot
.11409 .15865 Mdot
.1141 .15863 Mdot
.1141 .15862 Mdot
.11411 .1586 Mdot
.11412 .15859 Mdot
.11413 .15858 Mdot
.11414 .15856 Mdot
.11415 .15855 Mdot
.11416 .15853 Mdot
.11417 .15852 Mdot
.11418 .1585 Mdot
.11419 .15849 Mdot
.1142 .15848 Mdot
.11421 .15846 Mdot
.11422 .15845 Mdot
.11423 .15843 Mdot
.11424 .15842 Mdot
.11425 .1584 Mdot
.11426 .15839 Mdot
.11427 .15838 Mdot
.11428 .15836 Mdot
.11429 .15835 Mdot
.1143 .15833 Mdot
.1143 .15832 Mdot
.11431 .1583 Mdot
.11432 .15829 Mdot
.11433 .15828 Mdot
.11434 .15826 Mdot
.11435 .15825 Mdot
.11436 .15823 Mdot
.11437 .15822 Mdot
.11438 .1582 Mdot
.11439 .15819 Mdot
.1144 .15818 Mdot
.11441 .15816 Mdot
.11442 .15815 Mdot
.11443 .15813 Mdot
.11444 .15812 Mdot
.11445 .1581 Mdot
.11446 .15809 Mdot
.11447 .15808 Mdot
.11448 .15806 Mdot
.11449 .15805 Mdot
.1145 .15803 Mdot
.1145 .15802 Mdot
.11451 .158 Mdot
.11452 .15799 Mdot
.11453 .15798 Mdot
.11454 .15796 Mdot
.11455 .15795 Mdot
.11456 .15793 Mdot
.11457 .15792 Mdot
.11458 .1579 Mdot
.11459 .15789 Mdot
.1146 .15788 Mdot
.11461 .15786 Mdot
.11462 .15785 Mdot
.11463 .15783 Mdot
.11464 .15782 Mdot
.11465 .15781 Mdot
.11466 .15779 Mdot
.11467 .15778 Mdot
.11468 .15776 Mdot
.11469 .15775 Mdot
.1147 .15773 Mdot
.1147 .15772 Mdot
.11471 .15771 Mdot
.11472 .15769 Mdot
.11473 .15768 Mdot
.11474 .15766 Mdot
.11475 .15765 Mdot
.11476 .15763 Mdot
.11477 .15762 Mdot
.11478 .15761 Mdot
.11479 .15759 Mdot
.1148 .15758 Mdot
.11481 .15756 Mdot
.11482 .15755 Mdot
.11483 .15753 Mdot
.11484 .15752 Mdot
.11485 .15751 Mdot
.11486 .15749 Mdot
.11487 .15748 Mdot
.11488 .15746 Mdot
.11489 .15745 Mdot
.1149 .15743 Mdot
.1149 .15742 Mdot
.11491 .15741 Mdot
.11492 .15739 Mdot
.11493 .15738 Mdot
.11494 .15736 Mdot
.11495 .15735 Mdot
.11496 .15733 Mdot
.11497 .15732 Mdot
.11498 .15731 Mdot
.11499 .15729 Mdot
.115 .15728 Mdot
.11501 .15726 Mdot
.11502 .15725 Mdot
.11503 .15723 Mdot
.11504 .15722 Mdot
.11505 .15721 Mdot
.11506 .15719 Mdot
.11507 .15718 Mdot
.11508 .15716 Mdot
.11509 .15715 Mdot
.1151 .15713 Mdot
.1151 .15712 Mdot
.11511 .15711 Mdot
.11512 .15709 Mdot
.11513 .15708 Mdot
.11514 .15706 Mdot
.11515 .15705 Mdot
.11516 .15704 Mdot
.11517 .15702 Mdot
.11518 .15701 Mdot
.11519 .15699 Mdot
.1152 .15698 Mdot
.11521 .15696 Mdot
.11522 .15695 Mdot
.11523 .15694 Mdot
.11524 .15692 Mdot
.11525 .15691 Mdot
.11526 .15689 Mdot
.11527 .15688 Mdot
.11528 .15686 Mdot
.11529 .15685 Mdot
.1153 .15684 Mdot
.1153 .15682 Mdot
.11531 .15681 Mdot
.11532 .15679 Mdot
.11533 .15678 Mdot
.11534 .15676 Mdot
.11535 .15675 Mdot
.11536 .15674 Mdot
.11537 .15672 Mdot
.11538 .15671 Mdot
.11539 .15669 Mdot
.1154 .15668 Mdot
.11541 .15667 Mdot
.11542 .15665 Mdot
.11543 .15664 Mdot
.11544 .15662 Mdot
.11545 .15661 Mdot
.11546 .15659 Mdot
.11547 .15658 Mdot
.11548 .15657 Mdot
.11549 .15655 Mdot
.1155 .15654 Mdot
.1155 .15652 Mdot
.11551 .15651 Mdot
.11552 .15649 Mdot
.11553 .15648 Mdot
.11554 .15647 Mdot
.11555 .15645 Mdot
.11556 .15644 Mdot
.11557 .15642 Mdot
.11558 .15641 Mdot
.11559 .15639 Mdot
.1156 .15638 Mdot
.11561 .15637 Mdot
.11562 .15635 Mdot
.11563 .15634 Mdot
.11564 .15632 Mdot
.11565 .15631 Mdot
.11566 .1563 Mdot
.11567 .15628 Mdot
.11568 .15627 Mdot
.11569 .15625 Mdot
.1157 .15624 Mdot
.1157 .15622 Mdot
.11571 .15621 Mdot
.11572 .1562 Mdot
.11573 .15618 Mdot
.11574 .15617 Mdot
.11575 .15615 Mdot
.11576 .15614 Mdot
.11577 .15612 Mdot
.11578 .15611 Mdot
.11579 .1561 Mdot
.1158 .15608 Mdot
.11581 .15607 Mdot
.11582 .15605 Mdot
.11583 .15604 Mdot
.11584 .15603 Mdot
.11585 .15601 Mdot
.11586 .156 Mdot
.11587 .15598 Mdot
.11588 .15597 Mdot
.11589 .15595 Mdot
.1159 .15594 Mdot
.1159 .15593 Mdot
.11591 .15591 Mdot
.11592 .1559 Mdot
.11593 .15588 Mdot
.11594 .15587 Mdot
.11595 .15585 Mdot
.11596 .15584 Mdot
.11597 .15583 Mdot
.11598 .15581 Mdot
.11599 .1558 Mdot
.116 .15578 Mdot
.11601 .15577 Mdot
.11602 .15576 Mdot
.11603 .15574 Mdot
.11604 .15573 Mdot
.11605 .15571 Mdot
.11606 .1557 Mdot
.11607 .15568 Mdot
.11608 .15567 Mdot
.11609 .15566 Mdot
.1161 .15564 Mdot
.1161 .15563 Mdot
.11611 .15561 Mdot
.11612 .1556 Mdot
.11613 .15558 Mdot
.11614 .15557 Mdot
.11615 .15556 Mdot
.11616 .15554 Mdot
.11617 .15553 Mdot
.11618 .15551 Mdot
.11619 .1555 Mdot
.1162 .15549 Mdot
.11621 .15547 Mdot
.11622 .15546 Mdot
.11623 .15544 Mdot
.11624 .15543 Mdot
.11625 .15541 Mdot
.11626 .1554 Mdot
.11627 .15539 Mdot
.11628 .15537 Mdot
.11629 .15536 Mdot
.1163 .15534 Mdot
.1163 .15533 Mdot
.11631 .15532 Mdot
.11632 .1553 Mdot
.11633 .15529 Mdot
.11634 .15527 Mdot
.11635 .15526 Mdot
.11636 .15524 Mdot
.11637 .15523 Mdot
.11638 .15522 Mdot
.11639 .1552 Mdot
.1164 .15519 Mdot
.11641 .15517 Mdot
.11642 .15516 Mdot
.11643 .15514 Mdot
.11644 .15513 Mdot
.11645 .15512 Mdot
.11646 .1551 Mdot
.11647 .15509 Mdot
.11648 .15507 Mdot
.11649 .15506 Mdot
.1165 .15505 Mdot
.1165 .15503 Mdot
.11651 .15502 Mdot
.11652 .155 Mdot
.11653 .15499 Mdot
.11654 .15497 Mdot
.11655 .15496 Mdot
.11656 .15495 Mdot
.11657 .15493 Mdot
.11658 .15492 Mdot
.11659 .1549 Mdot
.1166 .15489 Mdot
.11661 .15488 Mdot
.11662 .15486 Mdot
.11663 .15485 Mdot
.11664 .15483 Mdot
.11665 .15482 Mdot
.11666 .1548 Mdot
.11667 .15479 Mdot
.11668 .15478 Mdot
.11669 .15476 Mdot
.1167 .15475 Mdot
.1167 .15473 Mdot
.11671 .15472 Mdot
.11672 .15471 Mdot
.11673 .15469 Mdot
.11674 .15468 Mdot
.11675 .15466 Mdot
.11676 .15465 Mdot
.11677 .15463 Mdot
.11678 .15462 Mdot
.11679 .15461 Mdot
.1168 .15459 Mdot
.11681 .15458 Mdot
.11682 .15456 Mdot
.11683 .15455 Mdot
.11684 .15454 Mdot
.11685 .15452 Mdot
.11686 .15451 Mdot
.11687 .15449 Mdot
.11688 .15448 Mdot
.11689 .15446 Mdot
.1169 .15445 Mdot
.1169 .15444 Mdot
.11691 .15442 Mdot
.11692 .15441 Mdot
.11693 .15439 Mdot
.11694 .15438 Mdot
.11695 .15437 Mdot
.11696 .15435 Mdot
.11697 .15434 Mdot
.11698 .15432 Mdot
.11699 .15431 Mdot
.117 .15429 Mdot
.11701 .15428 Mdot
.11702 .15427 Mdot
.11703 .15425 Mdot
.11704 .15424 Mdot
.11705 .15422 Mdot
.11706 .15421 Mdot
.11707 .1542 Mdot
.11708 .15418 Mdot
.11709 .15417 Mdot
.1171 .15415 Mdot
.1171 .15414 Mdot
.11711 .15413 Mdot
.11712 .15411 Mdot
.11713 .1541 Mdot
.11714 .15408 Mdot
.11715 .15407 Mdot
.11716 .15405 Mdot
.11717 .15404 Mdot
.11718 .15403 Mdot
.11719 .15401 Mdot
.1172 .154 Mdot
.11721 .15398 Mdot
.11722 .15397 Mdot
.11723 .15396 Mdot
.11724 .15394 Mdot
.11725 .15393 Mdot
.11726 .15391 Mdot
.11727 .1539 Mdot
.11728 .15388 Mdot
.11729 .15387 Mdot
.1173 .15386 Mdot
.1173 .15384 Mdot
.11731 .15383 Mdot
.11732 .15381 Mdot
.11733 .1538 Mdot
.11734 .15379 Mdot
.11735 .15377 Mdot
.11736 .15376 Mdot
.11737 .15374 Mdot
.11738 .15373 Mdot
.11739 .15371 Mdot
.1174 .1537 Mdot
.11741 .15369 Mdot
.11742 .15367 Mdot
.11743 .15366 Mdot
.11744 .15364 Mdot
.11745 .15363 Mdot
.11746 .15362 Mdot
.11747 .1536 Mdot
.11748 .15359 Mdot
.11749 .15357 Mdot
.1175 .15356 Mdot
.1175 .15355 Mdot
.11751 .15353 Mdot
.11752 .15352 Mdot
.11753 .1535 Mdot
.11754 .15349 Mdot
.11755 .15347 Mdot
.11756 .15346 Mdot
.11757 .15345 Mdot
.11758 .15343 Mdot
.11759 .15342 Mdot
.1176 .1534 Mdot
.11761 .15339 Mdot
.11762 .15338 Mdot
.11763 .15336 Mdot
.11764 .15335 Mdot
.11765 .15333 Mdot
.11766 .15332 Mdot
.11767 .15331 Mdot
.11768 .15329 Mdot
.11769 .15328 Mdot
.1177 .15326 Mdot
.1177 .15325 Mdot
.11771 .15323 Mdot
.11772 .15322 Mdot
.11773 .15321 Mdot
.11774 .15319 Mdot
.11775 .15318 Mdot
.11776 .15316 Mdot
.11777 .15315 Mdot
.11778 .15314 Mdot
.11779 .15312 Mdot
.1178 .15311 Mdot
.11781 .15309 Mdot
.11782 .15308 Mdot
.11783 .15307 Mdot
.11784 .15305 Mdot
.11785 .15304 Mdot
.11786 .15302 Mdot
.11787 .15301 Mdot
.11788 .15299 Mdot
.11789 .15298 Mdot
.1179 .15297 Mdot
.1179 .15295 Mdot
.11791 .15294 Mdot
.11792 .15292 Mdot
.11793 .15291 Mdot
.11794 .1529 Mdot
.11795 .15288 Mdot
.11796 .15287 Mdot
.11797 .15285 Mdot
.11798 .15284 Mdot
.11799 .15283 Mdot
.118 .15281 Mdot
.11801 .1528 Mdot
.11802 .15278 Mdot
.11803 .15277 Mdot
.11804 .15275 Mdot
.11805 .15274 Mdot
.11806 .15273 Mdot
.11807 .15271 Mdot
.11808 .1527 Mdot
.11809 .15268 Mdot
.1181 .15267 Mdot
.1181 .15266 Mdot
.11811 .15264 Mdot
.11812 .15263 Mdot
.11813 .15261 Mdot
.11814 .1526 Mdot
.11815 .15259 Mdot
.11816 .15257 Mdot
.11817 .15256 Mdot
.11818 .15254 Mdot
.11819 .15253 Mdot
.1182 .15252 Mdot
.11821 .1525 Mdot
.11822 .15249 Mdot
.11823 .15247 Mdot
.11824 .15246 Mdot
.11825 .15244 Mdot
.11826 .15243 Mdot
.11827 .15242 Mdot
.11828 .1524 Mdot
.11829 .15239 Mdot
.1183 .15237 Mdot
.1183 .15236 Mdot
.11831 .15235 Mdot
.11832 .15233 Mdot
.11833 .15232 Mdot
.11834 .1523 Mdot
.11835 .15229 Mdot
.11836 .15228 Mdot
.11837 .15226 Mdot
.11838 .15225 Mdot
.11839 .15223 Mdot
.1184 .15222 Mdot
.11841 .15221 Mdot
.11842 .15219 Mdot
.11843 .15218 Mdot
.11844 .15216 Mdot
.11845 .15215 Mdot
.11846 .15213 Mdot
.11847 .15212 Mdot
.11848 .15211 Mdot
.11849 .15209 Mdot
.1185 .15208 Mdot
.1185 .15206 Mdot
.11851 .15205 Mdot
.11852 .15204 Mdot
.11853 .15202 Mdot
.11854 .15201 Mdot
.11855 .15199 Mdot
.11856 .15198 Mdot
.11857 .15197 Mdot
.11858 .15195 Mdot
.11859 .15194 Mdot
.1186 .15192 Mdot
.11861 .15191 Mdot
.11862 .1519 Mdot
.11863 .15188 Mdot
.11864 .15187 Mdot
.11865 .15185 Mdot
.11866 .15184 Mdot
.11867 .15183 Mdot
.11868 .15181 Mdot
.11869 .1518 Mdot
.1187 .15178 Mdot
.1187 .15177 Mdot
.11871 .15175 Mdot
.11872 .15174 Mdot
.11873 .15173 Mdot
.11874 .15171 Mdot
.11875 .1517 Mdot
.11876 .15168 Mdot
.11877 .15167 Mdot
.11878 .15166 Mdot
.11879 .15164 Mdot
.1188 .15163 Mdot
.11881 .15161 Mdot
.11882 .1516 Mdot
.11883 .15159 Mdot
.11884 .15157 Mdot
.11885 .15156 Mdot
.11886 .15154 Mdot
.11887 .15153 Mdot
.11888 .15152 Mdot
.11889 .1515 Mdot
.1189 .15149 Mdot
.1189 .15147 Mdot
.11891 .15146 Mdot
.11892 .15145 Mdot
.11893 .15143 Mdot
.11894 .15142 Mdot
.11895 .1514 Mdot
.11896 .15139 Mdot
.11897 .15138 Mdot
.11898 .15136 Mdot
.11899 .15135 Mdot
.119 .15133 Mdot
.11901 .15132 Mdot
.11902 .1513 Mdot
.11903 .15129 Mdot
.11904 .15128 Mdot
.11905 .15126 Mdot
.11906 .15125 Mdot
.11907 .15123 Mdot
.11908 .15122 Mdot
.11909 .15121 Mdot
.1191 .15119 Mdot
.1191 .15118 Mdot
.11911 .15116 Mdot
.11912 .15115 Mdot
.11913 .15114 Mdot
.11914 .15112 Mdot
.11915 .15111 Mdot
.11916 .15109 Mdot
.11917 .15108 Mdot
.11918 .15107 Mdot
.11919 .15105 Mdot
.1192 .15104 Mdot
.11921 .15102 Mdot
.11922 .15101 Mdot
.11923 .151 Mdot
.11924 .15098 Mdot
.11925 .15097 Mdot
.11926 .15095 Mdot
.11927 .15094 Mdot
.11928 .15093 Mdot
.11929 .15091 Mdot
.1193 .1509 Mdot
.1193 .15088 Mdot
.11931 .15087 Mdot
.11932 .15086 Mdot
.11933 .15084 Mdot
.11934 .15083 Mdot
.11935 .15081 Mdot
.11936 .1508 Mdot
.11937 .15079 Mdot
.11938 .15077 Mdot
.11939 .15076 Mdot
.1194 .15074 Mdot
.11941 .15073 Mdot
.11942 .15072 Mdot
.11943 .1507 Mdot
.11944 .15069 Mdot
.11945 .15067 Mdot
.11946 .15066 Mdot
.11947 .15064 Mdot
.11948 .15063 Mdot
.11949 .15062 Mdot
.1195 .1506 Mdot
.1195 .15059 Mdot
.11951 .15057 Mdot
.11952 .15056 Mdot
.11953 .15055 Mdot
.11954 .15053 Mdot
.11955 .15052 Mdot
.11956 .1505 Mdot
.11957 .15049 Mdot
.11958 .15048 Mdot
.11959 .15046 Mdot
.1196 .15045 Mdot
.11961 .15043 Mdot
.11962 .15042 Mdot
.11963 .15041 Mdot
.11964 .15039 Mdot
.11965 .15038 Mdot
.11966 .15036 Mdot
.11967 .15035 Mdot
.11968 .15034 Mdot
.11969 .15032 Mdot
.1197 .15031 Mdot
.1197 .15029 Mdot
.11971 .15028 Mdot
.11972 .15027 Mdot
.11973 .15025 Mdot
.11974 .15024 Mdot
.11975 .15022 Mdot
.11976 .15021 Mdot
.11977 .1502 Mdot
.11978 .15018 Mdot
.11979 .15017 Mdot
.1198 .15015 Mdot
.11981 .15014 Mdot
.11982 .15013 Mdot
.11983 .15011 Mdot
.11984 .1501 Mdot
.11985 .15008 Mdot
.11986 .15007 Mdot
.11987 .15006 Mdot
.11988 .15004 Mdot
.11989 .15003 Mdot
.1199 .15001 Mdot
.1199 .15 Mdot
.11991 .14999 Mdot
.11992 .14997 Mdot
.11993 .14996 Mdot
.11994 .14994 Mdot
.11995 .14993 Mdot
.11996 .14992 Mdot
.11997 .1499 Mdot
.11998 .14989 Mdot
.11999 .14987 Mdot
.12 .14986 Mdot
.12001 .14985 Mdot
.12002 .14983 Mdot
.12003 .14982 Mdot
.12004 .1498 Mdot
.12005 .14979 Mdot
.12006 .14978 Mdot
.12007 .14976 Mdot
.12008 .14975 Mdot
.12009 .14973 Mdot
.1201 .14972 Mdot
.1201 .14971 Mdot
.12011 .14969 Mdot
.12012 .14968 Mdot
.12013 .14966 Mdot
.12014 .14965 Mdot
.12015 .14964 Mdot
.12016 .14962 Mdot
.12017 .14961 Mdot
.12018 .14959 Mdot
.12019 .14958 Mdot
.1202 .14957 Mdot
.12021 .14955 Mdot
.12022 .14954 Mdot
.12023 .14952 Mdot
.12024 .14951 Mdot
.12025 .1495 Mdot
.12026 .14948 Mdot
.12027 .14947 Mdot
.12028 .14945 Mdot
.12029 .14944 Mdot
.1203 .14943 Mdot
.1203 .14941 Mdot
.12031 .1494 Mdot
.12032 .14938 Mdot
.12033 .14937 Mdot
.12034 .14936 Mdot
.12035 .14934 Mdot
.12036 .14933 Mdot
.12037 .14931 Mdot
.12038 .1493 Mdot
.12039 .14929 Mdot
.1204 .14927 Mdot
.12041 .14926 Mdot
.12042 .14924 Mdot
.12043 .14923 Mdot
.12044 .14922 Mdot
.12045 .1492 Mdot
.12046 .14919 Mdot
.12047 .14917 Mdot
.12048 .14916 Mdot
.12049 .14915 Mdot
.1205 .14913 Mdot
.1205 .14912 Mdot
.12051 .1491 Mdot
.12052 .14909 Mdot
.12053 .14908 Mdot
.12054 .14906 Mdot
.12055 .14905 Mdot
.12056 .14903 Mdot
.12057 .14902 Mdot
.12058 .14901 Mdot
.12059 .14899 Mdot
.1206 .14898 Mdot
.12061 .14896 Mdot
.12062 .14895 Mdot
.12063 .14894 Mdot
.12064 .14892 Mdot
.12065 .14891 Mdot
.12066 .14889 Mdot
.12067 .14888 Mdot
.12068 .14887 Mdot
.12069 .14885 Mdot
.1207 .14884 Mdot
.1207 .14883 Mdot
.12071 .14881 Mdot
.12072 .1488 Mdot
.12073 .14878 Mdot
.12074 .14877 Mdot
.12075 .14876 Mdot
.12076 .14874 Mdot
.12077 .14873 Mdot
.12078 .14871 Mdot
.12079 .1487 Mdot
.1208 .14869 Mdot
.12081 .14867 Mdot
.12082 .14866 Mdot
.12083 .14864 Mdot
.12084 .14863 Mdot
.12085 .14862 Mdot
.12086 .1486 Mdot
.12087 .14859 Mdot
.12088 .14857 Mdot
.12089 .14856 Mdot
.1209 .14855 Mdot
.1209 .14853 Mdot
.12091 .14852 Mdot
.12092 .1485 Mdot
.12093 .14849 Mdot
.12094 .14848 Mdot
.12095 .14846 Mdot
.12096 .14845 Mdot
.12097 .14843 Mdot
.12098 .14842 Mdot
.12099 .14841 Mdot
.121 .14839 Mdot
.12101 .14838 Mdot
.12102 .14836 Mdot
.12103 .14835 Mdot
.12104 .14834 Mdot
.12105 .14832 Mdot
.12106 .14831 Mdot
.12107 .14829 Mdot
.12108 .14828 Mdot
.12109 .14827 Mdot
.1211 .14825 Mdot
.1211 .14824 Mdot
.12111 .14822 Mdot
.12112 .14821 Mdot
.12113 .1482 Mdot
.12114 .14818 Mdot
.12115 .14817 Mdot
.12116 .14816 Mdot
.12117 .14814 Mdot
.12118 .14813 Mdot
.12119 .14811 Mdot
.1212 .1481 Mdot
.12121 .14809 Mdot
.12122 .14807 Mdot
.12123 .14806 Mdot
.12124 .14804 Mdot
.12125 .14803 Mdot
.12126 .14802 Mdot
.12127 .148 Mdot
.12128 .14799 Mdot
.12129 .14797 Mdot
.1213 .14796 Mdot
.1213 .14795 Mdot
.12131 .14793 Mdot
.12132 .14792 Mdot
.12133 .1479 Mdot
.12134 .14789 Mdot
.12135 .14788 Mdot
.12136 .14786 Mdot
.12137 .14785 Mdot
.12138 .14783 Mdot
.12139 .14782 Mdot
.1214 .14781 Mdot
.12141 .14779 Mdot
.12142 .14778 Mdot
.12143 .14776 Mdot
.12144 .14775 Mdot
.12145 .14774 Mdot
.12146 .14772 Mdot
.12147 .14771 Mdot
.12148 .1477 Mdot
.12149 .14768 Mdot
.1215 .14767 Mdot
.1215 .14765 Mdot
.12151 .14764 Mdot
.12152 .14763 Mdot
.12153 .14761 Mdot
.12154 .1476 Mdot
.12155 .14758 Mdot
.12156 .14757 Mdot
.12157 .14756 Mdot
.12158 .14754 Mdot
.12159 .14753 Mdot
.1216 .14751 Mdot
.12161 .1475 Mdot
.12162 .14749 Mdot
.12163 .14747 Mdot
.12164 .14746 Mdot
.12165 .14744 Mdot
.12166 .14743 Mdot
.12167 .14742 Mdot
.12168 .1474 Mdot
.12169 .14739 Mdot
.1217 .14737 Mdot
.1217 .14736 Mdot
.12171 .14735 Mdot
.12172 .14733 Mdot
.12173 .14732 Mdot
.12174 .14731 Mdot
.12175 .14729 Mdot
.12176 .14728 Mdot
.12177 .14726 Mdot
.12178 .14725 Mdot
.12179 .14724 Mdot
.1218 .14722 Mdot
.12181 .14721 Mdot
.12182 .14719 Mdot
.12183 .14718 Mdot
.12184 .14717 Mdot
.12185 .14715 Mdot
.12186 .14714 Mdot
.12187 .14712 Mdot
.12188 .14711 Mdot
.12189 .1471 Mdot
.1219 .14708 Mdot
.1219 .14707 Mdot
.12191 .14706 Mdot
.12192 .14704 Mdot
.12193 .14703 Mdot
.12194 .14701 Mdot
.12195 .147 Mdot
.12196 .14699 Mdot
.12197 .14697 Mdot
.12198 .14696 Mdot
.12199 .14694 Mdot
.122 .14693 Mdot
.12201 .14692 Mdot
.12202 .1469 Mdot
.12203 .14689 Mdot
.12204 .14687 Mdot
.12205 .14686 Mdot
.12206 .14685 Mdot
.12207 .14683 Mdot
.12208 .14682 Mdot
.12209 .1468 Mdot
.1221 .14679 Mdot
.1221 .14678 Mdot
.12211 .14676 Mdot
.12212 .14675 Mdot
.12213 .14674 Mdot
.12214 .14672 Mdot
.12215 .14671 Mdot
.12216 .14669 Mdot
.12217 .14668 Mdot
.12218 .14667 Mdot
.12219 .14665 Mdot
.1222 .14664 Mdot
.12221 .14662 Mdot
.12222 .14661 Mdot
.12223 .1466 Mdot
.12224 .14658 Mdot
.12225 .14657 Mdot
.12226 .14655 Mdot
.12227 .14654 Mdot
.12228 .14653 Mdot
.12229 .14651 Mdot
.1223 .1465 Mdot
.1223 .14649 Mdot
.12231 .14647 Mdot
.12232 .14646 Mdot
.12233 .14644 Mdot
.12234 .14643 Mdot
.12235 .14642 Mdot
.12236 .1464 Mdot
.12237 .14639 Mdot
.12238 .14637 Mdot
.12239 .14636 Mdot
.1224 .14635 Mdot
.12241 .14633 Mdot
.12242 .14632 Mdot
.12243 .1463 Mdot
.12244 .14629 Mdot
.12245 .14628 Mdot
.12246 .14626 Mdot
.12247 .14625 Mdot
.12248 .14624 Mdot
.12249 .14622 Mdot
.1225 .14621 Mdot
.1225 .14619 Mdot
.12251 .14618 Mdot
.12252 .14617 Mdot
.12253 .14615 Mdot
.12254 .14614 Mdot
.12255 .14612 Mdot
.12256 .14611 Mdot
.12257 .1461 Mdot
.12258 .14608 Mdot
.12259 .14607 Mdot
.1226 .14606 Mdot
.12261 .14604 Mdot
.12262 .14603 Mdot
.12263 .14601 Mdot
.12264 .146 Mdot
.12265 .14599 Mdot
.12266 .14597 Mdot
.12267 .14596 Mdot
.12268 .14594 Mdot
.12269 .14593 Mdot
.1227 .14592 Mdot
.1227 .1459 Mdot
.12271 .14589 Mdot
.12272 .14587 Mdot
.12273 .14586 Mdot
.12274 .14585 Mdot
.12275 .14583 Mdot
.12276 .14582 Mdot
.12277 .14581 Mdot
.12278 .14579 Mdot
.12279 .14578 Mdot
.1228 .14576 Mdot
.12281 .14575 Mdot
.12282 .14574 Mdot
.12283 .14572 Mdot
.12284 .14571 Mdot
.12285 .14569 Mdot
.12286 .14568 Mdot
.12287 .14567 Mdot
.12288 .14565 Mdot
.12289 .14564 Mdot
.1229 .14563 Mdot
.1229 .14561 Mdot
.12291 .1456 Mdot
.12292 .14558 Mdot
.12293 .14557 Mdot
.12294 .14556 Mdot
.12295 .14554 Mdot
.12296 .14553 Mdot
.12297 .14551 Mdot
.12298 .1455 Mdot
.12299 .14549 Mdot
.123 .14547 Mdot
.12301 .14546 Mdot
.12302 .14545 Mdot
.12303 .14543 Mdot
.12304 .14542 Mdot
.12305 .1454 Mdot
.12306 .14539 Mdot
.12307 .14538 Mdot
.12308 .14536 Mdot
.12309 .14535 Mdot
.1231 .14533 Mdot
.1231 .14532 Mdot
.12311 .14531 Mdot
.12312 .14529 Mdot
.12313 .14528 Mdot
.12314 .14527 Mdot
.12315 .14525 Mdot
.12316 .14524 Mdot
.12317 .14522 Mdot
.12318 .14521 Mdot
.12319 .1452 Mdot
.1232 .14518 Mdot
.12321 .14517 Mdot
.12322 .14515 Mdot
.12323 .14514 Mdot
.12324 .14513 Mdot
.12325 .14511 Mdot
.12326 .1451 Mdot
.12327 .14509 Mdot
.12328 .14507 Mdot
.12329 .14506 Mdot
.1233 .14504 Mdot
.1233 .14503 Mdot
.12331 .14502 Mdot
.12332 .145 Mdot
.12333 .14499 Mdot
.12334 .14497 Mdot
.12335 .14496 Mdot
.12336 .14495 Mdot
.12337 .14493 Mdot
.12338 .14492 Mdot
.12339 .14491 Mdot
.1234 .14489 Mdot
.12341 .14488 Mdot
.12342 .14486 Mdot
.12343 .14485 Mdot
.12344 .14484 Mdot
.12345 .14482 Mdot
.12346 .14481 Mdot
.12347 .14479 Mdot
.12348 .14478 Mdot
.12349 .14477 Mdot
.1235 .14475 Mdot
.1235 .14474 Mdot
.12351 .14473 Mdot
.12352 .14471 Mdot
.12353 .1447 Mdot
.12354 .14468 Mdot
.12355 .14467 Mdot
.12356 .14466 Mdot
.12357 .14464 Mdot
.12358 .14463 Mdot
.12359 .14462 Mdot
.1236 .1446 Mdot
.12361 .14459 Mdot
.12362 .14457 Mdot
.12363 .14456 Mdot
.12364 .14455 Mdot
.12365 .14453 Mdot
.12366 .14452 Mdot
.12367 .1445 Mdot
.12368 .14449 Mdot
.12369 .14448 Mdot
.1237 .14446 Mdot
.1237 .14445 Mdot
.12371 .14444 Mdot
.12372 .14442 Mdot
.12373 .14441 Mdot
.12374 .14439 Mdot
.12375 .14438 Mdot
.12376 .14437 Mdot
.12377 .14435 Mdot
.12378 .14434 Mdot
.12379 .14433 Mdot
.1238 .14431 Mdot
.12381 .1443 Mdot
.12382 .14428 Mdot
.12383 .14427 Mdot
.12384 .14426 Mdot
.12385 .14424 Mdot
.12386 .14423 Mdot
.12387 .14421 Mdot
.12388 .1442 Mdot
.12389 .14419 Mdot
.1239 .14417 Mdot
.1239 .14416 Mdot
.12391 .14415 Mdot
.12392 .14413 Mdot
.12393 .14412 Mdot
.12394 .1441 Mdot
.12395 .14409 Mdot
.12396 .14408 Mdot
.12397 .14406 Mdot
.12398 .14405 Mdot
.12399 .14404 Mdot
.124 .14402 Mdot
.12401 .14401 Mdot
.12402 .14399 Mdot
.12403 .14398 Mdot
.12404 .14397 Mdot
.12405 .14395 Mdot
.12406 .14394 Mdot
.12407 .14392 Mdot
.12408 .14391 Mdot
.12409 .1439 Mdot
.1241 .14388 Mdot
.1241 .14387 Mdot
.12411 .14386 Mdot
.12412 .14384 Mdot
.12413 .14383 Mdot
.12414 .14381 Mdot
.12415 .1438 Mdot
.12416 .14379 Mdot
.12417 .14377 Mdot
.12418 .14376 Mdot
.12419 .14375 Mdot
.1242 .14373 Mdot
.12421 .14372 Mdot
.12422 .1437 Mdot
.12423 .14369 Mdot
.12424 .14368 Mdot
.12425 .14366 Mdot
.12426 .14365 Mdot
.12427 .14364 Mdot
.12428 .14362 Mdot
.12429 .14361 Mdot
.1243 .14359 Mdot
.1243 .14358 Mdot
.12431 .14357 Mdot
.12432 .14355 Mdot
.12433 .14354 Mdot
.12434 .14353 Mdot
.12435 .14351 Mdot
.12436 .1435 Mdot
.12437 .14348 Mdot
.12438 .14347 Mdot
.12439 .14346 Mdot
.1244 .14344 Mdot
.12441 .14343 Mdot
.12442 .14341 Mdot
.12443 .1434 Mdot
.12444 .14339 Mdot
.12445 .14337 Mdot
.12446 .14336 Mdot
.12447 .14335 Mdot
.12448 .14333 Mdot
.12449 .14332 Mdot
.1245 .1433 Mdot
.1245 .14329 Mdot
.12451 .14328 Mdot
.12452 .14326 Mdot
.12453 .14325 Mdot
.12454 .14324 Mdot
.12455 .14322 Mdot
.12456 .14321 Mdot
.12457 .14319 Mdot
.12458 .14318 Mdot
.12459 .14317 Mdot
.1246 .14315 Mdot
.12461 .14314 Mdot
.12462 .14313 Mdot
.12463 .14311 Mdot
.12464 .1431 Mdot
.12465 .14308 Mdot
.12466 .14307 Mdot
.12467 .14306 Mdot
.12468 .14304 Mdot
.12469 .14303 Mdot
.1247 .14302 Mdot
.1247 .143 Mdot
.12471 .14299 Mdot
.12472 .14297 Mdot
.12473 .14296 Mdot
.12474 .14295 Mdot
.12475 .14293 Mdot
.12476 .14292 Mdot
.12477 .14291 Mdot
.12478 .14289 Mdot
.12479 .14288 Mdot
.1248 .14286 Mdot
.12481 .14285 Mdot
.12482 .14284 Mdot
.12483 .14282 Mdot
.12484 .14281 Mdot
.12485 .1428 Mdot
.12486 .14278 Mdot
.12487 .14277 Mdot
.12488 .14275 Mdot
.12489 .14274 Mdot
.1249 .14273 Mdot
.1249 .14271 Mdot
.12491 .1427 Mdot
.12492 .14269 Mdot
.12493 .14267 Mdot
.12494 .14266 Mdot
.12495 .14264 Mdot
.12496 .14263 Mdot
.12497 .14262 Mdot
.12498 .1426 Mdot
.12499 .14259 Mdot
.125 .14258 Mdot
.12501 .14256 Mdot
.12502 .14255 Mdot
.12503 .14253 Mdot
.12504 .14252 Mdot
.12505 .14251 Mdot
.12506 .14249 Mdot
.12507 .14248 Mdot
.12508 .14247 Mdot
.12509 .14245 Mdot
.1251 .14244 Mdot
.1251 .14242 Mdot
.12511 .14241 Mdot
.12512 .1424 Mdot
.12513 .14238 Mdot
.12514 .14237 Mdot
.12515 .14236 Mdot
.12516 .14234 Mdot
.12517 .14233 Mdot
.12518 .14231 Mdot
.12519 .1423 Mdot
.1252 .14229 Mdot
.12521 .14227 Mdot
.12522 .14226 Mdot
.12523 .14225 Mdot
.12524 .14223 Mdot
.12525 .14222 Mdot
.12526 .1422 Mdot
.12527 .14219 Mdot
.12528 .14218 Mdot
.12529 .14216 Mdot
.1253 .14215 Mdot
.1253 .14214 Mdot
.12531 .14212 Mdot
.12532 .14211 Mdot
.12533 .14209 Mdot
.12534 .14208 Mdot
.12535 .14207 Mdot
.12536 .14205 Mdot
.12537 .14204 Mdot
.12538 .14203 Mdot
.12539 .14201 Mdot
.1254 .142 Mdot
.12541 .14199 Mdot
.12542 .14197 Mdot
.12543 .14196 Mdot
.12544 .14194 Mdot
.12545 .14193 Mdot
.12546 .14192 Mdot
.12547 .1419 Mdot
.12548 .14189 Mdot
.12549 .14188 Mdot
.1255 .14186 Mdot
.1255 .14185 Mdot
.12551 .14183 Mdot
.12552 .14182 Mdot
.12553 .14181 Mdot
.12554 .14179 Mdot
.12555 .14178 Mdot
.12556 .14177 Mdot
.12557 .14175 Mdot
.12558 .14174 Mdot
.12559 .14172 Mdot
.1256 .14171 Mdot
.12561 .1417 Mdot
.12562 .14168 Mdot
.12563 .14167 Mdot
.12564 .14166 Mdot
.12565 .14164 Mdot
.12566 .14163 Mdot
.12567 .14161 Mdot
.12568 .1416 Mdot
.12569 .14159 Mdot
.1257 .14157 Mdot
.1257 .14156 Mdot
.12571 .14155 Mdot
.12572 .14153 Mdot
.12573 .14152 Mdot
.12574 .14151 Mdot
.12575 .14149 Mdot
.12576 .14148 Mdot
.12577 .14146 Mdot
.12578 .14145 Mdot
.12579 .14144 Mdot
.1258 .14142 Mdot
.12581 .14141 Mdot
.12582 .1414 Mdot
.12583 .14138 Mdot
.12584 .14137 Mdot
.12585 .14135 Mdot
.12586 .14134 Mdot
.12587 .14133 Mdot
.12588 .14131 Mdot
.12589 .1413 Mdot
.1259 .14129 Mdot
.1259 .14127 Mdot
.12591 .14126 Mdot
.12592 .14124 Mdot
.12593 .14123 Mdot
.12594 .14122 Mdot
.12595 .1412 Mdot
.12596 .14119 Mdot
.12597 .14118 Mdot
.12598 .14116 Mdot
.12599 .14115 Mdot
.126 .14114 Mdot
.12601 .14112 Mdot
.12602 .14111 Mdot
.12603 .14109 Mdot
.12604 .14108 Mdot
.12605 .14107 Mdot
.12606 .14105 Mdot
.12607 .14104 Mdot
.12608 .14103 Mdot
.12609 .14101 Mdot
.1261 .141 Mdot
.1261 .14098 Mdot
.12611 .14097 Mdot
.12612 .14096 Mdot
.12613 .14094 Mdot
.12614 .14093 Mdot
.12615 .14092 Mdot
.12616 .1409 Mdot
.12617 .14089 Mdot
.12618 .14088 Mdot
.12619 .14086 Mdot
.1262 .14085 Mdot
.12621 .14083 Mdot
.12622 .14082 Mdot
.12623 .14081 Mdot
.12624 .14079 Mdot
.12625 .14078 Mdot
.12626 .14077 Mdot
.12627 .14075 Mdot
.12628 .14074 Mdot
.12629 .14072 Mdot
.1263 .14071 Mdot
.1263 .1407 Mdot
.12631 .14068 Mdot
.12632 .14067 Mdot
.12633 .14066 Mdot
.12634 .14064 Mdot
.12635 .14063 Mdot
.12636 .14062 Mdot
.12637 .1406 Mdot
.12638 .14059 Mdot
.12639 .14057 Mdot
.1264 .14056 Mdot
.12641 .14055 Mdot
.12642 .14053 Mdot
.12643 .14052 Mdot
.12644 .14051 Mdot
.12645 .14049 Mdot
.12646 .14048 Mdot
.12647 .14047 Mdot
.12648 .14045 Mdot
.12649 .14044 Mdot
.1265 .14042 Mdot
.1265 .14041 Mdot
.12651 .1404 Mdot
.12652 .14038 Mdot
.12653 .14037 Mdot
.12654 .14036 Mdot
.12655 .14034 Mdot
.12656 .14033 Mdot
.12657 .14031 Mdot
.12658 .1403 Mdot
.12659 .14029 Mdot
.1266 .14027 Mdot
.12661 .14026 Mdot
.12662 .14025 Mdot
.12663 .14023 Mdot
.12664 .14022 Mdot
.12665 .14021 Mdot
.12666 .14019 Mdot
.12667 .14018 Mdot
.12668 .14016 Mdot
.12669 .14015 Mdot
.1267 .14014 Mdot
.1267 .14012 Mdot
.12671 .14011 Mdot
.12672 .1401 Mdot
.12673 .14008 Mdot
.12674 .14007 Mdot
.12675 .14006 Mdot
.12676 .14004 Mdot
.12677 .14003 Mdot
.12678 .14001 Mdot
.12679 .14 Mdot
.1268 .13999 Mdot
.12681 .13997 Mdot
.12682 .13996 Mdot
.12683 .13995 Mdot
.12684 .13993 Mdot
.12685 .13992 Mdot
.12686 .13991 Mdot
.12687 .13989 Mdot
.12688 .13988 Mdot
.12689 .13986 Mdot
.1269 .13985 Mdot
.1269 .13984 Mdot
.12691 .13982 Mdot
.12692 .13981 Mdot
.12693 .1398 Mdot
.12694 .13978 Mdot
.12695 .13977 Mdot
.12696 .13976 Mdot
.12697 .13974 Mdot
.12698 .13973 Mdot
.12699 .13971 Mdot
.127 .1397 Mdot
.12701 .13969 Mdot
.12702 .13967 Mdot
.12703 .13966 Mdot
.12704 .13965 Mdot
.12705 .13963 Mdot
.12706 .13962 Mdot
.12707 .13961 Mdot
.12708 .13959 Mdot
.12709 .13958 Mdot
.1271 .13956 Mdot
.1271 .13955 Mdot
.12711 .13954 Mdot
.12712 .13952 Mdot
.12713 .13951 Mdot
.12714 .1395 Mdot
.12715 .13948 Mdot
.12716 .13947 Mdot
.12717 .13946 Mdot
.12718 .13944 Mdot
.12719 .13943 Mdot
.1272 .13941 Mdot
.12721 .1394 Mdot
.12722 .13939 Mdot
.12723 .13937 Mdot
.12724 .13936 Mdot
.12725 .13935 Mdot
.12726 .13933 Mdot
.12727 .13932 Mdot
.12728 .13931 Mdot
.12729 .13929 Mdot
.1273 .13928 Mdot
.1273 .13926 Mdot
.12731 .13925 Mdot
.12732 .13924 Mdot
.12733 .13922 Mdot
.12734 .13921 Mdot
.12735 .1392 Mdot
.12736 .13918 Mdot
.12737 .13917 Mdot
.12738 .13916 Mdot
.12739 .13914 Mdot
.1274 .13913 Mdot
.12741 .13911 Mdot
.12742 .1391 Mdot
.12743 .13909 Mdot
.12744 .13907 Mdot
.12745 .13906 Mdot
.12746 .13905 Mdot
.12747 .13903 Mdot
.12748 .13902 Mdot
.12749 .13901 Mdot
.1275 .13899 Mdot
.1275 .13898 Mdot
.12751 .13896 Mdot
.12752 .13895 Mdot
.12753 .13894 Mdot
.12754 .13892 Mdot
.12755 .13891 Mdot
.12756 .1389 Mdot
.12757 .13888 Mdot
.12758 .13887 Mdot
.12759 .13886 Mdot
.1276 .13884 Mdot
.12761 .13883 Mdot
.12762 .13882 Mdot
.12763 .1388 Mdot
.12764 .13879 Mdot
.12765 .13877 Mdot
.12766 .13876 Mdot
.12767 .13875 Mdot
.12768 .13873 Mdot
.12769 .13872 Mdot
.1277 .13871 Mdot
.1277 .13869 Mdot
.12771 .13868 Mdot
.12772 .13867 Mdot
.12773 .13865 Mdot
.12774 .13864 Mdot
.12775 .13862 Mdot
.12776 .13861 Mdot
.12777 .1386 Mdot
.12778 .13858 Mdot
.12779 .13857 Mdot
.1278 .13856 Mdot
.12781 .13854 Mdot
.12782 .13853 Mdot
.12783 .13852 Mdot
.12784 .1385 Mdot
.12785 .13849 Mdot
.12786 .13848 Mdot
.12787 .13846 Mdot
.12788 .13845 Mdot
.12789 .13843 Mdot
.1279 .13842 Mdot
.1279 .13841 Mdot
.12791 .13839 Mdot
.12792 .13838 Mdot
.12793 .13837 Mdot
.12794 .13835 Mdot
.12795 .13834 Mdot
.12796 .13833 Mdot
.12797 .13831 Mdot
.12798 .1383 Mdot
.12799 .13829 Mdot
.128 .13827 Mdot
.12801 .13826 Mdot
.12802 .13824 Mdot
.12803 .13823 Mdot
.12804 .13822 Mdot
.12805 .1382 Mdot
.12806 .13819 Mdot
.12807 .13818 Mdot
.12808 .13816 Mdot
.12809 .13815 Mdot
.1281 .13814 Mdot
.1281 .13812 Mdot
.12811 .13811 Mdot
.12812 .13809 Mdot
.12813 .13808 Mdot
.12814 .13807 Mdot
.12815 .13805 Mdot
.12816 .13804 Mdot
.12817 .13803 Mdot
.12818 .13801 Mdot
.12819 .138 Mdot
.1282 .13799 Mdot
.12821 .13797 Mdot
.12822 .13796 Mdot
.12823 .13795 Mdot
.12824 .13793 Mdot
.12825 .13792 Mdot
.12826 .1379 Mdot
.12827 .13789 Mdot
.12828 .13788 Mdot
.12829 .13786 Mdot
.1283 .13785 Mdot
.1283 .13784 Mdot
.12831 .13782 Mdot
.12832 .13781 Mdot
.12833 .1378 Mdot
.12834 .13778 Mdot
.12835 .13777 Mdot
.12836 .13776 Mdot
.12837 .13774 Mdot
.12838 .13773 Mdot
.12839 .13772 Mdot
.1284 .1377 Mdot
.12841 .13769 Mdot
.12842 .13767 Mdot
.12843 .13766 Mdot
.12844 .13765 Mdot
.12845 .13763 Mdot
.12846 .13762 Mdot
.12847 .13761 Mdot
.12848 .13759 Mdot
.12849 .13758 Mdot
.1285 .13757 Mdot
.1285 .13755 Mdot
.12851 .13754 Mdot
.12852 .13753 Mdot
.12853 .13751 Mdot
.12854 .1375 Mdot
.12855 .13748 Mdot
.12856 .13747 Mdot
.12857 .13746 Mdot
.12858 .13744 Mdot
.12859 .13743 Mdot
.1286 .13742 Mdot
.12861 .1374 Mdot
.12862 .13739 Mdot
.12863 .13738 Mdot
.12864 .13736 Mdot
.12865 .13735 Mdot
.12866 .13734 Mdot
.12867 .13732 Mdot
.12868 .13731 Mdot
.12869 .13729 Mdot
.1287 .13728 Mdot
.1287 .13727 Mdot
.12871 .13725 Mdot
.12872 .13724 Mdot
.12873 .13723 Mdot
.12874 .13721 Mdot
.12875 .1372 Mdot
.12876 .13719 Mdot
.12877 .13717 Mdot
.12878 .13716 Mdot
.12879 .13715 Mdot
.1288 .13713 Mdot
.12881 .13712 Mdot
.12882 .13711 Mdot
.12883 .13709 Mdot
.12884 .13708 Mdot
.12885 .13706 Mdot
.12886 .13705 Mdot
.12887 .13704 Mdot
.12888 .13702 Mdot
.12889 .13701 Mdot
.1289 .137 Mdot
.1289 .13698 Mdot
.12891 .13697 Mdot
.12892 .13696 Mdot
.12893 .13694 Mdot
.12894 .13693 Mdot
.12895 .13692 Mdot
.12896 .1369 Mdot
.12897 .13689 Mdot
.12898 .13688 Mdot
.12899 .13686 Mdot
.129 .13685 Mdot
.12901 .13683 Mdot
.12902 .13682 Mdot
.12903 .13681 Mdot
.12904 .13679 Mdot
.12905 .13678 Mdot
.12906 .13677 Mdot
.12907 .13675 Mdot
.12908 .13674 Mdot
.12909 .13673 Mdot
.1291 .13671 Mdot
.1291 .1367 Mdot
.12911 .13669 Mdot
.12912 .13667 Mdot
.12913 .13666 Mdot
.12914 .13665 Mdot
.12915 .13663 Mdot
.12916 .13662 Mdot
.12917 .1366 Mdot
.12918 .13659 Mdot
.12919 .13658 Mdot
.1292 .13656 Mdot
.12921 .13655 Mdot
.12922 .13654 Mdot
.12923 .13652 Mdot
.12924 .13651 Mdot
.12925 .1365 Mdot
.12926 .13648 Mdot
.12927 .13647 Mdot
.12928 .13646 Mdot
.12929 .13644 Mdot
.1293 .13643 Mdot
.1293 .13642 Mdot
.12931 .1364 Mdot
.12932 .13639 Mdot
.12933 .13638 Mdot
.12934 .13636 Mdot
.12935 .13635 Mdot
.12936 .13633 Mdot
.12937 .13632 Mdot
.12938 .13631 Mdot
.12939 .13629 Mdot
.1294 .13628 Mdot
.12941 .13627 Mdot
.12942 .13625 Mdot
.12943 .13624 Mdot
.12944 .13623 Mdot
.12945 .13621 Mdot
.12946 .1362 Mdot
.12947 .13619 Mdot
.12948 .13617 Mdot
.12949 .13616 Mdot
.1295 .13615 Mdot
.1295 .13613 Mdot
.12951 .13612 Mdot
.12952 .13611 Mdot
.12953 .13609 Mdot
.12954 .13608 Mdot
.12955 .13606 Mdot
.12956 .13605 Mdot
.12957 .13604 Mdot
.12958 .13602 Mdot
.12959 .13601 Mdot
.1296 .136 Mdot
.12961 .13598 Mdot
.12962 .13597 Mdot
.12963 .13596 Mdot
.12964 .13594 Mdot
.12965 .13593 Mdot
.12966 .13592 Mdot
.12967 .1359 Mdot
.12968 .13589 Mdot
.12969 .13588 Mdot
.1297 .13586 Mdot
.1297 .13585 Mdot
.12971 .13584 Mdot
.12972 .13582 Mdot
.12973 .13581 Mdot
.12974 .13579 Mdot
.12975 .13578 Mdot
.12976 .13577 Mdot
.12977 .13575 Mdot
.12978 .13574 Mdot
.12979 .13573 Mdot
.1298 .13571 Mdot
.12981 .1357 Mdot
.12982 .13569 Mdot
.12983 .13567 Mdot
.12984 .13566 Mdot
.12985 .13565 Mdot
.12986 .13563 Mdot
.12987 .13562 Mdot
.12988 .13561 Mdot
.12989 .13559 Mdot
.1299 .13558 Mdot
.1299 .13557 Mdot
.12991 .13555 Mdot
.12992 .13554 Mdot
.12993 .13553 Mdot
.12994 .13551 Mdot
.12995 .1355 Mdot
.12996 .13548 Mdot
.12997 .13547 Mdot
.12998 .13546 Mdot
.12999 .13544 Mdot
.13 .13543 Mdot
.13001 .13542 Mdot
.13002 .1354 Mdot
.13003 .13539 Mdot
.13004 .13538 Mdot
.13005 .13536 Mdot
.13006 .13535 Mdot
.13007 .13534 Mdot
.13008 .13532 Mdot
.13009 .13531 Mdot
.1301 .1353 Mdot
.1301 .13528 Mdot
.13011 .13527 Mdot
.13012 .13526 Mdot
.13013 .13524 Mdot
.13014 .13523 Mdot
.13015 .13522 Mdot
.13016 .1352 Mdot
.13017 .13519 Mdot
.13018 .13517 Mdot
.13019 .13516 Mdot
.1302 .13515 Mdot
.13021 .13513 Mdot
.13022 .13512 Mdot
.13023 .13511 Mdot
.13024 .13509 Mdot
.13025 .13508 Mdot
.13026 .13507 Mdot
.13027 .13505 Mdot
.13028 .13504 Mdot
.13029 .13503 Mdot
.1303 .13501 Mdot
.1303 .135 Mdot
.13031 .13499 Mdot
.13032 .13497 Mdot
.13033 .13496 Mdot
.13034 .13495 Mdot
.13035 .13493 Mdot
.13036 .13492 Mdot
.13037 .13491 Mdot
.13038 .13489 Mdot
.13039 .13488 Mdot
.1304 .13487 Mdot
.13041 .13485 Mdot
.13042 .13484 Mdot
.13043 .13483 Mdot
.13044 .13481 Mdot
.13045 .1348 Mdot
.13046 .13478 Mdot
.13047 .13477 Mdot
.13048 .13476 Mdot
.13049 .13474 Mdot
.1305 .13473 Mdot
.1305 .13472 Mdot
.13051 .1347 Mdot
.13052 .13469 Mdot
.13053 .13468 Mdot
.13054 .13466 Mdot
.13055 .13465 Mdot
.13056 .13464 Mdot
.13057 .13462 Mdot
.13058 .13461 Mdot
.13059 .1346 Mdot
.1306 .13458 Mdot
.13061 .13457 Mdot
.13062 .13456 Mdot
.13063 .13454 Mdot
.13064 .13453 Mdot
.13065 .13452 Mdot
.13066 .1345 Mdot
.13067 .13449 Mdot
.13068 .13448 Mdot
.13069 .13446 Mdot
.1307 .13445 Mdot
.1307 .13444 Mdot
.13071 .13442 Mdot
.13072 .13441 Mdot
.13073 .13439 Mdot
.13074 .13438 Mdot
.13075 .13437 Mdot
.13076 .13435 Mdot
.13077 .13434 Mdot
.13078 .13433 Mdot
.13079 .13431 Mdot
.1308 .1343 Mdot
.13081 .13429 Mdot
.13082 .13427 Mdot
.13083 .13426 Mdot
.13084 .13425 Mdot
.13085 .13423 Mdot
.13086 .13422 Mdot
.13087 .13421 Mdot
.13088 .13419 Mdot
.13089 .13418 Mdot
.1309 .13417 Mdot
.1309 .13415 Mdot
.13091 .13414 Mdot
.13092 .13413 Mdot
.13093 .13411 Mdot
.13094 .1341 Mdot
.13095 .13409 Mdot
.13096 .13407 Mdot
.13097 .13406 Mdot
.13098 .13405 Mdot
.13099 .13403 Mdot
.131 .13402 Mdot
.13101 .13401 Mdot
.13102 .13399 Mdot
.13103 .13398 Mdot
.13104 .13397 Mdot
.13105 .13395 Mdot
.13106 .13394 Mdot
.13107 .13393 Mdot
.13108 .13391 Mdot
.13109 .1339 Mdot
.1311 .13388 Mdot
.1311 .13387 Mdot
.13111 .13386 Mdot
.13112 .13384 Mdot
.13113 .13383 Mdot
.13114 .13382 Mdot
.13115 .1338 Mdot
.13116 .13379 Mdot
.13117 .13378 Mdot
.13118 .13376 Mdot
.13119 .13375 Mdot
.1312 .13374 Mdot
.13121 .13372 Mdot
.13122 .13371 Mdot
.13123 .1337 Mdot
.13124 .13368 Mdot
.13125 .13367 Mdot
.13126 .13366 Mdot
.13127 .13364 Mdot
.13128 .13363 Mdot
.13129 .13362 Mdot
.1313 .1336 Mdot
.1313 .13359 Mdot
.13131 .13358 Mdot
.13132 .13356 Mdot
.13133 .13355 Mdot
.13134 .13354 Mdot
.13135 .13352 Mdot
.13136 .13351 Mdot
.13137 .1335 Mdot
.13138 .13348 Mdot
.13139 .13347 Mdot
.1314 .13346 Mdot
.13141 .13344 Mdot
.13142 .13343 Mdot
.13143 .13342 Mdot
.13144 .1334 Mdot
.13145 .13339 Mdot
.13146 .13338 Mdot
.13147 .13336 Mdot
.13148 .13335 Mdot
.13149 .13334 Mdot
.1315 .13332 Mdot
.1315 .13331 Mdot
.13151 .1333 Mdot
.13152 .13328 Mdot
.13153 .13327 Mdot
.13154 .13326 Mdot
.13155 .13324 Mdot
.13156 .13323 Mdot
.13157 .13322 Mdot
.13158 .1332 Mdot
.13159 .13319 Mdot
.1316 .13317 Mdot
.13161 .13316 Mdot
.13162 .13315 Mdot
.13163 .13313 Mdot
.13164 .13312 Mdot
.13165 .13311 Mdot
.13166 .13309 Mdot
.13167 .13308 Mdot
.13168 .13307 Mdot
.13169 .13305 Mdot
.1317 .13304 Mdot
.1317 .13303 Mdot
.13171 .13301 Mdot
.13172 .133 Mdot
.13173 .13299 Mdot
.13174 .13297 Mdot
.13175 .13296 Mdot
.13176 .13295 Mdot
.13177 .13293 Mdot
.13178 .13292 Mdot
.13179 .13291 Mdot
.1318 .13289 Mdot
.13181 .13288 Mdot
.13182 .13287 Mdot
.13183 .13285 Mdot
.13184 .13284 Mdot
.13185 .13283 Mdot
.13186 .13281 Mdot
.13187 .1328 Mdot
.13188 .13279 Mdot
.13189 .13277 Mdot
.1319 .13276 Mdot
.1319 .13275 Mdot
.13191 .13273 Mdot
.13192 .13272 Mdot
.13193 .13271 Mdot
.13194 .13269 Mdot
.13195 .13268 Mdot
.13196 .13267 Mdot
.13197 .13265 Mdot
.13198 .13264 Mdot
.13199 .13263 Mdot
.132 .13261 Mdot
.13201 .1326 Mdot
.13202 .13259 Mdot
.13203 .13257 Mdot
.13204 .13256 Mdot
.13205 .13255 Mdot
.13206 .13253 Mdot
.13207 .13252 Mdot
.13208 .13251 Mdot
.13209 .13249 Mdot
.1321 .13248 Mdot
.1321 .13247 Mdot
.13211 .13245 Mdot
.13212 .13244 Mdot
.13213 .13243 Mdot
.13214 .13241 Mdot
.13215 .1324 Mdot
.13216 .13239 Mdot
.13217 .13237 Mdot
.13218 .13236 Mdot
.13219 .13235 Mdot
.1322 .13233 Mdot
.13221 .13232 Mdot
.13222 .13231 Mdot
.13223 .13229 Mdot
.13224 .13228 Mdot
.13225 .13227 Mdot
.13226 .13225 Mdot
.13227 .13224 Mdot
.13228 .13223 Mdot
.13229 .13221 Mdot
.1323 .1322 Mdot
.1323 .13219 Mdot
.13231 .13217 Mdot
.13232 .13216 Mdot
.13233 .13215 Mdot
.13234 .13213 Mdot
.13235 .13212 Mdot
.13236 .13211 Mdot
.13237 .13209 Mdot
.13238 .13208 Mdot
.13239 .13207 Mdot
.1324 .13205 Mdot
.13241 .13204 Mdot
.13242 .13203 Mdot
.13243 .13201 Mdot
.13244 .132 Mdot
.13245 .13199 Mdot
.13246 .13197 Mdot
.13247 .13196 Mdot
.13248 .13195 Mdot
.13249 .13193 Mdot
.1325 .13192 Mdot
.1325 .13191 Mdot
.13251 .13189 Mdot
.13252 .13188 Mdot
.13253 .13187 Mdot
.13254 .13185 Mdot
.13255 .13184 Mdot
.13256 .13183 Mdot
.13257 .13181 Mdot
.13258 .1318 Mdot
.13259 .13179 Mdot
.1326 .13177 Mdot
.13261 .13176 Mdot
.13262 .13175 Mdot
.13263 .13173 Mdot
.13264 .13172 Mdot
.13265 .13171 Mdot
.13266 .13169 Mdot
.13267 .13168 Mdot
.13268 .13167 Mdot
.13269 .13165 Mdot
.1327 .13164 Mdot
.1327 .13163 Mdot
.13271 .13161 Mdot
.13272 .1316 Mdot
.13273 .13159 Mdot
.13274 .13157 Mdot
.13275 .13156 Mdot
.13276 .13155 Mdot
.13277 .13153 Mdot
.13278 .13152 Mdot
.13279 .13151 Mdot
.1328 .13149 Mdot
.13281 .13148 Mdot
.13282 .13147 Mdot
.13283 .13145 Mdot
.13284 .13144 Mdot
.13285 .13143 Mdot
.13286 .13141 Mdot
.13287 .1314 Mdot
.13288 .13139 Mdot
.13289 .13137 Mdot
.1329 .13136 Mdot
.1329 .13135 Mdot
.13291 .13133 Mdot
.13292 .13132 Mdot
.13293 .13131 Mdot
.13294 .13129 Mdot
.13295 .13128 Mdot
.13296 .13127 Mdot
.13297 .13125 Mdot
.13298 .13124 Mdot
.13299 .13123 Mdot
.133 .13121 Mdot
.13301 .1312 Mdot
.13302 .13119 Mdot
.13303 .13117 Mdot
.13304 .13116 Mdot
.13305 .13115 Mdot
.13306 .13113 Mdot
.13307 .13112 Mdot
.13308 .13111 Mdot
.13309 .13109 Mdot
.1331 .13108 Mdot
.1331 .13107 Mdot
.13311 .13105 Mdot
.13312 .13104 Mdot
.13313 .13103 Mdot
.13314 .13101 Mdot
.13315 .131 Mdot
.13316 .13099 Mdot
.13317 .13097 Mdot
.13318 .13096 Mdot
.13319 .13095 Mdot
.1332 .13093 Mdot
.13321 .13092 Mdot
.13322 .13091 Mdot
.13323 .13089 Mdot
.13324 .13088 Mdot
.13325 .13087 Mdot
.13326 .13085 Mdot
.13327 .13084 Mdot
.13328 .13083 Mdot
.13329 .13081 Mdot
.1333 .1308 Mdot
.1333 .13079 Mdot
.13331 .13077 Mdot
.13332 .13076 Mdot
.13333 .13075 Mdot
.13334 .13073 Mdot
.13335 .13072 Mdot
.13336 .13071 Mdot
.13337 .1307 Mdot
.13338 .13068 Mdot
.13339 .13067 Mdot
.1334 .13066 Mdot
.13341 .13064 Mdot
.13342 .13063 Mdot
.13343 .13062 Mdot
.13344 .1306 Mdot
.13345 .13059 Mdot
.13346 .13058 Mdot
.13347 .13056 Mdot
.13348 .13055 Mdot
.13349 .13054 Mdot
.1335 .13052 Mdot
.1335 .13051 Mdot
.13351 .1305 Mdot
.13352 .13048 Mdot
.13353 .13047 Mdot
.13354 .13046 Mdot
.13355 .13044 Mdot
.13356 .13043 Mdot
.13357 .13042 Mdot
.13358 .1304 Mdot
.13359 .13039 Mdot
.1336 .13038 Mdot
.13361 .13036 Mdot
.13362 .13035 Mdot
.13363 .13034 Mdot
.13364 .13032 Mdot
.13365 .13031 Mdot
.13366 .1303 Mdot
.13367 .13028 Mdot
.13368 .13027 Mdot
.13369 .13026 Mdot
.1337 .13024 Mdot
.1337 .13023 Mdot
.13371 .13022 Mdot
.13372 .1302 Mdot
.13373 .13019 Mdot
.13374 .13018 Mdot
.13375 .13016 Mdot
.13376 .13015 Mdot
.13377 .13014 Mdot
.13378 .13012 Mdot
.13379 .13011 Mdot
.1338 .1301 Mdot
.13381 .13008 Mdot
.13382 .13007 Mdot
.13383 .13006 Mdot
.13384 .13004 Mdot
.13385 .13003 Mdot
.13386 .13002 Mdot
.13387 .13001 Mdot
.13388 .12999 Mdot
.13389 .12998 Mdot
.1339 .12997 Mdot
.1339 .12995 Mdot
.13391 .12994 Mdot
.13392 .12993 Mdot
.13393 .12991 Mdot
.13394 .1299 Mdot
.13395 .12989 Mdot
.13396 .12987 Mdot
.13397 .12986 Mdot
.13398 .12985 Mdot
.13399 .12983 Mdot
.134 .12982 Mdot
.13401 .12981 Mdot
.13402 .12979 Mdot
.13403 .12978 Mdot
.13404 .12977 Mdot
.13405 .12975 Mdot
.13406 .12974 Mdot
.13407 .12973 Mdot
.13408 .12971 Mdot
.13409 .1297 Mdot
.1341 .12969 Mdot
.1341 .12967 Mdot
.13411 .12966 Mdot
.13412 .12965 Mdot
.13413 .12963 Mdot
.13414 .12962 Mdot
.13415 .12961 Mdot
.13416 .12959 Mdot
.13417 .12958 Mdot
.13418 .12957 Mdot
.13419 .12955 Mdot
.1342 .12954 Mdot
.13421 .12953 Mdot
.13422 .12952 Mdot
.13423 .1295 Mdot
.13424 .12949 Mdot
.13425 .12948 Mdot
.13426 .12946 Mdot
.13427 .12945 Mdot
.13428 .12944 Mdot
.13429 .12942 Mdot
.1343 .12941 Mdot
.1343 .1294 Mdot
.13431 .12938 Mdot
.13432 .12937 Mdot
.13433 .12936 Mdot
.13434 .12934 Mdot
.13435 .12933 Mdot
.13436 .12932 Mdot
.13437 .1293 Mdot
.13438 .12929 Mdot
.13439 .12928 Mdot
.1344 .12926 Mdot
.13441 .12925 Mdot
.13442 .12924 Mdot
.13443 .12922 Mdot
.13444 .12921 Mdot
.13445 .1292 Mdot
.13446 .12918 Mdot
.13447 .12917 Mdot
.13448 .12916 Mdot
.13449 .12914 Mdot
.1345 .12913 Mdot
.1345 .12912 Mdot
.13451 .12911 Mdot
.13452 .12909 Mdot
.13453 .12908 Mdot
.13454 .12907 Mdot
.13455 .12905 Mdot
.13456 .12904 Mdot
.13457 .12903 Mdot
.13458 .12901 Mdot
.13459 .129 Mdot
.1346 .12899 Mdot
.13461 .12897 Mdot
.13462 .12896 Mdot
.13463 .12895 Mdot
.13464 .12893 Mdot
.13465 .12892 Mdot
.13466 .12891 Mdot
.13467 .12889 Mdot
.13468 .12888 Mdot
.13469 .12887 Mdot
.1347 .12885 Mdot
.1347 .12884 Mdot
.13471 .12883 Mdot
.13472 .12881 Mdot
.13473 .1288 Mdot
.13474 .12879 Mdot
.13475 .12877 Mdot
.13476 .12876 Mdot
.13477 .12875 Mdot
.13478 .12874 Mdot
.13479 .12872 Mdot
.1348 .12871 Mdot
.13481 .1287 Mdot
.13482 .12868 Mdot
.13483 .12867 Mdot
.13484 .12866 Mdot
.13485 .12864 Mdot
.13486 .12863 Mdot
.13487 .12862 Mdot
.13488 .1286 Mdot
.13489 .12859 Mdot
.1349 .12858 Mdot
.1349 .12856 Mdot
.13491 .12855 Mdot
.13492 .12854 Mdot
.13493 .12852 Mdot
.13494 .12851 Mdot
.13495 .1285 Mdot
.13496 .12848 Mdot
.13497 .12847 Mdot
.13498 .12846 Mdot
.13499 .12845 Mdot
.135 .12843 Mdot
.13501 .12842 Mdot
.13502 .12841 Mdot
.13503 .12839 Mdot
.13504 .12838 Mdot
.13505 .12837 Mdot
.13506 .12835 Mdot
.13507 .12834 Mdot
.13508 .12833 Mdot
.13509 .12831 Mdot
.1351 .1283 Mdot
.1351 .12829 Mdot
.13511 .12827 Mdot
.13512 .12826 Mdot
.13513 .12825 Mdot
.13514 .12823 Mdot
.13515 .12822 Mdot
.13516 .12821 Mdot
.13517 .12819 Mdot
.13518 .12818 Mdot
.13519 .12817 Mdot
.1352 .12816 Mdot
.13521 .12814 Mdot
.13522 .12813 Mdot
.13523 .12812 Mdot
.13524 .1281 Mdot
.13525 .12809 Mdot
.13526 .12808 Mdot
.13527 .12806 Mdot
.13528 .12805 Mdot
.13529 .12804 Mdot
.1353 .12802 Mdot
.1353 .12801 Mdot
.13531 .128 Mdot
.13532 .12798 Mdot
.13533 .12797 Mdot
.13534 .12796 Mdot
.13535 .12794 Mdot
.13536 .12793 Mdot
.13537 .12792 Mdot
.13538 .1279 Mdot
.13539 .12789 Mdot
.1354 .12788 Mdot
.13541 .12787 Mdot
.13542 .12785 Mdot
.13543 .12784 Mdot
.13544 .12783 Mdot
.13545 .12781 Mdot
.13546 .1278 Mdot
.13547 .12779 Mdot
.13548 .12777 Mdot
.13549 .12776 Mdot
.1355 .12775 Mdot
.1355 .12773 Mdot
.13551 .12772 Mdot
.13552 .12771 Mdot
.13553 .12769 Mdot
.13554 .12768 Mdot
.13555 .12767 Mdot
.13556 .12765 Mdot
.13557 .12764 Mdot
.13558 .12763 Mdot
.13559 .12762 Mdot
.1356 .1276 Mdot
.13561 .12759 Mdot
.13562 .12758 Mdot
.13563 .12756 Mdot
.13564 .12755 Mdot
.13565 .12754 Mdot
.13566 .12752 Mdot
.13567 .12751 Mdot
.13568 .1275 Mdot
.13569 .12748 Mdot
.1357 .12747 Mdot
.1357 .12746 Mdot
.13571 .12744 Mdot
.13572 .12743 Mdot
.13573 .12742 Mdot
.13574 .1274 Mdot
.13575 .12739 Mdot
.13576 .12738 Mdot
.13577 .12737 Mdot
.13578 .12735 Mdot
.13579 .12734 Mdot
.1358 .12733 Mdot
.13581 .12731 Mdot
.13582 .1273 Mdot
.13583 .12729 Mdot
.13584 .12727 Mdot
.13585 .12726 Mdot
.13586 .12725 Mdot
.13587 .12723 Mdot
.13588 .12722 Mdot
.13589 .12721 Mdot
.1359 .12719 Mdot
.1359 .12718 Mdot
.13591 .12717 Mdot
.13592 .12716 Mdot
.13593 .12714 Mdot
.13594 .12713 Mdot
.13595 .12712 Mdot
.13596 .1271 Mdot
.13597 .12709 Mdot
.13598 .12708 Mdot
.13599 .12706 Mdot
.136 .12705 Mdot
.13601 .12704 Mdot
.13602 .12702 Mdot
.13603 .12701 Mdot
.13604 .127 Mdot
.13605 .12698 Mdot
.13606 .12697 Mdot
.13607 .12696 Mdot
.13608 .12695 Mdot
.13609 .12693 Mdot
.1361 .12692 Mdot
.1361 .12691 Mdot
.13611 .12689 Mdot
.13612 .12688 Mdot
.13613 .12687 Mdot
.13614 .12685 Mdot
.13615 .12684 Mdot
.13616 .12683 Mdot
.13617 .12681 Mdot
.13618 .1268 Mdot
.13619 .12679 Mdot
.1362 .12677 Mdot
.13621 .12676 Mdot
.13622 .12675 Mdot
.13623 .12674 Mdot
.13624 .12672 Mdot
.13625 .12671 Mdot
.13626 .1267 Mdot
.13627 .12668 Mdot
.13628 .12667 Mdot
.13629 .12666 Mdot
.1363 .12664 Mdot
.1363 .12663 Mdot
.13631 .12662 Mdot
.13632 .1266 Mdot
.13633 .12659 Mdot
.13634 .12658 Mdot
.13635 .12656 Mdot
.13636 .12655 Mdot
.13637 .12654 Mdot
.13638 .12653 Mdot
.13639 .12651 Mdot
.1364 .1265 Mdot
.13641 .12649 Mdot
.13642 .12647 Mdot
.13643 .12646 Mdot
.13644 .12645 Mdot
.13645 .12643 Mdot
.13646 .12642 Mdot
.13647 .12641 Mdot
.13648 .12639 Mdot
.13649 .12638 Mdot
.1365 .12637 Mdot
.1365 .12636 Mdot
.13651 .12634 Mdot
.13652 .12633 Mdot
.13653 .12632 Mdot
.13654 .1263 Mdot
.13655 .12629 Mdot
.13656 .12628 Mdot
.13657 .12626 Mdot
.13658 .12625 Mdot
.13659 .12624 Mdot
.1366 .12622 Mdot
.13661 .12621 Mdot
.13662 .1262 Mdot
.13663 .12618 Mdot
.13664 .12617 Mdot
.13665 .12616 Mdot
.13666 .12615 Mdot
.13667 .12613 Mdot
.13668 .12612 Mdot
.13669 .12611 Mdot
.1367 .12609 Mdot
.1367 .12608 Mdot
.13671 .12607 Mdot
.13672 .12605 Mdot
.13673 .12604 Mdot
.13674 .12603 Mdot
.13675 .12601 Mdot
.13676 .126 Mdot
.13677 .12599 Mdot
.13678 .12598 Mdot
.13679 .12596 Mdot
.1368 .12595 Mdot
.13681 .12594 Mdot
.13682 .12592 Mdot
.13683 .12591 Mdot
.13684 .1259 Mdot
.13685 .12588 Mdot
.13686 .12587 Mdot
.13687 .12586 Mdot
.13688 .12584 Mdot
.13689 .12583 Mdot
.1369 .12582 Mdot
.1369 .12581 Mdot
.13691 .12579 Mdot
.13692 .12578 Mdot
.13693 .12577 Mdot
.13694 .12575 Mdot
.13695 .12574 Mdot
.13696 .12573 Mdot
.13697 .12571 Mdot
.13698 .1257 Mdot
.13699 .12569 Mdot
.137 .12567 Mdot
.13701 .12566 Mdot
.13702 .12565 Mdot
.13703 .12564 Mdot
.13704 .12562 Mdot
.13705 .12561 Mdot
.13706 .1256 Mdot
.13707 .12558 Mdot
.13708 .12557 Mdot
.13709 .12556 Mdot
.1371 .12554 Mdot
.1371 .12553 Mdot
.13711 .12552 Mdot
.13712 .1255 Mdot
.13713 .12549 Mdot
.13714 .12548 Mdot
.13715 .12547 Mdot
.13716 .12545 Mdot
.13717 .12544 Mdot
.13718 .12543 Mdot
.13719 .12541 Mdot
.1372 .1254 Mdot
.13721 .12539 Mdot
.13722 .12537 Mdot
.13723 .12536 Mdot
.13724 .12535 Mdot
.13725 .12533 Mdot
.13726 .12532 Mdot
.13727 .12531 Mdot
.13728 .1253 Mdot
.13729 .12528 Mdot
.1373 .12527 Mdot
.1373 .12526 Mdot
.13731 .12524 Mdot
.13732 .12523 Mdot
.13733 .12522 Mdot
.13734 .1252 Mdot
.13735 .12519 Mdot
.13736 .12518 Mdot
.13737 .12517 Mdot
.13738 .12515 Mdot
.13739 .12514 Mdot
.1374 .12513 Mdot
.13741 .12511 Mdot
.13742 .1251 Mdot
.13743 .12509 Mdot
.13744 .12507 Mdot
.13745 .12506 Mdot
.13746 .12505 Mdot
.13747 .12503 Mdot
.13748 .12502 Mdot
.13749 .12501 Mdot
.1375 .125 Mdot
.1375 .12498 Mdot
.13751 .12497 Mdot
.13752 .12496 Mdot
.13753 .12494 Mdot
.13754 .12493 Mdot
.13755 .12492 Mdot
.13756 .1249 Mdot
.13757 .12489 Mdot
.13758 .12488 Mdot
.13759 .12487 Mdot
.1376 .12485 Mdot
.13761 .12484 Mdot
.13762 .12483 Mdot
.13763 .12481 Mdot
.13764 .1248 Mdot
.13765 .12479 Mdot
.13766 .12477 Mdot
.13767 .12476 Mdot
.13768 .12475 Mdot
.13769 .12473 Mdot
.1377 .12472 Mdot
.1377 .12471 Mdot
.13771 .1247 Mdot
.13772 .12468 Mdot
.13773 .12467 Mdot
.13774 .12466 Mdot
.13775 .12464 Mdot
.13776 .12463 Mdot
.13777 .12462 Mdot
.13778 .1246 Mdot
.13779 .12459 Mdot
.1378 .12458 Mdot
.13781 .12457 Mdot
.13782 .12455 Mdot
.13783 .12454 Mdot
.13784 .12453 Mdot
.13785 .12451 Mdot
.13786 .1245 Mdot
.13787 .12449 Mdot
.13788 .12447 Mdot
.13789 .12446 Mdot
.1379 .12445 Mdot
.1379 .12444 Mdot
.13791 .12442 Mdot
.13792 .12441 Mdot
.13793 .1244 Mdot
.13794 .12438 Mdot
.13795 .12437 Mdot
.13796 .12436 Mdot
.13797 .12434 Mdot
.13798 .12433 Mdot
.13799 .12432 Mdot
.138 .12431 Mdot
.13801 .12429 Mdot
.13802 .12428 Mdot
.13803 .12427 Mdot
.13804 .12425 Mdot
.13805 .12424 Mdot
.13806 .12423 Mdot
.13807 .12421 Mdot
.13808 .1242 Mdot
.13809 .12419 Mdot
.1381 .12418 Mdot
.1381 .12416 Mdot
.13811 .12415 Mdot
.13812 .12414 Mdot
.13813 .12412 Mdot
.13814 .12411 Mdot
.13815 .1241 Mdot
.13816 .12408 Mdot
.13817 .12407 Mdot
.13818 .12406 Mdot
.13819 .12405 Mdot
.1382 .12403 Mdot
.13821 .12402 Mdot
.13822 .12401 Mdot
.13823 .12399 Mdot
.13824 .12398 Mdot
.13825 .12397 Mdot
.13826 .12395 Mdot
.13827 .12394 Mdot
.13828 .12393 Mdot
.13829 .12392 Mdot
.1383 .1239 Mdot
.1383 .12389 Mdot
.13831 .12388 Mdot
.13832 .12386 Mdot
.13833 .12385 Mdot
.13834 .12384 Mdot
.13835 .12382 Mdot
.13836 .12381 Mdot
.13837 .1238 Mdot
.13838 .12379 Mdot
.13839 .12377 Mdot
.1384 .12376 Mdot
.13841 .12375 Mdot
.13842 .12373 Mdot
.13843 .12372 Mdot
.13844 .12371 Mdot
.13845 .12369 Mdot
.13846 .12368 Mdot
.13847 .12367 Mdot
.13848 .12366 Mdot
.13849 .12364 Mdot
.1385 .12363 Mdot
.1385 .12362 Mdot
.13851 .1236 Mdot
.13852 .12359 Mdot
.13853 .12358 Mdot
.13854 .12356 Mdot
.13855 .12355 Mdot
.13856 .12354 Mdot
.13857 .12353 Mdot
.13858 .12351 Mdot
.13859 .1235 Mdot
.1386 .12349 Mdot
.13861 .12347 Mdot
.13862 .12346 Mdot
.13863 .12345 Mdot
.13864 .12343 Mdot
.13865 .12342 Mdot
.13866 .12341 Mdot
.13867 .1234 Mdot
.13868 .12338 Mdot
.13869 .12337 Mdot
.1387 .12336 Mdot
.1387 .12334 Mdot
.13871 .12333 Mdot
.13872 .12332 Mdot
.13873 .12331 Mdot
.13874 .12329 Mdot
.13875 .12328 Mdot
.13876 .12327 Mdot
.13877 .12325 Mdot
.13878 .12324 Mdot
.13879 .12323 Mdot
.1388 .12321 Mdot
.13881 .1232 Mdot
.13882 .12319 Mdot
.13883 .12318 Mdot
.13884 .12316 Mdot
.13885 .12315 Mdot
.13886 .12314 Mdot
.13887 .12312 Mdot
.13888 .12311 Mdot
.13889 .1231 Mdot
.1389 .12308 Mdot
.1389 .12307 Mdot
.13891 .12306 Mdot
.13892 .12305 Mdot
.13893 .12303 Mdot
.13894 .12302 Mdot
.13895 .12301 Mdot
.13896 .12299 Mdot
.13897 .12298 Mdot
.13898 .12297 Mdot
.13899 .12296 Mdot
.139 .12294 Mdot
.13901 .12293 Mdot
.13902 .12292 Mdot
.13903 .1229 Mdot
.13904 .12289 Mdot
.13905 .12288 Mdot
.13906 .12286 Mdot
.13907 .12285 Mdot
.13908 .12284 Mdot
.13909 .12283 Mdot
.1391 .12281 Mdot
.1391 .1228 Mdot
.13911 .12279 Mdot
.13912 .12277 Mdot
.13913 .12276 Mdot
.13914 .12275 Mdot
.13915 .12273 Mdot
.13916 .12272 Mdot
.13917 .12271 Mdot
.13918 .1227 Mdot
.13919 .12268 Mdot
.1392 .12267 Mdot
.13921 .12266 Mdot
.13922 .12264 Mdot
.13923 .12263 Mdot
.13924 .12262 Mdot
.13925 .12261 Mdot
.13926 .12259 Mdot
.13927 .12258 Mdot
.13928 .12257 Mdot
.13929 .12255 Mdot
.1393 .12254 Mdot
.1393 .12253 Mdot
.13931 .12252 Mdot
.13932 .1225 Mdot
.13933 .12249 Mdot
.13934 .12248 Mdot
.13935 .12246 Mdot
.13936 .12245 Mdot
.13937 .12244 Mdot
.13938 .12242 Mdot
.13939 .12241 Mdot
.1394 .1224 Mdot
.13941 .12239 Mdot
.13942 .12237 Mdot
.13943 .12236 Mdot
.13944 .12235 Mdot
.13945 .12233 Mdot
.13946 .12232 Mdot
.13947 .12231 Mdot
.13948 .1223 Mdot
.13949 .12228 Mdot
.1395 .12227 Mdot
.1395 .12226 Mdot
.13951 .12224 Mdot
.13952 .12223 Mdot
.13953 .12222 Mdot
.13954 .1222 Mdot
.13955 .12219 Mdot
.13956 .12218 Mdot
.13957 .12217 Mdot
.13958 .12215 Mdot
.13959 .12214 Mdot
.1396 .12213 Mdot
.13961 .12211 Mdot
.13962 .1221 Mdot
.13963 .12209 Mdot
.13964 .12208 Mdot
.13965 .12206 Mdot
.13966 .12205 Mdot
.13967 .12204 Mdot
.13968 .12202 Mdot
.13969 .12201 Mdot
.1397 .122 Mdot
.1397 .12199 Mdot
.13971 .12197 Mdot
.13972 .12196 Mdot
.13973 .12195 Mdot
.13974 .12193 Mdot
.13975 .12192 Mdot
.13976 .12191 Mdot
.13977 .12189 Mdot
.13978 .12188 Mdot
.13979 .12187 Mdot
.1398 .12186 Mdot
.13981 .12184 Mdot
.13982 .12183 Mdot
.13983 .12182 Mdot
.13984 .1218 Mdot
.13985 .12179 Mdot
.13986 .12178 Mdot
.13987 .12177 Mdot
.13988 .12175 Mdot
.13989 .12174 Mdot
.1399 .12173 Mdot
.1399 .12171 Mdot
.13991 .1217 Mdot
.13992 .12169 Mdot
.13993 .12168 Mdot
.13994 .12166 Mdot
.13995 .12165 Mdot
.13996 .12164 Mdot
.13997 .12162 Mdot
.13998 .12161 Mdot
.13999 .1216 Mdot
.14 .12159 Mdot
.14001 .12157 Mdot
.14002 .12156 Mdot
.14003 .12155 Mdot
.14004 .12153 Mdot
.14005 .12152 Mdot
.14006 .12151 Mdot
.14007 .1215 Mdot
.14008 .12148 Mdot
.14009 .12147 Mdot
.1401 .12146 Mdot
.1401 .12144 Mdot
.14011 .12143 Mdot
.14012 .12142 Mdot
.14013 .1214 Mdot
.14014 .12139 Mdot
.14015 .12138 Mdot
.14016 .12137 Mdot
.14017 .12135 Mdot
.14018 .12134 Mdot
.14019 .12133 Mdot
.1402 .12131 Mdot
.14021 .1213 Mdot
.14022 .12129 Mdot
.14023 .12128 Mdot
.14024 .12126 Mdot
.14025 .12125 Mdot
.14026 .12124 Mdot
.14027 .12122 Mdot
.14028 .12121 Mdot
.14029 .1212 Mdot
.1403 .12119 Mdot
.1403 .12117 Mdot
.14031 .12116 Mdot
.14032 .12115 Mdot
.14033 .12113 Mdot
.14034 .12112 Mdot
.14035 .12111 Mdot
.14036 .1211 Mdot
.14037 .12108 Mdot
.14038 .12107 Mdot
.14039 .12106 Mdot
.1404 .12104 Mdot
.14041 .12103 Mdot
.14042 .12102 Mdot
.14043 .12101 Mdot
.14044 .12099 Mdot
.14045 .12098 Mdot
.14046 .12097 Mdot
.14047 .12095 Mdot
.14048 .12094 Mdot
.14049 .12093 Mdot
.1405 .12092 Mdot
.1405 .1209 Mdot
.14051 .12089 Mdot
.14052 .12088 Mdot
.14053 .12086 Mdot
.14054 .12085 Mdot
.14055 .12084 Mdot
.14056 .12083 Mdot
.14057 .12081 Mdot
.14058 .1208 Mdot
.14059 .12079 Mdot
.1406 .12077 Mdot
.14061 .12076 Mdot
.14062 .12075 Mdot
.14063 .12074 Mdot
.14064 .12072 Mdot
.14065 .12071 Mdot
.14066 .1207 Mdot
.14067 .12068 Mdot
.14068 .12067 Mdot
.14069 .12066 Mdot
.1407 .12065 Mdot
.1407 .12063 Mdot
.14071 .12062 Mdot
.14072 .12061 Mdot
.14073 .12059 Mdot
.14074 .12058 Mdot
.14075 .12057 Mdot
.14076 .12056 Mdot
.14077 .12054 Mdot
.14078 .12053 Mdot
.14079 .12052 Mdot
.1408 .1205 Mdot
.14081 .12049 Mdot
.14082 .12048 Mdot
.14083 .12047 Mdot
.14084 .12045 Mdot
.14085 .12044 Mdot
.14086 .12043 Mdot
.14087 .12041 Mdot
.14088 .1204 Mdot
.14089 .12039 Mdot
.1409 .12038 Mdot
.1409 .12036 Mdot
.14091 .12035 Mdot
.14092 .12034 Mdot
.14093 .12032 Mdot
.14094 .12031 Mdot
.14095 .1203 Mdot
.14096 .12029 Mdot
.14097 .12027 Mdot
.14098 .12026 Mdot
.14099 .12025 Mdot
.141 .12023 Mdot
.14101 .12022 Mdot
.14102 .12021 Mdot
.14103 .1202 Mdot
.14104 .12018 Mdot
.14105 .12017 Mdot
.14106 .12016 Mdot
.14107 .12015 Mdot
.14108 .12013 Mdot
.14109 .12012 Mdot
.1411 .12011 Mdot
.1411 .12009 Mdot
.14111 .12008 Mdot
.14112 .12007 Mdot
.14113 .12006 Mdot
.14114 .12004 Mdot
.14115 .12003 Mdot
.14116 .12002 Mdot
.14117 .12 Mdot
.14118 .11999 Mdot
.14119 .11998 Mdot
.1412 .11997 Mdot
.14121 .11995 Mdot
.14122 .11994 Mdot
.14123 .11993 Mdot
.14124 .11991 Mdot
.14125 .1199 Mdot
.14126 .11989 Mdot
.14127 .11988 Mdot
.14128 .11986 Mdot
.14129 .11985 Mdot
.1413 .11984 Mdot
.1413 .11982 Mdot
.14131 .11981 Mdot
.14132 .1198 Mdot
.14133 .11979 Mdot
.14134 .11977 Mdot
.14135 .11976 Mdot
.14136 .11975 Mdot
.14137 .11973 Mdot
.14138 .11972 Mdot
.14139 .11971 Mdot
.1414 .1197 Mdot
.14141 .11968 Mdot
.14142 .11967 Mdot
.14143 .11966 Mdot
.14144 .11965 Mdot
.14145 .11963 Mdot
.14146 .11962 Mdot
.14147 .11961 Mdot
.14148 .11959 Mdot
.14149 .11958 Mdot
.1415 .11957 Mdot
.1415 .11956 Mdot
.14151 .11954 Mdot
.14152 .11953 Mdot
.14153 .11952 Mdot
.14154 .1195 Mdot
.14155 .11949 Mdot
.14156 .11948 Mdot
.14157 .11947 Mdot
.14158 .11945 Mdot
.14159 .11944 Mdot
.1416 .11943 Mdot
.14161 .11941 Mdot
.14162 .1194 Mdot
.14163 .11939 Mdot
.14164 .11938 Mdot
.14165 .11936 Mdot
.14166 .11935 Mdot
.14167 .11934 Mdot
.14168 .11933 Mdot
.14169 .11931 Mdot
.1417 .1193 Mdot
.1417 .11929 Mdot
.14171 .11927 Mdot
.14172 .11926 Mdot
.14173 .11925 Mdot
.14174 .11924 Mdot
.14175 .11922 Mdot
.14176 .11921 Mdot
.14177 .1192 Mdot
.14178 .11918 Mdot
.14179 .11917 Mdot
.1418 .11916 Mdot
.14181 .11915 Mdot
.14182 .11913 Mdot
.14183 .11912 Mdot
.14184 .11911 Mdot
.14185 .1191 Mdot
.14186 .11908 Mdot
.14187 .11907 Mdot
.14188 .11906 Mdot
.14189 .11904 Mdot
.1419 .11903 Mdot
.1419 .11902 Mdot
.14191 .11901 Mdot
.14192 .11899 Mdot
.14193 .11898 Mdot
.14194 .11897 Mdot
.14195 .11895 Mdot
.14196 .11894 Mdot
.14197 .11893 Mdot
.14198 .11892 Mdot
.14199 .1189 Mdot
.142 .11889 Mdot
.14201 .11888 Mdot
.14202 .11887 Mdot
.14203 .11885 Mdot
.14204 .11884 Mdot
.14205 .11883 Mdot
.14206 .11881 Mdot
.14207 .1188 Mdot
.14208 .11879 Mdot
.14209 .11878 Mdot
.1421 .11876 Mdot
.1421 .11875 Mdot
.14211 .11874 Mdot
.14212 .11872 Mdot
.14213 .11871 Mdot
.14214 .1187 Mdot
.14215 .11869 Mdot
.14216 .11867 Mdot
.14217 .11866 Mdot
.14218 .11865 Mdot
.14219 .11864 Mdot
.1422 .11862 Mdot
.14221 .11861 Mdot
.14222 .1186 Mdot
.14223 .11858 Mdot
.14224 .11857 Mdot
.14225 .11856 Mdot
.14226 .11855 Mdot
.14227 .11853 Mdot
.14228 .11852 Mdot
.14229 .11851 Mdot
.1423 .1185 Mdot
.1423 .11848 Mdot
.14231 .11847 Mdot
.14232 .11846 Mdot
.14233 .11844 Mdot
.14234 .11843 Mdot
.14235 .11842 Mdot
.14236 .11841 Mdot
.14237 .11839 Mdot
.14238 .11838 Mdot
.14239 .11837 Mdot
.1424 .11835 Mdot
.14241 .11834 Mdot
.14242 .11833 Mdot
.14243 .11832 Mdot
.14244 .1183 Mdot
.14245 .11829 Mdot
.14246 .11828 Mdot
.14247 .11827 Mdot
.14248 .11825 Mdot
.14249 .11824 Mdot
.1425 .11823 Mdot
.1425 .11821 Mdot
.14251 .1182 Mdot
.14252 .11819 Mdot
.14253 .11818 Mdot
.14254 .11816 Mdot
.14255 .11815 Mdot
.14256 .11814 Mdot
.14257 .11813 Mdot
.14258 .11811 Mdot
.14259 .1181 Mdot
.1426 .11809 Mdot
.14261 .11807 Mdot
.14262 .11806 Mdot
.14263 .11805 Mdot
.14264 .11804 Mdot
.14265 .11802 Mdot
.14266 .11801 Mdot
.14267 .118 Mdot
.14268 .11799 Mdot
.14269 .11797 Mdot
.1427 .11796 Mdot
.1427 .11795 Mdot
.14271 .11793 Mdot
.14272 .11792 Mdot
.14273 .11791 Mdot
.14274 .1179 Mdot
.14275 .11788 Mdot
.14276 .11787 Mdot
.14277 .11786 Mdot
.14278 .11785 Mdot
.14279 .11783 Mdot
.1428 .11782 Mdot
.14281 .11781 Mdot
.14282 .11779 Mdot
.14283 .11778 Mdot
.14284 .11777 Mdot
.14285 .11776 Mdot
.14286 .11774 Mdot
.14287 .11773 Mdot
.14288 .11772 Mdot
.14289 .11771 Mdot
.1429 .11769 Mdot
.1429 .11768 Mdot
.14291 .11767 Mdot
.14292 .11765 Mdot
.14293 .11764 Mdot
.14294 .11763 Mdot
.14295 .11762 Mdot
.14296 .1176 Mdot
.14297 .11759 Mdot
.14298 .11758 Mdot
.14299 .11757 Mdot
.143 .11755 Mdot
.14301 .11754 Mdot
.14302 .11753 Mdot
.14303 .11751 Mdot
.14304 .1175 Mdot
.14305 .11749 Mdot
.14306 .11748 Mdot
.14307 .11746 Mdot
.14308 .11745 Mdot
.14309 .11744 Mdot
.1431 .11743 Mdot
.1431 .11741 Mdot
.14311 .1174 Mdot
.14312 .11739 Mdot
.14313 .11738 Mdot
.14314 .11736 Mdot
.14315 .11735 Mdot
.14316 .11734 Mdot
.14317 .11732 Mdot
.14318 .11731 Mdot
.14319 .1173 Mdot
.1432 .11729 Mdot
.14321 .11727 Mdot
.14322 .11726 Mdot
.14323 .11725 Mdot
.14324 .11724 Mdot
.14325 .11722 Mdot
.14326 .11721 Mdot
.14327 .1172 Mdot
.14328 .11718 Mdot
.14329 .11717 Mdot
.1433 .11716 Mdot
.1433 .11715 Mdot
.14331 .11713 Mdot
.14332 .11712 Mdot
.14333 .11711 Mdot
.14334 .1171 Mdot
.14335 .11708 Mdot
.14336 .11707 Mdot
.14337 .11706 Mdot
.14338 .11705 Mdot
.14339 .11703 Mdot
.1434 .11702 Mdot
.14341 .11701 Mdot
.14342 .11699 Mdot
.14343 .11698 Mdot
.14344 .11697 Mdot
.14345 .11696 Mdot
.14346 .11694 Mdot
.14347 .11693 Mdot
.14348 .11692 Mdot
.14349 .11691 Mdot
.1435 .11689 Mdot
.1435 .11688 Mdot
.14351 .11687 Mdot
.14352 .11686 Mdot
.14353 .11684 Mdot
.14354 .11683 Mdot
.14355 .11682 Mdot
.14356 .1168 Mdot
.14357 .11679 Mdot
.14358 .11678 Mdot
.14359 .11677 Mdot
.1436 .11675 Mdot
.14361 .11674 Mdot
.14362 .11673 Mdot
.14363 .11672 Mdot
.14364 .1167 Mdot
.14365 .11669 Mdot
.14366 .11668 Mdot
.14367 .11666 Mdot
.14368 .11665 Mdot
.14369 .11664 Mdot
.1437 .11663 Mdot
.1437 .11661 Mdot
.14371 .1166 Mdot
.14372 .11659 Mdot
.14373 .11658 Mdot
.14374 .11656 Mdot
.14375 .11655 Mdot
.14376 .11654 Mdot
.14377 .11653 Mdot
.14378 .11651 Mdot
.14379 .1165 Mdot
.1438 .11649 Mdot
.14381 .11648 Mdot
.14382 .11646 Mdot
.14383 .11645 Mdot
.14384 .11644 Mdot
.14385 .11642 Mdot
.14386 .11641 Mdot
.14387 .1164 Mdot
.14388 .11639 Mdot
.14389 .11637 Mdot
.1439 .11636 Mdot
.1439 .11635 Mdot
.14391 .11634 Mdot
.14392 .11632 Mdot
.14393 .11631 Mdot
.14394 .1163 Mdot
.14395 .11629 Mdot
.14396 .11627 Mdot
.14397 .11626 Mdot
.14398 .11625 Mdot
.14399 .11623 Mdot
.144 .11622 Mdot
.14401 .11621 Mdot
.14402 .1162 Mdot
.14403 .11618 Mdot
.14404 .11617 Mdot
.14405 .11616 Mdot
.14406 .11615 Mdot
.14407 .11613 Mdot
.14408 .11612 Mdot
.14409 .11611 Mdot
.1441 .1161 Mdot
.1441 .11608 Mdot
.14411 .11607 Mdot
.14412 .11606 Mdot
.14413 .11604 Mdot
.14414 .11603 Mdot
.14415 .11602 Mdot
.14416 .11601 Mdot
.14417 .11599 Mdot
.14418 .11598 Mdot
.14419 .11597 Mdot
.1442 .11596 Mdot
.14421 .11594 Mdot
.14422 .11593 Mdot
.14423 .11592 Mdot
.14424 .11591 Mdot
.14425 .11589 Mdot
.14426 .11588 Mdot
.14427 .11587 Mdot
.14428 .11586 Mdot
.14429 .11584 Mdot
.1443 .11583 Mdot
.1443 .11582 Mdot
.14431 .1158 Mdot
.14432 .11579 Mdot
.14433 .11578 Mdot
.14434 .11577 Mdot
.14435 .11575 Mdot
.14436 .11574 Mdot
.14437 .11573 Mdot
.14438 .11572 Mdot
.14439 .1157 Mdot
.1444 .11569 Mdot
.14441 .11568 Mdot
.14442 .11567 Mdot
.14443 .11565 Mdot
.14444 .11564 Mdot
.14445 .11563 Mdot
.14446 .11562 Mdot
.14447 .1156 Mdot
.14448 .11559 Mdot
.14449 .11558 Mdot
.1445 .11557 Mdot
.1445 .11555 Mdot
.14451 .11554 Mdot
.14452 .11553 Mdot
.14453 .11551 Mdot
.14454 .1155 Mdot
.14455 .11549 Mdot
.14456 .11548 Mdot
.14457 .11546 Mdot
.14458 .11545 Mdot
.14459 .11544 Mdot
.1446 .11543 Mdot
.14461 .11541 Mdot
.14462 .1154 Mdot
.14463 .11539 Mdot
.14464 .11538 Mdot
.14465 .11536 Mdot
.14466 .11535 Mdot
.14467 .11534 Mdot
.14468 .11533 Mdot
.14469 .11531 Mdot
.1447 .1153 Mdot
.1447 .11529 Mdot
.14471 .11528 Mdot
.14472 .11526 Mdot
.14473 .11525 Mdot
.14474 .11524 Mdot
.14475 .11522 Mdot
.14476 .11521 Mdot
.14477 .1152 Mdot
.14478 .11519 Mdot
.14479 .11517 Mdot
.1448 .11516 Mdot
.14481 .11515 Mdot
.14482 .11514 Mdot
.14483 .11512 Mdot
.14484 .11511 Mdot
.14485 .1151 Mdot
.14486 .11509 Mdot
.14487 .11507 Mdot
.14488 .11506 Mdot
.14489 .11505 Mdot
.1449 .11504 Mdot
.1449 .11502 Mdot
.14491 .11501 Mdot
.14492 .115 Mdot
.14493 .11499 Mdot
.14494 .11497 Mdot
.14495 .11496 Mdot
.14496 .11495 Mdot
.14497 .11494 Mdot
.14498 .11492 Mdot
.14499 .11491 Mdot
.145 .1149 Mdot
.14501 .11488 Mdot
.14502 .11487 Mdot
.14503 .11486 Mdot
.14504 .11485 Mdot
.14505 .11483 Mdot
.14506 .11482 Mdot
.14507 .11481 Mdot
.14508 .1148 Mdot
.14509 .11478 Mdot
.1451 .11477 Mdot
.1451 .11476 Mdot
.14511 .11475 Mdot
.14512 .11473 Mdot
.14513 .11472 Mdot
.14514 .11471 Mdot
.14515 .1147 Mdot
.14516 .11468 Mdot
.14517 .11467 Mdot
.14518 .11466 Mdot
.14519 .11465 Mdot
.1452 .11463 Mdot
.14521 .11462 Mdot
.14522 .11461 Mdot
.14523 .1146 Mdot
.14524 .11458 Mdot
.14525 .11457 Mdot
.14526 .11456 Mdot
.14527 .11455 Mdot
.14528 .11453 Mdot
.14529 .11452 Mdot
.1453 .11451 Mdot
.1453 .11449 Mdot
.14531 .11448 Mdot
.14532 .11447 Mdot
.14533 .11446 Mdot
.14534 .11444 Mdot
.14535 .11443 Mdot
.14536 .11442 Mdot
.14537 .11441 Mdot
.14538 .11439 Mdot
.14539 .11438 Mdot
.1454 .11437 Mdot
.14541 .11436 Mdot
.14542 .11434 Mdot
.14543 .11433 Mdot
.14544 .11432 Mdot
.14545 .11431 Mdot
.14546 .11429 Mdot
.14547 .11428 Mdot
.14548 .11427 Mdot
.14549 .11426 Mdot
.1455 .11424 Mdot
.1455 .11423 Mdot
.14551 .11422 Mdot
.14552 .11421 Mdot
.14553 .11419 Mdot
.14554 .11418 Mdot
.14555 .11417 Mdot
.14556 .11416 Mdot
.14557 .11414 Mdot
.14558 .11413 Mdot
.14559 .11412 Mdot
.1456 .11411 Mdot
.14561 .11409 Mdot
.14562 .11408 Mdot
.14563 .11407 Mdot
.14564 .11406 Mdot
.14565 .11404 Mdot
.14566 .11403 Mdot
.14567 .11402 Mdot
.14568 .11401 Mdot
.14569 .11399 Mdot
.1457 .11398 Mdot
.1457 .11397 Mdot
.14571 .11396 Mdot
.14572 .11394 Mdot
.14573 .11393 Mdot
.14574 .11392 Mdot
.14575 .11391 Mdot
.14576 .11389 Mdot
.14577 .11388 Mdot
.14578 .11387 Mdot
.14579 .11385 Mdot
.1458 .11384 Mdot
.14581 .11383 Mdot
.14582 .11382 Mdot
.14583 .1138 Mdot
.14584 .11379 Mdot
.14585 .11378 Mdot
.14586 .11377 Mdot
.14587 .11375 Mdot
.14588 .11374 Mdot
.14589 .11373 Mdot
.1459 .11372 Mdot
.1459 .1137 Mdot
.14591 .11369 Mdot
.14592 .11368 Mdot
.14593 .11367 Mdot
.14594 .11365 Mdot
.14595 .11364 Mdot
.14596 .11363 Mdot
.14597 .11362 Mdot
.14598 .1136 Mdot
.14599 .11359 Mdot
.146 .11358 Mdot
.14601 .11357 Mdot
.14602 .11355 Mdot
.14603 .11354 Mdot
.14604 .11353 Mdot
.14605 .11352 Mdot
.14606 .1135 Mdot
.14607 .11349 Mdot
.14608 .11348 Mdot
.14609 .11347 Mdot
.1461 .11345 Mdot
.1461 .11344 Mdot
.14611 .11343 Mdot
.14612 .11342 Mdot
.14613 .1134 Mdot
.14614 .11339 Mdot
.14615 .11338 Mdot
.14616 .11337 Mdot
.14617 .11335 Mdot
.14618 .11334 Mdot
.14619 .11333 Mdot
.1462 .11332 Mdot
.14621 .1133 Mdot
.14622 .11329 Mdot
.14623 .11328 Mdot
.14624 .11327 Mdot
.14625 .11325 Mdot
.14626 .11324 Mdot
.14627 .11323 Mdot
.14628 .11322 Mdot
.14629 .1132 Mdot
.1463 .11319 Mdot
.1463 .11318 Mdot
.14631 .11317 Mdot
.14632 .11315 Mdot
.14633 .11314 Mdot
.14634 .11313 Mdot
.14635 .11312 Mdot
.14636 .1131 Mdot
.14637 .11309 Mdot
.14638 .11308 Mdot
.14639 .11307 Mdot
.1464 .11305 Mdot
.14641 .11304 Mdot
.14642 .11303 Mdot
.14643 .11302 Mdot
.14644 .113 Mdot
.14645 .11299 Mdot
.14646 .11298 Mdot
.14647 .11297 Mdot
.14648 .11295 Mdot
.14649 .11294 Mdot
.1465 .11293 Mdot
.1465 .11292 Mdot
.14651 .1129 Mdot
.14652 .11289 Mdot
.14653 .11288 Mdot
.14654 .11287 Mdot
.14655 .11285 Mdot
.14656 .11284 Mdot
.14657 .11283 Mdot
.14658 .11282 Mdot
.14659 .1128 Mdot
.1466 .11279 Mdot
.14661 .11278 Mdot
.14662 .11277 Mdot
.14663 .11275 Mdot
.14664 .11274 Mdot
.14665 .11273 Mdot
.14666 .11272 Mdot
.14667 .1127 Mdot
.14668 .11269 Mdot
.14669 .11268 Mdot
.1467 .11267 Mdot
.1467 .11265 Mdot
.14671 .11264 Mdot
.14672 .11263 Mdot
.14673 .11262 Mdot
.14674 .1126 Mdot
.14675 .11259 Mdot
.14676 .11258 Mdot
.14677 .11257 Mdot
.14678 .11255 Mdot
.14679 .11254 Mdot
.1468 .11253 Mdot
.14681 .11252 Mdot
.14682 .1125 Mdot
.14683 .11249 Mdot
.14684 .11248 Mdot
.14685 .11247 Mdot
.14686 .11245 Mdot
.14687 .11244 Mdot
.14688 .11243 Mdot
.14689 .11242 Mdot
.1469 .11241 Mdot
.1469 .11239 Mdot
.14691 .11238 Mdot
.14692 .11237 Mdot
.14693 .11236 Mdot
.14694 .11234 Mdot
.14695 .11233 Mdot
.14696 .11232 Mdot
.14697 .11231 Mdot
.14698 .11229 Mdot
.14699 .11228 Mdot
.147 .11227 Mdot
.14701 .11226 Mdot
.14702 .11224 Mdot
.14703 .11223 Mdot
.14704 .11222 Mdot
.14705 .11221 Mdot
.14706 .11219 Mdot
.14707 .11218 Mdot
.14708 .11217 Mdot
.14709 .11216 Mdot
.1471 .11214 Mdot
.1471 .11213 Mdot
.14711 .11212 Mdot
.14712 .11211 Mdot
.14713 .11209 Mdot
.14714 .11208 Mdot
.14715 .11207 Mdot
.14716 .11206 Mdot
.14717 .11204 Mdot
.14718 .11203 Mdot
.14719 .11202 Mdot
.1472 .11201 Mdot
.14721 .11199 Mdot
.14722 .11198 Mdot
.14723 .11197 Mdot
.14724 .11196 Mdot
.14725 .11194 Mdot
.14726 .11193 Mdot
.14727 .11192 Mdot
.14728 .11191 Mdot
.14729 .11189 Mdot
.1473 .11188 Mdot
.1473 .11187 Mdot
.14731 .11186 Mdot
.14732 .11184 Mdot
.14733 .11183 Mdot
.14734 .11182 Mdot
.14735 .11181 Mdot
.14736 .1118 Mdot
.14737 .11178 Mdot
.14738 .11177 Mdot
.14739 .11176 Mdot
.1474 .11175 Mdot
.14741 .11173 Mdot
.14742 .11172 Mdot
.14743 .11171 Mdot
.14744 .1117 Mdot
.14745 .11168 Mdot
.14746 .11167 Mdot
.14747 .11166 Mdot
.14748 .11165 Mdot
.14749 .11163 Mdot
.1475 .11162 Mdot
.1475 .11161 Mdot
.14751 .1116 Mdot
.14752 .11158 Mdot
.14753 .11157 Mdot
.14754 .11156 Mdot
.14755 .11155 Mdot
.14756 .11153 Mdot
.14757 .11152 Mdot
.14758 .11151 Mdot
.14759 .1115 Mdot
.1476 .11148 Mdot
.14761 .11147 Mdot
.14762 .11146 Mdot
.14763 .11145 Mdot
.14764 .11143 Mdot
.14765 .11142 Mdot
.14766 .11141 Mdot
.14767 .1114 Mdot
.14768 .11139 Mdot
.14769 .11137 Mdot
.1477 .11136 Mdot
.1477 .11135 Mdot
.14771 .11134 Mdot
.14772 .11132 Mdot
.14773 .11131 Mdot
.14774 .1113 Mdot
.14775 .11129 Mdot
.14776 .11127 Mdot
.14777 .11126 Mdot
.14778 .11125 Mdot
.14779 .11124 Mdot
.1478 .11122 Mdot
.14781 .11121 Mdot
.14782 .1112 Mdot
.14783 .11119 Mdot
.14784 .11117 Mdot
.14785 .11116 Mdot
.14786 .11115 Mdot
.14787 .11114 Mdot
.14788 .11112 Mdot
.14789 .11111 Mdot
.1479 .1111 Mdot
.1479 .11109 Mdot
.14791 .11107 Mdot
.14792 .11106 Mdot
.14793 .11105 Mdot
.14794 .11104 Mdot
.14795 .11103 Mdot
.14796 .11101 Mdot
.14797 .111 Mdot
.14798 .11099 Mdot
.14799 .11098 Mdot
.148 .11096 Mdot
.14801 .11095 Mdot
.14802 .11094 Mdot
.14803 .11093 Mdot
.14804 .11091 Mdot
.14805 .1109 Mdot
.14806 .11089 Mdot
.14807 .11088 Mdot
.14808 .11086 Mdot
.14809 .11085 Mdot
.1481 .11084 Mdot
.1481 .11083 Mdot
.14811 .11081 Mdot
.14812 .1108 Mdot
.14813 .11079 Mdot
.14814 .11078 Mdot
.14815 .11077 Mdot
.14816 .11075 Mdot
.14817 .11074 Mdot
.14818 .11073 Mdot
.14819 .11072 Mdot
.1482 .1107 Mdot
.14821 .11069 Mdot
.14822 .11068 Mdot
.14823 .11067 Mdot
.14824 .11065 Mdot
.14825 .11064 Mdot
.14826 .11063 Mdot
.14827 .11062 Mdot
.14828 .1106 Mdot
.14829 .11059 Mdot
.1483 .11058 Mdot
.1483 .11057 Mdot
.14831 .11055 Mdot
.14832 .11054 Mdot
.14833 .11053 Mdot
.14834 .11052 Mdot
.14835 .11051 Mdot
.14836 .11049 Mdot
.14837 .11048 Mdot
.14838 .11047 Mdot
.14839 .11046 Mdot
.1484 .11044 Mdot
.14841 .11043 Mdot
.14842 .11042 Mdot
.14843 .11041 Mdot
.14844 .11039 Mdot
.14845 .11038 Mdot
.14846 .11037 Mdot
.14847 .11036 Mdot
.14848 .11034 Mdot
.14849 .11033 Mdot
.1485 .11032 Mdot
.1485 .11031 Mdot
.14851 .11029 Mdot
.14852 .11028 Mdot
.14853 .11027 Mdot
.14854 .11026 Mdot
.14855 .11025 Mdot
.14856 .11023 Mdot
.14857 .11022 Mdot
.14858 .11021 Mdot
.14859 .1102 Mdot
.1486 .11018 Mdot
.14861 .11017 Mdot
.14862 .11016 Mdot
.14863 .11015 Mdot
.14864 .11013 Mdot
.14865 .11012 Mdot
.14866 .11011 Mdot
.14867 .1101 Mdot
.14868 .11008 Mdot
.14869 .11007 Mdot
.1487 .11006 Mdot
.1487 .11005 Mdot
.14871 .11004 Mdot
.14872 .11002 Mdot
.14873 .11001 Mdot
.14874 .11 Mdot
.14875 .10999 Mdot
.14876 .10997 Mdot
.14877 .10996 Mdot
.14878 .10995 Mdot
.14879 .10994 Mdot
.1488 .10992 Mdot
.14881 .10991 Mdot
.14882 .1099 Mdot
.14883 .10989 Mdot
.14884 .10988 Mdot
.14885 .10986 Mdot
.14886 .10985 Mdot
.14887 .10984 Mdot
.14888 .10983 Mdot
.14889 .10981 Mdot
.1489 .1098 Mdot
.1489 .10979 Mdot
.14891 .10978 Mdot
.14892 .10976 Mdot
.14893 .10975 Mdot
.14894 .10974 Mdot
.14895 .10973 Mdot
.14896 .10971 Mdot
.14897 .1097 Mdot
.14898 .10969 Mdot
.14899 .10968 Mdot
.149 .10967 Mdot
.14901 .10965 Mdot
.14902 .10964 Mdot
.14903 .10963 Mdot
.14904 .10962 Mdot
.14905 .1096 Mdot
.14906 .10959 Mdot
.14907 .10958 Mdot
.14908 .10957 Mdot
.14909 .10955 Mdot
.1491 .10954 Mdot
.1491 .10953 Mdot
.14911 .10952 Mdot
.14912 .10951 Mdot
.14913 .10949 Mdot
.14914 .10948 Mdot
.14915 .10947 Mdot
.14916 .10946 Mdot
.14917 .10944 Mdot
.14918 .10943 Mdot
.14919 .10942 Mdot
.1492 .10941 Mdot
.14921 .10939 Mdot
.14922 .10938 Mdot
.14923 .10937 Mdot
.14924 .10936 Mdot
.14925 .10935 Mdot
.14926 .10933 Mdot
.14927 .10932 Mdot
.14928 .10931 Mdot
.14929 .1093 Mdot
.1493 .10928 Mdot
.1493 .10927 Mdot
.14931 .10926 Mdot
.14932 .10925 Mdot
.14933 .10923 Mdot
.14934 .10922 Mdot
.14935 .10921 Mdot
.14936 .1092 Mdot
.14937 .10919 Mdot
.14938 .10917 Mdot
.14939 .10916 Mdot
.1494 .10915 Mdot
.14941 .10914 Mdot
.14942 .10912 Mdot
.14943 .10911 Mdot
.14944 .1091 Mdot
.14945 .10909 Mdot
.14946 .10907 Mdot
.14947 .10906 Mdot
.14948 .10905 Mdot
.14949 .10904 Mdot
.1495 .10903 Mdot
.1495 .10901 Mdot
.14951 .109 Mdot
.14952 .10899 Mdot
.14953 .10898 Mdot
.14954 .10896 Mdot
.14955 .10895 Mdot
.14956 .10894 Mdot
.14957 .10893 Mdot
.14958 .10891 Mdot
.14959 .1089 Mdot
.1496 .10889 Mdot
.14961 .10888 Mdot
.14962 .10887 Mdot
.14963 .10885 Mdot
.14964 .10884 Mdot
.14965 .10883 Mdot
.14966 .10882 Mdot
.14967 .1088 Mdot
.14968 .10879 Mdot
.14969 .10878 Mdot
.1497 .10877 Mdot
.1497 .10875 Mdot
.14971 .10874 Mdot
.14972 .10873 Mdot
.14973 .10872 Mdot
.14974 .10871 Mdot
.14975 .10869 Mdot
.14976 .10868 Mdot
.14977 .10867 Mdot
.14978 .10866 Mdot
.14979 .10864 Mdot
.1498 .10863 Mdot
.14981 .10862 Mdot
.14982 .10861 Mdot
.14983 .1086 Mdot
.14984 .10858 Mdot
.14985 .10857 Mdot
.14986 .10856 Mdot
.14987 .10855 Mdot
.14988 .10853 Mdot
.14989 .10852 Mdot
.1499 .10851 Mdot
.1499 .1085 Mdot
.14991 .10848 Mdot
.14992 .10847 Mdot
.14993 .10846 Mdot
.14994 .10845 Mdot
.14995 .10844 Mdot
.14996 .10842 Mdot
.14997 .10841 Mdot
.14998 .1084 Mdot
.14999 .10839 Mdot
.15 .10837 Mdot
.15001 .10836 Mdot
.15002 .10835 Mdot
.15003 .10834 Mdot
.15004 .10833 Mdot
.15005 .10831 Mdot
.15006 .1083 Mdot
.15007 .10829 Mdot
.15008 .10828 Mdot
.15009 .10826 Mdot
.1501 .10825 Mdot
.1501 .10824 Mdot
.15011 .10823 Mdot
.15012 .10821 Mdot
.15013 .1082 Mdot
.15014 .10819 Mdot
.15015 .10818 Mdot
.15016 .10817 Mdot
.15017 .10815 Mdot
.15018 .10814 Mdot
.15019 .10813 Mdot
.1502 .10812 Mdot
.15021 .1081 Mdot
.15022 .10809 Mdot
.15023 .10808 Mdot
.15024 .10807 Mdot
.15025 .10806 Mdot
.15026 .10804 Mdot
.15027 .10803 Mdot
.15028 .10802 Mdot
.15029 .10801 Mdot
.1503 .10799 Mdot
.1503 .10798 Mdot
.15031 .10797 Mdot
.15032 .10796 Mdot
.15033 .10795 Mdot
.15034 .10793 Mdot
.15035 .10792 Mdot
.15036 .10791 Mdot
.15037 .1079 Mdot
.15038 .10788 Mdot
.15039 .10787 Mdot
.1504 .10786 Mdot
.15041 .10785 Mdot
.15042 .10784 Mdot
.15043 .10782 Mdot
.15044 .10781 Mdot
.15045 .1078 Mdot
.15046 .10779 Mdot
.15047 .10777 Mdot
.15048 .10776 Mdot
.15049 .10775 Mdot
.1505 .10774 Mdot
.1505 .10773 Mdot
.15051 .10771 Mdot
.15052 .1077 Mdot
.15053 .10769 Mdot
.15054 .10768 Mdot
.15055 .10766 Mdot
.15056 .10765 Mdot
.15057 .10764 Mdot
.15058 .10763 Mdot
.15059 .10762 Mdot
.1506 .1076 Mdot
.15061 .10759 Mdot
.15062 .10758 Mdot
.15063 .10757 Mdot
.15064 .10755 Mdot
.15065 .10754 Mdot
.15066 .10753 Mdot
.15067 .10752 Mdot
.15068 .10751 Mdot
.15069 .10749 Mdot
.1507 .10748 Mdot
.1507 .10747 Mdot
.15071 .10746 Mdot
.15072 .10744 Mdot
.15073 .10743 Mdot
.15074 .10742 Mdot
.15075 .10741 Mdot
.15076 .1074 Mdot
.15077 .10738 Mdot
.15078 .10737 Mdot
.15079 .10736 Mdot
.1508 .10735 Mdot
.15081 .10733 Mdot
.15082 .10732 Mdot
.15083 .10731 Mdot
.15084 .1073 Mdot
.15085 .10729 Mdot
.15086 .10727 Mdot
.15087 .10726 Mdot
.15088 .10725 Mdot
.15089 .10724 Mdot
.1509 .10722 Mdot
.1509 .10721 Mdot
.15091 .1072 Mdot
.15092 .10719 Mdot
.15093 .10718 Mdot
.15094 .10716 Mdot
.15095 .10715 Mdot
.15096 .10714 Mdot
.15097 .10713 Mdot
.15098 .10711 Mdot
.15099 .1071 Mdot
.151 .10709 Mdot
.15101 .10708 Mdot
.15102 .10707 Mdot
.15103 .10705 Mdot
.15104 .10704 Mdot
.15105 .10703 Mdot
.15106 .10702 Mdot
.15107 .107 Mdot
.15108 .10699 Mdot
.15109 .10698 Mdot
.1511 .10697 Mdot
.1511 .10696 Mdot
.15111 .10694 Mdot
.15112 .10693 Mdot
.15113 .10692 Mdot
.15114 .10691 Mdot
.15115 .10689 Mdot
.15116 .10688 Mdot
.15117 .10687 Mdot
.15118 .10686 Mdot
.15119 .10685 Mdot
.1512 .10683 Mdot
.15121 .10682 Mdot
.15122 .10681 Mdot
.15123 .1068 Mdot
.15124 .10679 Mdot
.15125 .10677 Mdot
.15126 .10676 Mdot
.15127 .10675 Mdot
.15128 .10674 Mdot
.15129 .10672 Mdot
.1513 .10671 Mdot
.1513 .1067 Mdot
.15131 .10669 Mdot
.15132 .10668 Mdot
.15133 .10666 Mdot
.15134 .10665 Mdot
.15135 .10664 Mdot
.15136 .10663 Mdot
.15137 .10661 Mdot
.15138 .1066 Mdot
.15139 .10659 Mdot
.1514 .10658 Mdot
.15141 .10657 Mdot
.15142 .10655 Mdot
.15143 .10654 Mdot
.15144 .10653 Mdot
.15145 .10652 Mdot
.15146 .10651 Mdot
.15147 .10649 Mdot
.15148 .10648 Mdot
.15149 .10647 Mdot
.1515 .10646 Mdot
.1515 .10644 Mdot
.15151 .10643 Mdot
.15152 .10642 Mdot
.15153 .10641 Mdot
.15154 .1064 Mdot
.15155 .10638 Mdot
.15156 .10637 Mdot
.15157 .10636 Mdot
.15158 .10635 Mdot
.15159 .10633 Mdot
.1516 .10632 Mdot
.15161 .10631 Mdot
.15162 .1063 Mdot
.15163 .10629 Mdot
.15164 .10627 Mdot
.15165 .10626 Mdot
.15166 .10625 Mdot
.15167 .10624 Mdot
.15168 .10623 Mdot
.15169 .10621 Mdot
.1517 .1062 Mdot
.1517 .10619 Mdot
.15171 .10618 Mdot
.15172 .10616 Mdot
.15173 .10615 Mdot
.15174 .10614 Mdot
.15175 .10613 Mdot
.15176 .10612 Mdot
.15177 .1061 Mdot
.15178 .10609 Mdot
.15179 .10608 Mdot
.1518 .10607 Mdot
.15181 .10606 Mdot
.15182 .10604 Mdot
.15183 .10603 Mdot
.15184 .10602 Mdot
.15185 .10601 Mdot
.15186 .10599 Mdot
.15187 .10598 Mdot
.15188 .10597 Mdot
.15189 .10596 Mdot
.1519 .10595 Mdot
.1519 .10593 Mdot
.15191 .10592 Mdot
.15192 .10591 Mdot
.15193 .1059 Mdot
.15194 .10589 Mdot
.15195 .10587 Mdot
.15196 .10586 Mdot
.15197 .10585 Mdot
.15198 .10584 Mdot
.15199 .10582 Mdot
.152 .10581 Mdot
.15201 .1058 Mdot
.15202 .10579 Mdot
.15203 .10578 Mdot
.15204 .10576 Mdot
.15205 .10575 Mdot
.15206 .10574 Mdot
.15207 .10573 Mdot
.15208 .10572 Mdot
.15209 .1057 Mdot
.1521 .10569 Mdot
.1521 .10568 Mdot
.15211 .10567 Mdot
.15212 .10565 Mdot
.15213 .10564 Mdot
.15214 .10563 Mdot
.15215 .10562 Mdot
.15216 .10561 Mdot
.15217 .10559 Mdot
.15218 .10558 Mdot
.15219 .10557 Mdot
.1522 .10556 Mdot
.15221 .10555 Mdot
.15222 .10553 Mdot
.15223 .10552 Mdot
.15224 .10551 Mdot
.15225 .1055 Mdot
.15226 .10549 Mdot
.15227 .10547 Mdot
.15228 .10546 Mdot
.15229 .10545 Mdot
.1523 .10544 Mdot
.1523 .10542 Mdot
.15231 .10541 Mdot
.15232 .1054 Mdot
.15233 .10539 Mdot
.15234 .10538 Mdot
.15235 .10536 Mdot
.15236 .10535 Mdot
.15237 .10534 Mdot
.15238 .10533 Mdot
.15239 .10532 Mdot
.1524 .1053 Mdot
.15241 .10529 Mdot
.15242 .10528 Mdot
.15243 .10527 Mdot
.15244 .10526 Mdot
.15245 .10524 Mdot
.15246 .10523 Mdot
.15247 .10522 Mdot
.15248 .10521 Mdot
.15249 .10519 Mdot
.1525 .10518 Mdot
.1525 .10517 Mdot
.15251 .10516 Mdot
.15252 .10515 Mdot
.15253 .10513 Mdot
.15254 .10512 Mdot
.15255 .10511 Mdot
.15256 .1051 Mdot
.15257 .10509 Mdot
.15258 .10507 Mdot
.15259 .10506 Mdot
.1526 .10505 Mdot
.15261 .10504 Mdot
.15262 .10503 Mdot
.15263 .10501 Mdot
.15264 .105 Mdot
.15265 .10499 Mdot
.15266 .10498 Mdot
.15267 .10496 Mdot
.15268 .10495 Mdot
.15269 .10494 Mdot
.1527 .10493 Mdot
.1527 .10492 Mdot
.15271 .1049 Mdot
.15272 .10489 Mdot
.15273 .10488 Mdot
.15274 .10487 Mdot
.15275 .10486 Mdot
.15276 .10484 Mdot
.15277 .10483 Mdot
.15278 .10482 Mdot
.15279 .10481 Mdot
.1528 .1048 Mdot
.15281 .10478 Mdot
.15282 .10477 Mdot
.15283 .10476 Mdot
.15284 .10475 Mdot
.15285 .10474 Mdot
.15286 .10472 Mdot
.15287 .10471 Mdot
.15288 .1047 Mdot
.15289 .10469 Mdot
.1529 .10467 Mdot
.1529 .10466 Mdot
.15291 .10465 Mdot
.15292 .10464 Mdot
.15293 .10463 Mdot
.15294 .10461 Mdot
.15295 .1046 Mdot
.15296 .10459 Mdot
.15297 .10458 Mdot
.15298 .10457 Mdot
.15299 .10455 Mdot
.153 .10454 Mdot
.15301 .10453 Mdot
.15302 .10452 Mdot
.15303 .10451 Mdot
.15304 .10449 Mdot
.15305 .10448 Mdot
.15306 .10447 Mdot
.15307 .10446 Mdot
.15308 .10445 Mdot
.15309 .10443 Mdot
.1531 .10442 Mdot
.1531 .10441 Mdot
.15311 .1044 Mdot
.15312 .10439 Mdot
.15313 .10437 Mdot
.15314 .10436 Mdot
.15315 .10435 Mdot
.15316 .10434 Mdot
.15317 .10432 Mdot
.15318 .10431 Mdot
.15319 .1043 Mdot
.1532 .10429 Mdot
.15321 .10428 Mdot
.15322 .10426 Mdot
.15323 .10425 Mdot
.15324 .10424 Mdot
.15325 .10423 Mdot
.15326 .10422 Mdot
.15327 .1042 Mdot
.15328 .10419 Mdot
.15329 .10418 Mdot
.1533 .10417 Mdot
.1533 .10416 Mdot
.15331 .10414 Mdot
.15332 .10413 Mdot
.15333 .10412 Mdot
.15334 .10411 Mdot
.15335 .1041 Mdot
.15336 .10408 Mdot
.15337 .10407 Mdot
.15338 .10406 Mdot
.15339 .10405 Mdot
.1534 .10404 Mdot
.15341 .10402 Mdot
.15342 .10401 Mdot
.15343 .104 Mdot
.15344 .10399 Mdot
.15345 .10398 Mdot
.15346 .10396 Mdot
.15347 .10395 Mdot
.15348 .10394 Mdot
.15349 .10393 Mdot
.1535 .10392 Mdot
.1535 .1039 Mdot
.15351 .10389 Mdot
.15352 .10388 Mdot
.15353 .10387 Mdot
.15354 .10386 Mdot
.15355 .10384 Mdot
.15356 .10383 Mdot
.15357 .10382 Mdot
.15358 .10381 Mdot
.15359 .1038 Mdot
.1536 .10378 Mdot
.15361 .10377 Mdot
.15362 .10376 Mdot
.15363 .10375 Mdot
.15364 .10373 Mdot
.15365 .10372 Mdot
.15366 .10371 Mdot
.15367 .1037 Mdot
.15368 .10369 Mdot
.15369 .10367 Mdot
.1537 .10366 Mdot
.1537 .10365 Mdot
.15371 .10364 Mdot
.15372 .10363 Mdot
.15373 .10361 Mdot
.15374 .1036 Mdot
.15375 .10359 Mdot
.15376 .10358 Mdot
.15377 .10357 Mdot
.15378 .10355 Mdot
.15379 .10354 Mdot
.1538 .10353 Mdot
.15381 .10352 Mdot
.15382 .10351 Mdot
.15383 .10349 Mdot
.15384 .10348 Mdot
.15385 .10347 Mdot
.15386 .10346 Mdot
.15387 .10345 Mdot
.15388 .10343 Mdot
.15389 .10342 Mdot
.1539 .10341 Mdot
.1539 .1034 Mdot
.15391 .10339 Mdot
.15392 .10337 Mdot
.15393 .10336 Mdot
.15394 .10335 Mdot
.15395 .10334 Mdot
.15396 .10333 Mdot
.15397 .10331 Mdot
.15398 .1033 Mdot
.15399 .10329 Mdot
.154 .10328 Mdot
.15401 .10327 Mdot
.15402 .10325 Mdot
.15403 .10324 Mdot
.15404 .10323 Mdot
.15405 .10322 Mdot
.15406 .10321 Mdot
.15407 .10319 Mdot
.15408 .10318 Mdot
.15409 .10317 Mdot
.1541 .10316 Mdot
.1541 .10315 Mdot
.15411 .10313 Mdot
.15412 .10312 Mdot
.15413 .10311 Mdot
.15414 .1031 Mdot
.15415 .10309 Mdot
.15416 .10307 Mdot
.15417 .10306 Mdot
.15418 .10305 Mdot
.15419 .10304 Mdot
.1542 .10303 Mdot
.15421 .10301 Mdot
.15422 .103 Mdot
.15423 .10299 Mdot
.15424 .10298 Mdot
.15425 .10297 Mdot
.15426 .10295 Mdot
.15427 .10294 Mdot
.15428 .10293 Mdot
.15429 .10292 Mdot
.1543 .10291 Mdot
.1543 .10289 Mdot
.15431 .10288 Mdot
.15432 .10287 Mdot
.15433 .10286 Mdot
.15434 .10285 Mdot
.15435 .10283 Mdot
.15436 .10282 Mdot
.15437 .10281 Mdot
.15438 .1028 Mdot
.15439 .10279 Mdot
.1544 .10278 Mdot
.15441 .10276 Mdot
.15442 .10275 Mdot
.15443 .10274 Mdot
.15444 .10273 Mdot
.15445 .10272 Mdot
.15446 .1027 Mdot
.15447 .10269 Mdot
.15448 .10268 Mdot
.15449 .10267 Mdot
.1545 .10266 Mdot
.1545 .10264 Mdot
.15451 .10263 Mdot
.15452 .10262 Mdot
.15453 .10261 Mdot
.15454 .1026 Mdot
.15455 .10258 Mdot
.15456 .10257 Mdot
.15457 .10256 Mdot
.15458 .10255 Mdot
.15459 .10254 Mdot
.1546 .10252 Mdot
.15461 .10251 Mdot
.15462 .1025 Mdot
.15463 .10249 Mdot
.15464 .10248 Mdot
.15465 .10246 Mdot
.15466 .10245 Mdot
.15467 .10244 Mdot
.15468 .10243 Mdot
.15469 .10242 Mdot
.1547 .1024 Mdot
.1547 .10239 Mdot
.15471 .10238 Mdot
.15472 .10237 Mdot
.15473 .10236 Mdot
.15474 .10234 Mdot
.15475 .10233 Mdot
.15476 .10232 Mdot
.15477 .10231 Mdot
.15478 .1023 Mdot
.15479 .10228 Mdot
.1548 .10227 Mdot
.15481 .10226 Mdot
.15482 .10225 Mdot
.15483 .10224 Mdot
.15484 .10223 Mdot
.15485 .10221 Mdot
.15486 .1022 Mdot
.15487 .10219 Mdot
.15488 .10218 Mdot
.15489 .10217 Mdot
.1549 .10215 Mdot
.1549 .10214 Mdot
.15491 .10213 Mdot
.15492 .10212 Mdot
.15493 .10211 Mdot
.15494 .10209 Mdot
.15495 .10208 Mdot
.15496 .10207 Mdot
.15497 .10206 Mdot
.15498 .10205 Mdot
.15499 .10203 Mdot
.155 .10202 Mdot
.15501 .10201 Mdot
.15502 .102 Mdot
.15503 .10199 Mdot
.15504 .10197 Mdot
.15505 .10196 Mdot
.15506 .10195 Mdot
.15507 .10194 Mdot
.15508 .10193 Mdot
.15509 .10191 Mdot
.1551 .1019 Mdot
.1551 .10189 Mdot
.15511 .10188 Mdot
.15512 .10187 Mdot
.15513 .10186 Mdot
.15514 .10184 Mdot
.15515 .10183 Mdot
.15516 .10182 Mdot
.15517 .10181 Mdot
.15518 .1018 Mdot
.15519 .10178 Mdot
.1552 .10177 Mdot
.15521 .10176 Mdot
.15522 .10175 Mdot
.15523 .10174 Mdot
.15524 .10172 Mdot
.15525 .10171 Mdot
.15526 .1017 Mdot
.15527 .10169 Mdot
.15528 .10168 Mdot
.15529 .10166 Mdot
.1553 .10165 Mdot
.1553 .10164 Mdot
.15531 .10163 Mdot
.15532 .10162 Mdot
.15533 .1016 Mdot
.15534 .10159 Mdot
.15535 .10158 Mdot
.15536 .10157 Mdot
.15537 .10156 Mdot
.15538 .10155 Mdot
.15539 .10153 Mdot
.1554 .10152 Mdot
.15541 .10151 Mdot
.15542 .1015 Mdot
.15543 .10149 Mdot
.15544 .10147 Mdot
.15545 .10146 Mdot
.15546 .10145 Mdot
.15547 .10144 Mdot
.15548 .10143 Mdot
.15549 .10141 Mdot
.1555 .1014 Mdot
.1555 .10139 Mdot
.15551 .10138 Mdot
.15552 .10137 Mdot
.15553 .10135 Mdot
.15554 .10134 Mdot
.15555 .10133 Mdot
.15556 .10132 Mdot
.15557 .10131 Mdot
.15558 .1013 Mdot
.15559 .10128 Mdot
.1556 .10127 Mdot
.15561 .10126 Mdot
.15562 .10125 Mdot
.15563 .10124 Mdot
.15564 .10122 Mdot
.15565 .10121 Mdot
.15566 .1012 Mdot
.15567 .10119 Mdot
.15568 .10118 Mdot
.15569 .10116 Mdot
.1557 .10115 Mdot
.1557 .10114 Mdot
.15571 .10113 Mdot
.15572 .10112 Mdot
.15573 .10111 Mdot
.15574 .10109 Mdot
.15575 .10108 Mdot
.15576 .10107 Mdot
.15577 .10106 Mdot
.15578 .10105 Mdot
.15579 .10103 Mdot
.1558 .10102 Mdot
.15581 .10101 Mdot
.15582 .101 Mdot
.15583 .10099 Mdot
.15584 .10097 Mdot
.15585 .10096 Mdot
.15586 .10095 Mdot
.15587 .10094 Mdot
.15588 .10093 Mdot
.15589 .10092 Mdot
.1559 .1009 Mdot
.1559 .10089 Mdot
.15591 .10088 Mdot
.15592 .10087 Mdot
.15593 .10086 Mdot
.15594 .10084 Mdot
.15595 .10083 Mdot
.15596 .10082 Mdot
.15597 .10081 Mdot
.15598 .1008 Mdot
.15599 .10078 Mdot
.156 .10077 Mdot
.15601 .10076 Mdot
.15602 .10075 Mdot
.15603 .10074 Mdot
.15604 .10073 Mdot
.15605 .10071 Mdot
.15606 .1007 Mdot
.15607 .10069 Mdot
.15608 .10068 Mdot
.15609 .10067 Mdot
.1561 .10065 Mdot
.1561 .10064 Mdot
.15611 .10063 Mdot
.15612 .10062 Mdot
.15613 .10061 Mdot
.15614 .10059 Mdot
.15615 .10058 Mdot
.15616 .10057 Mdot
.15617 .10056 Mdot
.15618 .10055 Mdot
.15619 .10054 Mdot
.1562 .10052 Mdot
.15621 .10051 Mdot
.15622 .1005 Mdot
.15623 .10049 Mdot
.15624 .10048 Mdot
.15625 .10046 Mdot
.15626 .10045 Mdot
.15627 .10044 Mdot
.15628 .10043 Mdot
.15629 .10042 Mdot
.1563 .10041 Mdot
.1563 .10039 Mdot
.15631 .10038 Mdot
.15632 .10037 Mdot
.15633 .10036 Mdot
.15634 .10035 Mdot
.15635 .10033 Mdot
.15636 .10032 Mdot
.15637 .10031 Mdot
.15638 .1003 Mdot
.15639 .10029 Mdot
.1564 .10027 Mdot
.15641 .10026 Mdot
.15642 .10025 Mdot
.15643 .10024 Mdot
.15644 .10023 Mdot
.15645 .10022 Mdot
.15646 .1002 Mdot
.15647 .10019 Mdot
.15648 .10018 Mdot
.15649 .10017 Mdot
.1565 .10016 Mdot
.1565 .10014 Mdot
.15651 .10013 Mdot
.15652 .10012 Mdot
.15653 .10011 Mdot
.15654 .1001 Mdot
.15655 .10009 Mdot
.15656 .10007 Mdot
.15657 .10006 Mdot
.15658 .10005 Mdot
.15659 .10004 Mdot
.1566 .10003 Mdot
.15661 .10001 Mdot
.15662 .1 Mdot
.15663 .09999 Mdot
.15664 .09998 Mdot
.15665 .09997 Mdot
.15666 .09996 Mdot
.15667 .09994 Mdot
.15668 .09993 Mdot
.15669 .09992 Mdot
.1567 .09991 Mdot
.1567 .0999 Mdot
.15671 .09988 Mdot
.15672 .09987 Mdot
.15673 .09986 Mdot
.15674 .09985 Mdot
.15675 .09984 Mdot
.15676 .09983 Mdot
.15677 .09981 Mdot
.15678 .0998 Mdot
.15679 .09979 Mdot
.1568 .09978 Mdot
.15681 .09977 Mdot
.15682 .09975 Mdot
.15683 .09974 Mdot
.15684 .09973 Mdot
.15685 .09972 Mdot
.15686 .09971 Mdot
.15687 .0997 Mdot
.15688 .09968 Mdot
.15689 .09967 Mdot
.1569 .09966 Mdot
.1569 .09965 Mdot
.15691 .09964 Mdot
.15692 .09962 Mdot
.15693 .09961 Mdot
.15694 .0996 Mdot
.15695 .09959 Mdot
.15696 .09958 Mdot
.15697 .09957 Mdot
.15698 .09955 Mdot
.15699 .09954 Mdot
.157 .09953 Mdot
.15701 .09952 Mdot
.15702 .09951 Mdot
.15703 .0995 Mdot
.15704 .09948 Mdot
.15705 .09947 Mdot
.15706 .09946 Mdot
.15707 .09945 Mdot
.15708 .09944 Mdot
.15709 .09942 Mdot
.1571 .09941 Mdot
.1571 .0994 Mdot
.15711 .09939 Mdot
.15712 .09938 Mdot
.15713 .09937 Mdot
.15714 .09935 Mdot
.15715 .09934 Mdot
.15716 .09933 Mdot
.15717 .09932 Mdot
.15718 .09931 Mdot
.15719 .09929 Mdot
.1572 .09928 Mdot
.15721 .09927 Mdot
.15722 .09926 Mdot
.15723 .09925 Mdot
.15724 .09924 Mdot
.15725 .09922 Mdot
.15726 .09921 Mdot
.15727 .0992 Mdot
.15728 .09919 Mdot
.15729 .09918 Mdot
.1573 .09917 Mdot
.1573 .09915 Mdot
.15731 .09914 Mdot
.15732 .09913 Mdot
.15733 .09912 Mdot
.15734 .09911 Mdot
.15735 .09909 Mdot
.15736 .09908 Mdot
.15737 .09907 Mdot
.15738 .09906 Mdot
.15739 .09905 Mdot
.1574 .09904 Mdot
.15741 .09902 Mdot
.15742 .09901 Mdot
.15743 .099 Mdot
.15744 .09899 Mdot
.15745 .09898 Mdot
.15746 .09896 Mdot
.15747 .09895 Mdot
.15748 .09894 Mdot
.15749 .09893 Mdot
.1575 .09892 Mdot
.1575 .09891 Mdot
.15751 .09889 Mdot
.15752 .09888 Mdot
.15753 .09887 Mdot
.15754 .09886 Mdot
.15755 .09885 Mdot
.15756 .09884 Mdot
.15757 .09882 Mdot
.15758 .09881 Mdot
.15759 .0988 Mdot
.1576 .09879 Mdot
.15761 .09878 Mdot
.15762 .09876 Mdot
.15763 .09875 Mdot
.15764 .09874 Mdot
.15765 .09873 Mdot
.15766 .09872 Mdot
.15767 .09871 Mdot
.15768 .09869 Mdot
.15769 .09868 Mdot
.1577 .09867 Mdot
.1577 .09866 Mdot
.15771 .09865 Mdot
.15772 .09864 Mdot
.15773 .09862 Mdot
.15774 .09861 Mdot
.15775 .0986 Mdot
.15776 .09859 Mdot
.15777 .09858 Mdot
.15778 .09857 Mdot
.15779 .09855 Mdot
.1578 .09854 Mdot
.15781 .09853 Mdot
.15782 .09852 Mdot
.15783 .09851 Mdot
.15784 .09849 Mdot
.15785 .09848 Mdot
.15786 .09847 Mdot
.15787 .09846 Mdot
.15788 .09845 Mdot
.15789 .09844 Mdot
.1579 .09842 Mdot
.1579 .09841 Mdot
.15791 .0984 Mdot
.15792 .09839 Mdot
.15793 .09838 Mdot
.15794 .09837 Mdot
.15795 .09835 Mdot
.15796 .09834 Mdot
.15797 .09833 Mdot
.15798 .09832 Mdot
.15799 .09831 Mdot
.158 .0983 Mdot
.15801 .09828 Mdot
.15802 .09827 Mdot
.15803 .09826 Mdot
.15804 .09825 Mdot
.15805 .09824 Mdot
.15806 .09822 Mdot
.15807 .09821 Mdot
.15808 .0982 Mdot
.15809 .09819 Mdot
.1581 .09818 Mdot
.1581 .09817 Mdot
.15811 .09815 Mdot
.15812 .09814 Mdot
.15813 .09813 Mdot
.15814 .09812 Mdot
.15815 .09811 Mdot
.15816 .0981 Mdot
.15817 .09808 Mdot
.15818 .09807 Mdot
.15819 .09806 Mdot
.1582 .09805 Mdot
.15821 .09804 Mdot
.15822 .09803 Mdot
.15823 .09801 Mdot
.15824 .098 Mdot
.15825 .09799 Mdot
.15826 .09798 Mdot
.15827 .09797 Mdot
.15828 .09796 Mdot
.15829 .09794 Mdot
.1583 .09793 Mdot
.1583 .09792 Mdot
.15831 .09791 Mdot
.15832 .0979 Mdot
.15833 .09789 Mdot
.15834 .09787 Mdot
.15835 .09786 Mdot
.15836 .09785 Mdot
.15837 .09784 Mdot
.15838 .09783 Mdot
.15839 .09781 Mdot
.1584 .0978 Mdot
.15841 .09779 Mdot
.15842 .09778 Mdot
.15843 .09777 Mdot
.15844 .09776 Mdot
.15845 .09774 Mdot
.15846 .09773 Mdot
.15847 .09772 Mdot
.15848 .09771 Mdot
.15849 .0977 Mdot
.1585 .09769 Mdot
.1585 .09767 Mdot
.15851 .09766 Mdot
.15852 .09765 Mdot
.15853 .09764 Mdot
.15854 .09763 Mdot
.15855 .09762 Mdot
.15856 .0976 Mdot
.15857 .09759 Mdot
.15858 .09758 Mdot
.15859 .09757 Mdot
.1586 .09756 Mdot
.15861 .09755 Mdot
.15862 .09753 Mdot
.15863 .09752 Mdot
.15864 .09751 Mdot
.15865 .0975 Mdot
.15866 .09749 Mdot
.15867 .09748 Mdot
.15868 .09746 Mdot
.15869 .09745 Mdot
.1587 .09744 Mdot
.1587 .09743 Mdot
.15871 .09742 Mdot
.15872 .09741 Mdot
.15873 .09739 Mdot
.15874 .09738 Mdot
.15875 .09737 Mdot
.15876 .09736 Mdot
.15877 .09735 Mdot
.15878 .09734 Mdot
.15879 .09732 Mdot
.1588 .09731 Mdot
.15881 .0973 Mdot
.15882 .09729 Mdot
.15883 .09728 Mdot
.15884 .09727 Mdot
.15885 .09725 Mdot
.15886 .09724 Mdot
.15887 .09723 Mdot
.15888 .09722 Mdot
.15889 .09721 Mdot
.1589 .0972 Mdot
.1589 .09718 Mdot
.15891 .09717 Mdot
.15892 .09716 Mdot
.15893 .09715 Mdot
.15894 .09714 Mdot
.15895 .09713 Mdot
.15896 .09711 Mdot
.15897 .0971 Mdot
.15898 .09709 Mdot
.15899 .09708 Mdot
.159 .09707 Mdot
.15901 .09706 Mdot
.15902 .09704 Mdot
.15903 .09703 Mdot
.15904 .09702 Mdot
.15905 .09701 Mdot
.15906 .097 Mdot
.15907 .09699 Mdot
.15908 .09697 Mdot
.15909 .09696 Mdot
.1591 .09695 Mdot
.1591 .09694 Mdot
.15911 .09693 Mdot
.15912 .09692 Mdot
.15913 .0969 Mdot
.15914 .09689 Mdot
.15915 .09688 Mdot
.15916 .09687 Mdot
.15917 .09686 Mdot
.15918 .09685 Mdot
.15919 .09683 Mdot
.1592 .09682 Mdot
.15921 .09681 Mdot
.15922 .0968 Mdot
.15923 .09679 Mdot
.15924 .09678 Mdot
.15925 .09676 Mdot
.15926 .09675 Mdot
.15927 .09674 Mdot
.15928 .09673 Mdot
.15929 .09672 Mdot
.1593 .09671 Mdot
.1593 .09669 Mdot
.15931 .09668 Mdot
.15932 .09667 Mdot
.15933 .09666 Mdot
.15934 .09665 Mdot
.15935 .09664 Mdot
.15936 .09662 Mdot
.15937 .09661 Mdot
.15938 .0966 Mdot
.15939 .09659 Mdot
.1594 .09658 Mdot
.15941 .09657 Mdot
.15942 .09656 Mdot
.15943 .09654 Mdot
.15944 .09653 Mdot
.15945 .09652 Mdot
.15946 .09651 Mdot
.15947 .0965 Mdot
.15948 .09649 Mdot
.15949 .09647 Mdot
.1595 .09646 Mdot
.1595 .09645 Mdot
.15951 .09644 Mdot
.15952 .09643 Mdot
.15953 .09642 Mdot
.15954 .0964 Mdot
.15955 .09639 Mdot
.15956 .09638 Mdot
.15957 .09637 Mdot
.15958 .09636 Mdot
.15959 .09635 Mdot
.1596 .09633 Mdot
.15961 .09632 Mdot
.15962 .09631 Mdot
.15963 .0963 Mdot
.15964 .09629 Mdot
.15965 .09628 Mdot
.15966 .09626 Mdot
.15967 .09625 Mdot
.15968 .09624 Mdot
.15969 .09623 Mdot
.1597 .09622 Mdot
.1597 .09621 Mdot
.15971 .09619 Mdot
.15972 .09618 Mdot
.15973 .09617 Mdot
.15974 .09616 Mdot
.15975 .09615 Mdot
.15976 .09614 Mdot
.15977 .09613 Mdot
.15978 .09611 Mdot
.15979 .0961 Mdot
.1598 .09609 Mdot
.15981 .09608 Mdot
.15982 .09607 Mdot
.15983 .09606 Mdot
.15984 .09604 Mdot
.15985 .09603 Mdot
.15986 .09602 Mdot
.15987 .09601 Mdot
.15988 .096 Mdot
.15989 .09599 Mdot
.1599 .09597 Mdot
.1599 .09596 Mdot
.15991 .09595 Mdot
.15992 .09594 Mdot
.15993 .09593 Mdot
.15994 .09592 Mdot
.15995 .0959 Mdot
.15996 .09589 Mdot
.15997 .09588 Mdot
.15998 .09587 Mdot
.15999 .09586 Mdot
.16 .09585 Mdot
.16001 .09584 Mdot
.16002 .09582 Mdot
.16003 .09581 Mdot
.16004 .0958 Mdot
.16005 .09579 Mdot
.16006 .09578 Mdot
.16007 .09577 Mdot
.16008 .09575 Mdot
.16009 .09574 Mdot
.1601 .09573 Mdot
.1601 .09572 Mdot
.16011 .09571 Mdot
.16012 .0957 Mdot
.16013 .09568 Mdot
.16014 .09567 Mdot
.16015 .09566 Mdot
.16016 .09565 Mdot
.16017 .09564 Mdot
.16018 .09563 Mdot
.16019 .09562 Mdot
.1602 .0956 Mdot
.16021 .09559 Mdot
.16022 .09558 Mdot
.16023 .09557 Mdot
.16024 .09556 Mdot
.16025 .09555 Mdot
.16026 .09553 Mdot
.16027 .09552 Mdot
.16028 .09551 Mdot
.16029 .0955 Mdot
.1603 .09549 Mdot
.1603 .09548 Mdot
.16031 .09546 Mdot
.16032 .09545 Mdot
.16033 .09544 Mdot
.16034 .09543 Mdot
.16035 .09542 Mdot
.16036 .09541 Mdot
.16037 .0954 Mdot
.16038 .09538 Mdot
.16039 .09537 Mdot
.1604 .09536 Mdot
.16041 .09535 Mdot
.16042 .09534 Mdot
.16043 .09533 Mdot
.16044 .09531 Mdot
.16045 .0953 Mdot
.16046 .09529 Mdot
.16047 .09528 Mdot
.16048 .09527 Mdot
.16049 .09526 Mdot
.1605 .09525 Mdot
.1605 .09523 Mdot
.16051 .09522 Mdot
.16052 .09521 Mdot
.16053 .0952 Mdot
.16054 .09519 Mdot
.16055 .09518 Mdot
.16056 .09516 Mdot
.16057 .09515 Mdot
.16058 .09514 Mdot
.16059 .09513 Mdot
.1606 .09512 Mdot
.16061 .09511 Mdot
.16062 .09509 Mdot
.16063 .09508 Mdot
.16064 .09507 Mdot
.16065 .09506 Mdot
.16066 .09505 Mdot
.16067 .09504 Mdot
.16068 .09503 Mdot
.16069 .09501 Mdot
.1607 .095 Mdot
.1607 .09499 Mdot
.16071 .09498 Mdot
.16072 .09497 Mdot
.16073 .09496 Mdot
.16074 .09494 Mdot
.16075 .09493 Mdot
.16076 .09492 Mdot
.16077 .09491 Mdot
.16078 .0949 Mdot
.16079 .09489 Mdot
.1608 .09488 Mdot
.16081 .09486 Mdot
.16082 .09485 Mdot
.16083 .09484 Mdot
.16084 .09483 Mdot
.16085 .09482 Mdot
.16086 .09481 Mdot
.16087 .09479 Mdot
.16088 .09478 Mdot
.16089 .09477 Mdot
.1609 .09476 Mdot
.1609 .09475 Mdot
.16091 .09474 Mdot
.16092 .09473 Mdot
.16093 .09471 Mdot
.16094 .0947 Mdot
.16095 .09469 Mdot
.16096 .09468 Mdot
.16097 .09467 Mdot
.16098 .09466 Mdot
.16099 .09465 Mdot
.161 .09463 Mdot
.16101 .09462 Mdot
.16102 .09461 Mdot
.16103 .0946 Mdot
.16104 .09459 Mdot
.16105 .09458 Mdot
.16106 .09456 Mdot
.16107 .09455 Mdot
.16108 .09454 Mdot
.16109 .09453 Mdot
.1611 .09452 Mdot
.1611 .09451 Mdot
.16111 .0945 Mdot
.16112 .09448 Mdot
.16113 .09447 Mdot
.16114 .09446 Mdot
.16115 .09445 Mdot
.16116 .09444 Mdot
.16117 .09443 Mdot
.16118 .09441 Mdot
.16119 .0944 Mdot
.1612 .09439 Mdot
.16121 .09438 Mdot
.16122 .09437 Mdot
.16123 .09436 Mdot
.16124 .09435 Mdot
.16125 .09433 Mdot
.16126 .09432 Mdot
.16127 .09431 Mdot
.16128 .0943 Mdot
.16129 .09429 Mdot
.1613 .09428 Mdot
.1613 .09427 Mdot
.16131 .09425 Mdot
.16132 .09424 Mdot
.16133 .09423 Mdot
.16134 .09422 Mdot
.16135 .09421 Mdot
.16136 .0942 Mdot
.16137 .09418 Mdot
.16138 .09417 Mdot
.16139 .09416 Mdot
.1614 .09415 Mdot
.16141 .09414 Mdot
.16142 .09413 Mdot
.16143 .09412 Mdot
.16144 .0941 Mdot
.16145 .09409 Mdot
.16146 .09408 Mdot
.16147 .09407 Mdot
.16148 .09406 Mdot
.16149 .09405 Mdot
.1615 .09404 Mdot
.1615 .09402 Mdot
.16151 .09401 Mdot
.16152 .094 Mdot
.16153 .09399 Mdot
.16154 .09398 Mdot
.16155 .09397 Mdot
.16156 .09396 Mdot
.16157 .09394 Mdot
.16158 .09393 Mdot
.16159 .09392 Mdot
.1616 .09391 Mdot
.16161 .0939 Mdot
.16162 .09389 Mdot
.16163 .09387 Mdot
.16164 .09386 Mdot
.16165 .09385 Mdot
.16166 .09384 Mdot
.16167 .09383 Mdot
.16168 .09382 Mdot
.16169 .09381 Mdot
.1617 .09379 Mdot
.1617 .09378 Mdot
.16171 .09377 Mdot
.16172 .09376 Mdot
.16173 .09375 Mdot
.16174 .09374 Mdot
.16175 .09373 Mdot
.16176 .09371 Mdot
.16177 .0937 Mdot
.16178 .09369 Mdot
.16179 .09368 Mdot
.1618 .09367 Mdot
.16181 .09366 Mdot
.16182 .09365 Mdot
.16183 .09363 Mdot
.16184 .09362 Mdot
.16185 .09361 Mdot
.16186 .0936 Mdot
.16187 .09359 Mdot
.16188 .09358 Mdot
.16189 .09357 Mdot
.1619 .09355 Mdot
.1619 .09354 Mdot
.16191 .09353 Mdot
.16192 .09352 Mdot
.16193 .09351 Mdot
.16194 .0935 Mdot
.16195 .09348 Mdot
.16196 .09347 Mdot
.16197 .09346 Mdot
.16198 .09345 Mdot
.16199 .09344 Mdot
.162 .09343 Mdot
.16201 .09342 Mdot
.16202 .0934 Mdot
.16203 .09339 Mdot
.16204 .09338 Mdot
.16205 .09337 Mdot
.16206 .09336 Mdot
.16207 .09335 Mdot
.16208 .09334 Mdot
.16209 .09332 Mdot
.1621 .09331 Mdot
.1621 .0933 Mdot
.16211 .09329 Mdot
.16212 .09328 Mdot
.16213 .09327 Mdot
.16214 .09326 Mdot
.16215 .09324 Mdot
.16216 .09323 Mdot
.16217 .09322 Mdot
.16218 .09321 Mdot
.16219 .0932 Mdot
.1622 .09319 Mdot
.16221 .09318 Mdot
.16222 .09316 Mdot
.16223 .09315 Mdot
.16224 .09314 Mdot
.16225 .09313 Mdot
.16226 .09312 Mdot
.16227 .09311 Mdot
.16228 .0931 Mdot
.16229 .09308 Mdot
.1623 .09307 Mdot
.1623 .09306 Mdot
.16231 .09305 Mdot
.16232 .09304 Mdot
.16233 .09303 Mdot
.16234 .09302 Mdot
.16235 .093 Mdot
.16236 .09299 Mdot
.16237 .09298 Mdot
.16238 .09297 Mdot
.16239 .09296 Mdot
.1624 .09295 Mdot
.16241 .09294 Mdot
.16242 .09292 Mdot
.16243 .09291 Mdot
.16244 .0929 Mdot
.16245 .09289 Mdot
.16246 .09288 Mdot
.16247 .09287 Mdot
.16248 .09286 Mdot
.16249 .09284 Mdot
.1625 .09283 Mdot
.1625 .09282 Mdot
.16251 .09281 Mdot
.16252 .0928 Mdot
.16253 .09279 Mdot
.16254 .09278 Mdot
.16255 .09276 Mdot
.16256 .09275 Mdot
.16257 .09274 Mdot
.16258 .09273 Mdot
.16259 .09272 Mdot
.1626 .09271 Mdot
.16261 .0927 Mdot
.16262 .09268 Mdot
.16263 .09267 Mdot
.16264 .09266 Mdot
.16265 .09265 Mdot
.16266 .09264 Mdot
.16267 .09263 Mdot
.16268 .09262 Mdot
.16269 .09261 Mdot
.1627 .09259 Mdot
.1627 .09258 Mdot
.16271 .09257 Mdot
.16272 .09256 Mdot
.16273 .09255 Mdot
.16274 .09254 Mdot
.16275 .09253 Mdot
.16276 .09251 Mdot
.16277 .0925 Mdot
.16278 .09249 Mdot
.16279 .09248 Mdot
.1628 .09247 Mdot
.16281 .09246 Mdot
.16282 .09245 Mdot
.16283 .09243 Mdot
.16284 .09242 Mdot
.16285 .09241 Mdot
.16286 .0924 Mdot
.16287 .09239 Mdot
.16288 .09238 Mdot
.16289 .09237 Mdot
.1629 .09235 Mdot
.1629 .09234 Mdot
.16291 .09233 Mdot
.16292 .09232 Mdot
.16293 .09231 Mdot
.16294 .0923 Mdot
.16295 .09229 Mdot
.16296 .09227 Mdot
.16297 .09226 Mdot
.16298 .09225 Mdot
.16299 .09224 Mdot
.163 .09223 Mdot
.16301 .09222 Mdot
.16302 .09221 Mdot
.16303 .0922 Mdot
.16304 .09218 Mdot
.16305 .09217 Mdot
.16306 .09216 Mdot
.16307 .09215 Mdot
.16308 .09214 Mdot
.16309 .09213 Mdot
.1631 .09212 Mdot
.1631 .0921 Mdot
.16311 .09209 Mdot
.16312 .09208 Mdot
.16313 .09207 Mdot
.16314 .09206 Mdot
.16315 .09205 Mdot
.16316 .09204 Mdot
.16317 .09202 Mdot
.16318 .09201 Mdot
.16319 .092 Mdot
.1632 .09199 Mdot
.16321 .09198 Mdot
.16322 .09197 Mdot
.16323 .09196 Mdot
.16324 .09194 Mdot
.16325 .09193 Mdot
.16326 .09192 Mdot
.16327 .09191 Mdot
.16328 .0919 Mdot
.16329 .09189 Mdot
.1633 .09188 Mdot
.1633 .09187 Mdot
.16331 .09185 Mdot
.16332 .09184 Mdot
.16333 .09183 Mdot
.16334 .09182 Mdot
.16335 .09181 Mdot
.16336 .0918 Mdot
.16337 .09179 Mdot
.16338 .09177 Mdot
.16339 .09176 Mdot
.1634 .09175 Mdot
.16341 .09174 Mdot
.16342 .09173 Mdot
.16343 .09172 Mdot
.16344 .09171 Mdot
.16345 .0917 Mdot
.16346 .09168 Mdot
.16347 .09167 Mdot
.16348 .09166 Mdot
.16349 .09165 Mdot
.1635 .09164 Mdot
.1635 .09163 Mdot
.16351 .09162 Mdot
.16352 .0916 Mdot
.16353 .09159 Mdot
.16354 .09158 Mdot
.16355 .09157 Mdot
.16356 .09156 Mdot
.16357 .09155 Mdot
.16358 .09154 Mdot
.16359 .09152 Mdot
.1636 .09151 Mdot
.16361 .0915 Mdot
.16362 .09149 Mdot
.16363 .09148 Mdot
.16364 .09147 Mdot
.16365 .09146 Mdot
.16366 .09145 Mdot
.16367 .09143 Mdot
.16368 .09142 Mdot
.16369 .09141 Mdot
.1637 .0914 Mdot
.1637 .09139 Mdot
.16371 .09138 Mdot
.16372 .09137 Mdot
.16373 .09136 Mdot
.16374 .09134 Mdot
.16375 .09133 Mdot
.16376 .09132 Mdot
.16377 .09131 Mdot
.16378 .0913 Mdot
.16379 .09129 Mdot
.1638 .09128 Mdot
.16381 .09126 Mdot
.16382 .09125 Mdot
.16383 .09124 Mdot
.16384 .09123 Mdot
.16385 .09122 Mdot
.16386 .09121 Mdot
.16387 .0912 Mdot
.16388 .09119 Mdot
.16389 .09117 Mdot
.1639 .09116 Mdot
.1639 .09115 Mdot
.16391 .09114 Mdot
.16392 .09113 Mdot
.16393 .09112 Mdot
.16394 .09111 Mdot
.16395 .09109 Mdot
.16396 .09108 Mdot
.16397 .09107 Mdot
.16398 .09106 Mdot
.16399 .09105 Mdot
.164 .09104 Mdot
.16401 .09103 Mdot
.16402 .09102 Mdot
.16403 .091 Mdot
.16404 .09099 Mdot
.16405 .09098 Mdot
.16406 .09097 Mdot
.16407 .09096 Mdot
.16408 .09095 Mdot
.16409 .09094 Mdot
.1641 .09093 Mdot
.1641 .09091 Mdot
.16411 .0909 Mdot
.16412 .09089 Mdot
.16413 .09088 Mdot
.16414 .09087 Mdot
.16415 .09086 Mdot
.16416 .09085 Mdot
.16417 .09083 Mdot
.16418 .09082 Mdot
.16419 .09081 Mdot
.1642 .0908 Mdot
.16421 .09079 Mdot
.16422 .09078 Mdot
.16423 .09077 Mdot
.16424 .09076 Mdot
.16425 .09074 Mdot
.16426 .09073 Mdot
.16427 .09072 Mdot
.16428 .09071 Mdot
.16429 .0907 Mdot
.1643 .09069 Mdot
.1643 .09068 Mdot
.16431 .09067 Mdot
.16432 .09065 Mdot
.16433 .09064 Mdot
.16434 .09063 Mdot
.16435 .09062 Mdot
.16436 .09061 Mdot
.16437 .0906 Mdot
.16438 .09059 Mdot
.16439 .09058 Mdot
.1644 .09056 Mdot
.16441 .09055 Mdot
.16442 .09054 Mdot
.16443 .09053 Mdot
.16444 .09052 Mdot
.16445 .09051 Mdot
.16446 .0905 Mdot
.16447 .09048 Mdot
.16448 .09047 Mdot
.16449 .09046 Mdot
.1645 .09045 Mdot
.1645 .09044 Mdot
.16451 .09043 Mdot
.16452 .09042 Mdot
.16453 .09041 Mdot
.16454 .09039 Mdot
.16455 .09038 Mdot
.16456 .09037 Mdot
.16457 .09036 Mdot
.16458 .09035 Mdot
.16459 .09034 Mdot
.1646 .09033 Mdot
.16461 .09032 Mdot
.16462 .0903 Mdot
.16463 .09029 Mdot
.16464 .09028 Mdot
.16465 .09027 Mdot
.16466 .09026 Mdot
.16467 .09025 Mdot
.16468 .09024 Mdot
.16469 .09023 Mdot
.1647 .09021 Mdot
.1647 .0902 Mdot
.16471 .09019 Mdot
.16472 .09018 Mdot
.16473 .09017 Mdot
.16474 .09016 Mdot
.16475 .09015 Mdot
.16476 .09014 Mdot
.16477 .09012 Mdot
.16478 .09011 Mdot
.16479 .0901 Mdot
.1648 .09009 Mdot
.16481 .09008 Mdot
.16482 .09007 Mdot
.16483 .09006 Mdot
.16484 .09005 Mdot
.16485 .09003 Mdot
.16486 .09002 Mdot
.16487 .09001 Mdot
.16488 .09 Mdot
.16489 .08999 Mdot
.1649 .08998 Mdot
.1649 .08997 Mdot
.16491 .08996 Mdot
.16492 .08994 Mdot
.16493 .08993 Mdot
.16494 .08992 Mdot
.16495 .08991 Mdot
.16496 .0899 Mdot
.16497 .08989 Mdot
.16498 .08988 Mdot
.16499 .08987 Mdot
.165 .08985 Mdot
.16501 .08984 Mdot
.16502 .08983 Mdot
.16503 .08982 Mdot
.16504 .08981 Mdot
.16505 .0898 Mdot
.16506 .08979 Mdot
.16507 .08978 Mdot
.16508 .08976 Mdot
.16509 .08975 Mdot
.1651 .08974 Mdot
.1651 .08973 Mdot
.16511 .08972 Mdot
.16512 .08971 Mdot
.16513 .0897 Mdot
.16514 .08969 Mdot
.16515 .08967 Mdot
.16516 .08966 Mdot
.16517 .08965 Mdot
.16518 .08964 Mdot
.16519 .08963 Mdot
.1652 .08962 Mdot
.16521 .08961 Mdot
.16522 .0896 Mdot
.16523 .08959 Mdot
.16524 .08957 Mdot
.16525 .08956 Mdot
.16526 .08955 Mdot
.16527 .08954 Mdot
.16528 .08953 Mdot
.16529 .08952 Mdot
.1653 .08951 Mdot
.1653 .0895 Mdot
.16531 .08948 Mdot
.16532 .08947 Mdot
.16533 .08946 Mdot
.16534 .08945 Mdot
.16535 .08944 Mdot
.16536 .08943 Mdot
.16537 .08942 Mdot
.16538 .08941 Mdot
.16539 .08939 Mdot
.1654 .08938 Mdot
.16541 .08937 Mdot
.16542 .08936 Mdot
.16543 .08935 Mdot
.16544 .08934 Mdot
.16545 .08933 Mdot
.16546 .08932 Mdot
.16547 .0893 Mdot
.16548 .08929 Mdot
.16549 .08928 Mdot
.1655 .08927 Mdot
.1655 .08926 Mdot
.16551 .08925 Mdot
.16552 .08924 Mdot
.16553 .08923 Mdot
.16554 .08922 Mdot
.16555 .0892 Mdot
.16556 .08919 Mdot
.16557 .08918 Mdot
.16558 .08917 Mdot
.16559 .08916 Mdot
.1656 .08915 Mdot
.16561 .08914 Mdot
.16562 .08913 Mdot
.16563 .08911 Mdot
.16564 .0891 Mdot
.16565 .08909 Mdot
.16566 .08908 Mdot
.16567 .08907 Mdot
.16568 .08906 Mdot
.16569 .08905 Mdot
.1657 .08904 Mdot
.1657 .08903 Mdot
.16571 .08901 Mdot
.16572 .089 Mdot
.16573 .08899 Mdot
.16574 .08898 Mdot
.16575 .08897 Mdot
.16576 .08896 Mdot
.16577 .08895 Mdot
.16578 .08894 Mdot
.16579 .08892 Mdot
.1658 .08891 Mdot
.16581 .0889 Mdot
.16582 .08889 Mdot
.16583 .08888 Mdot
.16584 .08887 Mdot
.16585 .08886 Mdot
.16586 .08885 Mdot
.16587 .08883 Mdot
.16588 .08882 Mdot
.16589 .08881 Mdot
.1659 .0888 Mdot
.1659 .08879 Mdot
.16591 .08878 Mdot
.16592 .08877 Mdot
.16593 .08876 Mdot
.16594 .08875 Mdot
.16595 .08873 Mdot
.16596 .08872 Mdot
.16597 .08871 Mdot
.16598 .0887 Mdot
.16599 .08869 Mdot
.166 .08868 Mdot
.16601 .08867 Mdot
.16602 .08866 Mdot
.16603 .08865 Mdot
.16604 .08863 Mdot
.16605 .08862 Mdot
.16606 .08861 Mdot
.16607 .0886 Mdot
.16608 .08859 Mdot
.16609 .08858 Mdot
.1661 .08857 Mdot
.1661 .08856 Mdot
.16611 .08854 Mdot
.16612 .08853 Mdot
.16613 .08852 Mdot
.16614 .08851 Mdot
.16615 .0885 Mdot
.16616 .08849 Mdot
.16617 .08848 Mdot
.16618 .08847 Mdot
.16619 .08846 Mdot
.1662 .08844 Mdot
.16621 .08843 Mdot
.16622 .08842 Mdot
.16623 .08841 Mdot
.16624 .0884 Mdot
.16625 .08839 Mdot
.16626 .08838 Mdot
.16627 .08837 Mdot
.16628 .08836 Mdot
.16629 .08834 Mdot
.1663 .08833 Mdot
.1663 .08832 Mdot
.16631 .08831 Mdot
.16632 .0883 Mdot
.16633 .08829 Mdot
.16634 .08828 Mdot
.16635 .08827 Mdot
.16636 .08825 Mdot
.16637 .08824 Mdot
.16638 .08823 Mdot
.16639 .08822 Mdot
.1664 .08821 Mdot
.16641 .0882 Mdot
.16642 .08819 Mdot
.16643 .08818 Mdot
.16644 .08817 Mdot
.16645 .08815 Mdot
.16646 .08814 Mdot
.16647 .08813 Mdot
.16648 .08812 Mdot
.16649 .08811 Mdot
.1665 .0881 Mdot
.1665 .08809 Mdot
.16651 .08808 Mdot
.16652 .08807 Mdot
.16653 .08805 Mdot
.16654 .08804 Mdot
.16655 .08803 Mdot
.16656 .08802 Mdot
.16657 .08801 Mdot
.16658 .088 Mdot
.16659 .08799 Mdot
.1666 .08798 Mdot
.16661 .08797 Mdot
.16662 .08795 Mdot
.16663 .08794 Mdot
.16664 .08793 Mdot
.16665 .08792 Mdot
.16666 .08791 Mdot
.16667 .0879 Mdot
.16668 .08789 Mdot
.16669 .08788 Mdot
.1667 .08787 Mdot
.1667 .08785 Mdot
.16671 .08784 Mdot
.16672 .08783 Mdot
.16673 .08782 Mdot
.16674 .08781 Mdot
.16675 .0878 Mdot
.16676 .08779 Mdot
.16677 .08778 Mdot
.16678 .08777 Mdot
.16679 .08775 Mdot
.1668 .08774 Mdot
.16681 .08773 Mdot
.16682 .08772 Mdot
.16683 .08771 Mdot
.16684 .0877 Mdot
.16685 .08769 Mdot
.16686 .08768 Mdot
.16687 .08767 Mdot
.16688 .08765 Mdot
.16689 .08764 Mdot
.1669 .08763 Mdot
.1669 .08762 Mdot
.16691 .08761 Mdot
.16692 .0876 Mdot
.16693 .08759 Mdot
.16694 .08758 Mdot
.16695 .08757 Mdot
.16696 .08755 Mdot
.16697 .08754 Mdot
.16698 .08753 Mdot
.16699 .08752 Mdot
.167 .08751 Mdot
.16701 .0875 Mdot
.16702 .08749 Mdot
.16703 .08748 Mdot
.16704 .08747 Mdot
.16705 .08745 Mdot
.16706 .08744 Mdot
.16707 .08743 Mdot
.16708 .08742 Mdot
.16709 .08741 Mdot
.1671 .0874 Mdot
.1671 .08739 Mdot
.16711 .08738 Mdot
.16712 .08737 Mdot
.16713 .08736 Mdot
.16714 .08734 Mdot
.16715 .08733 Mdot
.16716 .08732 Mdot
.16717 .08731 Mdot
.16718 .0873 Mdot
.16719 .08729 Mdot
.1672 .08728 Mdot
.16721 .08727 Mdot
.16722 .08726 Mdot
.16723 .08724 Mdot
.16724 .08723 Mdot
.16725 .08722 Mdot
.16726 .08721 Mdot
.16727 .0872 Mdot
.16728 .08719 Mdot
.16729 .08718 Mdot
.1673 .08717 Mdot
.1673 .08716 Mdot
.16731 .08714 Mdot
.16732 .08713 Mdot
.16733 .08712 Mdot
.16734 .08711 Mdot
.16735 .0871 Mdot
.16736 .08709 Mdot
.16737 .08708 Mdot
.16738 .08707 Mdot
.16739 .08706 Mdot
.1674 .08705 Mdot
.16741 .08703 Mdot
.16742 .08702 Mdot
.16743 .08701 Mdot
.16744 .087 Mdot
.16745 .08699 Mdot
.16746 .08698 Mdot
.16747 .08697 Mdot
.16748 .08696 Mdot
.16749 .08695 Mdot
.1675 .08693 Mdot
.1675 .08692 Mdot
.16751 .08691 Mdot
.16752 .0869 Mdot
.16753 .08689 Mdot
.16754 .08688 Mdot
.16755 .08687 Mdot
.16756 .08686 Mdot
.16757 .08685 Mdot
.16758 .08683 Mdot
.16759 .08682 Mdot
.1676 .08681 Mdot
.16761 .0868 Mdot
.16762 .08679 Mdot
.16763 .08678 Mdot
.16764 .08677 Mdot
.16765 .08676 Mdot
.16766 .08675 Mdot
.16767 .08674 Mdot
.16768 .08672 Mdot
.16769 .08671 Mdot
.1677 .0867 Mdot
.1677 .08669 Mdot
.16771 .08668 Mdot
.16772 .08667 Mdot
.16773 .08666 Mdot
.16774 .08665 Mdot
.16775 .08664 Mdot
.16776 .08663 Mdot
.16777 .08661 Mdot
.16778 .0866 Mdot
.16779 .08659 Mdot
.1678 .08658 Mdot
.16781 .08657 Mdot
.16782 .08656 Mdot
.16783 .08655 Mdot
.16784 .08654 Mdot
.16785 .08653 Mdot
.16786 .08651 Mdot
.16787 .0865 Mdot
.16788 .08649 Mdot
.16789 .08648 Mdot
.1679 .08647 Mdot
.1679 .08646 Mdot
.16791 .08645 Mdot
.16792 .08644 Mdot
.16793 .08643 Mdot
.16794 .08642 Mdot
.16795 .0864 Mdot
.16796 .08639 Mdot
.16797 .08638 Mdot
.16798 .08637 Mdot
.16799 .08636 Mdot
.168 .08635 Mdot
.16801 .08634 Mdot
.16802 .08633 Mdot
.16803 .08632 Mdot
.16804 .08631 Mdot
.16805 .08629 Mdot
.16806 .08628 Mdot
.16807 .08627 Mdot
.16808 .08626 Mdot
.16809 .08625 Mdot
.1681 .08624 Mdot
.1681 .08623 Mdot
.16811 .08622 Mdot
.16812 .08621 Mdot
.16813 .0862 Mdot
.16814 .08618 Mdot
.16815 .08617 Mdot
.16816 .08616 Mdot
.16817 .08615 Mdot
.16818 .08614 Mdot
.16819 .08613 Mdot
.1682 .08612 Mdot
.16821 .08611 Mdot
.16822 .0861 Mdot
.16823 .08609 Mdot
.16824 .08607 Mdot
.16825 .08606 Mdot
.16826 .08605 Mdot
.16827 .08604 Mdot
.16828 .08603 Mdot
.16829 .08602 Mdot
.1683 .08601 Mdot
.1683 .086 Mdot
.16831 .08599 Mdot
.16832 .08598 Mdot
.16833 .08596 Mdot
.16834 .08595 Mdot
.16835 .08594 Mdot
.16836 .08593 Mdot
.16837 .08592 Mdot
.16838 .08591 Mdot
.16839 .0859 Mdot
.1684 .08589 Mdot
.16841 .08588 Mdot
.16842 .08587 Mdot
.16843 .08585 Mdot
.16844 .08584 Mdot
.16845 .08583 Mdot
.16846 .08582 Mdot
.16847 .08581 Mdot
.16848 .0858 Mdot
.16849 .08579 Mdot
.1685 .08578 Mdot
.1685 .08577 Mdot
.16851 .08576 Mdot
.16852 .08574 Mdot
.16853 .08573 Mdot
.16854 .08572 Mdot
.16855 .08571 Mdot
.16856 .0857 Mdot
.16857 .08569 Mdot
.16858 .08568 Mdot
.16859 .08567 Mdot
.1686 .08566 Mdot
.16861 .08565 Mdot
.16862 .08563 Mdot
.16863 .08562 Mdot
.16864 .08561 Mdot
.16865 .0856 Mdot
.16866 .08559 Mdot
.16867 .08558 Mdot
.16868 .08557 Mdot
.16869 .08556 Mdot
.1687 .08555 Mdot
.1687 .08554 Mdot
.16871 .08553 Mdot
.16872 .08551 Mdot
.16873 .0855 Mdot
.16874 .08549 Mdot
.16875 .08548 Mdot
.16876 .08547 Mdot
.16877 .08546 Mdot
.16878 .08545 Mdot
.16879 .08544 Mdot
.1688 .08543 Mdot
.16881 .08542 Mdot
.16882 .0854 Mdot
.16883 .08539 Mdot
.16884 .08538 Mdot
.16885 .08537 Mdot
.16886 .08536 Mdot
.16887 .08535 Mdot
.16888 .08534 Mdot
.16889 .08533 Mdot
.1689 .08532 Mdot
.1689 .08531 Mdot
.16891 .0853 Mdot
.16892 .08528 Mdot
.16893 .08527 Mdot
.16894 .08526 Mdot
.16895 .08525 Mdot
.16896 .08524 Mdot
.16897 .08523 Mdot
.16898 .08522 Mdot
.16899 .08521 Mdot
.169 .0852 Mdot
.16901 .08519 Mdot
.16902 .08517 Mdot
.16903 .08516 Mdot
.16904 .08515 Mdot
.16905 .08514 Mdot
.16906 .08513 Mdot
.16907 .08512 Mdot
.16908 .08511 Mdot
.16909 .0851 Mdot
.1691 .08509 Mdot
.1691 .08508 Mdot
.16911 .08507 Mdot
.16912 .08505 Mdot
.16913 .08504 Mdot
.16914 .08503 Mdot
.16915 .08502 Mdot
.16916 .08501 Mdot
.16917 .085 Mdot
.16918 .08499 Mdot
.16919 .08498 Mdot
.1692 .08497 Mdot
.16921 .08496 Mdot
.16922 .08494 Mdot
.16923 .08493 Mdot
.16924 .08492 Mdot
.16925 .08491 Mdot
.16926 .0849 Mdot
.16927 .08489 Mdot
.16928 .08488 Mdot
.16929 .08487 Mdot
.1693 .08486 Mdot
.1693 .08485 Mdot
.16931 .08484 Mdot
.16932 .08482 Mdot
.16933 .08481 Mdot
.16934 .0848 Mdot
.16935 .08479 Mdot
.16936 .08478 Mdot
.16937 .08477 Mdot
.16938 .08476 Mdot
.16939 .08475 Mdot
.1694 .08474 Mdot
.16941 .08473 Mdot
.16942 .08472 Mdot
.16943 .0847 Mdot
.16944 .08469 Mdot
.16945 .08468 Mdot
.16946 .08467 Mdot
.16947 .08466 Mdot
.16948 .08465 Mdot
.16949 .08464 Mdot
.1695 .08463 Mdot
.1695 .08462 Mdot
.16951 .08461 Mdot
.16952 .0846 Mdot
.16953 .08458 Mdot
.16954 .08457 Mdot
.16955 .08456 Mdot
.16956 .08455 Mdot
.16957 .08454 Mdot
.16958 .08453 Mdot
.16959 .08452 Mdot
.1696 .08451 Mdot
.16961 .0845 Mdot
.16962 .08449 Mdot
.16963 .08448 Mdot
.16964 .08446 Mdot
.16965 .08445 Mdot
.16966 .08444 Mdot
.16967 .08443 Mdot
.16968 .08442 Mdot
.16969 .08441 Mdot
.1697 .0844 Mdot
.1697 .08439 Mdot
.16971 .08438 Mdot
.16972 .08437 Mdot
.16973 .08436 Mdot
.16974 .08434 Mdot
.16975 .08433 Mdot
.16976 .08432 Mdot
.16977 .08431 Mdot
.16978 .0843 Mdot
.16979 .08429 Mdot
.1698 .08428 Mdot
.16981 .08427 Mdot
.16982 .08426 Mdot
.16983 .08425 Mdot
.16984 .08424 Mdot
.16985 .08423 Mdot
.16986 .08421 Mdot
.16987 .0842 Mdot
.16988 .08419 Mdot
.16989 .08418 Mdot
.1699 .08417 Mdot
.1699 .08416 Mdot
.16991 .08415 Mdot
.16992 .08414 Mdot
.16993 .08413 Mdot
.16994 .08412 Mdot
.16995 .08411 Mdot
.16996 .08409 Mdot
.16997 .08408 Mdot
.16998 .08407 Mdot
.16999 .08406 Mdot
.17 .08405 Mdot
.17001 .08404 Mdot
.17002 .08403 Mdot
.17003 .08402 Mdot
.17004 .08401 Mdot
.17005 .084 Mdot
.17006 .08399 Mdot
.17007 .08398 Mdot
.17008 .08396 Mdot
.17009 .08395 Mdot
.1701 .08394 Mdot
.1701 .08393 Mdot
.17011 .08392 Mdot
.17012 .08391 Mdot
.17013 .0839 Mdot
.17014 .08389 Mdot
.17015 .08388 Mdot
.17016 .08387 Mdot
.17017 .08386 Mdot
.17018 .08384 Mdot
.17019 .08383 Mdot
.1702 .08382 Mdot
.17021 .08381 Mdot
.17022 .0838 Mdot
.17023 .08379 Mdot
.17024 .08378 Mdot
.17025 .08377 Mdot
.17026 .08376 Mdot
.17027 .08375 Mdot
.17028 .08374 Mdot
.17029 .08373 Mdot
.1703 .08371 Mdot
.1703 .0837 Mdot
.17031 .08369 Mdot
.17032 .08368 Mdot
.17033 .08367 Mdot
.17034 .08366 Mdot
.17035 .08365 Mdot
.17036 .08364 Mdot
.17037 .08363 Mdot
.17038 .08362 Mdot
.17039 .08361 Mdot
.1704 .0836 Mdot
.17041 .08358 Mdot
.17042 .08357 Mdot
.17043 .08356 Mdot
.17044 .08355 Mdot
.17045 .08354 Mdot
.17046 .08353 Mdot
.17047 .08352 Mdot
.17048 .08351 Mdot
.17049 .0835 Mdot
.1705 .08349 Mdot
.1705 .08348 Mdot
.17051 .08347 Mdot
.17052 .08345 Mdot
.17053 .08344 Mdot
.17054 .08343 Mdot
.17055 .08342 Mdot
.17056 .08341 Mdot
.17057 .0834 Mdot
.17058 .08339 Mdot
.17059 .08338 Mdot
.1706 .08337 Mdot
.17061 .08336 Mdot
.17062 .08335 Mdot
.17063 .08334 Mdot
.17064 .08332 Mdot
.17065 .08331 Mdot
.17066 .0833 Mdot
.17067 .08329 Mdot
.17068 .08328 Mdot
.17069 .08327 Mdot
.1707 .08326 Mdot
.1707 .08325 Mdot
.17071 .08324 Mdot
.17072 .08323 Mdot
.17073 .08322 Mdot
.17074 .08321 Mdot
.17075 .08319 Mdot
.17076 .08318 Mdot
.17077 .08317 Mdot
.17078 .08316 Mdot
.17079 .08315 Mdot
.1708 .08314 Mdot
.17081 .08313 Mdot
.17082 .08312 Mdot
.17083 .08311 Mdot
.17084 .0831 Mdot
.17085 .08309 Mdot
.17086 .08308 Mdot
.17087 .08306 Mdot
.17088 .08305 Mdot
.17089 .08304 Mdot
.1709 .08303 Mdot
.1709 .08302 Mdot
.17091 .08301 Mdot
.17092 .083 Mdot
.17093 .08299 Mdot
.17094 .08298 Mdot
.17095 .08297 Mdot
.17096 .08296 Mdot
.17097 .08295 Mdot
.17098 .08294 Mdot
.17099 .08292 Mdot
.171 .08291 Mdot
.17101 .0829 Mdot
.17102 .08289 Mdot
.17103 .08288 Mdot
.17104 .08287 Mdot
.17105 .08286 Mdot
.17106 .08285 Mdot
.17107 .08284 Mdot
.17108 .08283 Mdot
.17109 .08282 Mdot
.1711 .08281 Mdot
.1711 .08279 Mdot
.17111 .08278 Mdot
.17112 .08277 Mdot
.17113 .08276 Mdot
.17114 .08275 Mdot
.17115 .08274 Mdot
.17116 .08273 Mdot
.17117 .08272 Mdot
.17118 .08271 Mdot
.17119 .0827 Mdot
.1712 .08269 Mdot
.17121 .08268 Mdot
.17122 .08267 Mdot
.17123 .08265 Mdot
.17124 .08264 Mdot
.17125 .08263 Mdot
.17126 .08262 Mdot
.17127 .08261 Mdot
.17128 .0826 Mdot
.17129 .08259 Mdot
.1713 .08258 Mdot
.1713 .08257 Mdot
.17131 .08256 Mdot
.17132 .08255 Mdot
.17133 .08254 Mdot
.17134 .08253 Mdot
.17135 .08251 Mdot
.17136 .0825 Mdot
.17137 .08249 Mdot
.17138 .08248 Mdot
.17139 .08247 Mdot
.1714 .08246 Mdot
.17141 .08245 Mdot
.17142 .08244 Mdot
.17143 .08243 Mdot
.17144 .08242 Mdot
.17145 .08241 Mdot
.17146 .0824 Mdot
.17147 .08239 Mdot
.17148 .08237 Mdot
.17149 .08236 Mdot
.1715 .08235 Mdot
.1715 .08234 Mdot
.17151 .08233 Mdot
.17152 .08232 Mdot
.17153 .08231 Mdot
.17154 .0823 Mdot
.17155 .08229 Mdot
.17156 .08228 Mdot
.17157 .08227 Mdot
.17158 .08226 Mdot
.17159 .08225 Mdot
.1716 .08223 Mdot
.17161 .08222 Mdot
.17162 .08221 Mdot
.17163 .0822 Mdot
.17164 .08219 Mdot
.17165 .08218 Mdot
.17166 .08217 Mdot
.17167 .08216 Mdot
.17168 .08215 Mdot
.17169 .08214 Mdot
.1717 .08213 Mdot
.1717 .08212 Mdot
.17171 .08211 Mdot
.17172 .0821 Mdot
.17173 .08208 Mdot
.17174 .08207 Mdot
.17175 .08206 Mdot
.17176 .08205 Mdot
.17177 .08204 Mdot
.17178 .08203 Mdot
.17179 .08202 Mdot
.1718 .08201 Mdot
.17181 .082 Mdot
.17182 .08199 Mdot
.17183 .08198 Mdot
.17184 .08197 Mdot
.17185 .08196 Mdot
.17186 .08194 Mdot
.17187 .08193 Mdot
.17188 .08192 Mdot
.17189 .08191 Mdot
.1719 .0819 Mdot
.1719 .08189 Mdot
.17191 .08188 Mdot
.17192 .08187 Mdot
.17193 .08186 Mdot
.17194 .08185 Mdot
.17195 .08184 Mdot
.17196 .08183 Mdot
.17197 .08182 Mdot
.17198 .08181 Mdot
.17199 .08179 Mdot
.172 .08178 Mdot
.17201 .08177 Mdot
.17202 .08176 Mdot
.17203 .08175 Mdot
.17204 .08174 Mdot
.17205 .08173 Mdot
.17206 .08172 Mdot
.17207 .08171 Mdot
.17208 .0817 Mdot
.17209 .08169 Mdot
.1721 .08168 Mdot
.1721 .08167 Mdot
.17211 .08166 Mdot
.17212 .08164 Mdot
.17213 .08163 Mdot
.17214 .08162 Mdot
.17215 .08161 Mdot
.17216 .0816 Mdot
.17217 .08159 Mdot
.17218 .08158 Mdot
.17219 .08157 Mdot
.1722 .08156 Mdot
.17221 .08155 Mdot
.17222 .08154 Mdot
.17223 .08153 Mdot
.17224 .08152 Mdot
.17225 .08151 Mdot
.17226 .08149 Mdot
.17227 .08148 Mdot
.17228 .08147 Mdot
.17229 .08146 Mdot
.1723 .08145 Mdot
.1723 .08144 Mdot
.17231 .08143 Mdot
.17232 .08142 Mdot
.17233 .08141 Mdot
.17234 .0814 Mdot
.17235 .08139 Mdot
.17236 .08138 Mdot
.17237 .08137 Mdot
.17238 .08136 Mdot
.17239 .08135 Mdot
.1724 .08133 Mdot
.17241 .08132 Mdot
.17242 .08131 Mdot
.17243 .0813 Mdot
.17244 .08129 Mdot
.17245 .08128 Mdot
.17246 .08127 Mdot
.17247 .08126 Mdot
.17248 .08125 Mdot
.17249 .08124 Mdot
.1725 .08123 Mdot
.1725 .08122 Mdot
.17251 .08121 Mdot
.17252 .0812 Mdot
.17253 .08118 Mdot
.17254 .08117 Mdot
.17255 .08116 Mdot
.17256 .08115 Mdot
.17257 .08114 Mdot
.17258 .08113 Mdot
.17259 .08112 Mdot
.1726 .08111 Mdot
.17261 .0811 Mdot
.17262 .08109 Mdot
.17263 .08108 Mdot
.17264 .08107 Mdot
.17265 .08106 Mdot
.17266 .08105 Mdot
.17267 .08104 Mdot
.17268 .08102 Mdot
.17269 .08101 Mdot
.1727 .081 Mdot
.1727 .08099 Mdot
.17271 .08098 Mdot
.17272 .08097 Mdot
.17273 .08096 Mdot
.17274 .08095 Mdot
.17275 .08094 Mdot
.17276 .08093 Mdot
.17277 .08092 Mdot
.17278 .08091 Mdot
.17279 .0809 Mdot
.1728 .08089 Mdot
.17281 .08088 Mdot
.17282 .08086 Mdot
.17283 .08085 Mdot
.17284 .08084 Mdot
.17285 .08083 Mdot
.17286 .08082 Mdot
.17287 .08081 Mdot
.17288 .0808 Mdot
.17289 .08079 Mdot
.1729 .08078 Mdot
.1729 .08077 Mdot
.17291 .08076 Mdot
.17292 .08075 Mdot
.17293 .08074 Mdot
.17294 .08073 Mdot
.17295 .08072 Mdot
.17296 .0807 Mdot
.17297 .08069 Mdot
.17298 .08068 Mdot
.17299 .08067 Mdot
.173 .08066 Mdot
.17301 .08065 Mdot
.17302 .08064 Mdot
.17303 .08063 Mdot
.17304 .08062 Mdot
.17305 .08061 Mdot
.17306 .0806 Mdot
.17307 .08059 Mdot
.17308 .08058 Mdot
.17309 .08057 Mdot
.1731 .08056 Mdot
.1731 .08055 Mdot
.17311 .08053 Mdot
.17312 .08052 Mdot
.17313 .08051 Mdot
.17314 .0805 Mdot
.17315 .08049 Mdot
.17316 .08048 Mdot
.17317 .08047 Mdot
.17318 .08046 Mdot
.17319 .08045 Mdot
.1732 .08044 Mdot
.17321 .08043 Mdot
.17322 .08042 Mdot
.17323 .08041 Mdot
.17324 .0804 Mdot
.17325 .08039 Mdot
.17326 .08038 Mdot
.17327 .08036 Mdot
.17328 .08035 Mdot
.17329 .08034 Mdot
.1733 .08033 Mdot
.1733 .08032 Mdot
.17331 .08031 Mdot
.17332 .0803 Mdot
.17333 .08029 Mdot
.17334 .08028 Mdot
.17335 .08027 Mdot
.17336 .08026 Mdot
.17337 .08025 Mdot
.17338 .08024 Mdot
.17339 .08023 Mdot
.1734 .08022 Mdot
.17341 .08021 Mdot
.17342 .08019 Mdot
.17343 .08018 Mdot
.17344 .08017 Mdot
.17345 .08016 Mdot
.17346 .08015 Mdot
.17347 .08014 Mdot
.17348 .08013 Mdot
.17349 .08012 Mdot
.1735 .08011 Mdot
.1735 .0801 Mdot
.17351 .08009 Mdot
.17352 .08008 Mdot
.17353 .08007 Mdot
.17354 .08006 Mdot
.17355 .08005 Mdot
.17356 .08004 Mdot
.17357 .08002 Mdot
.17358 .08001 Mdot
.17359 .08 Mdot
.1736 .07999 Mdot
.17361 .07998 Mdot
.17362 .07997 Mdot
.17363 .07996 Mdot
.17364 .07995 Mdot
.17365 .07994 Mdot
.17366 .07993 Mdot
.17367 .07992 Mdot
.17368 .07991 Mdot
.17369 .0799 Mdot
.1737 .07989 Mdot
.1737 .07988 Mdot
.17371 .07987 Mdot
.17372 .07986 Mdot
.17373 .07984 Mdot
.17374 .07983 Mdot
.17375 .07982 Mdot
.17376 .07981 Mdot
.17377 .0798 Mdot
.17378 .07979 Mdot
.17379 .07978 Mdot
.1738 .07977 Mdot
.17381 .07976 Mdot
.17382 .07975 Mdot
.17383 .07974 Mdot
.17384 .07973 Mdot
.17385 .07972 Mdot
.17386 .07971 Mdot
.17387 .0797 Mdot
.17388 .07969 Mdot
.17389 .07968 Mdot
.1739 .07966 Mdot
.1739 .07965 Mdot
.17391 .07964 Mdot
.17392 .07963 Mdot
.17393 .07962 Mdot
.17394 .07961 Mdot
.17395 .0796 Mdot
.17396 .07959 Mdot
.17397 .07958 Mdot
.17398 .07957 Mdot
.17399 .07956 Mdot
.174 .07955 Mdot
.17401 .07954 Mdot
.17402 .07953 Mdot
.17403 .07952 Mdot
.17404 .07951 Mdot
.17405 .0795 Mdot
.17406 .07948 Mdot
.17407 .07947 Mdot
.17408 .07946 Mdot
.17409 .07945 Mdot
.1741 .07944 Mdot
.1741 .07943 Mdot
.17411 .07942 Mdot
.17412 .07941 Mdot
.17413 .0794 Mdot
.17414 .07939 Mdot
.17415 .07938 Mdot
.17416 .07937 Mdot
.17417 .07936 Mdot
.17418 .07935 Mdot
.17419 .07934 Mdot
.1742 .07933 Mdot
.17421 .07932 Mdot
.17422 .07931 Mdot
.17423 .07929 Mdot
.17424 .07928 Mdot
.17425 .07927 Mdot
.17426 .07926 Mdot
.17427 .07925 Mdot
.17428 .07924 Mdot
.17429 .07923 Mdot
.1743 .07922 Mdot
.1743 .07921 Mdot
.17431 .0792 Mdot
.17432 .07919 Mdot
.17433 .07918 Mdot
.17434 .07917 Mdot
.17435 .07916 Mdot
.17436 .07915 Mdot
.17437 .07914 Mdot
.17438 .07913 Mdot
.17439 .07912 Mdot
.1744 .07911 Mdot
.17441 .07909 Mdot
.17442 .07908 Mdot
.17443 .07907 Mdot
.17444 .07906 Mdot
.17445 .07905 Mdot
.17446 .07904 Mdot
.17447 .07903 Mdot
.17448 .07902 Mdot
.17449 .07901 Mdot
.1745 .079 Mdot
.1745 .07899 Mdot
.17451 .07898 Mdot
.17452 .07897 Mdot
.17453 .07896 Mdot
.17454 .07895 Mdot
.17455 .07894 Mdot
.17456 .07893 Mdot
.17457 .07892 Mdot
.17458 .0789 Mdot
.17459 .07889 Mdot
.1746 .07888 Mdot
.17461 .07887 Mdot
.17462 .07886 Mdot
.17463 .07885 Mdot
.17464 .07884 Mdot
.17465 .07883 Mdot
.17466 .07882 Mdot
.17467 .07881 Mdot
.17468 .0788 Mdot
.17469 .07879 Mdot
.1747 .07878 Mdot
.1747 .07877 Mdot
.17471 .07876 Mdot
.17472 .07875 Mdot
.17473 .07874 Mdot
.17474 .07873 Mdot
.17475 .07872 Mdot
.17476 .07871 Mdot
.17477 .07869 Mdot
.17478 .07868 Mdot
.17479 .07867 Mdot
.1748 .07866 Mdot
.17481 .07865 Mdot
.17482 .07864 Mdot
.17483 .07863 Mdot
.17484 .07862 Mdot
.17485 .07861 Mdot
.17486 .0786 Mdot
.17487 .07859 Mdot
.17488 .07858 Mdot
.17489 .07857 Mdot
.1749 .07856 Mdot
.1749 .07855 Mdot
.17491 .07854 Mdot
.17492 .07853 Mdot
.17493 .07852 Mdot
.17494 .07851 Mdot
.17495 .07849 Mdot
.17496 .07848 Mdot
.17497 .07847 Mdot
.17498 .07846 Mdot
.17499 .07845 Mdot
.175 .07844 Mdot
.17501 .07843 Mdot
.17502 .07842 Mdot
.17503 .07841 Mdot
.17504 .0784 Mdot
.17505 .07839 Mdot
.17506 .07838 Mdot
.17507 .07837 Mdot
.17508 .07836 Mdot
.17509 .07835 Mdot
.1751 .07834 Mdot
.1751 .07833 Mdot
.17511 .07832 Mdot
.17512 .07831 Mdot
.17513 .0783 Mdot
.17514 .07829 Mdot
.17515 .07827 Mdot
.17516 .07826 Mdot
.17517 .07825 Mdot
.17518 .07824 Mdot
.17519 .07823 Mdot
.1752 .07822 Mdot
.17521 .07821 Mdot
.17522 .0782 Mdot
.17523 .07819 Mdot
.17524 .07818 Mdot
.17525 .07817 Mdot
.17526 .07816 Mdot
.17527 .07815 Mdot
.17528 .07814 Mdot
.17529 .07813 Mdot
.1753 .07812 Mdot
.1753 .07811 Mdot
.17531 .0781 Mdot
.17532 .07809 Mdot
.17533 .07808 Mdot
.17534 .07807 Mdot
.17535 .07805 Mdot
.17536 .07804 Mdot
.17537 .07803 Mdot
.17538 .07802 Mdot
.17539 .07801 Mdot
.1754 .078 Mdot
.17541 .07799 Mdot
.17542 .07798 Mdot
.17543 .07797 Mdot
.17544 .07796 Mdot
.17545 .07795 Mdot
.17546 .07794 Mdot
.17547 .07793 Mdot
.17548 .07792 Mdot
.17549 .07791 Mdot
.1755 .0779 Mdot
.1755 .07789 Mdot
.17551 .07788 Mdot
.17552 .07787 Mdot
.17553 .07786 Mdot
.17554 .07785 Mdot
.17555 .07783 Mdot
.17556 .07782 Mdot
.17557 .07781 Mdot
.17558 .0778 Mdot
.17559 .07779 Mdot
.1756 .07778 Mdot
.17561 .07777 Mdot
.17562 .07776 Mdot
.17563 .07775 Mdot
.17564 .07774 Mdot
.17565 .07773 Mdot
.17566 .07772 Mdot
.17567 .07771 Mdot
.17568 .0777 Mdot
.17569 .07769 Mdot
.1757 .07768 Mdot
.1757 .07767 Mdot
.17571 .07766 Mdot
.17572 .07765 Mdot
.17573 .07764 Mdot
.17574 .07763 Mdot
.17575 .07762 Mdot
.17576 .07761 Mdot
.17577 .07759 Mdot
.17578 .07758 Mdot
.17579 .07757 Mdot
.1758 .07756 Mdot
.17581 .07755 Mdot
.17582 .07754 Mdot
.17583 .07753 Mdot
.17584 .07752 Mdot
.17585 .07751 Mdot
.17586 .0775 Mdot
.17587 .07749 Mdot
.17588 .07748 Mdot
.17589 .07747 Mdot
.1759 .07746 Mdot
.1759 .07745 Mdot
.17591 .07744 Mdot
.17592 .07743 Mdot
.17593 .07742 Mdot
.17594 .07741 Mdot
.17595 .0774 Mdot
.17596 .07739 Mdot
.17597 .07738 Mdot
.17598 .07737 Mdot
.17599 .07735 Mdot
.176 .07734 Mdot
.17601 .07733 Mdot
.17602 .07732 Mdot
.17603 .07731 Mdot
.17604 .0773 Mdot
.17605 .07729 Mdot
.17606 .07728 Mdot
.17607 .07727 Mdot
.17608 .07726 Mdot
.17609 .07725 Mdot
.1761 .07724 Mdot
.1761 .07723 Mdot
.17611 .07722 Mdot
.17612 .07721 Mdot
.17613 .0772 Mdot
.17614 .07719 Mdot
.17615 .07718 Mdot
.17616 .07717 Mdot
.17617 .07716 Mdot
.17618 .07715 Mdot
.17619 .07714 Mdot
.1762 .07713 Mdot
.17621 .07712 Mdot
.17622 .07711 Mdot
.17623 .07709 Mdot
.17624 .07708 Mdot
.17625 .07707 Mdot
.17626 .07706 Mdot
.17627 .07705 Mdot
.17628 .07704 Mdot
.17629 .07703 Mdot
.1763 .07702 Mdot
.1763 .07701 Mdot
.17631 .077 Mdot
.17632 .07699 Mdot
.17633 .07698 Mdot
.17634 .07697 Mdot
.17635 .07696 Mdot
.17636 .07695 Mdot
.17637 .07694 Mdot
.17638 .07693 Mdot
.17639 .07692 Mdot
.1764 .07691 Mdot
.17641 .0769 Mdot
.17642 .07689 Mdot
.17643 .07688 Mdot
.17644 .07687 Mdot
.17645 .07686 Mdot
.17646 .07685 Mdot
.17647 .07683 Mdot
.17648 .07682 Mdot
.17649 .07681 Mdot
.1765 .0768 Mdot
.1765 .07679 Mdot
.17651 .07678 Mdot
.17652 .07677 Mdot
.17653 .07676 Mdot
.17654 .07675 Mdot
.17655 .07674 Mdot
.17656 .07673 Mdot
.17657 .07672 Mdot
.17658 .07671 Mdot
.17659 .0767 Mdot
.1766 .07669 Mdot
.17661 .07668 Mdot
.17662 .07667 Mdot
.17663 .07666 Mdot
.17664 .07665 Mdot
.17665 .07664 Mdot
.17666 .07663 Mdot
.17667 .07662 Mdot
.17668 .07661 Mdot
.17669 .0766 Mdot
.1767 .07659 Mdot
.1767 .07658 Mdot
.17671 .07657 Mdot
.17672 .07655 Mdot
.17673 .07654 Mdot
.17674 .07653 Mdot
.17675 .07652 Mdot
.17676 .07651 Mdot
.17677 .0765 Mdot
.17678 .07649 Mdot
.17679 .07648 Mdot
.1768 .07647 Mdot
.17681 .07646 Mdot
.17682 .07645 Mdot
.17683 .07644 Mdot
.17684 .07643 Mdot
.17685 .07642 Mdot
.17686 .07641 Mdot
.17687 .0764 Mdot
.17688 .07639 Mdot
.17689 .07638 Mdot
.1769 .07637 Mdot
.1769 .07636 Mdot
.17691 .07635 Mdot
.17692 .07634 Mdot
.17693 .07633 Mdot
.17694 .07632 Mdot
.17695 .07631 Mdot
.17696 .0763 Mdot
.17697 .07629 Mdot
.17698 .07628 Mdot
.17699 .07627 Mdot
.177 .07625 Mdot
.17701 .07624 Mdot
.17702 .07623 Mdot
.17703 .07622 Mdot
.17704 .07621 Mdot
.17705 .0762 Mdot
.17706 .07619 Mdot
.17707 .07618 Mdot
.17708 .07617 Mdot
.17709 .07616 Mdot
.1771 .07615 Mdot
.1771 .07614 Mdot
.17711 .07613 Mdot
.17712 .07612 Mdot
.17713 .07611 Mdot
.17714 .0761 Mdot
.17715 .07609 Mdot
.17716 .07608 Mdot
.17717 .07607 Mdot
.17718 .07606 Mdot
.17719 .07605 Mdot
.1772 .07604 Mdot
.17721 .07603 Mdot
.17722 .07602 Mdot
.17723 .07601 Mdot
.17724 .076 Mdot
.17725 .07599 Mdot
.17726 .07598 Mdot
.17727 .07597 Mdot
.17728 .07596 Mdot
.17729 .07594 Mdot
.1773 .07593 Mdot
.1773 .07592 Mdot
.17731 .07591 Mdot
.17732 .0759 Mdot
.17733 .07589 Mdot
.17734 .07588 Mdot
.17735 .07587 Mdot
.17736 .07586 Mdot
.17737 .07585 Mdot
.17738 .07584 Mdot
.17739 .07583 Mdot
.1774 .07582 Mdot
.17741 .07581 Mdot
.17742 .0758 Mdot
.17743 .07579 Mdot
.17744 .07578 Mdot
.17745 .07577 Mdot
.17746 .07576 Mdot
.17747 .07575 Mdot
.17748 .07574 Mdot
.17749 .07573 Mdot
.1775 .07572 Mdot
.1775 .07571 Mdot
.17751 .0757 Mdot
.17752 .07569 Mdot
.17753 .07568 Mdot
.17754 .07567 Mdot
.17755 .07566 Mdot
.17756 .07565 Mdot
.17757 .07564 Mdot
.17758 .07563 Mdot
.17759 .07561 Mdot
.1776 .0756 Mdot
.17761 .07559 Mdot
.17762 .07558 Mdot
.17763 .07557 Mdot
.17764 .07556 Mdot
.17765 .07555 Mdot
.17766 .07554 Mdot
.17767 .07553 Mdot
.17768 .07552 Mdot
.17769 .07551 Mdot
.1777 .0755 Mdot
.1777 .07549 Mdot
.17771 .07548 Mdot
.17772 .07547 Mdot
.17773 .07546 Mdot
.17774 .07545 Mdot
.17775 .07544 Mdot
.17776 .07543 Mdot
.17777 .07542 Mdot
.17778 .07541 Mdot
.17779 .0754 Mdot
.1778 .07539 Mdot
.17781 .07538 Mdot
.17782 .07537 Mdot
.17783 .07536 Mdot
.17784 .07535 Mdot
.17785 .07534 Mdot
.17786 .07533 Mdot
.17787 .07532 Mdot
.17788 .07531 Mdot
.17789 .0753 Mdot
.1779 .07529 Mdot
.1779 .07528 Mdot
.17791 .07527 Mdot
.17792 .07526 Mdot
.17793 .07524 Mdot
.17794 .07523 Mdot
.17795 .07522 Mdot
.17796 .07521 Mdot
.17797 .0752 Mdot
.17798 .07519 Mdot
.17799 .07518 Mdot
.178 .07517 Mdot
.17801 .07516 Mdot
.17802 .07515 Mdot
.17803 .07514 Mdot
.17804 .07513 Mdot
.17805 .07512 Mdot
.17806 .07511 Mdot
.17807 .0751 Mdot
.17808 .07509 Mdot
.17809 .07508 Mdot
.1781 .07507 Mdot
.1781 .07506 Mdot
.17811 .07505 Mdot
.17812 .07504 Mdot
.17813 .07503 Mdot
.17814 .07502 Mdot
.17815 .07501 Mdot
.17816 .075 Mdot
.17817 .07499 Mdot
.17818 .07498 Mdot
.17819 .07497 Mdot
.1782 .07496 Mdot
.17821 .07495 Mdot
.17822 .07494 Mdot
.17823 .07493 Mdot
.17824 .07492 Mdot
.17825 .07491 Mdot
.17826 .0749 Mdot
.17827 .07489 Mdot
.17828 .07488 Mdot
.17829 .07487 Mdot
.1783 .07486 Mdot
.1783 .07484 Mdot
.17831 .07483 Mdot
.17832 .07482 Mdot
.17833 .07481 Mdot
.17834 .0748 Mdot
.17835 .07479 Mdot
.17836 .07478 Mdot
.17837 .07477 Mdot
.17838 .07476 Mdot
.17839 .07475 Mdot
.1784 .07474 Mdot
.17841 .07473 Mdot
.17842 .07472 Mdot
.17843 .07471 Mdot
.17844 .0747 Mdot
.17845 .07469 Mdot
.17846 .07468 Mdot
.17847 .07467 Mdot
.17848 .07466 Mdot
.17849 .07465 Mdot
.1785 .07464 Mdot
.1785 .07463 Mdot
.17851 .07462 Mdot
.17852 .07461 Mdot
.17853 .0746 Mdot
.17854 .07459 Mdot
.17855 .07458 Mdot
.17856 .07457 Mdot
.17857 .07456 Mdot
.17858 .07455 Mdot
.17859 .07454 Mdot
.1786 .07453 Mdot
.17861 .07452 Mdot
.17862 .07451 Mdot
.17863 .0745 Mdot
.17864 .07449 Mdot
.17865 .07448 Mdot
.17866 .07447 Mdot
.17867 .07446 Mdot
.17868 .07445 Mdot
.17869 .07444 Mdot
.1787 .07443 Mdot
.1787 .07442 Mdot
.17871 .07441 Mdot
.17872 .0744 Mdot
.17873 .07438 Mdot
.17874 .07437 Mdot
.17875 .07436 Mdot
.17876 .07435 Mdot
.17877 .07434 Mdot
.17878 .07433 Mdot
.17879 .07432 Mdot
.1788 .07431 Mdot
.17881 .0743 Mdot
.17882 .07429 Mdot
.17883 .07428 Mdot
.17884 .07427 Mdot
.17885 .07426 Mdot
.17886 .07425 Mdot
.17887 .07424 Mdot
.17888 .07423 Mdot
.17889 .07422 Mdot
.1789 .07421 Mdot
.1789 .0742 Mdot
.17891 .07419 Mdot
.17892 .07418 Mdot
.17893 .07417 Mdot
.17894 .07416 Mdot
.17895 .07415 Mdot
.17896 .07414 Mdot
.17897 .07413 Mdot
.17898 .07412 Mdot
.17899 .07411 Mdot
.179 .0741 Mdot
.17901 .07409 Mdot
.17902 .07408 Mdot
.17903 .07407 Mdot
.17904 .07406 Mdot
.17905 .07405 Mdot
.17906 .07404 Mdot
.17907 .07403 Mdot
.17908 .07402 Mdot
.17909 .07401 Mdot
.1791 .074 Mdot
.1791 .07399 Mdot
.17911 .07398 Mdot
.17912 .07397 Mdot
.17913 .07396 Mdot
.17914 .07395 Mdot
.17915 .07394 Mdot
.17916 .07393 Mdot
.17917 .07392 Mdot
.17918 .07391 Mdot
.17919 .0739 Mdot
.1792 .07389 Mdot
.17921 .07388 Mdot
.17922 .07387 Mdot
.17923 .07386 Mdot
.17924 .07384 Mdot
.17925 .07383 Mdot
.17926 .07382 Mdot
.17927 .07381 Mdot
.17928 .0738 Mdot
.17929 .07379 Mdot
.1793 .07378 Mdot
.1793 .07377 Mdot
.17931 .07376 Mdot
.17932 .07375 Mdot
.17933 .07374 Mdot
.17934 .07373 Mdot
.17935 .07372 Mdot
.17936 .07371 Mdot
.17937 .0737 Mdot
.17938 .07369 Mdot
.17939 .07368 Mdot
.1794 .07367 Mdot
.17941 .07366 Mdot
.17942 .07365 Mdot
.17943 .07364 Mdot
.17944 .07363 Mdot
.17945 .07362 Mdot
.17946 .07361 Mdot
.17947 .0736 Mdot
.17948 .07359 Mdot
.17949 .07358 Mdot
.1795 .07357 Mdot
.1795 .07356 Mdot
.17951 .07355 Mdot
.17952 .07354 Mdot
.17953 .07353 Mdot
.17954 .07352 Mdot
.17955 .07351 Mdot
.17956 .0735 Mdot
.17957 .07349 Mdot
.17958 .07348 Mdot
.17959 .07347 Mdot
.1796 .07346 Mdot
.17961 .07345 Mdot
.17962 .07344 Mdot
.17963 .07343 Mdot
.17964 .07342 Mdot
.17965 .07341 Mdot
.17966 .0734 Mdot
.17967 .07339 Mdot
.17968 .07338 Mdot
.17969 .07337 Mdot
.1797 .07336 Mdot
.1797 .07335 Mdot
.17971 .07334 Mdot
.17972 .07333 Mdot
.17973 .07332 Mdot
.17974 .07331 Mdot
.17975 .0733 Mdot
.17976 .07329 Mdot
.17977 .07328 Mdot
.17978 .07327 Mdot
.17979 .07326 Mdot
.1798 .07325 Mdot
.17981 .07324 Mdot
.17982 .07323 Mdot
.17983 .07322 Mdot
.17984 .07321 Mdot
.17985 .0732 Mdot
.17986 .07319 Mdot
.17987 .07318 Mdot
.17988 .07317 Mdot
.17989 .07316 Mdot
.1799 .07315 Mdot
.1799 .07314 Mdot
.17991 .07312 Mdot
.17992 .07311 Mdot
.17993 .0731 Mdot
.17994 .07309 Mdot
.17995 .07308 Mdot
.17996 .07307 Mdot
.17997 .07306 Mdot
.17998 .07305 Mdot
.17999 .07304 Mdot
.18 .07303 Mdot
.18001 .07302 Mdot
.18002 .07301 Mdot
.18003 .073 Mdot
.18004 .07299 Mdot
.18005 .07298 Mdot
.18006 .07297 Mdot
.18007 .07296 Mdot
.18008 .07295 Mdot
.18009 .07294 Mdot
.1801 .07293 Mdot
.1801 .07292 Mdot
.18011 .07291 Mdot
.18012 .0729 Mdot
.18013 .07289 Mdot
.18014 .07288 Mdot
.18015 .07287 Mdot
.18016 .07286 Mdot
.18017 .07285 Mdot
.18018 .07284 Mdot
.18019 .07283 Mdot
.1802 .07282 Mdot
.18021 .07281 Mdot
.18022 .0728 Mdot
.18023 .07279 Mdot
.18024 .07278 Mdot
.18025 .07277 Mdot
.18026 .07276 Mdot
.18027 .07275 Mdot
.18028 .07274 Mdot
.18029 .07273 Mdot
.1803 .07272 Mdot
.1803 .07271 Mdot
.18031 .0727 Mdot
.18032 .07269 Mdot
.18033 .07268 Mdot
.18034 .07267 Mdot
.18035 .07266 Mdot
.18036 .07265 Mdot
.18037 .07264 Mdot
.18038 .07263 Mdot
.18039 .07262 Mdot
.1804 .07261 Mdot
.18041 .0726 Mdot
.18042 .07259 Mdot
.18043 .07258 Mdot
.18044 .07257 Mdot
.18045 .07256 Mdot
.18046 .07255 Mdot
.18047 .07254 Mdot
.18048 .07253 Mdot
.18049 .07252 Mdot
.1805 .07251 Mdot
.1805 .0725 Mdot
.18051 .07249 Mdot
.18052 .07248 Mdot
.18053 .07247 Mdot
.18054 .07246 Mdot
.18055 .07245 Mdot
.18056 .07244 Mdot
.18057 .07243 Mdot
.18058 .07242 Mdot
.18059 .07241 Mdot
.1806 .0724 Mdot
.18061 .07239 Mdot
.18062 .07238 Mdot
.18063 .07237 Mdot
.18064 .07236 Mdot
.18065 .07235 Mdot
.18066 .07234 Mdot
.18067 .07233 Mdot
.18068 .07232 Mdot
.18069 .07231 Mdot
.1807 .0723 Mdot
.1807 .07229 Mdot
.18071 .07228 Mdot
.18072 .07227 Mdot
.18073 .07226 Mdot
.18074 .07225 Mdot
.18075 .07224 Mdot
.18076 .07223 Mdot
.18077 .07222 Mdot
.18078 .07221 Mdot
.18079 .0722 Mdot
.1808 .07219 Mdot
.18081 .07218 Mdot
.18082 .07217 Mdot
.18083 .07216 Mdot
.18084 .07215 Mdot
.18085 .07214 Mdot
.18086 .07213 Mdot
.18087 .07212 Mdot
.18088 .07211 Mdot
.18089 .0721 Mdot
.1809 .07209 Mdot
.1809 .07208 Mdot
.18091 .07207 Mdot
.18092 .07206 Mdot
.18093 .07205 Mdot
.18094 .07204 Mdot
.18095 .07203 Mdot
.18096 .07202 Mdot
.18097 .07201 Mdot
.18098 .072 Mdot
.18099 .07199 Mdot
.181 .07198 Mdot
.18101 .07197 Mdot
.18102 .07196 Mdot
.18103 .07195 Mdot
.18104 .07194 Mdot
.18105 .07193 Mdot
.18106 .07192 Mdot
.18107 .07191 Mdot
.18108 .0719 Mdot
.18109 .07189 Mdot
.1811 .07188 Mdot
.1811 .07187 Mdot
.18111 .07186 Mdot
.18112 .07185 Mdot
.18113 .07184 Mdot
.18114 .07183 Mdot
.18115 .07182 Mdot
.18116 .07181 Mdot
.18117 .0718 Mdot
.18118 .07179 Mdot
.18119 .07178 Mdot
.1812 .07177 Mdot
.18121 .07176 Mdot
.18122 .07175 Mdot
.18123 .07174 Mdot
.18124 .07173 Mdot
.18125 .07172 Mdot
.18126 .07171 Mdot
.18127 .0717 Mdot
.18128 .07169 Mdot
.18129 .07168 Mdot
.1813 .07167 Mdot
.1813 .07166 Mdot
.18131 .07165 Mdot
.18132 .07164 Mdot
.18133 .07163 Mdot
.18134 .07162 Mdot
.18135 .07161 Mdot
.18136 .0716 Mdot
.18137 .07159 Mdot
.18138 .07158 Mdot
.18139 .07157 Mdot
.1814 .07156 Mdot
.18141 .07155 Mdot
.18142 .07154 Mdot
.18143 .07153 Mdot
.18144 .07152 Mdot
.18145 .07151 Mdot
.18146 .0715 Mdot
.18147 .07149 Mdot
.18148 .07148 Mdot
.18149 .07147 Mdot
.1815 .07146 Mdot
.1815 .07145 Mdot
.18151 .07144 Mdot
.18152 .07143 Mdot
.18153 .07142 Mdot
.18154 .07141 Mdot
.18155 .0714 Mdot
.18156 .07139 Mdot
.18157 .07138 Mdot
.18158 .07137 Mdot
.18159 .07136 Mdot
.1816 .07135 Mdot
.18161 .07134 Mdot
.18162 .07133 Mdot
.18163 .07132 Mdot
.18164 .07131 Mdot
.18165 .0713 Mdot
.18166 .07129 Mdot
.18167 .07128 Mdot
.18168 .07127 Mdot
.18169 .07126 Mdot
.1817 .07125 Mdot
.1817 .07124 Mdot
.18171 .07123 Mdot
.18172 .07122 Mdot
.18173 .07121 Mdot
.18174 .0712 Mdot
.18175 .07119 Mdot
.18176 .07118 Mdot
.18177 .07117 Mdot
.18178 .07116 Mdot
.18179 .07115 Mdot
.1818 .07114 Mdot
.18181 .07113 Mdot
.18182 .07112 Mdot
.18183 .07111 Mdot
.18184 .0711 Mdot
.18185 .07109 Mdot
.18186 .07108 Mdot
.18187 .07107 Mdot
.18188 .07106 Mdot
.18189 .07105 Mdot
.1819 .07104 Mdot
.1819 .07103 Mdot
.18191 .07102 Mdot
.18192 .07101 Mdot
.18193 .071 Mdot
.18194 .07099 Mdot
.18195 .07098 Mdot
.18196 .07097 Mdot
.18197 .07096 Mdot
.18198 .07095 Mdot
.18199 .07094 Mdot
.182 .07093 Mdot
.18201 .07092 Mdot
.18202 .07091 Mdot
.18203 .0709 Mdot
.18204 .07089 Mdot
.18205 .07088 Mdot
.18206 .07087 Mdot
.18207 .07086 Mdot
.18208 .07085 Mdot
.18209 .07084 Mdot
.1821 .07083 Mdot
.1821 .07082 Mdot
.18211 .07081 Mdot
.18212 .0708 Mdot
.18213 .07079 Mdot
.18214 .07078 Mdot
.18215 .07077 Mdot
.18216 .07076 Mdot
.18217 .07075 Mdot
.18218 .07074 Mdot
.18219 .07073 Mdot
.1822 .07072 Mdot
.18221 .07071 Mdot
.18222 .0707 Mdot
.18223 .07069 Mdot
.18224 .07068 Mdot
.18225 .07067 Mdot
.18226 .07066 Mdot
.18227 .07065 Mdot
.18228 .07064 Mdot
.18229 .07063 Mdot
.1823 .07062 Mdot
.1823 .07061 Mdot
.18231 .0706 Mdot
.18232 .07059 Mdot
.18233 .07058 Mdot
.18234 .07057 Mdot
.18235 .07056 Mdot
.18236 .07055 Mdot
.18237 .07054 Mdot
.18238 .07053 Mdot
.18239 .07052 Mdot
.1824 .07051 Mdot
.18241 .0705 Mdot
.18242 .07049 Mdot
.18243 .07048 Mdot
.18244 .07047 Mdot
.18245 .07046 Mdot
.18246 .07045 Mdot
.18247 .07044 Mdot
.18248 .07043 Mdot
.18249 .07042 Mdot
.1825 .07041 Mdot
.1825 .0704 Mdot
.18251 .07039 Mdot
.18252 .07038 Mdot
.18253 .07037 Mdot
.18254 .07036 Mdot
.18255 .07035 Mdot
.18256 .07034 Mdot
.18257 .07033 Mdot
.18258 .07032 Mdot
.18259 .07031 Mdot
.1826 .0703 Mdot
.18261 .07029 Mdot
.18262 .07028 Mdot
.18263 .07027 Mdot
.18264 .07026 Mdot
.18265 .07025 Mdot
.18266 .07024 Mdot
.18267 .07023 Mdot
.18268 .07022 Mdot
.18269 .07021 Mdot
.1827 .0702 Mdot
.1827 .07019 Mdot
.18271 .07018 Mdot
.18272 .07017 Mdot
.18273 .07016 Mdot
.18274 .07015 Mdot
.18275 .07014 Mdot
.18276 .07013 Mdot
.18277 .07012 Mdot
.18278 .07011 Mdot
.18279 .0701 Mdot
.1828 .07009 Mdot
.18281 .07008 Mdot
.18282 .07008 Mdot
.18283 .07007 Mdot
.18284 .07006 Mdot
.18285 .07005 Mdot
.18286 .07004 Mdot
.18287 .07003 Mdot
.18288 .07002 Mdot
.18289 .07001 Mdot
.1829 .07 Mdot
.1829 .06999 Mdot
.18291 .06998 Mdot
.18292 .06997 Mdot
.18293 .06996 Mdot
.18294 .06995 Mdot
.18295 .06994 Mdot
.18296 .06993 Mdot
.18297 .06992 Mdot
.18298 .06991 Mdot
.18299 .0699 Mdot
.183 .06989 Mdot
.18301 .06988 Mdot
.18302 .06987 Mdot
.18303 .06986 Mdot
.18304 .06985 Mdot
.18305 .06984 Mdot
.18306 .06983 Mdot
.18307 .06982 Mdot
.18308 .06981 Mdot
.18309 .0698 Mdot
.1831 .06979 Mdot
.1831 .06978 Mdot
.18311 .06977 Mdot
.18312 .06976 Mdot
.18313 .06975 Mdot
.18314 .06974 Mdot
.18315 .06973 Mdot
.18316 .06972 Mdot
.18317 .06971 Mdot
.18318 .0697 Mdot
.18319 .06969 Mdot
.1832 .06968 Mdot
.18321 .06967 Mdot
.18322 .06966 Mdot
.18323 .06965 Mdot
.18324 .06964 Mdot
.18325 .06963 Mdot
.18326 .06962 Mdot
.18327 .06961 Mdot
.18328 .0696 Mdot
.18329 .06959 Mdot
.1833 .06958 Mdot
.1833 .06957 Mdot
.18331 .06956 Mdot
.18332 .06955 Mdot
.18333 .06954 Mdot
.18334 .06953 Mdot
.18335 .06952 Mdot
.18336 .06951 Mdot
.18337 .0695 Mdot
.18338 .06949 Mdot
.18339 .06948 Mdot
.1834 .06947 Mdot
.18341 .06946 Mdot
.18342 .06945 Mdot
.18343 .06944 Mdot
.18344 .06943 Mdot
.18345 .06942 Mdot
.18346 .06941 Mdot
.18347 .0694 Mdot
.18348 .06939 Mdot
.18349 .06939 Mdot
.1835 .06938 Mdot
.1835 .06937 Mdot
.18351 .06936 Mdot
.18352 .06935 Mdot
.18353 .06934 Mdot
.18354 .06933 Mdot
.18355 .06932 Mdot
.18356 .06931 Mdot
.18357 .0693 Mdot
.18358 .06929 Mdot
.18359 .06928 Mdot
.1836 .06927 Mdot
.18361 .06926 Mdot
.18362 .06925 Mdot
.18363 .06924 Mdot
.18364 .06923 Mdot
.18365 .06922 Mdot
.18366 .06921 Mdot
.18367 .0692 Mdot
.18368 .06919 Mdot
.18369 .06918 Mdot
.1837 .06917 Mdot
.1837 .06916 Mdot
.18371 .06915 Mdot
.18372 .06914 Mdot
.18373 .06913 Mdot
.18374 .06912 Mdot
.18375 .06911 Mdot
.18376 .0691 Mdot
.18377 .06909 Mdot
.18378 .06908 Mdot
.18379 .06907 Mdot
.1838 .06906 Mdot
.18381 .06905 Mdot
.18382 .06904 Mdot
.18383 .06903 Mdot
.18384 .06902 Mdot
.18385 .06901 Mdot
.18386 .069 Mdot
.18387 .06899 Mdot
.18388 .06898 Mdot
.18389 .06897 Mdot
.1839 .06896 Mdot
.1839 .06895 Mdot
.18391 .06894 Mdot
.18392 .06893 Mdot
.18393 .06892 Mdot
.18394 .06891 Mdot
.18395 .0689 Mdot
.18396 .06889 Mdot
.18397 .06888 Mdot
.18398 .06887 Mdot
.18399 .06887 Mdot
.184 .06886 Mdot
.18401 .06885 Mdot
.18402 .06884 Mdot
.18403 .06883 Mdot
.18404 .06882 Mdot
.18405 .06881 Mdot
.18406 .0688 Mdot
.18407 .06879 Mdot
.18408 .06878 Mdot
.18409 .06877 Mdot
.1841 .06876 Mdot
.1841 .06875 Mdot
.18411 .06874 Mdot
.18412 .06873 Mdot
.18413 .06872 Mdot
.18414 .06871 Mdot
.18415 .0687 Mdot
.18416 .06869 Mdot
.18417 .06868 Mdot
.18418 .06867 Mdot
.18419 .06866 Mdot
.1842 .06865 Mdot
.18421 .06864 Mdot
.18422 .06863 Mdot
.18423 .06862 Mdot
.18424 .06861 Mdot
.18425 .0686 Mdot
.18426 .06859 Mdot
.18427 .06858 Mdot
.18428 .06857 Mdot
.18429 .06856 Mdot
.1843 .06855 Mdot
.1843 .06854 Mdot
.18431 .06853 Mdot
.18432 .06852 Mdot
.18433 .06851 Mdot
.18434 .0685 Mdot
.18435 .06849 Mdot
.18436 .06848 Mdot
.18437 .06847 Mdot
.18438 .06846 Mdot
.18439 .06845 Mdot
.1844 .06844 Mdot
.18441 .06843 Mdot
.18442 .06843 Mdot
.18443 .06842 Mdot
.18444 .06841 Mdot
.18445 .0684 Mdot
.18446 .06839 Mdot
.18447 .06838 Mdot
.18448 .06837 Mdot
.18449 .06836 Mdot
.1845 .06835 Mdot
.1845 .06834 Mdot
.18451 .06833 Mdot
.18452 .06832 Mdot
.18453 .06831 Mdot
.18454 .0683 Mdot
.18455 .06829 Mdot
.18456 .06828 Mdot
.18457 .06827 Mdot
.18458 .06826 Mdot
.18459 .06825 Mdot
.1846 .06824 Mdot
.18461 .06823 Mdot
.18462 .06822 Mdot
.18463 .06821 Mdot
.18464 .0682 Mdot
.18465 .06819 Mdot
.18466 .06818 Mdot
.18467 .06817 Mdot
.18468 .06816 Mdot
.18469 .06815 Mdot
.1847 .06814 Mdot
.1847 .06813 Mdot
.18471 .06812 Mdot
.18472 .06811 Mdot
.18473 .0681 Mdot
.18474 .06809 Mdot
.18475 .06808 Mdot
.18476 .06807 Mdot
.18477 .06806 Mdot
.18478 .06805 Mdot
.18479 .06805 Mdot
.1848 .06804 Mdot
.18481 .06803 Mdot
.18482 .06802 Mdot
.18483 .06801 Mdot
.18484 .068 Mdot
.18485 .06799 Mdot
.18486 .06798 Mdot
.18487 .06797 Mdot
.18488 .06796 Mdot
.18489 .06795 Mdot
.1849 .06794 Mdot
.1849 .06793 Mdot
.18491 .06792 Mdot
.18492 .06791 Mdot
.18493 .0679 Mdot
.18494 .06789 Mdot
.18495 .06788 Mdot
.18496 .06787 Mdot
.18497 .06786 Mdot
.18498 .06785 Mdot
.18499 .06784 Mdot
.185 .06783 Mdot
.18501 .06782 Mdot
.18502 .06781 Mdot
.18503 .0678 Mdot
.18504 .06779 Mdot
.18505 .06778 Mdot
.18506 .06777 Mdot
.18507 .06776 Mdot
.18508 .06775 Mdot
.18509 .06774 Mdot
.1851 .06773 Mdot
.1851 .06772 Mdot
.18511 .06772 Mdot
.18512 .06771 Mdot
.18513 .0677 Mdot
.18514 .06769 Mdot
.18515 .06768 Mdot
.18516 .06767 Mdot
.18517 .06766 Mdot
.18518 .06765 Mdot
.18519 .06764 Mdot
.1852 .06763 Mdot
.18521 .06762 Mdot
.18522 .06761 Mdot
.18523 .0676 Mdot
.18524 .06759 Mdot
.18525 .06758 Mdot
.18526 .06757 Mdot
.18527 .06756 Mdot
.18528 .06755 Mdot
.18529 .06754 Mdot
.1853 .06753 Mdot
.1853 .06752 Mdot
.18531 .06751 Mdot
.18532 .0675 Mdot
.18533 .06749 Mdot
.18534 .06748 Mdot
.18535 .06747 Mdot
.18536 .06746 Mdot
.18537 .06745 Mdot
.18538 .06744 Mdot
.18539 .06743 Mdot
.1854 .06742 Mdot
.18541 .06741 Mdot
.18542 .0674 Mdot
.18543 .0674 Mdot
.18544 .06739 Mdot
.18545 .06738 Mdot
.18546 .06737 Mdot
.18547 .06736 Mdot
.18548 .06735 Mdot
.18549 .06734 Mdot
.1855 .06733 Mdot
.1855 .06732 Mdot
.18551 .06731 Mdot
.18552 .0673 Mdot
.18553 .06729 Mdot
.18554 .06728 Mdot
.18555 .06727 Mdot
.18556 .06726 Mdot
.18557 .06725 Mdot
.18558 .06724 Mdot
.18559 .06723 Mdot
.1856 .06722 Mdot
.18561 .06721 Mdot
.18562 .0672 Mdot
.18563 .06719 Mdot
.18564 .06718 Mdot
.18565 .06717 Mdot
.18566 .06716 Mdot
.18567 .06715 Mdot
.18568 .06714 Mdot
.18569 .06713 Mdot
.1857 .06712 Mdot
.1857 .06712 Mdot
.18571 .06711 Mdot
.18572 .0671 Mdot
.18573 .06709 Mdot
.18574 .06708 Mdot
.18575 .06707 Mdot
.18576 .06706 Mdot
.18577 .06705 Mdot
.18578 .06704 Mdot
.18579 .06703 Mdot
.1858 .06702 Mdot
.18581 .06701 Mdot
.18582 .067 Mdot
.18583 .06699 Mdot
.18584 .06698 Mdot
.18585 .06697 Mdot
.18586 .06696 Mdot
.18587 .06695 Mdot
.18588 .06694 Mdot
.18589 .06693 Mdot
.1859 .06692 Mdot
.1859 .06691 Mdot
.18591 .0669 Mdot
.18592 .06689 Mdot
.18593 .06688 Mdot
.18594 .06687 Mdot
.18595 .06686 Mdot
.18596 .06685 Mdot
.18597 .06685 Mdot
.18598 .06684 Mdot
.18599 .06683 Mdot
.186 .06682 Mdot
.18601 .06681 Mdot
.18602 .0668 Mdot
.18603 .06679 Mdot
.18604 .06678 Mdot
.18605 .06677 Mdot
.18606 .06676 Mdot
.18607 .06675 Mdot
.18608 .06674 Mdot
.18609 .06673 Mdot
.1861 .06672 Mdot
.1861 .06671 Mdot
.18611 .0667 Mdot
.18612 .06669 Mdot
.18613 .06668 Mdot
.18614 .06667 Mdot
.18615 .06666 Mdot
.18616 .06665 Mdot
.18617 .06664 Mdot
.18618 .06663 Mdot
.18619 .06662 Mdot
.1862 .06661 Mdot
.18621 .0666 Mdot
.18622 .06659 Mdot
.18623 .06659 Mdot
.18624 .06658 Mdot
.18625 .06657 Mdot
.18626 .06656 Mdot
.18627 .06655 Mdot
.18628 .06654 Mdot
.18629 .06653 Mdot
.1863 .06652 Mdot
.1863 .06651 Mdot
.18631 .0665 Mdot
.18632 .06649 Mdot
.18633 .06648 Mdot
.18634 .06647 Mdot
.18635 .06646 Mdot
.18636 .06645 Mdot
.18637 .06644 Mdot
.18638 .06643 Mdot
.18639 .06642 Mdot
.1864 .06641 Mdot
.18641 .0664 Mdot
.18642 .06639 Mdot
.18643 .06638 Mdot
.18644 .06637 Mdot
.18645 .06636 Mdot
.18646 .06635 Mdot
.18647 .06635 Mdot
.18648 .06634 Mdot
.18649 .06633 Mdot
.1865 .06632 Mdot
.1865 .06631 Mdot
.18651 .0663 Mdot
.18652 .06629 Mdot
.18653 .06628 Mdot
.18654 .06627 Mdot
.18655 .06626 Mdot
.18656 .06625 Mdot
.18657 .06624 Mdot
.18658 .06623 Mdot
.18659 .06622 Mdot
.1866 .06621 Mdot
.18661 .0662 Mdot
.18662 .06619 Mdot
.18663 .06618 Mdot
.18664 .06617 Mdot
.18665 .06616 Mdot
.18666 .06615 Mdot
.18667 .06614 Mdot
.18668 .06613 Mdot
.18669 .06612 Mdot
.1867 .06612 Mdot
.1867 .06611 Mdot
.18671 .0661 Mdot
.18672 .06609 Mdot
.18673 .06608 Mdot
.18674 .06607 Mdot
.18675 .06606 Mdot
.18676 .06605 Mdot
.18677 .06604 Mdot
.18678 .06603 Mdot
.18679 .06602 Mdot
.1868 .06601 Mdot
.18681 .066 Mdot
.18682 .06599 Mdot
.18683 .06598 Mdot
.18684 .06597 Mdot
.18685 .06596 Mdot
.18686 .06595 Mdot
.18687 .06594 Mdot
.18688 .06593 Mdot
.18689 .06592 Mdot
.1869 .06591 Mdot
.1869 .0659 Mdot
.18691 .0659 Mdot
.18692 .06589 Mdot
.18693 .06588 Mdot
.18694 .06587 Mdot
.18695 .06586 Mdot
.18696 .06585 Mdot
.18697 .06584 Mdot
.18698 .06583 Mdot
.18699 .06582 Mdot
.187 .06581 Mdot
.18701 .0658 Mdot
.18702 .06579 Mdot
.18703 .06578 Mdot
.18704 .06577 Mdot
.18705 .06576 Mdot
.18706 .06575 Mdot
.18707 .06574 Mdot
.18708 .06573 Mdot
.18709 .06572 Mdot
.1871 .06571 Mdot
.1871 .0657 Mdot
.18711 .06569 Mdot
.18712 .06569 Mdot
.18713 .06568 Mdot
.18714 .06567 Mdot
.18715 .06566 Mdot
.18716 .06565 Mdot
.18717 .06564 Mdot
.18718 .06563 Mdot
.18719 .06562 Mdot
.1872 .06561 Mdot
.18721 .0656 Mdot
.18722 .06559 Mdot
.18723 .06558 Mdot
.18724 .06557 Mdot
.18725 .06556 Mdot
.18726 .06555 Mdot
.18727 .06554 Mdot
.18728 .06553 Mdot
.18729 .06552 Mdot
.1873 .06551 Mdot
.1873 .0655 Mdot
.18731 .06549 Mdot
.18732 .06549 Mdot
.18733 .06548 Mdot
.18734 .06547 Mdot
.18735 .06546 Mdot
.18736 .06545 Mdot
.18737 .06544 Mdot
.18738 .06543 Mdot
.18739 .06542 Mdot
.1874 .06541 Mdot
.18741 .0654 Mdot
.18742 .06539 Mdot
.18743 .06538 Mdot
.18744 .06537 Mdot
.18745 .06536 Mdot
.18746 .06535 Mdot
.18747 .06534 Mdot
.18748 .06533 Mdot
.18749 .06532 Mdot
.1875 .06531 Mdot
.1875 .0653 Mdot
.18751 .06529 Mdot
.18752 .06529 Mdot
.18753 .06528 Mdot
.18754 .06527 Mdot
.18755 .06526 Mdot
.18756 .06525 Mdot
.18757 .06524 Mdot
.18758 .06523 Mdot
.18759 .06522 Mdot
.1876 .06521 Mdot
.18761 .0652 Mdot
.18762 .06519 Mdot
.18763 .06518 Mdot
.18764 .06517 Mdot
.18765 .06516 Mdot
.18766 .06515 Mdot
.18767 .06514 Mdot
.18768 .06513 Mdot
.18769 .06512 Mdot
.1877 .06511 Mdot
.1877 .0651 Mdot
.18771 .0651 Mdot
.18772 .06509 Mdot
.18773 .06508 Mdot
.18774 .06507 Mdot
.18775 .06506 Mdot
.18776 .06505 Mdot
.18777 .06504 Mdot
.18778 .06503 Mdot
.18779 .06502 Mdot
.1878 .06501 Mdot
.18781 .065 Mdot
.18782 .06499 Mdot
.18783 .06498 Mdot
.18784 .06497 Mdot
.18785 .06496 Mdot
.18786 .06495 Mdot
.18787 .06494 Mdot
.18788 .06493 Mdot
.18789 .06492 Mdot
.1879 .06492 Mdot
.1879 .06491 Mdot
.18791 .0649 Mdot
.18792 .06489 Mdot
.18793 .06488 Mdot
.18794 .06487 Mdot
.18795 .06486 Mdot
.18796 .06485 Mdot
.18797 .06484 Mdot
.18798 .06483 Mdot
.18799 .06482 Mdot
.188 .06481 Mdot
.18801 .0648 Mdot
.18802 .06479 Mdot
.18803 .06478 Mdot
.18804 .06477 Mdot
.18805 .06476 Mdot
.18806 .06475 Mdot
.18807 .06474 Mdot
.18808 .06474 Mdot
.18809 .06473 Mdot
.1881 .06472 Mdot
.1881 .06471 Mdot
.18811 .0647 Mdot
.18812 .06469 Mdot
.18813 .06468 Mdot
.18814 .06467 Mdot
.18815 .06466 Mdot
.18816 .06465 Mdot
.18817 .06464 Mdot
.18818 .06463 Mdot
.18819 .06462 Mdot
.1882 .06461 Mdot
.18821 .0646 Mdot
.18822 .06459 Mdot
.18823 .06458 Mdot
.18824 .06457 Mdot
.18825 .06457 Mdot
.18826 .06456 Mdot
.18827 .06455 Mdot
.18828 .06454 Mdot
.18829 .06453 Mdot
.1883 .06452 Mdot
.1883 .06451 Mdot
.18831 .0645 Mdot
.18832 .06449 Mdot
.18833 .06448 Mdot
.18834 .06447 Mdot
.18835 .06446 Mdot
.18836 .06445 Mdot
.18837 .06444 Mdot
.18838 .06443 Mdot
.18839 .06442 Mdot
.1884 .06441 Mdot
.18841 .0644 Mdot
.18842 .0644 Mdot
.18843 .06439 Mdot
.18844 .06438 Mdot
.18845 .06437 Mdot
.18846 .06436 Mdot
.18847 .06435 Mdot
.18848 .06434 Mdot
.18849 .06433 Mdot
.1885 .06432 Mdot
.1885 .06431 Mdot
.18851 .0643 Mdot
.18852 .06429 Mdot
.18853 .06428 Mdot
.18854 .06427 Mdot
.18855 .06426 Mdot
.18856 .06425 Mdot
.18857 .06424 Mdot
.18858 .06424 Mdot
.18859 .06423 Mdot
.1886 .06422 Mdot
.18861 .06421 Mdot
.18862 .0642 Mdot
.18863 .06419 Mdot
.18864 .06418 Mdot
.18865 .06417 Mdot
.18866 .06416 Mdot
.18867 .06415 Mdot
.18868 .06414 Mdot
.18869 .06413 Mdot
.1887 .06412 Mdot
.1887 .06411 Mdot
.18871 .0641 Mdot
.18872 .06409 Mdot
.18873 .06408 Mdot
.18874 .06408 Mdot
.18875 .06407 Mdot
.18876 .06406 Mdot
.18877 .06405 Mdot
.18878 .06404 Mdot
.18879 .06403 Mdot
.1888 .06402 Mdot
.18881 .06401 Mdot
.18882 .064 Mdot
.18883 .06399 Mdot
.18884 .06398 Mdot
.18885 .06397 Mdot
.18886 .06396 Mdot
.18887 .06395 Mdot
.18888 .06394 Mdot
.18889 .06393 Mdot
.1889 .06392 Mdot
.1889 .06392 Mdot
.18891 .06391 Mdot
.18892 .0639 Mdot
.18893 .06389 Mdot
.18894 .06388 Mdot
.18895 .06387 Mdot
.18896 .06386 Mdot
.18897 .06385 Mdot
.18898 .06384 Mdot
.18899 .06383 Mdot
.189 .06382 Mdot
.18901 .06381 Mdot
.18902 .0638 Mdot
.18903 .06379 Mdot
.18904 .06378 Mdot
.18905 .06377 Mdot
.18906 .06377 Mdot
.18907 .06376 Mdot
.18908 .06375 Mdot
.18909 .06374 Mdot
.1891 .06373 Mdot
.1891 .06372 Mdot
.18911 .06371 Mdot
.18912 .0637 Mdot
.18913 .06369 Mdot
.18914 .06368 Mdot
.18915 .06367 Mdot
.18916 .06366 Mdot
.18917 .06365 Mdot
.18918 .06364 Mdot
.18919 .06363 Mdot
.1892 .06362 Mdot
.18921 .06362 Mdot
.18922 .06361 Mdot
.18923 .0636 Mdot
.18924 .06359 Mdot
.18925 .06358 Mdot
.18926 .06357 Mdot
.18927 .06356 Mdot
.18928 .06355 Mdot
.18929 .06354 Mdot
.1893 .06353 Mdot
.1893 .06352 Mdot
.18931 .06351 Mdot
.18932 .0635 Mdot
.18933 .06349 Mdot
.18934 .06348 Mdot
.18935 .06347 Mdot
.18936 .06347 Mdot
.18937 .06346 Mdot
.18938 .06345 Mdot
.18939 .06344 Mdot
.1894 .06343 Mdot
.18941 .06342 Mdot
.18942 .06341 Mdot
.18943 .0634 Mdot
.18944 .06339 Mdot
.18945 .06338 Mdot
.18946 .06337 Mdot
.18947 .06336 Mdot
.18948 .06335 Mdot
.18949 .06334 Mdot
.1895 .06333 Mdot
.1895 .06333 Mdot
.18951 .06332 Mdot
.18952 .06331 Mdot
.18953 .0633 Mdot
.18954 .06329 Mdot
.18955 .06328 Mdot
.18956 .06327 Mdot
.18957 .06326 Mdot
.18958 .06325 Mdot
.18959 .06324 Mdot
.1896 .06323 Mdot
.18961 .06322 Mdot
.18962 .06321 Mdot
.18963 .0632 Mdot
.18964 .06319 Mdot
.18965 .06319 Mdot
.18966 .06318 Mdot
.18967 .06317 Mdot
.18968 .06316 Mdot
.18969 .06315 Mdot
.1897 .06314 Mdot
.1897 .06313 Mdot
.18971 .06312 Mdot
.18972 .06311 Mdot
.18973 .0631 Mdot
.18974 .06309 Mdot
.18975 .06308 Mdot
.18976 .06307 Mdot
.18977 .06306 Mdot
.18978 .06305 Mdot
.18979 .06305 Mdot
.1898 .06304 Mdot
.18981 .06303 Mdot
.18982 .06302 Mdot
.18983 .06301 Mdot
.18984 .063 Mdot
.18985 .06299 Mdot
.18986 .06298 Mdot
.18987 .06297 Mdot
.18988 .06296 Mdot
.18989 .06295 Mdot
.1899 .06294 Mdot
.1899 .06293 Mdot
.18991 .06292 Mdot
.18992 .06291 Mdot
.18993 .06291 Mdot
.18994 .0629 Mdot
.18995 .06289 Mdot
.18996 .06288 Mdot
.18997 .06287 Mdot
.18998 .06286 Mdot
.18999 .06285 Mdot
.19 .06284 Mdot
.19001 .06283 Mdot
.19002 .06282 Mdot
.19003 .06281 Mdot
.19004 .0628 Mdot
.19005 .06279 Mdot
.19006 .06278 Mdot
.19007 .06278 Mdot
.19008 .06277 Mdot
.19009 .06276 Mdot
.1901 .06275 Mdot
.1901 .06274 Mdot
.19011 .06273 Mdot
.19012 .06272 Mdot
.19013 .06271 Mdot
.19014 .0627 Mdot
.19015 .06269 Mdot
.19016 .06268 Mdot
.19017 .06267 Mdot
.19018 .06266 Mdot
.19019 .06265 Mdot
.1902 .06265 Mdot
.19021 .06264 Mdot
.19022 .06263 Mdot
.19023 .06262 Mdot
.19024 .06261 Mdot
.19025 .0626 Mdot
.19026 .06259 Mdot
.19027 .06258 Mdot
.19028 .06257 Mdot
.19029 .06256 Mdot
.1903 .06255 Mdot
.1903 .06254 Mdot
.19031 .06253 Mdot
.19032 .06252 Mdot
.19033 .06252 Mdot
.19034 .06251 Mdot
.19035 .0625 Mdot
.19036 .06249 Mdot
.19037 .06248 Mdot
.19038 .06247 Mdot
.19039 .06246 Mdot
.1904 .06245 Mdot
.19041 .06244 Mdot
.19042 .06243 Mdot
.19043 .06242 Mdot
.19044 .06241 Mdot
.19045 .0624 Mdot
.19046 .06239 Mdot
.19047 .06239 Mdot
.19048 .06238 Mdot
.19049 .06237 Mdot
.1905 .06236 Mdot
.1905 .06235 Mdot
.19051 .06234 Mdot
.19052 .06233 Mdot
.19053 .06232 Mdot
.19054 .06231 Mdot
.19055 .0623 Mdot
.19056 .06229 Mdot
.19057 .06228 Mdot
.19058 .06227 Mdot
.19059 .06227 Mdot
.1906 .06226 Mdot
.19061 .06225 Mdot
.19062 .06224 Mdot
.19063 .06223 Mdot
.19064 .06222 Mdot
.19065 .06221 Mdot
.19066 .0622 Mdot
.19067 .06219 Mdot
.19068 .06218 Mdot
.19069 .06217 Mdot
.1907 .06216 Mdot
.1907 .06215 Mdot
.19071 .06214 Mdot
.19072 .06214 Mdot
.19073 .06213 Mdot
.19074 .06212 Mdot
.19075 .06211 Mdot
.19076 .0621 Mdot
.19077 .06209 Mdot
.19078 .06208 Mdot
.19079 .06207 Mdot
.1908 .06206 Mdot
.19081 .06205 Mdot
.19082 .06204 Mdot
.19083 .06203 Mdot
.19084 .06202 Mdot
.19085 .06202 Mdot
.19086 .06201 Mdot
.19087 .062 Mdot
.19088 .06199 Mdot
.19089 .06198 Mdot
.1909 .06197 Mdot
.1909 .06196 Mdot
.19091 .06195 Mdot
.19092 .06194 Mdot
.19093 .06193 Mdot
.19094 .06192 Mdot
.19095 .06191 Mdot
.19096 .0619 Mdot
.19097 .0619 Mdot
.19098 .06189 Mdot
.19099 .06188 Mdot
.191 .06187 Mdot
.19101 .06186 Mdot
.19102 .06185 Mdot
.19103 .06184 Mdot
.19104 .06183 Mdot
.19105 .06182 Mdot
.19106 .06181 Mdot
.19107 .0618 Mdot
.19108 .06179 Mdot
.19109 .06179 Mdot
.1911 .06178 Mdot
.1911 .06177 Mdot
.19111 .06176 Mdot
.19112 .06175 Mdot
.19113 .06174 Mdot
.19114 .06173 Mdot
.19115 .06172 Mdot
.19116 .06171 Mdot
.19117 .0617 Mdot
.19118 .06169 Mdot
.19119 .06168 Mdot
.1912 .06167 Mdot
.19121 .06167 Mdot
.19122 .06166 Mdot
.19123 .06165 Mdot
.19124 .06164 Mdot
.19125 .06163 Mdot
.19126 .06162 Mdot
.19127 .06161 Mdot
.19128 .0616 Mdot
.19129 .06159 Mdot
.1913 .06158 Mdot
.1913 .06157 Mdot
.19131 .06156 Mdot
.19132 .06156 Mdot
.19133 .06155 Mdot
.19134 .06154 Mdot
.19135 .06153 Mdot
.19136 .06152 Mdot
.19137 .06151 Mdot
.19138 .0615 Mdot
.19139 .06149 Mdot
.1914 .06148 Mdot
.19141 .06147 Mdot
.19142 .06146 Mdot
.19143 .06145 Mdot
.19144 .06144 Mdot
.19145 .06144 Mdot
.19146 .06143 Mdot
.19147 .06142 Mdot
.19148 .06141 Mdot
.19149 .0614 Mdot
.1915 .06139 Mdot
.1915 .06138 Mdot
.19151 .06137 Mdot
.19152 .06136 Mdot
.19153 .06135 Mdot
.19154 .06134 Mdot
.19155 .06133 Mdot
.19156 .06133 Mdot
.19157 .06132 Mdot
.19158 .06131 Mdot
.19159 .0613 Mdot
.1916 .06129 Mdot
.19161 .06128 Mdot
.19162 .06127 Mdot
.19163 .06126 Mdot
.19164 .06125 Mdot
.19165 .06124 Mdot
.19166 .06123 Mdot
.19167 .06122 Mdot
.19168 .06122 Mdot
.19169 .06121 Mdot
.1917 .0612 Mdot
.1917 .06119 Mdot
.19171 .06118 Mdot
.19172 .06117 Mdot
.19173 .06116 Mdot
.19174 .06115 Mdot
.19175 .06114 Mdot
.19176 .06113 Mdot
.19177 .06112 Mdot
.19178 .06111 Mdot
.19179 .06111 Mdot
.1918 .0611 Mdot
.19181 .06109 Mdot
.19182 .06108 Mdot
.19183 .06107 Mdot
.19184 .06106 Mdot
.19185 .06105 Mdot
.19186 .06104 Mdot
.19187 .06103 Mdot
.19188 .06102 Mdot
.19189 .06101 Mdot
.1919 .061 Mdot
.1919 .061 Mdot
.19191 .06099 Mdot
.19192 .06098 Mdot
.19193 .06097 Mdot
.19194 .06096 Mdot
.19195 .06095 Mdot
.19196 .06094 Mdot
.19197 .06093 Mdot
.19198 .06092 Mdot
.19199 .06091 Mdot
.192 .0609 Mdot
.19201 .0609 Mdot
.19202 .06089 Mdot
.19203 .06088 Mdot
.19204 .06087 Mdot
.19205 .06086 Mdot
.19206 .06085 Mdot
.19207 .06084 Mdot
.19208 .06083 Mdot
.19209 .06082 Mdot
.1921 .06081 Mdot
.1921 .0608 Mdot
.19211 .06079 Mdot
.19212 .06079 Mdot
.19213 .06078 Mdot
.19214 .06077 Mdot
.19215 .06076 Mdot
.19216 .06075 Mdot
.19217 .06074 Mdot
.19218 .06073 Mdot
.19219 .06072 Mdot
.1922 .06071 Mdot
.19221 .0607 Mdot
.19222 .06069 Mdot
.19223 .06069 Mdot
.19224 .06068 Mdot
.19225 .06067 Mdot
.19226 .06066 Mdot
.19227 .06065 Mdot
.19228 .06064 Mdot
.19229 .06063 Mdot
.1923 .06062 Mdot
.1923 .06061 Mdot
.19231 .0606 Mdot
.19232 .06059 Mdot
.19233 .06059 Mdot
.19234 .06058 Mdot
.19235 .06057 Mdot
.19236 .06056 Mdot
.19237 .06055 Mdot
.19238 .06054 Mdot
.19239 .06053 Mdot
.1924 .06052 Mdot
.19241 .06051 Mdot
.19242 .0605 Mdot
.19243 .06049 Mdot
.19244 .06049 Mdot
.19245 .06048 Mdot
.19246 .06047 Mdot
.19247 .06046 Mdot
.19248 .06045 Mdot
.19249 .06044 Mdot
.1925 .06043 Mdot
.1925 .06042 Mdot
.19251 .06041 Mdot
.19252 .0604 Mdot
.19253 .06039 Mdot
.19254 .06038 Mdot
.19255 .06038 Mdot
.19256 .06037 Mdot
.19257 .06036 Mdot
.19258 .06035 Mdot
.19259 .06034 Mdot
.1926 .06033 Mdot
.19261 .06032 Mdot
.19262 .06031 Mdot
.19263 .0603 Mdot
.19264 .06029 Mdot
.19265 .06029 Mdot
.19266 .06028 Mdot
.19267 .06027 Mdot
.19268 .06026 Mdot
.19269 .06025 Mdot
.1927 .06024 Mdot
.1927 .06023 Mdot
.19271 .06022 Mdot
.19272 .06021 Mdot
.19273 .0602 Mdot
.19274 .06019 Mdot
.19275 .06019 Mdot
.19276 .06018 Mdot
.19277 .06017 Mdot
.19278 .06016 Mdot
.19279 .06015 Mdot
.1928 .06014 Mdot
.19281 .06013 Mdot
.19282 .06012 Mdot
.19283 .06011 Mdot
.19284 .0601 Mdot
.19285 .06009 Mdot
.19286 .06009 Mdot
.19287 .06008 Mdot
.19288 .06007 Mdot
.19289 .06006 Mdot
.1929 .06005 Mdot
.1929 .06004 Mdot
.19291 .06003 Mdot
.19292 .06002 Mdot
.19293 .06001 Mdot
.19294 .06 Mdot
.19295 .05999 Mdot
.19296 .05999 Mdot
.19297 .05998 Mdot
.19298 .05997 Mdot
.19299 .05996 Mdot
.193 .05995 Mdot
.19301 .05994 Mdot
.19302 .05993 Mdot
.19303 .05992 Mdot
.19304 .05991 Mdot
.19305 .0599 Mdot
.19306 .0599 Mdot
.19307 .05989 Mdot
.19308 .05988 Mdot
.19309 .05987 Mdot
.1931 .05986 Mdot
.1931 .05985 Mdot
.19311 .05984 Mdot
.19312 .05983 Mdot
.19313 .05982 Mdot
.19314 .05981 Mdot
.19315 .0598 Mdot
.19316 .0598 Mdot
.19317 .05979 Mdot
.19318 .05978 Mdot
.19319 .05977 Mdot
.1932 .05976 Mdot
.19321 .05975 Mdot
.19322 .05974 Mdot
.19323 .05973 Mdot
.19324 .05972 Mdot
.19325 .05971 Mdot
.19326 .05971 Mdot
.19327 .0597 Mdot
.19328 .05969 Mdot
.19329 .05968 Mdot
.1933 .05967 Mdot
.1933 .05966 Mdot
.19331 .05965 Mdot
.19332 .05964 Mdot
.19333 .05963 Mdot
.19334 .05962 Mdot
.19335 .05962 Mdot
.19336 .05961 Mdot
.19337 .0596 Mdot
.19338 .05959 Mdot
.19339 .05958 Mdot
.1934 .05957 Mdot
.19341 .05956 Mdot
.19342 .05955 Mdot
.19343 .05954 Mdot
.19344 .05953 Mdot
.19345 .05952 Mdot
.19346 .05952 Mdot
.19347 .05951 Mdot
.19348 .0595 Mdot
.19349 .05949 Mdot
.1935 .05948 Mdot
.1935 .05947 Mdot
.19351 .05946 Mdot
.19352 .05945 Mdot
.19353 .05944 Mdot
.19354 .05943 Mdot
.19355 .05943 Mdot
.19356 .05942 Mdot
.19357 .05941 Mdot
.19358 .0594 Mdot
.19359 .05939 Mdot
.1936 .05938 Mdot
.19361 .05937 Mdot
.19362 .05936 Mdot
.19363 .05935 Mdot
.19364 .05934 Mdot
.19365 .05934 Mdot
.19366 .05933 Mdot
.19367 .05932 Mdot
.19368 .05931 Mdot
.19369 .0593 Mdot
.1937 .05929 Mdot
.1937 .05928 Mdot
.19371 .05927 Mdot
.19372 .05926 Mdot
.19373 .05925 Mdot
.19374 .05925 Mdot
.19375 .05924 Mdot
.19376 .05923 Mdot
.19377 .05922 Mdot
.19378 .05921 Mdot
.19379 .0592 Mdot
.1938 .05919 Mdot
.19381 .05918 Mdot
.19382 .05917 Mdot
.19383 .05917 Mdot
.19384 .05916 Mdot
.19385 .05915 Mdot
.19386 .05914 Mdot
.19387 .05913 Mdot
.19388 .05912 Mdot
.19389 .05911 Mdot
.1939 .0591 Mdot
.1939 .05909 Mdot
.19391 .05908 Mdot
.19392 .05908 Mdot
.19393 .05907 Mdot
.19394 .05906 Mdot
.19395 .05905 Mdot
.19396 .05904 Mdot
.19397 .05903 Mdot
.19398 .05902 Mdot
.19399 .05901 Mdot
.194 .059 Mdot
.19401 .05899 Mdot
.19402 .05899 Mdot
.19403 .05898 Mdot
.19404 .05897 Mdot
.19405 .05896 Mdot
.19406 .05895 Mdot
.19407 .05894 Mdot
.19408 .05893 Mdot
.19409 .05892 Mdot
.1941 .05891 Mdot
.1941 .0589 Mdot
.19411 .0589 Mdot
.19412 .05889 Mdot
.19413 .05888 Mdot
.19414 .05887 Mdot
.19415 .05886 Mdot
.19416 .05885 Mdot
.19417 .05884 Mdot
.19418 .05883 Mdot
.19419 .05882 Mdot
.1942 .05882 Mdot
.19421 .05881 Mdot
.19422 .0588 Mdot
.19423 .05879 Mdot
.19424 .05878 Mdot
.19425 .05877 Mdot
.19426 .05876 Mdot
.19427 .05875 Mdot
.19428 .05874 Mdot
.19429 .05873 Mdot
.1943 .05873 Mdot
.1943 .05872 Mdot
.19431 .05871 Mdot
.19432 .0587 Mdot
.19433 .05869 Mdot
.19434 .05868 Mdot
.19435 .05867 Mdot
.19436 .05866 Mdot
.19437 .05865 Mdot
.19438 .05865 Mdot
.19439 .05864 Mdot
.1944 .05863 Mdot
.19441 .05862 Mdot
.19442 .05861 Mdot
.19443 .0586 Mdot
.19444 .05859 Mdot
.19445 .05858 Mdot
.19446 .05857 Mdot
.19447 .05856 Mdot
.19448 .05856 Mdot
.19449 .05855 Mdot
.1945 .05854 Mdot
.1945 .05853 Mdot
.19451 .05852 Mdot
.19452 .05851 Mdot
.19453 .0585 Mdot
.19454 .05849 Mdot
.19455 .05848 Mdot
.19456 .05848 Mdot
.19457 .05847 Mdot
.19458 .05846 Mdot
.19459 .05845 Mdot
.1946 .05844 Mdot
.19461 .05843 Mdot
.19462 .05842 Mdot
.19463 .05841 Mdot
.19464 .0584 Mdot
.19465 .0584 Mdot
.19466 .05839 Mdot
.19467 .05838 Mdot
.19468 .05837 Mdot
.19469 .05836 Mdot
.1947 .05835 Mdot
.1947 .05834 Mdot
.19471 .05833 Mdot
.19472 .05832 Mdot
.19473 .05832 Mdot
.19474 .05831 Mdot
.19475 .0583 Mdot
.19476 .05829 Mdot
.19477 .05828 Mdot
.19478 .05827 Mdot
.19479 .05826 Mdot
.1948 .05825 Mdot
.19481 .05824 Mdot
.19482 .05824 Mdot
.19483 .05823 Mdot
.19484 .05822 Mdot
.19485 .05821 Mdot
.19486 .0582 Mdot
.19487 .05819 Mdot
.19488 .05818 Mdot
.19489 .05817 Mdot
.1949 .05816 Mdot
.1949 .05816 Mdot
.19491 .05815 Mdot
.19492 .05814 Mdot
.19493 .05813 Mdot
.19494 .05812 Mdot
.19495 .05811 Mdot
.19496 .0581 Mdot
.19497 .05809 Mdot
.19498 .05808 Mdot
.19499 .05808 Mdot
.195 .05807 Mdot
.19501 .05806 Mdot
.19502 .05805 Mdot
.19503 .05804 Mdot
.19504 .05803 Mdot
.19505 .05802 Mdot
.19506 .05801 Mdot
.19507 .058 Mdot
.19508 .058 Mdot
.19509 .05799 Mdot
.1951 .05798 Mdot
.1951 .05797 Mdot
.19511 .05796 Mdot
.19512 .05795 Mdot
.19513 .05794 Mdot
.19514 .05793 Mdot
.19515 .05792 Mdot
.19516 .05792 Mdot
.19517 .05791 Mdot
.19518 .0579 Mdot
.19519 .05789 Mdot
.1952 .05788 Mdot
.19521 .05787 Mdot
.19522 .05786 Mdot
.19523 .05785 Mdot
.19524 .05784 Mdot
.19525 .05784 Mdot
.19526 .05783 Mdot
.19527 .05782 Mdot
.19528 .05781 Mdot
.19529 .0578 Mdot
.1953 .05779 Mdot
.1953 .05778 Mdot
.19531 .05777 Mdot
.19532 .05776 Mdot
.19533 .05776 Mdot
.19534 .05775 Mdot
.19535 .05774 Mdot
.19536 .05773 Mdot
.19537 .05772 Mdot
.19538 .05771 Mdot
.19539 .0577 Mdot
.1954 .05769 Mdot
.19541 .05768 Mdot
.19542 .05768 Mdot
.19543 .05767 Mdot
.19544 .05766 Mdot
.19545 .05765 Mdot
.19546 .05764 Mdot
.19547 .05763 Mdot
.19548 .05762 Mdot
.19549 .05761 Mdot
.1955 .05761 Mdot
.1955 .0576 Mdot
.19551 .05759 Mdot
.19552 .05758 Mdot
.19553 .05757 Mdot
.19554 .05756 Mdot
.19555 .05755 Mdot
.19556 .05754 Mdot
.19557 .05753 Mdot
.19558 .05753 Mdot
.19559 .05752 Mdot
.1956 .05751 Mdot
.19561 .0575 Mdot
.19562 .05749 Mdot
.19563 .05748 Mdot
.19564 .05747 Mdot
.19565 .05746 Mdot
.19566 .05746 Mdot
.19567 .05745 Mdot
.19568 .05744 Mdot
.19569 .05743 Mdot
.1957 .05742 Mdot
.1957 .05741 Mdot
.19571 .0574 Mdot
.19572 .05739 Mdot
.19573 .05738 Mdot
.19574 .05738 Mdot
.19575 .05737 Mdot
.19576 .05736 Mdot
.19577 .05735 Mdot
.19578 .05734 Mdot
.19579 .05733 Mdot
.1958 .05732 Mdot
.19581 .05731 Mdot
.19582 .05731 Mdot
.19583 .0573 Mdot
.19584 .05729 Mdot
.19585 .05728 Mdot
.19586 .05727 Mdot
.19587 .05726 Mdot
.19588 .05725 Mdot
.19589 .05724 Mdot
.1959 .05723 Mdot
.1959 .05723 Mdot
.19591 .05722 Mdot
.19592 .05721 Mdot
.19593 .0572 Mdot
.19594 .05719 Mdot
.19595 .05718 Mdot
.19596 .05717 Mdot
.19597 .05716 Mdot
.19598 .05716 Mdot
.19599 .05715 Mdot
.196 .05714 Mdot
.19601 .05713 Mdot
.19602 .05712 Mdot
.19603 .05711 Mdot
.19604 .0571 Mdot
.19605 .05709 Mdot
.19606 .05709 Mdot
.19607 .05708 Mdot
.19608 .05707 Mdot
.19609 .05706 Mdot
.1961 .05705 Mdot
.1961 .05704 Mdot
.19611 .05703 Mdot
.19612 .05702 Mdot
.19613 .05701 Mdot
.19614 .05701 Mdot
.19615 .057 Mdot
.19616 .05699 Mdot
.19617 .05698 Mdot
.19618 .05697 Mdot
.19619 .05696 Mdot
.1962 .05695 Mdot
.19621 .05694 Mdot
.19622 .05694 Mdot
.19623 .05693 Mdot
.19624 .05692 Mdot
.19625 .05691 Mdot
.19626 .0569 Mdot
.19627 .05689 Mdot
.19628 .05688 Mdot
.19629 .05687 Mdot
.1963 .05687 Mdot
.1963 .05686 Mdot
.19631 .05685 Mdot
.19632 .05684 Mdot
.19633 .05683 Mdot
.19634 .05682 Mdot
.19635 .05681 Mdot
.19636 .0568 Mdot
.19637 .0568 Mdot
.19638 .05679 Mdot
.19639 .05678 Mdot
.1964 .05677 Mdot
.19641 .05676 Mdot
.19642 .05675 Mdot
.19643 .05674 Mdot
.19644 .05673 Mdot
.19645 .05673 Mdot
.19646 .05672 Mdot
.19647 .05671 Mdot
.19648 .0567 Mdot
.19649 .05669 Mdot
.1965 .05668 Mdot
.1965 .05667 Mdot
.19651 .05666 Mdot
.19652 .05666 Mdot
.19653 .05665 Mdot
.19654 .05664 Mdot
.19655 .05663 Mdot
.19656 .05662 Mdot
.19657 .05661 Mdot
.19658 .0566 Mdot
.19659 .05659 Mdot
.1966 .05659 Mdot
.19661 .05658 Mdot
.19662 .05657 Mdot
.19663 .05656 Mdot
.19664 .05655 Mdot
.19665 .05654 Mdot
.19666 .05653 Mdot
.19667 .05652 Mdot
.19668 .05652 Mdot
.19669 .05651 Mdot
.1967 .0565 Mdot
.1967 .05649 Mdot
.19671 .05648 Mdot
.19672 .05647 Mdot
.19673 .05646 Mdot
.19674 .05645 Mdot
.19675 .05645 Mdot
.19676 .05644 Mdot
.19677 .05643 Mdot
.19678 .05642 Mdot
.19679 .05641 Mdot
.1968 .0564 Mdot
.19681 .05639 Mdot
.19682 .05638 Mdot
.19683 .05638 Mdot
.19684 .05637 Mdot
.19685 .05636 Mdot
.19686 .05635 Mdot
.19687 .05634 Mdot
.19688 .05633 Mdot
.19689 .05632 Mdot
.1969 .05631 Mdot
.1969 .05631 Mdot
.19691 .0563 Mdot
.19692 .05629 Mdot
.19693 .05628 Mdot
.19694 .05627 Mdot
.19695 .05626 Mdot
.19696 .05625 Mdot
.19697 .05624 Mdot
.19698 .05624 Mdot
.19699 .05623 Mdot
.197 .05622 Mdot
.19701 .05621 Mdot
.19702 .0562 Mdot
.19703 .05619 Mdot
.19704 .05618 Mdot
.19705 .05617 Mdot
.19706 .05617 Mdot
.19707 .05616 Mdot
.19708 .05615 Mdot
.19709 .05614 Mdot
.1971 .05613 Mdot
.1971 .05612 Mdot
.19711 .05611 Mdot
.19712 .05611 Mdot
.19713 .0561 Mdot
.19714 .05609 Mdot
.19715 .05608 Mdot
.19716 .05607 Mdot
.19717 .05606 Mdot
.19718 .05605 Mdot
.19719 .05604 Mdot
.1972 .05604 Mdot
.19721 .05603 Mdot
.19722 .05602 Mdot
.19723 .05601 Mdot
.19724 .056 Mdot
.19725 .05599 Mdot
.19726 .05598 Mdot
.19727 .05597 Mdot
.19728 .05597 Mdot
.19729 .05596 Mdot
.1973 .05595 Mdot
.1973 .05594 Mdot
.19731 .05593 Mdot
.19732 .05592 Mdot
.19733 .05591 Mdot
.19734 .05591 Mdot
.19735 .0559 Mdot
.19736 .05589 Mdot
.19737 .05588 Mdot
.19738 .05587 Mdot
.19739 .05586 Mdot
.1974 .05585 Mdot
.19741 .05584 Mdot
.19742 .05584 Mdot
.19743 .05583 Mdot
.19744 .05582 Mdot
.19745 .05581 Mdot
.19746 .0558 Mdot
.19747 .05579 Mdot
.19748 .05578 Mdot
.19749 .05578 Mdot
.1975 .05577 Mdot
.1975 .05576 Mdot
.19751 .05575 Mdot
.19752 .05574 Mdot
.19753 .05573 Mdot
.19754 .05572 Mdot
.19755 .05571 Mdot
.19756 .05571 Mdot
.19757 .0557 Mdot
.19758 .05569 Mdot
.19759 .05568 Mdot
.1976 .05567 Mdot
.19761 .05566 Mdot
.19762 .05565 Mdot
.19763 .05565 Mdot
.19764 .05564 Mdot
.19765 .05563 Mdot
.19766 .05562 Mdot
.19767 .05561 Mdot
.19768 .0556 Mdot
.19769 .05559 Mdot
.1977 .05558 Mdot
.1977 .05558 Mdot
.19771 .05557 Mdot
.19772 .05556 Mdot
.19773 .05555 Mdot
.19774 .05554 Mdot
.19775 .05553 Mdot
.19776 .05552 Mdot
.19777 .05552 Mdot
.19778 .05551 Mdot
.19779 .0555 Mdot
.1978 .05549 Mdot
.19781 .05548 Mdot
.19782 .05547 Mdot
.19783 .05546 Mdot
.19784 .05545 Mdot
.19785 .05545 Mdot
.19786 .05544 Mdot
.19787 .05543 Mdot
.19788 .05542 Mdot
.19789 .05541 Mdot
.1979 .0554 Mdot
.1979 .05539 Mdot
.19791 .05539 Mdot
.19792 .05538 Mdot
.19793 .05537 Mdot
.19794 .05536 Mdot
.19795 .05535 Mdot
.19796 .05534 Mdot
.19797 .05533 Mdot
.19798 .05533 Mdot
.19799 .05532 Mdot
.198 .05531 Mdot
.19801 .0553 Mdot
.19802 .05529 Mdot
.19803 .05528 Mdot
.19804 .05527 Mdot
.19805 .05526 Mdot
.19806 .05526 Mdot
.19807 .05525 Mdot
.19808 .05524 Mdot
.19809 .05523 Mdot
.1981 .05522 Mdot
.1981 .05521 Mdot
.19811 .0552 Mdot
.19812 .0552 Mdot
.19813 .05519 Mdot
.19814 .05518 Mdot
.19815 .05517 Mdot
.19816 .05516 Mdot
.19817 .05515 Mdot
.19818 .05514 Mdot
.19819 .05514 Mdot
.1982 .05513 Mdot
.19821 .05512 Mdot
.19822 .05511 Mdot
.19823 .0551 Mdot
.19824 .05509 Mdot
.19825 .05508 Mdot
.19826 .05508 Mdot
.19827 .05507 Mdot
.19828 .05506 Mdot
.19829 .05505 Mdot
.1983 .05504 Mdot
.1983 .05503 Mdot
.19831 .05502 Mdot
.19832 .05502 Mdot
.19833 .05501 Mdot
.19834 .055 Mdot
.19835 .05499 Mdot
.19836 .05498 Mdot
.19837 .05497 Mdot
.19838 .05496 Mdot
.19839 .05495 Mdot
.1984 .05495 Mdot
.19841 .05494 Mdot
.19842 .05493 Mdot
.19843 .05492 Mdot
.19844 .05491 Mdot
.19845 .0549 Mdot
.19846 .05489 Mdot
.19847 .05489 Mdot
.19848 .05488 Mdot
.19849 .05487 Mdot
.1985 .05486 Mdot
.1985 .05485 Mdot
.19851 .05484 Mdot
.19852 .05483 Mdot
.19853 .05483 Mdot
.19854 .05482 Mdot
.19855 .05481 Mdot
.19856 .0548 Mdot
.19857 .05479 Mdot
.19858 .05478 Mdot
.19859 .05477 Mdot
.1986 .05477 Mdot
.19861 .05476 Mdot
.19862 .05475 Mdot
.19863 .05474 Mdot
.19864 .05473 Mdot
.19865 .05472 Mdot
.19866 .05471 Mdot
.19867 .05471 Mdot
.19868 .0547 Mdot
.19869 .05469 Mdot
.1987 .05468 Mdot
.1987 .05467 Mdot
.19871 .05466 Mdot
.19872 .05465 Mdot
.19873 .05465 Mdot
.19874 .05464 Mdot
.19875 .05463 Mdot
.19876 .05462 Mdot
.19877 .05461 Mdot
.19878 .0546 Mdot
.19879 .05459 Mdot
.1988 .05459 Mdot
.19881 .05458 Mdot
.19882 .05457 Mdot
.19883 .05456 Mdot
.19884 .05455 Mdot
.19885 .05454 Mdot
.19886 .05453 Mdot
.19887 .05453 Mdot
.19888 .05452 Mdot
.19889 .05451 Mdot
.1989 .0545 Mdot
.1989 .05449 Mdot
.19891 .05448 Mdot
.19892 .05447 Mdot
.19893 .05447 Mdot
.19894 .05446 Mdot
.19895 .05445 Mdot
.19896 .05444 Mdot
.19897 .05443 Mdot
.19898 .05442 Mdot
.19899 .05442 Mdot
.199 .05441 Mdot
.19901 .0544 Mdot
.19902 .05439 Mdot
.19903 .05438 Mdot
.19904 .05437 Mdot
.19905 .05436 Mdot
.19906 .05436 Mdot
.19907 .05435 Mdot
.19908 .05434 Mdot
.19909 .05433 Mdot
.1991 .05432 Mdot
.1991 .05431 Mdot
.19911 .0543 Mdot
.19912 .0543 Mdot
.19913 .05429 Mdot
.19914 .05428 Mdot
.19915 .05427 Mdot
.19916 .05426 Mdot
.19917 .05425 Mdot
.19918 .05424 Mdot
.19919 .05424 Mdot
.1992 .05423 Mdot
.19921 .05422 Mdot
.19922 .05421 Mdot
.19923 .0542 Mdot
.19924 .05419 Mdot
.19925 .05418 Mdot
.19926 .05418 Mdot
.19927 .05417 Mdot
.19928 .05416 Mdot
.19929 .05415 Mdot
.1993 .05414 Mdot
.1993 .05413 Mdot
.19931 .05413 Mdot
.19932 .05412 Mdot
.19933 .05411 Mdot
.19934 .0541 Mdot
.19935 .05409 Mdot
.19936 .05408 Mdot
.19937 .05407 Mdot
.19938 .05407 Mdot
.19939 .05406 Mdot
.1994 .05405 Mdot
.19941 .05404 Mdot
.19942 .05403 Mdot
.19943 .05402 Mdot
.19944 .05401 Mdot
.19945 .05401 Mdot
.19946 .054 Mdot
.19947 .05399 Mdot
.19948 .05398 Mdot
.19949 .05397 Mdot
.1995 .05396 Mdot
.1995 .05396 Mdot
.19951 .05395 Mdot
.19952 .05394 Mdot
.19953 .05393 Mdot
.19954 .05392 Mdot
.19955 .05391 Mdot
.19956 .0539 Mdot
.19957 .0539 Mdot
.19958 .05389 Mdot
.19959 .05388 Mdot
.1996 .05387 Mdot
.19961 .05386 Mdot
.19962 .05385 Mdot
.19963 .05384 Mdot
.19964 .05384 Mdot
.19965 .05383 Mdot
.19966 .05382 Mdot
.19967 .05381 Mdot
.19968 .0538 Mdot
.19969 .05379 Mdot
.1997 .05379 Mdot
.1997 .05378 Mdot
.19971 .05377 Mdot
.19972 .05376 Mdot
.19973 .05375 Mdot
.19974 .05374 Mdot
.19975 .05373 Mdot
.19976 .05373 Mdot
.19977 .05372 Mdot
.19978 .05371 Mdot
.19979 .0537 Mdot
.1998 .05369 Mdot
.19981 .05368 Mdot
.19982 .05368 Mdot
.19983 .05367 Mdot
.19984 .05366 Mdot
.19985 .05365 Mdot
.19986 .05364 Mdot
.19987 .05363 Mdot
.19988 .05362 Mdot
.19989 .05362 Mdot
.1999 .05361 Mdot
.1999 .0536 Mdot
.19991 .05359 Mdot
.19992 .05358 Mdot
.19993 .05357 Mdot
.19994 .05356 Mdot
.19995 .05356 Mdot
.19996 .05355 Mdot
.19997 .05354 Mdot
.19998 .05353 Mdot
.19999 .05352 Mdot
.2 .05351 Mdot
.20001 .05351 Mdot
.20002 .0535 Mdot
.20003 .05349 Mdot
.20004 .05348 Mdot
.20005 .05347 Mdot
.20006 .05346 Mdot
.20007 .05346 Mdot
.20008 .05345 Mdot
.20009 .05344 Mdot
.2001 .05343 Mdot
.2001 .05342 Mdot
.20011 .05341 Mdot
.20012 .0534 Mdot
.20013 .0534 Mdot
.20014 .05339 Mdot
.20015 .05338 Mdot
.20016 .05337 Mdot
.20017 .05336 Mdot
.20018 .05335 Mdot
.20019 .05335 Mdot
.2002 .05334 Mdot
.20021 .05333 Mdot
.20022 .05332 Mdot
.20023 .05331 Mdot
.20024 .0533 Mdot
.20025 .05329 Mdot
.20026 .05329 Mdot
.20027 .05328 Mdot
.20028 .05327 Mdot
.20029 .05326 Mdot
.2003 .05325 Mdot
.2003 .05324 Mdot
.20031 .05324 Mdot
.20032 .05323 Mdot
.20033 .05322 Mdot
.20034 .05321 Mdot
.20035 .0532 Mdot
.20036 .05319 Mdot
.20037 .05319 Mdot
.20038 .05318 Mdot
.20039 .05317 Mdot
.2004 .05316 Mdot
.20041 .05315 Mdot
.20042 .05314 Mdot
.20043 .05313 Mdot
.20044 .05313 Mdot
.20045 .05312 Mdot
.20046 .05311 Mdot
.20047 .0531 Mdot
.20048 .05309 Mdot
.20049 .05308 Mdot
.2005 .05308 Mdot
.2005 .05307 Mdot
.20051 .05306 Mdot
.20052 .05305 Mdot
.20053 .05304 Mdot
.20054 .05303 Mdot
.20055 .05303 Mdot
.20056 .05302 Mdot
.20057 .05301 Mdot
.20058 .053 Mdot
.20059 .05299 Mdot
.2006 .05298 Mdot
.20061 .05297 Mdot
.20062 .05297 Mdot
.20063 .05296 Mdot
.20064 .05295 Mdot
.20065 .05294 Mdot
.20066 .05293 Mdot
.20067 .05292 Mdot
.20068 .05292 Mdot
.20069 .05291 Mdot
.2007 .0529 Mdot
.2007 .05289 Mdot
.20071 .05288 Mdot
.20072 .05287 Mdot
.20073 .05287 Mdot
.20074 .05286 Mdot
.20075 .05285 Mdot
.20076 .05284 Mdot
.20077 .05283 Mdot
.20078 .05282 Mdot
.20079 .05282 Mdot
.2008 .05281 Mdot
.20081 .0528 Mdot
.20082 .05279 Mdot
.20083 .05278 Mdot
.20084 .05277 Mdot
.20085 .05276 Mdot
.20086 .05276 Mdot
.20087 .05275 Mdot
.20088 .05274 Mdot
.20089 .05273 Mdot
.2009 .05272 Mdot
.2009 .05271 Mdot
.20091 .05271 Mdot
.20092 .0527 Mdot
.20093 .05269 Mdot
.20094 .05268 Mdot
.20095 .05267 Mdot
.20096 .05266 Mdot
.20097 .05266 Mdot
.20098 .05265 Mdot
.20099 .05264 Mdot
.201 .05263 Mdot
.20101 .05262 Mdot
.20102 .05261 Mdot
.20103 .05261 Mdot
.20104 .0526 Mdot
.20105 .05259 Mdot
.20106 .05258 Mdot
.20107 .05257 Mdot
.20108 .05256 Mdot
.20109 .05256 Mdot
.2011 .05255 Mdot
.2011 .05254 Mdot
.20111 .05253 Mdot
.20112 .05252 Mdot
.20113 .05251 Mdot
.20114 .05251 Mdot
.20115 .0525 Mdot
.20116 .05249 Mdot
.20117 .05248 Mdot
.20118 .05247 Mdot
.20119 .05246 Mdot
.2012 .05246 Mdot
.20121 .05245 Mdot
.20122 .05244 Mdot
.20123 .05243 Mdot
.20124 .05242 Mdot
.20125 .05241 Mdot
.20126 .05241 Mdot
.20127 .0524 Mdot
.20128 .05239 Mdot
.20129 .05238 Mdot
.2013 .05237 Mdot
.2013 .05236 Mdot
.20131 .05236 Mdot
.20132 .05235 Mdot
.20133 .05234 Mdot
.20134 .05233 Mdot
.20135 .05232 Mdot
.20136 .05231 Mdot
.20137 .05231 Mdot
.20138 .0523 Mdot
.20139 .05229 Mdot
.2014 .05228 Mdot
.20141 .05227 Mdot
.20142 .05226 Mdot
.20143 .05226 Mdot
.20144 .05225 Mdot
.20145 .05224 Mdot
.20146 .05223 Mdot
.20147 .05222 Mdot
.20148 .05221 Mdot
.20149 .05221 Mdot
.2015 .0522 Mdot
.2015 .05219 Mdot
.20151 .05218 Mdot
.20152 .05217 Mdot
.20153 .05216 Mdot
.20154 .05216 Mdot
.20155 .05215 Mdot
.20156 .05214 Mdot
.20157 .05213 Mdot
.20158 .05212 Mdot
.20159 .05211 Mdot
.2016 .05211 Mdot
.20161 .0521 Mdot
.20162 .05209 Mdot
.20163 .05208 Mdot
.20164 .05207 Mdot
.20165 .05206 Mdot
.20166 .05206 Mdot
.20167 .05205 Mdot
.20168 .05204 Mdot
.20169 .05203 Mdot
.2017 .05202 Mdot
.2017 .05201 Mdot
.20171 .05201 Mdot
.20172 .052 Mdot
.20173 .05199 Mdot
.20174 .05198 Mdot
.20175 .05197 Mdot
.20176 .05196 Mdot
.20177 .05196 Mdot
.20178 .05195 Mdot
.20179 .05194 Mdot
.2018 .05193 Mdot
.20181 .05192 Mdot
.20182 .05191 Mdot
.20183 .05191 Mdot
.20184 .0519 Mdot
.20185 .05189 Mdot
.20186 .05188 Mdot
.20187 .05187 Mdot
.20188 .05186 Mdot
.20189 .05186 Mdot
.2019 .05185 Mdot
.2019 .05184 Mdot
.20191 .05183 Mdot
.20192 .05182 Mdot
.20193 .05181 Mdot
.20194 .05181 Mdot
.20195 .0518 Mdot
.20196 .05179 Mdot
.20197 .05178 Mdot
.20198 .05177 Mdot
.20199 .05177 Mdot
.202 .05176 Mdot
.20201 .05175 Mdot
.20202 .05174 Mdot
.20203 .05173 Mdot
.20204 .05172 Mdot
.20205 .05172 Mdot
.20206 .05171 Mdot
.20207 .0517 Mdot
.20208 .05169 Mdot
.20209 .05168 Mdot
.2021 .05167 Mdot
.2021 .05167 Mdot
.20211 .05166 Mdot
.20212 .05165 Mdot
.20213 .05164 Mdot
.20214 .05163 Mdot
.20215 .05162 Mdot
.20216 .05162 Mdot
.20217 .05161 Mdot
.20218 .0516 Mdot
.20219 .05159 Mdot
.2022 .05158 Mdot
.20221 .05157 Mdot
.20222 .05157 Mdot
.20223 .05156 Mdot
.20224 .05155 Mdot
.20225 .05154 Mdot
.20226 .05153 Mdot
.20227 .05153 Mdot
.20228 .05152 Mdot
.20229 .05151 Mdot
.2023 .0515 Mdot
.2023 .05149 Mdot
.20231 .05148 Mdot
.20232 .05148 Mdot
.20233 .05147 Mdot
.20234 .05146 Mdot
.20235 .05145 Mdot
.20236 .05144 Mdot
.20237 .05143 Mdot
.20238 .05143 Mdot
.20239 .05142 Mdot
.2024 .05141 Mdot
.20241 .0514 Mdot
.20242 .05139 Mdot
.20243 .05138 Mdot
.20244 .05138 Mdot
.20245 .05137 Mdot
.20246 .05136 Mdot
.20247 .05135 Mdot
.20248 .05134 Mdot
.20249 .05134 Mdot
.2025 .05133 Mdot
.2025 .05132 Mdot
.20251 .05131 Mdot
.20252 .0513 Mdot
.20253 .05129 Mdot
.20254 .05129 Mdot
.20255 .05128 Mdot
.20256 .05127 Mdot
.20257 .05126 Mdot
.20258 .05125 Mdot
.20259 .05124 Mdot
.2026 .05124 Mdot
.20261 .05123 Mdot
.20262 .05122 Mdot
.20263 .05121 Mdot
.20264 .0512 Mdot
.20265 .0512 Mdot
.20266 .05119 Mdot
.20267 .05118 Mdot
.20268 .05117 Mdot
.20269 .05116 Mdot
.2027 .05115 Mdot
.2027 .05115 Mdot
.20271 .05114 Mdot
.20272 .05113 Mdot
.20273 .05112 Mdot
.20274 .05111 Mdot
.20275 .05111 Mdot
.20276 .0511 Mdot
.20277 .05109 Mdot
.20278 .05108 Mdot
.20279 .05107 Mdot
.2028 .05106 Mdot
.20281 .05106 Mdot
.20282 .05105 Mdot
.20283 .05104 Mdot
.20284 .05103 Mdot
.20285 .05102 Mdot
.20286 .05101 Mdot
.20287 .05101 Mdot
.20288 .051 Mdot
.20289 .05099 Mdot
.2029 .05098 Mdot
.2029 .05097 Mdot
.20291 .05097 Mdot
.20292 .05096 Mdot
.20293 .05095 Mdot
.20294 .05094 Mdot
.20295 .05093 Mdot
.20296 .05092 Mdot
.20297 .05092 Mdot
.20298 .05091 Mdot
.20299 .0509 Mdot
.203 .05089 Mdot
.20301 .05088 Mdot
.20302 .05088 Mdot
.20303 .05087 Mdot
.20304 .05086 Mdot
.20305 .05085 Mdot
.20306 .05084 Mdot
.20307 .05083 Mdot
.20308 .05083 Mdot
.20309 .05082 Mdot
.2031 .05081 Mdot
.2031 .0508 Mdot
.20311 .05079 Mdot
.20312 .05079 Mdot
.20313 .05078 Mdot
.20314 .05077 Mdot
.20315 .05076 Mdot
.20316 .05075 Mdot
.20317 .05074 Mdot
.20318 .05074 Mdot
.20319 .05073 Mdot
.2032 .05072 Mdot
.20321 .05071 Mdot
.20322 .0507 Mdot
.20323 .0507 Mdot
.20324 .05069 Mdot
.20325 .05068 Mdot
.20326 .05067 Mdot
.20327 .05066 Mdot
.20328 .05065 Mdot
.20329 .05065 Mdot
.2033 .05064 Mdot
.2033 .05063 Mdot
.20331 .05062 Mdot
.20332 .05061 Mdot
.20333 .05061 Mdot
.20334 .0506 Mdot
.20335 .05059 Mdot
.20336 .05058 Mdot
.20337 .05057 Mdot
.20338 .05056 Mdot
.20339 .05056 Mdot
.2034 .05055 Mdot
.20341 .05054 Mdot
.20342 .05053 Mdot
.20343 .05052 Mdot
.20344 .05052 Mdot
.20345 .05051 Mdot
.20346 .0505 Mdot
.20347 .05049 Mdot
.20348 .05048 Mdot
.20349 .05048 Mdot
.2035 .05047 Mdot
.2035 .05046 Mdot
.20351 .05045 Mdot
.20352 .05044 Mdot
.20353 .05043 Mdot
.20354 .05043 Mdot
.20355 .05042 Mdot
.20356 .05041 Mdot
.20357 .0504 Mdot
.20358 .05039 Mdot
.20359 .05039 Mdot
.2036 .05038 Mdot
.20361 .05037 Mdot
.20362 .05036 Mdot
.20363 .05035 Mdot
.20364 .05034 Mdot
.20365 .05034 Mdot
.20366 .05033 Mdot
.20367 .05032 Mdot
.20368 .05031 Mdot
.20369 .0503 Mdot
.2037 .0503 Mdot
.2037 .05029 Mdot
.20371 .05028 Mdot
.20372 .05027 Mdot
.20373 .05026 Mdot
.20374 .05026 Mdot
.20375 .05025 Mdot
.20376 .05024 Mdot
.20377 .05023 Mdot
.20378 .05022 Mdot
.20379 .05021 Mdot
.2038 .05021 Mdot
.20381 .0502 Mdot
.20382 .05019 Mdot
.20383 .05018 Mdot
.20384 .05017 Mdot
.20385 .05017 Mdot
.20386 .05016 Mdot
.20387 .05015 Mdot
.20388 .05014 Mdot
.20389 .05013 Mdot
.2039 .05013 Mdot
.2039 .05012 Mdot
.20391 .05011 Mdot
.20392 .0501 Mdot
.20393 .05009 Mdot
.20394 .05008 Mdot
.20395 .05008 Mdot
.20396 .05007 Mdot
.20397 .05006 Mdot
.20398 .05005 Mdot
.20399 .05004 Mdot
.204 .05004 Mdot
.20401 .05003 Mdot
.20402 .05002 Mdot
.20403 .05001 Mdot
.20404 .05 Mdot
.20405 .05 Mdot
.20406 .04999 Mdot
.20407 .04998 Mdot
.20408 .04997 Mdot
.20409 .04996 Mdot
.2041 .04996 Mdot
.2041 .04995 Mdot
.20411 .04994 Mdot
.20412 .04993 Mdot
.20413 .04992 Mdot
.20414 .04991 Mdot
.20415 .04991 Mdot
.20416 .0499 Mdot
.20417 .04989 Mdot
.20418 .04988 Mdot
.20419 .04987 Mdot
.2042 .04987 Mdot
.20421 .04986 Mdot
.20422 .04985 Mdot
.20423 .04984 Mdot
.20424 .04983 Mdot
.20425 .04983 Mdot
.20426 .04982 Mdot
.20427 .04981 Mdot
.20428 .0498 Mdot
.20429 .04979 Mdot
.2043 .04979 Mdot
.2043 .04978 Mdot
.20431 .04977 Mdot
.20432 .04976 Mdot
.20433 .04975 Mdot
.20434 .04974 Mdot
.20435 .04974 Mdot
.20436 .04973 Mdot
.20437 .04972 Mdot
.20438 .04971 Mdot
.20439 .0497 Mdot
.2044 .0497 Mdot
.20441 .04969 Mdot
.20442 .04968 Mdot
.20443 .04967 Mdot
.20444 .04966 Mdot
.20445 .04966 Mdot
.20446 .04965 Mdot
.20447 .04964 Mdot
.20448 .04963 Mdot
.20449 .04962 Mdot
.2045 .04962 Mdot
.2045 .04961 Mdot
.20451 .0496 Mdot
.20452 .04959 Mdot
.20453 .04958 Mdot
.20454 .04958 Mdot
.20455 .04957 Mdot
.20456 .04956 Mdot
.20457 .04955 Mdot
.20458 .04954 Mdot
.20459 .04954 Mdot
.2046 .04953 Mdot
.20461 .04952 Mdot
.20462 .04951 Mdot
.20463 .0495 Mdot
.20464 .04949 Mdot
.20465 .04949 Mdot
.20466 .04948 Mdot
.20467 .04947 Mdot
.20468 .04946 Mdot
.20469 .04945 Mdot
.2047 .04945 Mdot
.2047 .04944 Mdot
.20471 .04943 Mdot
.20472 .04942 Mdot
.20473 .04941 Mdot
.20474 .04941 Mdot
.20475 .0494 Mdot
.20476 .04939 Mdot
.20477 .04938 Mdot
.20478 .04937 Mdot
.20479 .04937 Mdot
.2048 .04936 Mdot
.20481 .04935 Mdot
.20482 .04934 Mdot
.20483 .04933 Mdot
.20484 .04933 Mdot
.20485 .04932 Mdot
.20486 .04931 Mdot
.20487 .0493 Mdot
.20488 .04929 Mdot
.20489 .04929 Mdot
.2049 .04928 Mdot
.2049 .04927 Mdot
.20491 .04926 Mdot
.20492 .04925 Mdot
.20493 .04925 Mdot
.20494 .04924 Mdot
.20495 .04923 Mdot
.20496 .04922 Mdot
.20497 .04921 Mdot
.20498 .04921 Mdot
.20499 .0492 Mdot
.205 .04919 Mdot
.20501 .04918 Mdot
.20502 .04917 Mdot
.20503 .04917 Mdot
.20504 .04916 Mdot
.20505 .04915 Mdot
.20506 .04914 Mdot
.20507 .04913 Mdot
.20508 .04913 Mdot
.20509 .04912 Mdot
.2051 .04911 Mdot
.2051 .0491 Mdot
.20511 .04909 Mdot
.20512 .04909 Mdot
.20513 .04908 Mdot
.20514 .04907 Mdot
.20515 .04906 Mdot
.20516 .04905 Mdot
.20517 .04905 Mdot
.20518 .04904 Mdot
.20519 .04903 Mdot
.2052 .04902 Mdot
.20521 .04901 Mdot
.20522 .04901 Mdot
.20523 .049 Mdot
.20524 .04899 Mdot
.20525 .04898 Mdot
.20526 .04897 Mdot
.20527 .04897 Mdot
.20528 .04896 Mdot
.20529 .04895 Mdot
.2053 .04894 Mdot
.2053 .04893 Mdot
.20531 .04893 Mdot
.20532 .04892 Mdot
.20533 .04891 Mdot
.20534 .0489 Mdot
.20535 .04889 Mdot
.20536 .04889 Mdot
.20537 .04888 Mdot
.20538 .04887 Mdot
.20539 .04886 Mdot
.2054 .04885 Mdot
.20541 .04885 Mdot
.20542 .04884 Mdot
.20543 .04883 Mdot
.20544 .04882 Mdot
.20545 .04881 Mdot
.20546 .04881 Mdot
.20547 .0488 Mdot
.20548 .04879 Mdot
.20549 .04878 Mdot
.2055 .04877 Mdot
.2055 .04877 Mdot
.20551 .04876 Mdot
.20552 .04875 Mdot
.20553 .04874 Mdot
.20554 .04873 Mdot
.20555 .04873 Mdot
.20556 .04872 Mdot
.20557 .04871 Mdot
.20558 .0487 Mdot
.20559 .04869 Mdot
.2056 .04869 Mdot
.20561 .04868 Mdot
.20562 .04867 Mdot
.20563 .04866 Mdot
.20564 .04865 Mdot
.20565 .04865 Mdot
.20566 .04864 Mdot
.20567 .04863 Mdot
.20568 .04862 Mdot
.20569 .04861 Mdot
.2057 .04861 Mdot
.2057 .0486 Mdot
.20571 .04859 Mdot
.20572 .04858 Mdot
.20573 .04857 Mdot
.20574 .04857 Mdot
.20575 .04856 Mdot
.20576 .04855 Mdot
.20577 .04854 Mdot
.20578 .04853 Mdot
.20579 .04853 Mdot
.2058 .04852 Mdot
.20581 .04851 Mdot
.20582 .0485 Mdot
.20583 .0485 Mdot
.20584 .04849 Mdot
.20585 .04848 Mdot
.20586 .04847 Mdot
.20587 .04846 Mdot
.20588 .04846 Mdot
.20589 .04845 Mdot
.2059 .04844 Mdot
.2059 .04843 Mdot
.20591 .04842 Mdot
.20592 .04842 Mdot
.20593 .04841 Mdot
.20594 .0484 Mdot
.20595 .04839 Mdot
.20596 .04838 Mdot
.20597 .04838 Mdot
.20598 .04837 Mdot
.20599 .04836 Mdot
.206 .04835 Mdot
.20601 .04834 Mdot
.20602 .04834 Mdot
.20603 .04833 Mdot
.20604 .04832 Mdot
.20605 .04831 Mdot
.20606 .0483 Mdot
.20607 .0483 Mdot
.20608 .04829 Mdot
.20609 .04828 Mdot
.2061 .04827 Mdot
.2061 .04827 Mdot
.20611 .04826 Mdot
.20612 .04825 Mdot
.20613 .04824 Mdot
.20614 .04823 Mdot
.20615 .04823 Mdot
.20616 .04822 Mdot
.20617 .04821 Mdot
.20618 .0482 Mdot
.20619 .04819 Mdot
.2062 .04819 Mdot
.20621 .04818 Mdot
.20622 .04817 Mdot
.20623 .04816 Mdot
.20624 .04815 Mdot
.20625 .04815 Mdot
.20626 .04814 Mdot
.20627 .04813 Mdot
.20628 .04812 Mdot
.20629 .04811 Mdot
.2063 .04811 Mdot
.2063 .0481 Mdot
.20631 .04809 Mdot
.20632 .04808 Mdot
.20633 .04808 Mdot
.20634 .04807 Mdot
.20635 .04806 Mdot
.20636 .04805 Mdot
.20637 .04804 Mdot
.20638 .04804 Mdot
.20639 .04803 Mdot
.2064 .04802 Mdot
.20641 .04801 Mdot
.20642 .048 Mdot
.20643 .048 Mdot
.20644 .04799 Mdot
.20645 .04798 Mdot
.20646 .04797 Mdot
.20647 .04796 Mdot
.20648 .04796 Mdot
.20649 .04795 Mdot
.2065 .04794 Mdot
.2065 .04793 Mdot
.20651 .04793 Mdot
.20652 .04792 Mdot
.20653 .04791 Mdot
.20654 .0479 Mdot
.20655 .04789 Mdot
.20656 .04789 Mdot
.20657 .04788 Mdot
.20658 .04787 Mdot
.20659 .04786 Mdot
.2066 .04785 Mdot
.20661 .04785 Mdot
.20662 .04784 Mdot
.20663 .04783 Mdot
.20664 .04782 Mdot
.20665 .04782 Mdot
.20666 .04781 Mdot
.20667 .0478 Mdot
.20668 .04779 Mdot
.20669 .04778 Mdot
.2067 .04778 Mdot
.2067 .04777 Mdot
.20671 .04776 Mdot
.20672 .04775 Mdot
.20673 .04774 Mdot
.20674 .04774 Mdot
.20675 .04773 Mdot
.20676 .04772 Mdot
.20677 .04771 Mdot
.20678 .04771 Mdot
.20679 .0477 Mdot
.2068 .04769 Mdot
.20681 .04768 Mdot
.20682 .04767 Mdot
.20683 .04767 Mdot
.20684 .04766 Mdot
.20685 .04765 Mdot
.20686 .04764 Mdot
.20687 .04763 Mdot
.20688 .04763 Mdot
.20689 .04762 Mdot
.2069 .04761 Mdot
.2069 .0476 Mdot
.20691 .0476 Mdot
.20692 .04759 Mdot
.20693 .04758 Mdot
.20694 .04757 Mdot
.20695 .04756 Mdot
.20696 .04756 Mdot
.20697 .04755 Mdot
.20698 .04754 Mdot
.20699 .04753 Mdot
.207 .04752 Mdot
.20701 .04752 Mdot
.20702 .04751 Mdot
.20703 .0475 Mdot
.20704 .04749 Mdot
.20705 .04749 Mdot
.20706 .04748 Mdot
.20707 .04747 Mdot
.20708 .04746 Mdot
.20709 .04745 Mdot
.2071 .04745 Mdot
.2071 .04744 Mdot
.20711 .04743 Mdot
.20712 .04742 Mdot
.20713 .04741 Mdot
.20714 .04741 Mdot
.20715 .0474 Mdot
.20716 .04739 Mdot
.20717 .04738 Mdot
.20718 .04738 Mdot
.20719 .04737 Mdot
.2072 .04736 Mdot
.20721 .04735 Mdot
.20722 .04734 Mdot
.20723 .04734 Mdot
.20724 .04733 Mdot
.20725 .04732 Mdot
.20726 .04731 Mdot
.20727 .04731 Mdot
.20728 .0473 Mdot
.20729 .04729 Mdot
.2073 .04728 Mdot
.2073 .04727 Mdot
.20731 .04727 Mdot
.20732 .04726 Mdot
.20733 .04725 Mdot
.20734 .04724 Mdot
.20735 .04724 Mdot
.20736 .04723 Mdot
.20737 .04722 Mdot
.20738 .04721 Mdot
.20739 .0472 Mdot
.2074 .0472 Mdot
.20741 .04719 Mdot
.20742 .04718 Mdot
.20743 .04717 Mdot
.20744 .04716 Mdot
.20745 .04716 Mdot
.20746 .04715 Mdot
.20747 .04714 Mdot
.20748 .04713 Mdot
.20749 .04713 Mdot
.2075 .04712 Mdot
.2075 .04711 Mdot
.20751 .0471 Mdot
.20752 .04709 Mdot
.20753 .04709 Mdot
.20754 .04708 Mdot
.20755 .04707 Mdot
.20756 .04706 Mdot
.20757 .04706 Mdot
.20758 .04705 Mdot
.20759 .04704 Mdot
.2076 .04703 Mdot
.20761 .04702 Mdot
.20762 .04702 Mdot
.20763 .04701 Mdot
.20764 .047 Mdot
.20765 .04699 Mdot
.20766 .04699 Mdot
.20767 .04698 Mdot
.20768 .04697 Mdot
.20769 .04696 Mdot
.2077 .04695 Mdot
.2077 .04695 Mdot
.20771 .04694 Mdot
.20772 .04693 Mdot
.20773 .04692 Mdot
.20774 .04692 Mdot
.20775 .04691 Mdot
.20776 .0469 Mdot
.20777 .04689 Mdot
.20778 .04688 Mdot
.20779 .04688 Mdot
.2078 .04687 Mdot
.20781 .04686 Mdot
.20782 .04685 Mdot
.20783 .04685 Mdot
.20784 .04684 Mdot
.20785 .04683 Mdot
.20786 .04682 Mdot
.20787 .04681 Mdot
.20788 .04681 Mdot
.20789 .0468 Mdot
.2079 .04679 Mdot
.2079 .04678 Mdot
.20791 .04678 Mdot
.20792 .04677 Mdot
.20793 .04676 Mdot
.20794 .04675 Mdot
.20795 .04674 Mdot
.20796 .04674 Mdot
.20797 .04673 Mdot
.20798 .04672 Mdot
.20799 .04671 Mdot
.208 .04671 Mdot
.20801 .0467 Mdot
.20802 .04669 Mdot
.20803 .04668 Mdot
.20804 .04668 Mdot
.20805 .04667 Mdot
.20806 .04666 Mdot
.20807 .04665 Mdot
.20808 .04664 Mdot
.20809 .04664 Mdot
.2081 .04663 Mdot
.2081 .04662 Mdot
.20811 .04661 Mdot
.20812 .04661 Mdot
.20813 .0466 Mdot
.20814 .04659 Mdot
.20815 .04658 Mdot
.20816 .04657 Mdot
.20817 .04657 Mdot
.20818 .04656 Mdot
.20819 .04655 Mdot
.2082 .04654 Mdot
.20821 .04654 Mdot
.20822 .04653 Mdot
.20823 .04652 Mdot
.20824 .04651 Mdot
.20825 .0465 Mdot
.20826 .0465 Mdot
.20827 .04649 Mdot
.20828 .04648 Mdot
.20829 .04647 Mdot
.2083 .04647 Mdot
.2083 .04646 Mdot
.20831 .04645 Mdot
.20832 .04644 Mdot
.20833 .04644 Mdot
.20834 .04643 Mdot
.20835 .04642 Mdot
.20836 .04641 Mdot
.20837 .0464 Mdot
.20838 .0464 Mdot
.20839 .04639 Mdot
.2084 .04638 Mdot
.20841 .04637 Mdot
.20842 .04637 Mdot
.20843 .04636 Mdot
.20844 .04635 Mdot
.20845 .04634 Mdot
.20846 .04634 Mdot
.20847 .04633 Mdot
.20848 .04632 Mdot
.20849 .04631 Mdot
.2085 .0463 Mdot
.2085 .0463 Mdot
.20851 .04629 Mdot
.20852 .04628 Mdot
.20853 .04627 Mdot
.20854 .04627 Mdot
.20855 .04626 Mdot
.20856 .04625 Mdot
.20857 .04624 Mdot
.20858 .04623 Mdot
.20859 .04623 Mdot
.2086 .04622 Mdot
.20861 .04621 Mdot
.20862 .0462 Mdot
.20863 .0462 Mdot
.20864 .04619 Mdot
.20865 .04618 Mdot
.20866 .04617 Mdot
.20867 .04617 Mdot
.20868 .04616 Mdot
.20869 .04615 Mdot
.2087 .04614 Mdot
.2087 .04613 Mdot
.20871 .04613 Mdot
.20872 .04612 Mdot
.20873 .04611 Mdot
.20874 .0461 Mdot
.20875 .0461 Mdot
.20876 .04609 Mdot
.20877 .04608 Mdot
.20878 .04607 Mdot
.20879 .04607 Mdot
.2088 .04606 Mdot
.20881 .04605 Mdot
.20882 .04604 Mdot
.20883 .04604 Mdot
.20884 .04603 Mdot
.20885 .04602 Mdot
.20886 .04601 Mdot
.20887 .046 Mdot
.20888 .046 Mdot
.20889 .04599 Mdot
.2089 .04598 Mdot
.2089 .04597 Mdot
.20891 .04597 Mdot
.20892 .04596 Mdot
.20893 .04595 Mdot
.20894 .04594 Mdot
.20895 .04594 Mdot
.20896 .04593 Mdot
.20897 .04592 Mdot
.20898 .04591 Mdot
.20899 .0459 Mdot
.209 .0459 Mdot
.20901 .04589 Mdot
.20902 .04588 Mdot
.20903 .04587 Mdot
.20904 .04587 Mdot
.20905 .04586 Mdot
.20906 .04585 Mdot
.20907 .04584 Mdot
.20908 .04584 Mdot
.20909 .04583 Mdot
.2091 .04582 Mdot
.2091 .04581 Mdot
.20911 .04581 Mdot
.20912 .0458 Mdot
.20913 .04579 Mdot
.20914 .04578 Mdot
.20915 .04577 Mdot
.20916 .04577 Mdot
.20917 .04576 Mdot
.20918 .04575 Mdot
.20919 .04574 Mdot
.2092 .04574 Mdot
.20921 .04573 Mdot
.20922 .04572 Mdot
.20923 .04571 Mdot
.20924 .04571 Mdot
.20925 .0457 Mdot
.20926 .04569 Mdot
.20927 .04568 Mdot
.20928 .04568 Mdot
.20929 .04567 Mdot
.2093 .04566 Mdot
.2093 .04565 Mdot
.20931 .04564 Mdot
.20932 .04564 Mdot
.20933 .04563 Mdot
.20934 .04562 Mdot
.20935 .04561 Mdot
.20936 .04561 Mdot
.20937 .0456 Mdot
.20938 .04559 Mdot
.20939 .04558 Mdot
.2094 .04558 Mdot
.20941 .04557 Mdot
.20942 .04556 Mdot
.20943 .04555 Mdot
.20944 .04555 Mdot
.20945 .04554 Mdot
.20946 .04553 Mdot
.20947 .04552 Mdot
.20948 .04552 Mdot
.20949 .04551 Mdot
.2095 .0455 Mdot
.2095 .04549 Mdot
.20951 .04548 Mdot
.20952 .04548 Mdot
.20953 .04547 Mdot
.20954 .04546 Mdot
.20955 .04545 Mdot
.20956 .04545 Mdot
.20957 .04544 Mdot
.20958 .04543 Mdot
.20959 .04542 Mdot
.2096 .04542 Mdot
.20961 .04541 Mdot
.20962 .0454 Mdot
.20963 .04539 Mdot
.20964 .04539 Mdot
.20965 .04538 Mdot
.20966 .04537 Mdot
.20967 .04536 Mdot
.20968 .04536 Mdot
.20969 .04535 Mdot
.2097 .04534 Mdot
.2097 .04533 Mdot
.20971 .04532 Mdot
.20972 .04532 Mdot
.20973 .04531 Mdot
.20974 .0453 Mdot
.20975 .04529 Mdot
.20976 .04529 Mdot
.20977 .04528 Mdot
.20978 .04527 Mdot
.20979 .04526 Mdot
.2098 .04526 Mdot
.20981 .04525 Mdot
.20982 .04524 Mdot
.20983 .04523 Mdot
.20984 .04523 Mdot
.20985 .04522 Mdot
.20986 .04521 Mdot
.20987 .0452 Mdot
.20988 .0452 Mdot
.20989 .04519 Mdot
.2099 .04518 Mdot
.2099 .04517 Mdot
.20991 .04517 Mdot
.20992 .04516 Mdot
.20993 .04515 Mdot
.20994 .04514 Mdot
.20995 .04514 Mdot
.20996 .04513 Mdot
.20997 .04512 Mdot
.20998 .04511 Mdot
.20999 .04511 Mdot
.21 .0451 Mdot
.21001 .04509 Mdot
.21002 .04508 Mdot
.21003 .04507 Mdot
.21004 .04507 Mdot
.21005 .04506 Mdot
.21006 .04505 Mdot
.21007 .04504 Mdot
.21008 .04504 Mdot
.21009 .04503 Mdot
.2101 .04502 Mdot
.2101 .04501 Mdot
.21011 .04501 Mdot
.21012 .045 Mdot
.21013 .04499 Mdot
.21014 .04498 Mdot
.21015 .04498 Mdot
.21016 .04497 Mdot
.21017 .04496 Mdot
.21018 .04495 Mdot
.21019 .04495 Mdot
.2102 .04494 Mdot
.21021 .04493 Mdot
.21022 .04492 Mdot
.21023 .04492 Mdot
.21024 .04491 Mdot
.21025 .0449 Mdot
.21026 .04489 Mdot
.21027 .04489 Mdot
.21028 .04488 Mdot
.21029 .04487 Mdot
.2103 .04486 Mdot
.2103 .04486 Mdot
.21031 .04485 Mdot
.21032 .04484 Mdot
.21033 .04483 Mdot
.21034 .04483 Mdot
.21035 .04482 Mdot
.21036 .04481 Mdot
.21037 .0448 Mdot
.21038 .0448 Mdot
.21039 .04479 Mdot
.2104 .04478 Mdot
.21041 .04477 Mdot
.21042 .04477 Mdot
.21043 .04476 Mdot
.21044 .04475 Mdot
.21045 .04474 Mdot
.21046 .04474 Mdot
.21047 .04473 Mdot
.21048 .04472 Mdot
.21049 .04471 Mdot
.2105 .0447 Mdot
.2105 .0447 Mdot
.21051 .04469 Mdot
.21052 .04468 Mdot
.21053 .04467 Mdot
.21054 .04467 Mdot
.21055 .04466 Mdot
.21056 .04465 Mdot
.21057 .04464 Mdot
.21058 .04464 Mdot
.21059 .04463 Mdot
.2106 .04462 Mdot
.21061 .04461 Mdot
.21062 .04461 Mdot
.21063 .0446 Mdot
.21064 .04459 Mdot
.21065 .04458 Mdot
.21066 .04458 Mdot
.21067 .04457 Mdot
.21068 .04456 Mdot
.21069 .04455 Mdot
.2107 .04455 Mdot
.2107 .04454 Mdot
.21071 .04453 Mdot
.21072 .04452 Mdot
.21073 .04452 Mdot
.21074 .04451 Mdot
.21075 .0445 Mdot
.21076 .04449 Mdot
.21077 .04449 Mdot
.21078 .04448 Mdot
.21079 .04447 Mdot
.2108 .04446 Mdot
.21081 .04446 Mdot
.21082 .04445 Mdot
.21083 .04444 Mdot
.21084 .04443 Mdot
.21085 .04443 Mdot
.21086 .04442 Mdot
.21087 .04441 Mdot
.21088 .0444 Mdot
.21089 .0444 Mdot
.2109 .04439 Mdot
.2109 .04438 Mdot
.21091 .04437 Mdot
.21092 .04437 Mdot
.21093 .04436 Mdot
.21094 .04435 Mdot
.21095 .04434 Mdot
.21096 .04434 Mdot
.21097 .04433 Mdot
.21098 .04432 Mdot
.21099 .04431 Mdot
.211 .04431 Mdot
.21101 .0443 Mdot
.21102 .04429 Mdot
.21103 .04428 Mdot
.21104 .04428 Mdot
.21105 .04427 Mdot
.21106 .04426 Mdot
.21107 .04426 Mdot
.21108 .04425 Mdot
.21109 .04424 Mdot
.2111 .04423 Mdot
.2111 .04423 Mdot
.21111 .04422 Mdot
.21112 .04421 Mdot
.21113 .0442 Mdot
.21114 .0442 Mdot
.21115 .04419 Mdot
.21116 .04418 Mdot
.21117 .04417 Mdot
.21118 .04417 Mdot
.21119 .04416 Mdot
.2112 .04415 Mdot
.21121 .04414 Mdot
.21122 .04414 Mdot
.21123 .04413 Mdot
.21124 .04412 Mdot
.21125 .04411 Mdot
.21126 .04411 Mdot
.21127 .0441 Mdot
.21128 .04409 Mdot
.21129 .04408 Mdot
.2113 .04408 Mdot
.2113 .04407 Mdot
.21131 .04406 Mdot
.21132 .04405 Mdot
.21133 .04405 Mdot
.21134 .04404 Mdot
.21135 .04403 Mdot
.21136 .04402 Mdot
.21137 .04402 Mdot
.21138 .04401 Mdot
.21139 .044 Mdot
.2114 .04399 Mdot
.21141 .04399 Mdot
.21142 .04398 Mdot
.21143 .04397 Mdot
.21144 .04396 Mdot
.21145 .04396 Mdot
.21146 .04395 Mdot
.21147 .04394 Mdot
.21148 .04393 Mdot
.21149 .04393 Mdot
.2115 .04392 Mdot
.2115 .04391 Mdot
.21151 .0439 Mdot
.21152 .0439 Mdot
.21153 .04389 Mdot
.21154 .04388 Mdot
.21155 .04388 Mdot
.21156 .04387 Mdot
.21157 .04386 Mdot
.21158 .04385 Mdot
.21159 .04385 Mdot
.2116 .04384 Mdot
.21161 .04383 Mdot
.21162 .04382 Mdot
.21163 .04382 Mdot
.21164 .04381 Mdot
.21165 .0438 Mdot
.21166 .04379 Mdot
.21167 .04379 Mdot
.21168 .04378 Mdot
.21169 .04377 Mdot
.2117 .04376 Mdot
.2117 .04376 Mdot
.21171 .04375 Mdot
.21172 .04374 Mdot
.21173 .04373 Mdot
.21174 .04373 Mdot
.21175 .04372 Mdot
.21176 .04371 Mdot
.21177 .0437 Mdot
.21178 .0437 Mdot
.21179 .04369 Mdot
.2118 .04368 Mdot
.21181 .04367 Mdot
.21182 .04367 Mdot
.21183 .04366 Mdot
.21184 .04365 Mdot
.21185 .04365 Mdot
.21186 .04364 Mdot
.21187 .04363 Mdot
.21188 .04362 Mdot
.21189 .04362 Mdot
.2119 .04361 Mdot
.2119 .0436 Mdot
.21191 .04359 Mdot
.21192 .04359 Mdot
.21193 .04358 Mdot
.21194 .04357 Mdot
.21195 .04356 Mdot
.21196 .04356 Mdot
.21197 .04355 Mdot
.21198 .04354 Mdot
.21199 .04353 Mdot
.212 .04353 Mdot
.21201 .04352 Mdot
.21202 .04351 Mdot
.21203 .0435 Mdot
.21204 .0435 Mdot
.21205 .04349 Mdot
.21206 .04348 Mdot
.21207 .04348 Mdot
.21208 .04347 Mdot
.21209 .04346 Mdot
.2121 .04345 Mdot
.2121 .04345 Mdot
.21211 .04344 Mdot
.21212 .04343 Mdot
.21213 .04342 Mdot
.21214 .04342 Mdot
.21215 .04341 Mdot
.21216 .0434 Mdot
.21217 .04339 Mdot
.21218 .04339 Mdot
.21219 .04338 Mdot
.2122 .04337 Mdot
.21221 .04336 Mdot
.21222 .04336 Mdot
.21223 .04335 Mdot
.21224 .04334 Mdot
.21225 .04333 Mdot
.21226 .04333 Mdot
.21227 .04332 Mdot
.21228 .04331 Mdot
.21229 .04331 Mdot
.2123 .0433 Mdot
.2123 .04329 Mdot
.21231 .04328 Mdot
.21232 .04328 Mdot
.21233 .04327 Mdot
.21234 .04326 Mdot
.21235 .04325 Mdot
.21236 .04325 Mdot
.21237 .04324 Mdot
.21238 .04323 Mdot
.21239 .04322 Mdot
.2124 .04322 Mdot
.21241 .04321 Mdot
.21242 .0432 Mdot
.21243 .0432 Mdot
.21244 .04319 Mdot
.21245 .04318 Mdot
.21246 .04317 Mdot
.21247 .04317 Mdot
.21248 .04316 Mdot
.21249 .04315 Mdot
.2125 .04314 Mdot
.2125 .04314 Mdot
.21251 .04313 Mdot
.21252 .04312 Mdot
.21253 .04311 Mdot
.21254 .04311 Mdot
.21255 .0431 Mdot
.21256 .04309 Mdot
.21257 .04309 Mdot
.21258 .04308 Mdot
.21259 .04307 Mdot
.2126 .04306 Mdot
.21261 .04306 Mdot
.21262 .04305 Mdot
.21263 .04304 Mdot
.21264 .04303 Mdot
.21265 .04303 Mdot
.21266 .04302 Mdot
.21267 .04301 Mdot
.21268 .043 Mdot
.21269 .043 Mdot
.2127 .04299 Mdot
.2127 .04298 Mdot
.21271 .04298 Mdot
.21272 .04297 Mdot
.21273 .04296 Mdot
.21274 .04295 Mdot
.21275 .04295 Mdot
.21276 .04294 Mdot
.21277 .04293 Mdot
.21278 .04292 Mdot
.21279 .04292 Mdot
.2128 .04291 Mdot
.21281 .0429 Mdot
.21282 .04289 Mdot
.21283 .04289 Mdot
.21284 .04288 Mdot
.21285 .04287 Mdot
.21286 .04287 Mdot
.21287 .04286 Mdot
.21288 .04285 Mdot
.21289 .04284 Mdot
.2129 .04284 Mdot
.2129 .04283 Mdot
.21291 .04282 Mdot
.21292 .04281 Mdot
.21293 .04281 Mdot
.21294 .0428 Mdot
.21295 .04279 Mdot
.21296 .04279 Mdot
.21297 .04278 Mdot
.21298 .04277 Mdot
.21299 .04276 Mdot
.213 .04276 Mdot
.21301 .04275 Mdot
.21302 .04274 Mdot
.21303 .04273 Mdot
.21304 .04273 Mdot
.21305 .04272 Mdot
.21306 .04271 Mdot
.21307 .0427 Mdot
.21308 .0427 Mdot
.21309 .04269 Mdot
.2131 .04268 Mdot
.2131 .04268 Mdot
.21311 .04267 Mdot
.21312 .04266 Mdot
.21313 .04265 Mdot
.21314 .04265 Mdot
.21315 .04264 Mdot
.21316 .04263 Mdot
.21317 .04262 Mdot
.21318 .04262 Mdot
.21319 .04261 Mdot
.2132 .0426 Mdot
.21321 .0426 Mdot
.21322 .04259 Mdot
.21323 .04258 Mdot
.21324 .04257 Mdot
.21325 .04257 Mdot
.21326 .04256 Mdot
.21327 .04255 Mdot
.21328 .04254 Mdot
.21329 .04254 Mdot
.2133 .04253 Mdot
.2133 .04252 Mdot
.21331 .04252 Mdot
.21332 .04251 Mdot
.21333 .0425 Mdot
.21334 .04249 Mdot
.21335 .04249 Mdot
.21336 .04248 Mdot
.21337 .04247 Mdot
.21338 .04246 Mdot
.21339 .04246 Mdot
.2134 .04245 Mdot
.21341 .04244 Mdot
.21342 .04244 Mdot
.21343 .04243 Mdot
.21344 .04242 Mdot
.21345 .04241 Mdot
.21346 .04241 Mdot
.21347 .0424 Mdot
.21348 .04239 Mdot
.21349 .04238 Mdot
.2135 .04238 Mdot
.2135 .04237 Mdot
.21351 .04236 Mdot
.21352 .04236 Mdot
.21353 .04235 Mdot
.21354 .04234 Mdot
.21355 .04233 Mdot
.21356 .04233 Mdot
.21357 .04232 Mdot
.21358 .04231 Mdot
.21359 .04231 Mdot
.2136 .0423 Mdot
.21361 .04229 Mdot
.21362 .04228 Mdot
.21363 .04228 Mdot
.21364 .04227 Mdot
.21365 .04226 Mdot
.21366 .04225 Mdot
.21367 .04225 Mdot
.21368 .04224 Mdot
.21369 .04223 Mdot
.2137 .04223 Mdot
.2137 .04222 Mdot
.21371 .04221 Mdot
.21372 .0422 Mdot
.21373 .0422 Mdot
.21374 .04219 Mdot
.21375 .04218 Mdot
.21376 .04217 Mdot
.21377 .04217 Mdot
.21378 .04216 Mdot
.21379 .04215 Mdot
.2138 .04215 Mdot
.21381 .04214 Mdot
.21382 .04213 Mdot
.21383 .04212 Mdot
.21384 .04212 Mdot
.21385 .04211 Mdot
.21386 .0421 Mdot
.21387 .0421 Mdot
.21388 .04209 Mdot
.21389 .04208 Mdot
.2139 .04207 Mdot
.2139 .04207 Mdot
.21391 .04206 Mdot
.21392 .04205 Mdot
.21393 .04204 Mdot
.21394 .04204 Mdot
.21395 .04203 Mdot
.21396 .04202 Mdot
.21397 .04202 Mdot
.21398 .04201 Mdot
.21399 .042 Mdot
.214 .04199 Mdot
.21401 .04199 Mdot
.21402 .04198 Mdot
.21403 .04197 Mdot
.21404 .04197 Mdot
.21405 .04196 Mdot
.21406 .04195 Mdot
.21407 .04194 Mdot
.21408 .04194 Mdot
.21409 .04193 Mdot
.2141 .04192 Mdot
.2141 .04192 Mdot
.21411 .04191 Mdot
.21412 .0419 Mdot
.21413 .04189 Mdot
.21414 .04189 Mdot
.21415 .04188 Mdot
.21416 .04187 Mdot
.21417 .04186 Mdot
.21418 .04186 Mdot
.21419 .04185 Mdot
.2142 .04184 Mdot
.21421 .04184 Mdot
.21422 .04183 Mdot
.21423 .04182 Mdot
.21424 .04181 Mdot
.21425 .04181 Mdot
.21426 .0418 Mdot
.21427 .04179 Mdot
.21428 .04179 Mdot
.21429 .04178 Mdot
.2143 .04177 Mdot
.2143 .04176 Mdot
.21431 .04176 Mdot
.21432 .04175 Mdot
.21433 .04174 Mdot
.21434 .04174 Mdot
.21435 .04173 Mdot
.21436 .04172 Mdot
.21437 .04171 Mdot
.21438 .04171 Mdot
.21439 .0417 Mdot
.2144 .04169 Mdot
.21441 .04169 Mdot
.21442 .04168 Mdot
.21443 .04167 Mdot
.21444 .04166 Mdot
.21445 .04166 Mdot
.21446 .04165 Mdot
.21447 .04164 Mdot
.21448 .04164 Mdot
.21449 .04163 Mdot
.2145 .04162 Mdot
.2145 .04161 Mdot
.21451 .04161 Mdot
.21452 .0416 Mdot
.21453 .04159 Mdot
.21454 .04159 Mdot
.21455 .04158 Mdot
.21456 .04157 Mdot
.21457 .04156 Mdot
.21458 .04156 Mdot
.21459 .04155 Mdot
.2146 .04154 Mdot
.21461 .04154 Mdot
.21462 .04153 Mdot
.21463 .04152 Mdot
.21464 .04151 Mdot
.21465 .04151 Mdot
.21466 .0415 Mdot
.21467 .04149 Mdot
.21468 .04149 Mdot
.21469 .04148 Mdot
.2147 .04147 Mdot
.2147 .04146 Mdot
.21471 .04146 Mdot
.21472 .04145 Mdot
.21473 .04144 Mdot
.21474 .04144 Mdot
.21475 .04143 Mdot
.21476 .04142 Mdot
.21477 .04141 Mdot
.21478 .04141 Mdot
.21479 .0414 Mdot
.2148 .04139 Mdot
.21481 .04139 Mdot
.21482 .04138 Mdot
.21483 .04137 Mdot
.21484 .04136 Mdot
.21485 .04136 Mdot
.21486 .04135 Mdot
.21487 .04134 Mdot
.21488 .04134 Mdot
.21489 .04133 Mdot
.2149 .04132 Mdot
.2149 .04131 Mdot
.21491 .04131 Mdot
.21492 .0413 Mdot
.21493 .04129 Mdot
.21494 .04129 Mdot
.21495 .04128 Mdot
.21496 .04127 Mdot
.21497 .04126 Mdot
.21498 .04126 Mdot
.21499 .04125 Mdot
.215 .04124 Mdot
.21501 .04124 Mdot
.21502 .04123 Mdot
.21503 .04122 Mdot
.21504 .04121 Mdot
.21505 .04121 Mdot
.21506 .0412 Mdot
.21507 .04119 Mdot
.21508 .04119 Mdot
.21509 .04118 Mdot
.2151 .04117 Mdot
.2151 .04116 Mdot
.21511 .04116 Mdot
.21512 .04115 Mdot
.21513 .04114 Mdot
.21514 .04114 Mdot
.21515 .04113 Mdot
.21516 .04112 Mdot
.21517 .04111 Mdot
.21518 .04111 Mdot
.21519 .0411 Mdot
.2152 .04109 Mdot
.21521 .04109 Mdot
.21522 .04108 Mdot
.21523 .04107 Mdot
.21524 .04107 Mdot
.21525 .04106 Mdot
.21526 .04105 Mdot
.21527 .04104 Mdot
.21528 .04104 Mdot
.21529 .04103 Mdot
.2153 .04102 Mdot
.2153 .04102 Mdot
.21531 .04101 Mdot
.21532 .041 Mdot
.21533 .04099 Mdot
.21534 .04099 Mdot
.21535 .04098 Mdot
.21536 .04097 Mdot
.21537 .04097 Mdot
.21538 .04096 Mdot
.21539 .04095 Mdot
.2154 .04094 Mdot
.21541 .04094 Mdot
.21542 .04093 Mdot
.21543 .04092 Mdot
.21544 .04092 Mdot
.21545 .04091 Mdot
.21546 .0409 Mdot
.21547 .0409 Mdot
.21548 .04089 Mdot
.21549 .04088 Mdot
.2155 .04087 Mdot
.2155 .04087 Mdot
.21551 .04086 Mdot
.21552 .04085 Mdot
.21553 .04085 Mdot
.21554 .04084 Mdot
.21555 .04083 Mdot
.21556 .04082 Mdot
.21557 .04082 Mdot
.21558 .04081 Mdot
.21559 .0408 Mdot
.2156 .0408 Mdot
.21561 .04079 Mdot
.21562 .04078 Mdot
.21563 .04078 Mdot
.21564 .04077 Mdot
.21565 .04076 Mdot
.21566 .04075 Mdot
.21567 .04075 Mdot
.21568 .04074 Mdot
.21569 .04073 Mdot
.2157 .04073 Mdot
.2157 .04072 Mdot
.21571 .04071 Mdot
.21572 .0407 Mdot
.21573 .0407 Mdot
.21574 .04069 Mdot
.21575 .04068 Mdot
.21576 .04068 Mdot
.21577 .04067 Mdot
.21578 .04066 Mdot
.21579 .04066 Mdot
.2158 .04065 Mdot
.21581 .04064 Mdot
.21582 .04063 Mdot
.21583 .04063 Mdot
.21584 .04062 Mdot
.21585 .04061 Mdot
.21586 .04061 Mdot
.21587 .0406 Mdot
.21588 .04059 Mdot
.21589 .04059 Mdot
.2159 .04058 Mdot
.2159 .04057 Mdot
.21591 .04056 Mdot
.21592 .04056 Mdot
.21593 .04055 Mdot
.21594 .04054 Mdot
.21595 .04054 Mdot
.21596 .04053 Mdot
.21597 .04052 Mdot
.21598 .04051 Mdot
.21599 .04051 Mdot
.216 .0405 Mdot
.21601 .04049 Mdot
.21602 .04049 Mdot
.21603 .04048 Mdot
.21604 .04047 Mdot
.21605 .04047 Mdot
.21606 .04046 Mdot
.21607 .04045 Mdot
.21608 .04044 Mdot
.21609 .04044 Mdot
.2161 .04043 Mdot
.2161 .04042 Mdot
.21611 .04042 Mdot
.21612 .04041 Mdot
.21613 .0404 Mdot
.21614 .0404 Mdot
.21615 .04039 Mdot
.21616 .04038 Mdot
.21617 .04037 Mdot
.21618 .04037 Mdot
.21619 .04036 Mdot
.2162 .04035 Mdot
.21621 .04035 Mdot
.21622 .04034 Mdot
.21623 .04033 Mdot
.21624 .04033 Mdot
.21625 .04032 Mdot
.21626 .04031 Mdot
.21627 .0403 Mdot
.21628 .0403 Mdot
.21629 .04029 Mdot
.2163 .04028 Mdot
.2163 .04028 Mdot
.21631 .04027 Mdot
.21632 .04026 Mdot
.21633 .04026 Mdot
.21634 .04025 Mdot
.21635 .04024 Mdot
.21636 .04023 Mdot
.21637 .04023 Mdot
.21638 .04022 Mdot
.21639 .04021 Mdot
.2164 .04021 Mdot
.21641 .0402 Mdot
.21642 .04019 Mdot
.21643 .04019 Mdot
.21644 .04018 Mdot
.21645 .04017 Mdot
.21646 .04016 Mdot
.21647 .04016 Mdot
.21648 .04015 Mdot
.21649 .04014 Mdot
.2165 .04014 Mdot
.2165 .04013 Mdot
.21651 .04012 Mdot
.21652 .04012 Mdot
.21653 .04011 Mdot
.21654 .0401 Mdot
.21655 .0401 Mdot
.21656 .04009 Mdot
.21657 .04008 Mdot
.21658 .04007 Mdot
.21659 .04007 Mdot
.2166 .04006 Mdot
.21661 .04005 Mdot
.21662 .04005 Mdot
.21663 .04004 Mdot
.21664 .04003 Mdot
.21665 .04003 Mdot
.21666 .04002 Mdot
.21667 .04001 Mdot
.21668 .04 Mdot
.21669 .04 Mdot
.2167 .03999 Mdot
.2167 .03998 Mdot
.21671 .03998 Mdot
.21672 .03997 Mdot
.21673 .03996 Mdot
.21674 .03996 Mdot
.21675 .03995 Mdot
.21676 .03994 Mdot
.21677 .03993 Mdot
.21678 .03993 Mdot
.21679 .03992 Mdot
.2168 .03991 Mdot
.21681 .03991 Mdot
.21682 .0399 Mdot
.21683 .03989 Mdot
.21684 .03989 Mdot
.21685 .03988 Mdot
.21686 .03987 Mdot
.21687 .03987 Mdot
.21688 .03986 Mdot
.21689 .03985 Mdot
.2169 .03984 Mdot
.2169 .03984 Mdot
.21691 .03983 Mdot
.21692 .03982 Mdot
.21693 .03982 Mdot
.21694 .03981 Mdot
.21695 .0398 Mdot
.21696 .0398 Mdot
.21697 .03979 Mdot
.21698 .03978 Mdot
.21699 .03978 Mdot
.217 .03977 Mdot
.21701 .03976 Mdot
.21702 .03975 Mdot
.21703 .03975 Mdot
.21704 .03974 Mdot
.21705 .03973 Mdot
.21706 .03973 Mdot
.21707 .03972 Mdot
.21708 .03971 Mdot
.21709 .03971 Mdot
.2171 .0397 Mdot
.2171 .03969 Mdot
.21711 .03969 Mdot
.21712 .03968 Mdot
.21713 .03967 Mdot
.21714 .03966 Mdot
.21715 .03966 Mdot
.21716 .03965 Mdot
.21717 .03964 Mdot
.21718 .03964 Mdot
.21719 .03963 Mdot
.2172 .03962 Mdot
.21721 .03962 Mdot
.21722 .03961 Mdot
.21723 .0396 Mdot
.21724 .0396 Mdot
.21725 .03959 Mdot
.21726 .03958 Mdot
.21727 .03957 Mdot
.21728 .03957 Mdot
.21729 .03956 Mdot
.2173 .03955 Mdot
.2173 .03955 Mdot
.21731 .03954 Mdot
.21732 .03953 Mdot
.21733 .03953 Mdot
.21734 .03952 Mdot
.21735 .03951 Mdot
.21736 .03951 Mdot
.21737 .0395 Mdot
.21738 .03949 Mdot
.21739 .03949 Mdot
.2174 .03948 Mdot
.21741 .03947 Mdot
.21742 .03946 Mdot
.21743 .03946 Mdot
.21744 .03945 Mdot
.21745 .03944 Mdot
.21746 .03944 Mdot
.21747 .03943 Mdot
.21748 .03942 Mdot
.21749 .03942 Mdot
.2175 .03941 Mdot
.2175 .0394 Mdot
.21751 .0394 Mdot
.21752 .03939 Mdot
.21753 .03938 Mdot
.21754 .03938 Mdot
.21755 .03937 Mdot
.21756 .03936 Mdot
.21757 .03935 Mdot
.21758 .03935 Mdot
.21759 .03934 Mdot
.2176 .03933 Mdot
.21761 .03933 Mdot
.21762 .03932 Mdot
.21763 .03931 Mdot
.21764 .03931 Mdot
.21765 .0393 Mdot
.21766 .03929 Mdot
.21767 .03929 Mdot
.21768 .03928 Mdot
.21769 .03927 Mdot
.2177 .03927 Mdot
.2177 .03926 Mdot
.21771 .03925 Mdot
.21772 .03924 Mdot
.21773 .03924 Mdot
.21774 .03923 Mdot
.21775 .03922 Mdot
.21776 .03922 Mdot
.21777 .03921 Mdot
.21778 .0392 Mdot
.21779 .0392 Mdot
.2178 .03919 Mdot
.21781 .03918 Mdot
.21782 .03918 Mdot
.21783 .03917 Mdot
.21784 .03916 Mdot
.21785 .03916 Mdot
.21786 .03915 Mdot
.21787 .03914 Mdot
.21788 .03913 Mdot
.21789 .03913 Mdot
.2179 .03912 Mdot
.2179 .03911 Mdot
.21791 .03911 Mdot
.21792 .0391 Mdot
.21793 .03909 Mdot
.21794 .03909 Mdot
.21795 .03908 Mdot
.21796 .03907 Mdot
.21797 .03907 Mdot
.21798 .03906 Mdot
.21799 .03905 Mdot
.218 .03905 Mdot
.21801 .03904 Mdot
.21802 .03903 Mdot
.21803 .03903 Mdot
.21804 .03902 Mdot
.21805 .03901 Mdot
.21806 .039 Mdot
.21807 .039 Mdot
.21808 .03899 Mdot
.21809 .03898 Mdot
.2181 .03898 Mdot
.2181 .03897 Mdot
.21811 .03896 Mdot
.21812 .03896 Mdot
.21813 .03895 Mdot
.21814 .03894 Mdot
.21815 .03894 Mdot
.21816 .03893 Mdot
.21817 .03892 Mdot
.21818 .03892 Mdot
.21819 .03891 Mdot
.2182 .0389 Mdot
.21821 .0389 Mdot
.21822 .03889 Mdot
.21823 .03888 Mdot
.21824 .03888 Mdot
.21825 .03887 Mdot
.21826 .03886 Mdot
.21827 .03885 Mdot
.21828 .03885 Mdot
.21829 .03884 Mdot
.2183 .03883 Mdot
.2183 .03883 Mdot
.21831 .03882 Mdot
.21832 .03881 Mdot
.21833 .03881 Mdot
.21834 .0388 Mdot
.21835 .03879 Mdot
.21836 .03879 Mdot
.21837 .03878 Mdot
.21838 .03877 Mdot
.21839 .03877 Mdot
.2184 .03876 Mdot
.21841 .03875 Mdot
.21842 .03875 Mdot
.21843 .03874 Mdot
.21844 .03873 Mdot
.21845 .03873 Mdot
.21846 .03872 Mdot
.21847 .03871 Mdot
.21848 .03871 Mdot
.21849 .0387 Mdot
.2185 .03869 Mdot
.2185 .03869 Mdot
.21851 .03868 Mdot
.21852 .03867 Mdot
.21853 .03866 Mdot
.21854 .03866 Mdot
.21855 .03865 Mdot
.21856 .03864 Mdot
.21857 .03864 Mdot
.21858 .03863 Mdot
.21859 .03862 Mdot
.2186 .03862 Mdot
.21861 .03861 Mdot
.21862 .0386 Mdot
.21863 .0386 Mdot
.21864 .03859 Mdot
.21865 .03858 Mdot
.21866 .03858 Mdot
.21867 .03857 Mdot
.21868 .03856 Mdot
.21869 .03856 Mdot
.2187 .03855 Mdot
.2187 .03854 Mdot
.21871 .03854 Mdot
.21872 .03853 Mdot
.21873 .03852 Mdot
.21874 .03852 Mdot
.21875 .03851 Mdot
.21876 .0385 Mdot
.21877 .0385 Mdot
.21878 .03849 Mdot
.21879 .03848 Mdot
.2188 .03848 Mdot
.21881 .03847 Mdot
.21882 .03846 Mdot
.21883 .03845 Mdot
.21884 .03845 Mdot
.21885 .03844 Mdot
.21886 .03843 Mdot
.21887 .03843 Mdot
.21888 .03842 Mdot
.21889 .03841 Mdot
.2189 .03841 Mdot
.2189 .0384 Mdot
.21891 .03839 Mdot
.21892 .03839 Mdot
.21893 .03838 Mdot
.21894 .03837 Mdot
.21895 .03837 Mdot
.21896 .03836 Mdot
.21897 .03835 Mdot
.21898 .03835 Mdot
.21899 .03834 Mdot
.219 .03833 Mdot
.21901 .03833 Mdot
.21902 .03832 Mdot
.21903 .03831 Mdot
.21904 .03831 Mdot
.21905 .0383 Mdot
.21906 .03829 Mdot
.21907 .03829 Mdot
.21908 .03828 Mdot
.21909 .03827 Mdot
.2191 .03827 Mdot
.2191 .03826 Mdot
.21911 .03825 Mdot
.21912 .03825 Mdot
.21913 .03824 Mdot
.21914 .03823 Mdot
.21915 .03823 Mdot
.21916 .03822 Mdot
.21917 .03821 Mdot
.21918 .03821 Mdot
.21919 .0382 Mdot
.2192 .03819 Mdot
.21921 .03819 Mdot
.21922 .03818 Mdot
.21923 .03817 Mdot
.21924 .03817 Mdot
.21925 .03816 Mdot
.21926 .03815 Mdot
.21927 .03814 Mdot
.21928 .03814 Mdot
.21929 .03813 Mdot
.2193 .03812 Mdot
.2193 .03812 Mdot
.21931 .03811 Mdot
.21932 .0381 Mdot
.21933 .0381 Mdot
.21934 .03809 Mdot
.21935 .03808 Mdot
.21936 .03808 Mdot
.21937 .03807 Mdot
.21938 .03806 Mdot
.21939 .03806 Mdot
.2194 .03805 Mdot
.21941 .03804 Mdot
.21942 .03804 Mdot
.21943 .03803 Mdot
.21944 .03802 Mdot
.21945 .03802 Mdot
.21946 .03801 Mdot
.21947 .038 Mdot
.21948 .038 Mdot
.21949 .03799 Mdot
.2195 .03798 Mdot
.2195 .03798 Mdot
.21951 .03797 Mdot
.21952 .03796 Mdot
.21953 .03796 Mdot
.21954 .03795 Mdot
.21955 .03794 Mdot
.21956 .03794 Mdot
.21957 .03793 Mdot
.21958 .03792 Mdot
.21959 .03792 Mdot
.2196 .03791 Mdot
.21961 .0379 Mdot
.21962 .0379 Mdot
.21963 .03789 Mdot
.21964 .03788 Mdot
.21965 .03788 Mdot
.21966 .03787 Mdot
.21967 .03786 Mdot
.21968 .03786 Mdot
.21969 .03785 Mdot
.2197 .03784 Mdot
.2197 .03784 Mdot
.21971 .03783 Mdot
.21972 .03782 Mdot
.21973 .03782 Mdot
.21974 .03781 Mdot
.21975 .0378 Mdot
.21976 .0378 Mdot
.21977 .03779 Mdot
.21978 .03778 Mdot
.21979 .03778 Mdot
.2198 .03777 Mdot
.21981 .03776 Mdot
.21982 .03776 Mdot
.21983 .03775 Mdot
.21984 .03774 Mdot
.21985 .03774 Mdot
.21986 .03773 Mdot
.21987 .03772 Mdot
.21988 .03772 Mdot
.21989 .03771 Mdot
.2199 .0377 Mdot
.2199 .0377 Mdot
.21991 .03769 Mdot
.21992 .03768 Mdot
.21993 .03768 Mdot
.21994 .03767 Mdot
.21995 .03766 Mdot
.21996 .03766 Mdot
.21997 .03765 Mdot
.21998 .03764 Mdot
.21999 .03764 Mdot
.22 .03763 Mdot
.22001 .03762 Mdot
.22002 .03762 Mdot
.22003 .03761 Mdot
.22004 .0376 Mdot
.22005 .0376 Mdot
.22006 .03759 Mdot
.22007 .03758 Mdot
.22008 .03758 Mdot
.22009 .03757 Mdot
.2201 .03756 Mdot
.2201 .03756 Mdot
.22011 .03755 Mdot
.22012 .03754 Mdot
.22013 .03754 Mdot
.22014 .03753 Mdot
.22015 .03752 Mdot
.22016 .03752 Mdot
.22017 .03751 Mdot
.22018 .0375 Mdot
.22019 .0375 Mdot
.2202 .03749 Mdot
.22021 .03748 Mdot
.22022 .03748 Mdot
.22023 .03747 Mdot
.22024 .03746 Mdot
.22025 .03746 Mdot
.22026 .03745 Mdot
.22027 .03744 Mdot
.22028 .03744 Mdot
.22029 .03743 Mdot
.2203 .03742 Mdot
.2203 .03742 Mdot
.22031 .03741 Mdot
.22032 .0374 Mdot
.22033 .0374 Mdot
.22034 .03739 Mdot
.22035 .03739 Mdot
.22036 .03738 Mdot
.22037 .03737 Mdot
.22038 .03737 Mdot
.22039 .03736 Mdot
.2204 .03735 Mdot
.22041 .03735 Mdot
.22042 .03734 Mdot
.22043 .03733 Mdot
.22044 .03733 Mdot
.22045 .03732 Mdot
.22046 .03731 Mdot
.22047 .03731 Mdot
.22048 .0373 Mdot
.22049 .03729 Mdot
.2205 .03729 Mdot
.2205 .03728 Mdot
.22051 .03727 Mdot
.22052 .03727 Mdot
.22053 .03726 Mdot
.22054 .03725 Mdot
.22055 .03725 Mdot
.22056 .03724 Mdot
.22057 .03723 Mdot
.22058 .03723 Mdot
.22059 .03722 Mdot
.2206 .03721 Mdot
.22061 .03721 Mdot
.22062 .0372 Mdot
.22063 .03719 Mdot
.22064 .03719 Mdot
.22065 .03718 Mdot
.22066 .03717 Mdot
.22067 .03717 Mdot
.22068 .03716 Mdot
.22069 .03715 Mdot
.2207 .03715 Mdot
.2207 .03714 Mdot
.22071 .03713 Mdot
.22072 .03713 Mdot
.22073 .03712 Mdot
.22074 .03711 Mdot
.22075 .03711 Mdot
.22076 .0371 Mdot
.22077 .03709 Mdot
.22078 .03709 Mdot
.22079 .03708 Mdot
.2208 .03708 Mdot
.22081 .03707 Mdot
.22082 .03706 Mdot
.22083 .03706 Mdot
.22084 .03705 Mdot
.22085 .03704 Mdot
.22086 .03704 Mdot
.22087 .03703 Mdot
.22088 .03702 Mdot
.22089 .03702 Mdot
.2209 .03701 Mdot
.2209 .037 Mdot
.22091 .037 Mdot
.22092 .03699 Mdot
.22093 .03698 Mdot
.22094 .03698 Mdot
.22095 .03697 Mdot
.22096 .03696 Mdot
.22097 .03696 Mdot
.22098 .03695 Mdot
.22099 .03694 Mdot
.221 .03694 Mdot
.22101 .03693 Mdot
.22102 .03692 Mdot
.22103 .03692 Mdot
.22104 .03691 Mdot
.22105 .0369 Mdot
.22106 .0369 Mdot
.22107 .03689 Mdot
.22108 .03689 Mdot
.22109 .03688 Mdot
.2211 .03687 Mdot
.2211 .03687 Mdot
.22111 .03686 Mdot
.22112 .03685 Mdot
.22113 .03685 Mdot
.22114 .03684 Mdot
.22115 .03683 Mdot
.22116 .03683 Mdot
.22117 .03682 Mdot
.22118 .03681 Mdot
.22119 .03681 Mdot
.2212 .0368 Mdot
.22121 .03679 Mdot
.22122 .03679 Mdot
.22123 .03678 Mdot
.22124 .03677 Mdot
.22125 .03677 Mdot
.22126 .03676 Mdot
.22127 .03675 Mdot
.22128 .03675 Mdot
.22129 .03674 Mdot
.2213 .03673 Mdot
.2213 .03673 Mdot
.22131 .03672 Mdot
.22132 .03672 Mdot
.22133 .03671 Mdot
.22134 .0367 Mdot
.22135 .0367 Mdot
.22136 .03669 Mdot
.22137 .03668 Mdot
.22138 .03668 Mdot
.22139 .03667 Mdot
.2214 .03666 Mdot
.22141 .03666 Mdot
.22142 .03665 Mdot
.22143 .03664 Mdot
.22144 .03664 Mdot
.22145 .03663 Mdot
.22146 .03662 Mdot
.22147 .03662 Mdot
.22148 .03661 Mdot
.22149 .0366 Mdot
.2215 .0366 Mdot
.2215 .03659 Mdot
.22151 .03658 Mdot
.22152 .03658 Mdot
.22153 .03657 Mdot
.22154 .03657 Mdot
.22155 .03656 Mdot
.22156 .03655 Mdot
.22157 .03655 Mdot
.22158 .03654 Mdot
.22159 .03653 Mdot
.2216 .03653 Mdot
.22161 .03652 Mdot
.22162 .03651 Mdot
.22163 .03651 Mdot
.22164 .0365 Mdot
.22165 .03649 Mdot
.22166 .03649 Mdot
.22167 .03648 Mdot
.22168 .03647 Mdot
.22169 .03647 Mdot
.2217 .03646 Mdot
.2217 .03646 Mdot
.22171 .03645 Mdot
.22172 .03644 Mdot
.22173 .03644 Mdot
.22174 .03643 Mdot
.22175 .03642 Mdot
.22176 .03642 Mdot
.22177 .03641 Mdot
.22178 .0364 Mdot
.22179 .0364 Mdot
.2218 .03639 Mdot
.22181 .03638 Mdot
.22182 .03638 Mdot
.22183 .03637 Mdot
.22184 .03636 Mdot
.22185 .03636 Mdot
.22186 .03635 Mdot
.22187 .03634 Mdot
.22188 .03634 Mdot
.22189 .03633 Mdot
.2219 .03633 Mdot
.2219 .03632 Mdot
.22191 .03631 Mdot
.22192 .03631 Mdot
.22193 .0363 Mdot
.22194 .03629 Mdot
.22195 .03629 Mdot
.22196 .03628 Mdot
.22197 .03627 Mdot
.22198 .03627 Mdot
.22199 .03626 Mdot
.222 .03625 Mdot
.22201 .03625 Mdot
.22202 .03624 Mdot
.22203 .03624 Mdot
.22204 .03623 Mdot
.22205 .03622 Mdot
.22206 .03622 Mdot
.22207 .03621 Mdot
.22208 .0362 Mdot
.22209 .0362 Mdot
.2221 .03619 Mdot
.2221 .03618 Mdot
.22211 .03618 Mdot
.22212 .03617 Mdot
.22213 .03616 Mdot
.22214 .03616 Mdot
.22215 .03615 Mdot
.22216 .03614 Mdot
.22217 .03614 Mdot
.22218 .03613 Mdot
.22219 .03613 Mdot
.2222 .03612 Mdot
.22221 .03611 Mdot
.22222 .03611 Mdot
.22223 .0361 Mdot
.22224 .03609 Mdot
.22225 .03609 Mdot
.22226 .03608 Mdot
.22227 .03607 Mdot
.22228 .03607 Mdot
.22229 .03606 Mdot
.2223 .03605 Mdot
.2223 .03605 Mdot
.22231 .03604 Mdot
.22232 .03604 Mdot
.22233 .03603 Mdot
.22234 .03602 Mdot
.22235 .03602 Mdot
.22236 .03601 Mdot
.22237 .036 Mdot
.22238 .036 Mdot
.22239 .03599 Mdot
.2224 .03598 Mdot
.22241 .03598 Mdot
.22242 .03597 Mdot
.22243 .03596 Mdot
.22244 .03596 Mdot
.22245 .03595 Mdot
.22246 .03595 Mdot
.22247 .03594 Mdot
.22248 .03593 Mdot
.22249 .03593 Mdot
.2225 .03592 Mdot
.2225 .03591 Mdot
.22251 .03591 Mdot
.22252 .0359 Mdot
.22253 .03589 Mdot
.22254 .03589 Mdot
.22255 .03588 Mdot
.22256 .03587 Mdot
.22257 .03587 Mdot
.22258 .03586 Mdot
.22259 .03586 Mdot
.2226 .03585 Mdot
.22261 .03584 Mdot
.22262 .03584 Mdot
.22263 .03583 Mdot
.22264 .03582 Mdot
.22265 .03582 Mdot
.22266 .03581 Mdot
.22267 .0358 Mdot
.22268 .0358 Mdot
.22269 .03579 Mdot
.2227 .03579 Mdot
.2227 .03578 Mdot
.22271 .03577 Mdot
.22272 .03577 Mdot
.22273 .03576 Mdot
.22274 .03575 Mdot
.22275 .03575 Mdot
.22276 .03574 Mdot
.22277 .03573 Mdot
.22278 .03573 Mdot
.22279 .03572 Mdot
.2228 .03572 Mdot
.22281 .03571 Mdot
.22282 .0357 Mdot
.22283 .0357 Mdot
.22284 .03569 Mdot
.22285 .03568 Mdot
.22286 .03568 Mdot
.22287 .03567 Mdot
.22288 .03566 Mdot
.22289 .03566 Mdot
.2229 .03565 Mdot
.2229 .03565 Mdot
.22291 .03564 Mdot
.22292 .03563 Mdot
.22293 .03563 Mdot
.22294 .03562 Mdot
.22295 .03561 Mdot
.22296 .03561 Mdot
.22297 .0356 Mdot
.22298 .03559 Mdot
.22299 .03559 Mdot
.223 .03558 Mdot
.22301 .03557 Mdot
.22302 .03557 Mdot
.22303 .03556 Mdot
.22304 .03556 Mdot
.22305 .03555 Mdot
.22306 .03554 Mdot
.22307 .03554 Mdot
.22308 .03553 Mdot
.22309 .03552 Mdot
.2231 .03552 Mdot
.2231 .03551 Mdot
.22311 .03551 Mdot
.22312 .0355 Mdot
.22313 .03549 Mdot
.22314 .03549 Mdot
.22315 .03548 Mdot
.22316 .03547 Mdot
.22317 .03547 Mdot
.22318 .03546 Mdot
.22319 .03545 Mdot
.2232 .03545 Mdot
.22321 .03544 Mdot
.22322 .03544 Mdot
.22323 .03543 Mdot
.22324 .03542 Mdot
.22325 .03542 Mdot
.22326 .03541 Mdot
.22327 .0354 Mdot
.22328 .0354 Mdot
.22329 .03539 Mdot
.2233 .03538 Mdot
.2233 .03538 Mdot
.22331 .03537 Mdot
.22332 .03537 Mdot
.22333 .03536 Mdot
.22334 .03535 Mdot
.22335 .03535 Mdot
.22336 .03534 Mdot
.22337 .03533 Mdot
.22338 .03533 Mdot
.22339 .03532 Mdot
.2234 .03531 Mdot
.22341 .03531 Mdot
.22342 .0353 Mdot
.22343 .0353 Mdot
.22344 .03529 Mdot
.22345 .03528 Mdot
.22346 .03528 Mdot
.22347 .03527 Mdot
.22348 .03526 Mdot
.22349 .03526 Mdot
.2235 .03525 Mdot
.2235 .03525 Mdot
.22351 .03524 Mdot
.22352 .03523 Mdot
.22353 .03523 Mdot
.22354 .03522 Mdot
.22355 .03521 Mdot
.22356 .03521 Mdot
.22357 .0352 Mdot
.22358 .03519 Mdot
.22359 .03519 Mdot
.2236 .03518 Mdot
.22361 .03518 Mdot
.22362 .03517 Mdot
.22363 .03516 Mdot
.22364 .03516 Mdot
.22365 .03515 Mdot
.22366 .03514 Mdot
.22367 .03514 Mdot
.22368 .03513 Mdot
.22369 .03513 Mdot
.2237 .03512 Mdot
.2237 .03511 Mdot
.22371 .03511 Mdot
.22372 .0351 Mdot
.22373 .03509 Mdot
.22374 .03509 Mdot
.22375 .03508 Mdot
.22376 .03508 Mdot
.22377 .03507 Mdot
.22378 .03506 Mdot
.22379 .03506 Mdot
.2238 .03505 Mdot
.22381 .03504 Mdot
.22382 .03504 Mdot
.22383 .03503 Mdot
.22384 .03502 Mdot
.22385 .03502 Mdot
.22386 .03501 Mdot
.22387 .03501 Mdot
.22388 .035 Mdot
.22389 .03499 Mdot
.2239 .03499 Mdot
.2239 .03498 Mdot
.22391 .03497 Mdot
.22392 .03497 Mdot
.22393 .03496 Mdot
.22394 .03496 Mdot
.22395 .03495 Mdot
.22396 .03494 Mdot
.22397 .03494 Mdot
.22398 .03493 Mdot
.22399 .03492 Mdot
.224 .03492 Mdot
.22401 .03491 Mdot
.22402 .03491 Mdot
.22403 .0349 Mdot
.22404 .03489 Mdot
.22405 .03489 Mdot
.22406 .03488 Mdot
.22407 .03487 Mdot
.22408 .03487 Mdot
.22409 .03486 Mdot
.2241 .03486 Mdot
.2241 .03485 Mdot
.22411 .03484 Mdot
.22412 .03484 Mdot
.22413 .03483 Mdot
.22414 .03482 Mdot
.22415 .03482 Mdot
.22416 .03481 Mdot
.22417 .03481 Mdot
.22418 .0348 Mdot
.22419 .03479 Mdot
.2242 .03479 Mdot
.22421 .03478 Mdot
.22422 .03477 Mdot
.22423 .03477 Mdot
.22424 .03476 Mdot
.22425 .03476 Mdot
.22426 .03475 Mdot
.22427 .03474 Mdot
.22428 .03474 Mdot
.22429 .03473 Mdot
.2243 .03472 Mdot
.2243 .03472 Mdot
.22431 .03471 Mdot
.22432 .03471 Mdot
.22433 .0347 Mdot
.22434 .03469 Mdot
.22435 .03469 Mdot
.22436 .03468 Mdot
.22437 .03467 Mdot
.22438 .03467 Mdot
.22439 .03466 Mdot
.2244 .03466 Mdot
.22441 .03465 Mdot
.22442 .03464 Mdot
.22443 .03464 Mdot
.22444 .03463 Mdot
.22445 .03462 Mdot
.22446 .03462 Mdot
.22447 .03461 Mdot
.22448 .03461 Mdot
.22449 .0346 Mdot
.2245 .03459 Mdot
.2245 .03459 Mdot
.22451 .03458 Mdot
.22452 .03457 Mdot
.22453 .03457 Mdot
.22454 .03456 Mdot
.22455 .03456 Mdot
.22456 .03455 Mdot
.22457 .03454 Mdot
.22458 .03454 Mdot
.22459 .03453 Mdot
.2246 .03453 Mdot
.22461 .03452 Mdot
.22462 .03451 Mdot
.22463 .03451 Mdot
.22464 .0345 Mdot
.22465 .03449 Mdot
.22466 .03449 Mdot
.22467 .03448 Mdot
.22468 .03448 Mdot
.22469 .03447 Mdot
.2247 .03446 Mdot
.2247 .03446 Mdot
.22471 .03445 Mdot
.22472 .03444 Mdot
.22473 .03444 Mdot
.22474 .03443 Mdot
.22475 .03443 Mdot
.22476 .03442 Mdot
.22477 .03441 Mdot
.22478 .03441 Mdot
.22479 .0344 Mdot
.2248 .0344 Mdot
.22481 .03439 Mdot
.22482 .03438 Mdot
.22483 .03438 Mdot
.22484 .03437 Mdot
.22485 .03436 Mdot
.22486 .03436 Mdot
.22487 .03435 Mdot
.22488 .03435 Mdot
.22489 .03434 Mdot
.2249 .03433 Mdot
.2249 .03433 Mdot
.22491 .03432 Mdot
.22492 .03431 Mdot
.22493 .03431 Mdot
.22494 .0343 Mdot
.22495 .0343 Mdot
.22496 .03429 Mdot
.22497 .03428 Mdot
.22498 .03428 Mdot
.22499 .03427 Mdot
.225 .03427 Mdot
.22501 .03426 Mdot
.22502 .03425 Mdot
.22503 .03425 Mdot
.22504 .03424 Mdot
.22505 .03423 Mdot
.22506 .03423 Mdot
.22507 .03422 Mdot
.22508 .03422 Mdot
.22509 .03421 Mdot
.2251 .0342 Mdot
.2251 .0342 Mdot
.22511 .03419 Mdot
.22512 .03419 Mdot
.22513 .03418 Mdot
.22514 .03417 Mdot
.22515 .03417 Mdot
.22516 .03416 Mdot
.22517 .03415 Mdot
.22518 .03415 Mdot
.22519 .03414 Mdot
.2252 .03414 Mdot
.22521 .03413 Mdot
.22522 .03412 Mdot
.22523 .03412 Mdot
.22524 .03411 Mdot
.22525 .03411 Mdot
.22526 .0341 Mdot
.22527 .03409 Mdot
.22528 .03409 Mdot
.22529 .03408 Mdot
.2253 .03407 Mdot
.2253 .03407 Mdot
.22531 .03406 Mdot
.22532 .03406 Mdot
.22533 .03405 Mdot
.22534 .03404 Mdot
.22535 .03404 Mdot
.22536 .03403 Mdot
.22537 .03403 Mdot
.22538 .03402 Mdot
.22539 .03401 Mdot
.2254 .03401 Mdot
.22541 .034 Mdot
.22542 .03399 Mdot
.22543 .03399 Mdot
.22544 .03398 Mdot
.22545 .03398 Mdot
.22546 .03397 Mdot
.22547 .03396 Mdot
.22548 .03396 Mdot
.22549 .03395 Mdot
.2255 .03395 Mdot
.2255 .03394 Mdot
.22551 .03393 Mdot
.22552 .03393 Mdot
.22553 .03392 Mdot
.22554 .03391 Mdot
.22555 .03391 Mdot
.22556 .0339 Mdot
.22557 .0339 Mdot
.22558 .03389 Mdot
.22559 .03388 Mdot
.2256 .03388 Mdot
.22561 .03387 Mdot
.22562 .03387 Mdot
.22563 .03386 Mdot
.22564 .03385 Mdot
.22565 .03385 Mdot
.22566 .03384 Mdot
.22567 .03384 Mdot
.22568 .03383 Mdot
.22569 .03382 Mdot
.2257 .03382 Mdot
.2257 .03381 Mdot
.22571 .0338 Mdot
.22572 .0338 Mdot
.22573 .03379 Mdot
.22574 .03379 Mdot
.22575 .03378 Mdot
.22576 .03377 Mdot
.22577 .03377 Mdot
.22578 .03376 Mdot
.22579 .03376 Mdot
.2258 .03375 Mdot
.22581 .03374 Mdot
.22582 .03374 Mdot
.22583 .03373 Mdot
.22584 .03373 Mdot
.22585 .03372 Mdot
.22586 .03371 Mdot
.22587 .03371 Mdot
.22588 .0337 Mdot
.22589 .0337 Mdot
.2259 .03369 Mdot
.2259 .03368 Mdot
.22591 .03368 Mdot
.22592 .03367 Mdot
.22593 .03366 Mdot
.22594 .03366 Mdot
.22595 .03365 Mdot
.22596 .03365 Mdot
.22597 .03364 Mdot
.22598 .03363 Mdot
.22599 .03363 Mdot
.226 .03362 Mdot
.22601 .03362 Mdot
.22602 .03361 Mdot
.22603 .0336 Mdot
.22604 .0336 Mdot
.22605 .03359 Mdot
.22606 .03359 Mdot
.22607 .03358 Mdot
.22608 .03357 Mdot
.22609 .03357 Mdot
.2261 .03356 Mdot
.2261 .03356 Mdot
.22611 .03355 Mdot
.22612 .03354 Mdot
.22613 .03354 Mdot
.22614 .03353 Mdot
.22615 .03353 Mdot
.22616 .03352 Mdot
.22617 .03351 Mdot
.22618 .03351 Mdot
.22619 .0335 Mdot
.2262 .03349 Mdot
.22621 .03349 Mdot
.22622 .03348 Mdot
.22623 .03348 Mdot
.22624 .03347 Mdot
.22625 .03346 Mdot
.22626 .03346 Mdot
.22627 .03345 Mdot
.22628 .03345 Mdot
.22629 .03344 Mdot
.2263 .03343 Mdot
.2263 .03343 Mdot
.22631 .03342 Mdot
.22632 .03342 Mdot
.22633 .03341 Mdot
.22634 .0334 Mdot
.22635 .0334 Mdot
.22636 .03339 Mdot
.22637 .03339 Mdot
.22638 .03338 Mdot
.22639 .03337 Mdot
.2264 .03337 Mdot
.22641 .03336 Mdot
.22642 .03336 Mdot
.22643 .03335 Mdot
.22644 .03334 Mdot
.22645 .03334 Mdot
.22646 .03333 Mdot
.22647 .03333 Mdot
.22648 .03332 Mdot
.22649 .03331 Mdot
.2265 .03331 Mdot
.2265 .0333 Mdot
.22651 .0333 Mdot
.22652 .03329 Mdot
.22653 .03328 Mdot
.22654 .03328 Mdot
.22655 .03327 Mdot
.22656 .03327 Mdot
.22657 .03326 Mdot
.22658 .03325 Mdot
.22659 .03325 Mdot
.2266 .03324 Mdot
.22661 .03324 Mdot
.22662 .03323 Mdot
.22663 .03322 Mdot
.22664 .03322 Mdot
.22665 .03321 Mdot
.22666 .03321 Mdot
.22667 .0332 Mdot
.22668 .03319 Mdot
.22669 .03319 Mdot
.2267 .03318 Mdot
.2267 .03318 Mdot
.22671 .03317 Mdot
.22672 .03316 Mdot
.22673 .03316 Mdot
.22674 .03315 Mdot
.22675 .03315 Mdot
.22676 .03314 Mdot
.22677 .03313 Mdot
.22678 .03313 Mdot
.22679 .03312 Mdot
.2268 .03312 Mdot
.22681 .03311 Mdot
.22682 .0331 Mdot
.22683 .0331 Mdot
.22684 .03309 Mdot
.22685 .03309 Mdot
.22686 .03308 Mdot
.22687 .03307 Mdot
.22688 .03307 Mdot
.22689 .03306 Mdot
.2269 .03306 Mdot
.2269 .03305 Mdot
.22691 .03304 Mdot
.22692 .03304 Mdot
.22693 .03303 Mdot
.22694 .03303 Mdot
.22695 .03302 Mdot
.22696 .03301 Mdot
.22697 .03301 Mdot
.22698 .033 Mdot
.22699 .033 Mdot
.227 .03299 Mdot
.22701 .03298 Mdot
.22702 .03298 Mdot
.22703 .03297 Mdot
.22704 .03297 Mdot
.22705 .03296 Mdot
.22706 .03295 Mdot
.22707 .03295 Mdot
.22708 .03294 Mdot
.22709 .03294 Mdot
.2271 .03293 Mdot
.2271 .03292 Mdot
.22711 .03292 Mdot
.22712 .03291 Mdot
.22713 .03291 Mdot
.22714 .0329 Mdot
.22715 .03289 Mdot
.22716 .03289 Mdot
.22717 .03288 Mdot
.22718 .03288 Mdot
.22719 .03287 Mdot
.2272 .03286 Mdot
.22721 .03286 Mdot
.22722 .03285 Mdot
.22723 .03285 Mdot
.22724 .03284 Mdot
.22725 .03283 Mdot
.22726 .03283 Mdot
.22727 .03282 Mdot
.22728 .03282 Mdot
.22729 .03281 Mdot
.2273 .0328 Mdot
.2273 .0328 Mdot
.22731 .03279 Mdot
.22732 .03279 Mdot
.22733 .03278 Mdot
.22734 .03277 Mdot
.22735 .03277 Mdot
.22736 .03276 Mdot
.22737 .03276 Mdot
.22738 .03275 Mdot
.22739 .03274 Mdot
.2274 .03274 Mdot
.22741 .03273 Mdot
.22742 .03273 Mdot
.22743 .03272 Mdot
.22744 .03272 Mdot
.22745 .03271 Mdot
.22746 .0327 Mdot
.22747 .0327 Mdot
.22748 .03269 Mdot
.22749 .03269 Mdot
.2275 .03268 Mdot
.2275 .03267 Mdot
.22751 .03267 Mdot
.22752 .03266 Mdot
.22753 .03266 Mdot
.22754 .03265 Mdot
.22755 .03264 Mdot
.22756 .03264 Mdot
.22757 .03263 Mdot
.22758 .03263 Mdot
.22759 .03262 Mdot
.2276 .03261 Mdot
.22761 .03261 Mdot
.22762 .0326 Mdot
.22763 .0326 Mdot
.22764 .03259 Mdot
.22765 .03258 Mdot
.22766 .03258 Mdot
.22767 .03257 Mdot
.22768 .03257 Mdot
.22769 .03256 Mdot
.2277 .03256 Mdot
.2277 .03255 Mdot
.22771 .03254 Mdot
.22772 .03254 Mdot
.22773 .03253 Mdot
.22774 .03253 Mdot
.22775 .03252 Mdot
.22776 .03251 Mdot
.22777 .03251 Mdot
.22778 .0325 Mdot
.22779 .0325 Mdot
.2278 .03249 Mdot
.22781 .03248 Mdot
.22782 .03248 Mdot
.22783 .03247 Mdot
.22784 .03247 Mdot
.22785 .03246 Mdot
.22786 .03245 Mdot
.22787 .03245 Mdot
.22788 .03244 Mdot
.22789 .03244 Mdot
.2279 .03243 Mdot
.2279 .03243 Mdot
.22791 .03242 Mdot
.22792 .03241 Mdot
.22793 .03241 Mdot
.22794 .0324 Mdot
.22795 .0324 Mdot
.22796 .03239 Mdot
.22797 .03238 Mdot
.22798 .03238 Mdot
.22799 .03237 Mdot
.228 .03237 Mdot
.22801 .03236 Mdot
.22802 .03235 Mdot
.22803 .03235 Mdot
.22804 .03234 Mdot
.22805 .03234 Mdot
.22806 .03233 Mdot
.22807 .03233 Mdot
.22808 .03232 Mdot
.22809 .03231 Mdot
.2281 .03231 Mdot
.2281 .0323 Mdot
.22811 .0323 Mdot
.22812 .03229 Mdot
.22813 .03228 Mdot
.22814 .03228 Mdot
.22815 .03227 Mdot
.22816 .03227 Mdot
.22817 .03226 Mdot
.22818 .03226 Mdot
.22819 .03225 Mdot
.2282 .03224 Mdot
.22821 .03224 Mdot
.22822 .03223 Mdot
.22823 .03223 Mdot
.22824 .03222 Mdot
.22825 .03221 Mdot
.22826 .03221 Mdot
.22827 .0322 Mdot
.22828 .0322 Mdot
.22829 .03219 Mdot
.2283 .03218 Mdot
.2283 .03218 Mdot
.22831 .03217 Mdot
.22832 .03217 Mdot
.22833 .03216 Mdot
.22834 .03216 Mdot
.22835 .03215 Mdot
.22836 .03214 Mdot
.22837 .03214 Mdot
.22838 .03213 Mdot
.22839 .03213 Mdot
.2284 .03212 Mdot
.22841 .03211 Mdot
.22842 .03211 Mdot
.22843 .0321 Mdot
.22844 .0321 Mdot
.22845 .03209 Mdot
.22846 .03209 Mdot
.22847 .03208 Mdot
.22848 .03207 Mdot
.22849 .03207 Mdot
.2285 .03206 Mdot
.2285 .03206 Mdot
.22851 .03205 Mdot
.22852 .03204 Mdot
.22853 .03204 Mdot
.22854 .03203 Mdot
.22855 .03203 Mdot
.22856 .03202 Mdot
.22857 .03202 Mdot
.22858 .03201 Mdot
.22859 .032 Mdot
.2286 .032 Mdot
.22861 .03199 Mdot
.22862 .03199 Mdot
.22863 .03198 Mdot
.22864 .03197 Mdot
.22865 .03197 Mdot
.22866 .03196 Mdot
.22867 .03196 Mdot
.22868 .03195 Mdot
.22869 .03195 Mdot
.2287 .03194 Mdot
.2287 .03193 Mdot
.22871 .03193 Mdot
.22872 .03192 Mdot
.22873 .03192 Mdot
.22874 .03191 Mdot
.22875 .0319 Mdot
.22876 .0319 Mdot
.22877 .03189 Mdot
.22878 .03189 Mdot
.22879 .03188 Mdot
.2288 .03188 Mdot
.22881 .03187 Mdot
.22882 .03186 Mdot
.22883 .03186 Mdot
.22884 .03185 Mdot
.22885 .03185 Mdot
.22886 .03184 Mdot
.22887 .03184 Mdot
.22888 .03183 Mdot
.22889 .03182 Mdot
.2289 .03182 Mdot
.2289 .03181 Mdot
.22891 .03181 Mdot
.22892 .0318 Mdot
.22893 .03179 Mdot
.22894 .03179 Mdot
.22895 .03178 Mdot
.22896 .03178 Mdot
.22897 .03177 Mdot
.22898 .03177 Mdot
.22899 .03176 Mdot
.229 .03175 Mdot
.22901 .03175 Mdot
.22902 .03174 Mdot
.22903 .03174 Mdot
.22904 .03173 Mdot
.22905 .03173 Mdot
.22906 .03172 Mdot
.22907 .03171 Mdot
.22908 .03171 Mdot
.22909 .0317 Mdot
.2291 .0317 Mdot
.2291 .03169 Mdot
.22911 .03168 Mdot
.22912 .03168 Mdot
.22913 .03167 Mdot
.22914 .03167 Mdot
.22915 .03166 Mdot
.22916 .03166 Mdot
.22917 .03165 Mdot
.22918 .03164 Mdot
.22919 .03164 Mdot
.2292 .03163 Mdot
.22921 .03163 Mdot
.22922 .03162 Mdot
.22923 .03162 Mdot
.22924 .03161 Mdot
.22925 .0316 Mdot
.22926 .0316 Mdot
.22927 .03159 Mdot
.22928 .03159 Mdot
.22929 .03158 Mdot
.2293 .03158 Mdot
.2293 .03157 Mdot
.22931 .03156 Mdot
.22932 .03156 Mdot
.22933 .03155 Mdot
.22934 .03155 Mdot
.22935 .03154 Mdot
.22936 .03153 Mdot
.22937 .03153 Mdot
.22938 .03152 Mdot
.22939 .03152 Mdot
.2294 .03151 Mdot
.22941 .03151 Mdot
.22942 .0315 Mdot
.22943 .03149 Mdot
.22944 .03149 Mdot
.22945 .03148 Mdot
.22946 .03148 Mdot
.22947 .03147 Mdot
.22948 .03147 Mdot
.22949 .03146 Mdot
.2295 .03145 Mdot
.2295 .03145 Mdot
.22951 .03144 Mdot
.22952 .03144 Mdot
.22953 .03143 Mdot
.22954 .03143 Mdot
.22955 .03142 Mdot
.22956 .03141 Mdot
.22957 .03141 Mdot
.22958 .0314 Mdot
.22959 .0314 Mdot
.2296 .03139 Mdot
.22961 .03139 Mdot
.22962 .03138 Mdot
.22963 .03137 Mdot
.22964 .03137 Mdot
.22965 .03136 Mdot
.22966 .03136 Mdot
.22967 .03135 Mdot
.22968 .03135 Mdot
.22969 .03134 Mdot
.2297 .03133 Mdot
.2297 .03133 Mdot
.22971 .03132 Mdot
.22972 .03132 Mdot
.22973 .03131 Mdot
.22974 .03131 Mdot
.22975 .0313 Mdot
.22976 .03129 Mdot
.22977 .03129 Mdot
.22978 .03128 Mdot
.22979 .03128 Mdot
.2298 .03127 Mdot
.22981 .03127 Mdot
.22982 .03126 Mdot
.22983 .03125 Mdot
.22984 .03125 Mdot
.22985 .03124 Mdot
.22986 .03124 Mdot
.22987 .03123 Mdot
.22988 .03123 Mdot
.22989 .03122 Mdot
.2299 .03121 Mdot
.2299 .03121 Mdot
.22991 .0312 Mdot
.22992 .0312 Mdot
.22993 .03119 Mdot
.22994 .03119 Mdot
.22995 .03118 Mdot
.22996 .03117 Mdot
.22997 .03117 Mdot
.22998 .03116 Mdot
.22999 .03116 Mdot
.23 .03115 Mdot
.23001 .03115 Mdot
.23002 .03114 Mdot
.23003 .03113 Mdot
.23004 .03113 Mdot
.23005 .03112 Mdot
.23006 .03112 Mdot
.23007 .03111 Mdot
.23008 .03111 Mdot
.23009 .0311 Mdot
.2301 .03109 Mdot
.2301 .03109 Mdot
.23011 .03108 Mdot
.23012 .03108 Mdot
.23013 .03107 Mdot
.23014 .03107 Mdot
.23015 .03106 Mdot
.23016 .03106 Mdot
.23017 .03105 Mdot
.23018 .03104 Mdot
.23019 .03104 Mdot
.2302 .03103 Mdot
.23021 .03103 Mdot
.23022 .03102 Mdot
.23023 .03102 Mdot
.23024 .03101 Mdot
.23025 .031 Mdot
.23026 .031 Mdot
.23027 .03099 Mdot
.23028 .03099 Mdot
.23029 .03098 Mdot
.2303 .03098 Mdot
.2303 .03097 Mdot
.23031 .03096 Mdot
.23032 .03096 Mdot
.23033 .03095 Mdot
.23034 .03095 Mdot
.23035 .03094 Mdot
.23036 .03094 Mdot
.23037 .03093 Mdot
.23038 .03092 Mdot
.23039 .03092 Mdot
.2304 .03091 Mdot
.23041 .03091 Mdot
.23042 .0309 Mdot
.23043 .0309 Mdot
.23044 .03089 Mdot
.23045 .03089 Mdot
.23046 .03088 Mdot
.23047 .03087 Mdot
.23048 .03087 Mdot
.23049 .03086 Mdot
.2305 .03086 Mdot
.2305 .03085 Mdot
.23051 .03085 Mdot
.23052 .03084 Mdot
.23053 .03083 Mdot
.23054 .03083 Mdot
.23055 .03082 Mdot
.23056 .03082 Mdot
.23057 .03081 Mdot
.23058 .03081 Mdot
.23059 .0308 Mdot
.2306 .0308 Mdot
.23061 .03079 Mdot
.23062 .03078 Mdot
.23063 .03078 Mdot
.23064 .03077 Mdot
.23065 .03077 Mdot
.23066 .03076 Mdot
.23067 .03076 Mdot
.23068 .03075 Mdot
.23069 .03074 Mdot
.2307 .03074 Mdot
.2307 .03073 Mdot
.23071 .03073 Mdot
.23072 .03072 Mdot
.23073 .03072 Mdot
.23074 .03071 Mdot
.23075 .03071 Mdot
.23076 .0307 Mdot
.23077 .03069 Mdot
.23078 .03069 Mdot
.23079 .03068 Mdot
.2308 .03068 Mdot
.23081 .03067 Mdot
.23082 .03067 Mdot
.23083 .03066 Mdot
.23084 .03065 Mdot
.23085 .03065 Mdot
.23086 .03064 Mdot
.23087 .03064 Mdot
.23088 .03063 Mdot
.23089 .03063 Mdot
.2309 .03062 Mdot
.2309 .03062 Mdot
.23091 .03061 Mdot
.23092 .0306 Mdot
.23093 .0306 Mdot
.23094 .03059 Mdot
.23095 .03059 Mdot
.23096 .03058 Mdot
.23097 .03058 Mdot
.23098 .03057 Mdot
.23099 .03057 Mdot
.231 .03056 Mdot
.23101 .03055 Mdot
.23102 .03055 Mdot
.23103 .03054 Mdot
.23104 .03054 Mdot
.23105 .03053 Mdot
.23106 .03053 Mdot
.23107 .03052 Mdot
.23108 .03051 Mdot
.23109 .03051 Mdot
.2311 .0305 Mdot
.2311 .0305 Mdot
.23111 .03049 Mdot
.23112 .03049 Mdot
.23113 .03048 Mdot
.23114 .03048 Mdot
.23115 .03047 Mdot
.23116 .03046 Mdot
.23117 .03046 Mdot
.23118 .03045 Mdot
.23119 .03045 Mdot
.2312 .03044 Mdot
.23121 .03044 Mdot
.23122 .03043 Mdot
.23123 .03043 Mdot
.23124 .03042 Mdot
.23125 .03041 Mdot
.23126 .03041 Mdot
.23127 .0304 Mdot
.23128 .0304 Mdot
.23129 .03039 Mdot
.2313 .03039 Mdot
.2313 .03038 Mdot
.23131 .03038 Mdot
.23132 .03037 Mdot
.23133 .03036 Mdot
.23134 .03036 Mdot
.23135 .03035 Mdot
.23136 .03035 Mdot
.23137 .03034 Mdot
.23138 .03034 Mdot
.23139 .03033 Mdot
.2314 .03033 Mdot
.23141 .03032 Mdot
.23142 .03031 Mdot
.23143 .03031 Mdot
.23144 .0303 Mdot
.23145 .0303 Mdot
.23146 .03029 Mdot
.23147 .03029 Mdot
.23148 .03028 Mdot
.23149 .03028 Mdot
.2315 .03027 Mdot
.2315 .03026 Mdot
.23151 .03026 Mdot
.23152 .03025 Mdot
.23153 .03025 Mdot
.23154 .03024 Mdot
.23155 .03024 Mdot
.23156 .03023 Mdot
.23157 .03023 Mdot
.23158 .03022 Mdot
.23159 .03021 Mdot
.2316 .03021 Mdot
.23161 .0302 Mdot
.23162 .0302 Mdot
.23163 .03019 Mdot
.23164 .03019 Mdot
.23165 .03018 Mdot
.23166 .03018 Mdot
.23167 .03017 Mdot
.23168 .03017 Mdot
.23169 .03016 Mdot
.2317 .03015 Mdot
.2317 .03015 Mdot
.23171 .03014 Mdot
.23172 .03014 Mdot
.23173 .03013 Mdot
.23174 .03013 Mdot
.23175 .03012 Mdot
.23176 .03012 Mdot
.23177 .03011 Mdot
.23178 .0301 Mdot
.23179 .0301 Mdot
.2318 .03009 Mdot
.23181 .03009 Mdot
.23182 .03008 Mdot
.23183 .03008 Mdot
.23184 .03007 Mdot
.23185 .03007 Mdot
.23186 .03006 Mdot
.23187 .03005 Mdot
.23188 .03005 Mdot
.23189 .03004 Mdot
.2319 .03004 Mdot
.2319 .03003 Mdot
.23191 .03003 Mdot
.23192 .03002 Mdot
.23193 .03002 Mdot
.23194 .03001 Mdot
.23195 .03001 Mdot
.23196 .03 Mdot
.23197 .02999 Mdot
.23198 .02999 Mdot
.23199 .02998 Mdot
.232 .02998 Mdot
.23201 .02997 Mdot
.23202 .02997 Mdot
.23203 .02996 Mdot
.23204 .02996 Mdot
.23205 .02995 Mdot
.23206 .02994 Mdot
.23207 .02994 Mdot
.23208 .02993 Mdot
.23209 .02993 Mdot
.2321 .02992 Mdot
.2321 .02992 Mdot
.23211 .02991 Mdot
.23212 .02991 Mdot
.23213 .0299 Mdot
.23214 .0299 Mdot
.23215 .02989 Mdot
.23216 .02988 Mdot
.23217 .02988 Mdot
.23218 .02987 Mdot
.23219 .02987 Mdot
.2322 .02986 Mdot
.23221 .02986 Mdot
.23222 .02985 Mdot
.23223 .02985 Mdot
.23224 .02984 Mdot
.23225 .02984 Mdot
.23226 .02983 Mdot
.23227 .02982 Mdot
.23228 .02982 Mdot
.23229 .02981 Mdot
.2323 .02981 Mdot
.2323 .0298 Mdot
.23231 .0298 Mdot
.23232 .02979 Mdot
.23233 .02979 Mdot
.23234 .02978 Mdot
.23235 .02978 Mdot
.23236 .02977 Mdot
.23237 .02976 Mdot
.23238 .02976 Mdot
.23239 .02975 Mdot
.2324 .02975 Mdot
.23241 .02974 Mdot
.23242 .02974 Mdot
.23243 .02973 Mdot
.23244 .02973 Mdot
.23245 .02972 Mdot
.23246 .02972 Mdot
.23247 .02971 Mdot
.23248 .0297 Mdot
.23249 .0297 Mdot
.2325 .02969 Mdot
.2325 .02969 Mdot
.23251 .02968 Mdot
.23252 .02968 Mdot
.23253 .02967 Mdot
.23254 .02967 Mdot
.23255 .02966 Mdot
.23256 .02966 Mdot
.23257 .02965 Mdot
.23258 .02964 Mdot
.23259 .02964 Mdot
.2326 .02963 Mdot
.23261 .02963 Mdot
.23262 .02962 Mdot
.23263 .02962 Mdot
.23264 .02961 Mdot
.23265 .02961 Mdot
.23266 .0296 Mdot
.23267 .0296 Mdot
.23268 .02959 Mdot
.23269 .02958 Mdot
.2327 .02958 Mdot
.2327 .02957 Mdot
.23271 .02957 Mdot
.23272 .02956 Mdot
.23273 .02956 Mdot
.23274 .02955 Mdot
.23275 .02955 Mdot
.23276 .02954 Mdot
.23277 .02954 Mdot
.23278 .02953 Mdot
.23279 .02953 Mdot
.2328 .02952 Mdot
.23281 .02951 Mdot
.23282 .02951 Mdot
.23283 .0295 Mdot
.23284 .0295 Mdot
.23285 .02949 Mdot
.23286 .02949 Mdot
.23287 .02948 Mdot
.23288 .02948 Mdot
.23289 .02947 Mdot
.2329 .02947 Mdot
.2329 .02946 Mdot
.23291 .02945 Mdot
.23292 .02945 Mdot
.23293 .02944 Mdot
.23294 .02944 Mdot
.23295 .02943 Mdot
.23296 .02943 Mdot
.23297 .02942 Mdot
.23298 .02942 Mdot
.23299 .02941 Mdot
.233 .02941 Mdot
.23301 .0294 Mdot
.23302 .0294 Mdot
.23303 .02939 Mdot
.23304 .02938 Mdot
.23305 .02938 Mdot
.23306 .02937 Mdot
.23307 .02937 Mdot
.23308 .02936 Mdot
.23309 .02936 Mdot
.2331 .02935 Mdot
.2331 .02935 Mdot
.23311 .02934 Mdot
.23312 .02934 Mdot
.23313 .02933 Mdot
.23314 .02933 Mdot
.23315 .02932 Mdot
.23316 .02931 Mdot
.23317 .02931 Mdot
.23318 .0293 Mdot
.23319 .0293 Mdot
.2332 .02929 Mdot
.23321 .02929 Mdot
.23322 .02928 Mdot
.23323 .02928 Mdot
.23324 .02927 Mdot
.23325 .02927 Mdot
.23326 .02926 Mdot
.23327 .02926 Mdot
.23328 .02925 Mdot
.23329 .02925 Mdot
.2333 .02924 Mdot
.2333 .02923 Mdot
.23331 .02923 Mdot
.23332 .02922 Mdot
.23333 .02922 Mdot
.23334 .02921 Mdot
.23335 .02921 Mdot
.23336 .0292 Mdot
.23337 .0292 Mdot
.23338 .02919 Mdot
.23339 .02919 Mdot
.2334 .02918 Mdot
.23341 .02918 Mdot
.23342 .02917 Mdot
.23343 .02916 Mdot
.23344 .02916 Mdot
.23345 .02915 Mdot
.23346 .02915 Mdot
.23347 .02914 Mdot
.23348 .02914 Mdot
.23349 .02913 Mdot
.2335 .02913 Mdot
.2335 .02912 Mdot
.23351 .02912 Mdot
.23352 .02911 Mdot
.23353 .02911 Mdot
.23354 .0291 Mdot
.23355 .0291 Mdot
.23356 .02909 Mdot
.23357 .02908 Mdot
.23358 .02908 Mdot
.23359 .02907 Mdot
.2336 .02907 Mdot
.23361 .02906 Mdot
.23362 .02906 Mdot
.23363 .02905 Mdot
.23364 .02905 Mdot
.23365 .02904 Mdot
.23366 .02904 Mdot
.23367 .02903 Mdot
.23368 .02903 Mdot
.23369 .02902 Mdot
.2337 .02902 Mdot
.2337 .02901 Mdot
.23371 .029 Mdot
.23372 .029 Mdot
.23373 .02899 Mdot
.23374 .02899 Mdot
.23375 .02898 Mdot
.23376 .02898 Mdot
.23377 .02897 Mdot
.23378 .02897 Mdot
.23379 .02896 Mdot
.2338 .02896 Mdot
.23381 .02895 Mdot
.23382 .02895 Mdot
.23383 .02894 Mdot
.23384 .02894 Mdot
.23385 .02893 Mdot
.23386 .02892 Mdot
.23387 .02892 Mdot
.23388 .02891 Mdot
.23389 .02891 Mdot
.2339 .0289 Mdot
.2339 .0289 Mdot
.23391 .02889 Mdot
.23392 .02889 Mdot
.23393 .02888 Mdot
.23394 .02888 Mdot
.23395 .02887 Mdot
.23396 .02887 Mdot
.23397 .02886 Mdot
.23398 .02886 Mdot
.23399 .02885 Mdot
.234 .02885 Mdot
.23401 .02884 Mdot
.23402 .02883 Mdot
.23403 .02883 Mdot
.23404 .02882 Mdot
.23405 .02882 Mdot
.23406 .02881 Mdot
.23407 .02881 Mdot
.23408 .0288 Mdot
.23409 .0288 Mdot
.2341 .02879 Mdot
.2341 .02879 Mdot
.23411 .02878 Mdot
.23412 .02878 Mdot
.23413 .02877 Mdot
.23414 .02877 Mdot
.23415 .02876 Mdot
.23416 .02876 Mdot
.23417 .02875 Mdot
.23418 .02874 Mdot
.23419 .02874 Mdot
.2342 .02873 Mdot
.23421 .02873 Mdot
.23422 .02872 Mdot
.23423 .02872 Mdot
.23424 .02871 Mdot
.23425 .02871 Mdot
.23426 .0287 Mdot
.23427 .0287 Mdot
.23428 .02869 Mdot
.23429 .02869 Mdot
.2343 .02868 Mdot
.2343 .02868 Mdot
.23431 .02867 Mdot
.23432 .02867 Mdot
.23433 .02866 Mdot
.23434 .02866 Mdot
.23435 .02865 Mdot
.23436 .02864 Mdot
.23437 .02864 Mdot
.23438 .02863 Mdot
.23439 .02863 Mdot
.2344 .02862 Mdot
.23441 .02862 Mdot
.23442 .02861 Mdot
.23443 .02861 Mdot
.23444 .0286 Mdot
.23445 .0286 Mdot
.23446 .02859 Mdot
.23447 .02859 Mdot
.23448 .02858 Mdot
.23449 .02858 Mdot
.2345 .02857 Mdot
.2345 .02857 Mdot
.23451 .02856 Mdot
.23452 .02856 Mdot
.23453 .02855 Mdot
.23454 .02855 Mdot
.23455 .02854 Mdot
.23456 .02853 Mdot
.23457 .02853 Mdot
.23458 .02852 Mdot
.23459 .02852 Mdot
.2346 .02851 Mdot
.23461 .02851 Mdot
.23462 .0285 Mdot
.23463 .0285 Mdot
.23464 .02849 Mdot
.23465 .02849 Mdot
.23466 .02848 Mdot
.23467 .02848 Mdot
.23468 .02847 Mdot
.23469 .02847 Mdot
.2347 .02846 Mdot
.2347 .02846 Mdot
.23471 .02845 Mdot
.23472 .02845 Mdot
.23473 .02844 Mdot
.23474 .02844 Mdot
.23475 .02843 Mdot
.23476 .02842 Mdot
.23477 .02842 Mdot
.23478 .02841 Mdot
.23479 .02841 Mdot
.2348 .0284 Mdot
.23481 .0284 Mdot
.23482 .02839 Mdot
.23483 .02839 Mdot
.23484 .02838 Mdot
.23485 .02838 Mdot
.23486 .02837 Mdot
.23487 .02837 Mdot
.23488 .02836 Mdot
.23489 .02836 Mdot
.2349 .02835 Mdot
.2349 .02835 Mdot
.23491 .02834 Mdot
.23492 .02834 Mdot
.23493 .02833 Mdot
.23494 .02833 Mdot
.23495 .02832 Mdot
.23496 .02832 Mdot
.23497 .02831 Mdot
.23498 .0283 Mdot
.23499 .0283 Mdot
.235 .02829 Mdot
.23501 .02829 Mdot
.23502 .02828 Mdot
.23503 .02828 Mdot
.23504 .02827 Mdot
.23505 .02827 Mdot
.23506 .02826 Mdot
.23507 .02826 Mdot
.23508 .02825 Mdot
.23509 .02825 Mdot
.2351 .02824 Mdot
.2351 .02824 Mdot
.23511 .02823 Mdot
.23512 .02823 Mdot
.23513 .02822 Mdot
.23514 .02822 Mdot
.23515 .02821 Mdot
.23516 .02821 Mdot
.23517 .0282 Mdot
.23518 .0282 Mdot
.23519 .02819 Mdot
.2352 .02819 Mdot
.23521 .02818 Mdot
.23522 .02818 Mdot
.23523 .02817 Mdot
.23524 .02816 Mdot
.23525 .02816 Mdot
.23526 .02815 Mdot
.23527 .02815 Mdot
.23528 .02814 Mdot
.23529 .02814 Mdot
.2353 .02813 Mdot
.2353 .02813 Mdot
.23531 .02812 Mdot
.23532 .02812 Mdot
.23533 .02811 Mdot
.23534 .02811 Mdot
.23535 .0281 Mdot
.23536 .0281 Mdot
.23537 .02809 Mdot
.23538 .02809 Mdot
.23539 .02808 Mdot
.2354 .02808 Mdot
.23541 .02807 Mdot
.23542 .02807 Mdot
.23543 .02806 Mdot
.23544 .02806 Mdot
.23545 .02805 Mdot
.23546 .02805 Mdot
.23547 .02804 Mdot
.23548 .02804 Mdot
.23549 .02803 Mdot
.2355 .02803 Mdot
.2355 .02802 Mdot
.23551 .02802 Mdot
.23552 .02801 Mdot
.23553 .02801 Mdot
.23554 .028 Mdot
.23555 .02799 Mdot
.23556 .02799 Mdot
.23557 .02798 Mdot
.23558 .02798 Mdot
.23559 .02797 Mdot
.2356 .02797 Mdot
.23561 .02796 Mdot
.23562 .02796 Mdot
.23563 .02795 Mdot
.23564 .02795 Mdot
.23565 .02794 Mdot
.23566 .02794 Mdot
.23567 .02793 Mdot
.23568 .02793 Mdot
.23569 .02792 Mdot
.2357 .02792 Mdot
.2357 .02791 Mdot
.23571 .02791 Mdot
.23572 .0279 Mdot
.23573 .0279 Mdot
.23574 .02789 Mdot
.23575 .02789 Mdot
.23576 .02788 Mdot
.23577 .02788 Mdot
.23578 .02787 Mdot
.23579 .02787 Mdot
.2358 .02786 Mdot
.23581 .02786 Mdot
.23582 .02785 Mdot
.23583 .02785 Mdot
.23584 .02784 Mdot
.23585 .02784 Mdot
.23586 .02783 Mdot
.23587 .02783 Mdot
.23588 .02782 Mdot
.23589 .02782 Mdot
.2359 .02781 Mdot
.2359 .02781 Mdot
.23591 .0278 Mdot
.23592 .0278 Mdot
.23593 .02779 Mdot
.23594 .02778 Mdot
.23595 .02778 Mdot
.23596 .02777 Mdot
.23597 .02777 Mdot
.23598 .02776 Mdot
.23599 .02776 Mdot
.236 .02775 Mdot
.23601 .02775 Mdot
.23602 .02774 Mdot
.23603 .02774 Mdot
.23604 .02773 Mdot
.23605 .02773 Mdot
.23606 .02772 Mdot
.23607 .02772 Mdot
.23608 .02771 Mdot
.23609 .02771 Mdot
.2361 .0277 Mdot
.2361 .0277 Mdot
.23611 .02769 Mdot
.23612 .02769 Mdot
.23613 .02768 Mdot
.23614 .02768 Mdot
.23615 .02767 Mdot
.23616 .02767 Mdot
.23617 .02766 Mdot
.23618 .02766 Mdot
.23619 .02765 Mdot
.2362 .02765 Mdot
.23621 .02764 Mdot
.23622 .02764 Mdot
.23623 .02763 Mdot
.23624 .02763 Mdot
.23625 .02762 Mdot
.23626 .02762 Mdot
.23627 .02761 Mdot
.23628 .02761 Mdot
.23629 .0276 Mdot
.2363 .0276 Mdot
.2363 .02759 Mdot
.23631 .02759 Mdot
.23632 .02758 Mdot
.23633 .02758 Mdot
.23634 .02757 Mdot
.23635 .02757 Mdot
.23636 .02756 Mdot
.23637 .02756 Mdot
.23638 .02755 Mdot
.23639 .02755 Mdot
.2364 .02754 Mdot
.23641 .02754 Mdot
.23642 .02753 Mdot
.23643 .02753 Mdot
.23644 .02752 Mdot
.23645 .02752 Mdot
.23646 .02751 Mdot
.23647 .02751 Mdot
.23648 .0275 Mdot
.23649 .0275 Mdot
.2365 .02749 Mdot
.2365 .02749 Mdot
.23651 .02748 Mdot
.23652 .02748 Mdot
.23653 .02747 Mdot
.23654 .02747 Mdot
.23655 .02746 Mdot
.23656 .02746 Mdot
.23657 .02745 Mdot
.23658 .02745 Mdot
.23659 .02744 Mdot
.2366 .02744 Mdot
.23661 .02743 Mdot
.23662 .02743 Mdot
.23663 .02742 Mdot
.23664 .02741 Mdot
.23665 .02741 Mdot
.23666 .0274 Mdot
.23667 .0274 Mdot
.23668 .02739 Mdot
.23669 .02739 Mdot
.2367 .02738 Mdot
.2367 .02738 Mdot
.23671 .02737 Mdot
.23672 .02737 Mdot
.23673 .02736 Mdot
.23674 .02736 Mdot
.23675 .02735 Mdot
.23676 .02735 Mdot
.23677 .02734 Mdot
.23678 .02734 Mdot
.23679 .02733 Mdot
.2368 .02733 Mdot
.23681 .02732 Mdot
.23682 .02732 Mdot
.23683 .02731 Mdot
.23684 .02731 Mdot
.23685 .0273 Mdot
.23686 .0273 Mdot
.23687 .02729 Mdot
.23688 .02729 Mdot
.23689 .02728 Mdot
.2369 .02728 Mdot
.2369 .02727 Mdot
.23691 .02727 Mdot
.23692 .02726 Mdot
.23693 .02726 Mdot
.23694 .02725 Mdot
.23695 .02725 Mdot
.23696 .02724 Mdot
.23697 .02724 Mdot
.23698 .02723 Mdot
.23699 .02723 Mdot
.237 .02722 Mdot
.23701 .02722 Mdot
.23702 .02721 Mdot
.23703 .02721 Mdot
.23704 .0272 Mdot
.23705 .0272 Mdot
.23706 .02719 Mdot
.23707 .02719 Mdot
.23708 .02718 Mdot
.23709 .02718 Mdot
.2371 .02717 Mdot
.2371 .02717 Mdot
.23711 .02716 Mdot
.23712 .02716 Mdot
.23713 .02715 Mdot
.23714 .02715 Mdot
.23715 .02714 Mdot
.23716 .02714 Mdot
.23717 .02713 Mdot
.23718 .02713 Mdot
.23719 .02712 Mdot
.2372 .02712 Mdot
.23721 .02711 Mdot
.23722 .02711 Mdot
.23723 .0271 Mdot
.23724 .0271 Mdot
.23725 .02709 Mdot
.23726 .02709 Mdot
.23727 .02708 Mdot
.23728 .02708 Mdot
.23729 .02707 Mdot
.2373 .02707 Mdot
.2373 .02707 Mdot
.23731 .02706 Mdot
.23732 .02706 Mdot
.23733 .02705 Mdot
.23734 .02705 Mdot
.23735 .02704 Mdot
.23736 .02704 Mdot
.23737 .02703 Mdot
.23738 .02703 Mdot
.23739 .02702 Mdot
.2374 .02702 Mdot
.23741 .02701 Mdot
.23742 .02701 Mdot
.23743 .027 Mdot
.23744 .027 Mdot
.23745 .02699 Mdot
.23746 .02699 Mdot
.23747 .02698 Mdot
.23748 .02698 Mdot
.23749 .02697 Mdot
.2375 .02697 Mdot
.2375 .02696 Mdot
.23751 .02696 Mdot
.23752 .02695 Mdot
.23753 .02695 Mdot
.23754 .02694 Mdot
.23755 .02694 Mdot
.23756 .02693 Mdot
.23757 .02693 Mdot
.23758 .02692 Mdot
.23759 .02692 Mdot
.2376 .02691 Mdot
.23761 .02691 Mdot
.23762 .0269 Mdot
.23763 .0269 Mdot
.23764 .02689 Mdot
.23765 .02689 Mdot
.23766 .02688 Mdot
.23767 .02688 Mdot
.23768 .02687 Mdot
.23769 .02687 Mdot
.2377 .02686 Mdot
.2377 .02686 Mdot
.23771 .02685 Mdot
.23772 .02685 Mdot
.23773 .02684 Mdot
.23774 .02684 Mdot
.23775 .02683 Mdot
.23776 .02683 Mdot
.23777 .02682 Mdot
.23778 .02682 Mdot
.23779 .02681 Mdot
.2378 .02681 Mdot
.23781 .0268 Mdot
.23782 .0268 Mdot
.23783 .02679 Mdot
.23784 .02679 Mdot
.23785 .02678 Mdot
.23786 .02678 Mdot
.23787 .02677 Mdot
.23788 .02677 Mdot
.23789 .02676 Mdot
.2379 .02676 Mdot
.2379 .02675 Mdot
.23791 .02675 Mdot
.23792 .02674 Mdot
.23793 .02674 Mdot
.23794 .02673 Mdot
.23795 .02673 Mdot
.23796 .02672 Mdot
.23797 .02672 Mdot
.23798 .02671 Mdot
.23799 .02671 Mdot
.238 .02671 Mdot
.23801 .0267 Mdot
.23802 .0267 Mdot
.23803 .02669 Mdot
.23804 .02669 Mdot
.23805 .02668 Mdot
.23806 .02668 Mdot
.23807 .02667 Mdot
.23808 .02667 Mdot
.23809 .02666 Mdot
.2381 .02666 Mdot
.2381 .02665 Mdot
.23811 .02665 Mdot
.23812 .02664 Mdot
.23813 .02664 Mdot
.23814 .02663 Mdot
.23815 .02663 Mdot
.23816 .02662 Mdot
.23817 .02662 Mdot
.23818 .02661 Mdot
.23819 .02661 Mdot
.2382 .0266 Mdot
.23821 .0266 Mdot
.23822 .02659 Mdot
.23823 .02659 Mdot
.23824 .02658 Mdot
.23825 .02658 Mdot
.23826 .02657 Mdot
.23827 .02657 Mdot
.23828 .02656 Mdot
.23829 .02656 Mdot
.2383 .02655 Mdot
.2383 .02655 Mdot
.23831 .02654 Mdot
.23832 .02654 Mdot
.23833 .02653 Mdot
.23834 .02653 Mdot
.23835 .02652 Mdot
.23836 .02652 Mdot
.23837 .02651 Mdot
.23838 .02651 Mdot
.23839 .02651 Mdot
.2384 .0265 Mdot
.23841 .0265 Mdot
.23842 .02649 Mdot
.23843 .02649 Mdot
.23844 .02648 Mdot
.23845 .02648 Mdot
.23846 .02647 Mdot
.23847 .02647 Mdot
.23848 .02646 Mdot
.23849 .02646 Mdot
.2385 .02645 Mdot
.2385 .02645 Mdot
.23851 .02644 Mdot
.23852 .02644 Mdot
.23853 .02643 Mdot
.23854 .02643 Mdot
.23855 .02642 Mdot
.23856 .02642 Mdot
.23857 .02641 Mdot
.23858 .02641 Mdot
.23859 .0264 Mdot
.2386 .0264 Mdot
.23861 .02639 Mdot
.23862 .02639 Mdot
.23863 .02638 Mdot
.23864 .02638 Mdot
.23865 .02637 Mdot
.23866 .02637 Mdot
.23867 .02636 Mdot
.23868 .02636 Mdot
.23869 .02636 Mdot
.2387 .02635 Mdot
.2387 .02635 Mdot
.23871 .02634 Mdot
.23872 .02634 Mdot
.23873 .02633 Mdot
.23874 .02633 Mdot
.23875 .02632 Mdot
.23876 .02632 Mdot
.23877 .02631 Mdot
.23878 .02631 Mdot
.23879 .0263 Mdot
.2388 .0263 Mdot
.23881 .02629 Mdot
.23882 .02629 Mdot
.23883 .02628 Mdot
.23884 .02628 Mdot
.23885 .02627 Mdot
.23886 .02627 Mdot
.23887 .02626 Mdot
.23888 .02626 Mdot
.23889 .02625 Mdot
.2389 .02625 Mdot
.2389 .02624 Mdot
.23891 .02624 Mdot
.23892 .02623 Mdot
.23893 .02623 Mdot
.23894 .02623 Mdot
.23895 .02622 Mdot
.23896 .02622 Mdot
.23897 .02621 Mdot
.23898 .02621 Mdot
.23899 .0262 Mdot
.239 .0262 Mdot
.23901 .02619 Mdot
.23902 .02619 Mdot
.23903 .02618 Mdot
.23904 .02618 Mdot
.23905 .02617 Mdot
.23906 .02617 Mdot
.23907 .02616 Mdot
.23908 .02616 Mdot
.23909 .02615 Mdot
.2391 .02615 Mdot
.2391 .02614 Mdot
.23911 .02614 Mdot
.23912 .02613 Mdot
.23913 .02613 Mdot
.23914 .02612 Mdot
.23915 .02612 Mdot
.23916 .02611 Mdot
.23917 .02611 Mdot
.23918 .02611 Mdot
.23919 .0261 Mdot
.2392 .0261 Mdot
.23921 .02609 Mdot
.23922 .02609 Mdot
.23923 .02608 Mdot
.23924 .02608 Mdot
.23925 .02607 Mdot
.23926 .02607 Mdot
.23927 .02606 Mdot
.23928 .02606 Mdot
.23929 .02605 Mdot
.2393 .02605 Mdot
.2393 .02604 Mdot
.23931 .02604 Mdot
.23932 .02603 Mdot
.23933 .02603 Mdot
.23934 .02602 Mdot
.23935 .02602 Mdot
.23936 .02601 Mdot
.23937 .02601 Mdot
.23938 .02601 Mdot
.23939 .026 Mdot
.2394 .026 Mdot
.23941 .02599 Mdot
.23942 .02599 Mdot
.23943 .02598 Mdot
.23944 .02598 Mdot
.23945 .02597 Mdot
.23946 .02597 Mdot
.23947 .02596 Mdot
.23948 .02596 Mdot
.23949 .02595 Mdot
.2395 .02595 Mdot
.2395 .02594 Mdot
.23951 .02594 Mdot
.23952 .02593 Mdot
.23953 .02593 Mdot
.23954 .02592 Mdot
.23955 .02592 Mdot
.23956 .02592 Mdot
.23957 .02591 Mdot
.23958 .02591 Mdot
.23959 .0259 Mdot
.2396 .0259 Mdot
.23961 .02589 Mdot
.23962 .02589 Mdot
.23963 .02588 Mdot
.23964 .02588 Mdot
.23965 .02587 Mdot
.23966 .02587 Mdot
.23967 .02586 Mdot
.23968 .02586 Mdot
.23969 .02585 Mdot
.2397 .02585 Mdot
.2397 .02584 Mdot
.23971 .02584 Mdot
.23972 .02583 Mdot
.23973 .02583 Mdot
.23974 .02583 Mdot
.23975 .02582 Mdot
.23976 .02582 Mdot
.23977 .02581 Mdot
.23978 .02581 Mdot
.23979 .0258 Mdot
.2398 .0258 Mdot
.23981 .02579 Mdot
.23982 .02579 Mdot
.23983 .02578 Mdot
.23984 .02578 Mdot
.23985 .02577 Mdot
.23986 .02577 Mdot
.23987 .02576 Mdot
.23988 .02576 Mdot
.23989 .02575 Mdot
.2399 .02575 Mdot
.2399 .02575 Mdot
.23991 .02574 Mdot
.23992 .02574 Mdot
.23993 .02573 Mdot
.23994 .02573 Mdot
.23995 .02572 Mdot
.23996 .02572 Mdot
.23997 .02571 Mdot
.23998 .02571 Mdot
.23999 .0257 Mdot
.24 .0257 Mdot
.24001 .02569 Mdot
.24002 .02569 Mdot
.24003 .02568 Mdot
.24004 .02568 Mdot
.24005 .02567 Mdot
.24006 .02567 Mdot
.24007 .02567 Mdot
.24008 .02566 Mdot
.24009 .02566 Mdot
.2401 .02565 Mdot
.2401 .02565 Mdot
.24011 .02564 Mdot
.24012 .02564 Mdot
.24013 .02563 Mdot
.24014 .02563 Mdot
.24015 .02562 Mdot
.24016 .02562 Mdot
.24017 .02561 Mdot
.24018 .02561 Mdot
.24019 .0256 Mdot
.2402 .0256 Mdot
.24021 .0256 Mdot
.24022 .02559 Mdot
.24023 .02559 Mdot
.24024 .02558 Mdot
.24025 .02558 Mdot
.24026 .02557 Mdot
.24027 .02557 Mdot
.24028 .02556 Mdot
.24029 .02556 Mdot
.2403 .02555 Mdot
.2403 .02555 Mdot
.24031 .02554 Mdot
.24032 .02554 Mdot
.24033 .02553 Mdot
.24034 .02553 Mdot
.24035 .02553 Mdot
.24036 .02552 Mdot
.24037 .02552 Mdot
.24038 .02551 Mdot
.24039 .02551 Mdot
.2404 .0255 Mdot
.24041 .0255 Mdot
.24042 .02549 Mdot
.24043 .02549 Mdot
.24044 .02548 Mdot
.24045 .02548 Mdot
.24046 .02547 Mdot
.24047 .02547 Mdot
.24048 .02546 Mdot
.24049 .02546 Mdot
.2405 .02546 Mdot
.2405 .02545 Mdot
.24051 .02545 Mdot
.24052 .02544 Mdot
.24053 .02544 Mdot
.24054 .02543 Mdot
.24055 .02543 Mdot
.24056 .02542 Mdot
.24057 .02542 Mdot
.24058 .02541 Mdot
.24059 .02541 Mdot
.2406 .0254 Mdot
.24061 .0254 Mdot
.24062 .02539 Mdot
.24063 .02539 Mdot
.24064 .02539 Mdot
.24065 .02538 Mdot
.24066 .02538 Mdot
.24067 .02537 Mdot
.24068 .02537 Mdot
.24069 .02536 Mdot
.2407 .02536 Mdot
.2407 .02535 Mdot
.24071 .02535 Mdot
.24072 .02534 Mdot
.24073 .02534 Mdot
.24074 .02533 Mdot
.24075 .02533 Mdot
.24076 .02533 Mdot
.24077 .02532 Mdot
.24078 .02532 Mdot
.24079 .02531 Mdot
.2408 .02531 Mdot
.24081 .0253 Mdot
.24082 .0253 Mdot
.24083 .02529 Mdot
.24084 .02529 Mdot
.24085 .02528 Mdot
.24086 .02528 Mdot
.24087 .02527 Mdot
.24088 .02527 Mdot
.24089 .02527 Mdot
.2409 .02526 Mdot
.2409 .02526 Mdot
.24091 .02525 Mdot
.24092 .02525 Mdot
.24093 .02524 Mdot
.24094 .02524 Mdot
.24095 .02523 Mdot
.24096 .02523 Mdot
.24097 .02522 Mdot
.24098 .02522 Mdot
.24099 .02522 Mdot
.241 .02521 Mdot
.24101 .02521 Mdot
.24102 .0252 Mdot
.24103 .0252 Mdot
.24104 .02519 Mdot
.24105 .02519 Mdot
.24106 .02518 Mdot
.24107 .02518 Mdot
.24108 .02517 Mdot
.24109 .02517 Mdot
.2411 .02516 Mdot
.2411 .02516 Mdot
.24111 .02516 Mdot
.24112 .02515 Mdot
.24113 .02515 Mdot
.24114 .02514 Mdot
.24115 .02514 Mdot
.24116 .02513 Mdot
.24117 .02513 Mdot
.24118 .02512 Mdot
.24119 .02512 Mdot
.2412 .02511 Mdot
.24121 .02511 Mdot
.24122 .02511 Mdot
.24123 .0251 Mdot
.24124 .0251 Mdot
.24125 .02509 Mdot
.24126 .02509 Mdot
.24127 .02508 Mdot
.24128 .02508 Mdot
.24129 .02507 Mdot
.2413 .02507 Mdot
.2413 .02506 Mdot
.24131 .02506 Mdot
.24132 .02505 Mdot
.24133 .02505 Mdot
.24134 .02505 Mdot
.24135 .02504 Mdot
.24136 .02504 Mdot
.24137 .02503 Mdot
.24138 .02503 Mdot
.24139 .02502 Mdot
.2414 .02502 Mdot
.24141 .02501 Mdot
.24142 .02501 Mdot
.24143 .025 Mdot
.24144 .025 Mdot
.24145 .025 Mdot
.24146 .02499 Mdot
.24147 .02499 Mdot
.24148 .02498 Mdot
.24149 .02498 Mdot
.2415 .02497 Mdot
.2415 .02497 Mdot
.24151 .02496 Mdot
.24152 .02496 Mdot
.24153 .02495 Mdot
.24154 .02495 Mdot
.24155 .02495 Mdot
.24156 .02494 Mdot
.24157 .02494 Mdot
.24158 .02493 Mdot
.24159 .02493 Mdot
.2416 .02492 Mdot
.24161 .02492 Mdot
.24162 .02491 Mdot
.24163 .02491 Mdot
.24164 .0249 Mdot
.24165 .0249 Mdot
.24166 .0249 Mdot
.24167 .02489 Mdot
.24168 .02489 Mdot
.24169 .02488 Mdot
.2417 .02488 Mdot
.2417 .02487 Mdot
.24171 .02487 Mdot
.24172 .02486 Mdot
.24173 .02486 Mdot
.24174 .02486 Mdot
.24175 .02485 Mdot
.24176 .02485 Mdot
.24177 .02484 Mdot
.24178 .02484 Mdot
.24179 .02483 Mdot
.2418 .02483 Mdot
.24181 .02482 Mdot
.24182 .02482 Mdot
.24183 .02481 Mdot
.24184 .02481 Mdot
.24185 .02481 Mdot
.24186 .0248 Mdot
.24187 .0248 Mdot
.24188 .02479 Mdot
.24189 .02479 Mdot
.2419 .02478 Mdot
.2419 .02478 Mdot
.24191 .02477 Mdot
.24192 .02477 Mdot
.24193 .02476 Mdot
.24194 .02476 Mdot
.24195 .02476 Mdot
.24196 .02475 Mdot
.24197 .02475 Mdot
.24198 .02474 Mdot
.24199 .02474 Mdot
.242 .02473 Mdot
.24201 .02473 Mdot
.24202 .02472 Mdot
.24203 .02472 Mdot
.24204 .02472 Mdot
.24205 .02471 Mdot
.24206 .02471 Mdot
.24207 .0247 Mdot
.24208 .0247 Mdot
.24209 .02469 Mdot
.2421 .02469 Mdot
.2421 .02468 Mdot
.24211 .02468 Mdot
.24212 .02468 Mdot
.24213 .02467 Mdot
.24214 .02467 Mdot
.24215 .02466 Mdot
.24216 .02466 Mdot
.24217 .02465 Mdot
.24218 .02465 Mdot
.24219 .02464 Mdot
.2422 .02464 Mdot
.24221 .02463 Mdot
.24222 .02463 Mdot
.24223 .02463 Mdot
.24224 .02462 Mdot
.24225 .02462 Mdot
.24226 .02461 Mdot
.24227 .02461 Mdot
.24228 .0246 Mdot
.24229 .0246 Mdot
.2423 .02459 Mdot
.2423 .02459 Mdot
.24231 .02459 Mdot
.24232 .02458 Mdot
.24233 .02458 Mdot
.24234 .02457 Mdot
.24235 .02457 Mdot
.24236 .02456 Mdot
.24237 .02456 Mdot
.24238 .02455 Mdot
.24239 .02455 Mdot
.2424 .02455 Mdot
.24241 .02454 Mdot
.24242 .02454 Mdot
.24243 .02453 Mdot
.24244 .02453 Mdot
.24245 .02452 Mdot
.24246 .02452 Mdot
.24247 .02451 Mdot
.24248 .02451 Mdot
.24249 .02451 Mdot
.2425 .0245 Mdot
.2425 .0245 Mdot
.24251 .02449 Mdot
.24252 .02449 Mdot
.24253 .02448 Mdot
.24254 .02448 Mdot
.24255 .02447 Mdot
.24256 .02447 Mdot
.24257 .02447 Mdot
.24258 .02446 Mdot
.24259 .02446 Mdot
.2426 .02445 Mdot
.24261 .02445 Mdot
.24262 .02444 Mdot
.24263 .02444 Mdot
.24264 .02443 Mdot
.24265 .02443 Mdot
.24266 .02443 Mdot
.24267 .02442 Mdot
.24268 .02442 Mdot
.24269 .02441 Mdot
.2427 .02441 Mdot
.2427 .0244 Mdot
.24271 .0244 Mdot
.24272 .02439 Mdot
.24273 .02439 Mdot
.24274 .02439 Mdot
.24275 .02438 Mdot
.24276 .02438 Mdot
.24277 .02437 Mdot
.24278 .02437 Mdot
.24279 .02436 Mdot
.2428 .02436 Mdot
.24281 .02436 Mdot
.24282 .02435 Mdot
.24283 .02435 Mdot
.24284 .02434 Mdot
.24285 .02434 Mdot
.24286 .02433 Mdot
.24287 .02433 Mdot
.24288 .02432 Mdot
.24289 .02432 Mdot
.2429 .02432 Mdot
.2429 .02431 Mdot
.24291 .02431 Mdot
.24292 .0243 Mdot
.24293 .0243 Mdot
.24294 .02429 Mdot
.24295 .02429 Mdot
.24296 .02428 Mdot
.24297 .02428 Mdot
.24298 .02428 Mdot
.24299 .02427 Mdot
.243 .02427 Mdot
.24301 .02426 Mdot
.24302 .02426 Mdot
.24303 .02425 Mdot
.24304 .02425 Mdot
.24305 .02425 Mdot
.24306 .02424 Mdot
.24307 .02424 Mdot
.24308 .02423 Mdot
.24309 .02423 Mdot
.2431 .02422 Mdot
.2431 .02422 Mdot
.24311 .02421 Mdot
.24312 .02421 Mdot
.24313 .02421 Mdot
.24314 .0242 Mdot
.24315 .0242 Mdot
.24316 .02419 Mdot
.24317 .02419 Mdot
.24318 .02418 Mdot
.24319 .02418 Mdot
.2432 .02418 Mdot
.24321 .02417 Mdot
.24322 .02417 Mdot
.24323 .02416 Mdot
.24324 .02416 Mdot
.24325 .02415 Mdot
.24326 .02415 Mdot
.24327 .02414 Mdot
.24328 .02414 Mdot
.24329 .02414 Mdot
.2433 .02413 Mdot
.2433 .02413 Mdot
.24331 .02412 Mdot
.24332 .02412 Mdot
.24333 .02411 Mdot
.24334 .02411 Mdot
.24335 .02411 Mdot
.24336 .0241 Mdot
.24337 .0241 Mdot
.24338 .02409 Mdot
.24339 .02409 Mdot
.2434 .02408 Mdot
.24341 .02408 Mdot
.24342 .02407 Mdot
.24343 .02407 Mdot
.24344 .02407 Mdot
.24345 .02406 Mdot
.24346 .02406 Mdot
.24347 .02405 Mdot
.24348 .02405 Mdot
.24349 .02404 Mdot
.2435 .02404 Mdot
.2435 .02404 Mdot
.24351 .02403 Mdot
.24352 .02403 Mdot
.24353 .02402 Mdot
.24354 .02402 Mdot
.24355 .02401 Mdot
.24356 .02401 Mdot
.24357 .02401 Mdot
.24358 .024 Mdot
.24359 .024 Mdot
.2436 .02399 Mdot
.24361 .02399 Mdot
.24362 .02398 Mdot
.24363 .02398 Mdot
.24364 .02398 Mdot
.24365 .02397 Mdot
.24366 .02397 Mdot
.24367 .02396 Mdot
.24368 .02396 Mdot
.24369 .02395 Mdot
.2437 .02395 Mdot
.2437 .02394 Mdot
.24371 .02394 Mdot
.24372 .02394 Mdot
.24373 .02393 Mdot
.24374 .02393 Mdot
.24375 .02392 Mdot
.24376 .02392 Mdot
.24377 .02391 Mdot
.24378 .02391 Mdot
.24379 .02391 Mdot
.2438 .0239 Mdot
.24381 .0239 Mdot
.24382 .02389 Mdot
.24383 .02389 Mdot
.24384 .02388 Mdot
.24385 .02388 Mdot
.24386 .02388 Mdot
.24387 .02387 Mdot
.24388 .02387 Mdot
.24389 .02386 Mdot
.2439 .02386 Mdot
.2439 .02385 Mdot
.24391 .02385 Mdot
.24392 .02385 Mdot
.24393 .02384 Mdot
.24394 .02384 Mdot
.24395 .02383 Mdot
.24396 .02383 Mdot
.24397 .02382 Mdot
.24398 .02382 Mdot
.24399 .02382 Mdot
.244 .02381 Mdot
.24401 .02381 Mdot
.24402 .0238 Mdot
.24403 .0238 Mdot
.24404 .02379 Mdot
.24405 .02379 Mdot
.24406 .02379 Mdot
.24407 .02378 Mdot
.24408 .02378 Mdot
.24409 .02377 Mdot
.2441 .02377 Mdot
.2441 .02376 Mdot
.24411 .02376 Mdot
.24412 .02376 Mdot
.24413 .02375 Mdot
.24414 .02375 Mdot
.24415 .02374 Mdot
.24416 .02374 Mdot
.24417 .02373 Mdot
.24418 .02373 Mdot
.24419 .02373 Mdot
.2442 .02372 Mdot
.24421 .02372 Mdot
.24422 .02371 Mdot
.24423 .02371 Mdot
.24424 .0237 Mdot
.24425 .0237 Mdot
.24426 .0237 Mdot
.24427 .02369 Mdot
.24428 .02369 Mdot
.24429 .02368 Mdot
.2443 .02368 Mdot
.2443 .02367 Mdot
.24431 .02367 Mdot
.24432 .02367 Mdot
.24433 .02366 Mdot
.24434 .02366 Mdot
.24435 .02365 Mdot
.24436 .02365 Mdot
.24437 .02364 Mdot
.24438 .02364 Mdot
.24439 .02364 Mdot
.2444 .02363 Mdot
.24441 .02363 Mdot
.24442 .02362 Mdot
.24443 .02362 Mdot
.24444 .02362 Mdot
.24445 .02361 Mdot
.24446 .02361 Mdot
.24447 .0236 Mdot
.24448 .0236 Mdot
.24449 .02359 Mdot
.2445 .02359 Mdot
.2445 .02359 Mdot
.24451 .02358 Mdot
.24452 .02358 Mdot
.24453 .02357 Mdot
.24454 .02357 Mdot
.24455 .02356 Mdot
.24456 .02356 Mdot
.24457 .02356 Mdot
.24458 .02355 Mdot
.24459 .02355 Mdot
.2446 .02354 Mdot
.24461 .02354 Mdot
.24462 .02353 Mdot
.24463 .02353 Mdot
.24464 .02353 Mdot
.24465 .02352 Mdot
.24466 .02352 Mdot
.24467 .02351 Mdot
.24468 .02351 Mdot
.24469 .02351 Mdot
.2447 .0235 Mdot
.2447 .0235 Mdot
.24471 .02349 Mdot
.24472 .02349 Mdot
.24473 .02348 Mdot
.24474 .02348 Mdot
.24475 .02348 Mdot
.24476 .02347 Mdot
.24477 .02347 Mdot
.24478 .02346 Mdot
.24479 .02346 Mdot
.2448 .02345 Mdot
.24481 .02345 Mdot
.24482 .02345 Mdot
.24483 .02344 Mdot
.24484 .02344 Mdot
.24485 .02343 Mdot
.24486 .02343 Mdot
.24487 .02343 Mdot
.24488 .02342 Mdot
.24489 .02342 Mdot
.2449 .02341 Mdot
.2449 .02341 Mdot
.24491 .0234 Mdot
.24492 .0234 Mdot
.24493 .0234 Mdot
.24494 .02339 Mdot
.24495 .02339 Mdot
.24496 .02338 Mdot
.24497 .02338 Mdot
.24498 .02337 Mdot
.24499 .02337 Mdot
.245 .02337 Mdot
.24501 .02336 Mdot
.24502 .02336 Mdot
.24503 .02335 Mdot
.24504 .02335 Mdot
.24505 .02335 Mdot
.24506 .02334 Mdot
.24507 .02334 Mdot
.24508 .02333 Mdot
.24509 .02333 Mdot
.2451 .02332 Mdot
.2451 .02332 Mdot
.24511 .02332 Mdot
.24512 .02331 Mdot
.24513 .02331 Mdot
.24514 .0233 Mdot
.24515 .0233 Mdot
.24516 .0233 Mdot
.24517 .02329 Mdot
.24518 .02329 Mdot
.24519 .02328 Mdot
.2452 .02328 Mdot
.24521 .02327 Mdot
.24522 .02327 Mdot
.24523 .02327 Mdot
.24524 .02326 Mdot
.24525 .02326 Mdot
.24526 .02325 Mdot
.24527 .02325 Mdot
.24528 .02325 Mdot
.24529 .02324 Mdot
.2453 .02324 Mdot
.2453 .02323 Mdot
.24531 .02323 Mdot
.24532 .02322 Mdot
.24533 .02322 Mdot
.24534 .02322 Mdot
.24535 .02321 Mdot
.24536 .02321 Mdot
.24537 .0232 Mdot
.24538 .0232 Mdot
.24539 .0232 Mdot
.2454 .02319 Mdot
.24541 .02319 Mdot
.24542 .02318 Mdot
.24543 .02318 Mdot
.24544 .02318 Mdot
.24545 .02317 Mdot
.24546 .02317 Mdot
.24547 .02316 Mdot
.24548 .02316 Mdot
.24549 .02315 Mdot
.2455 .02315 Mdot
.2455 .02315 Mdot
.24551 .02314 Mdot
.24552 .02314 Mdot
.24553 .02313 Mdot
.24554 .02313 Mdot
.24555 .02313 Mdot
.24556 .02312 Mdot
.24557 .02312 Mdot
.24558 .02311 Mdot
.24559 .02311 Mdot
.2456 .0231 Mdot
.24561 .0231 Mdot
.24562 .0231 Mdot
.24563 .02309 Mdot
.24564 .02309 Mdot
.24565 .02308 Mdot
.24566 .02308 Mdot
.24567 .02308 Mdot
.24568 .02307 Mdot
.24569 .02307 Mdot
.2457 .02306 Mdot
.2457 .02306 Mdot
.24571 .02306 Mdot
.24572 .02305 Mdot
.24573 .02305 Mdot
.24574 .02304 Mdot
.24575 .02304 Mdot
.24576 .02303 Mdot
.24577 .02303 Mdot
.24578 .02303 Mdot
.24579 .02302 Mdot
.2458 .02302 Mdot
.24581 .02301 Mdot
.24582 .02301 Mdot
.24583 .02301 Mdot
.24584 .023 Mdot
.24585 .023 Mdot
.24586 .02299 Mdot
.24587 .02299 Mdot
.24588 .02299 Mdot
.24589 .02298 Mdot
.2459 .02298 Mdot
.2459 .02297 Mdot
.24591 .02297 Mdot
.24592 .02297 Mdot
.24593 .02296 Mdot
.24594 .02296 Mdot
.24595 .02295 Mdot
.24596 .02295 Mdot
.24597 .02294 Mdot
.24598 .02294 Mdot
.24599 .02294 Mdot
.246 .02293 Mdot
.24601 .02293 Mdot
.24602 .02292 Mdot
.24603 .02292 Mdot
.24604 .02292 Mdot
.24605 .02291 Mdot
.24606 .02291 Mdot
.24607 .0229 Mdot
.24608 .0229 Mdot
.24609 .0229 Mdot
.2461 .02289 Mdot
.2461 .02289 Mdot
.24611 .02288 Mdot
.24612 .02288 Mdot
.24613 .02288 Mdot
.24614 .02287 Mdot
.24615 .02287 Mdot
.24616 .02286 Mdot
.24617 .02286 Mdot
.24618 .02285 Mdot
.24619 .02285 Mdot
.2462 .02285 Mdot
.24621 .02284 Mdot
.24622 .02284 Mdot
.24623 .02283 Mdot
.24624 .02283 Mdot
.24625 .02283 Mdot
.24626 .02282 Mdot
.24627 .02282 Mdot
.24628 .02281 Mdot
.24629 .02281 Mdot
.2463 .02281 Mdot
.2463 .0228 Mdot
.24631 .0228 Mdot
.24632 .02279 Mdot
.24633 .02279 Mdot
.24634 .02279 Mdot
.24635 .02278 Mdot
.24636 .02278 Mdot
.24637 .02277 Mdot
.24638 .02277 Mdot
.24639 .02277 Mdot
.2464 .02276 Mdot
.24641 .02276 Mdot
.24642 .02275 Mdot
.24643 .02275 Mdot
.24644 .02275 Mdot
.24645 .02274 Mdot
.24646 .02274 Mdot
.24647 .02273 Mdot
.24648 .02273 Mdot
.24649 .02273 Mdot
.2465 .02272 Mdot
.2465 .02272 Mdot
.24651 .02271 Mdot
.24652 .02271 Mdot
.24653 .02271 Mdot
.24654 .0227 Mdot
.24655 .0227 Mdot
.24656 .02269 Mdot
.24657 .02269 Mdot
.24658 .02269 Mdot
.24659 .02268 Mdot
.2466 .02268 Mdot
.24661 .02267 Mdot
.24662 .02267 Mdot
.24663 .02267 Mdot
.24664 .02266 Mdot
.24665 .02266 Mdot
.24666 .02265 Mdot
.24667 .02265 Mdot
.24668 .02264 Mdot
.24669 .02264 Mdot
.2467 .02264 Mdot
.2467 .02263 Mdot
.24671 .02263 Mdot
.24672 .02262 Mdot
.24673 .02262 Mdot
.24674 .02262 Mdot
.24675 .02261 Mdot
.24676 .02261 Mdot
.24677 .0226 Mdot
.24678 .0226 Mdot
.24679 .0226 Mdot
.2468 .02259 Mdot
.24681 .02259 Mdot
.24682 .02258 Mdot
.24683 .02258 Mdot
.24684 .02258 Mdot
.24685 .02257 Mdot
.24686 .02257 Mdot
.24687 .02256 Mdot
.24688 .02256 Mdot
.24689 .02256 Mdot
.2469 .02255 Mdot
.2469 .02255 Mdot
.24691 .02254 Mdot
.24692 .02254 Mdot
.24693 .02254 Mdot
.24694 .02253 Mdot
.24695 .02253 Mdot
.24696 .02252 Mdot
.24697 .02252 Mdot
.24698 .02252 Mdot
.24699 .02251 Mdot
.247 .02251 Mdot
.24701 .02251 Mdot
.24702 .0225 Mdot
.24703 .0225 Mdot
.24704 .02249 Mdot
.24705 .02249 Mdot
.24706 .02249 Mdot
.24707 .02248 Mdot
.24708 .02248 Mdot
.24709 .02247 Mdot
.2471 .02247 Mdot
.2471 .02247 Mdot
.24711 .02246 Mdot
.24712 .02246 Mdot
.24713 .02245 Mdot
.24714 .02245 Mdot
.24715 .02245 Mdot
.24716 .02244 Mdot
.24717 .02244 Mdot
.24718 .02243 Mdot
.24719 .02243 Mdot
.2472 .02243 Mdot
.24721 .02242 Mdot
.24722 .02242 Mdot
.24723 .02241 Mdot
.24724 .02241 Mdot
.24725 .02241 Mdot
.24726 .0224 Mdot
.24727 .0224 Mdot
.24728 .02239 Mdot
.24729 .02239 Mdot
.2473 .02239 Mdot
.2473 .02238 Mdot
.24731 .02238 Mdot
.24732 .02237 Mdot
.24733 .02237 Mdot
.24734 .02237 Mdot
.24735 .02236 Mdot
.24736 .02236 Mdot
.24737 .02235 Mdot
.24738 .02235 Mdot
.24739 .02235 Mdot
.2474 .02234 Mdot
.24741 .02234 Mdot
.24742 .02233 Mdot
.24743 .02233 Mdot
.24744 .02233 Mdot
.24745 .02232 Mdot
.24746 .02232 Mdot
.24747 .02232 Mdot
.24748 .02231 Mdot
.24749 .02231 Mdot
.2475 .0223 Mdot
.2475 .0223 Mdot
.24751 .0223 Mdot
.24752 .02229 Mdot
.24753 .02229 Mdot
.24754 .02228 Mdot
.24755 .02228 Mdot
.24756 .02228 Mdot
.24757 .02227 Mdot
.24758 .02227 Mdot
.24759 .02226 Mdot
.2476 .02226 Mdot
.24761 .02226 Mdot
.24762 .02225 Mdot
.24763 .02225 Mdot
.24764 .02224 Mdot
.24765 .02224 Mdot
.24766 .02224 Mdot
.24767 .02223 Mdot
.24768 .02223 Mdot
.24769 .02223 Mdot
.2477 .02222 Mdot
.2477 .02222 Mdot
.24771 .02221 Mdot
.24772 .02221 Mdot
.24773 .02221 Mdot
.24774 .0222 Mdot
.24775 .0222 Mdot
.24776 .02219 Mdot
.24777 .02219 Mdot
.24778 .02219 Mdot
.24779 .02218 Mdot
.2478 .02218 Mdot
.24781 .02217 Mdot
.24782 .02217 Mdot
.24783 .02217 Mdot
.24784 .02216 Mdot
.24785 .02216 Mdot
.24786 .02215 Mdot
.24787 .02215 Mdot
.24788 .02215 Mdot
.24789 .02214 Mdot
.2479 .02214 Mdot
.2479 .02214 Mdot
.24791 .02213 Mdot
.24792 .02213 Mdot
.24793 .02212 Mdot
.24794 .02212 Mdot
.24795 .02212 Mdot
.24796 .02211 Mdot
.24797 .02211 Mdot
.24798 .0221 Mdot
.24799 .0221 Mdot
.248 .0221 Mdot
.24801 .02209 Mdot
.24802 .02209 Mdot
.24803 .02208 Mdot
.24804 .02208 Mdot
.24805 .02208 Mdot
.24806 .02207 Mdot
.24807 .02207 Mdot
.24808 .02207 Mdot
.24809 .02206 Mdot
.2481 .02206 Mdot
.2481 .02205 Mdot
.24811 .02205 Mdot
.24812 .02205 Mdot
.24813 .02204 Mdot
.24814 .02204 Mdot
.24815 .02203 Mdot
.24816 .02203 Mdot
.24817 .02203 Mdot
.24818 .02202 Mdot
.24819 .02202 Mdot
.2482 .02202 Mdot
.24821 .02201 Mdot
.24822 .02201 Mdot
.24823 .022 Mdot
.24824 .022 Mdot
.24825 .022 Mdot
.24826 .02199 Mdot
.24827 .02199 Mdot
.24828 .02198 Mdot
.24829 .02198 Mdot
.2483 .02198 Mdot
.2483 .02197 Mdot
.24831 .02197 Mdot
.24832 .02197 Mdot
.24833 .02196 Mdot
.24834 .02196 Mdot
.24835 .02195 Mdot
.24836 .02195 Mdot
.24837 .02195 Mdot
.24838 .02194 Mdot
.24839 .02194 Mdot
.2484 .02193 Mdot
.24841 .02193 Mdot
.24842 .02193 Mdot
.24843 .02192 Mdot
.24844 .02192 Mdot
.24845 .02192 Mdot
.24846 .02191 Mdot
.24847 .02191 Mdot
.24848 .0219 Mdot
.24849 .0219 Mdot
.2485 .0219 Mdot
.2485 .02189 Mdot
.24851 .02189 Mdot
.24852 .02188 Mdot
.24853 .02188 Mdot
.24854 .02188 Mdot
.24855 .02187 Mdot
.24856 .02187 Mdot
.24857 .02187 Mdot
.24858 .02186 Mdot
.24859 .02186 Mdot
.2486 .02185 Mdot
.24861 .02185 Mdot
.24862 .02185 Mdot
.24863 .02184 Mdot
.24864 .02184 Mdot
.24865 .02184 Mdot
.24866 .02183 Mdot
.24867 .02183 Mdot
.24868 .02182 Mdot
.24869 .02182 Mdot
.2487 .02182 Mdot
.2487 .02181 Mdot
.24871 .02181 Mdot
.24872 .0218 Mdot
.24873 .0218 Mdot
.24874 .0218 Mdot
.24875 .02179 Mdot
.24876 .02179 Mdot
.24877 .02179 Mdot
.24878 .02178 Mdot
.24879 .02178 Mdot
.2488 .02177 Mdot
.24881 .02177 Mdot
.24882 .02177 Mdot
.24883 .02176 Mdot
.24884 .02176 Mdot
.24885 .02176 Mdot
.24886 .02175 Mdot
.24887 .02175 Mdot
.24888 .02174 Mdot
.24889 .02174 Mdot
.2489 .02174 Mdot
.2489 .02173 Mdot
.24891 .02173 Mdot
.24892 .02173 Mdot
.24893 .02172 Mdot
.24894 .02172 Mdot
.24895 .02171 Mdot
.24896 .02171 Mdot
.24897 .02171 Mdot
.24898 .0217 Mdot
.24899 .0217 Mdot
.249 .02169 Mdot
.24901 .02169 Mdot
.24902 .02169 Mdot
.24903 .02168 Mdot
.24904 .02168 Mdot
.24905 .02168 Mdot
.24906 .02167 Mdot
.24907 .02167 Mdot
.24908 .02166 Mdot
.24909 .02166 Mdot
.2491 .02166 Mdot
.2491 .02165 Mdot
.24911 .02165 Mdot
.24912 .02165 Mdot
.24913 .02164 Mdot
.24914 .02164 Mdot
.24915 .02163 Mdot
.24916 .02163 Mdot
.24917 .02163 Mdot
.24918 .02162 Mdot
.24919 .02162 Mdot
.2492 .02162 Mdot
.24921 .02161 Mdot
.24922 .02161 Mdot
.24923 .0216 Mdot
.24924 .0216 Mdot
.24925 .0216 Mdot
.24926 .02159 Mdot
.24927 .02159 Mdot
.24928 .02159 Mdot
.24929 .02158 Mdot
.2493 .02158 Mdot
.2493 .02157 Mdot
.24931 .02157 Mdot
.24932 .02157 Mdot
.24933 .02156 Mdot
.24934 .02156 Mdot
.24935 .02156 Mdot
.24936 .02155 Mdot
.24937 .02155 Mdot
.24938 .02154 Mdot
.24939 .02154 Mdot
.2494 .02154 Mdot
.24941 .02153 Mdot
.24942 .02153 Mdot
.24943 .02153 Mdot
.24944 .02152 Mdot
.24945 .02152 Mdot
.24946 .02151 Mdot
.24947 .02151 Mdot
.24948 .02151 Mdot
.24949 .0215 Mdot
.2495 .0215 Mdot
.2495 .0215 Mdot
.24951 .02149 Mdot
.24952 .02149 Mdot
.24953 .02149 Mdot
.24954 .02148 Mdot
.24955 .02148 Mdot
.24956 .02147 Mdot
.24957 .02147 Mdot
.24958 .02147 Mdot
.24959 .02146 Mdot
.2496 .02146 Mdot
.24961 .02146 Mdot
.24962 .02145 Mdot
.24963 .02145 Mdot
.24964 .02144 Mdot
.24965 .02144 Mdot
.24966 .02144 Mdot
.24967 .02143 Mdot
.24968 .02143 Mdot
.24969 .02143 Mdot
.2497 .02142 Mdot
.2497 .02142 Mdot
.24971 .02141 Mdot
.24972 .02141 Mdot
.24973 .02141 Mdot
.24974 .0214 Mdot
.24975 .0214 Mdot
.24976 .0214 Mdot
.24977 .02139 Mdot
.24978 .02139 Mdot
.24979 .02139 Mdot
.2498 .02138 Mdot
.24981 .02138 Mdot
.24982 .02137 Mdot
.24983 .02137 Mdot
.24984 .02137 Mdot
.24985 .02136 Mdot
.24986 .02136 Mdot
.24987 .02136 Mdot
.24988 .02135 Mdot
.24989 .02135 Mdot
.2499 .02134 Mdot
.2499 .02134 Mdot
.24991 .02134 Mdot
.24992 .02133 Mdot
.24993 .02133 Mdot
.24994 .02133 Mdot
.24995 .02132 Mdot
.24996 .02132 Mdot
.24997 .02132 Mdot
.24998 .02131 Mdot
.24999 .02131 Mdot
.25 .0213 Mdot
.25001 .0213 Mdot
.25002 .0213 Mdot
.25003 .02129 Mdot
.25004 .02129 Mdot
.25005 .02129 Mdot
.25006 .02128 Mdot
.25007 .02128 Mdot
.25008 .02127 Mdot
.25009 .02127 Mdot
.2501 .02127 Mdot
.2501 .02126 Mdot
.25011 .02126 Mdot
.25012 .02126 Mdot
.25013 .02125 Mdot
.25014 .02125 Mdot
.25015 .02125 Mdot
.25016 .02124 Mdot
.25017 .02124 Mdot
.25018 .02123 Mdot
.25019 .02123 Mdot
.2502 .02123 Mdot
.25021 .02122 Mdot
.25022 .02122 Mdot
.25023 .02122 Mdot
.25024 .02121 Mdot
.25025 .02121 Mdot
.25026 .02121 Mdot
.25027 .0212 Mdot
.25028 .0212 Mdot
.25029 .02119 Mdot
.2503 .02119 Mdot
.2503 .02119 Mdot
.25031 .02118 Mdot
.25032 .02118 Mdot
.25033 .02118 Mdot
.25034 .02117 Mdot
.25035 .02117 Mdot
.25036 .02117 Mdot
.25037 .02116 Mdot
.25038 .02116 Mdot
.25039 .02115 Mdot
.2504 .02115 Mdot
.25041 .02115 Mdot
.25042 .02114 Mdot
.25043 .02114 Mdot
.25044 .02114 Mdot
.25045 .02113 Mdot
.25046 .02113 Mdot
.25047 .02113 Mdot
.25048 .02112 Mdot
.25049 .02112 Mdot
.2505 .02111 Mdot
.2505 .02111 Mdot
.25051 .02111 Mdot
.25052 .0211 Mdot
.25053 .0211 Mdot
.25054 .0211 Mdot
.25055 .02109 Mdot
.25056 .02109 Mdot
.25057 .02109 Mdot
.25058 .02108 Mdot
.25059 .02108 Mdot
.2506 .02107 Mdot
.25061 .02107 Mdot
.25062 .02107 Mdot
.25063 .02106 Mdot
.25064 .02106 Mdot
.25065 .02106 Mdot
.25066 .02105 Mdot
.25067 .02105 Mdot
.25068 .02105 Mdot
.25069 .02104 Mdot
.2507 .02104 Mdot
.2507 .02104 Mdot
.25071 .02103 Mdot
.25072 .02103 Mdot
.25073 .02102 Mdot
.25074 .02102 Mdot
.25075 .02102 Mdot
.25076 .02101 Mdot
.25077 .02101 Mdot
.25078 .02101 Mdot
.25079 .021 Mdot
.2508 .021 Mdot
.25081 .021 Mdot
.25082 .02099 Mdot
.25083 .02099 Mdot
.25084 .02099 Mdot
.25085 .02098 Mdot
.25086 .02098 Mdot
.25087 .02097 Mdot
.25088 .02097 Mdot
.25089 .02097 Mdot
.2509 .02096 Mdot
.2509 .02096 Mdot
.25091 .02096 Mdot
.25092 .02095 Mdot
.25093 .02095 Mdot
.25094 .02095 Mdot
.25095 .02094 Mdot
.25096 .02094 Mdot
.25097 .02094 Mdot
.25098 .02093 Mdot
.25099 .02093 Mdot
.251 .02092 Mdot
.25101 .02092 Mdot
.25102 .02092 Mdot
.25103 .02091 Mdot
.25104 .02091 Mdot
.25105 .02091 Mdot
.25106 .0209 Mdot
.25107 .0209 Mdot
.25108 .0209 Mdot
.25109 .02089 Mdot
.2511 .02089 Mdot
.2511 .02089 Mdot
.25111 .02088 Mdot
.25112 .02088 Mdot
.25113 .02087 Mdot
.25114 .02087 Mdot
.25115 .02087 Mdot
.25116 .02086 Mdot
.25117 .02086 Mdot
.25118 .02086 Mdot
.25119 .02085 Mdot
.2512 .02085 Mdot
.25121 .02085 Mdot
.25122 .02084 Mdot
.25123 .02084 Mdot
.25124 .02084 Mdot
.25125 .02083 Mdot
.25126 .02083 Mdot
.25127 .02082 Mdot
.25128 .02082 Mdot
.25129 .02082 Mdot
.2513 .02081 Mdot
.2513 .02081 Mdot
.25131 .02081 Mdot
.25132 .0208 Mdot
.25133 .0208 Mdot
.25134 .0208 Mdot
.25135 .02079 Mdot
.25136 .02079 Mdot
.25137 .02079 Mdot
.25138 .02078 Mdot
.25139 .02078 Mdot
.2514 .02078 Mdot
.25141 .02077 Mdot
.25142 .02077 Mdot
.25143 .02076 Mdot
.25144 .02076 Mdot
.25145 .02076 Mdot
.25146 .02075 Mdot
.25147 .02075 Mdot
.25148 .02075 Mdot
.25149 .02074 Mdot
.2515 .02074 Mdot
.2515 .02074 Mdot
.25151 .02073 Mdot
.25152 .02073 Mdot
.25153 .02073 Mdot
.25154 .02072 Mdot
.25155 .02072 Mdot
.25156 .02072 Mdot
.25157 .02071 Mdot
.25158 .02071 Mdot
.25159 .02071 Mdot
.2516 .0207 Mdot
.25161 .0207 Mdot
.25162 .02069 Mdot
.25163 .02069 Mdot
.25164 .02069 Mdot
.25165 .02068 Mdot
.25166 .02068 Mdot
.25167 .02068 Mdot
.25168 .02067 Mdot
.25169 .02067 Mdot
.2517 .02067 Mdot
.2517 .02066 Mdot
.25171 .02066 Mdot
.25172 .02066 Mdot
.25173 .02065 Mdot
.25174 .02065 Mdot
.25175 .02065 Mdot
.25176 .02064 Mdot
.25177 .02064 Mdot
.25178 .02064 Mdot
.25179 .02063 Mdot
.2518 .02063 Mdot
.25181 .02062 Mdot
.25182 .02062 Mdot
.25183 .02062 Mdot
.25184 .02061 Mdot
.25185 .02061 Mdot
.25186 .02061 Mdot
.25187 .0206 Mdot
.25188 .0206 Mdot
.25189 .0206 Mdot
.2519 .02059 Mdot
.2519 .02059 Mdot
.25191 .02059 Mdot
.25192 .02058 Mdot
.25193 .02058 Mdot
.25194 .02058 Mdot
.25195 .02057 Mdot
.25196 .02057 Mdot
.25197 .02057 Mdot
.25198 .02056 Mdot
.25199 .02056 Mdot
.252 .02056 Mdot
.25201 .02055 Mdot
.25202 .02055 Mdot
.25203 .02055 Mdot
.25204 .02054 Mdot
.25205 .02054 Mdot
.25206 .02053 Mdot
.25207 .02053 Mdot
.25208 .02053 Mdot
.25209 .02052 Mdot
.2521 .02052 Mdot
.2521 .02052 Mdot
.25211 .02051 Mdot
.25212 .02051 Mdot
.25213 .02051 Mdot
.25214 .0205 Mdot
.25215 .0205 Mdot
.25216 .0205 Mdot
.25217 .02049 Mdot
.25218 .02049 Mdot
.25219 .02049 Mdot
.2522 .02048 Mdot
.25221 .02048 Mdot
.25222 .02048 Mdot
.25223 .02047 Mdot
.25224 .02047 Mdot
.25225 .02047 Mdot
.25226 .02046 Mdot
.25227 .02046 Mdot
.25228 .02046 Mdot
.25229 .02045 Mdot
.2523 .02045 Mdot
.2523 .02045 Mdot
.25231 .02044 Mdot
.25232 .02044 Mdot
.25233 .02043 Mdot
.25234 .02043 Mdot
.25235 .02043 Mdot
.25236 .02042 Mdot
.25237 .02042 Mdot
.25238 .02042 Mdot
.25239 .02041 Mdot
.2524 .02041 Mdot
.25241 .02041 Mdot
.25242 .0204 Mdot
.25243 .0204 Mdot
.25244 .0204 Mdot
.25245 .02039 Mdot
.25246 .02039 Mdot
.25247 .02039 Mdot
.25248 .02038 Mdot
.25249 .02038 Mdot
.2525 .02038 Mdot
.2525 .02037 Mdot
.25251 .02037 Mdot
.25252 .02037 Mdot
.25253 .02036 Mdot
.25254 .02036 Mdot
.25255 .02036 Mdot
.25256 .02035 Mdot
.25257 .02035 Mdot
.25258 .02035 Mdot
.25259 .02034 Mdot
.2526 .02034 Mdot
.25261 .02034 Mdot
.25262 .02033 Mdot
.25263 .02033 Mdot
.25264 .02033 Mdot
.25265 .02032 Mdot
.25266 .02032 Mdot
.25267 .02032 Mdot
.25268 .02031 Mdot
.25269 .02031 Mdot
.2527 .02031 Mdot
.2527 .0203 Mdot
.25271 .0203 Mdot
.25272 .0203 Mdot
.25273 .02029 Mdot
.25274 .02029 Mdot
.25275 .02029 Mdot
.25276 .02028 Mdot
.25277 .02028 Mdot
.25278 .02028 Mdot
.25279 .02027 Mdot
.2528 .02027 Mdot
.25281 .02026 Mdot
.25282 .02026 Mdot
.25283 .02026 Mdot
.25284 .02025 Mdot
.25285 .02025 Mdot
.25286 .02025 Mdot
.25287 .02024 Mdot
.25288 .02024 Mdot
.25289 .02024 Mdot
.2529 .02023 Mdot
.2529 .02023 Mdot
.25291 .02023 Mdot
.25292 .02022 Mdot
.25293 .02022 Mdot
.25294 .02022 Mdot
.25295 .02021 Mdot
.25296 .02021 Mdot
.25297 .02021 Mdot
.25298 .0202 Mdot
.25299 .0202 Mdot
.253 .0202 Mdot
.25301 .02019 Mdot
.25302 .02019 Mdot
.25303 .02019 Mdot
.25304 .02018 Mdot
.25305 .02018 Mdot
.25306 .02018 Mdot
.25307 .02017 Mdot
.25308 .02017 Mdot
.25309 .02017 Mdot
.2531 .02016 Mdot
.2531 .02016 Mdot
.25311 .02016 Mdot
.25312 .02015 Mdot
.25313 .02015 Mdot
.25314 .02015 Mdot
.25315 .02014 Mdot
.25316 .02014 Mdot
.25317 .02014 Mdot
.25318 .02013 Mdot
.25319 .02013 Mdot
.2532 .02013 Mdot
.25321 .02012 Mdot
.25322 .02012 Mdot
.25323 .02012 Mdot
.25324 .02011 Mdot
.25325 .02011 Mdot
.25326 .02011 Mdot
.25327 .0201 Mdot
.25328 .0201 Mdot
.25329 .0201 Mdot
.2533 .02009 Mdot
.2533 .02009 Mdot
.25331 .02009 Mdot
.25332 .02008 Mdot
.25333 .02008 Mdot
.25334 .02008 Mdot
.25335 .02007 Mdot
.25336 .02007 Mdot
.25337 .02007 Mdot
.25338 .02006 Mdot
.25339 .02006 Mdot
.2534 .02006 Mdot
.25341 .02005 Mdot
.25342 .02005 Mdot
.25343 .02005 Mdot
.25344 .02004 Mdot
.25345 .02004 Mdot
.25346 .02004 Mdot
.25347 .02003 Mdot
.25348 .02003 Mdot
.25349 .02003 Mdot
.2535 .02002 Mdot
.2535 .02002 Mdot
.25351 .02002 Mdot
.25352 .02001 Mdot
.25353 .02001 Mdot
.25354 .02001 Mdot
.25355 .02 Mdot
.25356 .02 Mdot
.25357 .02 Mdot
.25358 .01999 Mdot
.25359 .01999 Mdot
.2536 .01999 Mdot
.25361 .01998 Mdot
.25362 .01998 Mdot
.25363 .01998 Mdot
.25364 .01997 Mdot
.25365 .01997 Mdot
.25366 .01997 Mdot
.25367 .01997 Mdot
.25368 .01996 Mdot
.25369 .01996 Mdot
.2537 .01996 Mdot
.2537 .01995 Mdot
.25371 .01995 Mdot
.25372 .01995 Mdot
.25373 .01994 Mdot
.25374 .01994 Mdot
.25375 .01994 Mdot
.25376 .01993 Mdot
.25377 .01993 Mdot
.25378 .01993 Mdot
.25379 .01992 Mdot
.2538 .01992 Mdot
.25381 .01992 Mdot
.25382 .01991 Mdot
.25383 .01991 Mdot
.25384 .01991 Mdot
.25385 .0199 Mdot
.25386 .0199 Mdot
.25387 .0199 Mdot
.25388 .01989 Mdot
.25389 .01989 Mdot
.2539 .01989 Mdot
.2539 .01988 Mdot
.25391 .01988 Mdot
.25392 .01988 Mdot
.25393 .01987 Mdot
.25394 .01987 Mdot
.25395 .01987 Mdot
.25396 .01986 Mdot
.25397 .01986 Mdot
.25398 .01986 Mdot
.25399 .01985 Mdot
.254 .01985 Mdot
.25401 .01985 Mdot
.25402 .01984 Mdot
.25403 .01984 Mdot
.25404 .01984 Mdot
.25405 .01983 Mdot
.25406 .01983 Mdot
.25407 .01983 Mdot
.25408 .01982 Mdot
.25409 .01982 Mdot
.2541 .01982 Mdot
.2541 .01982 Mdot
.25411 .01981 Mdot
.25412 .01981 Mdot
.25413 .01981 Mdot
.25414 .0198 Mdot
.25415 .0198 Mdot
.25416 .0198 Mdot
.25417 .01979 Mdot
.25418 .01979 Mdot
.25419 .01979 Mdot
.2542 .01978 Mdot
.25421 .01978 Mdot
.25422 .01978 Mdot
.25423 .01977 Mdot
.25424 .01977 Mdot
.25425 .01977 Mdot
.25426 .01976 Mdot
.25427 .01976 Mdot
.25428 .01976 Mdot
.25429 .01975 Mdot
.2543 .01975 Mdot
.2543 .01975 Mdot
.25431 .01974 Mdot
.25432 .01974 Mdot
.25433 .01974 Mdot
.25434 .01973 Mdot
.25435 .01973 Mdot
.25436 .01973 Mdot
.25437 .01972 Mdot
.25438 .01972 Mdot
.25439 .01972 Mdot
.2544 .01972 Mdot
.25441 .01971 Mdot
.25442 .01971 Mdot
.25443 .01971 Mdot
.25444 .0197 Mdot
.25445 .0197 Mdot
.25446 .0197 Mdot
.25447 .01969 Mdot
.25448 .01969 Mdot
.25449 .01969 Mdot
.2545 .01968 Mdot
.2545 .01968 Mdot
.25451 .01968 Mdot
.25452 .01967 Mdot
.25453 .01967 Mdot
.25454 .01967 Mdot
.25455 .01966 Mdot
.25456 .01966 Mdot
.25457 .01966 Mdot
.25458 .01965 Mdot
.25459 .01965 Mdot
.2546 .01965 Mdot
.25461 .01964 Mdot
.25462 .01964 Mdot
.25463 .01964 Mdot
.25464 .01964 Mdot
.25465 .01963 Mdot
.25466 .01963 Mdot
.25467 .01963 Mdot
.25468 .01962 Mdot
.25469 .01962 Mdot
.2547 .01962 Mdot
.2547 .01961 Mdot
.25471 .01961 Mdot
.25472 .01961 Mdot
.25473 .0196 Mdot
.25474 .0196 Mdot
.25475 .0196 Mdot
.25476 .01959 Mdot
.25477 .01959 Mdot
.25478 .01959 Mdot
.25479 .01958 Mdot
.2548 .01958 Mdot
.25481 .01958 Mdot
.25482 .01957 Mdot
.25483 .01957 Mdot
.25484 .01957 Mdot
.25485 .01957 Mdot
.25486 .01956 Mdot
.25487 .01956 Mdot
.25488 .01956 Mdot
.25489 .01955 Mdot
.2549 .01955 Mdot
.2549 .01955 Mdot
.25491 .01954 Mdot
.25492 .01954 Mdot
.25493 .01954 Mdot
.25494 .01953 Mdot
.25495 .01953 Mdot
.25496 .01953 Mdot
.25497 .01952 Mdot
.25498 .01952 Mdot
.25499 .01952 Mdot
.255 .01951 Mdot
.25501 .01951 Mdot
.25502 .01951 Mdot
.25503 .01951 Mdot
.25504 .0195 Mdot
.25505 .0195 Mdot
.25506 .0195 Mdot
.25507 .01949 Mdot
.25508 .01949 Mdot
.25509 .01949 Mdot
.2551 .01948 Mdot
.2551 .01948 Mdot
.25511 .01948 Mdot
.25512 .01947 Mdot
.25513 .01947 Mdot
.25514 .01947 Mdot
.25515 .01946 Mdot
.25516 .01946 Mdot
.25517 .01946 Mdot
.25518 .01946 Mdot
.25519 .01945 Mdot
.2552 .01945 Mdot
.25521 .01945 Mdot
.25522 .01944 Mdot
.25523 .01944 Mdot
.25524 .01944 Mdot
.25525 .01943 Mdot
.25526 .01943 Mdot
.25527 .01943 Mdot
.25528 .01942 Mdot
.25529 .01942 Mdot
.2553 .01942 Mdot
.2553 .01941 Mdot
.25531 .01941 Mdot
.25532 .01941 Mdot
.25533 .01941 Mdot
.25534 .0194 Mdot
.25535 .0194 Mdot
.25536 .0194 Mdot
.25537 .01939 Mdot
.25538 .01939 Mdot
.25539 .01939 Mdot
.2554 .01938 Mdot
.25541 .01938 Mdot
.25542 .01938 Mdot
.25543 .01937 Mdot
.25544 .01937 Mdot
.25545 .01937 Mdot
.25546 .01937 Mdot
.25547 .01936 Mdot
.25548 .01936 Mdot
.25549 .01936 Mdot
.2555 .01935 Mdot
.2555 .01935 Mdot
.25551 .01935 Mdot
.25552 .01934 Mdot
.25553 .01934 Mdot
.25554 .01934 Mdot
.25555 .01933 Mdot
.25556 .01933 Mdot
.25557 .01933 Mdot
.25558 .01932 Mdot
.25559 .01932 Mdot
.2556 .01932 Mdot
.25561 .01932 Mdot
.25562 .01931 Mdot
.25563 .01931 Mdot
.25564 .01931 Mdot
.25565 .0193 Mdot
.25566 .0193 Mdot
.25567 .0193 Mdot
.25568 .01929 Mdot
.25569 .01929 Mdot
.2557 .01929 Mdot
.2557 .01928 Mdot
.25571 .01928 Mdot
.25572 .01928 Mdot
.25573 .01928 Mdot
.25574 .01927 Mdot
.25575 .01927 Mdot
.25576 .01927 Mdot
.25577 .01926 Mdot
.25578 .01926 Mdot
.25579 .01926 Mdot
.2558 .01925 Mdot
.25581 .01925 Mdot
.25582 .01925 Mdot
.25583 .01925 Mdot
.25584 .01924 Mdot
.25585 .01924 Mdot
.25586 .01924 Mdot
.25587 .01923 Mdot
.25588 .01923 Mdot
.25589 .01923 Mdot
.2559 .01922 Mdot
.2559 .01922 Mdot
.25591 .01922 Mdot
.25592 .01921 Mdot
.25593 .01921 Mdot
.25594 .01921 Mdot
.25595 .01921 Mdot
.25596 .0192 Mdot
.25597 .0192 Mdot
.25598 .0192 Mdot
.25599 .01919 Mdot
.256 .01919 Mdot
.25601 .01919 Mdot
.25602 .01918 Mdot
.25603 .01918 Mdot
.25604 .01918 Mdot
.25605 .01917 Mdot
.25606 .01917 Mdot
.25607 .01917 Mdot
.25608 .01917 Mdot
.25609 .01916 Mdot
.2561 .01916 Mdot
.2561 .01916 Mdot
.25611 .01915 Mdot
.25612 .01915 Mdot
.25613 .01915 Mdot
.25614 .01914 Mdot
.25615 .01914 Mdot
.25616 .01914 Mdot
.25617 .01914 Mdot
.25618 .01913 Mdot
.25619 .01913 Mdot
.2562 .01913 Mdot
.25621 .01912 Mdot
.25622 .01912 Mdot
.25623 .01912 Mdot
.25624 .01911 Mdot
.25625 .01911 Mdot
.25626 .01911 Mdot
.25627 .01911 Mdot
.25628 .0191 Mdot
.25629 .0191 Mdot
.2563 .0191 Mdot
.2563 .01909 Mdot
.25631 .01909 Mdot
.25632 .01909 Mdot
.25633 .01908 Mdot
.25634 .01908 Mdot
.25635 .01908 Mdot
.25636 .01908 Mdot
.25637 .01907 Mdot
.25638 .01907 Mdot
.25639 .01907 Mdot
.2564 .01906 Mdot
.25641 .01906 Mdot
.25642 .01906 Mdot
.25643 .01905 Mdot
.25644 .01905 Mdot
.25645 .01905 Mdot
.25646 .01905 Mdot
.25647 .01904 Mdot
.25648 .01904 Mdot
.25649 .01904 Mdot
.2565 .01903 Mdot
.2565 .01903 Mdot
.25651 .01903 Mdot
.25652 .01902 Mdot
.25653 .01902 Mdot
.25654 .01902 Mdot
.25655 .01902 Mdot
.25656 .01901 Mdot
.25657 .01901 Mdot
.25658 .01901 Mdot
.25659 .019 Mdot
.2566 .019 Mdot
.25661 .019 Mdot
.25662 .01899 Mdot
.25663 .01899 Mdot
.25664 .01899 Mdot
.25665 .01899 Mdot
.25666 .01898 Mdot
.25667 .01898 Mdot
.25668 .01898 Mdot
.25669 .01897 Mdot
.2567 .01897 Mdot
.2567 .01897 Mdot
.25671 .01897 Mdot
.25672 .01896 Mdot
.25673 .01896 Mdot
.25674 .01896 Mdot
.25675 .01895 Mdot
.25676 .01895 Mdot
.25677 .01895 Mdot
.25678 .01894 Mdot
.25679 .01894 Mdot
.2568 .01894 Mdot
.25681 .01894 Mdot
.25682 .01893 Mdot
.25683 .01893 Mdot
.25684 .01893 Mdot
.25685 .01892 Mdot
.25686 .01892 Mdot
.25687 .01892 Mdot
.25688 .01891 Mdot
.25689 .01891 Mdot
.2569 .01891 Mdot
.2569 .01891 Mdot
.25691 .0189 Mdot
.25692 .0189 Mdot
.25693 .0189 Mdot
.25694 .01889 Mdot
.25695 .01889 Mdot
.25696 .01889 Mdot
.25697 .01889 Mdot
.25698 .01888 Mdot
.25699 .01888 Mdot
.257 .01888 Mdot
.25701 .01887 Mdot
.25702 .01887 Mdot
.25703 .01887 Mdot
.25704 .01886 Mdot
.25705 .01886 Mdot
.25706 .01886 Mdot
.25707 .01886 Mdot
.25708 .01885 Mdot
.25709 .01885 Mdot
.2571 .01885 Mdot
.2571 .01884 Mdot
.25711 .01884 Mdot
.25712 .01884 Mdot
.25713 .01884 Mdot
.25714 .01883 Mdot
.25715 .01883 Mdot
.25716 .01883 Mdot
.25717 .01882 Mdot
.25718 .01882 Mdot
.25719 .01882 Mdot
.2572 .01882 Mdot
.25721 .01881 Mdot
.25722 .01881 Mdot
.25723 .01881 Mdot
.25724 .0188 Mdot
.25725 .0188 Mdot
.25726 .0188 Mdot
.25727 .01879 Mdot
.25728 .01879 Mdot
.25729 .01879 Mdot
.2573 .01879 Mdot
.2573 .01878 Mdot
.25731 .01878 Mdot
.25732 .01878 Mdot
.25733 .01877 Mdot
.25734 .01877 Mdot
.25735 .01877 Mdot
.25736 .01877 Mdot
.25737 .01876 Mdot
.25738 .01876 Mdot
.25739 .01876 Mdot
.2574 .01875 Mdot
.25741 .01875 Mdot
.25742 .01875 Mdot
.25743 .01875 Mdot
.25744 .01874 Mdot
.25745 .01874 Mdot
.25746 .01874 Mdot
.25747 .01873 Mdot
.25748 .01873 Mdot
.25749 .01873 Mdot
.2575 .01873 Mdot
.2575 .01872 Mdot
.25751 .01872 Mdot
.25752 .01872 Mdot
.25753 .01871 Mdot
.25754 .01871 Mdot
.25755 .01871 Mdot
.25756 .01871 Mdot
.25757 .0187 Mdot
.25758 .0187 Mdot
.25759 .0187 Mdot
.2576 .01869 Mdot
.25761 .01869 Mdot
.25762 .01869 Mdot
.25763 .01869 Mdot
.25764 .01868 Mdot
.25765 .01868 Mdot
.25766 .01868 Mdot
.25767 .01867 Mdot
.25768 .01867 Mdot
.25769 .01867 Mdot
.2577 .01867 Mdot
.2577 .01866 Mdot
.25771 .01866 Mdot
.25772 .01866 Mdot
.25773 .01865 Mdot
.25774 .01865 Mdot
.25775 .01865 Mdot
.25776 .01865 Mdot
.25777 .01864 Mdot
.25778 .01864 Mdot
.25779 .01864 Mdot
.2578 .01863 Mdot
.25781 .01863 Mdot
.25782 .01863 Mdot
.25783 .01863 Mdot
.25784 .01862 Mdot
.25785 .01862 Mdot
.25786 .01862 Mdot
.25787 .01861 Mdot
.25788 .01861 Mdot
.25789 .01861 Mdot
.2579 .01861 Mdot
.2579 .0186 Mdot
.25791 .0186 Mdot
.25792 .0186 Mdot
.25793 .01859 Mdot
.25794 .01859 Mdot
.25795 .01859 Mdot
.25796 .01859 Mdot
.25797 .01858 Mdot
.25798 .01858 Mdot
.25799 .01858 Mdot
.258 .01857 Mdot
.25801 .01857 Mdot
.25802 .01857 Mdot
.25803 .01857 Mdot
.25804 .01856 Mdot
.25805 .01856 Mdot
.25806 .01856 Mdot
.25807 .01855 Mdot
.25808 .01855 Mdot
.25809 .01855 Mdot
.2581 .01855 Mdot
.2581 .01854 Mdot
.25811 .01854 Mdot
.25812 .01854 Mdot
.25813 .01853 Mdot
.25814 .01853 Mdot
.25815 .01853 Mdot
.25816 .01853 Mdot
.25817 .01852 Mdot
.25818 .01852 Mdot
.25819 .01852 Mdot
.2582 .01851 Mdot
.25821 .01851 Mdot
.25822 .01851 Mdot
.25823 .01851 Mdot
.25824 .0185 Mdot
.25825 .0185 Mdot
.25826 .0185 Mdot
.25827 .0185 Mdot
.25828 .01849 Mdot
.25829 .01849 Mdot
.2583 .01849 Mdot
.2583 .01848 Mdot
.25831 .01848 Mdot
.25832 .01848 Mdot
.25833 .01848 Mdot
.25834 .01847 Mdot
.25835 .01847 Mdot
.25836 .01847 Mdot
.25837 .01846 Mdot
.25838 .01846 Mdot
.25839 .01846 Mdot
.2584 .01846 Mdot
.25841 .01845 Mdot
.25842 .01845 Mdot
.25843 .01845 Mdot
.25844 .01845 Mdot
.25845 .01844 Mdot
.25846 .01844 Mdot
.25847 .01844 Mdot
.25848 .01843 Mdot
.25849 .01843 Mdot
.2585 .01843 Mdot
.2585 .01843 Mdot
.25851 .01842 Mdot
.25852 .01842 Mdot
.25853 .01842 Mdot
.25854 .01841 Mdot
.25855 .01841 Mdot
.25856 .01841 Mdot
.25857 .01841 Mdot
.25858 .0184 Mdot
.25859 .0184 Mdot
.2586 .0184 Mdot
.25861 .0184 Mdot
.25862 .01839 Mdot
.25863 .01839 Mdot
.25864 .01839 Mdot
.25865 .01838 Mdot
.25866 .01838 Mdot
.25867 .01838 Mdot
.25868 .01838 Mdot
.25869 .01837 Mdot
.2587 .01837 Mdot
.2587 .01837 Mdot
.25871 .01836 Mdot
.25872 .01836 Mdot
.25873 .01836 Mdot
.25874 .01836 Mdot
.25875 .01835 Mdot
.25876 .01835 Mdot
.25877 .01835 Mdot
.25878 .01835 Mdot
.25879 .01834 Mdot
.2588 .01834 Mdot
.25881 .01834 Mdot
.25882 .01833 Mdot
.25883 .01833 Mdot
.25884 .01833 Mdot
.25885 .01833 Mdot
.25886 .01832 Mdot
.25887 .01832 Mdot
.25888 .01832 Mdot
.25889 .01832 Mdot
.2589 .01831 Mdot
.2589 .01831 Mdot
.25891 .01831 Mdot
.25892 .0183 Mdot
.25893 .0183 Mdot
.25894 .0183 Mdot
.25895 .0183 Mdot
.25896 .01829 Mdot
.25897 .01829 Mdot
.25898 .01829 Mdot
.25899 .01829 Mdot
.259 .01828 Mdot
.25901 .01828 Mdot
.25902 .01828 Mdot
.25903 .01827 Mdot
.25904 .01827 Mdot
.25905 .01827 Mdot
.25906 .01827 Mdot
.25907 .01826 Mdot
.25908 .01826 Mdot
.25909 .01826 Mdot
.2591 .01826 Mdot
.2591 .01825 Mdot
.25911 .01825 Mdot
.25912 .01825 Mdot
.25913 .01824 Mdot
.25914 .01824 Mdot
.25915 .01824 Mdot
.25916 .01824 Mdot
.25917 .01823 Mdot
.25918 .01823 Mdot
.25919 .01823 Mdot
.2592 .01823 Mdot
.25921 .01822 Mdot
.25922 .01822 Mdot
.25923 .01822 Mdot
.25924 .01822 Mdot
.25925 .01821 Mdot
.25926 .01821 Mdot
.25927 .01821 Mdot
.25928 .0182 Mdot
.25929 .0182 Mdot
.2593 .0182 Mdot
.2593 .0182 Mdot
.25931 .01819 Mdot
.25932 .01819 Mdot
.25933 .01819 Mdot
.25934 .01819 Mdot
.25935 .01818 Mdot
.25936 .01818 Mdot
.25937 .01818 Mdot
.25938 .01817 Mdot
.25939 .01817 Mdot
.2594 .01817 Mdot
.25941 .01817 Mdot
.25942 .01816 Mdot
.25943 .01816 Mdot
.25944 .01816 Mdot
.25945 .01816 Mdot
.25946 .01815 Mdot
.25947 .01815 Mdot
.25948 .01815 Mdot
.25949 .01815 Mdot
.2595 .01814 Mdot
.2595 .01814 Mdot
.25951 .01814 Mdot
.25952 .01813 Mdot
.25953 .01813 Mdot
.25954 .01813 Mdot
.25955 .01813 Mdot
.25956 .01812 Mdot
.25957 .01812 Mdot
.25958 .01812 Mdot
.25959 .01812 Mdot
.2596 .01811 Mdot
.25961 .01811 Mdot
.25962 .01811 Mdot
.25963 .01811 Mdot
.25964 .0181 Mdot
.25965 .0181 Mdot
.25966 .0181 Mdot
.25967 .01809 Mdot
.25968 .01809 Mdot
.25969 .01809 Mdot
.2597 .01809 Mdot
.2597 .01808 Mdot
.25971 .01808 Mdot
.25972 .01808 Mdot
.25973 .01808 Mdot
.25974 .01807 Mdot
.25975 .01807 Mdot
.25976 .01807 Mdot
.25977 .01807 Mdot
.25978 .01806 Mdot
.25979 .01806 Mdot
.2598 .01806 Mdot
.25981 .01806 Mdot
.25982 .01805 Mdot
.25983 .01805 Mdot
.25984 .01805 Mdot
.25985 .01804 Mdot
.25986 .01804 Mdot
.25987 .01804 Mdot
.25988 .01804 Mdot
.25989 .01803 Mdot
.2599 .01803 Mdot
.2599 .01803 Mdot
.25991 .01803 Mdot
.25992 .01802 Mdot
.25993 .01802 Mdot
.25994 .01802 Mdot
.25995 .01802 Mdot
.25996 .01801 Mdot
.25997 .01801 Mdot
.25998 .01801 Mdot
.25999 .01801 Mdot
.26 .018 Mdot
.26001 .018 Mdot
.26002 .018 Mdot
.26003 .01799 Mdot
.26004 .01799 Mdot
.26005 .01799 Mdot
.26006 .01799 Mdot
.26007 .01798 Mdot
.26008 .01798 Mdot
.26009 .01798 Mdot
.2601 .01798 Mdot
.2601 .01797 Mdot
.26011 .01797 Mdot
.26012 .01797 Mdot
.26013 .01797 Mdot
.26014 .01796 Mdot
.26015 .01796 Mdot
.26016 .01796 Mdot
.26017 .01796 Mdot
.26018 .01795 Mdot
.26019 .01795 Mdot
.2602 .01795 Mdot
.26021 .01795 Mdot
.26022 .01794 Mdot
.26023 .01794 Mdot
.26024 .01794 Mdot
.26025 .01794 Mdot
.26026 .01793 Mdot
.26027 .01793 Mdot
.26028 .01793 Mdot
.26029 .01792 Mdot
.2603 .01792 Mdot
.2603 .01792 Mdot
.26031 .01792 Mdot
.26032 .01791 Mdot
.26033 .01791 Mdot
.26034 .01791 Mdot
.26035 .01791 Mdot
.26036 .0179 Mdot
.26037 .0179 Mdot
.26038 .0179 Mdot
.26039 .0179 Mdot
.2604 .01789 Mdot
.26041 .01789 Mdot
.26042 .01789 Mdot
.26043 .01789 Mdot
.26044 .01788 Mdot
.26045 .01788 Mdot
.26046 .01788 Mdot
.26047 .01788 Mdot
.26048 .01787 Mdot
.26049 .01787 Mdot
.2605 .01787 Mdot
.2605 .01787 Mdot
.26051 .01786 Mdot
.26052 .01786 Mdot
.26053 .01786 Mdot
.26054 .01786 Mdot
.26055 .01785 Mdot
.26056 .01785 Mdot
.26057 .01785 Mdot
.26058 .01785 Mdot
.26059 .01784 Mdot
.2606 .01784 Mdot
.26061 .01784 Mdot
.26062 .01783 Mdot
.26063 .01783 Mdot
.26064 .01783 Mdot
.26065 .01783 Mdot
.26066 .01782 Mdot
.26067 .01782 Mdot
.26068 .01782 Mdot
.26069 .01782 Mdot
.2607 .01781 Mdot
.2607 .01781 Mdot
.26071 .01781 Mdot
.26072 .01781 Mdot
.26073 .0178 Mdot
.26074 .0178 Mdot
.26075 .0178 Mdot
.26076 .0178 Mdot
.26077 .01779 Mdot
.26078 .01779 Mdot
.26079 .01779 Mdot
.2608 .01779 Mdot
.26081 .01778 Mdot
.26082 .01778 Mdot
.26083 .01778 Mdot
.26084 .01778 Mdot
.26085 .01777 Mdot
.26086 .01777 Mdot
.26087 .01777 Mdot
.26088 .01777 Mdot
.26089 .01776 Mdot
.2609 .01776 Mdot
.2609 .01776 Mdot
.26091 .01776 Mdot
.26092 .01775 Mdot
.26093 .01775 Mdot
.26094 .01775 Mdot
.26095 .01775 Mdot
.26096 .01774 Mdot
.26097 .01774 Mdot
.26098 .01774 Mdot
.26099 .01774 Mdot
.261 .01773 Mdot
.26101 .01773 Mdot
.26102 .01773 Mdot
.26103 .01773 Mdot
.26104 .01772 Mdot
.26105 .01772 Mdot
.26106 .01772 Mdot
.26107 .01772 Mdot
.26108 .01771 Mdot
.26109 .01771 Mdot
.2611 .01771 Mdot
.2611 .01771 Mdot
.26111 .0177 Mdot
.26112 .0177 Mdot
.26113 .0177 Mdot
.26114 .0177 Mdot
.26115 .01769 Mdot
.26116 .01769 Mdot
.26117 .01769 Mdot
.26118 .01769 Mdot
.26119 .01768 Mdot
.2612 .01768 Mdot
.26121 .01768 Mdot
.26122 .01768 Mdot
.26123 .01767 Mdot
.26124 .01767 Mdot
.26125 .01767 Mdot
.26126 .01767 Mdot
.26127 .01766 Mdot
.26128 .01766 Mdot
.26129 .01766 Mdot
.2613 .01766 Mdot
.2613 .01765 Mdot
.26131 .01765 Mdot
.26132 .01765 Mdot
.26133 .01765 Mdot
.26134 .01764 Mdot
.26135 .01764 Mdot
.26136 .01764 Mdot
.26137 .01764 Mdot
.26138 .01763 Mdot
.26139 .01763 Mdot
.2614 .01763 Mdot
.26141 .01763 Mdot
.26142 .01762 Mdot
.26143 .01762 Mdot
.26144 .01762 Mdot
.26145 .01762 Mdot
.26146 .01761 Mdot
.26147 .01761 Mdot
.26148 .01761 Mdot
.26149 .01761 Mdot
.2615 .0176 Mdot
.2615 .0176 Mdot
.26151 .0176 Mdot
.26152 .0176 Mdot
.26153 .0176 Mdot
.26154 .01759 Mdot
.26155 .01759 Mdot
.26156 .01759 Mdot
.26157 .01759 Mdot
.26158 .01758 Mdot
.26159 .01758 Mdot
.2616 .01758 Mdot
.26161 .01758 Mdot
.26162 .01757 Mdot
.26163 .01757 Mdot
.26164 .01757 Mdot
.26165 .01757 Mdot
.26166 .01756 Mdot
.26167 .01756 Mdot
.26168 .01756 Mdot
.26169 .01756 Mdot
.2617 .01755 Mdot
.2617 .01755 Mdot
.26171 .01755 Mdot
.26172 .01755 Mdot
.26173 .01754 Mdot
.26174 .01754 Mdot
.26175 .01754 Mdot
.26176 .01754 Mdot
.26177 .01753 Mdot
.26178 .01753 Mdot
.26179 .01753 Mdot
.2618 .01753 Mdot
.26181 .01752 Mdot
.26182 .01752 Mdot
.26183 .01752 Mdot
.26184 .01752 Mdot
.26185 .01751 Mdot
.26186 .01751 Mdot
.26187 .01751 Mdot
.26188 .01751 Mdot
.26189 .01751 Mdot
.2619 .0175 Mdot
.2619 .0175 Mdot
.26191 .0175 Mdot
.26192 .0175 Mdot
.26193 .01749 Mdot
.26194 .01749 Mdot
.26195 .01749 Mdot
.26196 .01749 Mdot
.26197 .01748 Mdot
.26198 .01748 Mdot
.26199 .01748 Mdot
.262 .01748 Mdot
.26201 .01747 Mdot
.26202 .01747 Mdot
.26203 .01747 Mdot
.26204 .01747 Mdot
.26205 .01746 Mdot
.26206 .01746 Mdot
.26207 .01746 Mdot
.26208 .01746 Mdot
.26209 .01745 Mdot
.2621 .01745 Mdot
.2621 .01745 Mdot
.26211 .01745 Mdot
.26212 .01745 Mdot
.26213 .01744 Mdot
.26214 .01744 Mdot
.26215 .01744 Mdot
.26216 .01744 Mdot
.26217 .01743 Mdot
.26218 .01743 Mdot
.26219 .01743 Mdot
.2622 .01743 Mdot
.26221 .01742 Mdot
.26222 .01742 Mdot
.26223 .01742 Mdot
.26224 .01742 Mdot
.26225 .01741 Mdot
.26226 .01741 Mdot
.26227 .01741 Mdot
.26228 .01741 Mdot
.26229 .0174 Mdot
.2623 .0174 Mdot
.2623 .0174 Mdot
.26231 .0174 Mdot
.26232 .0174 Mdot
.26233 .01739 Mdot
.26234 .01739 Mdot
.26235 .01739 Mdot
.26236 .01739 Mdot
.26237 .01738 Mdot
.26238 .01738 Mdot
.26239 .01738 Mdot
.2624 .01738 Mdot
.26241 .01737 Mdot
.26242 .01737 Mdot
.26243 .01737 Mdot
.26244 .01737 Mdot
.26245 .01736 Mdot
.26246 .01736 Mdot
.26247 .01736 Mdot
.26248 .01736 Mdot
.26249 .01736 Mdot
.2625 .01735 Mdot
.2625 .01735 Mdot
.26251 .01735 Mdot
.26252 .01735 Mdot
.26253 .01734 Mdot
.26254 .01734 Mdot
.26255 .01734 Mdot
.26256 .01734 Mdot
.26257 .01733 Mdot
.26258 .01733 Mdot
.26259 .01733 Mdot
.2626 .01733 Mdot
.26261 .01732 Mdot
.26262 .01732 Mdot
.26263 .01732 Mdot
.26264 .01732 Mdot
.26265 .01732 Mdot
.26266 .01731 Mdot
.26267 .01731 Mdot
.26268 .01731 Mdot
.26269 .01731 Mdot
.2627 .0173 Mdot
.2627 .0173 Mdot
.26271 .0173 Mdot
.26272 .0173 Mdot
.26273 .01729 Mdot
.26274 .01729 Mdot
.26275 .01729 Mdot
.26276 .01729 Mdot
.26277 .01729 Mdot
.26278 .01728 Mdot
.26279 .01728 Mdot
.2628 .01728 Mdot
.26281 .01728 Mdot
.26282 .01727 Mdot
.26283 .01727 Mdot
.26284 .01727 Mdot
.26285 .01727 Mdot
.26286 .01726 Mdot
.26287 .01726 Mdot
.26288 .01726 Mdot
.26289 .01726 Mdot
.2629 .01726 Mdot
.2629 .01725 Mdot
.26291 .01725 Mdot
.26292 .01725 Mdot
.26293 .01725 Mdot
.26294 .01724 Mdot
.26295 .01724 Mdot
.26296 .01724 Mdot
.26297 .01724 Mdot
.26298 .01723 Mdot
.26299 .01723 Mdot
.263 .01723 Mdot
.26301 .01723 Mdot
.26302 .01723 Mdot
.26303 .01722 Mdot
.26304 .01722 Mdot
.26305 .01722 Mdot
.26306 .01722 Mdot
.26307 .01721 Mdot
.26308 .01721 Mdot
.26309 .01721 Mdot
.2631 .01721 Mdot
.2631 .0172 Mdot
.26311 .0172 Mdot
.26312 .0172 Mdot
.26313 .0172 Mdot
.26314 .0172 Mdot
.26315 .01719 Mdot
.26316 .01719 Mdot
.26317 .01719 Mdot
.26318 .01719 Mdot
.26319 .01718 Mdot
.2632 .01718 Mdot
.26321 .01718 Mdot
.26322 .01718 Mdot
.26323 .01718 Mdot
.26324 .01717 Mdot
.26325 .01717 Mdot
.26326 .01717 Mdot
.26327 .01717 Mdot
.26328 .01716 Mdot
.26329 .01716 Mdot
.2633 .01716 Mdot
.2633 .01716 Mdot
.26331 .01715 Mdot
.26332 .01715 Mdot
.26333 .01715 Mdot
.26334 .01715 Mdot
.26335 .01715 Mdot
.26336 .01714 Mdot
.26337 .01714 Mdot
.26338 .01714 Mdot
.26339 .01714 Mdot
.2634 .01713 Mdot
.26341 .01713 Mdot
.26342 .01713 Mdot
.26343 .01713 Mdot
.26344 .01713 Mdot
.26345 .01712 Mdot
.26346 .01712 Mdot
.26347 .01712 Mdot
.26348 .01712 Mdot
.26349 .01711 Mdot
.2635 .01711 Mdot
.2635 .01711 Mdot
.26351 .01711 Mdot
.26352 .01711 Mdot
.26353 .0171 Mdot
.26354 .0171 Mdot
.26355 .0171 Mdot
.26356 .0171 Mdot
.26357 .01709 Mdot
.26358 .01709 Mdot
.26359 .01709 Mdot
.2636 .01709 Mdot
.26361 .01709 Mdot
.26362 .01708 Mdot
.26363 .01708 Mdot
.26364 .01708 Mdot
.26365 .01708 Mdot
.26366 .01707 Mdot
.26367 .01707 Mdot
.26368 .01707 Mdot
.26369 .01707 Mdot
.2637 .01707 Mdot
.2637 .01706 Mdot
.26371 .01706 Mdot
.26372 .01706 Mdot
.26373 .01706 Mdot
.26374 .01705 Mdot
.26375 .01705 Mdot
.26376 .01705 Mdot
.26377 .01705 Mdot
.26378 .01705 Mdot
.26379 .01704 Mdot
.2638 .01704 Mdot
.26381 .01704 Mdot
.26382 .01704 Mdot
.26383 .01703 Mdot
.26384 .01703 Mdot
.26385 .01703 Mdot
.26386 .01703 Mdot
.26387 .01703 Mdot
.26388 .01702 Mdot
.26389 .01702 Mdot
.2639 .01702 Mdot
.2639 .01702 Mdot
.26391 .01701 Mdot
.26392 .01701 Mdot
.26393 .01701 Mdot
.26394 .01701 Mdot
.26395 .01701 Mdot
.26396 .017 Mdot
.26397 .017 Mdot
.26398 .017 Mdot
.26399 .017 Mdot
.264 .01699 Mdot
.26401 .01699 Mdot
.26402 .01699 Mdot
.26403 .01699 Mdot
.26404 .01699 Mdot
.26405 .01698 Mdot
.26406 .01698 Mdot
.26407 .01698 Mdot
.26408 .01698 Mdot
.26409 .01698 Mdot
.2641 .01697 Mdot
.2641 .01697 Mdot
.26411 .01697 Mdot
.26412 .01697 Mdot
.26413 .01696 Mdot
.26414 .01696 Mdot
.26415 .01696 Mdot
.26416 .01696 Mdot
.26417 .01696 Mdot
.26418 .01695 Mdot
.26419 .01695 Mdot
.2642 .01695 Mdot
.26421 .01695 Mdot
.26422 .01694 Mdot
.26423 .01694 Mdot
.26424 .01694 Mdot
.26425 .01694 Mdot
.26426 .01694 Mdot
.26427 .01693 Mdot
.26428 .01693 Mdot
.26429 .01693 Mdot
.2643 .01693 Mdot
.2643 .01693 Mdot
.26431 .01692 Mdot
.26432 .01692 Mdot
.26433 .01692 Mdot
.26434 .01692 Mdot
.26435 .01691 Mdot
.26436 .01691 Mdot
.26437 .01691 Mdot
.26438 .01691 Mdot
.26439 .01691 Mdot
.2644 .0169 Mdot
.26441 .0169 Mdot
.26442 .0169 Mdot
.26443 .0169 Mdot
.26444 .0169 Mdot
.26445 .01689 Mdot
.26446 .01689 Mdot
.26447 .01689 Mdot
.26448 .01689 Mdot
.26449 .01688 Mdot
.2645 .01688 Mdot
.2645 .01688 Mdot
.26451 .01688 Mdot
.26452 .01688 Mdot
.26453 .01687 Mdot
.26454 .01687 Mdot
.26455 .01687 Mdot
.26456 .01687 Mdot
.26457 .01687 Mdot
.26458 .01686 Mdot
.26459 .01686 Mdot
.2646 .01686 Mdot
.26461 .01686 Mdot
.26462 .01686 Mdot
.26463 .01685 Mdot
.26464 .01685 Mdot
.26465 .01685 Mdot
.26466 .01685 Mdot
.26467 .01684 Mdot
.26468 .01684 Mdot
.26469 .01684 Mdot
.2647 .01684 Mdot
.2647 .01684 Mdot
.26471 .01683 Mdot
.26472 .01683 Mdot
.26473 .01683 Mdot
.26474 .01683 Mdot
.26475 .01683 Mdot
.26476 .01682 Mdot
.26477 .01682 Mdot
.26478 .01682 Mdot
.26479 .01682 Mdot
.2648 .01682 Mdot
.26481 .01681 Mdot
.26482 .01681 Mdot
.26483 .01681 Mdot
.26484 .01681 Mdot
.26485 .0168 Mdot
.26486 .0168 Mdot
.26487 .0168 Mdot
.26488 .0168 Mdot
.26489 .0168 Mdot
.2649 .01679 Mdot
.2649 .01679 Mdot
.26491 .01679 Mdot
.26492 .01679 Mdot
.26493 .01679 Mdot
.26494 .01678 Mdot
.26495 .01678 Mdot
.26496 .01678 Mdot
.26497 .01678 Mdot
.26498 .01678 Mdot
.26499 .01677 Mdot
.265 .01677 Mdot
.26501 .01677 Mdot
.26502 .01677 Mdot
.26503 .01677 Mdot
.26504 .01676 Mdot
.26505 .01676 Mdot
.26506 .01676 Mdot
.26507 .01676 Mdot
.26508 .01675 Mdot
.26509 .01675 Mdot
.2651 .01675 Mdot
.2651 .01675 Mdot
.26511 .01675 Mdot
.26512 .01674 Mdot
.26513 .01674 Mdot
.26514 .01674 Mdot
.26515 .01674 Mdot
.26516 .01674 Mdot
.26517 .01673 Mdot
.26518 .01673 Mdot
.26519 .01673 Mdot
.2652 .01673 Mdot
.26521 .01673 Mdot
.26522 .01672 Mdot
.26523 .01672 Mdot
.26524 .01672 Mdot
.26525 .01672 Mdot
.26526 .01672 Mdot
.26527 .01671 Mdot
.26528 .01671 Mdot
.26529 .01671 Mdot
.2653 .01671 Mdot
.2653 .01671 Mdot
.26531 .0167 Mdot
.26532 .0167 Mdot
.26533 .0167 Mdot
.26534 .0167 Mdot
.26535 .0167 Mdot
.26536 .01669 Mdot
.26537 .01669 Mdot
.26538 .01669 Mdot
.26539 .01669 Mdot
.2654 .01669 Mdot
.26541 .01668 Mdot
.26542 .01668 Mdot
.26543 .01668 Mdot
.26544 .01668 Mdot
.26545 .01667 Mdot
.26546 .01667 Mdot
.26547 .01667 Mdot
.26548 .01667 Mdot
.26549 .01667 Mdot
.2655 .01666 Mdot
.2655 .01666 Mdot
.26551 .01666 Mdot
.26552 .01666 Mdot
.26553 .01666 Mdot
.26554 .01665 Mdot
.26555 .01665 Mdot
.26556 .01665 Mdot
.26557 .01665 Mdot
.26558 .01665 Mdot
.26559 .01664 Mdot
.2656 .01664 Mdot
.26561 .01664 Mdot
.26562 .01664 Mdot
.26563 .01664 Mdot
.26564 .01663 Mdot
.26565 .01663 Mdot
.26566 .01663 Mdot
.26567 .01663 Mdot
.26568 .01663 Mdot
.26569 .01662 Mdot
.2657 .01662 Mdot
.2657 .01662 Mdot
.26571 .01662 Mdot
.26572 .01662 Mdot
.26573 .01661 Mdot
.26574 .01661 Mdot
.26575 .01661 Mdot
.26576 .01661 Mdot
.26577 .01661 Mdot
.26578 .0166 Mdot
.26579 .0166 Mdot
.2658 .0166 Mdot
.26581 .0166 Mdot
.26582 .0166 Mdot
.26583 .01659 Mdot
.26584 .01659 Mdot
.26585 .01659 Mdot
.26586 .01659 Mdot
.26587 .01659 Mdot
.26588 .01658 Mdot
.26589 .01658 Mdot
.2659 .01658 Mdot
.2659 .01658 Mdot
.26591 .01658 Mdot
.26592 .01657 Mdot
.26593 .01657 Mdot
.26594 .01657 Mdot
.26595 .01657 Mdot
.26596 .01657 Mdot
.26597 .01656 Mdot
.26598 .01656 Mdot
.26599 .01656 Mdot
.266 .01656 Mdot
.26601 .01656 Mdot
.26602 .01656 Mdot
.26603 .01655 Mdot
.26604 .01655 Mdot
.26605 .01655 Mdot
.26606 .01655 Mdot
.26607 .01655 Mdot
.26608 .01654 Mdot
.26609 .01654 Mdot
.2661 .01654 Mdot
.2661 .01654 Mdot
.26611 .01654 Mdot
.26612 .01653 Mdot
.26613 .01653 Mdot
.26614 .01653 Mdot
.26615 .01653 Mdot
.26616 .01653 Mdot
.26617 .01652 Mdot
.26618 .01652 Mdot
.26619 .01652 Mdot
.2662 .01652 Mdot
.26621 .01652 Mdot
.26622 .01651 Mdot
.26623 .01651 Mdot
.26624 .01651 Mdot
.26625 .01651 Mdot
.26626 .01651 Mdot
.26627 .0165 Mdot
.26628 .0165 Mdot
.26629 .0165 Mdot
.2663 .0165 Mdot
.2663 .0165 Mdot
.26631 .01649 Mdot
.26632 .01649 Mdot
.26633 .01649 Mdot
.26634 .01649 Mdot
.26635 .01649 Mdot
.26636 .01649 Mdot
.26637 .01648 Mdot
.26638 .01648 Mdot
.26639 .01648 Mdot
.2664 .01648 Mdot
.26641 .01648 Mdot
.26642 .01647 Mdot
.26643 .01647 Mdot
.26644 .01647 Mdot
.26645 .01647 Mdot
.26646 .01647 Mdot
.26647 .01646 Mdot
.26648 .01646 Mdot
.26649 .01646 Mdot
.2665 .01646 Mdot
.2665 .01646 Mdot
.26651 .01645 Mdot
.26652 .01645 Mdot
.26653 .01645 Mdot
.26654 .01645 Mdot
.26655 .01645 Mdot
.26656 .01644 Mdot
.26657 .01644 Mdot
.26658 .01644 Mdot
.26659 .01644 Mdot
.2666 .01644 Mdot
.26661 .01644 Mdot
.26662 .01643 Mdot
.26663 .01643 Mdot
.26664 .01643 Mdot
.26665 .01643 Mdot
.26666 .01643 Mdot
.26667 .01642 Mdot
.26668 .01642 Mdot
.26669 .01642 Mdot
.2667 .01642 Mdot
.2667 .01642 Mdot
.26671 .01641 Mdot
.26672 .01641 Mdot
.26673 .01641 Mdot
.26674 .01641 Mdot
.26675 .01641 Mdot
.26676 .01641 Mdot
.26677 .0164 Mdot
.26678 .0164 Mdot
.26679 .0164 Mdot
.2668 .0164 Mdot
.26681 .0164 Mdot
.26682 .01639 Mdot
.26683 .01639 Mdot
.26684 .01639 Mdot
.26685 .01639 Mdot
.26686 .01639 Mdot
.26687 .01638 Mdot
.26688 .01638 Mdot
.26689 .01638 Mdot
.2669 .01638 Mdot
.2669 .01638 Mdot
.26691 .01637 Mdot
.26692 .01637 Mdot
.26693 .01637 Mdot
.26694 .01637 Mdot
.26695 .01637 Mdot
.26696 .01637 Mdot
.26697 .01636 Mdot
.26698 .01636 Mdot
.26699 .01636 Mdot
.267 .01636 Mdot
.26701 .01636 Mdot
.26702 .01635 Mdot
.26703 .01635 Mdot
.26704 .01635 Mdot
.26705 .01635 Mdot
.26706 .01635 Mdot
.26707 .01635 Mdot
.26708 .01634 Mdot
.26709 .01634 Mdot
.2671 .01634 Mdot
.2671 .01634 Mdot
.26711 .01634 Mdot
.26712 .01633 Mdot
.26713 .01633 Mdot
.26714 .01633 Mdot
.26715 .01633 Mdot
.26716 .01633 Mdot
.26717 .01632 Mdot
.26718 .01632 Mdot
.26719 .01632 Mdot
.2672 .01632 Mdot
.26721 .01632 Mdot
.26722 .01632 Mdot
.26723 .01631 Mdot
.26724 .01631 Mdot
.26725 .01631 Mdot
.26726 .01631 Mdot
.26727 .01631 Mdot
.26728 .0163 Mdot
.26729 .0163 Mdot
.2673 .0163 Mdot
.2673 .0163 Mdot
.26731 .0163 Mdot
.26732 .0163 Mdot
.26733 .01629 Mdot
.26734 .01629 Mdot
.26735 .01629 Mdot
.26736 .01629 Mdot
.26737 .01629 Mdot
.26738 .01628 Mdot
.26739 .01628 Mdot
.2674 .01628 Mdot
.26741 .01628 Mdot
.26742 .01628 Mdot
.26743 .01628 Mdot
.26744 .01627 Mdot
.26745 .01627 Mdot
.26746 .01627 Mdot
.26747 .01627 Mdot
.26748 .01627 Mdot
.26749 .01626 Mdot
.2675 .01626 Mdot
.2675 .01626 Mdot
.26751 .01626 Mdot
.26752 .01626 Mdot
.26753 .01626 Mdot
.26754 .01625 Mdot
.26755 .01625 Mdot
.26756 .01625 Mdot
.26757 .01625 Mdot
.26758 .01625 Mdot
.26759 .01624 Mdot
.2676 .01624 Mdot
.26761 .01624 Mdot
.26762 .01624 Mdot
.26763 .01624 Mdot
.26764 .01624 Mdot
.26765 .01623 Mdot
.26766 .01623 Mdot
.26767 .01623 Mdot
.26768 .01623 Mdot
.26769 .01623 Mdot
.2677 .01623 Mdot
.2677 .01622 Mdot
.26771 .01622 Mdot
.26772 .01622 Mdot
.26773 .01622 Mdot
.26774 .01622 Mdot
.26775 .01621 Mdot
.26776 .01621 Mdot
.26777 .01621 Mdot
.26778 .01621 Mdot
.26779 .01621 Mdot
.2678 .01621 Mdot
.26781 .0162 Mdot
.26782 .0162 Mdot
.26783 .0162 Mdot
.26784 .0162 Mdot
.26785 .0162 Mdot
.26786 .0162 Mdot
.26787 .01619 Mdot
.26788 .01619 Mdot
.26789 .01619 Mdot
.2679 .01619 Mdot
.2679 .01619 Mdot
.26791 .01618 Mdot
.26792 .01618 Mdot
.26793 .01618 Mdot
.26794 .01618 Mdot
.26795 .01618 Mdot
.26796 .01618 Mdot
.26797 .01617 Mdot
.26798 .01617 Mdot
.26799 .01617 Mdot
.268 .01617 Mdot
.26801 .01617 Mdot
.26802 .01617 Mdot
.26803 .01616 Mdot
.26804 .01616 Mdot
.26805 .01616 Mdot
.26806 .01616 Mdot
.26807 .01616 Mdot
.26808 .01615 Mdot
.26809 .01615 Mdot
.2681 .01615 Mdot
.2681 .01615 Mdot
.26811 .01615 Mdot
.26812 .01615 Mdot
.26813 .01614 Mdot
.26814 .01614 Mdot
.26815 .01614 Mdot
.26816 .01614 Mdot
.26817 .01614 Mdot
.26818 .01614 Mdot
.26819 .01613 Mdot
.2682 .01613 Mdot
.26821 .01613 Mdot
.26822 .01613 Mdot
.26823 .01613 Mdot
.26824 .01613 Mdot
.26825 .01612 Mdot
.26826 .01612 Mdot
.26827 .01612 Mdot
.26828 .01612 Mdot
.26829 .01612 Mdot
.2683 .01612 Mdot
.2683 .01611 Mdot
.26831 .01611 Mdot
.26832 .01611 Mdot
.26833 .01611 Mdot
.26834 .01611 Mdot
.26835 .0161 Mdot
.26836 .0161 Mdot
.26837 .0161 Mdot
.26838 .0161 Mdot
.26839 .0161 Mdot
.2684 .0161 Mdot
.26841 .01609 Mdot
.26842 .01609 Mdot
.26843 .01609 Mdot
.26844 .01609 Mdot
.26845 .01609 Mdot
.26846 .01609 Mdot
.26847 .01608 Mdot
.26848 .01608 Mdot
.26849 .01608 Mdot
.2685 .01608 Mdot
.2685 .01608 Mdot
.26851 .01608 Mdot
.26852 .01607 Mdot
.26853 .01607 Mdot
.26854 .01607 Mdot
.26855 .01607 Mdot
.26856 .01607 Mdot
.26857 .01607 Mdot
.26858 .01606 Mdot
.26859 .01606 Mdot
.2686 .01606 Mdot
.26861 .01606 Mdot
.26862 .01606 Mdot
.26863 .01606 Mdot
.26864 .01605 Mdot
.26865 .01605 Mdot
.26866 .01605 Mdot
.26867 .01605 Mdot
.26868 .01605 Mdot
.26869 .01605 Mdot
.2687 .01604 Mdot
.2687 .01604 Mdot
.26871 .01604 Mdot
.26872 .01604 Mdot
.26873 .01604 Mdot
.26874 .01604 Mdot
.26875 .01603 Mdot
.26876 .01603 Mdot
.26877 .01603 Mdot
.26878 .01603 Mdot
.26879 .01603 Mdot
.2688 .01603 Mdot
.26881 .01602 Mdot
.26882 .01602 Mdot
.26883 .01602 Mdot
.26884 .01602 Mdot
.26885 .01602 Mdot
.26886 .01602 Mdot
.26887 .01601 Mdot
.26888 .01601 Mdot
.26889 .01601 Mdot
.2689 .01601 Mdot
.2689 .01601 Mdot
.26891 .01601 Mdot
.26892 .016 Mdot
.26893 .016 Mdot
.26894 .016 Mdot
.26895 .016 Mdot
.26896 .016 Mdot
.26897 .016 Mdot
.26898 .01599 Mdot
.26899 .01599 Mdot
.269 .01599 Mdot
.26901 .01599 Mdot
.26902 .01599 Mdot
.26903 .01599 Mdot
.26904 .01598 Mdot
.26905 .01598 Mdot
.26906 .01598 Mdot
.26907 .01598 Mdot
.26908 .01598 Mdot
.26909 .01598 Mdot
.2691 .01597 Mdot
.2691 .01597 Mdot
.26911 .01597 Mdot
.26912 .01597 Mdot
.26913 .01597 Mdot
.26914 .01597 Mdot
.26915 .01596 Mdot
.26916 .01596 Mdot
.26917 .01596 Mdot
.26918 .01596 Mdot
.26919 .01596 Mdot
.2692 .01596 Mdot
.26921 .01596 Mdot
.26922 .01595 Mdot
.26923 .01595 Mdot
.26924 .01595 Mdot
.26925 .01595 Mdot
.26926 .01595 Mdot
.26927 .01595 Mdot
.26928 .01594 Mdot
.26929 .01594 Mdot
.2693 .01594 Mdot
.2693 .01594 Mdot
.26931 .01594 Mdot
.26932 .01594 Mdot
.26933 .01593 Mdot
.26934 .01593 Mdot
.26935 .01593 Mdot
.26936 .01593 Mdot
.26937 .01593 Mdot
.26938 .01593 Mdot
.26939 .01592 Mdot
.2694 .01592 Mdot
.26941 .01592 Mdot
.26942 .01592 Mdot
.26943 .01592 Mdot
.26944 .01592 Mdot
.26945 .01591 Mdot
.26946 .01591 Mdot
.26947 .01591 Mdot
.26948 .01591 Mdot
.26949 .01591 Mdot
.2695 .01591 Mdot
.2695 .01591 Mdot
.26951 .0159 Mdot
.26952 .0159 Mdot
.26953 .0159 Mdot
.26954 .0159 Mdot
.26955 .0159 Mdot
.26956 .0159 Mdot
.26957 .01589 Mdot
.26958 .01589 Mdot
.26959 .01589 Mdot
.2696 .01589 Mdot
.26961 .01589 Mdot
.26962 .01589 Mdot
.26963 .01588 Mdot
.26964 .01588 Mdot
.26965 .01588 Mdot
.26966 .01588 Mdot
.26967 .01588 Mdot
.26968 .01588 Mdot
.26969 .01588 Mdot
.2697 .01587 Mdot
.2697 .01587 Mdot
.26971 .01587 Mdot
.26972 .01587 Mdot
.26973 .01587 Mdot
.26974 .01587 Mdot
.26975 .01586 Mdot
.26976 .01586 Mdot
.26977 .01586 Mdot
.26978 .01586 Mdot
.26979 .01586 Mdot
.2698 .01586 Mdot
.26981 .01586 Mdot
.26982 .01585 Mdot
.26983 .01585 Mdot
.26984 .01585 Mdot
.26985 .01585 Mdot
.26986 .01585 Mdot
.26987 .01585 Mdot
.26988 .01584 Mdot
.26989 .01584 Mdot
.2699 .01584 Mdot
.2699 .01584 Mdot
.26991 .01584 Mdot
.26992 .01584 Mdot
.26993 .01584 Mdot
.26994 .01583 Mdot
.26995 .01583 Mdot
.26996 .01583 Mdot
.26997 .01583 Mdot
.26998 .01583 Mdot
.26999 .01583 Mdot
.27 .01582 Mdot
.27001 .01582 Mdot
.27002 .01582 Mdot
.27003 .01582 Mdot
.27004 .01582 Mdot
.27005 .01582 Mdot
.27006 .01582 Mdot
.27007 .01581 Mdot
.27008 .01581 Mdot
.27009 .01581 Mdot
.2701 .01581 Mdot
.2701 .01581 Mdot
.27011 .01581 Mdot
.27012 .0158 Mdot
.27013 .0158 Mdot
.27014 .0158 Mdot
.27015 .0158 Mdot
.27016 .0158 Mdot
.27017 .0158 Mdot
.27018 .0158 Mdot
.27019 .01579 Mdot
.2702 .01579 Mdot
.27021 .01579 Mdot
.27022 .01579 Mdot
.27023 .01579 Mdot
.27024 .01579 Mdot
.27025 .01578 Mdot
.27026 .01578 Mdot
.27027 .01578 Mdot
.27028 .01578 Mdot
.27029 .01578 Mdot
.2703 .01578 Mdot
.2703 .01578 Mdot
.27031 .01577 Mdot
.27032 .01577 Mdot
.27033 .01577 Mdot
.27034 .01577 Mdot
.27035 .01577 Mdot
.27036 .01577 Mdot
.27037 .01577 Mdot
.27038 .01576 Mdot
.27039 .01576 Mdot
.2704 .01576 Mdot
.27041 .01576 Mdot
.27042 .01576 Mdot
.27043 .01576 Mdot
.27044 .01576 Mdot
.27045 .01575 Mdot
.27046 .01575 Mdot
.27047 .01575 Mdot
.27048 .01575 Mdot
.27049 .01575 Mdot
.2705 .01575 Mdot
.2705 .01574 Mdot
.27051 .01574 Mdot
.27052 .01574 Mdot
.27053 .01574 Mdot
.27054 .01574 Mdot
.27055 .01574 Mdot
.27056 .01574 Mdot
.27057 .01573 Mdot
.27058 .01573 Mdot
.27059 .01573 Mdot
.2706 .01573 Mdot
.27061 .01573 Mdot
.27062 .01573 Mdot
.27063 .01573 Mdot
.27064 .01572 Mdot
.27065 .01572 Mdot
.27066 .01572 Mdot
.27067 .01572 Mdot
.27068 .01572 Mdot
.27069 .01572 Mdot
.2707 .01572 Mdot
.2707 .01571 Mdot
.27071 .01571 Mdot
.27072 .01571 Mdot
.27073 .01571 Mdot
.27074 .01571 Mdot
.27075 .01571 Mdot
.27076 .01571 Mdot
.27077 .0157 Mdot
.27078 .0157 Mdot
.27079 .0157 Mdot
.2708 .0157 Mdot
.27081 .0157 Mdot
.27082 .0157 Mdot
.27083 .0157 Mdot
.27084 .01569 Mdot
.27085 .01569 Mdot
.27086 .01569 Mdot
.27087 .01569 Mdot
.27088 .01569 Mdot
.27089 .01569 Mdot
.2709 .01569 Mdot
.2709 .01568 Mdot
.27091 .01568 Mdot
.27092 .01568 Mdot
.27093 .01568 Mdot
.27094 .01568 Mdot
.27095 .01568 Mdot
.27096 .01568 Mdot
.27097 .01567 Mdot
.27098 .01567 Mdot
.27099 .01567 Mdot
.271 .01567 Mdot
.27101 .01567 Mdot
.27102 .01567 Mdot
.27103 .01567 Mdot
.27104 .01566 Mdot
.27105 .01566 Mdot
.27106 .01566 Mdot
.27107 .01566 Mdot
.27108 .01566 Mdot
.27109 .01566 Mdot
.2711 .01566 Mdot
.2711 .01565 Mdot
.27111 .01565 Mdot
.27112 .01565 Mdot
.27113 .01565 Mdot
.27114 .01565 Mdot
.27115 .01565 Mdot
.27116 .01565 Mdot
.27117 .01564 Mdot
.27118 .01564 Mdot
.27119 .01564 Mdot
.2712 .01564 Mdot
.27121 .01564 Mdot
.27122 .01564 Mdot
.27123 .01564 Mdot
.27124 .01563 Mdot
.27125 .01563 Mdot
.27126 .01563 Mdot
.27127 .01563 Mdot
.27128 .01563 Mdot
.27129 .01563 Mdot
.2713 .01563 Mdot
.2713 .01562 Mdot
.27131 .01562 Mdot
.27132 .01562 Mdot
.27133 .01562 Mdot
.27134 .01562 Mdot
.27135 .01562 Mdot
.27136 .01562 Mdot
.27137 .01561 Mdot
.27138 .01561 Mdot
.27139 .01561 Mdot
.2714 .01561 Mdot
.27141 .01561 Mdot
.27142 .01561 Mdot
.27143 .01561 Mdot
.27144 .01561 Mdot
.27145 .0156 Mdot
.27146 .0156 Mdot
.27147 .0156 Mdot
.27148 .0156 Mdot
.27149 .0156 Mdot
.2715 .0156 Mdot
.2715 .0156 Mdot
.27151 .01559 Mdot
.27152 .01559 Mdot
.27153 .01559 Mdot
.27154 .01559 Mdot
.27155 .01559 Mdot
.27156 .01559 Mdot
.27157 .01559 Mdot
.27158 .01558 Mdot
.27159 .01558 Mdot
.2716 .01558 Mdot
.27161 .01558 Mdot
.27162 .01558 Mdot
.27163 .01558 Mdot
.27164 .01558 Mdot
.27165 .01558 Mdot
.27166 .01557 Mdot
.27167 .01557 Mdot
.27168 .01557 Mdot
.27169 .01557 Mdot
.2717 .01557 Mdot
.2717 .01557 Mdot
.27171 .01557 Mdot
.27172 .01556 Mdot
.27173 .01556 Mdot
.27174 .01556 Mdot
.27175 .01556 Mdot
.27176 .01556 Mdot
.27177 .01556 Mdot
.27178 .01556 Mdot
.27179 .01556 Mdot
.2718 .01555 Mdot
.27181 .01555 Mdot
.27182 .01555 Mdot
.27183 .01555 Mdot
.27184 .01555 Mdot
.27185 .01555 Mdot
.27186 .01555 Mdot
.27187 .01554 Mdot
.27188 .01554 Mdot
.27189 .01554 Mdot
.2719 .01554 Mdot
.2719 .01554 Mdot
.27191 .01554 Mdot
.27192 .01554 Mdot
.27193 .01554 Mdot
.27194 .01553 Mdot
.27195 .01553 Mdot
.27196 .01553 Mdot
.27197 .01553 Mdot
.27198 .01553 Mdot
.27199 .01553 Mdot
.272 .01553 Mdot
.27201 .01552 Mdot
.27202 .01552 Mdot
.27203 .01552 Mdot
.27204 .01552 Mdot
.27205 .01552 Mdot
.27206 .01552 Mdot
.27207 .01552 Mdot
.27208 .01552 Mdot
.27209 .01551 Mdot
.2721 .01551 Mdot
.2721 .01551 Mdot
.27211 .01551 Mdot
.27212 .01551 Mdot
.27213 .01551 Mdot
.27214 .01551 Mdot
.27215 .01551 Mdot
.27216 .0155 Mdot
.27217 .0155 Mdot
.27218 .0155 Mdot
.27219 .0155 Mdot
.2722 .0155 Mdot
.27221 .0155 Mdot
.27222 .0155 Mdot
.27223 .01549 Mdot
.27224 .01549 Mdot
.27225 .01549 Mdot
.27226 .01549 Mdot
.27227 .01549 Mdot
.27228 .01549 Mdot
.27229 .01549 Mdot
.2723 .01549 Mdot
.2723 .01548 Mdot
.27231 .01548 Mdot
.27232 .01548 Mdot
.27233 .01548 Mdot
.27234 .01548 Mdot
.27235 .01548 Mdot
.27236 .01548 Mdot
.27237 .01548 Mdot
.27238 .01547 Mdot
.27239 .01547 Mdot
.2724 .01547 Mdot
.27241 .01547 Mdot
.27242 .01547 Mdot
.27243 .01547 Mdot
.27244 .01547 Mdot
.27245 .01547 Mdot
.27246 .01546 Mdot
.27247 .01546 Mdot
.27248 .01546 Mdot
.27249 .01546 Mdot
.2725 .01546 Mdot
.2725 .01546 Mdot
.27251 .01546 Mdot
.27252 .01546 Mdot
.27253 .01545 Mdot
.27254 .01545 Mdot
.27255 .01545 Mdot
.27256 .01545 Mdot
.27257 .01545 Mdot
.27258 .01545 Mdot
.27259 .01545 Mdot
.2726 .01545 Mdot
.27261 .01544 Mdot
.27262 .01544 Mdot
.27263 .01544 Mdot
.27264 .01544 Mdot
.27265 .01544 Mdot
.27266 .01544 Mdot
.27267 .01544 Mdot
.27268 .01544 Mdot
.27269 .01543 Mdot
.2727 .01543 Mdot
.2727 .01543 Mdot
.27271 .01543 Mdot
.27272 .01543 Mdot
.27273 .01543 Mdot
.27274 .01543 Mdot
.27275 .01543 Mdot
.27276 .01542 Mdot
.27277 .01542 Mdot
.27278 .01542 Mdot
.27279 .01542 Mdot
.2728 .01542 Mdot
.27281 .01542 Mdot
.27282 .01542 Mdot
.27283 .01542 Mdot
.27284 .01541 Mdot
.27285 .01541 Mdot
.27286 .01541 Mdot
.27287 .01541 Mdot
.27288 .01541 Mdot
.27289 .01541 Mdot
.2729 .01541 Mdot
.2729 .01541 Mdot
.27291 .01541 Mdot
.27292 .0154 Mdot
.27293 .0154 Mdot
.27294 .0154 Mdot
.27295 .0154 Mdot
.27296 .0154 Mdot
.27297 .0154 Mdot
.27298 .0154 Mdot
.27299 .0154 Mdot
.273 .01539 Mdot
.27301 .01539 Mdot
.27302 .01539 Mdot
.27303 .01539 Mdot
.27304 .01539 Mdot
.27305 .01539 Mdot
.27306 .01539 Mdot
.27307 .01539 Mdot
.27308 .01538 Mdot
.27309 .01538 Mdot
.2731 .01538 Mdot
.2731 .01538 Mdot
.27311 .01538 Mdot
.27312 .01538 Mdot
.27313 .01538 Mdot
.27314 .01538 Mdot
.27315 .01538 Mdot
.27316 .01537 Mdot
.27317 .01537 Mdot
.27318 .01537 Mdot
.27319 .01537 Mdot
.2732 .01537 Mdot
.27321 .01537 Mdot
.27322 .01537 Mdot
.27323 .01537 Mdot
.27324 .01536 Mdot
.27325 .01536 Mdot
.27326 .01536 Mdot
.27327 .01536 Mdot
.27328 .01536 Mdot
.27329 .01536 Mdot
.2733 .01536 Mdot
.2733 .01536 Mdot
.27331 .01536 Mdot
.27332 .01535 Mdot
.27333 .01535 Mdot
.27334 .01535 Mdot
.27335 .01535 Mdot
.27336 .01535 Mdot
.27337 .01535 Mdot
.27338 .01535 Mdot
.27339 .01535 Mdot
.2734 .01534 Mdot
.27341 .01534 Mdot
.27342 .01534 Mdot
.27343 .01534 Mdot
.27344 .01534 Mdot
.27345 .01534 Mdot
.27346 .01534 Mdot
.27347 .01534 Mdot
.27348 .01534 Mdot
.27349 .01533 Mdot
.2735 .01533 Mdot
.2735 .01533 Mdot
.27351 .01533 Mdot
.27352 .01533 Mdot
.27353 .01533 Mdot
.27354 .01533 Mdot
.27355 .01533 Mdot
.27356 .01533 Mdot
.27357 .01532 Mdot
.27358 .01532 Mdot
.27359 .01532 Mdot
.2736 .01532 Mdot
.27361 .01532 Mdot
.27362 .01532 Mdot
.27363 .01532 Mdot
.27364 .01532 Mdot
.27365 .01532 Mdot
.27366 .01531 Mdot
.27367 .01531 Mdot
.27368 .01531 Mdot
.27369 .01531 Mdot
.2737 .01531 Mdot
.2737 .01531 Mdot
.27371 .01531 Mdot
.27372 .01531 Mdot
.27373 .0153 Mdot
.27374 .0153 Mdot
.27375 .0153 Mdot
.27376 .0153 Mdot
.27377 .0153 Mdot
.27378 .0153 Mdot
.27379 .0153 Mdot
.2738 .0153 Mdot
.27381 .0153 Mdot
.27382 .01529 Mdot
.27383 .01529 Mdot
.27384 .01529 Mdot
.27385 .01529 Mdot
.27386 .01529 Mdot
.27387 .01529 Mdot
.27388 .01529 Mdot
.27389 .01529 Mdot
.2739 .01529 Mdot
.2739 .01528 Mdot
.27391 .01528 Mdot
.27392 .01528 Mdot
.27393 .01528 Mdot
.27394 .01528 Mdot
.27395 .01528 Mdot
.27396 .01528 Mdot
.27397 .01528 Mdot
.27398 .01528 Mdot
.27399 .01528 Mdot
.274 .01527 Mdot
.27401 .01527 Mdot
.27402 .01527 Mdot
.27403 .01527 Mdot
.27404 .01527 Mdot
.27405 .01527 Mdot
.27406 .01527 Mdot
.27407 .01527 Mdot
.27408 .01527 Mdot
.27409 .01526 Mdot
.2741 .01526 Mdot
.2741 .01526 Mdot
.27411 .01526 Mdot
.27412 .01526 Mdot
.27413 .01526 Mdot
.27414 .01526 Mdot
.27415 .01526 Mdot
.27416 .01526 Mdot
.27417 .01525 Mdot
.27418 .01525 Mdot
.27419 .01525 Mdot
.2742 .01525 Mdot
.27421 .01525 Mdot
.27422 .01525 Mdot
.27423 .01525 Mdot
.27424 .01525 Mdot
.27425 .01525 Mdot
.27426 .01524 Mdot
.27427 .01524 Mdot
.27428 .01524 Mdot
.27429 .01524 Mdot
.2743 .01524 Mdot
.2743 .01524 Mdot
.27431 .01524 Mdot
.27432 .01524 Mdot
.27433 .01524 Mdot
.27434 .01524 Mdot
.27435 .01523 Mdot
.27436 .01523 Mdot
.27437 .01523 Mdot
.27438 .01523 Mdot
.27439 .01523 Mdot
.2744 .01523 Mdot
.27441 .01523 Mdot
.27442 .01523 Mdot
.27443 .01523 Mdot
.27444 .01523 Mdot
.27445 .01522 Mdot
.27446 .01522 Mdot
.27447 .01522 Mdot
.27448 .01522 Mdot
.27449 .01522 Mdot
.2745 .01522 Mdot
.2745 .01522 Mdot
.27451 .01522 Mdot
.27452 .01522 Mdot
.27453 .01521 Mdot
.27454 .01521 Mdot
.27455 .01521 Mdot
.27456 .01521 Mdot
.27457 .01521 Mdot
.27458 .01521 Mdot
.27459 .01521 Mdot
.2746 .01521 Mdot
.27461 .01521 Mdot
.27462 .01521 Mdot
.27463 .0152 Mdot
.27464 .0152 Mdot
.27465 .0152 Mdot
.27466 .0152 Mdot
.27467 .0152 Mdot
.27468 .0152 Mdot
.27469 .0152 Mdot
.2747 .0152 Mdot
.2747 .0152 Mdot
.27471 .0152 Mdot
.27472 .01519 Mdot
.27473 .01519 Mdot
.27474 .01519 Mdot
.27475 .01519 Mdot
.27476 .01519 Mdot
.27477 .01519 Mdot
.27478 .01519 Mdot
.27479 .01519 Mdot
.2748 .01519 Mdot
.27481 .01519 Mdot
.27482 .01518 Mdot
.27483 .01518 Mdot
.27484 .01518 Mdot
.27485 .01518 Mdot
.27486 .01518 Mdot
.27487 .01518 Mdot
.27488 .01518 Mdot
.27489 .01518 Mdot
.2749 .01518 Mdot
.2749 .01518 Mdot
.27491 .01517 Mdot
.27492 .01517 Mdot
.27493 .01517 Mdot
.27494 .01517 Mdot
.27495 .01517 Mdot
.27496 .01517 Mdot
.27497 .01517 Mdot
.27498 .01517 Mdot
.27499 .01517 Mdot
.275 .01517 Mdot
.27501 .01516 Mdot
.27502 .01516 Mdot
.27503 .01516 Mdot
.27504 .01516 Mdot
.27505 .01516 Mdot
.27506 .01516 Mdot
.27507 .01516 Mdot
.27508 .01516 Mdot
.27509 .01516 Mdot
.2751 .01516 Mdot
.2751 .01515 Mdot
.27511 .01515 Mdot
.27512 .01515 Mdot
.27513 .01515 Mdot
.27514 .01515 Mdot
.27515 .01515 Mdot
.27516 .01515 Mdot
.27517 .01515 Mdot
.27518 .01515 Mdot
.27519 .01515 Mdot
.2752 .01515 Mdot
.27521 .01514 Mdot
.27522 .01514 Mdot
.27523 .01514 Mdot
.27524 .01514 Mdot
.27525 .01514 Mdot
.27526 .01514 Mdot
.27527 .01514 Mdot
.27528 .01514 Mdot
.27529 .01514 Mdot
.2753 .01514 Mdot
.2753 .01513 Mdot
.27531 .01513 Mdot
.27532 .01513 Mdot
.27533 .01513 Mdot
.27534 .01513 Mdot
.27535 .01513 Mdot
.27536 .01513 Mdot
.27537 .01513 Mdot
.27538 .01513 Mdot
.27539 .01513 Mdot
.2754 .01513 Mdot
.27541 .01512 Mdot
.27542 .01512 Mdot
.27543 .01512 Mdot
.27544 .01512 Mdot
.27545 .01512 Mdot
.27546 .01512 Mdot
.27547 .01512 Mdot
.27548 .01512 Mdot
.27549 .01512 Mdot
.2755 .01512 Mdot
.2755 .01512 Mdot
.27551 .01511 Mdot
.27552 .01511 Mdot
.27553 .01511 Mdot
.27554 .01511 Mdot
.27555 .01511 Mdot
.27556 .01511 Mdot
.27557 .01511 Mdot
.27558 .01511 Mdot
.27559 .01511 Mdot
.2756 .01511 Mdot
.27561 .0151 Mdot
.27562 .0151 Mdot
.27563 .0151 Mdot
.27564 .0151 Mdot
.27565 .0151 Mdot
.27566 .0151 Mdot
.27567 .0151 Mdot
.27568 .0151 Mdot
.27569 .0151 Mdot
.2757 .0151 Mdot
.2757 .0151 Mdot
.27571 .01509 Mdot
.27572 .01509 Mdot
.27573 .01509 Mdot
.27574 .01509 Mdot
.27575 .01509 Mdot
.27576 .01509 Mdot
.27577 .01509 Mdot
.27578 .01509 Mdot
.27579 .01509 Mdot
.2758 .01509 Mdot
.27581 .01509 Mdot
.27582 .01509 Mdot
.27583 .01508 Mdot
.27584 .01508 Mdot
.27585 .01508 Mdot
.27586 .01508 Mdot
.27587 .01508 Mdot
.27588 .01508 Mdot
.27589 .01508 Mdot
.2759 .01508 Mdot
.2759 .01508 Mdot
.27591 .01508 Mdot
.27592 .01508 Mdot
.27593 .01507 Mdot
.27594 .01507 Mdot
.27595 .01507 Mdot
.27596 .01507 Mdot
.27597 .01507 Mdot
.27598 .01507 Mdot
.27599 .01507 Mdot
.276 .01507 Mdot
.27601 .01507 Mdot
.27602 .01507 Mdot
.27603 .01507 Mdot
.27604 .01507 Mdot
.27605 .01506 Mdot
.27606 .01506 Mdot
.27607 .01506 Mdot
.27608 .01506 Mdot
.27609 .01506 Mdot
.2761 .01506 Mdot
.2761 .01506 Mdot
.27611 .01506 Mdot
.27612 .01506 Mdot
.27613 .01506 Mdot
.27614 .01506 Mdot
.27615 .01505 Mdot
.27616 .01505 Mdot
.27617 .01505 Mdot
.27618 .01505 Mdot
.27619 .01505 Mdot
.2762 .01505 Mdot
.27621 .01505 Mdot
.27622 .01505 Mdot
.27623 .01505 Mdot
.27624 .01505 Mdot
.27625 .01505 Mdot
.27626 .01505 Mdot
.27627 .01504 Mdot
.27628 .01504 Mdot
.27629 .01504 Mdot
.2763 .01504 Mdot
.2763 .01504 Mdot
.27631 .01504 Mdot
.27632 .01504 Mdot
.27633 .01504 Mdot
.27634 .01504 Mdot
.27635 .01504 Mdot
.27636 .01504 Mdot
.27637 .01504 Mdot
.27638 .01503 Mdot
.27639 .01503 Mdot
.2764 .01503 Mdot
.27641 .01503 Mdot
.27642 .01503 Mdot
.27643 .01503 Mdot
.27644 .01503 Mdot
.27645 .01503 Mdot
.27646 .01503 Mdot
.27647 .01503 Mdot
.27648 .01503 Mdot
.27649 .01503 Mdot
.2765 .01502 Mdot
.2765 .01502 Mdot
.27651 .01502 Mdot
.27652 .01502 Mdot
.27653 .01502 Mdot
.27654 .01502 Mdot
.27655 .01502 Mdot
.27656 .01502 Mdot
.27657 .01502 Mdot
.27658 .01502 Mdot
.27659 .01502 Mdot
.2766 .01502 Mdot
.27661 .01502 Mdot
.27662 .01501 Mdot
.27663 .01501 Mdot
.27664 .01501 Mdot
.27665 .01501 Mdot
.27666 .01501 Mdot
.27667 .01501 Mdot
.27668 .01501 Mdot
.27669 .01501 Mdot
.2767 .01501 Mdot
.2767 .01501 Mdot
.27671 .01501 Mdot
.27672 .01501 Mdot
.27673 .015 Mdot
.27674 .015 Mdot
.27675 .015 Mdot
.27676 .015 Mdot
.27677 .015 Mdot
.27678 .015 Mdot
.27679 .015 Mdot
.2768 .015 Mdot
.27681 .015 Mdot
.27682 .015 Mdot
.27683 .015 Mdot
.27684 .015 Mdot
.27685 .015 Mdot
.27686 .01499 Mdot
.27687 .01499 Mdot
.27688 .01499 Mdot
.27689 .01499 Mdot
.2769 .01499 Mdot
.2769 .01499 Mdot
.27691 .01499 Mdot
.27692 .01499 Mdot
.27693 .01499 Mdot
.27694 .01499 Mdot
.27695 .01499 Mdot
.27696 .01499 Mdot
.27697 .01499 Mdot
.27698 .01498 Mdot
.27699 .01498 Mdot
.277 .01498 Mdot
.27701 .01498 Mdot
.27702 .01498 Mdot
.27703 .01498 Mdot
.27704 .01498 Mdot
.27705 .01498 Mdot
.27706 .01498 Mdot
.27707 .01498 Mdot
.27708 .01498 Mdot
.27709 .01498 Mdot
.2771 .01498 Mdot
.2771 .01497 Mdot
.27711 .01497 Mdot
.27712 .01497 Mdot
.27713 .01497 Mdot
.27714 .01497 Mdot
.27715 .01497 Mdot
.27716 .01497 Mdot
.27717 .01497 Mdot
.27718 .01497 Mdot
.27719 .01497 Mdot
.2772 .01497 Mdot
.27721 .01497 Mdot
.27722 .01497 Mdot
.27723 .01497 Mdot
.27724 .01496 Mdot
.27725 .01496 Mdot
.27726 .01496 Mdot
.27727 .01496 Mdot
.27728 .01496 Mdot
.27729 .01496 Mdot
.2773 .01496 Mdot
.2773 .01496 Mdot
.27731 .01496 Mdot
.27732 .01496 Mdot
.27733 .01496 Mdot
.27734 .01496 Mdot
.27735 .01496 Mdot
.27736 .01496 Mdot
.27737 .01495 Mdot
.27738 .01495 Mdot
.27739 .01495 Mdot
.2774 .01495 Mdot
.27741 .01495 Mdot
.27742 .01495 Mdot
.27743 .01495 Mdot
.27744 .01495 Mdot
.27745 .01495 Mdot
.27746 .01495 Mdot
.27747 .01495 Mdot
.27748 .01495 Mdot
.27749 .01495 Mdot
.2775 .01495 Mdot
.2775 .01494 Mdot
.27751 .01494 Mdot
.27752 .01494 Mdot
.27753 .01494 Mdot
.27754 .01494 Mdot
.27755 .01494 Mdot
.27756 .01494 Mdot
.27757 .01494 Mdot
.27758 .01494 Mdot
.27759 .01494 Mdot
.2776 .01494 Mdot
.27761 .01494 Mdot
.27762 .01494 Mdot
.27763 .01494 Mdot
.27764 .01493 Mdot
.27765 .01493 Mdot
.27766 .01493 Mdot
.27767 .01493 Mdot
.27768 .01493 Mdot
.27769 .01493 Mdot
.2777 .01493 Mdot
.2777 .01493 Mdot
.27771 .01493 Mdot
.27772 .01493 Mdot
.27773 .01493 Mdot
.27774 .01493 Mdot
.27775 .01493 Mdot
.27776 .01493 Mdot
.27777 .01493 Mdot
.27778 .01492 Mdot
.27779 .01492 Mdot
.2778 .01492 Mdot
.27781 .01492 Mdot
.27782 .01492 Mdot
.27783 .01492 Mdot
.27784 .01492 Mdot
.27785 .01492 Mdot
.27786 .01492 Mdot
.27787 .01492 Mdot
.27788 .01492 Mdot
.27789 .01492 Mdot
.2779 .01492 Mdot
.2779 .01492 Mdot
.27791 .01492 Mdot
.27792 .01491 Mdot
.27793 .01491 Mdot
.27794 .01491 Mdot
.27795 .01491 Mdot
.27796 .01491 Mdot
.27797 .01491 Mdot
.27798 .01491 Mdot
.27799 .01491 Mdot
.278 .01491 Mdot
.27801 .01491 Mdot
.27802 .01491 Mdot
.27803 .01491 Mdot
.27804 .01491 Mdot
.27805 .01491 Mdot
.27806 .01491 Mdot
.27807 .01491 Mdot
.27808 .0149 Mdot
.27809 .0149 Mdot
.2781 .0149 Mdot
.2781 .0149 Mdot
.27811 .0149 Mdot
.27812 .0149 Mdot
.27813 .0149 Mdot
.27814 .0149 Mdot
.27815 .0149 Mdot
.27816 .0149 Mdot
.27817 .0149 Mdot
.27818 .0149 Mdot
.27819 .0149 Mdot
.2782 .0149 Mdot
.27821 .0149 Mdot
.27822 .0149 Mdot
.27823 .01489 Mdot
.27824 .01489 Mdot
.27825 .01489 Mdot
.27826 .01489 Mdot
.27827 .01489 Mdot
.27828 .01489 Mdot
.27829 .01489 Mdot
.2783 .01489 Mdot
.2783 .01489 Mdot
.27831 .01489 Mdot
.27832 .01489 Mdot
.27833 .01489 Mdot
.27834 .01489 Mdot
.27835 .01489 Mdot
.27836 .01489 Mdot
.27837 .01489 Mdot
.27838 .01488 Mdot
.27839 .01488 Mdot
.2784 .01488 Mdot
.27841 .01488 Mdot
.27842 .01488 Mdot
.27843 .01488 Mdot
.27844 .01488 Mdot
.27845 .01488 Mdot
.27846 .01488 Mdot
.27847 .01488 Mdot
.27848 .01488 Mdot
.27849 .01488 Mdot
.2785 .01488 Mdot
.2785 .01488 Mdot
.27851 .01488 Mdot
.27852 .01488 Mdot
.27853 .01488 Mdot
.27854 .01487 Mdot
.27855 .01487 Mdot
.27856 .01487 Mdot
.27857 .01487 Mdot
.27858 .01487 Mdot
.27859 .01487 Mdot
.2786 .01487 Mdot
.27861 .01487 Mdot
.27862 .01487 Mdot
.27863 .01487 Mdot
.27864 .01487 Mdot
.27865 .01487 Mdot
.27866 .01487 Mdot
.27867 .01487 Mdot
.27868 .01487 Mdot
.27869 .01487 Mdot
.2787 .01487 Mdot
.2787 .01486 Mdot
.27871 .01486 Mdot
.27872 .01486 Mdot
.27873 .01486 Mdot
.27874 .01486 Mdot
.27875 .01486 Mdot
.27876 .01486 Mdot
.27877 .01486 Mdot
.27878 .01486 Mdot
.27879 .01486 Mdot
.2788 .01486 Mdot
.27881 .01486 Mdot
.27882 .01486 Mdot
.27883 .01486 Mdot
.27884 .01486 Mdot
.27885 .01486 Mdot
.27886 .01486 Mdot
.27887 .01486 Mdot
.27888 .01485 Mdot
.27889 .01485 Mdot
.2789 .01485 Mdot
.2789 .01485 Mdot
.27891 .01485 Mdot
.27892 .01485 Mdot
.27893 .01485 Mdot
.27894 .01485 Mdot
.27895 .01485 Mdot
.27896 .01485 Mdot
.27897 .01485 Mdot
.27898 .01485 Mdot
.27899 .01485 Mdot
.279 .01485 Mdot
.27901 .01485 Mdot
.27902 .01485 Mdot
.27903 .01485 Mdot
.27904 .01485 Mdot
.27905 .01485 Mdot
.27906 .01484 Mdot
.27907 .01484 Mdot
.27908 .01484 Mdot
.27909 .01484 Mdot
.2791 .01484 Mdot
.2791 .01484 Mdot
.27911 .01484 Mdot
.27912 .01484 Mdot
.27913 .01484 Mdot
.27914 .01484 Mdot
.27915 .01484 Mdot
.27916 .01484 Mdot
.27917 .01484 Mdot
.27918 .01484 Mdot
.27919 .01484 Mdot
.2792 .01484 Mdot
.27921 .01484 Mdot
.27922 .01484 Mdot
.27923 .01484 Mdot
.27924 .01483 Mdot
.27925 .01483 Mdot
.27926 .01483 Mdot
.27927 .01483 Mdot
.27928 .01483 Mdot
.27929 .01483 Mdot
.2793 .01483 Mdot
.2793 .01483 Mdot
.27931 .01483 Mdot
.27932 .01483 Mdot
.27933 .01483 Mdot
.27934 .01483 Mdot
.27935 .01483 Mdot
.27936 .01483 Mdot
.27937 .01483 Mdot
.27938 .01483 Mdot
.27939 .01483 Mdot
.2794 .01483 Mdot
.27941 .01483 Mdot
.27942 .01483 Mdot
.27943 .01482 Mdot
.27944 .01482 Mdot
.27945 .01482 Mdot
.27946 .01482 Mdot
.27947 .01482 Mdot
.27948 .01482 Mdot
.27949 .01482 Mdot
.2795 .01482 Mdot
.2795 .01482 Mdot
.27951 .01482 Mdot
.27952 .01482 Mdot
.27953 .01482 Mdot
.27954 .01482 Mdot
.27955 .01482 Mdot
.27956 .01482 Mdot
.27957 .01482 Mdot
.27958 .01482 Mdot
.27959 .01482 Mdot
.2796 .01482 Mdot
.27961 .01482 Mdot
.27962 .01482 Mdot
.27963 .01481 Mdot
.27964 .01481 Mdot
.27965 .01481 Mdot
.27966 .01481 Mdot
.27967 .01481 Mdot
.27968 .01481 Mdot
.27969 .01481 Mdot
.2797 .01481 Mdot
.2797 .01481 Mdot
.27971 .01481 Mdot
.27972 .01481 Mdot
.27973 .01481 Mdot
.27974 .01481 Mdot
.27975 .01481 Mdot
.27976 .01481 Mdot
.27977 .01481 Mdot
.27978 .01481 Mdot
.27979 .01481 Mdot
.2798 .01481 Mdot
.27981 .01481 Mdot
.27982 .01481 Mdot
.27983 .01481 Mdot
.27984 .01481 Mdot
.27985 .0148 Mdot
.27986 .0148 Mdot
.27987 .0148 Mdot
.27988 .0148 Mdot
.27989 .0148 Mdot
.2799 .0148 Mdot
.2799 .0148 Mdot
.27991 .0148 Mdot
.27992 .0148 Mdot
.27993 .0148 Mdot
.27994 .0148 Mdot
.27995 .0148 Mdot
.27996 .0148 Mdot
.27997 .0148 Mdot
.27998 .0148 Mdot
.27999 .0148 Mdot
.28 .0148 Mdot
.28001 .0148 Mdot
.28002 .0148 Mdot
.28003 .0148 Mdot
.28004 .0148 Mdot
.28005 .0148 Mdot
.28006 .0148 Mdot
.28007 .01479 Mdot
.28008 .01479 Mdot
.28009 .01479 Mdot
.2801 .01479 Mdot
.2801 .01479 Mdot
.28011 .01479 Mdot
.28012 .01479 Mdot
.28013 .01479 Mdot
.28014 .01479 Mdot
.28015 .01479 Mdot
.28016 .01479 Mdot
.28017 .01479 Mdot
.28018 .01479 Mdot
.28019 .01479 Mdot
.2802 .01479 Mdot
.28021 .01479 Mdot
.28022 .01479 Mdot
.28023 .01479 Mdot
.28024 .01479 Mdot
.28025 .01479 Mdot
.28026 .01479 Mdot
.28027 .01479 Mdot
.28028 .01479 Mdot
.28029 .01479 Mdot
.2803 .01479 Mdot
.2803 .01478 Mdot
.28031 .01478 Mdot
.28032 .01478 Mdot
.28033 .01478 Mdot
.28034 .01478 Mdot
.28035 .01478 Mdot
.28036 .01478 Mdot
.28037 .01478 Mdot
.28038 .01478 Mdot
.28039 .01478 Mdot
.2804 .01478 Mdot
.28041 .01478 Mdot
.28042 .01478 Mdot
.28043 .01478 Mdot
.28044 .01478 Mdot
.28045 .01478 Mdot
.28046 .01478 Mdot
.28047 .01478 Mdot
.28048 .01478 Mdot
.28049 .01478 Mdot
.2805 .01478 Mdot
.2805 .01478 Mdot
.28051 .01478 Mdot
.28052 .01478 Mdot
.28053 .01478 Mdot
.28054 .01478 Mdot
.28055 .01478 Mdot
.28056 .01477 Mdot
.28057 .01477 Mdot
.28058 .01477 Mdot
.28059 .01477 Mdot
.2806 .01477 Mdot
.28061 .01477 Mdot
.28062 .01477 Mdot
.28063 .01477 Mdot
.28064 .01477 Mdot
.28065 .01477 Mdot
.28066 .01477 Mdot
.28067 .01477 Mdot
.28068 .01477 Mdot
.28069 .01477 Mdot
.2807 .01477 Mdot
.2807 .01477 Mdot
.28071 .01477 Mdot
.28072 .01477 Mdot
.28073 .01477 Mdot
.28074 .01477 Mdot
.28075 .01477 Mdot
.28076 .01477 Mdot
.28077 .01477 Mdot
.28078 .01477 Mdot
.28079 .01477 Mdot
.2808 .01477 Mdot
.28081 .01477 Mdot
.28082 .01477 Mdot
.28083 .01477 Mdot
.28084 .01476 Mdot
.28085 .01476 Mdot
.28086 .01476 Mdot
.28087 .01476 Mdot
.28088 .01476 Mdot
.28089 .01476 Mdot
.2809 .01476 Mdot
.2809 .01476 Mdot
.28091 .01476 Mdot
.28092 .01476 Mdot
.28093 .01476 Mdot
.28094 .01476 Mdot
.28095 .01476 Mdot
.28096 .01476 Mdot
.28097 .01476 Mdot
.28098 .01476 Mdot
.28099 .01476 Mdot
.281 .01476 Mdot
.28101 .01476 Mdot
.28102 .01476 Mdot
.28103 .01476 Mdot
.28104 .01476 Mdot
.28105 .01476 Mdot
.28106 .01476 Mdot
.28107 .01476 Mdot
.28108 .01476 Mdot
.28109 .01476 Mdot
.2811 .01476 Mdot
.2811 .01476 Mdot
.28111 .01476 Mdot
.28112 .01476 Mdot
.28113 .01476 Mdot
.28114 .01475 Mdot
.28115 .01475 Mdot
.28116 .01475 Mdot
.28117 .01475 Mdot
.28118 .01475 Mdot
.28119 .01475 Mdot
.2812 .01475 Mdot
.28121 .01475 Mdot
.28122 .01475 Mdot
.28123 .01475 Mdot
.28124 .01475 Mdot
.28125 .01475 Mdot
.28126 .01475 Mdot
.28127 .01475 Mdot
.28128 .01475 Mdot
.28129 .01475 Mdot
.2813 .01475 Mdot
.2813 .01475 Mdot
.28131 .01475 Mdot
.28132 .01475 Mdot
.28133 .01475 Mdot
.28134 .01475 Mdot
.28135 .01475 Mdot
.28136 .01475 Mdot
.28137 .01475 Mdot
.28138 .01475 Mdot
.28139 .01475 Mdot
.2814 .01475 Mdot
.28141 .01475 Mdot
.28142 .01475 Mdot
.28143 .01475 Mdot
.28144 .01475 Mdot
.28145 .01475 Mdot
.28146 .01475 Mdot
.28147 .01475 Mdot
.28148 .01475 Mdot
.28149 .01475 Mdot
.2815 .01474 Mdot
.2815 .01474 Mdot
.28151 .01474 Mdot
.28152 .01474 Mdot
.28153 .01474 Mdot
.28154 .01474 Mdot
.28155 .01474 Mdot
.28156 .01474 Mdot
.28157 .01474 Mdot
.28158 .01474 Mdot
.28159 .01474 Mdot
.2816 .01474 Mdot
.28161 .01474 Mdot
.28162 .01474 Mdot
.28163 .01474 Mdot
.28164 .01474 Mdot
.28165 .01474 Mdot
.28166 .01474 Mdot
.28167 .01474 Mdot
.28168 .01474 Mdot
.28169 .01474 Mdot
.2817 .01474 Mdot
.2817 .01474 Mdot
.28171 .01474 Mdot
.28172 .01474 Mdot
.28173 .01474 Mdot
.28174 .01474 Mdot
.28175 .01474 Mdot
.28176 .01474 Mdot
.28177 .01474 Mdot
.28178 .01474 Mdot
.28179 .01474 Mdot
.2818 .01474 Mdot
.28181 .01474 Mdot
.28182 .01474 Mdot
.28183 .01474 Mdot
.28184 .01474 Mdot
.28185 .01474 Mdot
.28186 .01474 Mdot
.28187 .01474 Mdot
.28188 .01474 Mdot
.28189 .01474 Mdot
.2819 .01474 Mdot
.2819 .01473 Mdot
.28191 .01473 Mdot
.28192 .01473 Mdot
.28193 .01473 Mdot
.28194 .01473 Mdot
.28195 .01473 Mdot
.28196 .01473 Mdot
.28197 .01473 Mdot
.28198 .01473 Mdot
.28199 .01473 Mdot
.282 .01473 Mdot
.28201 .01473 Mdot
.28202 .01473 Mdot
.28203 .01473 Mdot
.28204 .01473 Mdot
.28205 .01473 Mdot
.28206 .01473 Mdot
.28207 .01473 Mdot
.28208 .01473 Mdot
.28209 .01473 Mdot
.2821 .01473 Mdot
.2821 .01473 Mdot
.28211 .01473 Mdot
.28212 .01473 Mdot
.28213 .01473 Mdot
.28214 .01473 Mdot
.28215 .01473 Mdot
.28216 .01473 Mdot
.28217 .01473 Mdot
.28218 .01473 Mdot
.28219 .01473 Mdot
.2822 .01473 Mdot
.28221 .01473 Mdot
.28222 .01473 Mdot
.28223 .01473 Mdot
.28224 .01473 Mdot
.28225 .01473 Mdot
.28226 .01473 Mdot
.28227 .01473 Mdot
.28228 .01473 Mdot
.28229 .01473 Mdot
.2823 .01473 Mdot
.2823 .01473 Mdot
.28231 .01473 Mdot
.28232 .01473 Mdot
.28233 .01473 Mdot
.28234 .01473 Mdot
.28235 .01473 Mdot
.28236 .01473 Mdot
.28237 .01473 Mdot
.28238 .01473 Mdot
.28239 .01473 Mdot
.2824 .01473 Mdot
.28241 .01473 Mdot
.28242 .01473 Mdot
.28243 .01473 Mdot
.28244 .01473 Mdot
.28245 .01472 Mdot
.28246 .01472 Mdot
.28247 .01472 Mdot
.28248 .01472 Mdot
.28249 .01472 Mdot
.2825 .01472 Mdot
.2825 .01472 Mdot
.28251 .01472 Mdot
.28252 .01472 Mdot
.28253 .01472 Mdot
.28254 .01472 Mdot
.28255 .01472 Mdot
.28256 .01472 Mdot
.28257 .01472 Mdot
.28258 .01472 Mdot
.28259 .01472 Mdot
.2826 .01472 Mdot
.28261 .01472 Mdot
.28262 .01472 Mdot
.28263 .01472 Mdot
.28264 .01472 Mdot
.28265 .01472 Mdot
.28266 .01472 Mdot
.28267 .01472 Mdot
.28268 .01472 Mdot
.28269 .01472 Mdot
.2827 .01472 Mdot
.2827 .01472 Mdot
.28271 .01472 Mdot
.28272 .01472 Mdot
.28273 .01472 Mdot
.28274 .01472 Mdot
.28275 .01472 Mdot
.28276 .01472 Mdot
.28277 .01472 Mdot
.28278 .01472 Mdot
.28279 .01472 Mdot
.2828 .01472 Mdot
.28281 .01472 Mdot
.28282 .01472 Mdot
.28283 .01472 Mdot
.28284 .01472 Mdot
.28285 .01472 Mdot
.28286 .01472 Mdot
.28287 .01472 Mdot
.28288 .01472 Mdot
.28289 .01472 Mdot
.2829 .01472 Mdot
.2829 .01472 Mdot
.28291 .01472 Mdot
.28292 .01472 Mdot
.28293 .01472 Mdot
.28294 .01472 Mdot
.28295 .01472 Mdot
.28296 .01472 Mdot
.28297 .01472 Mdot
.28298 .01472 Mdot
.28299 .01472 Mdot
.283 .01472 Mdot
.28301 .01472 Mdot
.28302 .01472 Mdot
.28303 .01472 Mdot
.28304 .01472 Mdot
.28305 .01472 Mdot
.28306 .01472 Mdot
.28307 .01472 Mdot
.28308 .01472 Mdot
.28309 .01472 Mdot
.2831 .01472 Mdot
.2831 .01472 Mdot
.28311 .01472 Mdot
.28312 .01472 Mdot
.28313 .01472 Mdot
.28314 .01472 Mdot
.28315 .01472 Mdot
.28316 .01472 Mdot
.28317 .01472 Mdot
.28318 .01472 Mdot
.28319 .01472 Mdot
.2832 .01472 Mdot
.28321 .01472 Mdot
.28322 .01472 Mdot
.28323 .01472 Mdot
.28324 .01472 Mdot
.28325 .01472 Mdot
.28326 .01472 Mdot
.28327 .01472 Mdot
.28328 .01472 Mdot
.28329 .01472 Mdot
.2833 .01472 Mdot
.2833 .01472 Mdot
.28331 .01472 Mdot
.28332 .01472 Mdot
.28333 .01472 Mdot
.28334 .01472 Mdot
.28335 .01472 Mdot
.28336 .01472 Mdot
.28337 .01472 Mdot
.28338 .01472 Mdot
.28339 .01472 Mdot
.2834 .01472 Mdot
.28341 .01472 Mdot
.28342 .01472 Mdot
.28343 .01472 Mdot
.28344 .01472 Mdot
.28345 .01472 Mdot
.28346 .01472 Mdot
.28347 .01472 Mdot
.28348 .01472 Mdot
.28349 .01472 Mdot
.2835 .01472 Mdot
.2835 .01472 Mdot
.28351 .01472 Mdot
.28352 .01472 Mdot
.28353 .01472 Mdot
.28354 .01472 Mdot
.28355 .01472 Mdot
.28356 .01472 Mdot
.28357 .01472 Mdot
.28358 .01472 Mdot
.28359 .01472 Mdot
.2836 .01472 Mdot
.28361 .01472 Mdot
.28362 .01472 Mdot
.28363 .01472 Mdot
.28364 .01472 Mdot
.28365 .01472 Mdot
.28366 .01472 Mdot
.28367 .01472 Mdot
.28368 .01472 Mdot
.28369 .01472 Mdot
.2837 .01472 Mdot
.2837 .01472 Mdot
.28371 .01472 Mdot
.28372 .01472 Mdot
.28373 .01472 Mdot
.28374 .01472 Mdot
.28375 .01472 Mdot
.28376 .01472 Mdot
.28377 .01472 Mdot
.28378 .01472 Mdot
.28379 .01472 Mdot
.2838 .01472 Mdot
.28381 .01472 Mdot
.28382 .01472 Mdot
.28383 .01472 Mdot
.28384 .01472 Mdot
.28385 .01472 Mdot
.28386 .01472 Mdot
.28387 .01472 Mdot
.28388 .01472 Mdot
.28389 .01472 Mdot
.2839 .01472 Mdot
.2839 .01472 Mdot
.28391 .01472 Mdot
.28392 .01472 Mdot
.28393 .01472 Mdot
.28394 .01472 Mdot
.28395 .01472 Mdot
.28396 .01472 Mdot
.28397 .01472 Mdot
.28398 .01472 Mdot
.28399 .01472 Mdot
.284 .01472 Mdot
.28401 .01472 Mdot
.28402 .01472 Mdot
.28403 .01472 Mdot
.28404 .01472 Mdot
.28405 .01472 Mdot
.28406 .01472 Mdot
.28407 .01472 Mdot
.28408 .01472 Mdot
.28409 .01472 Mdot
.2841 .01472 Mdot
.2841 .01472 Mdot
.28411 .01472 Mdot
.28412 .01472 Mdot
.28413 .01472 Mdot
.28414 .01472 Mdot
.28415 .01472 Mdot
.28416 .01472 Mdot
.28417 .01472 Mdot
.28418 .01472 Mdot
.28419 .01472 Mdot
.2842 .01472 Mdot
.28421 .01472 Mdot
.28422 .01472 Mdot
.28423 .01472 Mdot
.28424 .01472 Mdot
.28425 .01472 Mdot
.28426 .01472 Mdot
.28427 .01472 Mdot
.28428 .01472 Mdot
.28429 .01472 Mdot
.2843 .01472 Mdot
.2843 .01472 Mdot
.28431 .01472 Mdot
.28432 .01472 Mdot
.28433 .01472 Mdot
.28434 .01472 Mdot
.28435 .01472 Mdot
.28436 .01472 Mdot
.28437 .01472 Mdot
.28438 .01472 Mdot
.28439 .01472 Mdot
.2844 .01472 Mdot
.28441 .01472 Mdot
.28442 .01472 Mdot
.28443 .01472 Mdot
.28444 .01472 Mdot
.28445 .01472 Mdot
.28446 .01472 Mdot
.28447 .01472 Mdot
.28448 .01472 Mdot
.28449 .01472 Mdot
.2845 .01472 Mdot
.2845 .01472 Mdot
.28451 .01472 Mdot
.28452 .01472 Mdot
.28453 .01472 Mdot
.28454 .01472 Mdot
.28455 .01472 Mdot
.28456 .01472 Mdot
.28457 .01472 Mdot
.28458 .01472 Mdot
.28459 .01472 Mdot
.2846 .01472 Mdot
.28461 .01472 Mdot
.28462 .01472 Mdot
.28463 .01472 Mdot
.28464 .01472 Mdot
.28465 .01472 Mdot
.28466 .01472 Mdot
.28467 .01472 Mdot
.28468 .01472 Mdot
.28469 .01472 Mdot
.2847 .01472 Mdot
.2847 .01472 Mdot
.28471 .01472 Mdot
.28472 .01472 Mdot
.28473 .01472 Mdot
.28474 .01472 Mdot
.28475 .01472 Mdot
.28476 .01472 Mdot
.28477 .01472 Mdot
.28478 .01472 Mdot
.28479 .01472 Mdot
.2848 .01472 Mdot
.28481 .01472 Mdot
.28482 .01472 Mdot
.28483 .01472 Mdot
.28484 .01472 Mdot
.28485 .01472 Mdot
.28486 .01472 Mdot
.28487 .01472 Mdot
.28488 .01472 Mdot
.28489 .01472 Mdot
.2849 .01472 Mdot
.2849 .01472 Mdot
.28491 .01472 Mdot
.28492 .01472 Mdot
.28493 .01472 Mdot
.28494 .01472 Mdot
.28495 .01472 Mdot
.28496 .01472 Mdot
.28497 .01472 Mdot
.28498 .01472 Mdot
.28499 .01472 Mdot
.285 .01472 Mdot
.28501 .01472 Mdot
.28502 .01472 Mdot
.28503 .01473 Mdot
.28504 .01473 Mdot
.28505 .01473 Mdot
.28506 .01473 Mdot
.28507 .01473 Mdot
.28508 .01473 Mdot
.28509 .01473 Mdot
.2851 .01473 Mdot
.2851 .01473 Mdot
.28511 .01473 Mdot
.28512 .01473 Mdot
.28513 .01473 Mdot
.28514 .01473 Mdot
.28515 .01473 Mdot
.28516 .01473 Mdot
.28517 .01473 Mdot
.28518 .01473 Mdot
.28519 .01473 Mdot
.2852 .01473 Mdot
.28521 .01473 Mdot
.28522 .01473 Mdot
.28523 .01473 Mdot
.28524 .01473 Mdot
.28525 .01473 Mdot
.28526 .01473 Mdot
.28527 .01473 Mdot
.28528 .01473 Mdot
.28529 .01473 Mdot
.2853 .01473 Mdot
.2853 .01473 Mdot
.28531 .01473 Mdot
.28532 .01473 Mdot
.28533 .01473 Mdot
.28534 .01473 Mdot
.28535 .01473 Mdot
.28536 .01473 Mdot
.28537 .01473 Mdot
.28538 .01473 Mdot
.28539 .01473 Mdot
.2854 .01473 Mdot
.28541 .01473 Mdot
.28542 .01473 Mdot
.28543 .01473 Mdot
.28544 .01473 Mdot
.28545 .01473 Mdot
.28546 .01473 Mdot
.28547 .01473 Mdot
.28548 .01473 Mdot
.28549 .01473 Mdot
.2855 .01473 Mdot
.2855 .01473 Mdot
.28551 .01473 Mdot
.28552 .01473 Mdot
.28553 .01473 Mdot
.28554 .01473 Mdot
.28555 .01473 Mdot
.28556 .01473 Mdot
.28557 .01474 Mdot
.28558 .01474 Mdot
.28559 .01474 Mdot
.2856 .01474 Mdot
.28561 .01474 Mdot
.28562 .01474 Mdot
.28563 .01474 Mdot
.28564 .01474 Mdot
.28565 .01474 Mdot
.28566 .01474 Mdot
.28567 .01474 Mdot
.28568 .01474 Mdot
.28569 .01474 Mdot
.2857 .01474 Mdot
.2857 .01474 Mdot
.28571 .01474 Mdot
.28572 .01474 Mdot
.28573 .01474 Mdot
.28574 .01474 Mdot
.28575 .01474 Mdot
.28576 .01474 Mdot
.28577 .01474 Mdot
.28578 .01474 Mdot
.28579 .01474 Mdot
.2858 .01474 Mdot
.28581 .01474 Mdot
.28582 .01474 Mdot
.28583 .01474 Mdot
.28584 .01474 Mdot
.28585 .01474 Mdot
.28586 .01474 Mdot
.28587 .01474 Mdot
.28588 .01474 Mdot
.28589 .01474 Mdot
.2859 .01474 Mdot
.2859 .01474 Mdot
.28591 .01474 Mdot
.28592 .01474 Mdot
.28593 .01474 Mdot
.28594 .01474 Mdot
.28595 .01474 Mdot
.28596 .01474 Mdot
.28597 .01474 Mdot
.28598 .01475 Mdot
.28599 .01475 Mdot
.286 .01475 Mdot
.28601 .01475 Mdot
.28602 .01475 Mdot
.28603 .01475 Mdot
.28604 .01475 Mdot
.28605 .01475 Mdot
.28606 .01475 Mdot
.28607 .01475 Mdot
.28608 .01475 Mdot
.28609 .01475 Mdot
.2861 .01475 Mdot
.2861 .01475 Mdot
.28611 .01475 Mdot
.28612 .01475 Mdot
.28613 .01475 Mdot
.28614 .01475 Mdot
.28615 .01475 Mdot
.28616 .01475 Mdot
.28617 .01475 Mdot
.28618 .01475 Mdot
.28619 .01475 Mdot
.2862 .01475 Mdot
.28621 .01475 Mdot
.28622 .01475 Mdot
.28623 .01475 Mdot
.28624 .01475 Mdot
.28625 .01475 Mdot
.28626 .01475 Mdot
.28627 .01475 Mdot
.28628 .01475 Mdot
.28629 .01475 Mdot
.2863 .01475 Mdot
.2863 .01475 Mdot
.28631 .01475 Mdot
.28632 .01475 Mdot
.28633 .01476 Mdot
.28634 .01476 Mdot
.28635 .01476 Mdot
.28636 .01476 Mdot
.28637 .01476 Mdot
.28638 .01476 Mdot
.28639 .01476 Mdot
.2864 .01476 Mdot
.28641 .01476 Mdot
.28642 .01476 Mdot
.28643 .01476 Mdot
.28644 .01476 Mdot
.28645 .01476 Mdot
.28646 .01476 Mdot
.28647 .01476 Mdot
.28648 .01476 Mdot
.28649 .01476 Mdot
.2865 .01476 Mdot
.2865 .01476 Mdot
.28651 .01476 Mdot
.28652 .01476 Mdot
.28653 .01476 Mdot
.28654 .01476 Mdot
.28655 .01476 Mdot
.28656 .01476 Mdot
.28657 .01476 Mdot
.28658 .01476 Mdot
.28659 .01476 Mdot
.2866 .01476 Mdot
.28661 .01476 Mdot
.28662 .01476 Mdot
.28663 .01476 Mdot
.28664 .01477 Mdot
.28665 .01477 Mdot
.28666 .01477 Mdot
.28667 .01477 Mdot
.28668 .01477 Mdot
.28669 .01477 Mdot
.2867 .01477 Mdot
.2867 .01477 Mdot
.28671 .01477 Mdot
.28672 .01477 Mdot
.28673 .01477 Mdot
.28674 .01477 Mdot
.28675 .01477 Mdot
.28676 .01477 Mdot
.28677 .01477 Mdot
.28678 .01477 Mdot
.28679 .01477 Mdot
.2868 .01477 Mdot
.28681 .01477 Mdot
.28682 .01477 Mdot
.28683 .01477 Mdot
.28684 .01477 Mdot
.28685 .01477 Mdot
.28686 .01477 Mdot
.28687 .01477 Mdot
.28688 .01477 Mdot
.28689 .01477 Mdot
.2869 .01477 Mdot
.2869 .01477 Mdot
.28691 .01478 Mdot
.28692 .01478 Mdot
.28693 .01478 Mdot
.28694 .01478 Mdot
.28695 .01478 Mdot
.28696 .01478 Mdot
.28697 .01478 Mdot
.28698 .01478 Mdot
.28699 .01478 Mdot
.287 .01478 Mdot
.28701 .01478 Mdot
.28702 .01478 Mdot
.28703 .01478 Mdot
.28704 .01478 Mdot
.28705 .01478 Mdot
.28706 .01478 Mdot
.28707 .01478 Mdot
.28708 .01478 Mdot
.28709 .01478 Mdot
.2871 .01478 Mdot
.2871 .01478 Mdot
.28711 .01478 Mdot
.28712 .01478 Mdot
.28713 .01478 Mdot
.28714 .01478 Mdot
.28715 .01478 Mdot
.28716 .01478 Mdot
.28717 .01479 Mdot
.28718 .01479 Mdot
.28719 .01479 Mdot
.2872 .01479 Mdot
.28721 .01479 Mdot
.28722 .01479 Mdot
.28723 .01479 Mdot
.28724 .01479 Mdot
.28725 .01479 Mdot
.28726 .01479 Mdot
.28727 .01479 Mdot
.28728 .01479 Mdot
.28729 .01479 Mdot
.2873 .01479 Mdot
.2873 .01479 Mdot
.28731 .01479 Mdot
.28732 .01479 Mdot
.28733 .01479 Mdot
.28734 .01479 Mdot
.28735 .01479 Mdot
.28736 .01479 Mdot
.28737 .01479 Mdot
.28738 .01479 Mdot
.28739 .01479 Mdot
.2874 .01479 Mdot
.28741 .0148 Mdot
.28742 .0148 Mdot
.28743 .0148 Mdot
.28744 .0148 Mdot
.28745 .0148 Mdot
.28746 .0148 Mdot
.28747 .0148 Mdot
.28748 .0148 Mdot
.28749 .0148 Mdot
.2875 .0148 Mdot
.2875 .0148 Mdot
.28751 .0148 Mdot
.28752 .0148 Mdot
.28753 .0148 Mdot
.28754 .0148 Mdot
.28755 .0148 Mdot
.28756 .0148 Mdot
.28757 .0148 Mdot
.28758 .0148 Mdot
.28759 .0148 Mdot
.2876 .0148 Mdot
.28761 .0148 Mdot
.28762 .0148 Mdot
.28763 .01481 Mdot
.28764 .01481 Mdot
.28765 .01481 Mdot
.28766 .01481 Mdot
.28767 .01481 Mdot
.28768 .01481 Mdot
.28769 .01481 Mdot
.2877 .01481 Mdot
.2877 .01481 Mdot
.28771 .01481 Mdot
.28772 .01481 Mdot
.28773 .01481 Mdot
.28774 .01481 Mdot
.28775 .01481 Mdot
.28776 .01481 Mdot
.28777 .01481 Mdot
.28778 .01481 Mdot
.28779 .01481 Mdot
.2878 .01481 Mdot
.28781 .01481 Mdot
.28782 .01481 Mdot
.28783 .01481 Mdot
.28784 .01482 Mdot
.28785 .01482 Mdot
.28786 .01482 Mdot
.28787 .01482 Mdot
.28788 .01482 Mdot
.28789 .01482 Mdot
.2879 .01482 Mdot
.2879 .01482 Mdot
.28791 .01482 Mdot
.28792 .01482 Mdot
.28793 .01482 Mdot
.28794 .01482 Mdot
.28795 .01482 Mdot
.28796 .01482 Mdot
.28797 .01482 Mdot
.28798 .01482 Mdot
.28799 .01482 Mdot
.288 .01482 Mdot
.28801 .01482 Mdot
.28802 .01482 Mdot
.28803 .01482 Mdot
.28804 .01483 Mdot
.28805 .01483 Mdot
.28806 .01483 Mdot
.28807 .01483 Mdot
.28808 .01483 Mdot
.28809 .01483 Mdot
.2881 .01483 Mdot
.2881 .01483 Mdot
.28811 .01483 Mdot
.28812 .01483 Mdot
.28813 .01483 Mdot
.28814 .01483 Mdot
.28815 .01483 Mdot
.28816 .01483 Mdot
.28817 .01483 Mdot
.28818 .01483 Mdot
.28819 .01483 Mdot
.2882 .01483 Mdot
.28821 .01483 Mdot
.28822 .01483 Mdot
.28823 .01484 Mdot
.28824 .01484 Mdot
.28825 .01484 Mdot
.28826 .01484 Mdot
.28827 .01484 Mdot
.28828 .01484 Mdot
.28829 .01484 Mdot
.2883 .01484 Mdot
.2883 .01484 Mdot
.28831 .01484 Mdot
.28832 .01484 Mdot
.28833 .01484 Mdot
.28834 .01484 Mdot
.28835 .01484 Mdot
.28836 .01484 Mdot
.28837 .01484 Mdot
.28838 .01484 Mdot
.28839 .01484 Mdot
.2884 .01484 Mdot
.28841 .01485 Mdot
.28842 .01485 Mdot
.28843 .01485 Mdot
.28844 .01485 Mdot
.28845 .01485 Mdot
.28846 .01485 Mdot
.28847 .01485 Mdot
.28848 .01485 Mdot
.28849 .01485 Mdot
.2885 .01485 Mdot
.2885 .01485 Mdot
.28851 .01485 Mdot
.28852 .01485 Mdot
.28853 .01485 Mdot
.28854 .01485 Mdot
.28855 .01485 Mdot
.28856 .01485 Mdot
.28857 .01485 Mdot
.28858 .01485 Mdot
.28859 .01486 Mdot
.2886 .01486 Mdot
.28861 .01486 Mdot
.28862 .01486 Mdot
.28863 .01486 Mdot
.28864 .01486 Mdot
.28865 .01486 Mdot
.28866 .01486 Mdot
.28867 .01486 Mdot
.28868 .01486 Mdot
.28869 .01486 Mdot
.2887 .01486 Mdot
.2887 .01486 Mdot
.28871 .01486 Mdot
.28872 .01486 Mdot
.28873 .01486 Mdot
.28874 .01486 Mdot
.28875 .01487 Mdot
.28876 .01487 Mdot
.28877 .01487 Mdot
.28878 .01487 Mdot
.28879 .01487 Mdot
.2888 .01487 Mdot
.28881 .01487 Mdot
.28882 .01487 Mdot
.28883 .01487 Mdot
.28884 .01487 Mdot
.28885 .01487 Mdot
.28886 .01487 Mdot
.28887 .01487 Mdot
.28888 .01487 Mdot
.28889 .01487 Mdot
.2889 .01487 Mdot
.2889 .01487 Mdot
.28891 .01487 Mdot
.28892 .01488 Mdot
.28893 .01488 Mdot
.28894 .01488 Mdot
.28895 .01488 Mdot
.28896 .01488 Mdot
.28897 .01488 Mdot
.28898 .01488 Mdot
.28899 .01488 Mdot
.289 .01488 Mdot
.28901 .01488 Mdot
.28902 .01488 Mdot
.28903 .01488 Mdot
.28904 .01488 Mdot
.28905 .01488 Mdot
.28906 .01488 Mdot
.28907 .01488 Mdot
.28908 .01489 Mdot
.28909 .01489 Mdot
.2891 .01489 Mdot
.2891 .01489 Mdot
.28911 .01489 Mdot
.28912 .01489 Mdot
.28913 .01489 Mdot
.28914 .01489 Mdot
.28915 .01489 Mdot
.28916 .01489 Mdot
.28917 .01489 Mdot
.28918 .01489 Mdot
.28919 .01489 Mdot
.2892 .01489 Mdot
.28921 .01489 Mdot
.28922 .01489 Mdot
.28923 .01489 Mdot
.28924 .0149 Mdot
.28925 .0149 Mdot
.28926 .0149 Mdot
.28927 .0149 Mdot
.28928 .0149 Mdot
.28929 .0149 Mdot
.2893 .0149 Mdot
.2893 .0149 Mdot
.28931 .0149 Mdot
.28932 .0149 Mdot
.28933 .0149 Mdot
.28934 .0149 Mdot
.28935 .0149 Mdot
.28936 .0149 Mdot
.28937 .0149 Mdot
.28938 .01491 Mdot
.28939 .01491 Mdot
.2894 .01491 Mdot
.28941 .01491 Mdot
.28942 .01491 Mdot
.28943 .01491 Mdot
.28944 .01491 Mdot
.28945 .01491 Mdot
.28946 .01491 Mdot
.28947 .01491 Mdot
.28948 .01491 Mdot
.28949 .01491 Mdot
.2895 .01491 Mdot
.2895 .01491 Mdot
.28951 .01491 Mdot
.28952 .01491 Mdot
.28953 .01492 Mdot
.28954 .01492 Mdot
.28955 .01492 Mdot
.28956 .01492 Mdot
.28957 .01492 Mdot
.28958 .01492 Mdot
.28959 .01492 Mdot
.2896 .01492 Mdot
.28961 .01492 Mdot
.28962 .01492 Mdot
.28963 .01492 Mdot
.28964 .01492 Mdot
.28965 .01492 Mdot
.28966 .01492 Mdot
.28967 .01492 Mdot
.28968 .01493 Mdot
.28969 .01493 Mdot
.2897 .01493 Mdot
.2897 .01493 Mdot
.28971 .01493 Mdot
.28972 .01493 Mdot
.28973 .01493 Mdot
.28974 .01493 Mdot
.28975 .01493 Mdot
.28976 .01493 Mdot
.28977 .01493 Mdot
.28978 .01493 Mdot
.28979 .01493 Mdot
.2898 .01493 Mdot
.28981 .01493 Mdot
.28982 .01494 Mdot
.28983 .01494 Mdot
.28984 .01494 Mdot
.28985 .01494 Mdot
.28986 .01494 Mdot
.28987 .01494 Mdot
.28988 .01494 Mdot
.28989 .01494 Mdot
.2899 .01494 Mdot
.2899 .01494 Mdot
.28991 .01494 Mdot
.28992 .01494 Mdot
.28993 .01494 Mdot
.28994 .01494 Mdot
.28995 .01495 Mdot
.28996 .01495 Mdot
.28997 .01495 Mdot
.28998 .01495 Mdot
.28999 .01495 Mdot
.29 .01495 Mdot
.29001 .01495 Mdot
.29002 .01495 Mdot
.29003 .01495 Mdot
.29004 .01495 Mdot
.29005 .01495 Mdot
.29006 .01495 Mdot
.29007 .01495 Mdot
.29008 .01495 Mdot
.29009 .01496 Mdot
.2901 .01496 Mdot
.2901 .01496 Mdot
.29011 .01496 Mdot
.29012 .01496 Mdot
.29013 .01496 Mdot
.29014 .01496 Mdot
.29015 .01496 Mdot
.29016 .01496 Mdot
.29017 .01496 Mdot
.29018 .01496 Mdot
.29019 .01496 Mdot
.2902 .01496 Mdot
.29021 .01496 Mdot
.29022 .01497 Mdot
.29023 .01497 Mdot
.29024 .01497 Mdot
.29025 .01497 Mdot
.29026 .01497 Mdot
.29027 .01497 Mdot
.29028 .01497 Mdot
.29029 .01497 Mdot
.2903 .01497 Mdot
.2903 .01497 Mdot
.29031 .01497 Mdot
.29032 .01497 Mdot
.29033 .01497 Mdot
.29034 .01498 Mdot
.29035 .01498 Mdot
.29036 .01498 Mdot
.29037 .01498 Mdot
.29038 .01498 Mdot
.29039 .01498 Mdot
.2904 .01498 Mdot
.29041 .01498 Mdot
.29042 .01498 Mdot
.29043 .01498 Mdot
.29044 .01498 Mdot
.29045 .01498 Mdot
.29046 .01498 Mdot
.29047 .01499 Mdot
.29048 .01499 Mdot
.29049 .01499 Mdot
.2905 .01499 Mdot
.2905 .01499 Mdot
.29051 .01499 Mdot
.29052 .01499 Mdot
.29053 .01499 Mdot
.29054 .01499 Mdot
.29055 .01499 Mdot
.29056 .01499 Mdot
.29057 .01499 Mdot
.29058 .01499 Mdot
.29059 .015 Mdot
.2906 .015 Mdot
.29061 .015 Mdot
.29062 .015 Mdot
.29063 .015 Mdot
.29064 .015 Mdot
.29065 .015 Mdot
.29066 .015 Mdot
.29067 .015 Mdot
.29068 .015 Mdot
.29069 .015 Mdot
.2907 .015 Mdot
.2907 .015 Mdot
.29071 .01501 Mdot
.29072 .01501 Mdot
.29073 .01501 Mdot
.29074 .01501 Mdot
.29075 .01501 Mdot
.29076 .01501 Mdot
.29077 .01501 Mdot
.29078 .01501 Mdot
.29079 .01501 Mdot
.2908 .01501 Mdot
.29081 .01501 Mdot
.29082 .01501 Mdot
.29083 .01502 Mdot
.29084 .01502 Mdot
.29085 .01502 Mdot
.29086 .01502 Mdot
.29087 .01502 Mdot
.29088 .01502 Mdot
.29089 .01502 Mdot
.2909 .01502 Mdot
.2909 .01502 Mdot
.29091 .01502 Mdot
.29092 .01502 Mdot
.29093 .01502 Mdot
.29094 .01502 Mdot
.29095 .01503 Mdot
.29096 .01503 Mdot
.29097 .01503 Mdot
.29098 .01503 Mdot
.29099 .01503 Mdot
.291 .01503 Mdot
.29101 .01503 Mdot
.29102 .01503 Mdot
.29103 .01503 Mdot
.29104 .01503 Mdot
.29105 .01503 Mdot
.29106 .01503 Mdot
.29107 .01504 Mdot
.29108 .01504 Mdot
.29109 .01504 Mdot
.2911 .01504 Mdot
.2911 .01504 Mdot
.29111 .01504 Mdot
.29112 .01504 Mdot
.29113 .01504 Mdot
.29114 .01504 Mdot
.29115 .01504 Mdot
.29116 .01504 Mdot
.29117 .01504 Mdot
.29118 .01505 Mdot
.29119 .01505 Mdot
.2912 .01505 Mdot
.29121 .01505 Mdot
.29122 .01505 Mdot
.29123 .01505 Mdot
.29124 .01505 Mdot
.29125 .01505 Mdot
.29126 .01505 Mdot
.29127 .01505 Mdot
.29128 .01505 Mdot
.29129 .01506 Mdot
.2913 .01506 Mdot
.2913 .01506 Mdot
.29131 .01506 Mdot
.29132 .01506 Mdot
.29133 .01506 Mdot
.29134 .01506 Mdot
.29135 .01506 Mdot
.29136 .01506 Mdot
.29137 .01506 Mdot
.29138 .01506 Mdot
.29139 .01506 Mdot
.2914 .01507 Mdot
.29141 .01507 Mdot
.29142 .01507 Mdot
.29143 .01507 Mdot
.29144 .01507 Mdot
.29145 .01507 Mdot
.29146 .01507 Mdot
.29147 .01507 Mdot
.29148 .01507 Mdot
.29149 .01507 Mdot
.2915 .01507 Mdot
.2915 .01508 Mdot
.29151 .01508 Mdot
.29152 .01508 Mdot
.29153 .01508 Mdot
.29154 .01508 Mdot
.29155 .01508 Mdot
.29156 .01508 Mdot
.29157 .01508 Mdot
.29158 .01508 Mdot
.29159 .01508 Mdot
.2916 .01508 Mdot
.29161 .01509 Mdot
.29162 .01509 Mdot
.29163 .01509 Mdot
.29164 .01509 Mdot
.29165 .01509 Mdot
.29166 .01509 Mdot
.29167 .01509 Mdot
.29168 .01509 Mdot
.29169 .01509 Mdot
.2917 .01509 Mdot
.2917 .01509 Mdot
.29171 .0151 Mdot
.29172 .0151 Mdot
.29173 .0151 Mdot
.29174 .0151 Mdot
.29175 .0151 Mdot
.29176 .0151 Mdot
.29177 .0151 Mdot
.29178 .0151 Mdot
.29179 .0151 Mdot
.2918 .0151 Mdot
.29181 .0151 Mdot
.29182 .01511 Mdot
.29183 .01511 Mdot
.29184 .01511 Mdot
.29185 .01511 Mdot
.29186 .01511 Mdot
.29187 .01511 Mdot
.29188 .01511 Mdot
.29189 .01511 Mdot
.2919 .01511 Mdot
.2919 .01511 Mdot
.29191 .01511 Mdot
.29192 .01512 Mdot
.29193 .01512 Mdot
.29194 .01512 Mdot
.29195 .01512 Mdot
.29196 .01512 Mdot
.29197 .01512 Mdot
.29198 .01512 Mdot
.29199 .01512 Mdot
.292 .01512 Mdot
.29201 .01512 Mdot
.29202 .01512 Mdot
.29203 .01513 Mdot
.29204 .01513 Mdot
.29205 .01513 Mdot
.29206 .01513 Mdot
.29207 .01513 Mdot
.29208 .01513 Mdot
.29209 .01513 Mdot
.2921 .01513 Mdot
.2921 .01513 Mdot
.29211 .01513 Mdot
.29212 .01514 Mdot
.29213 .01514 Mdot
.29214 .01514 Mdot
.29215 .01514 Mdot
.29216 .01514 Mdot
.29217 .01514 Mdot
.29218 .01514 Mdot
.29219 .01514 Mdot
.2922 .01514 Mdot
.29221 .01514 Mdot
.29222 .01514 Mdot
.29223 .01515 Mdot
.29224 .01515 Mdot
.29225 .01515 Mdot
.29226 .01515 Mdot
.29227 .01515 Mdot
.29228 .01515 Mdot
.29229 .01515 Mdot
.2923 .01515 Mdot
.2923 .01515 Mdot
.29231 .01515 Mdot
.29232 .01516 Mdot
.29233 .01516 Mdot
.29234 .01516 Mdot
.29235 .01516 Mdot
.29236 .01516 Mdot
.29237 .01516 Mdot
.29238 .01516 Mdot
.29239 .01516 Mdot
.2924 .01516 Mdot
.29241 .01516 Mdot
.29242 .01517 Mdot
.29243 .01517 Mdot
.29244 .01517 Mdot
.29245 .01517 Mdot
.29246 .01517 Mdot
.29247 .01517 Mdot
.29248 .01517 Mdot
.29249 .01517 Mdot
.2925 .01517 Mdot
.2925 .01517 Mdot
.29251 .01518 Mdot
.29252 .01518 Mdot
.29253 .01518 Mdot
.29254 .01518 Mdot
.29255 .01518 Mdot
.29256 .01518 Mdot
.29257 .01518 Mdot
.29258 .01518 Mdot
.29259 .01518 Mdot
.2926 .01518 Mdot
.29261 .01519 Mdot
.29262 .01519 Mdot
.29263 .01519 Mdot
.29264 .01519 Mdot
.29265 .01519 Mdot
.29266 .01519 Mdot
.29267 .01519 Mdot
.29268 .01519 Mdot
.29269 .01519 Mdot
.2927 .01519 Mdot
.2927 .0152 Mdot
.29271 .0152 Mdot
.29272 .0152 Mdot
.29273 .0152 Mdot
.29274 .0152 Mdot
.29275 .0152 Mdot
.29276 .0152 Mdot
.29277 .0152 Mdot
.29278 .0152 Mdot
.29279 .0152 Mdot
.2928 .01521 Mdot
.29281 .01521 Mdot
.29282 .01521 Mdot
.29283 .01521 Mdot
.29284 .01521 Mdot
.29285 .01521 Mdot
.29286 .01521 Mdot
.29287 .01521 Mdot
.29288 .01521 Mdot
.29289 .01522 Mdot
.2929 .01522 Mdot
.2929 .01522 Mdot
.29291 .01522 Mdot
.29292 .01522 Mdot
.29293 .01522 Mdot
.29294 .01522 Mdot
.29295 .01522 Mdot
.29296 .01522 Mdot
.29297 .01522 Mdot
.29298 .01523 Mdot
.29299 .01523 Mdot
.293 .01523 Mdot
.29301 .01523 Mdot
.29302 .01523 Mdot
.29303 .01523 Mdot
.29304 .01523 Mdot
.29305 .01523 Mdot
.29306 .01523 Mdot
.29307 .01524 Mdot
.29308 .01524 Mdot
.29309 .01524 Mdot
.2931 .01524 Mdot
.2931 .01524 Mdot
.29311 .01524 Mdot
.29312 .01524 Mdot
.29313 .01524 Mdot
.29314 .01524 Mdot
.29315 .01524 Mdot
.29316 .01525 Mdot
.29317 .01525 Mdot
.29318 .01525 Mdot
.29319 .01525 Mdot
.2932 .01525 Mdot
.29321 .01525 Mdot
.29322 .01525 Mdot
.29323 .01525 Mdot
.29324 .01525 Mdot
.29325 .01526 Mdot
.29326 .01526 Mdot
.29327 .01526 Mdot
.29328 .01526 Mdot
.29329 .01526 Mdot
.2933 .01526 Mdot
.2933 .01526 Mdot
.29331 .01526 Mdot
.29332 .01526 Mdot
.29333 .01527 Mdot
.29334 .01527 Mdot
.29335 .01527 Mdot
.29336 .01527 Mdot
.29337 .01527 Mdot
.29338 .01527 Mdot
.29339 .01527 Mdot
.2934 .01527 Mdot
.29341 .01527 Mdot
.29342 .01528 Mdot
.29343 .01528 Mdot
.29344 .01528 Mdot
.29345 .01528 Mdot
.29346 .01528 Mdot
.29347 .01528 Mdot
.29348 .01528 Mdot
.29349 .01528 Mdot
.2935 .01528 Mdot
.2935 .01529 Mdot
.29351 .01529 Mdot
.29352 .01529 Mdot
.29353 .01529 Mdot
.29354 .01529 Mdot
.29355 .01529 Mdot
.29356 .01529 Mdot
.29357 .01529 Mdot
.29358 .01529 Mdot
.29359 .0153 Mdot
.2936 .0153 Mdot
.29361 .0153 Mdot
.29362 .0153 Mdot
.29363 .0153 Mdot
.29364 .0153 Mdot
.29365 .0153 Mdot
.29366 .0153 Mdot
.29367 .0153 Mdot
.29368 .01531 Mdot
.29369 .01531 Mdot
.2937 .01531 Mdot
.2937 .01531 Mdot
.29371 .01531 Mdot
.29372 .01531 Mdot
.29373 .01531 Mdot
.29374 .01531 Mdot
.29375 .01531 Mdot
.29376 .01532 Mdot
.29377 .01532 Mdot
.29378 .01532 Mdot
.29379 .01532 Mdot
.2938 .01532 Mdot
.29381 .01532 Mdot
.29382 .01532 Mdot
.29383 .01532 Mdot
.29384 .01533 Mdot
.29385 .01533 Mdot
.29386 .01533 Mdot
.29387 .01533 Mdot
.29388 .01533 Mdot
.29389 .01533 Mdot
.2939 .01533 Mdot
.2939 .01533 Mdot
.29391 .01533 Mdot
.29392 .01534 Mdot
.29393 .01534 Mdot
.29394 .01534 Mdot
.29395 .01534 Mdot
.29396 .01534 Mdot
.29397 .01534 Mdot
.29398 .01534 Mdot
.29399 .01534 Mdot
.294 .01534 Mdot
.29401 .01535 Mdot
.29402 .01535 Mdot
.29403 .01535 Mdot
.29404 .01535 Mdot
.29405 .01535 Mdot
.29406 .01535 Mdot
.29407 .01535 Mdot
.29408 .01535 Mdot
.29409 .01536 Mdot
.2941 .01536 Mdot
.2941 .01536 Mdot
.29411 .01536 Mdot
.29412 .01536 Mdot
.29413 .01536 Mdot
.29414 .01536 Mdot
.29415 .01536 Mdot
.29416 .01536 Mdot
.29417 .01537 Mdot
.29418 .01537 Mdot
.29419 .01537 Mdot
.2942 .01537 Mdot
.29421 .01537 Mdot
.29422 .01537 Mdot
.29423 .01537 Mdot
.29424 .01537 Mdot
.29425 .01538 Mdot
.29426 .01538 Mdot
.29427 .01538 Mdot
.29428 .01538 Mdot
.29429 .01538 Mdot
.2943 .01538 Mdot
.2943 .01538 Mdot
.29431 .01538 Mdot
.29432 .01539 Mdot
.29433 .01539 Mdot
.29434 .01539 Mdot
.29435 .01539 Mdot
.29436 .01539 Mdot
.29437 .01539 Mdot
.29438 .01539 Mdot
.29439 .01539 Mdot
.2944 .0154 Mdot
.29441 .0154 Mdot
.29442 .0154 Mdot
.29443 .0154 Mdot
.29444 .0154 Mdot
.29445 .0154 Mdot
.29446 .0154 Mdot
.29447 .0154 Mdot
.29448 .0154 Mdot
.29449 .01541 Mdot
.2945 .01541 Mdot
.2945 .01541 Mdot
.29451 .01541 Mdot
.29452 .01541 Mdot
.29453 .01541 Mdot
.29454 .01541 Mdot
.29455 .01541 Mdot
.29456 .01542 Mdot
.29457 .01542 Mdot
.29458 .01542 Mdot
.29459 .01542 Mdot
.2946 .01542 Mdot
.29461 .01542 Mdot
.29462 .01542 Mdot
.29463 .01542 Mdot
.29464 .01543 Mdot
.29465 .01543 Mdot
.29466 .01543 Mdot
.29467 .01543 Mdot
.29468 .01543 Mdot
.29469 .01543 Mdot
.2947 .01543 Mdot
.2947 .01543 Mdot
.29471 .01544 Mdot
.29472 .01544 Mdot
.29473 .01544 Mdot
.29474 .01544 Mdot
.29475 .01544 Mdot
.29476 .01544 Mdot
.29477 .01544 Mdot
.29478 .01544 Mdot
.29479 .01545 Mdot
.2948 .01545 Mdot
.29481 .01545 Mdot
.29482 .01545 Mdot
.29483 .01545 Mdot
.29484 .01545 Mdot
.29485 .01545 Mdot
.29486 .01545 Mdot
.29487 .01546 Mdot
.29488 .01546 Mdot
.29489 .01546 Mdot
.2949 .01546 Mdot
.2949 .01546 Mdot
.29491 .01546 Mdot
.29492 .01546 Mdot
.29493 .01547 Mdot
.29494 .01547 Mdot
.29495 .01547 Mdot
.29496 .01547 Mdot
.29497 .01547 Mdot
.29498 .01547 Mdot
.29499 .01547 Mdot
.295 .01547 Mdot
.29501 .01548 Mdot
.29502 .01548 Mdot
.29503 .01548 Mdot
.29504 .01548 Mdot
.29505 .01548 Mdot
.29506 .01548 Mdot
.29507 .01548 Mdot
.29508 .01548 Mdot
.29509 .01549 Mdot
.2951 .01549 Mdot
.2951 .01549 Mdot
.29511 .01549 Mdot
.29512 .01549 Mdot
.29513 .01549 Mdot
.29514 .01549 Mdot
.29515 .01549 Mdot
.29516 .0155 Mdot
.29517 .0155 Mdot
.29518 .0155 Mdot
.29519 .0155 Mdot
.2952 .0155 Mdot
.29521 .0155 Mdot
.29522 .0155 Mdot
.29523 .01551 Mdot
.29524 .01551 Mdot
.29525 .01551 Mdot
.29526 .01551 Mdot
.29527 .01551 Mdot
.29528 .01551 Mdot
.29529 .01551 Mdot
.2953 .01551 Mdot
.2953 .01552 Mdot
.29531 .01552 Mdot
.29532 .01552 Mdot
.29533 .01552 Mdot
.29534 .01552 Mdot
.29535 .01552 Mdot
.29536 .01552 Mdot
.29537 .01553 Mdot
.29538 .01553 Mdot
.29539 .01553 Mdot
.2954 .01553 Mdot
.29541 .01553 Mdot
.29542 .01553 Mdot
.29543 .01553 Mdot
.29544 .01553 Mdot
.29545 .01554 Mdot
.29546 .01554 Mdot
.29547 .01554 Mdot
.29548 .01554 Mdot
.29549 .01554 Mdot
.2955 .01554 Mdot
.2955 .01554 Mdot
.29551 .01555 Mdot
.29552 .01555 Mdot
.29553 .01555 Mdot
.29554 .01555 Mdot
.29555 .01555 Mdot
.29556 .01555 Mdot
.29557 .01555 Mdot
.29558 .01555 Mdot
.29559 .01556 Mdot
.2956 .01556 Mdot
.29561 .01556 Mdot
.29562 .01556 Mdot
.29563 .01556 Mdot
.29564 .01556 Mdot
.29565 .01556 Mdot
.29566 .01557 Mdot
.29567 .01557 Mdot
.29568 .01557 Mdot
.29569 .01557 Mdot
.2957 .01557 Mdot
.2957 .01557 Mdot
.29571 .01557 Mdot
.29572 .01558 Mdot
.29573 .01558 Mdot
.29574 .01558 Mdot
.29575 .01558 Mdot
.29576 .01558 Mdot
.29577 .01558 Mdot
.29578 .01558 Mdot
.29579 .01558 Mdot
.2958 .01559 Mdot
.29581 .01559 Mdot
.29582 .01559 Mdot
.29583 .01559 Mdot
.29584 .01559 Mdot
.29585 .01559 Mdot
.29586 .01559 Mdot
.29587 .0156 Mdot
.29588 .0156 Mdot
.29589 .0156 Mdot
.2959 .0156 Mdot
.2959 .0156 Mdot
.29591 .0156 Mdot
.29592 .0156 Mdot
.29593 .01561 Mdot
.29594 .01561 Mdot
.29595 .01561 Mdot
.29596 .01561 Mdot
.29597 .01561 Mdot
.29598 .01561 Mdot
.29599 .01561 Mdot
.296 .01562 Mdot
.29601 .01562 Mdot
.29602 .01562 Mdot
.29603 .01562 Mdot
.29604 .01562 Mdot
.29605 .01562 Mdot
.29606 .01562 Mdot
.29607 .01563 Mdot
.29608 .01563 Mdot
.29609 .01563 Mdot
.2961 .01563 Mdot
.2961 .01563 Mdot
.29611 .01563 Mdot
.29612 .01563 Mdot
.29613 .01564 Mdot
.29614 .01564 Mdot
.29615 .01564 Mdot
.29616 .01564 Mdot
.29617 .01564 Mdot
.29618 .01564 Mdot
.29619 .01564 Mdot
.2962 .01565 Mdot
.29621 .01565 Mdot
.29622 .01565 Mdot
.29623 .01565 Mdot
.29624 .01565 Mdot
.29625 .01565 Mdot
.29626 .01565 Mdot
.29627 .01566 Mdot
.29628 .01566 Mdot
.29629 .01566 Mdot
.2963 .01566 Mdot
.2963 .01566 Mdot
.29631 .01566 Mdot
.29632 .01566 Mdot
.29633 .01567 Mdot
.29634 .01567 Mdot
.29635 .01567 Mdot
.29636 .01567 Mdot
.29637 .01567 Mdot
.29638 .01567 Mdot
.29639 .01567 Mdot
.2964 .01568 Mdot
.29641 .01568 Mdot
.29642 .01568 Mdot
.29643 .01568 Mdot
.29644 .01568 Mdot
.29645 .01568 Mdot
.29646 .01568 Mdot
.29647 .01569 Mdot
.29648 .01569 Mdot
.29649 .01569 Mdot
.2965 .01569 Mdot
.2965 .01569 Mdot
.29651 .01569 Mdot
.29652 .01569 Mdot
.29653 .0157 Mdot
.29654 .0157 Mdot
.29655 .0157 Mdot
.29656 .0157 Mdot
.29657 .0157 Mdot
.29658 .0157 Mdot
.29659 .0157 Mdot
.2966 .01571 Mdot
.29661 .01571 Mdot
.29662 .01571 Mdot
.29663 .01571 Mdot
.29664 .01571 Mdot
.29665 .01571 Mdot
.29666 .01571 Mdot
.29667 .01572 Mdot
.29668 .01572 Mdot
.29669 .01572 Mdot
.2967 .01572 Mdot
.2967 .01572 Mdot
.29671 .01572 Mdot
.29672 .01573 Mdot
.29673 .01573 Mdot
.29674 .01573 Mdot
.29675 .01573 Mdot
.29676 .01573 Mdot
.29677 .01573 Mdot
.29678 .01573 Mdot
.29679 .01574 Mdot
.2968 .01574 Mdot
.29681 .01574 Mdot
.29682 .01574 Mdot
.29683 .01574 Mdot
.29684 .01574 Mdot
.29685 .01574 Mdot
.29686 .01575 Mdot
.29687 .01575 Mdot
.29688 .01575 Mdot
.29689 .01575 Mdot
.2969 .01575 Mdot
.2969 .01575 Mdot
.29691 .01576 Mdot
.29692 .01576 Mdot
.29693 .01576 Mdot
.29694 .01576 Mdot
.29695 .01576 Mdot
.29696 .01576 Mdot
.29697 .01576 Mdot
.29698 .01577 Mdot
.29699 .01577 Mdot
.297 .01577 Mdot
.29701 .01577 Mdot
.29702 .01577 Mdot
.29703 .01577 Mdot
.29704 .01577 Mdot
.29705 .01578 Mdot
.29706 .01578 Mdot
.29707 .01578 Mdot
.29708 .01578 Mdot
.29709 .01578 Mdot
.2971 .01578 Mdot
.2971 .01579 Mdot
.29711 .01579 Mdot
.29712 .01579 Mdot
.29713 .01579 Mdot
.29714 .01579 Mdot
.29715 .01579 Mdot
.29716 .01579 Mdot
.29717 .0158 Mdot
.29718 .0158 Mdot
.29719 .0158 Mdot
.2972 .0158 Mdot
.29721 .0158 Mdot
.29722 .0158 Mdot
.29723 .01581 Mdot
.29724 .01581 Mdot
.29725 .01581 Mdot
.29726 .01581 Mdot
.29727 .01581 Mdot
.29728 .01581 Mdot
.29729 .01581 Mdot
.2973 .01582 Mdot
.2973 .01582 Mdot
.29731 .01582 Mdot
.29732 .01582 Mdot
.29733 .01582 Mdot
.29734 .01582 Mdot
.29735 .01583 Mdot
.29736 .01583 Mdot
.29737 .01583 Mdot
.29738 .01583 Mdot
.29739 .01583 Mdot
.2974 .01583 Mdot
.29741 .01584 Mdot
.29742 .01584 Mdot
.29743 .01584 Mdot
.29744 .01584 Mdot
.29745 .01584 Mdot
.29746 .01584 Mdot
.29747 .01584 Mdot
.29748 .01585 Mdot
.29749 .01585 Mdot
.2975 .01585 Mdot
.2975 .01585 Mdot
.29751 .01585 Mdot
.29752 .01585 Mdot
.29753 .01586 Mdot
.29754 .01586 Mdot
.29755 .01586 Mdot
.29756 .01586 Mdot
.29757 .01586 Mdot
.29758 .01586 Mdot
.29759 .01587 Mdot
.2976 .01587 Mdot
.29761 .01587 Mdot
.29762 .01587 Mdot
.29763 .01587 Mdot
.29764 .01587 Mdot
.29765 .01587 Mdot
.29766 .01588 Mdot
.29767 .01588 Mdot
.29768 .01588 Mdot
.29769 .01588 Mdot
.2977 .01588 Mdot
.2977 .01588 Mdot
.29771 .01589 Mdot
.29772 .01589 Mdot
.29773 .01589 Mdot
.29774 .01589 Mdot
.29775 .01589 Mdot
.29776 .01589 Mdot
.29777 .0159 Mdot
.29778 .0159 Mdot
.29779 .0159 Mdot
.2978 .0159 Mdot
.29781 .0159 Mdot
.29782 .0159 Mdot
.29783 .01591 Mdot
.29784 .01591 Mdot
.29785 .01591 Mdot
.29786 .01591 Mdot
.29787 .01591 Mdot
.29788 .01591 Mdot
.29789 .01591 Mdot
.2979 .01592 Mdot
.2979 .01592 Mdot
.29791 .01592 Mdot
.29792 .01592 Mdot
.29793 .01592 Mdot
.29794 .01592 Mdot
.29795 .01593 Mdot
.29796 .01593 Mdot
.29797 .01593 Mdot
.29798 .01593 Mdot
.29799 .01593 Mdot
.298 .01593 Mdot
.29801 .01594 Mdot
.29802 .01594 Mdot
.29803 .01594 Mdot
.29804 .01594 Mdot
.29805 .01594 Mdot
.29806 .01594 Mdot
.29807 .01595 Mdot
.29808 .01595 Mdot
.29809 .01595 Mdot
.2981 .01595 Mdot
.2981 .01595 Mdot
.29811 .01595 Mdot
.29812 .01596 Mdot
.29813 .01596 Mdot
.29814 .01596 Mdot
.29815 .01596 Mdot
.29816 .01596 Mdot
.29817 .01596 Mdot
.29818 .01597 Mdot
.29819 .01597 Mdot
.2982 .01597 Mdot
.29821 .01597 Mdot
.29822 .01597 Mdot
.29823 .01597 Mdot
.29824 .01598 Mdot
.29825 .01598 Mdot
.29826 .01598 Mdot
.29827 .01598 Mdot
.29828 .01598 Mdot
.29829 .01598 Mdot
.2983 .01599 Mdot
.2983 .01599 Mdot
.29831 .01599 Mdot
.29832 .01599 Mdot
.29833 .01599 Mdot
.29834 .01599 Mdot
.29835 .016 Mdot
.29836 .016 Mdot
.29837 .016 Mdot
.29838 .016 Mdot
.29839 .016 Mdot
.2984 .016 Mdot
.29841 .01601 Mdot
.29842 .01601 Mdot
.29843 .01601 Mdot
.29844 .01601 Mdot
.29845 .01601 Mdot
.29846 .01601 Mdot
.29847 .01602 Mdot
.29848 .01602 Mdot
.29849 .01602 Mdot
.2985 .01602 Mdot
.2985 .01602 Mdot
.29851 .01602 Mdot
.29852 .01603 Mdot
.29853 .01603 Mdot
.29854 .01603 Mdot
.29855 .01603 Mdot
.29856 .01603 Mdot
.29857 .01603 Mdot
.29858 .01604 Mdot
.29859 .01604 Mdot
.2986 .01604 Mdot
.29861 .01604 Mdot
.29862 .01604 Mdot
.29863 .01604 Mdot
.29864 .01605 Mdot
.29865 .01605 Mdot
.29866 .01605 Mdot
.29867 .01605 Mdot
.29868 .01605 Mdot
.29869 .01606 Mdot
.2987 .01606 Mdot
.2987 .01606 Mdot
.29871 .01606 Mdot
.29872 .01606 Mdot
.29873 .01606 Mdot
.29874 .01607 Mdot
.29875 .01607 Mdot
.29876 .01607 Mdot
.29877 .01607 Mdot
.29878 .01607 Mdot
.29879 .01607 Mdot
.2988 .01608 Mdot
.29881 .01608 Mdot
.29882 .01608 Mdot
.29883 .01608 Mdot
.29884 .01608 Mdot
.29885 .01608 Mdot
.29886 .01609 Mdot
.29887 .01609 Mdot
.29888 .01609 Mdot
.29889 .01609 Mdot
.2989 .01609 Mdot
.2989 .01609 Mdot
.29891 .0161 Mdot
.29892 .0161 Mdot
.29893 .0161 Mdot
.29894 .0161 Mdot
.29895 .0161 Mdot
.29896 .01611 Mdot
.29897 .01611 Mdot
.29898 .01611 Mdot
.29899 .01611 Mdot
.299 .01611 Mdot
.29901 .01611 Mdot
.29902 .01612 Mdot
.29903 .01612 Mdot
.29904 .01612 Mdot
.29905 .01612 Mdot
.29906 .01612 Mdot
.29907 .01612 Mdot
.29908 .01613 Mdot
.29909 .01613 Mdot
.2991 .01613 Mdot
.2991 .01613 Mdot
.29911 .01613 Mdot
.29912 .01614 Mdot
.29913 .01614 Mdot
.29914 .01614 Mdot
.29915 .01614 Mdot
.29916 .01614 Mdot
.29917 .01614 Mdot
.29918 .01615 Mdot
.29919 .01615 Mdot
.2992 .01615 Mdot
.29921 .01615 Mdot
.29922 .01615 Mdot
.29923 .01615 Mdot
.29924 .01616 Mdot
.29925 .01616 Mdot
.29926 .01616 Mdot
.29927 .01616 Mdot
.29928 .01616 Mdot
.29929 .01617 Mdot
.2993 .01617 Mdot
.2993 .01617 Mdot
.29931 .01617 Mdot
.29932 .01617 Mdot
.29933 .01617 Mdot
.29934 .01618 Mdot
.29935 .01618 Mdot
.29936 .01618 Mdot
.29937 .01618 Mdot
.29938 .01618 Mdot
.29939 .01619 Mdot
.2994 .01619 Mdot
.29941 .01619 Mdot
.29942 .01619 Mdot
.29943 .01619 Mdot
.29944 .01619 Mdot
.29945 .0162 Mdot
.29946 .0162 Mdot
.29947 .0162 Mdot
.29948 .0162 Mdot
.29949 .0162 Mdot
.2995 .0162 Mdot
.2995 .01621 Mdot
.29951 .01621 Mdot
.29952 .01621 Mdot
.29953 .01621 Mdot
.29954 .01621 Mdot
.29955 .01622 Mdot
.29956 .01622 Mdot
.29957 .01622 Mdot
.29958 .01622 Mdot
.29959 .01622 Mdot
.2996 .01622 Mdot
.29961 .01623 Mdot
.29962 .01623 Mdot
.29963 .01623 Mdot
.29964 .01623 Mdot
.29965 .01623 Mdot
.29966 .01624 Mdot
.29967 .01624 Mdot
.29968 .01624 Mdot
.29969 .01624 Mdot
.2997 .01624 Mdot
.2997 .01624 Mdot
.29971 .01625 Mdot
.29972 .01625 Mdot
.29973 .01625 Mdot
.29974 .01625 Mdot
.29975 .01625 Mdot
.29976 .01626 Mdot
.29977 .01626 Mdot
.29978 .01626 Mdot
.29979 .01626 Mdot
.2998 .01626 Mdot
.29981 .01627 Mdot
.29982 .01627 Mdot
.29983 .01627 Mdot
.29984 .01627 Mdot
.29985 .01627 Mdot
.29986 .01627 Mdot
.29987 .01628 Mdot
.29988 .01628 Mdot
.29989 .01628 Mdot
.2999 .01628 Mdot
.2999 .01628 Mdot
.29991 .01629 Mdot
.29992 .01629 Mdot
.29993 .01629 Mdot
.29994 .01629 Mdot
.29995 .01629 Mdot
.29996 .01629 Mdot
.29997 .0163 Mdot
.29998 .0163 Mdot
.29999 .0163 Mdot
.3 .0163 Mdot
.30001 .0163 Mdot
.30002 .01631 Mdot
.30003 .01631 Mdot
.30004 .01631 Mdot
.30005 .01631 Mdot
.30006 .01631 Mdot
.30007 .01632 Mdot
.30008 .01632 Mdot
.30009 .01632 Mdot
.3001 .01632 Mdot
.3001 .01632 Mdot
.30011 .01632 Mdot
.30012 .01633 Mdot
.30013 .01633 Mdot
.30014 .01633 Mdot
.30015 .01633 Mdot
.30016 .01633 Mdot
.30017 .01634 Mdot
.30018 .01634 Mdot
.30019 .01634 Mdot
.3002 .01634 Mdot
.30021 .01634 Mdot
.30022 .01635 Mdot
.30023 .01635 Mdot
.30024 .01635 Mdot
.30025 .01635 Mdot
.30026 .01635 Mdot
.30027 .01636 Mdot
.30028 .01636 Mdot
.30029 .01636 Mdot
.3003 .01636 Mdot
.3003 .01636 Mdot
.30031 .01636 Mdot
.30032 .01637 Mdot
.30033 .01637 Mdot
.30034 .01637 Mdot
.30035 .01637 Mdot
.30036 .01637 Mdot
.30037 .01638 Mdot
.30038 .01638 Mdot
.30039 .01638 Mdot
.3004 .01638 Mdot
.30041 .01638 Mdot
.30042 .01639 Mdot
.30043 .01639 Mdot
.30044 .01639 Mdot
.30045 .01639 Mdot
.30046 .01639 Mdot
.30047 .0164 Mdot
.30048 .0164 Mdot
.30049 .0164 Mdot
.3005 .0164 Mdot
.3005 .0164 Mdot
.30051 .0164 Mdot
.30052 .01641 Mdot
.30053 .01641 Mdot
.30054 .01641 Mdot
.30055 .01641 Mdot
.30056 .01641 Mdot
.30057 .01642 Mdot
.30058 .01642 Mdot
.30059 .01642 Mdot
.3006 .01642 Mdot
.30061 .01642 Mdot
.30062 .01643 Mdot
.30063 .01643 Mdot
.30064 .01643 Mdot
.30065 .01643 Mdot
.30066 .01643 Mdot
.30067 .01644 Mdot
.30068 .01644 Mdot
.30069 .01644 Mdot
.3007 .01644 Mdot
.3007 .01644 Mdot
.30071 .01645 Mdot
.30072 .01645 Mdot
.30073 .01645 Mdot
.30074 .01645 Mdot
.30075 .01645 Mdot
.30076 .01646 Mdot
.30077 .01646 Mdot
.30078 .01646 Mdot
.30079 .01646 Mdot
.3008 .01646 Mdot
.30081 .01647 Mdot
.30082 .01647 Mdot
.30083 .01647 Mdot
.30084 .01647 Mdot
.30085 .01647 Mdot
.30086 .01647 Mdot
.30087 .01648 Mdot
.30088 .01648 Mdot
.30089 .01648 Mdot
.3009 .01648 Mdot
.3009 .01648 Mdot
.30091 .01649 Mdot
.30092 .01649 Mdot
.30093 .01649 Mdot
.30094 .01649 Mdot
.30095 .01649 Mdot
.30096 .0165 Mdot
.30097 .0165 Mdot
.30098 .0165 Mdot
.30099 .0165 Mdot
.301 .0165 Mdot
.30101 .01651 Mdot
.30102 .01651 Mdot
.30103 .01651 Mdot
.30104 .01651 Mdot
.30105 .01651 Mdot
.30106 .01652 Mdot
.30107 .01652 Mdot
.30108 .01652 Mdot
.30109 .01652 Mdot
.3011 .01652 Mdot
.3011 .01653 Mdot
.30111 .01653 Mdot
.30112 .01653 Mdot
.30113 .01653 Mdot
.30114 .01653 Mdot
.30115 .01654 Mdot
.30116 .01654 Mdot
.30117 .01654 Mdot
.30118 .01654 Mdot
.30119 .01654 Mdot
.3012 .01655 Mdot
.30121 .01655 Mdot
.30122 .01655 Mdot
.30123 .01655 Mdot
.30124 .01655 Mdot
.30125 .01656 Mdot
.30126 .01656 Mdot
.30127 .01656 Mdot
.30128 .01656 Mdot
.30129 .01656 Mdot
.3013 .01657 Mdot
.3013 .01657 Mdot
.30131 .01657 Mdot
.30132 .01657 Mdot
.30133 .01657 Mdot
.30134 .01658 Mdot
.30135 .01658 Mdot
.30136 .01658 Mdot
.30137 .01658 Mdot
.30138 .01658 Mdot
.30139 .01659 Mdot
.3014 .01659 Mdot
.30141 .01659 Mdot
.30142 .01659 Mdot
.30143 .0166 Mdot
.30144 .0166 Mdot
.30145 .0166 Mdot
.30146 .0166 Mdot
.30147 .0166 Mdot
.30148 .01661 Mdot
.30149 .01661 Mdot
.3015 .01661 Mdot
.3015 .01661 Mdot
.30151 .01661 Mdot
.30152 .01662 Mdot
.30153 .01662 Mdot
.30154 .01662 Mdot
.30155 .01662 Mdot
.30156 .01662 Mdot
.30157 .01663 Mdot
.30158 .01663 Mdot
.30159 .01663 Mdot
.3016 .01663 Mdot
.30161 .01663 Mdot
.30162 .01664 Mdot
.30163 .01664 Mdot
.30164 .01664 Mdot
.30165 .01664 Mdot
.30166 .01664 Mdot
.30167 .01665 Mdot
.30168 .01665 Mdot
.30169 .01665 Mdot
.3017 .01665 Mdot
.3017 .01665 Mdot
.30171 .01666 Mdot
.30172 .01666 Mdot
.30173 .01666 Mdot
.30174 .01666 Mdot
.30175 .01666 Mdot
.30176 .01667 Mdot
.30177 .01667 Mdot
.30178 .01667 Mdot
.30179 .01667 Mdot
.3018 .01668 Mdot
.30181 .01668 Mdot
.30182 .01668 Mdot
.30183 .01668 Mdot
.30184 .01668 Mdot
.30185 .01669 Mdot
.30186 .01669 Mdot
.30187 .01669 Mdot
.30188 .01669 Mdot
.30189 .01669 Mdot
.3019 .0167 Mdot
.3019 .0167 Mdot
.30191 .0167 Mdot
.30192 .0167 Mdot
.30193 .0167 Mdot
.30194 .01671 Mdot
.30195 .01671 Mdot
.30196 .01671 Mdot
.30197 .01671 Mdot
.30198 .01671 Mdot
.30199 .01672 Mdot
.302 .01672 Mdot
.30201 .01672 Mdot
.30202 .01672 Mdot
.30203 .01673 Mdot
.30204 .01673 Mdot
.30205 .01673 Mdot
.30206 .01673 Mdot
.30207 .01673 Mdot
.30208 .01674 Mdot
.30209 .01674 Mdot
.3021 .01674 Mdot
.3021 .01674 Mdot
.30211 .01674 Mdot
.30212 .01675 Mdot
.30213 .01675 Mdot
.30214 .01675 Mdot
.30215 .01675 Mdot
.30216 .01676 Mdot
.30217 .01676 Mdot
.30218 .01676 Mdot
.30219 .01676 Mdot
.3022 .01676 Mdot
.30221 .01677 Mdot
.30222 .01677 Mdot
.30223 .01677 Mdot
.30224 .01677 Mdot
.30225 .01677 Mdot
.30226 .01678 Mdot
.30227 .01678 Mdot
.30228 .01678 Mdot
.30229 .01678 Mdot
.3023 .01678 Mdot
.3023 .01679 Mdot
.30231 .01679 Mdot
.30232 .01679 Mdot
.30233 .01679 Mdot
.30234 .0168 Mdot
.30235 .0168 Mdot
.30236 .0168 Mdot
.30237 .0168 Mdot
.30238 .0168 Mdot
.30239 .01681 Mdot
.3024 .01681 Mdot
.30241 .01681 Mdot
.30242 .01681 Mdot
.30243 .01681 Mdot
.30244 .01682 Mdot
.30245 .01682 Mdot
.30246 .01682 Mdot
.30247 .01682 Mdot
.30248 .01683 Mdot
.30249 .01683 Mdot
.3025 .01683 Mdot
.3025 .01683 Mdot
.30251 .01683 Mdot
.30252 .01684 Mdot
.30253 .01684 Mdot
.30254 .01684 Mdot
.30255 .01684 Mdot
.30256 .01685 Mdot
.30257 .01685 Mdot
.30258 .01685 Mdot
.30259 .01685 Mdot
.3026 .01685 Mdot
.30261 .01686 Mdot
.30262 .01686 Mdot
.30263 .01686 Mdot
.30264 .01686 Mdot
.30265 .01686 Mdot
.30266 .01687 Mdot
.30267 .01687 Mdot
.30268 .01687 Mdot
.30269 .01687 Mdot
.3027 .01688 Mdot
.3027 .01688 Mdot
.30271 .01688 Mdot
.30272 .01688 Mdot
.30273 .01688 Mdot
.30274 .01689 Mdot
.30275 .01689 Mdot
.30276 .01689 Mdot
.30277 .01689 Mdot
.30278 .0169 Mdot
.30279 .0169 Mdot
.3028 .0169 Mdot
.30281 .0169 Mdot
.30282 .0169 Mdot
.30283 .01691 Mdot
.30284 .01691 Mdot
.30285 .01691 Mdot
.30286 .01691 Mdot
.30287 .01692 Mdot
.30288 .01692 Mdot
.30289 .01692 Mdot
.3029 .01692 Mdot
.3029 .01692 Mdot
.30291 .01693 Mdot
.30292 .01693 Mdot
.30293 .01693 Mdot
.30294 .01693 Mdot
.30295 .01693 Mdot
.30296 .01694 Mdot
.30297 .01694 Mdot
.30298 .01694 Mdot
.30299 .01694 Mdot
.303 .01695 Mdot
.30301 .01695 Mdot
.30302 .01695 Mdot
.30303 .01695 Mdot
.30304 .01695 Mdot
.30305 .01696 Mdot
.30306 .01696 Mdot
.30307 .01696 Mdot
.30308 .01696 Mdot
.30309 .01697 Mdot
.3031 .01697 Mdot
.3031 .01697 Mdot
.30311 .01697 Mdot
.30312 .01697 Mdot
.30313 .01698 Mdot
.30314 .01698 Mdot
.30315 .01698 Mdot
.30316 .01698 Mdot
.30317 .01699 Mdot
.30318 .01699 Mdot
.30319 .01699 Mdot
.3032 .01699 Mdot
.30321 .017 Mdot
.30322 .017 Mdot
.30323 .017 Mdot
.30324 .017 Mdot
.30325 .017 Mdot
.30326 .01701 Mdot
.30327 .01701 Mdot
.30328 .01701 Mdot
.30329 .01701 Mdot
.3033 .01702 Mdot
.3033 .01702 Mdot
.30331 .01702 Mdot
.30332 .01702 Mdot
.30333 .01702 Mdot
.30334 .01703 Mdot
.30335 .01703 Mdot
.30336 .01703 Mdot
.30337 .01703 Mdot
.30338 .01704 Mdot
.30339 .01704 Mdot
.3034 .01704 Mdot
.30341 .01704 Mdot
.30342 .01704 Mdot
.30343 .01705 Mdot
.30344 .01705 Mdot
.30345 .01705 Mdot
.30346 .01705 Mdot
.30347 .01706 Mdot
.30348 .01706 Mdot
.30349 .01706 Mdot
.3035 .01706 Mdot
.3035 .01707 Mdot
.30351 .01707 Mdot
.30352 .01707 Mdot
.30353 .01707 Mdot
.30354 .01707 Mdot
.30355 .01708 Mdot
.30356 .01708 Mdot
.30357 .01708 Mdot
.30358 .01708 Mdot
.30359 .01709 Mdot
.3036 .01709 Mdot
.30361 .01709 Mdot
.30362 .01709 Mdot
.30363 .01709 Mdot
.30364 .0171 Mdot
.30365 .0171 Mdot
.30366 .0171 Mdot
.30367 .0171 Mdot
.30368 .01711 Mdot
.30369 .01711 Mdot
.3037 .01711 Mdot
.3037 .01711 Mdot
.30371 .01712 Mdot
.30372 .01712 Mdot
.30373 .01712 Mdot
.30374 .01712 Mdot
.30375 .01712 Mdot
.30376 .01713 Mdot
.30377 .01713 Mdot
.30378 .01713 Mdot
.30379 .01713 Mdot
.3038 .01714 Mdot
.30381 .01714 Mdot
.30382 .01714 Mdot
.30383 .01714 Mdot
.30384 .01715 Mdot
.30385 .01715 Mdot
.30386 .01715 Mdot
.30387 .01715 Mdot
.30388 .01715 Mdot
.30389 .01716 Mdot
.3039 .01716 Mdot
.3039 .01716 Mdot
.30391 .01716 Mdot
.30392 .01717 Mdot
.30393 .01717 Mdot
.30394 .01717 Mdot
.30395 .01717 Mdot
.30396 .01718 Mdot
.30397 .01718 Mdot
.30398 .01718 Mdot
.30399 .01718 Mdot
.304 .01719 Mdot
.30401 .01719 Mdot
.30402 .01719 Mdot
.30403 .01719 Mdot
.30404 .01719 Mdot
.30405 .0172 Mdot
.30406 .0172 Mdot
.30407 .0172 Mdot
.30408 .0172 Mdot
.30409 .01721 Mdot
.3041 .01721 Mdot
.3041 .01721 Mdot
.30411 .01721 Mdot
.30412 .01722 Mdot
.30413 .01722 Mdot
.30414 .01722 Mdot
.30415 .01722 Mdot
.30416 .01723 Mdot
.30417 .01723 Mdot
.30418 .01723 Mdot
.30419 .01723 Mdot
.3042 .01723 Mdot
.30421 .01724 Mdot
.30422 .01724 Mdot
.30423 .01724 Mdot
.30424 .01724 Mdot
.30425 .01725 Mdot
.30426 .01725 Mdot
.30427 .01725 Mdot
.30428 .01725 Mdot
.30429 .01726 Mdot
.3043 .01726 Mdot
.3043 .01726 Mdot
.30431 .01726 Mdot
.30432 .01727 Mdot
.30433 .01727 Mdot
.30434 .01727 Mdot
.30435 .01727 Mdot
.30436 .01727 Mdot
.30437 .01728 Mdot
.30438 .01728 Mdot
.30439 .01728 Mdot
.3044 .01728 Mdot
.30441 .01729 Mdot
.30442 .01729 Mdot
.30443 .01729 Mdot
.30444 .01729 Mdot
.30445 .0173 Mdot
.30446 .0173 Mdot
.30447 .0173 Mdot
.30448 .0173 Mdot
.30449 .01731 Mdot
.3045 .01731 Mdot
.3045 .01731 Mdot
.30451 .01731 Mdot
.30452 .01732 Mdot
.30453 .01732 Mdot
.30454 .01732 Mdot
.30455 .01732 Mdot
.30456 .01732 Mdot
.30457 .01733 Mdot
.30458 .01733 Mdot
.30459 .01733 Mdot
.3046 .01733 Mdot
.30461 .01734 Mdot
.30462 .01734 Mdot
.30463 .01734 Mdot
.30464 .01734 Mdot
.30465 .01735 Mdot
.30466 .01735 Mdot
.30467 .01735 Mdot
.30468 .01735 Mdot
.30469 .01736 Mdot
.3047 .01736 Mdot
.3047 .01736 Mdot
.30471 .01736 Mdot
.30472 .01737 Mdot
.30473 .01737 Mdot
.30474 .01737 Mdot
.30475 .01737 Mdot
.30476 .01738 Mdot
.30477 .01738 Mdot
.30478 .01738 Mdot
.30479 .01738 Mdot
.3048 .01739 Mdot
.30481 .01739 Mdot
.30482 .01739 Mdot
.30483 .01739 Mdot
.30484 .0174 Mdot
.30485 .0174 Mdot
.30486 .0174 Mdot
.30487 .0174 Mdot
.30488 .0174 Mdot
.30489 .01741 Mdot
.3049 .01741 Mdot
.3049 .01741 Mdot
.30491 .01741 Mdot
.30492 .01742 Mdot
.30493 .01742 Mdot
.30494 .01742 Mdot
.30495 .01742 Mdot
.30496 .01743 Mdot
.30497 .01743 Mdot
.30498 .01743 Mdot
.30499 .01743 Mdot
.305 .01744 Mdot
.30501 .01744 Mdot
.30502 .01744 Mdot
.30503 .01744 Mdot
.30504 .01745 Mdot
.30505 .01745 Mdot
.30506 .01745 Mdot
.30507 .01745 Mdot
.30508 .01746 Mdot
.30509 .01746 Mdot
.3051 .01746 Mdot
.3051 .01746 Mdot
.30511 .01747 Mdot
.30512 .01747 Mdot
.30513 .01747 Mdot
.30514 .01747 Mdot
.30515 .01748 Mdot
.30516 .01748 Mdot
.30517 .01748 Mdot
.30518 .01748 Mdot
.30519 .01749 Mdot
.3052 .01749 Mdot
.30521 .01749 Mdot
.30522 .01749 Mdot
.30523 .0175 Mdot
.30524 .0175 Mdot
.30525 .0175 Mdot
.30526 .0175 Mdot
.30527 .01751 Mdot
.30528 .01751 Mdot
.30529 .01751 Mdot
.3053 .01751 Mdot
.3053 .01752 Mdot
.30531 .01752 Mdot
.30532 .01752 Mdot
.30533 .01752 Mdot
.30534 .01753 Mdot
.30535 .01753 Mdot
.30536 .01753 Mdot
.30537 .01753 Mdot
.30538 .01754 Mdot
.30539 .01754 Mdot
.3054 .01754 Mdot
.30541 .01754 Mdot
.30542 .01755 Mdot
.30543 .01755 Mdot
.30544 .01755 Mdot
.30545 .01755 Mdot
.30546 .01756 Mdot
.30547 .01756 Mdot
.30548 .01756 Mdot
.30549 .01756 Mdot
.3055 .01757 Mdot
.3055 .01757 Mdot
.30551 .01757 Mdot
.30552 .01757 Mdot
.30553 .01758 Mdot
.30554 .01758 Mdot
.30555 .01758 Mdot
.30556 .01758 Mdot
.30557 .01759 Mdot
.30558 .01759 Mdot
.30559 .01759 Mdot
.3056 .01759 Mdot
.30561 .0176 Mdot
.30562 .0176 Mdot
.30563 .0176 Mdot
.30564 .0176 Mdot
.30565 .01761 Mdot
.30566 .01761 Mdot
.30567 .01761 Mdot
.30568 .01761 Mdot
.30569 .01762 Mdot
.3057 .01762 Mdot
.3057 .01762 Mdot
.30571 .01762 Mdot
.30572 .01763 Mdot
.30573 .01763 Mdot
.30574 .01763 Mdot
.30575 .01763 Mdot
.30576 .01764 Mdot
.30577 .01764 Mdot
.30578 .01764 Mdot
.30579 .01764 Mdot
.3058 .01765 Mdot
.30581 .01765 Mdot
.30582 .01765 Mdot
.30583 .01765 Mdot
.30584 .01766 Mdot
.30585 .01766 Mdot
.30586 .01766 Mdot
.30587 .01766 Mdot
.30588 .01767 Mdot
.30589 .01767 Mdot
.3059 .01767 Mdot
.3059 .01767 Mdot
.30591 .01768 Mdot
.30592 .01768 Mdot
.30593 .01768 Mdot
.30594 .01768 Mdot
.30595 .01769 Mdot
.30596 .01769 Mdot
.30597 .01769 Mdot
.30598 .0177 Mdot
.30599 .0177 Mdot
.306 .0177 Mdot
.30601 .0177 Mdot
.30602 .01771 Mdot
.30603 .01771 Mdot
.30604 .01771 Mdot
.30605 .01771 Mdot
.30606 .01772 Mdot
.30607 .01772 Mdot
.30608 .01772 Mdot
.30609 .01772 Mdot
.3061 .01773 Mdot
.3061 .01773 Mdot
.30611 .01773 Mdot
.30612 .01773 Mdot
.30613 .01774 Mdot
.30614 .01774 Mdot
.30615 .01774 Mdot
.30616 .01774 Mdot
.30617 .01775 Mdot
.30618 .01775 Mdot
.30619 .01775 Mdot
.3062 .01775 Mdot
.30621 .01776 Mdot
.30622 .01776 Mdot
.30623 .01776 Mdot
.30624 .01776 Mdot
.30625 .01777 Mdot
.30626 .01777 Mdot
.30627 .01777 Mdot
.30628 .01778 Mdot
.30629 .01778 Mdot
.3063 .01778 Mdot
.3063 .01778 Mdot
.30631 .01779 Mdot
.30632 .01779 Mdot
.30633 .01779 Mdot
.30634 .01779 Mdot
.30635 .0178 Mdot
.30636 .0178 Mdot
.30637 .0178 Mdot
.30638 .0178 Mdot
.30639 .01781 Mdot
.3064 .01781 Mdot
.30641 .01781 Mdot
.30642 .01781 Mdot
.30643 .01782 Mdot
.30644 .01782 Mdot
.30645 .01782 Mdot
.30646 .01783 Mdot
.30647 .01783 Mdot
.30648 .01783 Mdot
.30649 .01783 Mdot
.3065 .01784 Mdot
.3065 .01784 Mdot
.30651 .01784 Mdot
.30652 .01784 Mdot
.30653 .01785 Mdot
.30654 .01785 Mdot
.30655 .01785 Mdot
.30656 .01785 Mdot
.30657 .01786 Mdot
.30658 .01786 Mdot
.30659 .01786 Mdot
.3066 .01786 Mdot
.30661 .01787 Mdot
.30662 .01787 Mdot
.30663 .01787 Mdot
.30664 .01788 Mdot
.30665 .01788 Mdot
.30666 .01788 Mdot
.30667 .01788 Mdot
.30668 .01789 Mdot
.30669 .01789 Mdot
.3067 .01789 Mdot
.3067 .01789 Mdot
.30671 .0179 Mdot
.30672 .0179 Mdot
.30673 .0179 Mdot
.30674 .0179 Mdot
.30675 .01791 Mdot
.30676 .01791 Mdot
.30677 .01791 Mdot
.30678 .01791 Mdot
.30679 .01792 Mdot
.3068 .01792 Mdot
.30681 .01792 Mdot
.30682 .01793 Mdot
.30683 .01793 Mdot
.30684 .01793 Mdot
.30685 .01793 Mdot
.30686 .01794 Mdot
.30687 .01794 Mdot
.30688 .01794 Mdot
.30689 .01794 Mdot
.3069 .01795 Mdot
.3069 .01795 Mdot
.30691 .01795 Mdot
.30692 .01796 Mdot
.30693 .01796 Mdot
.30694 .01796 Mdot
.30695 .01796 Mdot
.30696 .01797 Mdot
.30697 .01797 Mdot
.30698 .01797 Mdot
.30699 .01797 Mdot
.307 .01798 Mdot
.30701 .01798 Mdot
.30702 .01798 Mdot
.30703 .01798 Mdot
.30704 .01799 Mdot
.30705 .01799 Mdot
.30706 .01799 Mdot
.30707 .018 Mdot
.30708 .018 Mdot
.30709 .018 Mdot
.3071 .018 Mdot
.3071 .01801 Mdot
.30711 .01801 Mdot
.30712 .01801 Mdot
.30713 .01801 Mdot
.30714 .01802 Mdot
.30715 .01802 Mdot
.30716 .01802 Mdot
.30717 .01803 Mdot
.30718 .01803 Mdot
.30719 .01803 Mdot
.3072 .01803 Mdot
.30721 .01804 Mdot
.30722 .01804 Mdot
.30723 .01804 Mdot
.30724 .01804 Mdot
.30725 .01805 Mdot
.30726 .01805 Mdot
.30727 .01805 Mdot
.30728 .01805 Mdot
.30729 .01806 Mdot
.3073 .01806 Mdot
.3073 .01806 Mdot
.30731 .01807 Mdot
.30732 .01807 Mdot
.30733 .01807 Mdot
.30734 .01807 Mdot
.30735 .01808 Mdot
.30736 .01808 Mdot
.30737 .01808 Mdot
.30738 .01808 Mdot
.30739 .01809 Mdot
.3074 .01809 Mdot
.30741 .01809 Mdot
.30742 .0181 Mdot
.30743 .0181 Mdot
.30744 .0181 Mdot
.30745 .0181 Mdot
.30746 .01811 Mdot
.30747 .01811 Mdot
.30748 .01811 Mdot
.30749 .01812 Mdot
.3075 .01812 Mdot
.3075 .01812 Mdot
.30751 .01812 Mdot
.30752 .01813 Mdot
.30753 .01813 Mdot
.30754 .01813 Mdot
.30755 .01813 Mdot
.30756 .01814 Mdot
.30757 .01814 Mdot
.30758 .01814 Mdot
.30759 .01815 Mdot
.3076 .01815 Mdot
.30761 .01815 Mdot
.30762 .01815 Mdot
.30763 .01816 Mdot
.30764 .01816 Mdot
.30765 .01816 Mdot
.30766 .01816 Mdot
.30767 .01817 Mdot
.30768 .01817 Mdot
.30769 .01817 Mdot
.3077 .01818 Mdot
.3077 .01818 Mdot
.30771 .01818 Mdot
.30772 .01818 Mdot
.30773 .01819 Mdot
.30774 .01819 Mdot
.30775 .01819 Mdot
.30776 .0182 Mdot
.30777 .0182 Mdot
.30778 .0182 Mdot
.30779 .0182 Mdot
.3078 .01821 Mdot
.30781 .01821 Mdot
.30782 .01821 Mdot
.30783 .01821 Mdot
.30784 .01822 Mdot
.30785 .01822 Mdot
.30786 .01822 Mdot
.30787 .01823 Mdot
.30788 .01823 Mdot
.30789 .01823 Mdot
.3079 .01823 Mdot
.3079 .01824 Mdot
.30791 .01824 Mdot
.30792 .01824 Mdot
.30793 .01825 Mdot
.30794 .01825 Mdot
.30795 .01825 Mdot
.30796 .01825 Mdot
.30797 .01826 Mdot
.30798 .01826 Mdot
.30799 .01826 Mdot
.308 .01827 Mdot
.30801 .01827 Mdot
.30802 .01827 Mdot
.30803 .01827 Mdot
.30804 .01828 Mdot
.30805 .01828 Mdot
.30806 .01828 Mdot
.30807 .01828 Mdot
.30808 .01829 Mdot
.30809 .01829 Mdot
.3081 .01829 Mdot
.3081 .0183 Mdot
.30811 .0183 Mdot
.30812 .0183 Mdot
.30813 .0183 Mdot
.30814 .01831 Mdot
.30815 .01831 Mdot
.30816 .01831 Mdot
.30817 .01832 Mdot
.30818 .01832 Mdot
.30819 .01832 Mdot
.3082 .01832 Mdot
.30821 .01833 Mdot
.30822 .01833 Mdot
.30823 .01833 Mdot
.30824 .01834 Mdot
.30825 .01834 Mdot
.30826 .01834 Mdot
.30827 .01834 Mdot
.30828 .01835 Mdot
.30829 .01835 Mdot
.3083 .01835 Mdot
.3083 .01836 Mdot
.30831 .01836 Mdot
.30832 .01836 Mdot
.30833 .01836 Mdot
.30834 .01837 Mdot
.30835 .01837 Mdot
.30836 .01837 Mdot
.30837 .01838 Mdot
.30838 .01838 Mdot
.30839 .01838 Mdot
.3084 .01838 Mdot
.30841 .01839 Mdot
.30842 .01839 Mdot
.30843 .01839 Mdot
.30844 .0184 Mdot
.30845 .0184 Mdot
.30846 .0184 Mdot
.30847 .0184 Mdot
.30848 .01841 Mdot
.30849 .01841 Mdot
.3085 .01841 Mdot
.3085 .01842 Mdot
.30851 .01842 Mdot
.30852 .01842 Mdot
.30853 .01842 Mdot
.30854 .01843 Mdot
.30855 .01843 Mdot
.30856 .01843 Mdot
.30857 .01844 Mdot
.30858 .01844 Mdot
.30859 .01844 Mdot
.3086 .01844 Mdot
.30861 .01845 Mdot
.30862 .01845 Mdot
.30863 .01845 Mdot
.30864 .01846 Mdot
.30865 .01846 Mdot
.30866 .01846 Mdot
.30867 .01846 Mdot
.30868 .01847 Mdot
.30869 .01847 Mdot
.3087 .01847 Mdot
.3087 .01848 Mdot
.30871 .01848 Mdot
.30872 .01848 Mdot
.30873 .01848 Mdot
.30874 .01849 Mdot
.30875 .01849 Mdot
.30876 .01849 Mdot
.30877 .0185 Mdot
.30878 .0185 Mdot
.30879 .0185 Mdot
.3088 .0185 Mdot
.30881 .01851 Mdot
.30882 .01851 Mdot
.30883 .01851 Mdot
.30884 .01852 Mdot
.30885 .01852 Mdot
.30886 .01852 Mdot
.30887 .01853 Mdot
.30888 .01853 Mdot
.30889 .01853 Mdot
.3089 .01853 Mdot
.3089 .01854 Mdot
.30891 .01854 Mdot
.30892 .01854 Mdot
.30893 .01855 Mdot
.30894 .01855 Mdot
.30895 .01855 Mdot
.30896 .01855 Mdot
.30897 .01856 Mdot
.30898 .01856 Mdot
.30899 .01856 Mdot
.309 .01857 Mdot
.30901 .01857 Mdot
.30902 .01857 Mdot
.30903 .01857 Mdot
.30904 .01858 Mdot
.30905 .01858 Mdot
.30906 .01858 Mdot
.30907 .01859 Mdot
.30908 .01859 Mdot
.30909 .01859 Mdot
.3091 .0186 Mdot
.3091 .0186 Mdot
.30911 .0186 Mdot
.30912 .0186 Mdot
.30913 .01861 Mdot
.30914 .01861 Mdot
.30915 .01861 Mdot
.30916 .01862 Mdot
.30917 .01862 Mdot
.30918 .01862 Mdot
.30919 .01862 Mdot
.3092 .01863 Mdot
.30921 .01863 Mdot
.30922 .01863 Mdot
.30923 .01864 Mdot
.30924 .01864 Mdot
.30925 .01864 Mdot
.30926 .01865 Mdot
.30927 .01865 Mdot
.30928 .01865 Mdot
.30929 .01865 Mdot
.3093 .01866 Mdot
.3093 .01866 Mdot
.30931 .01866 Mdot
.30932 .01867 Mdot
.30933 .01867 Mdot
.30934 .01867 Mdot
.30935 .01867 Mdot
.30936 .01868 Mdot
.30937 .01868 Mdot
.30938 .01868 Mdot
.30939 .01869 Mdot
.3094 .01869 Mdot
.30941 .01869 Mdot
.30942 .0187 Mdot
.30943 .0187 Mdot
.30944 .0187 Mdot
.30945 .0187 Mdot
.30946 .01871 Mdot
.30947 .01871 Mdot
.30948 .01871 Mdot
.30949 .01872 Mdot
.3095 .01872 Mdot
.3095 .01872 Mdot
.30951 .01873 Mdot
.30952 .01873 Mdot
.30953 .01873 Mdot
.30954 .01873 Mdot
.30955 .01874 Mdot
.30956 .01874 Mdot
.30957 .01874 Mdot
.30958 .01875 Mdot
.30959 .01875 Mdot
.3096 .01875 Mdot
.30961 .01876 Mdot
.30962 .01876 Mdot
.30963 .01876 Mdot
.30964 .01876 Mdot
.30965 .01877 Mdot
.30966 .01877 Mdot
.30967 .01877 Mdot
.30968 .01878 Mdot
.30969 .01878 Mdot
.3097 .01878 Mdot
.3097 .01879 Mdot
.30971 .01879 Mdot
.30972 .01879 Mdot
.30973 .01879 Mdot
.30974 .0188 Mdot
.30975 .0188 Mdot
.30976 .0188 Mdot
.30977 .01881 Mdot
.30978 .01881 Mdot
.30979 .01881 Mdot
.3098 .01882 Mdot
.30981 .01882 Mdot
.30982 .01882 Mdot
.30983 .01882 Mdot
.30984 .01883 Mdot
.30985 .01883 Mdot
.30986 .01883 Mdot
.30987 .01884 Mdot
.30988 .01884 Mdot
.30989 .01884 Mdot
.3099 .01885 Mdot
.3099 .01885 Mdot
.30991 .01885 Mdot
.30992 .01885 Mdot
.30993 .01886 Mdot
.30994 .01886 Mdot
.30995 .01886 Mdot
.30996 .01887 Mdot
.30997 .01887 Mdot
.30998 .01887 Mdot
.30999 .01888 Mdot
.31 .01888 Mdot
.31001 .01888 Mdot
.31002 .01889 Mdot
.31003 .01889 Mdot
.31004 .01889 Mdot
.31005 .01889 Mdot
.31006 .0189 Mdot
.31007 .0189 Mdot
.31008 .0189 Mdot
.31009 .01891 Mdot
.3101 .01891 Mdot
.3101 .01891 Mdot
.31011 .01892 Mdot
.31012 .01892 Mdot
.31013 .01892 Mdot
.31014 .01893 Mdot
.31015 .01893 Mdot
.31016 .01893 Mdot
.31017 .01893 Mdot
.31018 .01894 Mdot
.31019 .01894 Mdot
.3102 .01894 Mdot
.31021 .01895 Mdot
.31022 .01895 Mdot
.31023 .01895 Mdot
.31024 .01896 Mdot
.31025 .01896 Mdot
.31026 .01896 Mdot
.31027 .01896 Mdot
.31028 .01897 Mdot
.31029 .01897 Mdot
.3103 .01897 Mdot
.3103 .01898 Mdot
.31031 .01898 Mdot
.31032 .01898 Mdot
.31033 .01899 Mdot
.31034 .01899 Mdot
.31035 .01899 Mdot
.31036 .019 Mdot
.31037 .019 Mdot
.31038 .019 Mdot
.31039 .01901 Mdot
.3104 .01901 Mdot
.31041 .01901 Mdot
.31042 .01901 Mdot
.31043 .01902 Mdot
.31044 .01902 Mdot
.31045 .01902 Mdot
.31046 .01903 Mdot
.31047 .01903 Mdot
.31048 .01903 Mdot
.31049 .01904 Mdot
.3105 .01904 Mdot
.3105 .01904 Mdot
.31051 .01905 Mdot
.31052 .01905 Mdot
.31053 .01905 Mdot
.31054 .01905 Mdot
.31055 .01906 Mdot
.31056 .01906 Mdot
.31057 .01906 Mdot
.31058 .01907 Mdot
.31059 .01907 Mdot
.3106 .01907 Mdot
.31061 .01908 Mdot
.31062 .01908 Mdot
.31063 .01908 Mdot
.31064 .01909 Mdot
.31065 .01909 Mdot
.31066 .01909 Mdot
.31067 .0191 Mdot
.31068 .0191 Mdot
.31069 .0191 Mdot
.3107 .0191 Mdot
.3107 .01911 Mdot
.31071 .01911 Mdot
.31072 .01911 Mdot
.31073 .01912 Mdot
.31074 .01912 Mdot
.31075 .01912 Mdot
.31076 .01913 Mdot
.31077 .01913 Mdot
.31078 .01913 Mdot
.31079 .01914 Mdot
.3108 .01914 Mdot
.31081 .01914 Mdot
.31082 .01915 Mdot
.31083 .01915 Mdot
.31084 .01915 Mdot
.31085 .01915 Mdot
.31086 .01916 Mdot
.31087 .01916 Mdot
.31088 .01916 Mdot
.31089 .01917 Mdot
.3109 .01917 Mdot
.3109 .01917 Mdot
.31091 .01918 Mdot
.31092 .01918 Mdot
.31093 .01918 Mdot
.31094 .01919 Mdot
.31095 .01919 Mdot
.31096 .01919 Mdot
.31097 .0192 Mdot
.31098 .0192 Mdot
.31099 .0192 Mdot
.311 .01921 Mdot
.31101 .01921 Mdot
.31102 .01921 Mdot
.31103 .01921 Mdot
.31104 .01922 Mdot
.31105 .01922 Mdot
.31106 .01922 Mdot
.31107 .01923 Mdot
.31108 .01923 Mdot
.31109 .01923 Mdot
.3111 .01924 Mdot
.3111 .01924 Mdot
.31111 .01924 Mdot
.31112 .01925 Mdot
.31113 .01925 Mdot
.31114 .01925 Mdot
.31115 .01926 Mdot
.31116 .01926 Mdot
.31117 .01926 Mdot
.31118 .01927 Mdot
.31119 .01927 Mdot
.3112 .01927 Mdot
.31121 .01927 Mdot
.31122 .01928 Mdot
.31123 .01928 Mdot
.31124 .01928 Mdot
.31125 .01929 Mdot
.31126 .01929 Mdot
.31127 .01929 Mdot
.31128 .0193 Mdot
.31129 .0193 Mdot
.3113 .0193 Mdot
.3113 .01931 Mdot
.31131 .01931 Mdot
.31132 .01931 Mdot
.31133 .01932 Mdot
.31134 .01932 Mdot
.31135 .01932 Mdot
.31136 .01933 Mdot
.31137 .01933 Mdot
.31138 .01933 Mdot
.31139 .01934 Mdot
.3114 .01934 Mdot
.31141 .01934 Mdot
.31142 .01935 Mdot
.31143 .01935 Mdot
.31144 .01935 Mdot
.31145 .01935 Mdot
.31146 .01936 Mdot
.31147 .01936 Mdot
.31148 .01936 Mdot
.31149 .01937 Mdot
.3115 .01937 Mdot
.3115 .01937 Mdot
.31151 .01938 Mdot
.31152 .01938 Mdot
.31153 .01938 Mdot
.31154 .01939 Mdot
.31155 .01939 Mdot
.31156 .01939 Mdot
.31157 .0194 Mdot
.31158 .0194 Mdot
.31159 .0194 Mdot
.3116 .01941 Mdot
.31161 .01941 Mdot
.31162 .01941 Mdot
.31163 .01942 Mdot
.31164 .01942 Mdot
.31165 .01942 Mdot
.31166 .01943 Mdot
.31167 .01943 Mdot
.31168 .01943 Mdot
.31169 .01944 Mdot
.3117 .01944 Mdot
.3117 .01944 Mdot
.31171 .01945 Mdot
.31172 .01945 Mdot
.31173 .01945 Mdot
.31174 .01946 Mdot
.31175 .01946 Mdot
.31176 .01946 Mdot
.31177 .01946 Mdot
.31178 .01947 Mdot
.31179 .01947 Mdot
.3118 .01947 Mdot
.31181 .01948 Mdot
.31182 .01948 Mdot
.31183 .01948 Mdot
.31184 .01949 Mdot
.31185 .01949 Mdot
.31186 .01949 Mdot
.31187 .0195 Mdot
.31188 .0195 Mdot
.31189 .0195 Mdot
.3119 .01951 Mdot
.3119 .01951 Mdot
.31191 .01951 Mdot
.31192 .01952 Mdot
.31193 .01952 Mdot
.31194 .01952 Mdot
.31195 .01953 Mdot
.31196 .01953 Mdot
.31197 .01953 Mdot
.31198 .01954 Mdot
.31199 .01954 Mdot
.312 .01954 Mdot
.31201 .01955 Mdot
.31202 .01955 Mdot
.31203 .01955 Mdot
.31204 .01956 Mdot
.31205 .01956 Mdot
.31206 .01956 Mdot
.31207 .01957 Mdot
.31208 .01957 Mdot
.31209 .01957 Mdot
.3121 .01958 Mdot
.3121 .01958 Mdot
.31211 .01958 Mdot
.31212 .01959 Mdot
.31213 .01959 Mdot
.31214 .01959 Mdot
.31215 .0196 Mdot
.31216 .0196 Mdot
.31217 .0196 Mdot
.31218 .01961 Mdot
.31219 .01961 Mdot
.3122 .01961 Mdot
.31221 .01962 Mdot
.31222 .01962 Mdot
.31223 .01962 Mdot
.31224 .01963 Mdot
.31225 .01963 Mdot
.31226 .01963 Mdot
.31227 .01964 Mdot
.31228 .01964 Mdot
.31229 .01964 Mdot
.3123 .01965 Mdot
.3123 .01965 Mdot
.31231 .01965 Mdot
.31232 .01966 Mdot
.31233 .01966 Mdot
.31234 .01966 Mdot
.31235 .01967 Mdot
.31236 .01967 Mdot
.31237 .01967 Mdot
.31238 .01968 Mdot
.31239 .01968 Mdot
.3124 .01968 Mdot
.31241 .01969 Mdot
.31242 .01969 Mdot
.31243 .01969 Mdot
.31244 .0197 Mdot
.31245 .0197 Mdot
.31246 .0197 Mdot
.31247 .01971 Mdot
.31248 .01971 Mdot
.31249 .01971 Mdot
.3125 .01972 Mdot
.3125 .01972 Mdot
.31251 .01972 Mdot
.31252 .01973 Mdot
.31253 .01973 Mdot
.31254 .01973 Mdot
.31255 .01974 Mdot
.31256 .01974 Mdot
.31257 .01974 Mdot
.31258 .01975 Mdot
.31259 .01975 Mdot
.3126 .01975 Mdot
.31261 .01976 Mdot
.31262 .01976 Mdot
.31263 .01976 Mdot
.31264 .01977 Mdot
.31265 .01977 Mdot
.31266 .01977 Mdot
.31267 .01978 Mdot
.31268 .01978 Mdot
.31269 .01978 Mdot
.3127 .01979 Mdot
.3127 .01979 Mdot
.31271 .01979 Mdot
.31272 .0198 Mdot
.31273 .0198 Mdot
.31274 .0198 Mdot
.31275 .01981 Mdot
.31276 .01981 Mdot
.31277 .01981 Mdot
.31278 .01982 Mdot
.31279 .01982 Mdot
.3128 .01982 Mdot
.31281 .01983 Mdot
.31282 .01983 Mdot
.31283 .01983 Mdot
.31284 .01984 Mdot
.31285 .01984 Mdot
.31286 .01984 Mdot
.31287 .01985 Mdot
.31288 .01985 Mdot
.31289 .01985 Mdot
.3129 .01986 Mdot
.3129 .01986 Mdot
.31291 .01986 Mdot
.31292 .01987 Mdot
.31293 .01987 Mdot
.31294 .01987 Mdot
.31295 .01988 Mdot
.31296 .01988 Mdot
.31297 .01988 Mdot
.31298 .01989 Mdot
.31299 .01989 Mdot
.313 .01989 Mdot
.31301 .0199 Mdot
.31302 .0199 Mdot
.31303 .0199 Mdot
.31304 .01991 Mdot
.31305 .01991 Mdot
.31306 .01991 Mdot
.31307 .01992 Mdot
.31308 .01992 Mdot
.31309 .01992 Mdot
.3131 .01993 Mdot
.3131 .01993 Mdot
.31311 .01993 Mdot
.31312 .01994 Mdot
.31313 .01994 Mdot
.31314 .01995 Mdot
.31315 .01995 Mdot
.31316 .01995 Mdot
.31317 .01996 Mdot
.31318 .01996 Mdot
.31319 .01996 Mdot
.3132 .01997 Mdot
.31321 .01997 Mdot
.31322 .01997 Mdot
.31323 .01998 Mdot
.31324 .01998 Mdot
.31325 .01998 Mdot
.31326 .01999 Mdot
.31327 .01999 Mdot
.31328 .01999 Mdot
.31329 .02 Mdot
.3133 .02 Mdot
.3133 .02 Mdot
.31331 .02001 Mdot
.31332 .02001 Mdot
.31333 .02001 Mdot
.31334 .02002 Mdot
.31335 .02002 Mdot
.31336 .02002 Mdot
.31337 .02003 Mdot
.31338 .02003 Mdot
.31339 .02003 Mdot
.3134 .02004 Mdot
.31341 .02004 Mdot
.31342 .02004 Mdot
.31343 .02005 Mdot
.31344 .02005 Mdot
.31345 .02005 Mdot
.31346 .02006 Mdot
.31347 .02006 Mdot
.31348 .02007 Mdot
.31349 .02007 Mdot
.3135 .02007 Mdot
.3135 .02008 Mdot
.31351 .02008 Mdot
.31352 .02008 Mdot
.31353 .02009 Mdot
.31354 .02009 Mdot
.31355 .02009 Mdot
.31356 .0201 Mdot
.31357 .0201 Mdot
.31358 .0201 Mdot
.31359 .02011 Mdot
.3136 .02011 Mdot
.31361 .02011 Mdot
.31362 .02012 Mdot
.31363 .02012 Mdot
.31364 .02012 Mdot
.31365 .02013 Mdot
.31366 .02013 Mdot
.31367 .02013 Mdot
.31368 .02014 Mdot
.31369 .02014 Mdot
.3137 .02015 Mdot
.3137 .02015 Mdot
.31371 .02015 Mdot
.31372 .02016 Mdot
.31373 .02016 Mdot
.31374 .02016 Mdot
.31375 .02017 Mdot
.31376 .02017 Mdot
.31377 .02017 Mdot
.31378 .02018 Mdot
.31379 .02018 Mdot
.3138 .02018 Mdot
.31381 .02019 Mdot
.31382 .02019 Mdot
.31383 .02019 Mdot
.31384 .0202 Mdot
.31385 .0202 Mdot
.31386 .0202 Mdot
.31387 .02021 Mdot
.31388 .02021 Mdot
.31389 .02022 Mdot
.3139 .02022 Mdot
.3139 .02022 Mdot
.31391 .02023 Mdot
.31392 .02023 Mdot
.31393 .02023 Mdot
.31394 .02024 Mdot
.31395 .02024 Mdot
.31396 .02024 Mdot
.31397 .02025 Mdot
.31398 .02025 Mdot
.31399 .02025 Mdot
.314 .02026 Mdot
.31401 .02026 Mdot
.31402 .02026 Mdot
.31403 .02027 Mdot
.31404 .02027 Mdot
.31405 .02027 Mdot
.31406 .02028 Mdot
.31407 .02028 Mdot
.31408 .02029 Mdot
.31409 .02029 Mdot
.3141 .02029 Mdot
.3141 .0203 Mdot
.31411 .0203 Mdot
.31412 .0203 Mdot
.31413 .02031 Mdot
.31414 .02031 Mdot
.31415 .02031 Mdot
.31416 .02032 Mdot
.31417 .02032 Mdot
.31418 .02032 Mdot
.31419 .02033 Mdot
.3142 .02033 Mdot
.31421 .02033 Mdot
.31422 .02034 Mdot
.31423 .02034 Mdot
.31424 .02035 Mdot
.31425 .02035 Mdot
.31426 .02035 Mdot
.31427 .02036 Mdot
.31428 .02036 Mdot
.31429 .02036 Mdot
.3143 .02037 Mdot
.3143 .02037 Mdot
.31431 .02037 Mdot
.31432 .02038 Mdot
.31433 .02038 Mdot
.31434 .02038 Mdot
.31435 .02039 Mdot
.31436 .02039 Mdot
.31437 .0204 Mdot
.31438 .0204 Mdot
.31439 .0204 Mdot
.3144 .02041 Mdot
.31441 .02041 Mdot
.31442 .02041 Mdot
.31443 .02042 Mdot
.31444 .02042 Mdot
.31445 .02042 Mdot
.31446 .02043 Mdot
.31447 .02043 Mdot
.31448 .02043 Mdot
.31449 .02044 Mdot
.3145 .02044 Mdot
.3145 .02045 Mdot
.31451 .02045 Mdot
.31452 .02045 Mdot
.31453 .02046 Mdot
.31454 .02046 Mdot
.31455 .02046 Mdot
.31456 .02047 Mdot
.31457 .02047 Mdot
.31458 .02047 Mdot
.31459 .02048 Mdot
.3146 .02048 Mdot
.31461 .02048 Mdot
.31462 .02049 Mdot
.31463 .02049 Mdot
.31464 .0205 Mdot
.31465 .0205 Mdot
.31466 .0205 Mdot
.31467 .02051 Mdot
.31468 .02051 Mdot
.31469 .02051 Mdot
.3147 .02052 Mdot
.3147 .02052 Mdot
.31471 .02052 Mdot
.31472 .02053 Mdot
.31473 .02053 Mdot
.31474 .02054 Mdot
.31475 .02054 Mdot
.31476 .02054 Mdot
.31477 .02055 Mdot
.31478 .02055 Mdot
.31479 .02055 Mdot
.3148 .02056 Mdot
.31481 .02056 Mdot
.31482 .02056 Mdot
.31483 .02057 Mdot
.31484 .02057 Mdot
.31485 .02057 Mdot
.31486 .02058 Mdot
.31487 .02058 Mdot
.31488 .02059 Mdot
.31489 .02059 Mdot
.3149 .02059 Mdot
.3149 .0206 Mdot
.31491 .0206 Mdot
.31492 .0206 Mdot
.31493 .02061 Mdot
.31494 .02061 Mdot
.31495 .02061 Mdot
.31496 .02062 Mdot
.31497 .02062 Mdot
.31498 .02063 Mdot
.31499 .02063 Mdot
.315 .02063 Mdot
.31501 .02064 Mdot
.31502 .02064 Mdot
.31503 .02064 Mdot
.31504 .02065 Mdot
.31505 .02065 Mdot
.31506 .02065 Mdot
.31507 .02066 Mdot
.31508 .02066 Mdot
.31509 .02067 Mdot
.3151 .02067 Mdot
.3151 .02067 Mdot
.31511 .02068 Mdot
.31512 .02068 Mdot
.31513 .02068 Mdot
.31514 .02069 Mdot
.31515 .02069 Mdot
.31516 .02069 Mdot
.31517 .0207 Mdot
.31518 .0207 Mdot
.31519 .02071 Mdot
.3152 .02071 Mdot
.31521 .02071 Mdot
.31522 .02072 Mdot
.31523 .02072 Mdot
.31524 .02072 Mdot
.31525 .02073 Mdot
.31526 .02073 Mdot
.31527 .02074 Mdot
.31528 .02074 Mdot
.31529 .02074 Mdot
.3153 .02075 Mdot
.3153 .02075 Mdot
.31531 .02075 Mdot
.31532 .02076 Mdot
.31533 .02076 Mdot
.31534 .02076 Mdot
.31535 .02077 Mdot
.31536 .02077 Mdot
.31537 .02078 Mdot
.31538 .02078 Mdot
.31539 .02078 Mdot
.3154 .02079 Mdot
.31541 .02079 Mdot
.31542 .02079 Mdot
.31543 .0208 Mdot
.31544 .0208 Mdot
.31545 .02081 Mdot
.31546 .02081 Mdot
.31547 .02081 Mdot
.31548 .02082 Mdot
.31549 .02082 Mdot
.3155 .02082 Mdot
.3155 .02083 Mdot
.31551 .02083 Mdot
.31552 .02083 Mdot
.31553 .02084 Mdot
.31554 .02084 Mdot
.31555 .02085 Mdot
.31556 .02085 Mdot
.31557 .02085 Mdot
.31558 .02086 Mdot
.31559 .02086 Mdot
.3156 .02086 Mdot
.31561 .02087 Mdot
.31562 .02087 Mdot
.31563 .02088 Mdot
.31564 .02088 Mdot
.31565 .02088 Mdot
.31566 .02089 Mdot
.31567 .02089 Mdot
.31568 .02089 Mdot
.31569 .0209 Mdot
.3157 .0209 Mdot
.3157 .02091 Mdot
.31571 .02091 Mdot
.31572 .02091 Mdot
.31573 .02092 Mdot
.31574 .02092 Mdot
.31575 .02092 Mdot
.31576 .02093 Mdot
.31577 .02093 Mdot
.31578 .02093 Mdot
.31579 .02094 Mdot
.3158 .02094 Mdot
.31581 .02095 Mdot
.31582 .02095 Mdot
.31583 .02095 Mdot
.31584 .02096 Mdot
.31585 .02096 Mdot
.31586 .02096 Mdot
.31587 .02097 Mdot
.31588 .02097 Mdot
.31589 .02098 Mdot
.3159 .02098 Mdot
.3159 .02098 Mdot
.31591 .02099 Mdot
.31592 .02099 Mdot
.31593 .02099 Mdot
.31594 .021 Mdot
.31595 .021 Mdot
.31596 .02101 Mdot
.31597 .02101 Mdot
.31598 .02101 Mdot
.31599 .02102 Mdot
.316 .02102 Mdot
.31601 .02102 Mdot
.31602 .02103 Mdot
.31603 .02103 Mdot
.31604 .02104 Mdot
.31605 .02104 Mdot
.31606 .02104 Mdot
.31607 .02105 Mdot
.31608 .02105 Mdot
.31609 .02105 Mdot
.3161 .02106 Mdot
.3161 .02106 Mdot
.31611 .02107 Mdot
.31612 .02107 Mdot
.31613 .02107 Mdot
.31614 .02108 Mdot
.31615 .02108 Mdot
.31616 .02109 Mdot
.31617 .02109 Mdot
.31618 .02109 Mdot
.31619 .0211 Mdot
.3162 .0211 Mdot
.31621 .0211 Mdot
.31622 .02111 Mdot
.31623 .02111 Mdot
.31624 .02112 Mdot
.31625 .02112 Mdot
.31626 .02112 Mdot
.31627 .02113 Mdot
.31628 .02113 Mdot
.31629 .02113 Mdot
.3163 .02114 Mdot
.3163 .02114 Mdot
.31631 .02115 Mdot
.31632 .02115 Mdot
.31633 .02115 Mdot
.31634 .02116 Mdot
.31635 .02116 Mdot
.31636 .02116 Mdot
.31637 .02117 Mdot
.31638 .02117 Mdot
.31639 .02118 Mdot
.3164 .02118 Mdot
.31641 .02118 Mdot
.31642 .02119 Mdot
.31643 .02119 Mdot
.31644 .0212 Mdot
.31645 .0212 Mdot
.31646 .0212 Mdot
.31647 .02121 Mdot
.31648 .02121 Mdot
.31649 .02121 Mdot
.3165 .02122 Mdot
.3165 .02122 Mdot
.31651 .02123 Mdot
.31652 .02123 Mdot
.31653 .02123 Mdot
.31654 .02124 Mdot
.31655 .02124 Mdot
.31656 .02124 Mdot
.31657 .02125 Mdot
.31658 .02125 Mdot
.31659 .02126 Mdot
.3166 .02126 Mdot
.31661 .02126 Mdot
.31662 .02127 Mdot
.31663 .02127 Mdot
.31664 .02128 Mdot
.31665 .02128 Mdot
.31666 .02128 Mdot
.31667 .02129 Mdot
.31668 .02129 Mdot
.31669 .02129 Mdot
.3167 .0213 Mdot
.3167 .0213 Mdot
.31671 .02131 Mdot
.31672 .02131 Mdot
.31673 .02131 Mdot
.31674 .02132 Mdot
.31675 .02132 Mdot
.31676 .02133 Mdot
.31677 .02133 Mdot
.31678 .02133 Mdot
.31679 .02134 Mdot
.3168 .02134 Mdot
.31681 .02134 Mdot
.31682 .02135 Mdot
.31683 .02135 Mdot
.31684 .02136 Mdot
.31685 .02136 Mdot
.31686 .02136 Mdot
.31687 .02137 Mdot
.31688 .02137 Mdot
.31689 .02138 Mdot
.3169 .02138 Mdot
.3169 .02138 Mdot
.31691 .02139 Mdot
.31692 .02139 Mdot
.31693 .02139 Mdot
.31694 .0214 Mdot
.31695 .0214 Mdot
.31696 .02141 Mdot
.31697 .02141 Mdot
.31698 .02141 Mdot
.31699 .02142 Mdot
.317 .02142 Mdot
.31701 .02143 Mdot
.31702 .02143 Mdot
.31703 .02143 Mdot
.31704 .02144 Mdot
.31705 .02144 Mdot
.31706 .02145 Mdot
.31707 .02145 Mdot
.31708 .02145 Mdot
.31709 .02146 Mdot
.3171 .02146 Mdot
.3171 .02146 Mdot
.31711 .02147 Mdot
.31712 .02147 Mdot
.31713 .02148 Mdot
.31714 .02148 Mdot
.31715 .02148 Mdot
.31716 .02149 Mdot
.31717 .02149 Mdot
.31718 .0215 Mdot
.31719 .0215 Mdot
.3172 .0215 Mdot
.31721 .02151 Mdot
.31722 .02151 Mdot
.31723 .02152 Mdot
.31724 .02152 Mdot
.31725 .02152 Mdot
.31726 .02153 Mdot
.31727 .02153 Mdot
.31728 .02153 Mdot
.31729 .02154 Mdot
.3173 .02154 Mdot
.3173 .02155 Mdot
.31731 .02155 Mdot
.31732 .02155 Mdot
.31733 .02156 Mdot
.31734 .02156 Mdot
.31735 .02157 Mdot
.31736 .02157 Mdot
.31737 .02157 Mdot
.31738 .02158 Mdot
.31739 .02158 Mdot
.3174 .02159 Mdot
.31741 .02159 Mdot
.31742 .02159 Mdot
.31743 .0216 Mdot
.31744 .0216 Mdot
.31745 .02161 Mdot
.31746 .02161 Mdot
.31747 .02161 Mdot
.31748 .02162 Mdot
.31749 .02162 Mdot
.3175 .02162 Mdot
.3175 .02163 Mdot
.31751 .02163 Mdot
.31752 .02164 Mdot
.31753 .02164 Mdot
.31754 .02164 Mdot
.31755 .02165 Mdot
.31756 .02165 Mdot
.31757 .02166 Mdot
.31758 .02166 Mdot
.31759 .02166 Mdot
.3176 .02167 Mdot
.31761 .02167 Mdot
.31762 .02168 Mdot
.31763 .02168 Mdot
.31764 .02168 Mdot
.31765 .02169 Mdot
.31766 .02169 Mdot
.31767 .0217 Mdot
.31768 .0217 Mdot
.31769 .0217 Mdot
.3177 .02171 Mdot
.3177 .02171 Mdot
.31771 .02172 Mdot
.31772 .02172 Mdot
.31773 .02172 Mdot
.31774 .02173 Mdot
.31775 .02173 Mdot
.31776 .02174 Mdot
.31777 .02174 Mdot
.31778 .02174 Mdot
.31779 .02175 Mdot
.3178 .02175 Mdot
.31781 .02176 Mdot
.31782 .02176 Mdot
.31783 .02176 Mdot
.31784 .02177 Mdot
.31785 .02177 Mdot
.31786 .02178 Mdot
.31787 .02178 Mdot
.31788 .02178 Mdot
.31789 .02179 Mdot
.3179 .02179 Mdot
.3179 .0218 Mdot
.31791 .0218 Mdot
.31792 .0218 Mdot
.31793 .02181 Mdot
.31794 .02181 Mdot
.31795 .02182 Mdot
.31796 .02182 Mdot
.31797 .02182 Mdot
.31798 .02183 Mdot
.31799 .02183 Mdot
.318 .02184 Mdot
.31801 .02184 Mdot
.31802 .02184 Mdot
.31803 .02185 Mdot
.31804 .02185 Mdot
.31805 .02186 Mdot
.31806 .02186 Mdot
.31807 .02186 Mdot
.31808 .02187 Mdot
.31809 .02187 Mdot
.3181 .02188 Mdot
.3181 .02188 Mdot
.31811 .02188 Mdot
.31812 .02189 Mdot
.31813 .02189 Mdot
.31814 .0219 Mdot
.31815 .0219 Mdot
.31816 .0219 Mdot
.31817 .02191 Mdot
.31818 .02191 Mdot
.31819 .02192 Mdot
.3182 .02192 Mdot
.31821 .02192 Mdot
.31822 .02193 Mdot
.31823 .02193 Mdot
.31824 .02194 Mdot
.31825 .02194 Mdot
.31826 .02194 Mdot
.31827 .02195 Mdot
.31828 .02195 Mdot
.31829 .02196 Mdot
.3183 .02196 Mdot
.3183 .02196 Mdot
.31831 .02197 Mdot
.31832 .02197 Mdot
.31833 .02198 Mdot
.31834 .02198 Mdot
.31835 .02198 Mdot
.31836 .02199 Mdot
.31837 .02199 Mdot
.31838 .022 Mdot
.31839 .022 Mdot
.3184 .022 Mdot
.31841 .02201 Mdot
.31842 .02201 Mdot
.31843 .02202 Mdot
.31844 .02202 Mdot
.31845 .02202 Mdot
.31846 .02203 Mdot
.31847 .02203 Mdot
.31848 .02204 Mdot
.31849 .02204 Mdot
.3185 .02204 Mdot
.3185 .02205 Mdot
.31851 .02205 Mdot
.31852 .02206 Mdot
.31853 .02206 Mdot
.31854 .02206 Mdot
.31855 .02207 Mdot
.31856 .02207 Mdot
.31857 .02208 Mdot
.31858 .02208 Mdot
.31859 .02208 Mdot
.3186 .02209 Mdot
.31861 .02209 Mdot
.31862 .0221 Mdot
.31863 .0221 Mdot
.31864 .02211 Mdot
.31865 .02211 Mdot
.31866 .02211 Mdot
.31867 .02212 Mdot
.31868 .02212 Mdot
.31869 .02213 Mdot
.3187 .02213 Mdot
.3187 .02213 Mdot
.31871 .02214 Mdot
.31872 .02214 Mdot
.31873 .02215 Mdot
.31874 .02215 Mdot
.31875 .02215 Mdot
.31876 .02216 Mdot
.31877 .02216 Mdot
.31878 .02217 Mdot
.31879 .02217 Mdot
.3188 .02217 Mdot
.31881 .02218 Mdot
.31882 .02218 Mdot
.31883 .02219 Mdot
.31884 .02219 Mdot
.31885 .0222 Mdot
.31886 .0222 Mdot
.31887 .0222 Mdot
.31888 .02221 Mdot
.31889 .02221 Mdot
.3189 .02222 Mdot
.3189 .02222 Mdot
.31891 .02222 Mdot
.31892 .02223 Mdot
.31893 .02223 Mdot
.31894 .02224 Mdot
.31895 .02224 Mdot
.31896 .02224 Mdot
.31897 .02225 Mdot
.31898 .02225 Mdot
.31899 .02226 Mdot
.319 .02226 Mdot
.31901 .02227 Mdot
.31902 .02227 Mdot
.31903 .02227 Mdot
.31904 .02228 Mdot
.31905 .02228 Mdot
.31906 .02229 Mdot
.31907 .02229 Mdot
.31908 .02229 Mdot
.31909 .0223 Mdot
.3191 .0223 Mdot
.3191 .02231 Mdot
.31911 .02231 Mdot
.31912 .02231 Mdot
.31913 .02232 Mdot
.31914 .02232 Mdot
.31915 .02233 Mdot
.31916 .02233 Mdot
.31917 .02234 Mdot
.31918 .02234 Mdot
.31919 .02234 Mdot
.3192 .02235 Mdot
.31921 .02235 Mdot
.31922 .02236 Mdot
.31923 .02236 Mdot
.31924 .02236 Mdot
.31925 .02237 Mdot
.31926 .02237 Mdot
.31927 .02238 Mdot
.31928 .02238 Mdot
.31929 .02238 Mdot
.3193 .02239 Mdot
.3193 .02239 Mdot
.31931 .0224 Mdot
.31932 .0224 Mdot
.31933 .02241 Mdot
.31934 .02241 Mdot
.31935 .02241 Mdot
.31936 .02242 Mdot
.31937 .02242 Mdot
.31938 .02243 Mdot
.31939 .02243 Mdot
.3194 .02243 Mdot
.31941 .02244 Mdot
.31942 .02244 Mdot
.31943 .02245 Mdot
.31944 .02245 Mdot
.31945 .02246 Mdot
.31946 .02246 Mdot
.31947 .02246 Mdot
.31948 .02247 Mdot
.31949 .02247 Mdot
.3195 .02248 Mdot
.3195 .02248 Mdot
.31951 .02248 Mdot
.31952 .02249 Mdot
.31953 .02249 Mdot
.31954 .0225 Mdot
.31955 .0225 Mdot
.31956 .02251 Mdot
.31957 .02251 Mdot
.31958 .02251 Mdot
.31959 .02252 Mdot
.3196 .02252 Mdot
.31961 .02253 Mdot
.31962 .02253 Mdot
.31963 .02254 Mdot
.31964 .02254 Mdot
.31965 .02254 Mdot
.31966 .02255 Mdot
.31967 .02255 Mdot
.31968 .02256 Mdot
.31969 .02256 Mdot
.3197 .02256 Mdot
.3197 .02257 Mdot
.31971 .02257 Mdot
.31972 .02258 Mdot
.31973 .02258 Mdot
.31974 .02259 Mdot
.31975 .02259 Mdot
.31976 .02259 Mdot
.31977 .0226 Mdot
.31978 .0226 Mdot
.31979 .02261 Mdot
.3198 .02261 Mdot
.31981 .02261 Mdot
.31982 .02262 Mdot
.31983 .02262 Mdot
.31984 .02263 Mdot
.31985 .02263 Mdot
.31986 .02264 Mdot
.31987 .02264 Mdot
.31988 .02264 Mdot
.31989 .02265 Mdot
.3199 .02265 Mdot
.3199 .02266 Mdot
.31991 .02266 Mdot
.31992 .02267 Mdot
.31993 .02267 Mdot
.31994 .02267 Mdot
.31995 .02268 Mdot
.31996 .02268 Mdot
.31997 .02269 Mdot
.31998 .02269 Mdot
.31999 .0227 Mdot
.32 .0227 Mdot
.32001 .0227 Mdot
.32002 .02271 Mdot
.32003 .02271 Mdot
.32004 .02272 Mdot
.32005 .02272 Mdot
.32006 .02272 Mdot
.32007 .02273 Mdot
.32008 .02273 Mdot
.32009 .02274 Mdot
.3201 .02274 Mdot
.3201 .02275 Mdot
.32011 .02275 Mdot
.32012 .02275 Mdot
.32013 .02276 Mdot
.32014 .02276 Mdot
.32015 .02277 Mdot
.32016 .02277 Mdot
.32017 .02278 Mdot
.32018 .02278 Mdot
.32019 .02278 Mdot
.3202 .02279 Mdot
.32021 .02279 Mdot
.32022 .0228 Mdot
.32023 .0228 Mdot
.32024 .02281 Mdot
.32025 .02281 Mdot
.32026 .02281 Mdot
.32027 .02282 Mdot
.32028 .02282 Mdot
.32029 .02283 Mdot
.3203 .02283 Mdot
.3203 .02284 Mdot
.32031 .02284 Mdot
.32032 .02284 Mdot
.32033 .02285 Mdot
.32034 .02285 Mdot
.32035 .02286 Mdot
.32036 .02286 Mdot
.32037 .02287 Mdot
.32038 .02287 Mdot
.32039 .02287 Mdot
.3204 .02288 Mdot
.32041 .02288 Mdot
.32042 .02289 Mdot
.32043 .02289 Mdot
.32044 .0229 Mdot
.32045 .0229 Mdot
.32046 .0229 Mdot
.32047 .02291 Mdot
.32048 .02291 Mdot
.32049 .02292 Mdot
.3205 .02292 Mdot
.3205 .02293 Mdot
.32051 .02293 Mdot
.32052 .02293 Mdot
.32053 .02294 Mdot
.32054 .02294 Mdot
.32055 .02295 Mdot
.32056 .02295 Mdot
.32057 .02296 Mdot
.32058 .02296 Mdot
.32059 .02296 Mdot
.3206 .02297 Mdot
.32061 .02297 Mdot
.32062 .02298 Mdot
.32063 .02298 Mdot
.32064 .02299 Mdot
.32065 .02299 Mdot
.32066 .02299 Mdot
.32067 .023 Mdot
.32068 .023 Mdot
.32069 .02301 Mdot
.3207 .02301 Mdot
.3207 .02302 Mdot
.32071 .02302 Mdot
.32072 .02302 Mdot
.32073 .02303 Mdot
.32074 .02303 Mdot
.32075 .02304 Mdot
.32076 .02304 Mdot
.32077 .02305 Mdot
.32078 .02305 Mdot
.32079 .02305 Mdot
.3208 .02306 Mdot
.32081 .02306 Mdot
.32082 .02307 Mdot
.32083 .02307 Mdot
.32084 .02308 Mdot
.32085 .02308 Mdot
.32086 .02309 Mdot
.32087 .02309 Mdot
.32088 .02309 Mdot
.32089 .0231 Mdot
.3209 .0231 Mdot
.3209 .02311 Mdot
.32091 .02311 Mdot
.32092 .02312 Mdot
.32093 .02312 Mdot
.32094 .02312 Mdot
.32095 .02313 Mdot
.32096 .02313 Mdot
.32097 .02314 Mdot
.32098 .02314 Mdot
.32099 .02315 Mdot
.321 .02315 Mdot
.32101 .02315 Mdot
.32102 .02316 Mdot
.32103 .02316 Mdot
.32104 .02317 Mdot
.32105 .02317 Mdot
.32106 .02318 Mdot
.32107 .02318 Mdot
.32108 .02319 Mdot
.32109 .02319 Mdot
.3211 .02319 Mdot
.3211 .0232 Mdot
.32111 .0232 Mdot
.32112 .02321 Mdot
.32113 .02321 Mdot
.32114 .02322 Mdot
.32115 .02322 Mdot
.32116 .02322 Mdot
.32117 .02323 Mdot
.32118 .02323 Mdot
.32119 .02324 Mdot
.3212 .02324 Mdot
.32121 .02325 Mdot
.32122 .02325 Mdot
.32123 .02326 Mdot
.32124 .02326 Mdot
.32125 .02326 Mdot
.32126 .02327 Mdot
.32127 .02327 Mdot
.32128 .02328 Mdot
.32129 .02328 Mdot
.3213 .02329 Mdot
.3213 .02329 Mdot
.32131 .02329 Mdot
.32132 .0233 Mdot
.32133 .0233 Mdot
.32134 .02331 Mdot
.32135 .02331 Mdot
.32136 .02332 Mdot
.32137 .02332 Mdot
.32138 .02333 Mdot
.32139 .02333 Mdot
.3214 .02333 Mdot
.32141 .02334 Mdot
.32142 .02334 Mdot
.32143 .02335 Mdot
.32144 .02335 Mdot
.32145 .02336 Mdot
.32146 .02336 Mdot
.32147 .02337 Mdot
.32148 .02337 Mdot
.32149 .02337 Mdot
.3215 .02338 Mdot
.3215 .02338 Mdot
.32151 .02339 Mdot
.32152 .02339 Mdot
.32153 .0234 Mdot
.32154 .0234 Mdot
.32155 .0234 Mdot
.32156 .02341 Mdot
.32157 .02341 Mdot
.32158 .02342 Mdot
.32159 .02342 Mdot
.3216 .02343 Mdot
.32161 .02343 Mdot
.32162 .02344 Mdot
.32163 .02344 Mdot
.32164 .02344 Mdot
.32165 .02345 Mdot
.32166 .02345 Mdot
.32167 .02346 Mdot
.32168 .02346 Mdot
.32169 .02347 Mdot
.3217 .02347 Mdot
.3217 .02348 Mdot
.32171 .02348 Mdot
.32172 .02348 Mdot
.32173 .02349 Mdot
.32174 .02349 Mdot
.32175 .0235 Mdot
.32176 .0235 Mdot
.32177 .02351 Mdot
.32178 .02351 Mdot
.32179 .02352 Mdot
.3218 .02352 Mdot
.32181 .02352 Mdot
.32182 .02353 Mdot
.32183 .02353 Mdot
.32184 .02354 Mdot
.32185 .02354 Mdot
.32186 .02355 Mdot
.32187 .02355 Mdot
.32188 .02356 Mdot
.32189 .02356 Mdot
.3219 .02356 Mdot
.3219 .02357 Mdot
.32191 .02357 Mdot
.32192 .02358 Mdot
.32193 .02358 Mdot
.32194 .02359 Mdot
.32195 .02359 Mdot
.32196 .0236 Mdot
.32197 .0236 Mdot
.32198 .02361 Mdot
.32199 .02361 Mdot
.322 .02361 Mdot
.32201 .02362 Mdot
.32202 .02362 Mdot
.32203 .02363 Mdot
.32204 .02363 Mdot
.32205 .02364 Mdot
.32206 .02364 Mdot
.32207 .02365 Mdot
.32208 .02365 Mdot
.32209 .02365 Mdot
.3221 .02366 Mdot
.3221 .02366 Mdot
.32211 .02367 Mdot
.32212 .02367 Mdot
.32213 .02368 Mdot
.32214 .02368 Mdot
.32215 .02369 Mdot
.32216 .02369 Mdot
.32217 .02369 Mdot
.32218 .0237 Mdot
.32219 .0237 Mdot
.3222 .02371 Mdot
.32221 .02371 Mdot
.32222 .02372 Mdot
.32223 .02372 Mdot
.32224 .02373 Mdot
.32225 .02373 Mdot
.32226 .02374 Mdot
.32227 .02374 Mdot
.32228 .02374 Mdot
.32229 .02375 Mdot
.3223 .02375 Mdot
.3223 .02376 Mdot
.32231 .02376 Mdot
.32232 .02377 Mdot
.32233 .02377 Mdot
.32234 .02378 Mdot
.32235 .02378 Mdot
.32236 .02378 Mdot
.32237 .02379 Mdot
.32238 .02379 Mdot
.32239 .0238 Mdot
.3224 .0238 Mdot
.32241 .02381 Mdot
.32242 .02381 Mdot
.32243 .02382 Mdot
.32244 .02382 Mdot
.32245 .02383 Mdot
.32246 .02383 Mdot
.32247 .02383 Mdot
.32248 .02384 Mdot
.32249 .02384 Mdot
.3225 .02385 Mdot
.3225 .02385 Mdot
.32251 .02386 Mdot
.32252 .02386 Mdot
.32253 .02387 Mdot
.32254 .02387 Mdot
.32255 .02388 Mdot
.32256 .02388 Mdot
.32257 .02388 Mdot
.32258 .02389 Mdot
.32259 .02389 Mdot
.3226 .0239 Mdot
.32261 .0239 Mdot
.32262 .02391 Mdot
.32263 .02391 Mdot
.32264 .02392 Mdot
.32265 .02392 Mdot
.32266 .02393 Mdot
.32267 .02393 Mdot
.32268 .02393 Mdot
.32269 .02394 Mdot
.3227 .02394 Mdot
.3227 .02395 Mdot
.32271 .02395 Mdot
.32272 .02396 Mdot
.32273 .02396 Mdot
.32274 .02397 Mdot
.32275 .02397 Mdot
.32276 .02398 Mdot
.32277 .02398 Mdot
.32278 .02398 Mdot
.32279 .02399 Mdot
.3228 .02399 Mdot
.32281 .024 Mdot
.32282 .024 Mdot
.32283 .02401 Mdot
.32284 .02401 Mdot
.32285 .02402 Mdot
.32286 .02402 Mdot
.32287 .02403 Mdot
.32288 .02403 Mdot
.32289 .02404 Mdot
.3229 .02404 Mdot
.3229 .02404 Mdot
.32291 .02405 Mdot
.32292 .02405 Mdot
.32293 .02406 Mdot
.32294 .02406 Mdot
.32295 .02407 Mdot
.32296 .02407 Mdot
.32297 .02408 Mdot
.32298 .02408 Mdot
.32299 .02409 Mdot
.323 .02409 Mdot
.32301 .02409 Mdot
.32302 .0241 Mdot
.32303 .0241 Mdot
.32304 .02411 Mdot
.32305 .02411 Mdot
.32306 .02412 Mdot
.32307 .02412 Mdot
.32308 .02413 Mdot
.32309 .02413 Mdot
.3231 .02414 Mdot
.3231 .02414 Mdot
.32311 .02415 Mdot
.32312 .02415 Mdot
.32313 .02415 Mdot
.32314 .02416 Mdot
.32315 .02416 Mdot
.32316 .02417 Mdot
.32317 .02417 Mdot
.32318 .02418 Mdot
.32319 .02418 Mdot
.3232 .02419 Mdot
.32321 .02419 Mdot
.32322 .0242 Mdot
.32323 .0242 Mdot
.32324 .02421 Mdot
.32325 .02421 Mdot
.32326 .02421 Mdot
.32327 .02422 Mdot
.32328 .02422 Mdot
.32329 .02423 Mdot
.3233 .02423 Mdot
.3233 .02424 Mdot
.32331 .02424 Mdot
.32332 .02425 Mdot
.32333 .02425 Mdot
.32334 .02426 Mdot
.32335 .02426 Mdot
.32336 .02427 Mdot
.32337 .02427 Mdot
.32338 .02428 Mdot
.32339 .02428 Mdot
.3234 .02428 Mdot
.32341 .02429 Mdot
.32342 .02429 Mdot
.32343 .0243 Mdot
.32344 .0243 Mdot
.32345 .02431 Mdot
.32346 .02431 Mdot
.32347 .02432 Mdot
.32348 .02432 Mdot
.32349 .02433 Mdot
.3235 .02433 Mdot
.3235 .02434 Mdot
.32351 .02434 Mdot
.32352 .02434 Mdot
.32353 .02435 Mdot
.32354 .02435 Mdot
.32355 .02436 Mdot
.32356 .02436 Mdot
.32357 .02437 Mdot
.32358 .02437 Mdot
.32359 .02438 Mdot
.3236 .02438 Mdot
.32361 .02439 Mdot
.32362 .02439 Mdot
.32363 .0244 Mdot
.32364 .0244 Mdot
.32365 .02441 Mdot
.32366 .02441 Mdot
.32367 .02441 Mdot
.32368 .02442 Mdot
.32369 .02442 Mdot
.3237 .02443 Mdot
.3237 .02443 Mdot
.32371 .02444 Mdot
.32372 .02444 Mdot
.32373 .02445 Mdot
.32374 .02445 Mdot
.32375 .02446 Mdot
.32376 .02446 Mdot
.32377 .02447 Mdot
.32378 .02447 Mdot
.32379 .02448 Mdot
.3238 .02448 Mdot
.32381 .02449 Mdot
.32382 .02449 Mdot
.32383 .02449 Mdot
.32384 .0245 Mdot
.32385 .0245 Mdot
.32386 .02451 Mdot
.32387 .02451 Mdot
.32388 .02452 Mdot
.32389 .02452 Mdot
.3239 .02453 Mdot
.3239 .02453 Mdot
.32391 .02454 Mdot
.32392 .02454 Mdot
.32393 .02455 Mdot
.32394 .02455 Mdot
.32395 .02456 Mdot
.32396 .02456 Mdot
.32397 .02457 Mdot
.32398 .02457 Mdot
.32399 .02457 Mdot
.324 .02458 Mdot
.32401 .02458 Mdot
.32402 .02459 Mdot
.32403 .02459 Mdot
.32404 .0246 Mdot
.32405 .0246 Mdot
.32406 .02461 Mdot
.32407 .02461 Mdot
.32408 .02462 Mdot
.32409 .02462 Mdot
.3241 .02463 Mdot
.3241 .02463 Mdot
.32411 .02464 Mdot
.32412 .02464 Mdot
.32413 .02465 Mdot
.32414 .02465 Mdot
.32415 .02465 Mdot
.32416 .02466 Mdot
.32417 .02466 Mdot
.32418 .02467 Mdot
.32419 .02467 Mdot
.3242 .02468 Mdot
.32421 .02468 Mdot
.32422 .02469 Mdot
.32423 .02469 Mdot
.32424 .0247 Mdot
.32425 .0247 Mdot
.32426 .02471 Mdot
.32427 .02471 Mdot
.32428 .02472 Mdot
.32429 .02472 Mdot
.3243 .02473 Mdot
.3243 .02473 Mdot
.32431 .02474 Mdot
.32432 .02474 Mdot
.32433 .02475 Mdot
.32434 .02475 Mdot
.32435 .02475 Mdot
.32436 .02476 Mdot
.32437 .02476 Mdot
.32438 .02477 Mdot
.32439 .02477 Mdot
.3244 .02478 Mdot
.32441 .02478 Mdot
.32442 .02479 Mdot
.32443 .02479 Mdot
.32444 .0248 Mdot
.32445 .0248 Mdot
.32446 .02481 Mdot
.32447 .02481 Mdot
.32448 .02482 Mdot
.32449 .02482 Mdot
.3245 .02483 Mdot
.3245 .02483 Mdot
.32451 .02484 Mdot
.32452 .02484 Mdot
.32453 .02485 Mdot
.32454 .02485 Mdot
.32455 .02485 Mdot
.32456 .02486 Mdot
.32457 .02486 Mdot
.32458 .02487 Mdot
.32459 .02487 Mdot
.3246 .02488 Mdot
.32461 .02488 Mdot
.32462 .02489 Mdot
.32463 .02489 Mdot
.32464 .0249 Mdot
.32465 .0249 Mdot
.32466 .02491 Mdot
.32467 .02491 Mdot
.32468 .02492 Mdot
.32469 .02492 Mdot
.3247 .02493 Mdot
.3247 .02493 Mdot
.32471 .02494 Mdot
.32472 .02494 Mdot
.32473 .02495 Mdot
.32474 .02495 Mdot
.32475 .02496 Mdot
.32476 .02496 Mdot
.32477 .02497 Mdot
.32478 .02497 Mdot
.32479 .02497 Mdot
.3248 .02498 Mdot
.32481 .02498 Mdot
.32482 .02499 Mdot
.32483 .02499 Mdot
.32484 .025 Mdot
.32485 .025 Mdot
.32486 .02501 Mdot
.32487 .02501 Mdot
.32488 .02502 Mdot
.32489 .02502 Mdot
.3249 .02503 Mdot
.3249 .02503 Mdot
.32491 .02504 Mdot
.32492 .02504 Mdot
.32493 .02505 Mdot
.32494 .02505 Mdot
.32495 .02506 Mdot
.32496 .02506 Mdot
.32497 .02507 Mdot
.32498 .02507 Mdot
.32499 .02508 Mdot
.325 .02508 Mdot
.32501 .02509 Mdot
.32502 .02509 Mdot
.32503 .0251 Mdot
.32504 .0251 Mdot
.32505 .02511 Mdot
.32506 .02511 Mdot
.32507 .02511 Mdot
.32508 .02512 Mdot
.32509 .02512 Mdot
.3251 .02513 Mdot
.3251 .02513 Mdot
.32511 .02514 Mdot
.32512 .02514 Mdot
.32513 .02515 Mdot
.32514 .02515 Mdot
.32515 .02516 Mdot
.32516 .02516 Mdot
.32517 .02517 Mdot
.32518 .02517 Mdot
.32519 .02518 Mdot
.3252 .02518 Mdot
.32521 .02519 Mdot
.32522 .02519 Mdot
.32523 .0252 Mdot
.32524 .0252 Mdot
.32525 .02521 Mdot
.32526 .02521 Mdot
.32527 .02522 Mdot
.32528 .02522 Mdot
.32529 .02523 Mdot
.3253 .02523 Mdot
.3253 .02524 Mdot
.32531 .02524 Mdot
.32532 .02525 Mdot
.32533 .02525 Mdot
.32534 .02526 Mdot
.32535 .02526 Mdot
.32536 .02527 Mdot
.32537 .02527 Mdot
.32538 .02528 Mdot
.32539 .02528 Mdot
.3254 .02529 Mdot
.32541 .02529 Mdot
.32542 .02529 Mdot
.32543 .0253 Mdot
.32544 .0253 Mdot
.32545 .02531 Mdot
.32546 .02531 Mdot
.32547 .02532 Mdot
.32548 .02532 Mdot
.32549 .02533 Mdot
.3255 .02533 Mdot
.3255 .02534 Mdot
.32551 .02534 Mdot
.32552 .02535 Mdot
.32553 .02535 Mdot
.32554 .02536 Mdot
.32555 .02536 Mdot
.32556 .02537 Mdot
.32557 .02537 Mdot
.32558 .02538 Mdot
.32559 .02538 Mdot
.3256 .02539 Mdot
.32561 .02539 Mdot
.32562 .0254 Mdot
.32563 .0254 Mdot
.32564 .02541 Mdot
.32565 .02541 Mdot
.32566 .02542 Mdot
.32567 .02542 Mdot
.32568 .02543 Mdot
.32569 .02543 Mdot
.3257 .02544 Mdot
.3257 .02544 Mdot
.32571 .02545 Mdot
.32572 .02545 Mdot
.32573 .02546 Mdot
.32574 .02546 Mdot
.32575 .02547 Mdot
.32576 .02547 Mdot
.32577 .02548 Mdot
.32578 .02548 Mdot
.32579 .02549 Mdot
.3258 .02549 Mdot
.32581 .0255 Mdot
.32582 .0255 Mdot
.32583 .02551 Mdot
.32584 .02551 Mdot
.32585 .02552 Mdot
.32586 .02552 Mdot
.32587 .02553 Mdot
.32588 .02553 Mdot
.32589 .02554 Mdot
.3259 .02554 Mdot
.3259 .02555 Mdot
.32591 .02555 Mdot
.32592 .02556 Mdot
.32593 .02556 Mdot
.32594 .02557 Mdot
.32595 .02557 Mdot
.32596 .02558 Mdot
.32597 .02558 Mdot
.32598 .02559 Mdot
.32599 .02559 Mdot
.326 .0256 Mdot
.32601 .0256 Mdot
.32602 .02561 Mdot
.32603 .02561 Mdot
.32604 .02562 Mdot
.32605 .02562 Mdot
.32606 .02562 Mdot
.32607 .02563 Mdot
.32608 .02563 Mdot
.32609 .02564 Mdot
.3261 .02564 Mdot
.3261 .02565 Mdot
.32611 .02565 Mdot
.32612 .02566 Mdot
.32613 .02566 Mdot
.32614 .02567 Mdot
.32615 .02567 Mdot
.32616 .02568 Mdot
.32617 .02568 Mdot
.32618 .02569 Mdot
.32619 .02569 Mdot
.3262 .0257 Mdot
.32621 .0257 Mdot
.32622 .02571 Mdot
.32623 .02571 Mdot
.32624 .02572 Mdot
.32625 .02572 Mdot
.32626 .02573 Mdot
.32627 .02573 Mdot
.32628 .02574 Mdot
.32629 .02574 Mdot
.3263 .02575 Mdot
.3263 .02575 Mdot
.32631 .02576 Mdot
.32632 .02576 Mdot
.32633 .02577 Mdot
.32634 .02577 Mdot
.32635 .02578 Mdot
.32636 .02578 Mdot
.32637 .02579 Mdot
.32638 .02579 Mdot
.32639 .0258 Mdot
.3264 .0258 Mdot
.32641 .02581 Mdot
.32642 .02581 Mdot
.32643 .02582 Mdot
.32644 .02582 Mdot
.32645 .02583 Mdot
.32646 .02583 Mdot
.32647 .02584 Mdot
.32648 .02584 Mdot
.32649 .02585 Mdot
.3265 .02585 Mdot
.3265 .02586 Mdot
.32651 .02586 Mdot
.32652 .02587 Mdot
.32653 .02587 Mdot
.32654 .02588 Mdot
.32655 .02588 Mdot
.32656 .02589 Mdot
.32657 .02589 Mdot
.32658 .0259 Mdot
.32659 .0259 Mdot
.3266 .02591 Mdot
.32661 .02591 Mdot
.32662 .02592 Mdot
.32663 .02592 Mdot
.32664 .02593 Mdot
.32665 .02594 Mdot
.32666 .02594 Mdot
.32667 .02595 Mdot
.32668 .02595 Mdot
.32669 .02596 Mdot
.3267 .02596 Mdot
.3267 .02597 Mdot
.32671 .02597 Mdot
.32672 .02598 Mdot
.32673 .02598 Mdot
.32674 .02599 Mdot
.32675 .02599 Mdot
.32676 .026 Mdot
.32677 .026 Mdot
.32678 .02601 Mdot
.32679 .02601 Mdot
.3268 .02602 Mdot
.32681 .02602 Mdot
.32682 .02603 Mdot
.32683 .02603 Mdot
.32684 .02604 Mdot
.32685 .02604 Mdot
.32686 .02605 Mdot
.32687 .02605 Mdot
.32688 .02606 Mdot
.32689 .02606 Mdot
.3269 .02607 Mdot
.3269 .02607 Mdot
.32691 .02608 Mdot
.32692 .02608 Mdot
.32693 .02609 Mdot
.32694 .02609 Mdot
.32695 .0261 Mdot
.32696 .0261 Mdot
.32697 .02611 Mdot
.32698 .02611 Mdot
.32699 .02612 Mdot
.327 .02612 Mdot
.32701 .02613 Mdot
.32702 .02613 Mdot
.32703 .02614 Mdot
.32704 .02614 Mdot
.32705 .02615 Mdot
.32706 .02615 Mdot
.32707 .02616 Mdot
.32708 .02616 Mdot
.32709 .02617 Mdot
.3271 .02617 Mdot
.3271 .02618 Mdot
.32711 .02618 Mdot
.32712 .02619 Mdot
.32713 .02619 Mdot
.32714 .0262 Mdot
.32715 .0262 Mdot
.32716 .02621 Mdot
.32717 .02621 Mdot
.32718 .02622 Mdot
.32719 .02622 Mdot
.3272 .02623 Mdot
.32721 .02623 Mdot
.32722 .02624 Mdot
.32723 .02624 Mdot
.32724 .02625 Mdot
.32725 .02625 Mdot
.32726 .02626 Mdot
.32727 .02626 Mdot
.32728 .02627 Mdot
.32729 .02628 Mdot
.3273 .02628 Mdot
.3273 .02629 Mdot
.32731 .02629 Mdot
.32732 .0263 Mdot
.32733 .0263 Mdot
.32734 .02631 Mdot
.32735 .02631 Mdot
.32736 .02632 Mdot
.32737 .02632 Mdot
.32738 .02633 Mdot
.32739 .02633 Mdot
.3274 .02634 Mdot
.32741 .02634 Mdot
.32742 .02635 Mdot
.32743 .02635 Mdot
.32744 .02636 Mdot
.32745 .02636 Mdot
.32746 .02637 Mdot
.32747 .02637 Mdot
.32748 .02638 Mdot
.32749 .02638 Mdot
.3275 .02639 Mdot
.3275 .02639 Mdot
.32751 .0264 Mdot
.32752 .0264 Mdot
.32753 .02641 Mdot
.32754 .02641 Mdot
.32755 .02642 Mdot
.32756 .02642 Mdot
.32757 .02643 Mdot
.32758 .02643 Mdot
.32759 .02644 Mdot
.3276 .02644 Mdot
.32761 .02645 Mdot
.32762 .02645 Mdot
.32763 .02646 Mdot
.32764 .02647 Mdot
.32765 .02647 Mdot
.32766 .02648 Mdot
.32767 .02648 Mdot
.32768 .02649 Mdot
.32769 .02649 Mdot
.3277 .0265 Mdot
.3277 .0265 Mdot
.32771 .02651 Mdot
.32772 .02651 Mdot
.32773 .02652 Mdot
.32774 .02652 Mdot
.32775 .02653 Mdot
.32776 .02653 Mdot
.32777 .02654 Mdot
.32778 .02654 Mdot
.32779 .02655 Mdot
.3278 .02655 Mdot
.32781 .02656 Mdot
.32782 .02656 Mdot
.32783 .02657 Mdot
.32784 .02657 Mdot
.32785 .02658 Mdot
.32786 .02658 Mdot
.32787 .02659 Mdot
.32788 .02659 Mdot
.32789 .0266 Mdot
.3279 .0266 Mdot
.3279 .02661 Mdot
.32791 .02662 Mdot
.32792 .02662 Mdot
.32793 .02663 Mdot
.32794 .02663 Mdot
.32795 .02664 Mdot
.32796 .02664 Mdot
.32797 .02665 Mdot
.32798 .02665 Mdot
.32799 .02666 Mdot
.328 .02666 Mdot
.32801 .02667 Mdot
.32802 .02667 Mdot
.32803 .02668 Mdot
.32804 .02668 Mdot
.32805 .02669 Mdot
.32806 .02669 Mdot
.32807 .0267 Mdot
.32808 .0267 Mdot
.32809 .02671 Mdot
.3281 .02671 Mdot
.3281 .02672 Mdot
.32811 .02672 Mdot
.32812 .02673 Mdot
.32813 .02673 Mdot
.32814 .02674 Mdot
.32815 .02675 Mdot
.32816 .02675 Mdot
.32817 .02676 Mdot
.32818 .02676 Mdot
.32819 .02677 Mdot
.3282 .02677 Mdot
.32821 .02678 Mdot
.32822 .02678 Mdot
.32823 .02679 Mdot
.32824 .02679 Mdot
.32825 .0268 Mdot
.32826 .0268 Mdot
.32827 .02681 Mdot
.32828 .02681 Mdot
.32829 .02682 Mdot
.3283 .02682 Mdot
.3283 .02683 Mdot
.32831 .02683 Mdot
.32832 .02684 Mdot
.32833 .02684 Mdot
.32834 .02685 Mdot
.32835 .02686 Mdot
.32836 .02686 Mdot
.32837 .02687 Mdot
.32838 .02687 Mdot
.32839 .02688 Mdot
.3284 .02688 Mdot
.32841 .02689 Mdot
.32842 .02689 Mdot
.32843 .0269 Mdot
.32844 .0269 Mdot
.32845 .02691 Mdot
.32846 .02691 Mdot
.32847 .02692 Mdot
.32848 .02692 Mdot
.32849 .02693 Mdot
.3285 .02693 Mdot
.3285 .02694 Mdot
.32851 .02694 Mdot
.32852 .02695 Mdot
.32853 .02695 Mdot
.32854 .02696 Mdot
.32855 .02697 Mdot
.32856 .02697 Mdot
.32857 .02698 Mdot
.32858 .02698 Mdot
.32859 .02699 Mdot
.3286 .02699 Mdot
.32861 .027 Mdot
.32862 .027 Mdot
.32863 .02701 Mdot
.32864 .02701 Mdot
.32865 .02702 Mdot
.32866 .02702 Mdot
.32867 .02703 Mdot
.32868 .02703 Mdot
.32869 .02704 Mdot
.3287 .02704 Mdot
.3287 .02705 Mdot
.32871 .02706 Mdot
.32872 .02706 Mdot
.32873 .02707 Mdot
.32874 .02707 Mdot
.32875 .02708 Mdot
.32876 .02708 Mdot
.32877 .02709 Mdot
.32878 .02709 Mdot
.32879 .0271 Mdot
.3288 .0271 Mdot
.32881 .02711 Mdot
.32882 .02711 Mdot
.32883 .02712 Mdot
.32884 .02712 Mdot
.32885 .02713 Mdot
.32886 .02713 Mdot
.32887 .02714 Mdot
.32888 .02715 Mdot
.32889 .02715 Mdot
.3289 .02716 Mdot
.3289 .02716 Mdot
.32891 .02717 Mdot
.32892 .02717 Mdot
.32893 .02718 Mdot
.32894 .02718 Mdot
.32895 .02719 Mdot
.32896 .02719 Mdot
.32897 .0272 Mdot
.32898 .0272 Mdot
.32899 .02721 Mdot
.329 .02721 Mdot
.32901 .02722 Mdot
.32902 .02722 Mdot
.32903 .02723 Mdot
.32904 .02724 Mdot
.32905 .02724 Mdot
.32906 .02725 Mdot
.32907 .02725 Mdot
.32908 .02726 Mdot
.32909 .02726 Mdot
.3291 .02727 Mdot
.3291 .02727 Mdot
.32911 .02728 Mdot
.32912 .02728 Mdot
.32913 .02729 Mdot
.32914 .02729 Mdot
.32915 .0273 Mdot
.32916 .0273 Mdot
.32917 .02731 Mdot
.32918 .02732 Mdot
.32919 .02732 Mdot
.3292 .02733 Mdot
.32921 .02733 Mdot
.32922 .02734 Mdot
.32923 .02734 Mdot
.32924 .02735 Mdot
.32925 .02735 Mdot
.32926 .02736 Mdot
.32927 .02736 Mdot
.32928 .02737 Mdot
.32929 .02737 Mdot
.3293 .02738 Mdot
.3293 .02739 Mdot
.32931 .02739 Mdot
.32932 .0274 Mdot
.32933 .0274 Mdot
.32934 .02741 Mdot
.32935 .02741 Mdot
.32936 .02742 Mdot
.32937 .02742 Mdot
.32938 .02743 Mdot
.32939 .02743 Mdot
.3294 .02744 Mdot
.32941 .02744 Mdot
.32942 .02745 Mdot
.32943 .02745 Mdot
.32944 .02746 Mdot
.32945 .02747 Mdot
.32946 .02747 Mdot
.32947 .02748 Mdot
.32948 .02748 Mdot
.32949 .02749 Mdot
.3295 .02749 Mdot
.3295 .0275 Mdot
.32951 .0275 Mdot
.32952 .02751 Mdot
.32953 .02751 Mdot
.32954 .02752 Mdot
.32955 .02752 Mdot
.32956 .02753 Mdot
.32957 .02754 Mdot
.32958 .02754 Mdot
.32959 .02755 Mdot
.3296 .02755 Mdot
.32961 .02756 Mdot
.32962 .02756 Mdot
.32963 .02757 Mdot
.32964 .02757 Mdot
.32965 .02758 Mdot
.32966 .02758 Mdot
.32967 .02759 Mdot
.32968 .0276 Mdot
.32969 .0276 Mdot
.3297 .02761 Mdot
.3297 .02761 Mdot
.32971 .02762 Mdot
.32972 .02762 Mdot
.32973 .02763 Mdot
.32974 .02763 Mdot
.32975 .02764 Mdot
.32976 .02764 Mdot
.32977 .02765 Mdot
.32978 .02765 Mdot
.32979 .02766 Mdot
.3298 .02767 Mdot
.32981 .02767 Mdot
.32982 .02768 Mdot
.32983 .02768 Mdot
.32984 .02769 Mdot
.32985 .02769 Mdot
.32986 .0277 Mdot
.32987 .0277 Mdot
.32988 .02771 Mdot
.32989 .02771 Mdot
.3299 .02772 Mdot
.3299 .02773 Mdot
.32991 .02773 Mdot
.32992 .02774 Mdot
.32993 .02774 Mdot
.32994 .02775 Mdot
.32995 .02775 Mdot
.32996 .02776 Mdot
.32997 .02776 Mdot
.32998 .02777 Mdot
.32999 .02777 Mdot
.33 .02778 Mdot
.33001 .02778 Mdot
.33002 .02779 Mdot
.33003 .0278 Mdot
.33004 .0278 Mdot
.33005 .02781 Mdot
.33006 .02781 Mdot
.33007 .02782 Mdot
.33008 .02782 Mdot
.33009 .02783 Mdot
.3301 .02783 Mdot
.3301 .02784 Mdot
.33011 .02784 Mdot
.33012 .02785 Mdot
.33013 .02786 Mdot
.33014 .02786 Mdot
.33015 .02787 Mdot
.33016 .02787 Mdot
.33017 .02788 Mdot
.33018 .02788 Mdot
.33019 .02789 Mdot
.3302 .02789 Mdot
.33021 .0279 Mdot
.33022 .0279 Mdot
.33023 .02791 Mdot
.33024 .02792 Mdot
.33025 .02792 Mdot
.33026 .02793 Mdot
.33027 .02793 Mdot
.33028 .02794 Mdot
.33029 .02794 Mdot
.3303 .02795 Mdot
.3303 .02795 Mdot
.33031 .02796 Mdot
.33032 .02797 Mdot
.33033 .02797 Mdot
.33034 .02798 Mdot
.33035 .02798 Mdot
.33036 .02799 Mdot
.33037 .02799 Mdot
.33038 .028 Mdot
.33039 .028 Mdot
.3304 .02801 Mdot
.33041 .02801 Mdot
.33042 .02802 Mdot
.33043 .02803 Mdot
.33044 .02803 Mdot
.33045 .02804 Mdot
.33046 .02804 Mdot
.33047 .02805 Mdot
.33048 .02805 Mdot
.33049 .02806 Mdot
.3305 .02806 Mdot
.3305 .02807 Mdot
.33051 .02808 Mdot
.33052 .02808 Mdot
.33053 .02809 Mdot
.33054 .02809 Mdot
.33055 .0281 Mdot
.33056 .0281 Mdot
.33057 .02811 Mdot
.33058 .02811 Mdot
.33059 .02812 Mdot
.3306 .02812 Mdot
.33061 .02813 Mdot
.33062 .02814 Mdot
.33063 .02814 Mdot
.33064 .02815 Mdot
.33065 .02815 Mdot
.33066 .02816 Mdot
.33067 .02816 Mdot
.33068 .02817 Mdot
.33069 .02817 Mdot
.3307 .02818 Mdot
.3307 .02819 Mdot
.33071 .02819 Mdot
.33072 .0282 Mdot
.33073 .0282 Mdot
.33074 .02821 Mdot
.33075 .02821 Mdot
.33076 .02822 Mdot
.33077 .02822 Mdot
.33078 .02823 Mdot
.33079 .02824 Mdot
.3308 .02824 Mdot
.33081 .02825 Mdot
.33082 .02825 Mdot
.33083 .02826 Mdot
.33084 .02826 Mdot
.33085 .02827 Mdot
.33086 .02827 Mdot
.33087 .02828 Mdot
.33088 .02829 Mdot
.33089 .02829 Mdot
.3309 .0283 Mdot
.3309 .0283 Mdot
.33091 .02831 Mdot
.33092 .02831 Mdot
.33093 .02832 Mdot
.33094 .02832 Mdot
.33095 .02833 Mdot
.33096 .02834 Mdot
.33097 .02834 Mdot
.33098 .02835 Mdot
.33099 .02835 Mdot
.331 .02836 Mdot
.33101 .02836 Mdot
.33102 .02837 Mdot
.33103 .02837 Mdot
.33104 .02838 Mdot
.33105 .02839 Mdot
.33106 .02839 Mdot
.33107 .0284 Mdot
.33108 .0284 Mdot
.33109 .02841 Mdot
.3311 .02841 Mdot
.3311 .02842 Mdot
.33111 .02842 Mdot
.33112 .02843 Mdot
.33113 .02844 Mdot
.33114 .02844 Mdot
.33115 .02845 Mdot
.33116 .02845 Mdot
.33117 .02846 Mdot
.33118 .02846 Mdot
.33119 .02847 Mdot
.3312 .02847 Mdot
.33121 .02848 Mdot
.33122 .02849 Mdot
.33123 .02849 Mdot
.33124 .0285 Mdot
.33125 .0285 Mdot
.33126 .02851 Mdot
.33127 .02851 Mdot
.33128 .02852 Mdot
.33129 .02852 Mdot
.3313 .02853 Mdot
.3313 .02854 Mdot
.33131 .02854 Mdot
.33132 .02855 Mdot
.33133 .02855 Mdot
.33134 .02856 Mdot
.33135 .02856 Mdot
.33136 .02857 Mdot
.33137 .02858 Mdot
.33138 .02858 Mdot
.33139 .02859 Mdot
.3314 .02859 Mdot
.33141 .0286 Mdot
.33142 .0286 Mdot
.33143 .02861 Mdot
.33144 .02861 Mdot
.33145 .02862 Mdot
.33146 .02863 Mdot
.33147 .02863 Mdot
.33148 .02864 Mdot
.33149 .02864 Mdot
.3315 .02865 Mdot
.3315 .02865 Mdot
.33151 .02866 Mdot
.33152 .02867 Mdot
.33153 .02867 Mdot
.33154 .02868 Mdot
.33155 .02868 Mdot
.33156 .02869 Mdot
.33157 .02869 Mdot
.33158 .0287 Mdot
.33159 .0287 Mdot
.3316 .02871 Mdot
.33161 .02872 Mdot
.33162 .02872 Mdot
.33163 .02873 Mdot
.33164 .02873 Mdot
.33165 .02874 Mdot
.33166 .02874 Mdot
.33167 .02875 Mdot
.33168 .02876 Mdot
.33169 .02876 Mdot
.3317 .02877 Mdot
.3317 .02877 Mdot
.33171 .02878 Mdot
.33172 .02878 Mdot
.33173 .02879 Mdot
.33174 .02879 Mdot
.33175 .0288 Mdot
.33176 .02881 Mdot
.33177 .02881 Mdot
.33178 .02882 Mdot
.33179 .02882 Mdot
.3318 .02883 Mdot
.33181 .02883 Mdot
.33182 .02884 Mdot
.33183 .02885 Mdot
.33184 .02885 Mdot
.33185 .02886 Mdot
.33186 .02886 Mdot
.33187 .02887 Mdot
.33188 .02887 Mdot
.33189 .02888 Mdot
.3319 .02889 Mdot
.3319 .02889 Mdot
.33191 .0289 Mdot
.33192 .0289 Mdot
.33193 .02891 Mdot
.33194 .02891 Mdot
.33195 .02892 Mdot
.33196 .02893 Mdot
.33197 .02893 Mdot
.33198 .02894 Mdot
.33199 .02894 Mdot
.332 .02895 Mdot
.33201 .02895 Mdot
.33202 .02896 Mdot
.33203 .02896 Mdot
.33204 .02897 Mdot
.33205 .02898 Mdot
.33206 .02898 Mdot
.33207 .02899 Mdot
.33208 .02899 Mdot
.33209 .029 Mdot
.3321 .029 Mdot
.3321 .02901 Mdot
.33211 .02902 Mdot
.33212 .02902 Mdot
.33213 .02903 Mdot
.33214 .02903 Mdot
.33215 .02904 Mdot
.33216 .02904 Mdot
.33217 .02905 Mdot
.33218 .02906 Mdot
.33219 .02906 Mdot
.3322 .02907 Mdot
.33221 .02907 Mdot
.33222 .02908 Mdot
.33223 .02908 Mdot
.33224 .02909 Mdot
.33225 .0291 Mdot
.33226 .0291 Mdot
.33227 .02911 Mdot
.33228 .02911 Mdot
.33229 .02912 Mdot
.3323 .02912 Mdot
.3323 .02913 Mdot
.33231 .02914 Mdot
.33232 .02914 Mdot
.33233 .02915 Mdot
.33234 .02915 Mdot
.33235 .02916 Mdot
.33236 .02916 Mdot
.33237 .02917 Mdot
.33238 .02918 Mdot
.33239 .02918 Mdot
.3324 .02919 Mdot
.33241 .02919 Mdot
.33242 .0292 Mdot
.33243 .0292 Mdot
.33244 .02921 Mdot
.33245 .02922 Mdot
.33246 .02922 Mdot
.33247 .02923 Mdot
.33248 .02923 Mdot
.33249 .02924 Mdot
.3325 .02925 Mdot
.3325 .02925 Mdot
.33251 .02926 Mdot
.33252 .02926 Mdot
.33253 .02927 Mdot
.33254 .02927 Mdot
.33255 .02928 Mdot
.33256 .02929 Mdot
.33257 .02929 Mdot
.33258 .0293 Mdot
.33259 .0293 Mdot
.3326 .02931 Mdot
.33261 .02931 Mdot
.33262 .02932 Mdot
.33263 .02933 Mdot
.33264 .02933 Mdot
.33265 .02934 Mdot
.33266 .02934 Mdot
.33267 .02935 Mdot
.33268 .02935 Mdot
.33269 .02936 Mdot
.3327 .02937 Mdot
.3327 .02937 Mdot
.33271 .02938 Mdot
.33272 .02938 Mdot
.33273 .02939 Mdot
.33274 .02939 Mdot
.33275 .0294 Mdot
.33276 .02941 Mdot
.33277 .02941 Mdot
.33278 .02942 Mdot
.33279 .02942 Mdot
.3328 .02943 Mdot
.33281 .02944 Mdot
.33282 .02944 Mdot
.33283 .02945 Mdot
.33284 .02945 Mdot
.33285 .02946 Mdot
.33286 .02946 Mdot
.33287 .02947 Mdot
.33288 .02948 Mdot
.33289 .02948 Mdot
.3329 .02949 Mdot
.3329 .02949 Mdot
.33291 .0295 Mdot
.33292 .0295 Mdot
.33293 .02951 Mdot
.33294 .02952 Mdot
.33295 .02952 Mdot
.33296 .02953 Mdot
.33297 .02953 Mdot
.33298 .02954 Mdot
.33299 .02955 Mdot
.333 .02955 Mdot
.33301 .02956 Mdot
.33302 .02956 Mdot
.33303 .02957 Mdot
.33304 .02957 Mdot
.33305 .02958 Mdot
.33306 .02959 Mdot
.33307 .02959 Mdot
.33308 .0296 Mdot
.33309 .0296 Mdot
.3331 .02961 Mdot
.3331 .02962 Mdot
.33311 .02962 Mdot
.33312 .02963 Mdot
.33313 .02963 Mdot
.33314 .02964 Mdot
.33315 .02964 Mdot
.33316 .02965 Mdot
.33317 .02966 Mdot
.33318 .02966 Mdot
.33319 .02967 Mdot
.3332 .02967 Mdot
.33321 .02968 Mdot
.33322 .02969 Mdot
.33323 .02969 Mdot
.33324 .0297 Mdot
.33325 .0297 Mdot
.33326 .02971 Mdot
.33327 .02971 Mdot
.33328 .02972 Mdot
.33329 .02973 Mdot
.3333 .02973 Mdot
.3333 .02974 Mdot
.33331 .02974 Mdot
.33332 .02975 Mdot
.33333 .02976 Mdot
.33334 .02976 Mdot
.33335 .02977 Mdot
.33336 .02977 Mdot
.33337 .02978 Mdot
.33338 .02978 Mdot
.33339 .02979 Mdot
.3334 .0298 Mdot
.33341 .0298 Mdot
.33342 .02981 Mdot
.33343 .02981 Mdot
.33344 .02982 Mdot
.33345 .02983 Mdot
.33346 .02983 Mdot
.33347 .02984 Mdot
.33348 .02984 Mdot
.33349 .02985 Mdot
.3335 .02985 Mdot
.3335 .02986 Mdot
.33351 .02987 Mdot
.33352 .02987 Mdot
.33353 .02988 Mdot
.33354 .02988 Mdot
.33355 .02989 Mdot
.33356 .0299 Mdot
.33357 .0299 Mdot
.33358 .02991 Mdot
.33359 .02991 Mdot
.3336 .02992 Mdot
.33361 .02993 Mdot
.33362 .02993 Mdot
.33363 .02994 Mdot
.33364 .02994 Mdot
.33365 .02995 Mdot
.33366 .02995 Mdot
.33367 .02996 Mdot
.33368 .02997 Mdot
.33369 .02997 Mdot
.3337 .02998 Mdot
.3337 .02998 Mdot
.33371 .02999 Mdot
.33372 .03 Mdot
.33373 .03 Mdot
.33374 .03001 Mdot
.33375 .03001 Mdot
.33376 .03002 Mdot
.33377 .03003 Mdot
.33378 .03003 Mdot
.33379 .03004 Mdot
.3338 .03004 Mdot
.33381 .03005 Mdot
.33382 .03006 Mdot
.33383 .03006 Mdot
.33384 .03007 Mdot
.33385 .03007 Mdot
.33386 .03008 Mdot
.33387 .03008 Mdot
.33388 .03009 Mdot
.33389 .0301 Mdot
.3339 .0301 Mdot
.3339 .03011 Mdot
.33391 .03011 Mdot
.33392 .03012 Mdot
.33393 .03013 Mdot
.33394 .03013 Mdot
.33395 .03014 Mdot
.33396 .03014 Mdot
.33397 .03015 Mdot
.33398 .03016 Mdot
.33399 .03016 Mdot
.334 .03017 Mdot
.33401 .03017 Mdot
.33402 .03018 Mdot
.33403 .03019 Mdot
.33404 .03019 Mdot
.33405 .0302 Mdot
.33406 .0302 Mdot
.33407 .03021 Mdot
.33408 .03022 Mdot
.33409 .03022 Mdot
.3341 .03023 Mdot
.3341 .03023 Mdot
.33411 .03024 Mdot
.33412 .03024 Mdot
.33413 .03025 Mdot
.33414 .03026 Mdot
.33415 .03026 Mdot
.33416 .03027 Mdot
.33417 .03027 Mdot
.33418 .03028 Mdot
.33419 .03029 Mdot
.3342 .03029 Mdot
.33421 .0303 Mdot
.33422 .0303 Mdot
.33423 .03031 Mdot
.33424 .03032 Mdot
.33425 .03032 Mdot
.33426 .03033 Mdot
.33427 .03033 Mdot
.33428 .03034 Mdot
.33429 .03035 Mdot
.3343 .03035 Mdot
.3343 .03036 Mdot
.33431 .03036 Mdot
.33432 .03037 Mdot
.33433 .03038 Mdot
.33434 .03038 Mdot
.33435 .03039 Mdot
.33436 .03039 Mdot
.33437 .0304 Mdot
.33438 .03041 Mdot
.33439 .03041 Mdot
.3344 .03042 Mdot
.33441 .03042 Mdot
.33442 .03043 Mdot
.33443 .03044 Mdot
.33444 .03044 Mdot
.33445 .03045 Mdot
.33446 .03045 Mdot
.33447 .03046 Mdot
.33448 .03047 Mdot
.33449 .03047 Mdot
.3345 .03048 Mdot
.3345 .03048 Mdot
.33451 .03049 Mdot
.33452 .0305 Mdot
.33453 .0305 Mdot
.33454 .03051 Mdot
.33455 .03051 Mdot
.33456 .03052 Mdot
.33457 .03053 Mdot
.33458 .03053 Mdot
.33459 .03054 Mdot
.3346 .03054 Mdot
.33461 .03055 Mdot
.33462 .03056 Mdot
.33463 .03056 Mdot
.33464 .03057 Mdot
.33465 .03057 Mdot
.33466 .03058 Mdot
.33467 .03059 Mdot
.33468 .03059 Mdot
.33469 .0306 Mdot
.3347 .0306 Mdot
.3347 .03061 Mdot
.33471 .03062 Mdot
.33472 .03062 Mdot
.33473 .03063 Mdot
.33474 .03063 Mdot
.33475 .03064 Mdot
.33476 .03065 Mdot
.33477 .03065 Mdot
.33478 .03066 Mdot
.33479 .03066 Mdot
.3348 .03067 Mdot
.33481 .03068 Mdot
.33482 .03068 Mdot
.33483 .03069 Mdot
.33484 .03069 Mdot
.33485 .0307 Mdot
.33486 .03071 Mdot
.33487 .03071 Mdot
.33488 .03072 Mdot
.33489 .03072 Mdot
.3349 .03073 Mdot
.3349 .03074 Mdot
.33491 .03074 Mdot
.33492 .03075 Mdot
.33493 .03075 Mdot
.33494 .03076 Mdot
.33495 .03077 Mdot
.33496 .03077 Mdot
.33497 .03078 Mdot
.33498 .03078 Mdot
.33499 .03079 Mdot
.335 .0308 Mdot
.33501 .0308 Mdot
.33502 .03081 Mdot
.33503 .03081 Mdot
.33504 .03082 Mdot
.33505 .03083 Mdot
.33506 .03083 Mdot
.33507 .03084 Mdot
.33508 .03085 Mdot
.33509 .03085 Mdot
.3351 .03086 Mdot
.3351 .03086 Mdot
.33511 .03087 Mdot
.33512 .03088 Mdot
.33513 .03088 Mdot
.33514 .03089 Mdot
.33515 .03089 Mdot
.33516 .0309 Mdot
.33517 .03091 Mdot
.33518 .03091 Mdot
.33519 .03092 Mdot
.3352 .03092 Mdot
.33521 .03093 Mdot
.33522 .03094 Mdot
.33523 .03094 Mdot
.33524 .03095 Mdot
.33525 .03095 Mdot
.33526 .03096 Mdot
.33527 .03097 Mdot
.33528 .03097 Mdot
.33529 .03098 Mdot
.3353 .03098 Mdot
.3353 .03099 Mdot
.33531 .031 Mdot
.33532 .031 Mdot
.33533 .03101 Mdot
.33534 .03102 Mdot
.33535 .03102 Mdot
.33536 .03103 Mdot
.33537 .03103 Mdot
.33538 .03104 Mdot
.33539 .03105 Mdot
.3354 .03105 Mdot
.33541 .03106 Mdot
.33542 .03106 Mdot
.33543 .03107 Mdot
.33544 .03108 Mdot
.33545 .03108 Mdot
.33546 .03109 Mdot
.33547 .03109 Mdot
.33548 .0311 Mdot
.33549 .03111 Mdot
.3355 .03111 Mdot
.3355 .03112 Mdot
.33551 .03113 Mdot
.33552 .03113 Mdot
.33553 .03114 Mdot
.33554 .03114 Mdot
.33555 .03115 Mdot
.33556 .03116 Mdot
.33557 .03116 Mdot
.33558 .03117 Mdot
.33559 .03117 Mdot
.3356 .03118 Mdot
.33561 .03119 Mdot
.33562 .03119 Mdot
.33563 .0312 Mdot
.33564 .0312 Mdot
.33565 .03121 Mdot
.33566 .03122 Mdot
.33567 .03122 Mdot
.33568 .03123 Mdot
.33569 .03124 Mdot
.3357 .03124 Mdot
.3357 .03125 Mdot
.33571 .03125 Mdot
.33572 .03126 Mdot
.33573 .03127 Mdot
.33574 .03127 Mdot
.33575 .03128 Mdot
.33576 .03128 Mdot
.33577 .03129 Mdot
.33578 .0313 Mdot
.33579 .0313 Mdot
.3358 .03131 Mdot
.33581 .03132 Mdot
.33582 .03132 Mdot
.33583 .03133 Mdot
.33584 .03133 Mdot
.33585 .03134 Mdot
.33586 .03135 Mdot
.33587 .03135 Mdot
.33588 .03136 Mdot
.33589 .03136 Mdot
.3359 .03137 Mdot
.3359 .03138 Mdot
.33591 .03138 Mdot
.33592 .03139 Mdot
.33593 .0314 Mdot
.33594 .0314 Mdot
.33595 .03141 Mdot
.33596 .03141 Mdot
.33597 .03142 Mdot
.33598 .03143 Mdot
.33599 .03143 Mdot
.336 .03144 Mdot
.33601 .03144 Mdot
.33602 .03145 Mdot
.33603 .03146 Mdot
.33604 .03146 Mdot
.33605 .03147 Mdot
.33606 .03148 Mdot
.33607 .03148 Mdot
.33608 .03149 Mdot
.33609 .03149 Mdot
.3361 .0315 Mdot
.3361 .03151 Mdot
.33611 .03151 Mdot
.33612 .03152 Mdot
.33613 .03152 Mdot
.33614 .03153 Mdot
.33615 .03154 Mdot
.33616 .03154 Mdot
.33617 .03155 Mdot
.33618 .03156 Mdot
.33619 .03156 Mdot
.3362 .03157 Mdot
.33621 .03157 Mdot
.33622 .03158 Mdot
.33623 .03159 Mdot
.33624 .03159 Mdot
.33625 .0316 Mdot
.33626 .03161 Mdot
.33627 .03161 Mdot
.33628 .03162 Mdot
.33629 .03162 Mdot
.3363 .03163 Mdot
.3363 .03164 Mdot
.33631 .03164 Mdot
.33632 .03165 Mdot
.33633 .03166 Mdot
.33634 .03166 Mdot
.33635 .03167 Mdot
.33636 .03167 Mdot
.33637 .03168 Mdot
.33638 .03169 Mdot
.33639 .03169 Mdot
.3364 .0317 Mdot
.33641 .0317 Mdot
.33642 .03171 Mdot
.33643 .03172 Mdot
.33644 .03172 Mdot
.33645 .03173 Mdot
.33646 .03174 Mdot
.33647 .03174 Mdot
.33648 .03175 Mdot
.33649 .03175 Mdot
.3365 .03176 Mdot
.3365 .03177 Mdot
.33651 .03177 Mdot
.33652 .03178 Mdot
.33653 .03179 Mdot
.33654 .03179 Mdot
.33655 .0318 Mdot
.33656 .0318 Mdot
.33657 .03181 Mdot
.33658 .03182 Mdot
.33659 .03182 Mdot
.3366 .03183 Mdot
.33661 .03184 Mdot
.33662 .03184 Mdot
.33663 .03185 Mdot
.33664 .03185 Mdot
.33665 .03186 Mdot
.33666 .03187 Mdot
.33667 .03187 Mdot
.33668 .03188 Mdot
.33669 .03189 Mdot
.3367 .03189 Mdot
.3367 .0319 Mdot
.33671 .0319 Mdot
.33672 .03191 Mdot
.33673 .03192 Mdot
.33674 .03192 Mdot
.33675 .03193 Mdot
.33676 .03194 Mdot
.33677 .03194 Mdot
.33678 .03195 Mdot
.33679 .03195 Mdot
.3368 .03196 Mdot
.33681 .03197 Mdot
.33682 .03197 Mdot
.33683 .03198 Mdot
.33684 .03199 Mdot
.33685 .03199 Mdot
.33686 .032 Mdot
.33687 .032 Mdot
.33688 .03201 Mdot
.33689 .03202 Mdot
.3369 .03202 Mdot
.3369 .03203 Mdot
.33691 .03204 Mdot
.33692 .03204 Mdot
.33693 .03205 Mdot
.33694 .03206 Mdot
.33695 .03206 Mdot
.33696 .03207 Mdot
.33697 .03207 Mdot
.33698 .03208 Mdot
.33699 .03209 Mdot
.337 .03209 Mdot
.33701 .0321 Mdot
.33702 .03211 Mdot
.33703 .03211 Mdot
.33704 .03212 Mdot
.33705 .03212 Mdot
.33706 .03213 Mdot
.33707 .03214 Mdot
.33708 .03214 Mdot
.33709 .03215 Mdot
.3371 .03216 Mdot
.3371 .03216 Mdot
.33711 .03217 Mdot
.33712 .03217 Mdot
.33713 .03218 Mdot
.33714 .03219 Mdot
.33715 .03219 Mdot
.33716 .0322 Mdot
.33717 .03221 Mdot
.33718 .03221 Mdot
.33719 .03222 Mdot
.3372 .03223 Mdot
.33721 .03223 Mdot
.33722 .03224 Mdot
.33723 .03224 Mdot
.33724 .03225 Mdot
.33725 .03226 Mdot
.33726 .03226 Mdot
.33727 .03227 Mdot
.33728 .03228 Mdot
.33729 .03228 Mdot
.3373 .03229 Mdot
.3373 .0323 Mdot
.33731 .0323 Mdot
.33732 .03231 Mdot
.33733 .03231 Mdot
.33734 .03232 Mdot
.33735 .03233 Mdot
.33736 .03233 Mdot
.33737 .03234 Mdot
.33738 .03235 Mdot
.33739 .03235 Mdot
.3374 .03236 Mdot
.33741 .03236 Mdot
.33742 .03237 Mdot
.33743 .03238 Mdot
.33744 .03238 Mdot
.33745 .03239 Mdot
.33746 .0324 Mdot
.33747 .0324 Mdot
.33748 .03241 Mdot
.33749 .03242 Mdot
.3375 .03242 Mdot
.3375 .03243 Mdot
.33751 .03243 Mdot
.33752 .03244 Mdot
.33753 .03245 Mdot
.33754 .03245 Mdot
.33755 .03246 Mdot
.33756 .03247 Mdot
.33757 .03247 Mdot
.33758 .03248 Mdot
.33759 .03249 Mdot
.3376 .03249 Mdot
.33761 .0325 Mdot
.33762 .0325 Mdot
.33763 .03251 Mdot
.33764 .03252 Mdot
.33765 .03252 Mdot
.33766 .03253 Mdot
.33767 .03254 Mdot
.33768 .03254 Mdot
.33769 .03255 Mdot
.3377 .03256 Mdot
.3377 .03256 Mdot
.33771 .03257 Mdot
.33772 .03257 Mdot
.33773 .03258 Mdot
.33774 .03259 Mdot
.33775 .03259 Mdot
.33776 .0326 Mdot
.33777 .03261 Mdot
.33778 .03261 Mdot
.33779 .03262 Mdot
.3378 .03263 Mdot
.33781 .03263 Mdot
.33782 .03264 Mdot
.33783 .03265 Mdot
.33784 .03265 Mdot
.33785 .03266 Mdot
.33786 .03266 Mdot
.33787 .03267 Mdot
.33788 .03268 Mdot
.33789 .03268 Mdot
.3379 .03269 Mdot
.3379 .0327 Mdot
.33791 .0327 Mdot
.33792 .03271 Mdot
.33793 .03272 Mdot
.33794 .03272 Mdot
.33795 .03273 Mdot
.33796 .03273 Mdot
.33797 .03274 Mdot
.33798 .03275 Mdot
.33799 .03275 Mdot
.338 .03276 Mdot
.33801 .03277 Mdot
.33802 .03277 Mdot
.33803 .03278 Mdot
.33804 .03279 Mdot
.33805 .03279 Mdot
.33806 .0328 Mdot
.33807 .03281 Mdot
.33808 .03281 Mdot
.33809 .03282 Mdot
.3381 .03282 Mdot
.3381 .03283 Mdot
.33811 .03284 Mdot
.33812 .03284 Mdot
.33813 .03285 Mdot
.33814 .03286 Mdot
.33815 .03286 Mdot
.33816 .03287 Mdot
.33817 .03288 Mdot
.33818 .03288 Mdot
.33819 .03289 Mdot
.3382 .0329 Mdot
.33821 .0329 Mdot
.33822 .03291 Mdot
.33823 .03291 Mdot
.33824 .03292 Mdot
.33825 .03293 Mdot
.33826 .03293 Mdot
.33827 .03294 Mdot
.33828 .03295 Mdot
.33829 .03295 Mdot
.3383 .03296 Mdot
.3383 .03297 Mdot
.33831 .03297 Mdot
.33832 .03298 Mdot
.33833 .03299 Mdot
.33834 .03299 Mdot
.33835 .033 Mdot
.33836 .03301 Mdot
.33837 .03301 Mdot
.33838 .03302 Mdot
.33839 .03302 Mdot
.3384 .03303 Mdot
.33841 .03304 Mdot
.33842 .03304 Mdot
.33843 .03305 Mdot
.33844 .03306 Mdot
.33845 .03306 Mdot
.33846 .03307 Mdot
.33847 .03308 Mdot
.33848 .03308 Mdot
.33849 .03309 Mdot
.3385 .0331 Mdot
.3385 .0331 Mdot
.33851 .03311 Mdot
.33852 .03312 Mdot
.33853 .03312 Mdot
.33854 .03313 Mdot
.33855 .03313 Mdot
.33856 .03314 Mdot
.33857 .03315 Mdot
.33858 .03315 Mdot
.33859 .03316 Mdot
.3386 .03317 Mdot
.33861 .03317 Mdot
.33862 .03318 Mdot
.33863 .03319 Mdot
.33864 .03319 Mdot
.33865 .0332 Mdot
.33866 .03321 Mdot
.33867 .03321 Mdot
.33868 .03322 Mdot
.33869 .03323 Mdot
.3387 .03323 Mdot
.3387 .03324 Mdot
.33871 .03325 Mdot
.33872 .03325 Mdot
.33873 .03326 Mdot
.33874 .03326 Mdot
.33875 .03327 Mdot
.33876 .03328 Mdot
.33877 .03328 Mdot
.33878 .03329 Mdot
.33879 .0333 Mdot
.3388 .0333 Mdot
.33881 .03331 Mdot
.33882 .03332 Mdot
.33883 .03332 Mdot
.33884 .03333 Mdot
.33885 .03334 Mdot
.33886 .03334 Mdot
.33887 .03335 Mdot
.33888 .03336 Mdot
.33889 .03336 Mdot
.3389 .03337 Mdot
.3389 .03338 Mdot
.33891 .03338 Mdot
.33892 .03339 Mdot
.33893 .0334 Mdot
.33894 .0334 Mdot
.33895 .03341 Mdot
.33896 .03341 Mdot
.33897 .03342 Mdot
.33898 .03343 Mdot
.33899 .03343 Mdot
.339 .03344 Mdot
.33901 .03345 Mdot
.33902 .03345 Mdot
.33903 .03346 Mdot
.33904 .03347 Mdot
.33905 .03347 Mdot
.33906 .03348 Mdot
.33907 .03349 Mdot
.33908 .03349 Mdot
.33909 .0335 Mdot
.3391 .03351 Mdot
.3391 .03351 Mdot
.33911 .03352 Mdot
.33912 .03353 Mdot
.33913 .03353 Mdot
.33914 .03354 Mdot
.33915 .03355 Mdot
.33916 .03355 Mdot
.33917 .03356 Mdot
.33918 .03357 Mdot
.33919 .03357 Mdot
.3392 .03358 Mdot
.33921 .03358 Mdot
.33922 .03359 Mdot
.33923 .0336 Mdot
.33924 .0336 Mdot
.33925 .03361 Mdot
.33926 .03362 Mdot
.33927 .03362 Mdot
.33928 .03363 Mdot
.33929 .03364 Mdot
.3393 .03364 Mdot
.3393 .03365 Mdot
.33931 .03366 Mdot
.33932 .03366 Mdot
.33933 .03367 Mdot
.33934 .03368 Mdot
.33935 .03368 Mdot
.33936 .03369 Mdot
.33937 .0337 Mdot
.33938 .0337 Mdot
.33939 .03371 Mdot
.3394 .03372 Mdot
.33941 .03372 Mdot
.33942 .03373 Mdot
.33943 .03374 Mdot
.33944 .03374 Mdot
.33945 .03375 Mdot
.33946 .03376 Mdot
.33947 .03376 Mdot
.33948 .03377 Mdot
.33949 .03378 Mdot
.3395 .03378 Mdot
.3395 .03379 Mdot
.33951 .0338 Mdot
.33952 .0338 Mdot
.33953 .03381 Mdot
.33954 .03382 Mdot
.33955 .03382 Mdot
.33956 .03383 Mdot
.33957 .03384 Mdot
.33958 .03384 Mdot
.33959 .03385 Mdot
.3396 .03386 Mdot
.33961 .03386 Mdot
.33962 .03387 Mdot
.33963 .03387 Mdot
.33964 .03388 Mdot
.33965 .03389 Mdot
.33966 .03389 Mdot
.33967 .0339 Mdot
.33968 .03391 Mdot
.33969 .03391 Mdot
.3397 .03392 Mdot
.3397 .03393 Mdot
.33971 .03393 Mdot
.33972 .03394 Mdot
.33973 .03395 Mdot
.33974 .03395 Mdot
.33975 .03396 Mdot
.33976 .03397 Mdot
.33977 .03397 Mdot
.33978 .03398 Mdot
.33979 .03399 Mdot
.3398 .03399 Mdot
.33981 .034 Mdot
.33982 .03401 Mdot
.33983 .03401 Mdot
.33984 .03402 Mdot
.33985 .03403 Mdot
.33986 .03403 Mdot
.33987 .03404 Mdot
.33988 .03405 Mdot
.33989 .03405 Mdot
.3399 .03406 Mdot
.3399 .03407 Mdot
.33991 .03407 Mdot
.33992 .03408 Mdot
.33993 .03409 Mdot
.33994 .03409 Mdot
.33995 .0341 Mdot
.33996 .03411 Mdot
.33997 .03411 Mdot
.33998 .03412 Mdot
.33999 .03413 Mdot
.34 .03413 Mdot
.34001 .03414 Mdot
.34002 .03415 Mdot
.34003 .03415 Mdot
.34004 .03416 Mdot
.34005 .03417 Mdot
.34006 .03417 Mdot
.34007 .03418 Mdot
.34008 .03419 Mdot
.34009 .03419 Mdot
.3401 .0342 Mdot
.3401 .03421 Mdot
.34011 .03421 Mdot
.34012 .03422 Mdot
.34013 .03423 Mdot
.34014 .03423 Mdot
.34015 .03424 Mdot
.34016 .03425 Mdot
.34017 .03425 Mdot
.34018 .03426 Mdot
.34019 .03427 Mdot
.3402 .03427 Mdot
.34021 .03428 Mdot
.34022 .03429 Mdot
.34023 .03429 Mdot
.34024 .0343 Mdot
.34025 .03431 Mdot
.34026 .03431 Mdot
.34027 .03432 Mdot
.34028 .03433 Mdot
.34029 .03433 Mdot
.3403 .03434 Mdot
.3403 .03435 Mdot
.34031 .03435 Mdot
.34032 .03436 Mdot
.34033 .03437 Mdot
.34034 .03437 Mdot
.34035 .03438 Mdot
.34036 .03439 Mdot
.34037 .03439 Mdot
.34038 .0344 Mdot
.34039 .03441 Mdot
.3404 .03441 Mdot
.34041 .03442 Mdot
.34042 .03443 Mdot
.34043 .03443 Mdot
.34044 .03444 Mdot
.34045 .03445 Mdot
.34046 .03446 Mdot
.34047 .03446 Mdot
.34048 .03447 Mdot
.34049 .03448 Mdot
.3405 .03448 Mdot
.3405 .03449 Mdot
.34051 .0345 Mdot
.34052 .0345 Mdot
.34053 .03451 Mdot
.34054 .03452 Mdot
.34055 .03452 Mdot
.34056 .03453 Mdot
.34057 .03454 Mdot
.34058 .03454 Mdot
.34059 .03455 Mdot
.3406 .03456 Mdot
.34061 .03456 Mdot
.34062 .03457 Mdot
.34063 .03458 Mdot
.34064 .03458 Mdot
.34065 .03459 Mdot
.34066 .0346 Mdot
.34067 .0346 Mdot
.34068 .03461 Mdot
.34069 .03462 Mdot
.3407 .03462 Mdot
.3407 .03463 Mdot
.34071 .03464 Mdot
.34072 .03464 Mdot
.34073 .03465 Mdot
.34074 .03466 Mdot
.34075 .03466 Mdot
.34076 .03467 Mdot
.34077 .03468 Mdot
.34078 .03468 Mdot
.34079 .03469 Mdot
.3408 .0347 Mdot
.34081 .0347 Mdot
.34082 .03471 Mdot
.34083 .03472 Mdot
.34084 .03472 Mdot
.34085 .03473 Mdot
.34086 .03474 Mdot
.34087 .03475 Mdot
.34088 .03475 Mdot
.34089 .03476 Mdot
.3409 .03477 Mdot
.3409 .03477 Mdot
.34091 .03478 Mdot
.34092 .03479 Mdot
.34093 .03479 Mdot
.34094 .0348 Mdot
.34095 .03481 Mdot
.34096 .03481 Mdot
.34097 .03482 Mdot
.34098 .03483 Mdot
.34099 .03483 Mdot
.341 .03484 Mdot
.34101 .03485 Mdot
.34102 .03485 Mdot
.34103 .03486 Mdot
.34104 .03487 Mdot
.34105 .03487 Mdot
.34106 .03488 Mdot
.34107 .03489 Mdot
.34108 .03489 Mdot
.34109 .0349 Mdot
.3411 .03491 Mdot
.3411 .03491 Mdot
.34111 .03492 Mdot
.34112 .03493 Mdot
.34113 .03494 Mdot
.34114 .03494 Mdot
.34115 .03495 Mdot
.34116 .03496 Mdot
.34117 .03496 Mdot
.34118 .03497 Mdot
.34119 .03498 Mdot
.3412 .03498 Mdot
.34121 .03499 Mdot
.34122 .035 Mdot
.34123 .035 Mdot
.34124 .03501 Mdot
.34125 .03502 Mdot
.34126 .03502 Mdot
.34127 .03503 Mdot
.34128 .03504 Mdot
.34129 .03504 Mdot
.3413 .03505 Mdot
.3413 .03506 Mdot
.34131 .03506 Mdot
.34132 .03507 Mdot
.34133 .03508 Mdot
.34134 .03509 Mdot
.34135 .03509 Mdot
.34136 .0351 Mdot
.34137 .03511 Mdot
.34138 .03511 Mdot
.34139 .03512 Mdot
.3414 .03513 Mdot
.34141 .03513 Mdot
.34142 .03514 Mdot
.34143 .03515 Mdot
.34144 .03515 Mdot
.34145 .03516 Mdot
.34146 .03517 Mdot
.34147 .03517 Mdot
.34148 .03518 Mdot
.34149 .03519 Mdot
.3415 .03519 Mdot
.3415 .0352 Mdot
.34151 .03521 Mdot
.34152 .03521 Mdot
.34153 .03522 Mdot
.34154 .03523 Mdot
.34155 .03524 Mdot
.34156 .03524 Mdot
.34157 .03525 Mdot
.34158 .03526 Mdot
.34159 .03526 Mdot
.3416 .03527 Mdot
.34161 .03528 Mdot
.34162 .03528 Mdot
.34163 .03529 Mdot
.34164 .0353 Mdot
.34165 .0353 Mdot
.34166 .03531 Mdot
.34167 .03532 Mdot
.34168 .03532 Mdot
.34169 .03533 Mdot
.3417 .03534 Mdot
.3417 .03535 Mdot
.34171 .03535 Mdot
.34172 .03536 Mdot
.34173 .03537 Mdot
.34174 .03537 Mdot
.34175 .03538 Mdot
.34176 .03539 Mdot
.34177 .03539 Mdot
.34178 .0354 Mdot
.34179 .03541 Mdot
.3418 .03541 Mdot
.34181 .03542 Mdot
.34182 .03543 Mdot
.34183 .03543 Mdot
.34184 .03544 Mdot
.34185 .03545 Mdot
.34186 .03546 Mdot
.34187 .03546 Mdot
.34188 .03547 Mdot
.34189 .03548 Mdot
.3419 .03548 Mdot
.3419 .03549 Mdot
.34191 .0355 Mdot
.34192 .0355 Mdot
.34193 .03551 Mdot
.34194 .03552 Mdot
.34195 .03552 Mdot
.34196 .03553 Mdot
.34197 .03554 Mdot
.34198 .03555 Mdot
.34199 .03555 Mdot
.342 .03556 Mdot
.34201 .03557 Mdot
.34202 .03557 Mdot
.34203 .03558 Mdot
.34204 .03559 Mdot
.34205 .03559 Mdot
.34206 .0356 Mdot
.34207 .03561 Mdot
.34208 .03561 Mdot
.34209 .03562 Mdot
.3421 .03563 Mdot
.3421 .03563 Mdot
.34211 .03564 Mdot
.34212 .03565 Mdot
.34213 .03566 Mdot
.34214 .03566 Mdot
.34215 .03567 Mdot
.34216 .03568 Mdot
.34217 .03568 Mdot
.34218 .03569 Mdot
.34219 .0357 Mdot
.3422 .0357 Mdot
.34221 .03571 Mdot
.34222 .03572 Mdot
.34223 .03573 Mdot
.34224 .03573 Mdot
.34225 .03574 Mdot
.34226 .03575 Mdot
.34227 .03575 Mdot
.34228 .03576 Mdot
.34229 .03577 Mdot
.3423 .03577 Mdot
.3423 .03578 Mdot
.34231 .03579 Mdot
.34232 .03579 Mdot
.34233 .0358 Mdot
.34234 .03581 Mdot
.34235 .03582 Mdot
.34236 .03582 Mdot
.34237 .03583 Mdot
.34238 .03584 Mdot
.34239 .03584 Mdot
.3424 .03585 Mdot
.34241 .03586 Mdot
.34242 .03586 Mdot
.34243 .03587 Mdot
.34244 .03588 Mdot
.34245 .03588 Mdot
.34246 .03589 Mdot
.34247 .0359 Mdot
.34248 .03591 Mdot
.34249 .03591 Mdot
.3425 .03592 Mdot
.3425 .03593 Mdot
.34251 .03593 Mdot
.34252 .03594 Mdot
.34253 .03595 Mdot
.34254 .03595 Mdot
.34255 .03596 Mdot
.34256 .03597 Mdot
.34257 .03598 Mdot
.34258 .03598 Mdot
.34259 .03599 Mdot
.3426 .036 Mdot
.34261 .036 Mdot
.34262 .03601 Mdot
.34263 .03602 Mdot
.34264 .03602 Mdot
.34265 .03603 Mdot
.34266 .03604 Mdot
.34267 .03605 Mdot
.34268 .03605 Mdot
.34269 .03606 Mdot
.3427 .03607 Mdot
.3427 .03607 Mdot
.34271 .03608 Mdot
.34272 .03609 Mdot
.34273 .03609 Mdot
.34274 .0361 Mdot
.34275 .03611 Mdot
.34276 .03612 Mdot
.34277 .03612 Mdot
.34278 .03613 Mdot
.34279 .03614 Mdot
.3428 .03614 Mdot
.34281 .03615 Mdot
.34282 .03616 Mdot
.34283 .03616 Mdot
.34284 .03617 Mdot
.34285 .03618 Mdot
.34286 .03619 Mdot
.34287 .03619 Mdot
.34288 .0362 Mdot
.34289 .03621 Mdot
.3429 .03621 Mdot
.3429 .03622 Mdot
.34291 .03623 Mdot
.34292 .03623 Mdot
.34293 .03624 Mdot
.34294 .03625 Mdot
.34295 .03626 Mdot
.34296 .03626 Mdot
.34297 .03627 Mdot
.34298 .03628 Mdot
.34299 .03628 Mdot
.343 .03629 Mdot
.34301 .0363 Mdot
.34302 .0363 Mdot
.34303 .03631 Mdot
.34304 .03632 Mdot
.34305 .03633 Mdot
.34306 .03633 Mdot
.34307 .03634 Mdot
.34308 .03635 Mdot
.34309 .03635 Mdot
.3431 .03636 Mdot
.3431 .03637 Mdot
.34311 .03638 Mdot
.34312 .03638 Mdot
.34313 .03639 Mdot
.34314 .0364 Mdot
.34315 .0364 Mdot
.34316 .03641 Mdot
.34317 .03642 Mdot
.34318 .03642 Mdot
.34319 .03643 Mdot
.3432 .03644 Mdot
.34321 .03645 Mdot
.34322 .03645 Mdot
.34323 .03646 Mdot
.34324 .03647 Mdot
.34325 .03647 Mdot
.34326 .03648 Mdot
.34327 .03649 Mdot
.34328 .0365 Mdot
.34329 .0365 Mdot
.3433 .03651 Mdot
.3433 .03652 Mdot
.34331 .03652 Mdot
.34332 .03653 Mdot
.34333 .03654 Mdot
.34334 .03654 Mdot
.34335 .03655 Mdot
.34336 .03656 Mdot
.34337 .03657 Mdot
.34338 .03657 Mdot
.34339 .03658 Mdot
.3434 .03659 Mdot
.34341 .03659 Mdot
.34342 .0366 Mdot
.34343 .03661 Mdot
.34344 .03662 Mdot
.34345 .03662 Mdot
.34346 .03663 Mdot
.34347 .03664 Mdot
.34348 .03664 Mdot
.34349 .03665 Mdot
.3435 .03666 Mdot
.3435 .03666 Mdot
.34351 .03667 Mdot
.34352 .03668 Mdot
.34353 .03669 Mdot
.34354 .03669 Mdot
.34355 .0367 Mdot
.34356 .03671 Mdot
.34357 .03671 Mdot
.34358 .03672 Mdot
.34359 .03673 Mdot
.3436 .03674 Mdot
.34361 .03674 Mdot
.34362 .03675 Mdot
.34363 .03676 Mdot
.34364 .03676 Mdot
.34365 .03677 Mdot
.34366 .03678 Mdot
.34367 .03679 Mdot
.34368 .03679 Mdot
.34369 .0368 Mdot
.3437 .03681 Mdot
.3437 .03681 Mdot
.34371 .03682 Mdot
.34372 .03683 Mdot
.34373 .03684 Mdot
.34374 .03684 Mdot
.34375 .03685 Mdot
.34376 .03686 Mdot
.34377 .03686 Mdot
.34378 .03687 Mdot
.34379 .03688 Mdot
.3438 .03689 Mdot
.34381 .03689 Mdot
.34382 .0369 Mdot
.34383 .03691 Mdot
.34384 .03691 Mdot
.34385 .03692 Mdot
.34386 .03693 Mdot
.34387 .03694 Mdot
.34388 .03694 Mdot
.34389 .03695 Mdot
.3439 .03696 Mdot
.3439 .03696 Mdot
.34391 .03697 Mdot
.34392 .03698 Mdot
.34393 .03699 Mdot
.34394 .03699 Mdot
.34395 .037 Mdot
.34396 .03701 Mdot
.34397 .03701 Mdot
.34398 .03702 Mdot
.34399 .03703 Mdot
.344 .03704 Mdot
.34401 .03704 Mdot
.34402 .03705 Mdot
.34403 .03706 Mdot
.34404 .03706 Mdot
.34405 .03707 Mdot
.34406 .03708 Mdot
.34407 .03709 Mdot
.34408 .03709 Mdot
.34409 .0371 Mdot
.3441 .03711 Mdot
.3441 .03711 Mdot
.34411 .03712 Mdot
.34412 .03713 Mdot
.34413 .03714 Mdot
.34414 .03714 Mdot
.34415 .03715 Mdot
.34416 .03716 Mdot
.34417 .03716 Mdot
.34418 .03717 Mdot
.34419 .03718 Mdot
.3442 .03719 Mdot
.34421 .03719 Mdot
.34422 .0372 Mdot
.34423 .03721 Mdot
.34424 .03721 Mdot
.34425 .03722 Mdot
.34426 .03723 Mdot
.34427 .03724 Mdot
.34428 .03724 Mdot
.34429 .03725 Mdot
.3443 .03726 Mdot
.3443 .03726 Mdot
.34431 .03727 Mdot
.34432 .03728 Mdot
.34433 .03729 Mdot
.34434 .03729 Mdot
.34435 .0373 Mdot
.34436 .03731 Mdot
.34437 .03732 Mdot
.34438 .03732 Mdot
.34439 .03733 Mdot
.3444 .03734 Mdot
.34441 .03734 Mdot
.34442 .03735 Mdot
.34443 .03736 Mdot
.34444 .03737 Mdot
.34445 .03737 Mdot
.34446 .03738 Mdot
.34447 .03739 Mdot
.34448 .03739 Mdot
.34449 .0374 Mdot
.3445 .03741 Mdot
.3445 .03742 Mdot
.34451 .03742 Mdot
.34452 .03743 Mdot
.34453 .03744 Mdot
.34454 .03745 Mdot
.34455 .03745 Mdot
.34456 .03746 Mdot
.34457 .03747 Mdot
.34458 .03747 Mdot
.34459 .03748 Mdot
.3446 .03749 Mdot
.34461 .0375 Mdot
.34462 .0375 Mdot
.34463 .03751 Mdot
.34464 .03752 Mdot
.34465 .03752 Mdot
.34466 .03753 Mdot
.34467 .03754 Mdot
.34468 .03755 Mdot
.34469 .03755 Mdot
.3447 .03756 Mdot
.3447 .03757 Mdot
.34471 .03758 Mdot
.34472 .03758 Mdot
.34473 .03759 Mdot
.34474 .0376 Mdot
.34475 .0376 Mdot
.34476 .03761 Mdot
.34477 .03762 Mdot
.34478 .03763 Mdot
.34479 .03763 Mdot
.3448 .03764 Mdot
.34481 .03765 Mdot
.34482 .03765 Mdot
.34483 .03766 Mdot
.34484 .03767 Mdot
.34485 .03768 Mdot
.34486 .03768 Mdot
.34487 .03769 Mdot
.34488 .0377 Mdot
.34489 .03771 Mdot
.3449 .03771 Mdot
.3449 .03772 Mdot
.34491 .03773 Mdot
.34492 .03773 Mdot
.34493 .03774 Mdot
.34494 .03775 Mdot
.34495 .03776 Mdot
.34496 .03776 Mdot
.34497 .03777 Mdot
.34498 .03778 Mdot
.34499 .03779 Mdot
.345 .03779 Mdot
.34501 .0378 Mdot
.34502 .03781 Mdot
.34503 .03781 Mdot
.34504 .03782 Mdot
.34505 .03783 Mdot
.34506 .03784 Mdot
.34507 .03784 Mdot
.34508 .03785 Mdot
.34509 .03786 Mdot
.3451 .03787 Mdot
.3451 .03787 Mdot
.34511 .03788 Mdot
.34512 .03789 Mdot
.34513 .03789 Mdot
.34514 .0379 Mdot
.34515 .03791 Mdot
.34516 .03792 Mdot
.34517 .03792 Mdot
.34518 .03793 Mdot
.34519 .03794 Mdot
.3452 .03795 Mdot
.34521 .03795 Mdot
.34522 .03796 Mdot
.34523 .03797 Mdot
.34524 .03798 Mdot
.34525 .03798 Mdot
.34526 .03799 Mdot
.34527 .038 Mdot
.34528 .038 Mdot
.34529 .03801 Mdot
.3453 .03802 Mdot
.3453 .03803 Mdot
.34531 .03803 Mdot
.34532 .03804 Mdot
.34533 .03805 Mdot
.34534 .03806 Mdot
.34535 .03806 Mdot
.34536 .03807 Mdot
.34537 .03808 Mdot
.34538 .03809 Mdot
.34539 .03809 Mdot
.3454 .0381 Mdot
.34541 .03811 Mdot
.34542 .03811 Mdot
.34543 .03812 Mdot
.34544 .03813 Mdot
.34545 .03814 Mdot
.34546 .03814 Mdot
.34547 .03815 Mdot
.34548 .03816 Mdot
.34549 .03817 Mdot
.3455 .03817 Mdot
.3455 .03818 Mdot
.34551 .03819 Mdot
.34552 .03819 Mdot
.34553 .0382 Mdot
.34554 .03821 Mdot
.34555 .03822 Mdot
.34556 .03822 Mdot
.34557 .03823 Mdot
.34558 .03824 Mdot
.34559 .03825 Mdot
.3456 .03825 Mdot
.34561 .03826 Mdot
.34562 .03827 Mdot
.34563 .03828 Mdot
.34564 .03828 Mdot
.34565 .03829 Mdot
.34566 .0383 Mdot
.34567 .03831 Mdot
.34568 .03831 Mdot
.34569 .03832 Mdot
.3457 .03833 Mdot
.3457 .03833 Mdot
.34571 .03834 Mdot
.34572 .03835 Mdot
.34573 .03836 Mdot
.34574 .03836 Mdot
.34575 .03837 Mdot
.34576 .03838 Mdot
.34577 .03839 Mdot
.34578 .03839 Mdot
.34579 .0384 Mdot
.3458 .03841 Mdot
.34581 .03842 Mdot
.34582 .03842 Mdot
.34583 .03843 Mdot
.34584 .03844 Mdot
.34585 .03845 Mdot
.34586 .03845 Mdot
.34587 .03846 Mdot
.34588 .03847 Mdot
.34589 .03847 Mdot
.3459 .03848 Mdot
.3459 .03849 Mdot
.34591 .0385 Mdot
.34592 .0385 Mdot
.34593 .03851 Mdot
.34594 .03852 Mdot
.34595 .03853 Mdot
.34596 .03853 Mdot
.34597 .03854 Mdot
.34598 .03855 Mdot
.34599 .03856 Mdot
.346 .03856 Mdot
.34601 .03857 Mdot
.34602 .03858 Mdot
.34603 .03859 Mdot
.34604 .03859 Mdot
.34605 .0386 Mdot
.34606 .03861 Mdot
.34607 .03862 Mdot
.34608 .03862 Mdot
.34609 .03863 Mdot
.3461 .03864 Mdot
.3461 .03864 Mdot
.34611 .03865 Mdot
.34612 .03866 Mdot
.34613 .03867 Mdot
.34614 .03867 Mdot
.34615 .03868 Mdot
.34616 .03869 Mdot
.34617 .0387 Mdot
.34618 .0387 Mdot
.34619 .03871 Mdot
.3462 .03872 Mdot
.34621 .03873 Mdot
.34622 .03873 Mdot
.34623 .03874 Mdot
.34624 .03875 Mdot
.34625 .03876 Mdot
.34626 .03876 Mdot
.34627 .03877 Mdot
.34628 .03878 Mdot
.34629 .03879 Mdot
.3463 .03879 Mdot
.3463 .0388 Mdot
.34631 .03881 Mdot
.34632 .03882 Mdot
.34633 .03882 Mdot
.34634 .03883 Mdot
.34635 .03884 Mdot
.34636 .03885 Mdot
.34637 .03885 Mdot
.34638 .03886 Mdot
.34639 .03887 Mdot
.3464 .03888 Mdot
.34641 .03888 Mdot
.34642 .03889 Mdot
.34643 .0389 Mdot
.34644 .03891 Mdot
.34645 .03891 Mdot
.34646 .03892 Mdot
.34647 .03893 Mdot
.34648 .03893 Mdot
.34649 .03894 Mdot
.3465 .03895 Mdot
.3465 .03896 Mdot
.34651 .03896 Mdot
.34652 .03897 Mdot
.34653 .03898 Mdot
.34654 .03899 Mdot
.34655 .03899 Mdot
.34656 .039 Mdot
.34657 .03901 Mdot
.34658 .03902 Mdot
.34659 .03902 Mdot
.3466 .03903 Mdot
.34661 .03904 Mdot
.34662 .03905 Mdot
.34663 .03905 Mdot
.34664 .03906 Mdot
.34665 .03907 Mdot
.34666 .03908 Mdot
.34667 .03908 Mdot
.34668 .03909 Mdot
.34669 .0391 Mdot
.3467 .03911 Mdot
.3467 .03911 Mdot
.34671 .03912 Mdot
.34672 .03913 Mdot
.34673 .03914 Mdot
.34674 .03914 Mdot
.34675 .03915 Mdot
.34676 .03916 Mdot
.34677 .03917 Mdot
.34678 .03917 Mdot
.34679 .03918 Mdot
.3468 .03919 Mdot
.34681 .0392 Mdot
.34682 .0392 Mdot
.34683 .03921 Mdot
.34684 .03922 Mdot
.34685 .03923 Mdot
.34686 .03923 Mdot
.34687 .03924 Mdot
.34688 .03925 Mdot
.34689 .03926 Mdot
.3469 .03926 Mdot
.3469 .03927 Mdot
.34691 .03928 Mdot
.34692 .03929 Mdot
.34693 .03929 Mdot
.34694 .0393 Mdot
.34695 .03931 Mdot
.34696 .03932 Mdot
.34697 .03932 Mdot
.34698 .03933 Mdot
.34699 .03934 Mdot
.347 .03935 Mdot
.34701 .03935 Mdot
.34702 .03936 Mdot
.34703 .03937 Mdot
.34704 .03938 Mdot
.34705 .03938 Mdot
.34706 .03939 Mdot
.34707 .0394 Mdot
.34708 .03941 Mdot
.34709 .03941 Mdot
.3471 .03942 Mdot
.3471 .03943 Mdot
.34711 .03944 Mdot
.34712 .03944 Mdot
.34713 .03945 Mdot
.34714 .03946 Mdot
.34715 .03947 Mdot
.34716 .03948 Mdot
.34717 .03948 Mdot
.34718 .03949 Mdot
.34719 .0395 Mdot
.3472 .03951 Mdot
.34721 .03951 Mdot
.34722 .03952 Mdot
.34723 .03953 Mdot
.34724 .03954 Mdot
.34725 .03954 Mdot
.34726 .03955 Mdot
.34727 .03956 Mdot
.34728 .03957 Mdot
.34729 .03957 Mdot
.3473 .03958 Mdot
.3473 .03959 Mdot
.34731 .0396 Mdot
.34732 .0396 Mdot
.34733 .03961 Mdot
.34734 .03962 Mdot
.34735 .03963 Mdot
.34736 .03963 Mdot
.34737 .03964 Mdot
.34738 .03965 Mdot
.34739 .03966 Mdot
.3474 .03966 Mdot
.34741 .03967 Mdot
.34742 .03968 Mdot
.34743 .03969 Mdot
.34744 .03969 Mdot
.34745 .0397 Mdot
.34746 .03971 Mdot
.34747 .03972 Mdot
.34748 .03972 Mdot
.34749 .03973 Mdot
.3475 .03974 Mdot
.3475 .03975 Mdot
.34751 .03975 Mdot
.34752 .03976 Mdot
.34753 .03977 Mdot
.34754 .03978 Mdot
.34755 .03979 Mdot
.34756 .03979 Mdot
.34757 .0398 Mdot
.34758 .03981 Mdot
.34759 .03982 Mdot
.3476 .03982 Mdot
.34761 .03983 Mdot
.34762 .03984 Mdot
.34763 .03985 Mdot
.34764 .03985 Mdot
.34765 .03986 Mdot
.34766 .03987 Mdot
.34767 .03988 Mdot
.34768 .03988 Mdot
.34769 .03989 Mdot
.3477 .0399 Mdot
.3477 .03991 Mdot
.34771 .03991 Mdot
.34772 .03992 Mdot
.34773 .03993 Mdot
.34774 .03994 Mdot
.34775 .03994 Mdot
.34776 .03995 Mdot
.34777 .03996 Mdot
.34778 .03997 Mdot
.34779 .03998 Mdot
.3478 .03998 Mdot
.34781 .03999 Mdot
.34782 .04 Mdot
.34783 .04001 Mdot
.34784 .04001 Mdot
.34785 .04002 Mdot
.34786 .04003 Mdot
.34787 .04004 Mdot
.34788 .04004 Mdot
.34789 .04005 Mdot
.3479 .04006 Mdot
.3479 .04007 Mdot
.34791 .04007 Mdot
.34792 .04008 Mdot
.34793 .04009 Mdot
.34794 .0401 Mdot
.34795 .04011 Mdot
.34796 .04011 Mdot
.34797 .04012 Mdot
.34798 .04013 Mdot
.34799 .04014 Mdot
.348 .04014 Mdot
.34801 .04015 Mdot
.34802 .04016 Mdot
.34803 .04017 Mdot
.34804 .04017 Mdot
.34805 .04018 Mdot
.34806 .04019 Mdot
.34807 .0402 Mdot
.34808 .0402 Mdot
.34809 .04021 Mdot
.3481 .04022 Mdot
.3481 .04023 Mdot
.34811 .04024 Mdot
.34812 .04024 Mdot
.34813 .04025 Mdot
.34814 .04026 Mdot
.34815 .04027 Mdot
.34816 .04027 Mdot
.34817 .04028 Mdot
.34818 .04029 Mdot
.34819 .0403 Mdot
.3482 .0403 Mdot
.34821 .04031 Mdot
.34822 .04032 Mdot
.34823 .04033 Mdot
.34824 .04033 Mdot
.34825 .04034 Mdot
.34826 .04035 Mdot
.34827 .04036 Mdot
.34828 .04037 Mdot
.34829 .04037 Mdot
.3483 .04038 Mdot
.3483 .04039 Mdot
.34831 .0404 Mdot
.34832 .0404 Mdot
.34833 .04041 Mdot
.34834 .04042 Mdot
.34835 .04043 Mdot
.34836 .04043 Mdot
.34837 .04044 Mdot
.34838 .04045 Mdot
.34839 .04046 Mdot
.3484 .04047 Mdot
.34841 .04047 Mdot
.34842 .04048 Mdot
.34843 .04049 Mdot
.34844 .0405 Mdot
.34845 .0405 Mdot
.34846 .04051 Mdot
.34847 .04052 Mdot
.34848 .04053 Mdot
.34849 .04053 Mdot
.3485 .04054 Mdot
.3485 .04055 Mdot
.34851 .04056 Mdot
.34852 .04057 Mdot
.34853 .04057 Mdot
.34854 .04058 Mdot
.34855 .04059 Mdot
.34856 .0406 Mdot
.34857 .0406 Mdot
.34858 .04061 Mdot
.34859 .04062 Mdot
.3486 .04063 Mdot
.34861 .04064 Mdot
.34862 .04064 Mdot
.34863 .04065 Mdot
.34864 .04066 Mdot
.34865 .04067 Mdot
.34866 .04067 Mdot
.34867 .04068 Mdot
.34868 .04069 Mdot
.34869 .0407 Mdot
.3487 .0407 Mdot
.3487 .04071 Mdot
.34871 .04072 Mdot
.34872 .04073 Mdot
.34873 .04074 Mdot
.34874 .04074 Mdot
.34875 .04075 Mdot
.34876 .04076 Mdot
.34877 .04077 Mdot
.34878 .04077 Mdot
.34879 .04078 Mdot
.3488 .04079 Mdot
.34881 .0408 Mdot
.34882 .04081 Mdot
.34883 .04081 Mdot
.34884 .04082 Mdot
.34885 .04083 Mdot
.34886 .04084 Mdot
.34887 .04084 Mdot
.34888 .04085 Mdot
.34889 .04086 Mdot
.3489 .04087 Mdot
.3489 .04088 Mdot
.34891 .04088 Mdot
.34892 .04089 Mdot
.34893 .0409 Mdot
.34894 .04091 Mdot
.34895 .04091 Mdot
.34896 .04092 Mdot
.34897 .04093 Mdot
.34898 .04094 Mdot
.34899 .04094 Mdot
.349 .04095 Mdot
.34901 .04096 Mdot
.34902 .04097 Mdot
.34903 .04098 Mdot
.34904 .04098 Mdot
.34905 .04099 Mdot
.34906 .041 Mdot
.34907 .04101 Mdot
.34908 .04101 Mdot
.34909 .04102 Mdot
.3491 .04103 Mdot
.3491 .04104 Mdot
.34911 .04105 Mdot
.34912 .04105 Mdot
.34913 .04106 Mdot
.34914 .04107 Mdot
.34915 .04108 Mdot
.34916 .04108 Mdot
.34917 .04109 Mdot
.34918 .0411 Mdot
.34919 .04111 Mdot
.3492 .04112 Mdot
.34921 .04112 Mdot
.34922 .04113 Mdot
.34923 .04114 Mdot
.34924 .04115 Mdot
.34925 .04116 Mdot
.34926 .04116 Mdot
.34927 .04117 Mdot
.34928 .04118 Mdot
.34929 .04119 Mdot
.3493 .04119 Mdot
.3493 .0412 Mdot
.34931 .04121 Mdot
.34932 .04122 Mdot
.34933 .04123 Mdot
.34934 .04123 Mdot
.34935 .04124 Mdot
.34936 .04125 Mdot
.34937 .04126 Mdot
.34938 .04126 Mdot
.34939 .04127 Mdot
.3494 .04128 Mdot
.34941 .04129 Mdot
.34942 .0413 Mdot
.34943 .0413 Mdot
.34944 .04131 Mdot
.34945 .04132 Mdot
.34946 .04133 Mdot
.34947 .04133 Mdot
.34948 .04134 Mdot
.34949 .04135 Mdot
.3495 .04136 Mdot
.3495 .04137 Mdot
.34951 .04137 Mdot
.34952 .04138 Mdot
.34953 .04139 Mdot
.34954 .0414 Mdot
.34955 .04141 Mdot
.34956 .04141 Mdot
.34957 .04142 Mdot
.34958 .04143 Mdot
.34959 .04144 Mdot
.3496 .04144 Mdot
.34961 .04145 Mdot
.34962 .04146 Mdot
.34963 .04147 Mdot
.34964 .04148 Mdot
.34965 .04148 Mdot
.34966 .04149 Mdot
.34967 .0415 Mdot
.34968 .04151 Mdot
.34969 .04152 Mdot
.3497 .04152 Mdot
.3497 .04153 Mdot
.34971 .04154 Mdot
.34972 .04155 Mdot
.34973 .04155 Mdot
.34974 .04156 Mdot
.34975 .04157 Mdot
.34976 .04158 Mdot
.34977 .04159 Mdot
.34978 .04159 Mdot
.34979 .0416 Mdot
.3498 .04161 Mdot
.34981 .04162 Mdot
.34982 .04163 Mdot
.34983 .04163 Mdot
.34984 .04164 Mdot
.34985 .04165 Mdot
.34986 .04166 Mdot
.34987 .04166 Mdot
.34988 .04167 Mdot
.34989 .04168 Mdot
.3499 .04169 Mdot
.3499 .0417 Mdot
.34991 .0417 Mdot
.34992 .04171 Mdot
.34993 .04172 Mdot
.34994 .04173 Mdot
.34995 .04174 Mdot
.34996 .04174 Mdot
.34997 .04175 Mdot
.34998 .04176 Mdot
.34999 .04177 Mdot
.35 .04177 Mdot
.35001 .04178 Mdot
.35002 .04179 Mdot
.35003 .0418 Mdot
.35004 .04181 Mdot
.35005 .04181 Mdot
.35006 .04182 Mdot
.35007 .04183 Mdot
.35008 .04184 Mdot
.35009 .04185 Mdot
.3501 .04185 Mdot
.3501 .04186 Mdot
.35011 .04187 Mdot
.35012 .04188 Mdot
.35013 .04189 Mdot
.35014 .04189 Mdot
.35015 .0419 Mdot
.35016 .04191 Mdot
.35017 .04192 Mdot
.35018 .04193 Mdot
.35019 .04193 Mdot
.3502 .04194 Mdot
.35021 .04195 Mdot
.35022 .04196 Mdot
.35023 .04196 Mdot
.35024 .04197 Mdot
.35025 .04198 Mdot
.35026 .04199 Mdot
.35027 .042 Mdot
.35028 .042 Mdot
.35029 .04201 Mdot
.3503 .04202 Mdot
.3503 .04203 Mdot
.35031 .04204 Mdot
.35032 .04204 Mdot
.35033 .04205 Mdot
.35034 .04206 Mdot
.35035 .04207 Mdot
.35036 .04208 Mdot
.35037 .04208 Mdot
.35038 .04209 Mdot
.35039 .0421 Mdot
.3504 .04211 Mdot
.35041 .04212 Mdot
.35042 .04212 Mdot
.35043 .04213 Mdot
.35044 .04214 Mdot
.35045 .04215 Mdot
.35046 .04216 Mdot
.35047 .04216 Mdot
.35048 .04217 Mdot
.35049 .04218 Mdot
.3505 .04219 Mdot
.3505 .04219 Mdot
.35051 .0422 Mdot
.35052 .04221 Mdot
.35053 .04222 Mdot
.35054 .04223 Mdot
.35055 .04223 Mdot
.35056 .04224 Mdot
.35057 .04225 Mdot
.35058 .04226 Mdot
.35059 .04227 Mdot
.3506 .04227 Mdot
.35061 .04228 Mdot
.35062 .04229 Mdot
.35063 .0423 Mdot
.35064 .04231 Mdot
.35065 .04231 Mdot
.35066 .04232 Mdot
.35067 .04233 Mdot
.35068 .04234 Mdot
.35069 .04235 Mdot
.3507 .04235 Mdot
.3507 .04236 Mdot
.35071 .04237 Mdot
.35072 .04238 Mdot
.35073 .04239 Mdot
.35074 .04239 Mdot
.35075 .0424 Mdot
.35076 .04241 Mdot
.35077 .04242 Mdot
.35078 .04243 Mdot
.35079 .04243 Mdot
.3508 .04244 Mdot
.35081 .04245 Mdot
.35082 .04246 Mdot
.35083 .04247 Mdot
.35084 .04247 Mdot
.35085 .04248 Mdot
.35086 .04249 Mdot
.35087 .0425 Mdot
.35088 .04251 Mdot
.35089 .04251 Mdot
.3509 .04252 Mdot
.3509 .04253 Mdot
.35091 .04254 Mdot
.35092 .04255 Mdot
.35093 .04255 Mdot
.35094 .04256 Mdot
.35095 .04257 Mdot
.35096 .04258 Mdot
.35097 .04259 Mdot
.35098 .04259 Mdot
.35099 .0426 Mdot
.351 .04261 Mdot
.35101 .04262 Mdot
.35102 .04263 Mdot
.35103 .04263 Mdot
.35104 .04264 Mdot
.35105 .04265 Mdot
.35106 .04266 Mdot
.35107 .04267 Mdot
.35108 .04267 Mdot
.35109 .04268 Mdot
.3511 .04269 Mdot
.3511 .0427 Mdot
.35111 .04271 Mdot
.35112 .04271 Mdot
.35113 .04272 Mdot
.35114 .04273 Mdot
.35115 .04274 Mdot
.35116 .04275 Mdot
.35117 .04275 Mdot
.35118 .04276 Mdot
.35119 .04277 Mdot
.3512 .04278 Mdot
.35121 .04279 Mdot
.35122 .04279 Mdot
.35123 .0428 Mdot
.35124 .04281 Mdot
.35125 .04282 Mdot
.35126 .04283 Mdot
.35127 .04284 Mdot
.35128 .04284 Mdot
.35129 .04285 Mdot
.3513 .04286 Mdot
.3513 .04287 Mdot
.35131 .04288 Mdot
.35132 .04288 Mdot
.35133 .04289 Mdot
.35134 .0429 Mdot
.35135 .04291 Mdot
.35136 .04292 Mdot
.35137 .04292 Mdot
.35138 .04293 Mdot
.35139 .04294 Mdot
.3514 .04295 Mdot
.35141 .04296 Mdot
.35142 .04296 Mdot
.35143 .04297 Mdot
.35144 .04298 Mdot
.35145 .04299 Mdot
.35146 .043 Mdot
.35147 .043 Mdot
.35148 .04301 Mdot
.35149 .04302 Mdot
.3515 .04303 Mdot
.3515 .04304 Mdot
.35151 .04304 Mdot
.35152 .04305 Mdot
.35153 .04306 Mdot
.35154 .04307 Mdot
.35155 .04308 Mdot
.35156 .04309 Mdot
.35157 .04309 Mdot
.35158 .0431 Mdot
.35159 .04311 Mdot
.3516 .04312 Mdot
.35161 .04313 Mdot
.35162 .04313 Mdot
.35163 .04314 Mdot
.35164 .04315 Mdot
.35165 .04316 Mdot
.35166 .04317 Mdot
.35167 .04317 Mdot
.35168 .04318 Mdot
.35169 .04319 Mdot
.3517 .0432 Mdot
.3517 .04321 Mdot
.35171 .04321 Mdot
.35172 .04322 Mdot
.35173 .04323 Mdot
.35174 .04324 Mdot
.35175 .04325 Mdot
.35176 .04326 Mdot
.35177 .04326 Mdot
.35178 .04327 Mdot
.35179 .04328 Mdot
.3518 .04329 Mdot
.35181 .0433 Mdot
.35182 .0433 Mdot
.35183 .04331 Mdot
.35184 .04332 Mdot
.35185 .04333 Mdot
.35186 .04334 Mdot
.35187 .04334 Mdot
.35188 .04335 Mdot
.35189 .04336 Mdot
.3519 .04337 Mdot
.3519 .04338 Mdot
.35191 .04339 Mdot
.35192 .04339 Mdot
.35193 .0434 Mdot
.35194 .04341 Mdot
.35195 .04342 Mdot
.35196 .04343 Mdot
.35197 .04343 Mdot
.35198 .04344 Mdot
.35199 .04345 Mdot
.352 .04346 Mdot
.35201 .04347 Mdot
.35202 .04347 Mdot
.35203 .04348 Mdot
.35204 .04349 Mdot
.35205 .0435 Mdot
.35206 .04351 Mdot
.35207 .04352 Mdot
.35208 .04352 Mdot
.35209 .04353 Mdot
.3521 .04354 Mdot
.3521 .04355 Mdot
.35211 .04356 Mdot
.35212 .04356 Mdot
.35213 .04357 Mdot
.35214 .04358 Mdot
.35215 .04359 Mdot
.35216 .0436 Mdot
.35217 .04361 Mdot
.35218 .04361 Mdot
.35219 .04362 Mdot
.3522 .04363 Mdot
.35221 .04364 Mdot
.35222 .04365 Mdot
.35223 .04365 Mdot
.35224 .04366 Mdot
.35225 .04367 Mdot
.35226 .04368 Mdot
.35227 .04369 Mdot
.35228 .04369 Mdot
.35229 .0437 Mdot
.3523 .04371 Mdot
.3523 .04372 Mdot
.35231 .04373 Mdot
.35232 .04374 Mdot
.35233 .04374 Mdot
.35234 .04375 Mdot
.35235 .04376 Mdot
.35236 .04377 Mdot
.35237 .04378 Mdot
.35238 .04378 Mdot
.35239 .04379 Mdot
.3524 .0438 Mdot
.35241 .04381 Mdot
.35242 .04382 Mdot
.35243 .04383 Mdot
.35244 .04383 Mdot
.35245 .04384 Mdot
.35246 .04385 Mdot
.35247 .04386 Mdot
.35248 .04387 Mdot
.35249 .04388 Mdot
.3525 .04388 Mdot
.3525 .04389 Mdot
.35251 .0439 Mdot
.35252 .04391 Mdot
.35253 .04392 Mdot
.35254 .04392 Mdot
.35255 .04393 Mdot
.35256 .04394 Mdot
.35257 .04395 Mdot
.35258 .04396 Mdot
.35259 .04397 Mdot
.3526 .04397 Mdot
.35261 .04398 Mdot
.35262 .04399 Mdot
.35263 .044 Mdot
.35264 .04401 Mdot
.35265 .04401 Mdot
.35266 .04402 Mdot
.35267 .04403 Mdot
.35268 .04404 Mdot
.35269 .04405 Mdot
.3527 .04406 Mdot
.3527 .04406 Mdot
.35271 .04407 Mdot
.35272 .04408 Mdot
.35273 .04409 Mdot
.35274 .0441 Mdot
.35275 .04411 Mdot
.35276 .04411 Mdot
.35277 .04412 Mdot
.35278 .04413 Mdot
.35279 .04414 Mdot
.3528 .04415 Mdot
.35281 .04415 Mdot
.35282 .04416 Mdot
.35283 .04417 Mdot
.35284 .04418 Mdot
.35285 .04419 Mdot
.35286 .0442 Mdot
.35287 .0442 Mdot
.35288 .04421 Mdot
.35289 .04422 Mdot
.3529 .04423 Mdot
.3529 .04424 Mdot
.35291 .04425 Mdot
.35292 .04425 Mdot
.35293 .04426 Mdot
.35294 .04427 Mdot
.35295 .04428 Mdot
.35296 .04429 Mdot
.35297 .04429 Mdot
.35298 .0443 Mdot
.35299 .04431 Mdot
.353 .04432 Mdot
.35301 .04433 Mdot
.35302 .04434 Mdot
.35303 .04434 Mdot
.35304 .04435 Mdot
.35305 .04436 Mdot
.35306 .04437 Mdot
.35307 .04438 Mdot
.35308 .04439 Mdot
.35309 .04439 Mdot
.3531 .0444 Mdot
.3531 .04441 Mdot
.35311 .04442 Mdot
.35312 .04443 Mdot
.35313 .04444 Mdot
.35314 .04444 Mdot
.35315 .04445 Mdot
.35316 .04446 Mdot
.35317 .04447 Mdot
.35318 .04448 Mdot
.35319 .04449 Mdot
.3532 .04449 Mdot
.35321 .0445 Mdot
.35322 .04451 Mdot
.35323 .04452 Mdot
.35324 .04453 Mdot
.35325 .04453 Mdot
.35326 .04454 Mdot
.35327 .04455 Mdot
.35328 .04456 Mdot
.35329 .04457 Mdot
.3533 .04458 Mdot
.3533 .04458 Mdot
.35331 .04459 Mdot
.35332 .0446 Mdot
.35333 .04461 Mdot
.35334 .04462 Mdot
.35335 .04463 Mdot
.35336 .04463 Mdot
.35337 .04464 Mdot
.35338 .04465 Mdot
.35339 .04466 Mdot
.3534 .04467 Mdot
.35341 .04468 Mdot
.35342 .04468 Mdot
.35343 .04469 Mdot
.35344 .0447 Mdot
.35345 .04471 Mdot
.35346 .04472 Mdot
.35347 .04473 Mdot
.35348 .04473 Mdot
.35349 .04474 Mdot
.3535 .04475 Mdot
.3535 .04476 Mdot
.35351 .04477 Mdot
.35352 .04478 Mdot
.35353 .04478 Mdot
.35354 .04479 Mdot
.35355 .0448 Mdot
.35356 .04481 Mdot
.35357 .04482 Mdot
.35358 .04483 Mdot
.35359 .04483 Mdot
.3536 .04484 Mdot
.35361 .04485 Mdot
.35362 .04486 Mdot
.35363 .04487 Mdot
.35364 .04488 Mdot
.35365 .04488 Mdot
.35366 .04489 Mdot
.35367 .0449 Mdot
.35368 .04491 Mdot
.35369 .04492 Mdot
.3537 .04493 Mdot
.3537 .04493 Mdot
.35371 .04494 Mdot
.35372 .04495 Mdot
.35373 .04496 Mdot
.35374 .04497 Mdot
.35375 .04498 Mdot
.35376 .04498 Mdot
.35377 .04499 Mdot
.35378 .045 Mdot
.35379 .04501 Mdot
.3538 .04502 Mdot
.35381 .04503 Mdot
.35382 .04503 Mdot
.35383 .04504 Mdot
.35384 .04505 Mdot
.35385 .04506 Mdot
.35386 .04507 Mdot
.35387 .04508 Mdot
.35388 .04508 Mdot
.35389 .04509 Mdot
.3539 .0451 Mdot
.3539 .04511 Mdot
.35391 .04512 Mdot
.35392 .04513 Mdot
.35393 .04514 Mdot
.35394 .04514 Mdot
.35395 .04515 Mdot
.35396 .04516 Mdot
.35397 .04517 Mdot
.35398 .04518 Mdot
.35399 .04519 Mdot
.354 .04519 Mdot
.35401 .0452 Mdot
.35402 .04521 Mdot
.35403 .04522 Mdot
.35404 .04523 Mdot
.35405 .04524 Mdot
.35406 .04524 Mdot
.35407 .04525 Mdot
.35408 .04526 Mdot
.35409 .04527 Mdot
.3541 .04528 Mdot
.3541 .04529 Mdot
.35411 .04529 Mdot
.35412 .0453 Mdot
.35413 .04531 Mdot
.35414 .04532 Mdot
.35415 .04533 Mdot
.35416 .04534 Mdot
.35417 .04534 Mdot
.35418 .04535 Mdot
.35419 .04536 Mdot
.3542 .04537 Mdot
.35421 .04538 Mdot
.35422 .04539 Mdot
.35423 .0454 Mdot
.35424 .0454 Mdot
.35425 .04541 Mdot
.35426 .04542 Mdot
.35427 .04543 Mdot
.35428 .04544 Mdot
.35429 .04545 Mdot
.3543 .04545 Mdot
.3543 .04546 Mdot
.35431 .04547 Mdot
.35432 .04548 Mdot
.35433 .04549 Mdot
.35434 .0455 Mdot
.35435 .0455 Mdot
.35436 .04551 Mdot
.35437 .04552 Mdot
.35438 .04553 Mdot
.35439 .04554 Mdot
.3544 .04555 Mdot
.35441 .04556 Mdot
.35442 .04556 Mdot
.35443 .04557 Mdot
.35444 .04558 Mdot
.35445 .04559 Mdot
.35446 .0456 Mdot
.35447 .04561 Mdot
.35448 .04561 Mdot
.35449 .04562 Mdot
.3545 .04563 Mdot
.3545 .04564 Mdot
.35451 .04565 Mdot
.35452 .04566 Mdot
.35453 .04567 Mdot
.35454 .04567 Mdot
.35455 .04568 Mdot
.35456 .04569 Mdot
.35457 .0457 Mdot
.35458 .04571 Mdot
.35459 .04572 Mdot
.3546 .04572 Mdot
.35461 .04573 Mdot
.35462 .04574 Mdot
.35463 .04575 Mdot
.35464 .04576 Mdot
.35465 .04577 Mdot
.35466 .04578 Mdot
.35467 .04578 Mdot
.35468 .04579 Mdot
.35469 .0458 Mdot
.3547 .04581 Mdot
.3547 .04582 Mdot
.35471 .04583 Mdot
.35472 .04583 Mdot
.35473 .04584 Mdot
.35474 .04585 Mdot
.35475 .04586 Mdot
.35476 .04587 Mdot
.35477 .04588 Mdot
.35478 .04589 Mdot
.35479 .04589 Mdot
.3548 .0459 Mdot
.35481 .04591 Mdot
.35482 .04592 Mdot
.35483 .04593 Mdot
.35484 .04594 Mdot
.35485 .04594 Mdot
.35486 .04595 Mdot
.35487 .04596 Mdot
.35488 .04597 Mdot
.35489 .04598 Mdot
.3549 .04599 Mdot
.3549 .046 Mdot
.35491 .046 Mdot
.35492 .04601 Mdot
.35493 .04602 Mdot
.35494 .04603 Mdot
.35495 .04604 Mdot
.35496 .04605 Mdot
.35497 .04606 Mdot
.35498 .04606 Mdot
.35499 .04607 Mdot
.355 .04608 Mdot
.35501 .04609 Mdot
.35502 .0461 Mdot
.35503 .04611 Mdot
.35504 .04612 Mdot
.35505 .04612 Mdot
.35506 .04613 Mdot
.35507 .04614 Mdot
.35508 .04615 Mdot
.35509 .04616 Mdot
.3551 .04617 Mdot
.3551 .04617 Mdot
.35511 .04618 Mdot
.35512 .04619 Mdot
.35513 .0462 Mdot
.35514 .04621 Mdot
.35515 .04622 Mdot
.35516 .04623 Mdot
.35517 .04623 Mdot
.35518 .04624 Mdot
.35519 .04625 Mdot
.3552 .04626 Mdot
.35521 .04627 Mdot
.35522 .04628 Mdot
.35523 .04629 Mdot
.35524 .04629 Mdot
.35525 .0463 Mdot
.35526 .04631 Mdot
.35527 .04632 Mdot
.35528 .04633 Mdot
.35529 .04634 Mdot
.3553 .04635 Mdot
.3553 .04635 Mdot
.35531 .04636 Mdot
.35532 .04637 Mdot
.35533 .04638 Mdot
.35534 .04639 Mdot
.35535 .0464 Mdot
.35536 .04641 Mdot
.35537 .04641 Mdot
.35538 .04642 Mdot
.35539 .04643 Mdot
.3554 .04644 Mdot
.35541 .04645 Mdot
.35542 .04646 Mdot
.35543 .04647 Mdot
.35544 .04647 Mdot
.35545 .04648 Mdot
.35546 .04649 Mdot
.35547 .0465 Mdot
.35548 .04651 Mdot
.35549 .04652 Mdot
.3555 .04653 Mdot
.3555 .04653 Mdot
.35551 .04654 Mdot
.35552 .04655 Mdot
.35553 .04656 Mdot
.35554 .04657 Mdot
.35555 .04658 Mdot
.35556 .04659 Mdot
.35557 .04659 Mdot
.35558 .0466 Mdot
.35559 .04661 Mdot
.3556 .04662 Mdot
.35561 .04663 Mdot
.35562 .04664 Mdot
.35563 .04665 Mdot
.35564 .04665 Mdot
.35565 .04666 Mdot
.35566 .04667 Mdot
.35567 .04668 Mdot
.35568 .04669 Mdot
.35569 .0467 Mdot
.3557 .04671 Mdot
.3557 .04671 Mdot
.35571 .04672 Mdot
.35572 .04673 Mdot
.35573 .04674 Mdot
.35574 .04675 Mdot
.35575 .04676 Mdot
.35576 .04677 Mdot
.35577 .04677 Mdot
.35578 .04678 Mdot
.35579 .04679 Mdot
.3558 .0468 Mdot
.35581 .04681 Mdot
.35582 .04682 Mdot
.35583 .04683 Mdot
.35584 .04683 Mdot
.35585 .04684 Mdot
.35586 .04685 Mdot
.35587 .04686 Mdot
.35588 .04687 Mdot
.35589 .04688 Mdot
.3559 .04689 Mdot
.3559 .04689 Mdot
.35591 .0469 Mdot
.35592 .04691 Mdot
.35593 .04692 Mdot
.35594 .04693 Mdot
.35595 .04694 Mdot
.35596 .04695 Mdot
.35597 .04696 Mdot
.35598 .04696 Mdot
.35599 .04697 Mdot
.356 .04698 Mdot
.35601 .04699 Mdot
.35602 .047 Mdot
.35603 .04701 Mdot
.35604 .04702 Mdot
.35605 .04702 Mdot
.35606 .04703 Mdot
.35607 .04704 Mdot
.35608 .04705 Mdot
.35609 .04706 Mdot
.3561 .04707 Mdot
.3561 .04708 Mdot
.35611 .04708 Mdot
.35612 .04709 Mdot
.35613 .0471 Mdot
.35614 .04711 Mdot
.35615 .04712 Mdot
.35616 .04713 Mdot
.35617 .04714 Mdot
.35618 .04715 Mdot
.35619 .04715 Mdot
.3562 .04716 Mdot
.35621 .04717 Mdot
.35622 .04718 Mdot
.35623 .04719 Mdot
.35624 .0472 Mdot
.35625 .04721 Mdot
.35626 .04721 Mdot
.35627 .04722 Mdot
.35628 .04723 Mdot
.35629 .04724 Mdot
.3563 .04725 Mdot
.3563 .04726 Mdot
.35631 .04727 Mdot
.35632 .04728 Mdot
.35633 .04728 Mdot
.35634 .04729 Mdot
.35635 .0473 Mdot
.35636 .04731 Mdot
.35637 .04732 Mdot
.35638 .04733 Mdot
.35639 .04734 Mdot
.3564 .04734 Mdot
.35641 .04735 Mdot
.35642 .04736 Mdot
.35643 .04737 Mdot
.35644 .04738 Mdot
.35645 .04739 Mdot
.35646 .0474 Mdot
.35647 .04741 Mdot
.35648 .04741 Mdot
.35649 .04742 Mdot
.3565 .04743 Mdot
.3565 .04744 Mdot
.35651 .04745 Mdot
.35652 .04746 Mdot
.35653 .04747 Mdot
.35654 .04748 Mdot
.35655 .04748 Mdot
.35656 .04749 Mdot
.35657 .0475 Mdot
.35658 .04751 Mdot
.35659 .04752 Mdot
.3566 .04753 Mdot
.35661 .04754 Mdot
.35662 .04754 Mdot
.35663 .04755 Mdot
.35664 .04756 Mdot
.35665 .04757 Mdot
.35666 .04758 Mdot
.35667 .04759 Mdot
.35668 .0476 Mdot
.35669 .04761 Mdot
.3567 .04761 Mdot
.3567 .04762 Mdot
.35671 .04763 Mdot
.35672 .04764 Mdot
.35673 .04765 Mdot
.35674 .04766 Mdot
.35675 .04767 Mdot
.35676 .04768 Mdot
.35677 .04768 Mdot
.35678 .04769 Mdot
.35679 .0477 Mdot
.3568 .04771 Mdot
.35681 .04772 Mdot
.35682 .04773 Mdot
.35683 .04774 Mdot
.35684 .04775 Mdot
.35685 .04775 Mdot
.35686 .04776 Mdot
.35687 .04777 Mdot
.35688 .04778 Mdot
.35689 .04779 Mdot
.3569 .0478 Mdot
.3569 .04781 Mdot
.35691 .04782 Mdot
.35692 .04782 Mdot
.35693 .04783 Mdot
.35694 .04784 Mdot
.35695 .04785 Mdot
.35696 .04786 Mdot
.35697 .04787 Mdot
.35698 .04788 Mdot
.35699 .04789 Mdot
.357 .04789 Mdot
.35701 .0479 Mdot
.35702 .04791 Mdot
.35703 .04792 Mdot
.35704 .04793 Mdot
.35705 .04794 Mdot
.35706 .04795 Mdot
.35707 .04796 Mdot
.35708 .04796 Mdot
.35709 .04797 Mdot
.3571 .04798 Mdot
.3571 .04799 Mdot
.35711 .048 Mdot
.35712 .04801 Mdot
.35713 .04802 Mdot
.35714 .04803 Mdot
.35715 .04803 Mdot
.35716 .04804 Mdot
.35717 .04805 Mdot
.35718 .04806 Mdot
.35719 .04807 Mdot
.3572 .04808 Mdot
.35721 .04809 Mdot
.35722 .0481 Mdot
.35723 .0481 Mdot
.35724 .04811 Mdot
.35725 .04812 Mdot
.35726 .04813 Mdot
.35727 .04814 Mdot
.35728 .04815 Mdot
.35729 .04816 Mdot
.3573 .04817 Mdot
.3573 .04818 Mdot
.35731 .04818 Mdot
.35732 .04819 Mdot
.35733 .0482 Mdot
.35734 .04821 Mdot
.35735 .04822 Mdot
.35736 .04823 Mdot
.35737 .04824 Mdot
.35738 .04825 Mdot
.35739 .04825 Mdot
.3574 .04826 Mdot
.35741 .04827 Mdot
.35742 .04828 Mdot
.35743 .04829 Mdot
.35744 .0483 Mdot
.35745 .04831 Mdot
.35746 .04832 Mdot
.35747 .04832 Mdot
.35748 .04833 Mdot
.35749 .04834 Mdot
.3575 .04835 Mdot
.3575 .04836 Mdot
.35751 .04837 Mdot
.35752 .04838 Mdot
.35753 .04839 Mdot
.35754 .0484 Mdot
.35755 .0484 Mdot
.35756 .04841 Mdot
.35757 .04842 Mdot
.35758 .04843 Mdot
.35759 .04844 Mdot
.3576 .04845 Mdot
.35761 .04846 Mdot
.35762 .04847 Mdot
.35763 .04847 Mdot
.35764 .04848 Mdot
.35765 .04849 Mdot
.35766 .0485 Mdot
.35767 .04851 Mdot
.35768 .04852 Mdot
.35769 .04853 Mdot
.3577 .04854 Mdot
.3577 .04855 Mdot
.35771 .04855 Mdot
.35772 .04856 Mdot
.35773 .04857 Mdot
.35774 .04858 Mdot
.35775 .04859 Mdot
.35776 .0486 Mdot
.35777 .04861 Mdot
.35778 .04862 Mdot
.35779 .04863 Mdot
.3578 .04863 Mdot
.35781 .04864 Mdot
.35782 .04865 Mdot
.35783 .04866 Mdot
.35784 .04867 Mdot
.35785 .04868 Mdot
.35786 .04869 Mdot
.35787 .0487 Mdot
.35788 .04871 Mdot
.35789 .04871 Mdot
.3579 .04872 Mdot
.3579 .04873 Mdot
.35791 .04874 Mdot
.35792 .04875 Mdot
.35793 .04876 Mdot
.35794 .04877 Mdot
.35795 .04878 Mdot
.35796 .04878 Mdot
.35797 .04879 Mdot
.35798 .0488 Mdot
.35799 .04881 Mdot
.358 .04882 Mdot
.35801 .04883 Mdot
.35802 .04884 Mdot
.35803 .04885 Mdot
.35804 .04886 Mdot
.35805 .04886 Mdot
.35806 .04887 Mdot
.35807 .04888 Mdot
.35808 .04889 Mdot
.35809 .0489 Mdot
.3581 .04891 Mdot
.3581 .04892 Mdot
.35811 .04893 Mdot
.35812 .04894 Mdot
.35813 .04894 Mdot
.35814 .04895 Mdot
.35815 .04896 Mdot
.35816 .04897 Mdot
.35817 .04898 Mdot
.35818 .04899 Mdot
.35819 .049 Mdot
.3582 .04901 Mdot
.35821 .04902 Mdot
.35822 .04903 Mdot
.35823 .04903 Mdot
.35824 .04904 Mdot
.35825 .04905 Mdot
.35826 .04906 Mdot
.35827 .04907 Mdot
.35828 .04908 Mdot
.35829 .04909 Mdot
.3583 .0491 Mdot
.3583 .04911 Mdot
.35831 .04911 Mdot
.35832 .04912 Mdot
.35833 .04913 Mdot
.35834 .04914 Mdot
.35835 .04915 Mdot
.35836 .04916 Mdot
.35837 .04917 Mdot
.35838 .04918 Mdot
.35839 .04919 Mdot
.3584 .04919 Mdot
.35841 .0492 Mdot
.35842 .04921 Mdot
.35843 .04922 Mdot
.35844 .04923 Mdot
.35845 .04924 Mdot
.35846 .04925 Mdot
.35847 .04926 Mdot
.35848 .04927 Mdot
.35849 .04928 Mdot
.3585 .04928 Mdot
.3585 .04929 Mdot
.35851 .0493 Mdot
.35852 .04931 Mdot
.35853 .04932 Mdot
.35854 .04933 Mdot
.35855 .04934 Mdot
.35856 .04935 Mdot
.35857 .04936 Mdot
.35858 .04936 Mdot
.35859 .04937 Mdot
.3586 .04938 Mdot
.35861 .04939 Mdot
.35862 .0494 Mdot
.35863 .04941 Mdot
.35864 .04942 Mdot
.35865 .04943 Mdot
.35866 .04944 Mdot
.35867 .04945 Mdot
.35868 .04945 Mdot
.35869 .04946 Mdot
.3587 .04947 Mdot
.3587 .04948 Mdot
.35871 .04949 Mdot
.35872 .0495 Mdot
.35873 .04951 Mdot
.35874 .04952 Mdot
.35875 .04953 Mdot
.35876 .04953 Mdot
.35877 .04954 Mdot
.35878 .04955 Mdot
.35879 .04956 Mdot
.3588 .04957 Mdot
.35881 .04958 Mdot
.35882 .04959 Mdot
.35883 .0496 Mdot
.35884 .04961 Mdot
.35885 .04962 Mdot
.35886 .04962 Mdot
.35887 .04963 Mdot
.35888 .04964 Mdot
.35889 .04965 Mdot
.3589 .04966 Mdot
.3589 .04967 Mdot
.35891 .04968 Mdot
.35892 .04969 Mdot
.35893 .0497 Mdot
.35894 .04971 Mdot
.35895 .04971 Mdot
.35896 .04972 Mdot
.35897 .04973 Mdot
.35898 .04974 Mdot
.35899 .04975 Mdot
.359 .04976 Mdot
.35901 .04977 Mdot
.35902 .04978 Mdot
.35903 .04979 Mdot
.35904 .0498 Mdot
.35905 .0498 Mdot
.35906 .04981 Mdot
.35907 .04982 Mdot
.35908 .04983 Mdot
.35909 .04984 Mdot
.3591 .04985 Mdot
.3591 .04986 Mdot
.35911 .04987 Mdot
.35912 .04988 Mdot
.35913 .04989 Mdot
.35914 .04989 Mdot
.35915 .0499 Mdot
.35916 .04991 Mdot
.35917 .04992 Mdot
.35918 .04993 Mdot
.35919 .04994 Mdot
.3592 .04995 Mdot
.35921 .04996 Mdot
.35922 .04997 Mdot
.35923 .04998 Mdot
.35924 .04999 Mdot
.35925 .04999 Mdot
.35926 .05 Mdot
.35927 .05001 Mdot
.35928 .05002 Mdot
.35929 .05003 Mdot
.3593 .05004 Mdot
.3593 .05005 Mdot
.35931 .05006 Mdot
.35932 .05007 Mdot
.35933 .05008 Mdot
.35934 .05008 Mdot
.35935 .05009 Mdot
.35936 .0501 Mdot
.35937 .05011 Mdot
.35938 .05012 Mdot
.35939 .05013 Mdot
.3594 .05014 Mdot
.35941 .05015 Mdot
.35942 .05016 Mdot
.35943 .05017 Mdot
.35944 .05018 Mdot
.35945 .05018 Mdot
.35946 .05019 Mdot
.35947 .0502 Mdot
.35948 .05021 Mdot
.35949 .05022 Mdot
.3595 .05023 Mdot
.3595 .05024 Mdot
.35951 .05025 Mdot
.35952 .05026 Mdot
.35953 .05027 Mdot
.35954 .05028 Mdot
.35955 .05028 Mdot
.35956 .05029 Mdot
.35957 .0503 Mdot
.35958 .05031 Mdot
.35959 .05032 Mdot
.3596 .05033 Mdot
.35961 .05034 Mdot
.35962 .05035 Mdot
.35963 .05036 Mdot
.35964 .05037 Mdot
.35965 .05037 Mdot
.35966 .05038 Mdot
.35967 .05039 Mdot
.35968 .0504 Mdot
.35969 .05041 Mdot
.3597 .05042 Mdot
.3597 .05043 Mdot
.35971 .05044 Mdot
.35972 .05045 Mdot
.35973 .05046 Mdot
.35974 .05047 Mdot
.35975 .05047 Mdot
.35976 .05048 Mdot
.35977 .05049 Mdot
.35978 .0505 Mdot
.35979 .05051 Mdot
.3598 .05052 Mdot
.35981 .05053 Mdot
.35982 .05054 Mdot
.35983 .05055 Mdot
.35984 .05056 Mdot
.35985 .05057 Mdot
.35986 .05058 Mdot
.35987 .05058 Mdot
.35988 .05059 Mdot
.35989 .0506 Mdot
.3599 .05061 Mdot
.3599 .05062 Mdot
.35991 .05063 Mdot
.35992 .05064 Mdot
.35993 .05065 Mdot
.35994 .05066 Mdot
.35995 .05067 Mdot
.35996 .05068 Mdot
.35997 .05068 Mdot
.35998 .05069 Mdot
.35999 .0507 Mdot
.36 .05071 Mdot
.36001 .05072 Mdot
.36002 .05073 Mdot
.36003 .05074 Mdot
.36004 .05075 Mdot
.36005 .05076 Mdot
.36006 .05077 Mdot
.36007 .05078 Mdot
.36008 .05079 Mdot
.36009 .05079 Mdot
.3601 .0508 Mdot
.3601 .05081 Mdot
.36011 .05082 Mdot
.36012 .05083 Mdot
.36013 .05084 Mdot
.36014 .05085 Mdot
.36015 .05086 Mdot
.36016 .05087 Mdot
.36017 .05088 Mdot
.36018 .05089 Mdot
.36019 .05089 Mdot
.3602 .0509 Mdot
.36021 .05091 Mdot
.36022 .05092 Mdot
.36023 .05093 Mdot
.36024 .05094 Mdot
.36025 .05095 Mdot
.36026 .05096 Mdot
.36027 .05097 Mdot
.36028 .05098 Mdot
.36029 .05099 Mdot
.3603 .051 Mdot
.3603 .051 Mdot
.36031 .05101 Mdot
.36032 .05102 Mdot
.36033 .05103 Mdot
.36034 .05104 Mdot
.36035 .05105 Mdot
.36036 .05106 Mdot
.36037 .05107 Mdot
.36038 .05108 Mdot
.36039 .05109 Mdot
.3604 .0511 Mdot
.36041 .05111 Mdot
.36042 .05111 Mdot
.36043 .05112 Mdot
.36044 .05113 Mdot
.36045 .05114 Mdot
.36046 .05115 Mdot
.36047 .05116 Mdot
.36048 .05117 Mdot
.36049 .05118 Mdot
.3605 .05119 Mdot
.3605 .0512 Mdot
.36051 .05121 Mdot
.36052 .05122 Mdot
.36053 .05123 Mdot
.36054 .05123 Mdot
.36055 .05124 Mdot
.36056 .05125 Mdot
.36057 .05126 Mdot
.36058 .05127 Mdot
.36059 .05128 Mdot
.3606 .05129 Mdot
.36061 .0513 Mdot
.36062 .05131 Mdot
.36063 .05132 Mdot
.36064 .05133 Mdot
.36065 .05134 Mdot
.36066 .05134 Mdot
.36067 .05135 Mdot
.36068 .05136 Mdot
.36069 .05137 Mdot
.3607 .05138 Mdot
.3607 .05139 Mdot
.36071 .0514 Mdot
.36072 .05141 Mdot
.36073 .05142 Mdot
.36074 .05143 Mdot
.36075 .05144 Mdot
.36076 .05145 Mdot
.36077 .05146 Mdot
.36078 .05146 Mdot
.36079 .05147 Mdot
.3608 .05148 Mdot
.36081 .05149 Mdot
.36082 .0515 Mdot
.36083 .05151 Mdot
.36084 .05152 Mdot
.36085 .05153 Mdot
.36086 .05154 Mdot
.36087 .05155 Mdot
.36088 .05156 Mdot
.36089 .05157 Mdot
.3609 .05158 Mdot
.3609 .05158 Mdot
.36091 .05159 Mdot
.36092 .0516 Mdot
.36093 .05161 Mdot
.36094 .05162 Mdot
.36095 .05163 Mdot
.36096 .05164 Mdot
.36097 .05165 Mdot
.36098 .05166 Mdot
.36099 .05167 Mdot
.361 .05168 Mdot
.36101 .05169 Mdot
.36102 .0517 Mdot
.36103 .0517 Mdot
.36104 .05171 Mdot
.36105 .05172 Mdot
.36106 .05173 Mdot
.36107 .05174 Mdot
.36108 .05175 Mdot
.36109 .05176 Mdot
.3611 .05177 Mdot
.3611 .05178 Mdot
.36111 .05179 Mdot
.36112 .0518 Mdot
.36113 .05181 Mdot
.36114 .05182 Mdot
.36115 .05183 Mdot
.36116 .05183 Mdot
.36117 .05184 Mdot
.36118 .05185 Mdot
.36119 .05186 Mdot
.3612 .05187 Mdot
.36121 .05188 Mdot
.36122 .05189 Mdot
.36123 .0519 Mdot
.36124 .05191 Mdot
.36125 .05192 Mdot
.36126 .05193 Mdot
.36127 .05194 Mdot
.36128 .05195 Mdot
.36129 .05196 Mdot
.3613 .05196 Mdot
.3613 .05197 Mdot
.36131 .05198 Mdot
.36132 .05199 Mdot
.36133 .052 Mdot
.36134 .05201 Mdot
.36135 .05202 Mdot
.36136 .05203 Mdot
.36137 .05204 Mdot
.36138 .05205 Mdot
.36139 .05206 Mdot
.3614 .05207 Mdot
.36141 .05208 Mdot
.36142 .05209 Mdot
.36143 .05209 Mdot
.36144 .0521 Mdot
.36145 .05211 Mdot
.36146 .05212 Mdot
.36147 .05213 Mdot
.36148 .05214 Mdot
.36149 .05215 Mdot
.3615 .05216 Mdot
.3615 .05217 Mdot
.36151 .05218 Mdot
.36152 .05219 Mdot
.36153 .0522 Mdot
.36154 .05221 Mdot
.36155 .05222 Mdot
.36156 .05223 Mdot
.36157 .05223 Mdot
.36158 .05224 Mdot
.36159 .05225 Mdot
.3616 .05226 Mdot
.36161 .05227 Mdot
.36162 .05228 Mdot
.36163 .05229 Mdot
.36164 .0523 Mdot
.36165 .05231 Mdot
.36166 .05232 Mdot
.36167 .05233 Mdot
.36168 .05234 Mdot
.36169 .05235 Mdot
.3617 .05236 Mdot
.3617 .05237 Mdot
.36171 .05237 Mdot
.36172 .05238 Mdot
.36173 .05239 Mdot
.36174 .0524 Mdot
.36175 .05241 Mdot
.36176 .05242 Mdot
.36177 .05243 Mdot
.36178 .05244 Mdot
.36179 .05245 Mdot
.3618 .05246 Mdot
.36181 .05247 Mdot
.36182 .05248 Mdot
.36183 .05249 Mdot
.36184 .0525 Mdot
.36185 .05251 Mdot
.36186 .05251 Mdot
.36187 .05252 Mdot
.36188 .05253 Mdot
.36189 .05254 Mdot
.3619 .05255 Mdot
.3619 .05256 Mdot
.36191 .05257 Mdot
.36192 .05258 Mdot
.36193 .05259 Mdot
.36194 .0526 Mdot
.36195 .05261 Mdot
.36196 .05262 Mdot
.36197 .05263 Mdot
.36198 .05264 Mdot
.36199 .05265 Mdot
.362 .05266 Mdot
.36201 .05266 Mdot
.36202 .05267 Mdot
.36203 .05268 Mdot
.36204 .05269 Mdot
.36205 .0527 Mdot
.36206 .05271 Mdot
.36207 .05272 Mdot
.36208 .05273 Mdot
.36209 .05274 Mdot
.3621 .05275 Mdot
.3621 .05276 Mdot
.36211 .05277 Mdot
.36212 .05278 Mdot
.36213 .05279 Mdot
.36214 .0528 Mdot
.36215 .05281 Mdot
.36216 .05282 Mdot
.36217 .05282 Mdot
.36218 .05283 Mdot
.36219 .05284 Mdot
.3622 .05285 Mdot
.36221 .05286 Mdot
.36222 .05287 Mdot
.36223 .05288 Mdot
.36224 .05289 Mdot
.36225 .0529 Mdot
.36226 .05291 Mdot
.36227 .05292 Mdot
.36228 .05293 Mdot
.36229 .05294 Mdot
.3623 .05295 Mdot
.3623 .05296 Mdot
.36231 .05297 Mdot
.36232 .05298 Mdot
.36233 .05298 Mdot
.36234 .05299 Mdot
.36235 .053 Mdot
.36236 .05301 Mdot
.36237 .05302 Mdot
.36238 .05303 Mdot
.36239 .05304 Mdot
.3624 .05305 Mdot
.36241 .05306 Mdot
.36242 .05307 Mdot
.36243 .05308 Mdot
.36244 .05309 Mdot
.36245 .0531 Mdot
.36246 .05311 Mdot
.36247 .05312 Mdot
.36248 .05313 Mdot
.36249 .05314 Mdot
.3625 .05314 Mdot
.3625 .05315 Mdot
.36251 .05316 Mdot
.36252 .05317 Mdot
.36253 .05318 Mdot
.36254 .05319 Mdot
.36255 .0532 Mdot
.36256 .05321 Mdot
.36257 .05322 Mdot
.36258 .05323 Mdot
.36259 .05324 Mdot
.3626 .05325 Mdot
.36261 .05326 Mdot
.36262 .05327 Mdot
.36263 .05328 Mdot
.36264 .05329 Mdot
.36265 .0533 Mdot
.36266 .05331 Mdot
.36267 .05331 Mdot
.36268 .05332 Mdot
.36269 .05333 Mdot
.3627 .05334 Mdot
.3627 .05335 Mdot
.36271 .05336 Mdot
.36272 .05337 Mdot
.36273 .05338 Mdot
.36274 .05339 Mdot
.36275 .0534 Mdot
.36276 .05341 Mdot
.36277 .05342 Mdot
.36278 .05343 Mdot
.36279 .05344 Mdot
.3628 .05345 Mdot
.36281 .05346 Mdot
.36282 .05347 Mdot
.36283 .05348 Mdot
.36284 .05349 Mdot
.36285 .05349 Mdot
.36286 .0535 Mdot
.36287 .05351 Mdot
.36288 .05352 Mdot
.36289 .05353 Mdot
.3629 .05354 Mdot
.3629 .05355 Mdot
.36291 .05356 Mdot
.36292 .05357 Mdot
.36293 .05358 Mdot
.36294 .05359 Mdot
.36295 .0536 Mdot
.36296 .05361 Mdot
.36297 .05362 Mdot
.36298 .05363 Mdot
.36299 .05364 Mdot
.363 .05365 Mdot
.36301 .05366 Mdot
.36302 .05367 Mdot
.36303 .05368 Mdot
.36304 .05368 Mdot
.36305 .05369 Mdot
.36306 .0537 Mdot
.36307 .05371 Mdot
.36308 .05372 Mdot
.36309 .05373 Mdot
.3631 .05374 Mdot
.3631 .05375 Mdot
.36311 .05376 Mdot
.36312 .05377 Mdot
.36313 .05378 Mdot
.36314 .05379 Mdot
.36315 .0538 Mdot
.36316 .05381 Mdot
.36317 .05382 Mdot
.36318 .05383 Mdot
.36319 .05384 Mdot
.3632 .05385 Mdot
.36321 .05386 Mdot
.36322 .05387 Mdot
.36323 .05388 Mdot
.36324 .05388 Mdot
.36325 .05389 Mdot
.36326 .0539 Mdot
.36327 .05391 Mdot
.36328 .05392 Mdot
.36329 .05393 Mdot
.3633 .05394 Mdot
.3633 .05395 Mdot
.36331 .05396 Mdot
.36332 .05397 Mdot
.36333 .05398 Mdot
.36334 .05399 Mdot
.36335 .054 Mdot
.36336 .05401 Mdot
.36337 .05402 Mdot
.36338 .05403 Mdot
.36339 .05404 Mdot
.3634 .05405 Mdot
.36341 .05406 Mdot
.36342 .05407 Mdot
.36343 .05408 Mdot
.36344 .05409 Mdot
.36345 .05409 Mdot
.36346 .0541 Mdot
.36347 .05411 Mdot
.36348 .05412 Mdot
.36349 .05413 Mdot
.3635 .05414 Mdot
.3635 .05415 Mdot
.36351 .05416 Mdot
.36352 .05417 Mdot
.36353 .05418 Mdot
.36354 .05419 Mdot
.36355 .0542 Mdot
.36356 .05421 Mdot
.36357 .05422 Mdot
.36358 .05423 Mdot
.36359 .05424 Mdot
.3636 .05425 Mdot
.36361 .05426 Mdot
.36362 .05427 Mdot
.36363 .05428 Mdot
.36364 .05429 Mdot
.36365 .0543 Mdot
.36366 .05431 Mdot
.36367 .05431 Mdot
.36368 .05432 Mdot
.36369 .05433 Mdot
.3637 .05434 Mdot
.3637 .05435 Mdot
.36371 .05436 Mdot
.36372 .05437 Mdot
.36373 .05438 Mdot
.36374 .05439 Mdot
.36375 .0544 Mdot
.36376 .05441 Mdot
.36377 .05442 Mdot
.36378 .05443 Mdot
.36379 .05444 Mdot
.3638 .05445 Mdot
.36381 .05446 Mdot
.36382 .05447 Mdot
.36383 .05448 Mdot
.36384 .05449 Mdot
.36385 .0545 Mdot
.36386 .05451 Mdot
.36387 .05452 Mdot
.36388 .05453 Mdot
.36389 .05454 Mdot
.3639 .05455 Mdot
.3639 .05456 Mdot
.36391 .05456 Mdot
.36392 .05457 Mdot
.36393 .05458 Mdot
.36394 .05459 Mdot
.36395 .0546 Mdot
.36396 .05461 Mdot
.36397 .05462 Mdot
.36398 .05463 Mdot
.36399 .05464 Mdot
.364 .05465 Mdot
.36401 .05466 Mdot
.36402 .05467 Mdot
.36403 .05468 Mdot
.36404 .05469 Mdot
.36405 .0547 Mdot
.36406 .05471 Mdot
.36407 .05472 Mdot
.36408 .05473 Mdot
.36409 .05474 Mdot
.3641 .05475 Mdot
.3641 .05476 Mdot
.36411 .05477 Mdot
.36412 .05478 Mdot
.36413 .05479 Mdot
.36414 .0548 Mdot
.36415 .05481 Mdot
.36416 .05482 Mdot
.36417 .05482 Mdot
.36418 .05483 Mdot
.36419 .05484 Mdot
.3642 .05485 Mdot
.36421 .05486 Mdot
.36422 .05487 Mdot
.36423 .05488 Mdot
.36424 .05489 Mdot
.36425 .0549 Mdot
.36426 .05491 Mdot
.36427 .05492 Mdot
.36428 .05493 Mdot
.36429 .05494 Mdot
.3643 .05495 Mdot
.3643 .05496 Mdot
.36431 .05497 Mdot
.36432 .05498 Mdot
.36433 .05499 Mdot
.36434 .055 Mdot
.36435 .05501 Mdot
.36436 .05502 Mdot
.36437 .05503 Mdot
.36438 .05504 Mdot
.36439 .05505 Mdot
.3644 .05506 Mdot
.36441 .05507 Mdot
.36442 .05508 Mdot
.36443 .05509 Mdot
.36444 .0551 Mdot
.36445 .05511 Mdot
.36446 .05511 Mdot
.36447 .05512 Mdot
.36448 .05513 Mdot
.36449 .05514 Mdot
.3645 .05515 Mdot
.3645 .05516 Mdot
.36451 .05517 Mdot
.36452 .05518 Mdot
.36453 .05519 Mdot
.36454 .0552 Mdot
.36455 .05521 Mdot
.36456 .05522 Mdot
.36457 .05523 Mdot
.36458 .05524 Mdot
.36459 .05525 Mdot
.3646 .05526 Mdot
.36461 .05527 Mdot
.36462 .05528 Mdot
.36463 .05529 Mdot
.36464 .0553 Mdot
.36465 .05531 Mdot
.36466 .05532 Mdot
.36467 .05533 Mdot
.36468 .05534 Mdot
.36469 .05535 Mdot
.3647 .05536 Mdot
.3647 .05537 Mdot
.36471 .05538 Mdot
.36472 .05539 Mdot
.36473 .0554 Mdot
.36474 .05541 Mdot
.36475 .05542 Mdot
.36476 .05543 Mdot
.36477 .05543 Mdot
.36478 .05544 Mdot
.36479 .05545 Mdot
.3648 .05546 Mdot
.36481 .05547 Mdot
.36482 .05548 Mdot
.36483 .05549 Mdot
.36484 .0555 Mdot
.36485 .05551 Mdot
.36486 .05552 Mdot
.36487 .05553 Mdot
.36488 .05554 Mdot
.36489 .05555 Mdot
.3649 .05556 Mdot
.3649 .05557 Mdot
.36491 .05558 Mdot
.36492 .05559 Mdot
.36493 .0556 Mdot
.36494 .05561 Mdot
.36495 .05562 Mdot
.36496 .05563 Mdot
.36497 .05564 Mdot
.36498 .05565 Mdot
.36499 .05566 Mdot
.365 .05567 Mdot
.36501 .05568 Mdot
.36502 .05569 Mdot
.36503 .0557 Mdot
.36504 .05571 Mdot
.36505 .05572 Mdot
.36506 .05573 Mdot
.36507 .05574 Mdot
.36508 .05575 Mdot
.36509 .05576 Mdot
.3651 .05577 Mdot
.3651 .05578 Mdot
.36511 .05579 Mdot
.36512 .0558 Mdot
.36513 .05581 Mdot
.36514 .05582 Mdot
.36515 .05582 Mdot
.36516 .05583 Mdot
.36517 .05584 Mdot
.36518 .05585 Mdot
.36519 .05586 Mdot
.3652 .05587 Mdot
.36521 .05588 Mdot
.36522 .05589 Mdot
.36523 .0559 Mdot
.36524 .05591 Mdot
.36525 .05592 Mdot
.36526 .05593 Mdot
.36527 .05594 Mdot
.36528 .05595 Mdot
.36529 .05596 Mdot
.3653 .05597 Mdot
.3653 .05598 Mdot
.36531 .05599 Mdot
.36532 .056 Mdot
.36533 .05601 Mdot
.36534 .05602 Mdot
.36535 .05603 Mdot
.36536 .05604 Mdot
.36537 .05605 Mdot
.36538 .05606 Mdot
.36539 .05607 Mdot
.3654 .05608 Mdot
.36541 .05609 Mdot
.36542 .0561 Mdot
.36543 .05611 Mdot
.36544 .05612 Mdot
.36545 .05613 Mdot
.36546 .05614 Mdot
.36547 .05615 Mdot
.36548 .05616 Mdot
.36549 .05617 Mdot
.3655 .05618 Mdot
.3655 .05619 Mdot
.36551 .0562 Mdot
.36552 .05621 Mdot
.36553 .05622 Mdot
.36554 .05623 Mdot
.36555 .05624 Mdot
.36556 .05625 Mdot
.36557 .05626 Mdot
.36558 .05627 Mdot
.36559 .05628 Mdot
.3656 .05629 Mdot
.36561 .0563 Mdot
.36562 .05631 Mdot
.36563 .05631 Mdot
.36564 .05632 Mdot
.36565 .05633 Mdot
.36566 .05634 Mdot
.36567 .05635 Mdot
.36568 .05636 Mdot
.36569 .05637 Mdot
.3657 .05638 Mdot
.3657 .05639 Mdot
.36571 .0564 Mdot
.36572 .05641 Mdot
.36573 .05642 Mdot
.36574 .05643 Mdot
.36575 .05644 Mdot
.36576 .05645 Mdot
.36577 .05646 Mdot
.36578 .05647 Mdot
.36579 .05648 Mdot
.3658 .05649 Mdot
.36581 .0565 Mdot
.36582 .05651 Mdot
.36583 .05652 Mdot
.36584 .05653 Mdot
.36585 .05654 Mdot
.36586 .05655 Mdot
.36587 .05656 Mdot
.36588 .05657 Mdot
.36589 .05658 Mdot
.3659 .05659 Mdot
.3659 .0566 Mdot
.36591 .05661 Mdot
.36592 .05662 Mdot
.36593 .05663 Mdot
.36594 .05664 Mdot
.36595 .05665 Mdot
.36596 .05666 Mdot
.36597 .05667 Mdot
.36598 .05668 Mdot
.36599 .05669 Mdot
.366 .0567 Mdot
.36601 .05671 Mdot
.36602 .05672 Mdot
.36603 .05673 Mdot
.36604 .05674 Mdot
.36605 .05675 Mdot
.36606 .05676 Mdot
.36607 .05677 Mdot
.36608 .05678 Mdot
.36609 .05679 Mdot
.3661 .0568 Mdot
.3661 .05681 Mdot
.36611 .05682 Mdot
.36612 .05683 Mdot
.36613 .05684 Mdot
.36614 .05685 Mdot
.36615 .05686 Mdot
.36616 .05687 Mdot
.36617 .05688 Mdot
.36618 .05689 Mdot
.36619 .0569 Mdot
.3662 .05691 Mdot
.36621 .05692 Mdot
.36622 .05693 Mdot
.36623 .05694 Mdot
.36624 .05695 Mdot
.36625 .05696 Mdot
.36626 .05697 Mdot
.36627 .05698 Mdot
.36628 .05699 Mdot
.36629 .057 Mdot
.3663 .05701 Mdot
.3663 .05702 Mdot
.36631 .05703 Mdot
.36632 .05704 Mdot
.36633 .05705 Mdot
.36634 .05706 Mdot
.36635 .05707 Mdot
.36636 .05708 Mdot
.36637 .05709 Mdot
.36638 .0571 Mdot
.36639 .05711 Mdot
.3664 .05712 Mdot
.36641 .05712 Mdot
.36642 .05713 Mdot
.36643 .05714 Mdot
.36644 .05715 Mdot
.36645 .05716 Mdot
.36646 .05717 Mdot
.36647 .05718 Mdot
.36648 .05719 Mdot
.36649 .0572 Mdot
.3665 .05721 Mdot
.3665 .05722 Mdot
.36651 .05723 Mdot
.36652 .05724 Mdot
.36653 .05725 Mdot
.36654 .05726 Mdot
.36655 .05727 Mdot
.36656 .05728 Mdot
.36657 .05729 Mdot
.36658 .0573 Mdot
.36659 .05731 Mdot
.3666 .05732 Mdot
.36661 .05733 Mdot
.36662 .05734 Mdot
.36663 .05735 Mdot
.36664 .05736 Mdot
.36665 .05737 Mdot
.36666 .05738 Mdot
.36667 .05739 Mdot
.36668 .0574 Mdot
.36669 .05741 Mdot
.3667 .05742 Mdot
.3667 .05743 Mdot
.36671 .05744 Mdot
.36672 .05745 Mdot
.36673 .05746 Mdot
.36674 .05747 Mdot
.36675 .05748 Mdot
.36676 .05749 Mdot
.36677 .0575 Mdot
.36678 .05751 Mdot
.36679 .05752 Mdot
.3668 .05753 Mdot
.36681 .05754 Mdot
.36682 .05755 Mdot
.36683 .05756 Mdot
.36684 .05757 Mdot
.36685 .05758 Mdot
.36686 .05759 Mdot
.36687 .0576 Mdot
.36688 .05761 Mdot
.36689 .05762 Mdot
.3669 .05763 Mdot
.3669 .05764 Mdot
.36691 .05765 Mdot
.36692 .05766 Mdot
.36693 .05767 Mdot
.36694 .05768 Mdot
.36695 .05769 Mdot
.36696 .0577 Mdot
.36697 .05771 Mdot
.36698 .05772 Mdot
.36699 .05773 Mdot
.367 .05774 Mdot
.36701 .05775 Mdot
.36702 .05776 Mdot
.36703 .05777 Mdot
.36704 .05778 Mdot
.36705 .05779 Mdot
.36706 .0578 Mdot
.36707 .05781 Mdot
.36708 .05782 Mdot
.36709 .05783 Mdot
.3671 .05784 Mdot
.3671 .05785 Mdot
.36711 .05786 Mdot
.36712 .05787 Mdot
.36713 .05788 Mdot
.36714 .05789 Mdot
.36715 .0579 Mdot
.36716 .05791 Mdot
.36717 .05792 Mdot
.36718 .05793 Mdot
.36719 .05794 Mdot
.3672 .05795 Mdot
.36721 .05796 Mdot
.36722 .05797 Mdot
.36723 .05798 Mdot
.36724 .05799 Mdot
.36725 .058 Mdot
.36726 .05801 Mdot
.36727 .05802 Mdot
.36728 .05803 Mdot
.36729 .05804 Mdot
.3673 .05805 Mdot
.3673 .05806 Mdot
.36731 .05807 Mdot
.36732 .05808 Mdot
.36733 .05809 Mdot
.36734 .0581 Mdot
.36735 .05811 Mdot
.36736 .05812 Mdot
.36737 .05813 Mdot
.36738 .05814 Mdot
.36739 .05815 Mdot
.3674 .05816 Mdot
.36741 .05817 Mdot
.36742 .05818 Mdot
.36743 .05819 Mdot
.36744 .0582 Mdot
.36745 .05821 Mdot
.36746 .05822 Mdot
.36747 .05823 Mdot
.36748 .05824 Mdot
.36749 .05825 Mdot
.3675 .05826 Mdot
.3675 .05827 Mdot
.36751 .05828 Mdot
.36752 .05829 Mdot
.36753 .0583 Mdot
.36754 .05831 Mdot
.36755 .05832 Mdot
.36756 .05833 Mdot
.36757 .05834 Mdot
.36758 .05835 Mdot
.36759 .05837 Mdot
.3676 .05838 Mdot
.36761 .05839 Mdot
.36762 .0584 Mdot
.36763 .05841 Mdot
.36764 .05842 Mdot
.36765 .05843 Mdot
.36766 .05844 Mdot
.36767 .05845 Mdot
.36768 .05846 Mdot
.36769 .05847 Mdot
.3677 .05848 Mdot
.3677 .05849 Mdot
.36771 .0585 Mdot
.36772 .05851 Mdot
.36773 .05852 Mdot
.36774 .05853 Mdot
.36775 .05854 Mdot
.36776 .05855 Mdot
.36777 .05856 Mdot
.36778 .05857 Mdot
.36779 .05858 Mdot
.3678 .05859 Mdot
.36781 .0586 Mdot
.36782 .05861 Mdot
.36783 .05862 Mdot
.36784 .05863 Mdot
.36785 .05864 Mdot
.36786 .05865 Mdot
.36787 .05866 Mdot
.36788 .05867 Mdot
.36789 .05868 Mdot
.3679 .05869 Mdot
.3679 .0587 Mdot
.36791 .05871 Mdot
.36792 .05872 Mdot
.36793 .05873 Mdot
.36794 .05874 Mdot
.36795 .05875 Mdot
.36796 .05876 Mdot
.36797 .05877 Mdot
.36798 .05878 Mdot
.36799 .05879 Mdot
.368 .0588 Mdot
.36801 .05881 Mdot
.36802 .05882 Mdot
.36803 .05883 Mdot
.36804 .05884 Mdot
.36805 .05885 Mdot
.36806 .05886 Mdot
.36807 .05887 Mdot
.36808 .05888 Mdot
.36809 .05889 Mdot
.3681 .0589 Mdot
.3681 .05891 Mdot
.36811 .05892 Mdot
.36812 .05893 Mdot
.36813 .05894 Mdot
.36814 .05895 Mdot
.36815 .05896 Mdot
.36816 .05897 Mdot
.36817 .05898 Mdot
.36818 .05899 Mdot
.36819 .059 Mdot
.3682 .05901 Mdot
.36821 .05902 Mdot
.36822 .05903 Mdot
.36823 .05904 Mdot
.36824 .05905 Mdot
.36825 .05906 Mdot
.36826 .05907 Mdot
.36827 .05908 Mdot
.36828 .05909 Mdot
.36829 .0591 Mdot
.3683 .05911 Mdot
.3683 .05912 Mdot
.36831 .05913 Mdot
.36832 .05914 Mdot
.36833 .05915 Mdot
.36834 .05916 Mdot
.36835 .05917 Mdot
.36836 .05918 Mdot
.36837 .0592 Mdot
.36838 .05921 Mdot
.36839 .05922 Mdot
.3684 .05923 Mdot
.36841 .05924 Mdot
.36842 .05925 Mdot
.36843 .05926 Mdot
.36844 .05927 Mdot
.36845 .05928 Mdot
.36846 .05929 Mdot
.36847 .0593 Mdot
.36848 .05931 Mdot
.36849 .05932 Mdot
.3685 .05933 Mdot
.3685 .05934 Mdot
.36851 .05935 Mdot
.36852 .05936 Mdot
.36853 .05937 Mdot
.36854 .05938 Mdot
.36855 .05939 Mdot
.36856 .0594 Mdot
.36857 .05941 Mdot
.36858 .05942 Mdot
.36859 .05943 Mdot
.3686 .05944 Mdot
.36861 .05945 Mdot
.36862 .05946 Mdot
.36863 .05947 Mdot
.36864 .05948 Mdot
.36865 .05949 Mdot
.36866 .0595 Mdot
.36867 .05951 Mdot
.36868 .05952 Mdot
.36869 .05953 Mdot
.3687 .05954 Mdot
.3687 .05955 Mdot
.36871 .05956 Mdot
.36872 .05957 Mdot
.36873 .05958 Mdot
.36874 .05959 Mdot
.36875 .0596 Mdot
.36876 .05961 Mdot
.36877 .05962 Mdot
.36878 .05963 Mdot
.36879 .05964 Mdot
.3688 .05965 Mdot
.36881 .05966 Mdot
.36882 .05967 Mdot
.36883 .05968 Mdot
.36884 .05969 Mdot
.36885 .05971 Mdot
.36886 .05972 Mdot
.36887 .05973 Mdot
.36888 .05974 Mdot
.36889 .05975 Mdot
.3689 .05976 Mdot
.3689 .05977 Mdot
.36891 .05978 Mdot
.36892 .05979 Mdot
.36893 .0598 Mdot
.36894 .05981 Mdot
.36895 .05982 Mdot
.36896 .05983 Mdot
.36897 .05984 Mdot
.36898 .05985 Mdot
.36899 .05986 Mdot
.369 .05987 Mdot
.36901 .05988 Mdot
.36902 .05989 Mdot
.36903 .0599 Mdot
.36904 .05991 Mdot
.36905 .05992 Mdot
.36906 .05993 Mdot
.36907 .05994 Mdot
.36908 .05995 Mdot
.36909 .05996 Mdot
.3691 .05997 Mdot
.3691 .05998 Mdot
.36911 .05999 Mdot
.36912 .06 Mdot
.36913 .06001 Mdot
.36914 .06002 Mdot
.36915 .06003 Mdot
.36916 .06004 Mdot
.36917 .06005 Mdot
.36918 .06006 Mdot
.36919 .06007 Mdot
.3692 .06008 Mdot
.36921 .06009 Mdot
.36922 .06011 Mdot
.36923 .06012 Mdot
.36924 .06013 Mdot
.36925 .06014 Mdot
.36926 .06015 Mdot
.36927 .06016 Mdot
.36928 .06017 Mdot
.36929 .06018 Mdot
.3693 .06019 Mdot
.3693 .0602 Mdot
.36931 .06021 Mdot
.36932 .06022 Mdot
.36933 .06023 Mdot
.36934 .06024 Mdot
.36935 .06025 Mdot
.36936 .06026 Mdot
.36937 .06027 Mdot
.36938 .06028 Mdot
.36939 .06029 Mdot
.3694 .0603 Mdot
.36941 .06031 Mdot
.36942 .06032 Mdot
.36943 .06033 Mdot
.36944 .06034 Mdot
.36945 .06035 Mdot
.36946 .06036 Mdot
.36947 .06037 Mdot
.36948 .06038 Mdot
.36949 .06039 Mdot
.3695 .0604 Mdot
.3695 .06041 Mdot
.36951 .06042 Mdot
.36952 .06043 Mdot
.36953 .06044 Mdot
.36954 .06046 Mdot
.36955 .06047 Mdot
.36956 .06048 Mdot
.36957 .06049 Mdot
.36958 .0605 Mdot
.36959 .06051 Mdot
.3696 .06052 Mdot
.36961 .06053 Mdot
.36962 .06054 Mdot
.36963 .06055 Mdot
.36964 .06056 Mdot
.36965 .06057 Mdot
.36966 .06058 Mdot
.36967 .06059 Mdot
.36968 .0606 Mdot
.36969 .06061 Mdot
.3697 .06062 Mdot
.3697 .06063 Mdot
.36971 .06064 Mdot
.36972 .06065 Mdot
.36973 .06066 Mdot
.36974 .06067 Mdot
.36975 .06068 Mdot
.36976 .06069 Mdot
.36977 .0607 Mdot
.36978 .06071 Mdot
.36979 .06072 Mdot
.3698 .06073 Mdot
.36981 .06074 Mdot
.36982 .06075 Mdot
.36983 .06077 Mdot
.36984 .06078 Mdot
.36985 .06079 Mdot
.36986 .0608 Mdot
.36987 .06081 Mdot
.36988 .06082 Mdot
.36989 .06083 Mdot
.3699 .06084 Mdot
.3699 .06085 Mdot
.36991 .06086 Mdot
.36992 .06087 Mdot
.36993 .06088 Mdot
.36994 .06089 Mdot
.36995 .0609 Mdot
.36996 .06091 Mdot
.36997 .06092 Mdot
.36998 .06093 Mdot
.36999 .06094 Mdot
.37 .06095 Mdot
.37001 .06096 Mdot
.37002 .06097 Mdot
.37003 .06098 Mdot
.37004 .06099 Mdot
.37005 .061 Mdot
.37006 .06101 Mdot
.37007 .06102 Mdot
.37008 .06103 Mdot
.37009 .06105 Mdot
.3701 .06106 Mdot
.3701 .06107 Mdot
.37011 .06108 Mdot
.37012 .06109 Mdot
.37013 .0611 Mdot
.37014 .06111 Mdot
.37015 .06112 Mdot
.37016 .06113 Mdot
.37017 .06114 Mdot
.37018 .06115 Mdot
.37019 .06116 Mdot
.3702 .06117 Mdot
.37021 .06118 Mdot
.37022 .06119 Mdot
.37023 .0612 Mdot
.37024 .06121 Mdot
.37025 .06122 Mdot
.37026 .06123 Mdot
.37027 .06124 Mdot
.37028 .06125 Mdot
.37029 .06126 Mdot
.3703 .06127 Mdot
.3703 .06128 Mdot
.37031 .06129 Mdot
.37032 .06131 Mdot
.37033 .06132 Mdot
.37034 .06133 Mdot
.37035 .06134 Mdot
.37036 .06135 Mdot
.37037 .06136 Mdot
.37038 .06137 Mdot
.37039 .06138 Mdot
.3704 .06139 Mdot
.37041 .0614 Mdot
.37042 .06141 Mdot
.37043 .06142 Mdot
.37044 .06143 Mdot
.37045 .06144 Mdot
.37046 .06145 Mdot
.37047 .06146 Mdot
.37048 .06147 Mdot
.37049 .06148 Mdot
.3705 .06149 Mdot
.3705 .0615 Mdot
.37051 .06151 Mdot
.37052 .06152 Mdot
.37053 .06153 Mdot
.37054 .06155 Mdot
.37055 .06156 Mdot
.37056 .06157 Mdot
.37057 .06158 Mdot
.37058 .06159 Mdot
.37059 .0616 Mdot
.3706 .06161 Mdot
.37061 .06162 Mdot
.37062 .06163 Mdot
.37063 .06164 Mdot
.37064 .06165 Mdot
.37065 .06166 Mdot
.37066 .06167 Mdot
.37067 .06168 Mdot
.37068 .06169 Mdot
.37069 .0617 Mdot
.3707 .06171 Mdot
.3707 .06172 Mdot
.37071 .06173 Mdot
.37072 .06174 Mdot
.37073 .06175 Mdot
.37074 .06176 Mdot
.37075 .06178 Mdot
.37076 .06179 Mdot
.37077 .0618 Mdot
.37078 .06181 Mdot
.37079 .06182 Mdot
.3708 .06183 Mdot
.37081 .06184 Mdot
.37082 .06185 Mdot
.37083 .06186 Mdot
.37084 .06187 Mdot
.37085 .06188 Mdot
.37086 .06189 Mdot
.37087 .0619 Mdot
.37088 .06191 Mdot
.37089 .06192 Mdot
.3709 .06193 Mdot
.3709 .06194 Mdot
.37091 .06195 Mdot
.37092 .06196 Mdot
.37093 .06197 Mdot
.37094 .06198 Mdot
.37095 .062 Mdot
.37096 .06201 Mdot
.37097 .06202 Mdot
.37098 .06203 Mdot
.37099 .06204 Mdot
.371 .06205 Mdot
.37101 .06206 Mdot
.37102 .06207 Mdot
.37103 .06208 Mdot
.37104 .06209 Mdot
.37105 .0621 Mdot
.37106 .06211 Mdot
.37107 .06212 Mdot
.37108 .06213 Mdot
.37109 .06214 Mdot
.3711 .06215 Mdot
.3711 .06216 Mdot
.37111 .06217 Mdot
.37112 .06218 Mdot
.37113 .06219 Mdot
.37114 .06221 Mdot
.37115 .06222 Mdot
.37116 .06223 Mdot
.37117 .06224 Mdot
.37118 .06225 Mdot
.37119 .06226 Mdot
.3712 .06227 Mdot
.37121 .06228 Mdot
.37122 .06229 Mdot
.37123 .0623 Mdot
.37124 .06231 Mdot
.37125 .06232 Mdot
.37126 .06233 Mdot
.37127 .06234 Mdot
.37128 .06235 Mdot
.37129 .06236 Mdot
.3713 .06237 Mdot
.3713 .06238 Mdot
.37131 .06239 Mdot
.37132 .06241 Mdot
.37133 .06242 Mdot
.37134 .06243 Mdot
.37135 .06244 Mdot
.37136 .06245 Mdot
.37137 .06246 Mdot
.37138 .06247 Mdot
.37139 .06248 Mdot
.3714 .06249 Mdot
.37141 .0625 Mdot
.37142 .06251 Mdot
.37143 .06252 Mdot
.37144 .06253 Mdot
.37145 .06254 Mdot
.37146 .06255 Mdot
.37147 .06256 Mdot
.37148 .06257 Mdot
.37149 .06258 Mdot
.3715 .0626 Mdot
.3715 .06261 Mdot
.37151 .06262 Mdot
.37152 .06263 Mdot
.37153 .06264 Mdot
.37154 .06265 Mdot
.37155 .06266 Mdot
.37156 .06267 Mdot
.37157 .06268 Mdot
.37158 .06269 Mdot
.37159 .0627 Mdot
.3716 .06271 Mdot
.37161 .06272 Mdot
.37162 .06273 Mdot
.37163 .06274 Mdot
.37164 .06275 Mdot
.37165 .06276 Mdot
.37166 .06277 Mdot
.37167 .06279 Mdot
.37168 .0628 Mdot
.37169 .06281 Mdot
.3717 .06282 Mdot
.3717 .06283 Mdot
.37171 .06284 Mdot
.37172 .06285 Mdot
.37173 .06286 Mdot
.37174 .06287 Mdot
.37175 .06288 Mdot
.37176 .06289 Mdot
.37177 .0629 Mdot
.37178 .06291 Mdot
.37179 .06292 Mdot
.3718 .06293 Mdot
.37181 .06294 Mdot
.37182 .06295 Mdot
.37183 .06297 Mdot
.37184 .06298 Mdot
.37185 .06299 Mdot
.37186 .063 Mdot
.37187 .06301 Mdot
.37188 .06302 Mdot
.37189 .06303 Mdot
.3719 .06304 Mdot
.3719 .06305 Mdot
.37191 .06306 Mdot
.37192 .06307 Mdot
.37193 .06308 Mdot
.37194 .06309 Mdot
.37195 .0631 Mdot
.37196 .06311 Mdot
.37197 .06312 Mdot
.37198 .06314 Mdot
.37199 .06315 Mdot
.372 .06316 Mdot
.37201 .06317 Mdot
.37202 .06318 Mdot
.37203 .06319 Mdot
.37204 .0632 Mdot
.37205 .06321 Mdot
.37206 .06322 Mdot
.37207 .06323 Mdot
.37208 .06324 Mdot
.37209 .06325 Mdot
.3721 .06326 Mdot
.3721 .06327 Mdot
.37211 .06328 Mdot
.37212 .06329 Mdot
.37213 .06331 Mdot
.37214 .06332 Mdot
.37215 .06333 Mdot
.37216 .06334 Mdot
.37217 .06335 Mdot
.37218 .06336 Mdot
.37219 .06337 Mdot
.3722 .06338 Mdot
.37221 .06339 Mdot
.37222 .0634 Mdot
.37223 .06341 Mdot
.37224 .06342 Mdot
.37225 .06343 Mdot
.37226 .06344 Mdot
.37227 .06345 Mdot
.37228 .06347 Mdot
.37229 .06348 Mdot
.3723 .06349 Mdot
.3723 .0635 Mdot
.37231 .06351 Mdot
.37232 .06352 Mdot
.37233 .06353 Mdot
.37234 .06354 Mdot
.37235 .06355 Mdot
.37236 .06356 Mdot
.37237 .06357 Mdot
.37238 .06358 Mdot
.37239 .06359 Mdot
.3724 .0636 Mdot
.37241 .06361 Mdot
.37242 .06363 Mdot
.37243 .06364 Mdot
.37244 .06365 Mdot
.37245 .06366 Mdot
.37246 .06367 Mdot
.37247 .06368 Mdot
.37248 .06369 Mdot
.37249 .0637 Mdot
.3725 .06371 Mdot
.3725 .06372 Mdot
.37251 .06373 Mdot
.37252 .06374 Mdot
.37253 .06375 Mdot
.37254 .06376 Mdot
.37255 .06377 Mdot
.37256 .06379 Mdot
.37257 .0638 Mdot
.37258 .06381 Mdot
.37259 .06382 Mdot
.3726 .06383 Mdot
.37261 .06384 Mdot
.37262 .06385 Mdot
.37263 .06386 Mdot
.37264 .06387 Mdot
.37265 .06388 Mdot
.37266 .06389 Mdot
.37267 .0639 Mdot
.37268 .06391 Mdot
.37269 .06392 Mdot
.3727 .06394 Mdot
.3727 .06395 Mdot
.37271 .06396 Mdot
.37272 .06397 Mdot
.37273 .06398 Mdot
.37274 .06399 Mdot
.37275 .064 Mdot
.37276 .06401 Mdot
.37277 .06402 Mdot
.37278 .06403 Mdot
.37279 .06404 Mdot
.3728 .06405 Mdot
.37281 .06406 Mdot
.37282 .06407 Mdot
.37283 .06409 Mdot
.37284 .0641 Mdot
.37285 .06411 Mdot
.37286 .06412 Mdot
.37287 .06413 Mdot
.37288 .06414 Mdot
.37289 .06415 Mdot
.3729 .06416 Mdot
.3729 .06417 Mdot
.37291 .06418 Mdot
.37292 .06419 Mdot
.37293 .0642 Mdot
.37294 .06421 Mdot
.37295 .06422 Mdot
.37296 .06424 Mdot
.37297 .06425 Mdot
.37298 .06426 Mdot
.37299 .06427 Mdot
.373 .06428 Mdot
.37301 .06429 Mdot
.37302 .0643 Mdot
.37303 .06431 Mdot
.37304 .06432 Mdot
.37305 .06433 Mdot
.37306 .06434 Mdot
.37307 .06435 Mdot
.37308 .06436 Mdot
.37309 .06438 Mdot
.3731 .06439 Mdot
.3731 .0644 Mdot
.37311 .06441 Mdot
.37312 .06442 Mdot
.37313 .06443 Mdot
.37314 .06444 Mdot
.37315 .06445 Mdot
.37316 .06446 Mdot
.37317 .06447 Mdot
.37318 .06448 Mdot
.37319 .06449 Mdot
.3732 .0645 Mdot
.37321 .06452 Mdot
.37322 .06453 Mdot
.37323 .06454 Mdot
.37324 .06455 Mdot
.37325 .06456 Mdot
.37326 .06457 Mdot
.37327 .06458 Mdot
.37328 .06459 Mdot
.37329 .0646 Mdot
.3733 .06461 Mdot
.3733 .06462 Mdot
.37331 .06463 Mdot
.37332 .06464 Mdot
.37333 .06466 Mdot
.37334 .06467 Mdot
.37335 .06468 Mdot
.37336 .06469 Mdot
.37337 .0647 Mdot
.37338 .06471 Mdot
.37339 .06472 Mdot
.3734 .06473 Mdot
.37341 .06474 Mdot
.37342 .06475 Mdot
.37343 .06476 Mdot
.37344 .06477 Mdot
.37345 .06478 Mdot
.37346 .0648 Mdot
.37347 .06481 Mdot
.37348 .06482 Mdot
.37349 .06483 Mdot
.3735 .06484 Mdot
.3735 .06485 Mdot
.37351 .06486 Mdot
.37352 .06487 Mdot
.37353 .06488 Mdot
.37354 .06489 Mdot
.37355 .0649 Mdot
.37356 .06491 Mdot
.37357 .06493 Mdot
.37358 .06494 Mdot
.37359 .06495 Mdot
.3736 .06496 Mdot
.37361 .06497 Mdot
.37362 .06498 Mdot
.37363 .06499 Mdot
.37364 .065 Mdot
.37365 .06501 Mdot
.37366 .06502 Mdot
.37367 .06503 Mdot
.37368 .06504 Mdot
.37369 .06506 Mdot
.3737 .06507 Mdot
.3737 .06508 Mdot
.37371 .06509 Mdot
.37372 .0651 Mdot
.37373 .06511 Mdot
.37374 .06512 Mdot
.37375 .06513 Mdot
.37376 .06514 Mdot
.37377 .06515 Mdot
.37378 .06516 Mdot
.37379 .06517 Mdot
.3738 .06519 Mdot
.37381 .0652 Mdot
.37382 .06521 Mdot
.37383 .06522 Mdot
.37384 .06523 Mdot
.37385 .06524 Mdot
.37386 .06525 Mdot
.37387 .06526 Mdot
.37388 .06527 Mdot
.37389 .06528 Mdot
.3739 .06529 Mdot
.3739 .0653 Mdot
.37391 .06532 Mdot
.37392 .06533 Mdot
.37393 .06534 Mdot
.37394 .06535 Mdot
.37395 .06536 Mdot
.37396 .06537 Mdot
.37397 .06538 Mdot
.37398 .06539 Mdot
.37399 .0654 Mdot
.374 .06541 Mdot
.37401 .06542 Mdot
.37402 .06544 Mdot
.37403 .06545 Mdot
.37404 .06546 Mdot
.37405 .06547 Mdot
.37406 .06548 Mdot
.37407 .06549 Mdot
.37408 .0655 Mdot
.37409 .06551 Mdot
.3741 .06552 Mdot
.3741 .06553 Mdot
.37411 .06554 Mdot
.37412 .06555 Mdot
.37413 .06557 Mdot
.37414 .06558 Mdot
.37415 .06559 Mdot
.37416 .0656 Mdot
.37417 .06561 Mdot
.37418 .06562 Mdot
.37419 .06563 Mdot
.3742 .06564 Mdot
.37421 .06565 Mdot
.37422 .06566 Mdot
.37423 .06567 Mdot
.37424 .06569 Mdot
.37425 .0657 Mdot
.37426 .06571 Mdot
.37427 .06572 Mdot
.37428 .06573 Mdot
.37429 .06574 Mdot
.3743 .06575 Mdot
.3743 .06576 Mdot
.37431 .06577 Mdot
.37432 .06578 Mdot
.37433 .06579 Mdot
.37434 .06581 Mdot
.37435 .06582 Mdot
.37436 .06583 Mdot
.37437 .06584 Mdot
.37438 .06585 Mdot
.37439 .06586 Mdot
.3744 .06587 Mdot
.37441 .06588 Mdot
.37442 .06589 Mdot
.37443 .0659 Mdot
.37444 .06591 Mdot
.37445 .06593 Mdot
.37446 .06594 Mdot
.37447 .06595 Mdot
.37448 .06596 Mdot
.37449 .06597 Mdot
.3745 .06598 Mdot
.3745 .06599 Mdot
.37451 .066 Mdot
.37452 .06601 Mdot
.37453 .06602 Mdot
.37454 .06604 Mdot
.37455 .06605 Mdot
.37456 .06606 Mdot
.37457 .06607 Mdot
.37458 .06608 Mdot
.37459 .06609 Mdot
.3746 .0661 Mdot
.37461 .06611 Mdot
.37462 .06612 Mdot
.37463 .06613 Mdot
.37464 .06614 Mdot
.37465 .06616 Mdot
.37466 .06617 Mdot
.37467 .06618 Mdot
.37468 .06619 Mdot
.37469 .0662 Mdot
.3747 .06621 Mdot
.3747 .06622 Mdot
.37471 .06623 Mdot
.37472 .06624 Mdot
.37473 .06625 Mdot
.37474 .06627 Mdot
.37475 .06628 Mdot
.37476 .06629 Mdot
.37477 .0663 Mdot
.37478 .06631 Mdot
.37479 .06632 Mdot
.3748 .06633 Mdot
.37481 .06634 Mdot
.37482 .06635 Mdot
.37483 .06636 Mdot
.37484 .06637 Mdot
.37485 .06639 Mdot
.37486 .0664 Mdot
.37487 .06641 Mdot
.37488 .06642 Mdot
.37489 .06643 Mdot
.3749 .06644 Mdot
.3749 .06645 Mdot
.37491 .06646 Mdot
.37492 .06647 Mdot
.37493 .06648 Mdot
.37494 .0665 Mdot
.37495 .06651 Mdot
.37496 .06652 Mdot
.37497 .06653 Mdot
.37498 .06654 Mdot
.37499 .06655 Mdot
.375 .06656 Mdot
.37501 .06657 Mdot
.37502 .06658 Mdot
.37503 .06659 Mdot
.37504 .06661 Mdot
.37505 .06662 Mdot
.37506 .06663 Mdot
.37507 .06664 Mdot
.37508 .06665 Mdot
.37509 .06666 Mdot
.3751 .06667 Mdot
.3751 .06668 Mdot
.37511 .06669 Mdot
.37512 .0667 Mdot
.37513 .06672 Mdot
.37514 .06673 Mdot
.37515 .06674 Mdot
.37516 .06675 Mdot
.37517 .06676 Mdot
.37518 .06677 Mdot
.37519 .06678 Mdot
.3752 .06679 Mdot
.37521 .0668 Mdot
.37522 .06681 Mdot
.37523 .06683 Mdot
.37524 .06684 Mdot
.37525 .06685 Mdot
.37526 .06686 Mdot
.37527 .06687 Mdot
.37528 .06688 Mdot
.37529 .06689 Mdot
.3753 .0669 Mdot
.3753 .06691 Mdot
.37531 .06693 Mdot
.37532 .06694 Mdot
.37533 .06695 Mdot
.37534 .06696 Mdot
.37535 .06697 Mdot
.37536 .06698 Mdot
.37537 .06699 Mdot
.37538 .067 Mdot
.37539 .06701 Mdot
.3754 .06702 Mdot
.37541 .06704 Mdot
.37542 .06705 Mdot
.37543 .06706 Mdot
.37544 .06707 Mdot
.37545 .06708 Mdot
.37546 .06709 Mdot
.37547 .0671 Mdot
.37548 .06711 Mdot
.37549 .06712 Mdot
.3755 .06714 Mdot
.3755 .06715 Mdot
.37551 .06716 Mdot
.37552 .06717 Mdot
.37553 .06718 Mdot
.37554 .06719 Mdot
.37555 .0672 Mdot
.37556 .06721 Mdot
.37557 .06722 Mdot
.37558 .06723 Mdot
.37559 .06725 Mdot
.3756 .06726 Mdot
.37561 .06727 Mdot
.37562 .06728 Mdot
.37563 .06729 Mdot
.37564 .0673 Mdot
.37565 .06731 Mdot
.37566 .06732 Mdot
.37567 .06733 Mdot
.37568 .06735 Mdot
.37569 .06736 Mdot
.3757 .06737 Mdot
.3757 .06738 Mdot
.37571 .06739 Mdot
.37572 .0674 Mdot
.37573 .06741 Mdot
.37574 .06742 Mdot
.37575 .06743 Mdot
.37576 .06745 Mdot
.37577 .06746 Mdot
.37578 .06747 Mdot
.37579 .06748 Mdot
.3758 .06749 Mdot
.37581 .0675 Mdot
.37582 .06751 Mdot
.37583 .06752 Mdot
.37584 .06753 Mdot
.37585 .06755 Mdot
.37586 .06756 Mdot
.37587 .06757 Mdot
.37588 .06758 Mdot
.37589 .06759 Mdot
.3759 .0676 Mdot
.3759 .06761 Mdot
.37591 .06762 Mdot
.37592 .06763 Mdot
.37593 .06765 Mdot
.37594 .06766 Mdot
.37595 .06767 Mdot
.37596 .06768 Mdot
.37597 .06769 Mdot
.37598 .0677 Mdot
.37599 .06771 Mdot
.376 .06772 Mdot
.37601 .06773 Mdot
.37602 .06775 Mdot
.37603 .06776 Mdot
.37604 .06777 Mdot
.37605 .06778 Mdot
.37606 .06779 Mdot
.37607 .0678 Mdot
.37608 .06781 Mdot
.37609 .06782 Mdot
.3761 .06783 Mdot
.3761 .06785 Mdot
.37611 .06786 Mdot
.37612 .06787 Mdot
.37613 .06788 Mdot
.37614 .06789 Mdot
.37615 .0679 Mdot
.37616 .06791 Mdot
.37617 .06792 Mdot
.37618 .06793 Mdot
.37619 .06795 Mdot
.3762 .06796 Mdot
.37621 .06797 Mdot
.37622 .06798 Mdot
.37623 .06799 Mdot
.37624 .068 Mdot
.37625 .06801 Mdot
.37626 .06802 Mdot
.37627 .06803 Mdot
.37628 .06805 Mdot
.37629 .06806 Mdot
.3763 .06807 Mdot
.3763 .06808 Mdot
.37631 .06809 Mdot
.37632 .0681 Mdot
.37633 .06811 Mdot
.37634 .06812 Mdot
.37635 .06814 Mdot
.37636 .06815 Mdot
.37637 .06816 Mdot
.37638 .06817 Mdot
.37639 .06818 Mdot
.3764 .06819 Mdot
.37641 .0682 Mdot
.37642 .06821 Mdot
.37643 .06822 Mdot
.37644 .06824 Mdot
.37645 .06825 Mdot
.37646 .06826 Mdot
.37647 .06827 Mdot
.37648 .06828 Mdot
.37649 .06829 Mdot
.3765 .0683 Mdot
.3765 .06831 Mdot
.37651 .06833 Mdot
.37652 .06834 Mdot
.37653 .06835 Mdot
.37654 .06836 Mdot
.37655 .06837 Mdot
.37656 .06838 Mdot
.37657 .06839 Mdot
.37658 .0684 Mdot
.37659 .06841 Mdot
.3766 .06843 Mdot
.37661 .06844 Mdot
.37662 .06845 Mdot
.37663 .06846 Mdot
.37664 .06847 Mdot
.37665 .06848 Mdot
.37666 .06849 Mdot
.37667 .0685 Mdot
.37668 .06852 Mdot
.37669 .06853 Mdot
.3767 .06854 Mdot
.3767 .06855 Mdot
.37671 .06856 Mdot
.37672 .06857 Mdot
.37673 .06858 Mdot
.37674 .06859 Mdot
.37675 .06861 Mdot
.37676 .06862 Mdot
.37677 .06863 Mdot
.37678 .06864 Mdot
.37679 .06865 Mdot
.3768 .06866 Mdot
.37681 .06867 Mdot
.37682 .06868 Mdot
.37683 .06869 Mdot
.37684 .06871 Mdot
.37685 .06872 Mdot
.37686 .06873 Mdot
.37687 .06874 Mdot
.37688 .06875 Mdot
.37689 .06876 Mdot
.3769 .06877 Mdot
.3769 .06878 Mdot
.37691 .0688 Mdot
.37692 .06881 Mdot
.37693 .06882 Mdot
.37694 .06883 Mdot
.37695 .06884 Mdot
.37696 .06885 Mdot
.37697 .06886 Mdot
.37698 .06887 Mdot
.37699 .06889 Mdot
.377 .0689 Mdot
.37701 .06891 Mdot
.37702 .06892 Mdot
.37703 .06893 Mdot
.37704 .06894 Mdot
.37705 .06895 Mdot
.37706 .06896 Mdot
.37707 .06898 Mdot
.37708 .06899 Mdot
.37709 .069 Mdot
.3771 .06901 Mdot
.3771 .06902 Mdot
.37711 .06903 Mdot
.37712 .06904 Mdot
.37713 .06905 Mdot
.37714 .06907 Mdot
.37715 .06908 Mdot
.37716 .06909 Mdot
.37717 .0691 Mdot
.37718 .06911 Mdot
.37719 .06912 Mdot
.3772 .06913 Mdot
.37721 .06914 Mdot
.37722 .06916 Mdot
.37723 .06917 Mdot
.37724 .06918 Mdot
.37725 .06919 Mdot
.37726 .0692 Mdot
.37727 .06921 Mdot
.37728 .06922 Mdot
.37729 .06924 Mdot
.3773 .06925 Mdot
.3773 .06926 Mdot
.37731 .06927 Mdot
.37732 .06928 Mdot
.37733 .06929 Mdot
.37734 .0693 Mdot
.37735 .06931 Mdot
.37736 .06933 Mdot
.37737 .06934 Mdot
.37738 .06935 Mdot
.37739 .06936 Mdot
.3774 .06937 Mdot
.37741 .06938 Mdot
.37742 .06939 Mdot
.37743 .0694 Mdot
.37744 .06942 Mdot
.37745 .06943 Mdot
.37746 .06944 Mdot
.37747 .06945 Mdot
.37748 .06946 Mdot
.37749 .06947 Mdot
.3775 .06948 Mdot
.3775 .06949 Mdot
.37751 .06951 Mdot
.37752 .06952 Mdot
.37753 .06953 Mdot
.37754 .06954 Mdot
.37755 .06955 Mdot
.37756 .06956 Mdot
.37757 .06957 Mdot
.37758 .06959 Mdot
.37759 .0696 Mdot
.3776 .06961 Mdot
.37761 .06962 Mdot
.37762 .06963 Mdot
.37763 .06964 Mdot
.37764 .06965 Mdot
.37765 .06966 Mdot
.37766 .06968 Mdot
.37767 .06969 Mdot
.37768 .0697 Mdot
.37769 .06971 Mdot
.3777 .06972 Mdot
.3777 .06973 Mdot
.37771 .06974 Mdot
.37772 .06976 Mdot
.37773 .06977 Mdot
.37774 .06978 Mdot
.37775 .06979 Mdot
.37776 .0698 Mdot
.37777 .06981 Mdot
.37778 .06982 Mdot
.37779 .06983 Mdot
.3778 .06985 Mdot
.37781 .06986 Mdot
.37782 .06987 Mdot
.37783 .06988 Mdot
.37784 .06989 Mdot
.37785 .0699 Mdot
.37786 .06991 Mdot
.37787 .06993 Mdot
.37788 .06994 Mdot
.37789 .06995 Mdot
.3779 .06996 Mdot
.3779 .06997 Mdot
.37791 .06998 Mdot
.37792 .06999 Mdot
.37793 .07001 Mdot
.37794 .07002 Mdot
.37795 .07003 Mdot
.37796 .07004 Mdot
.37797 .07005 Mdot
.37798 .07006 Mdot
.37799 .07007 Mdot
.378 .07008 Mdot
.37801 .0701 Mdot
.37802 .07011 Mdot
.37803 .07012 Mdot
.37804 .07013 Mdot
.37805 .07014 Mdot
.37806 .07015 Mdot
.37807 .07016 Mdot
.37808 .07018 Mdot
.37809 .07019 Mdot
.3781 .0702 Mdot
.3781 .07021 Mdot
.37811 .07022 Mdot
.37812 .07023 Mdot
.37813 .07024 Mdot
.37814 .07026 Mdot
.37815 .07027 Mdot
.37816 .07028 Mdot
.37817 .07029 Mdot
.37818 .0703 Mdot
.37819 .07031 Mdot
.3782 .07032 Mdot
.37821 .07034 Mdot
.37822 .07035 Mdot
.37823 .07036 Mdot
.37824 .07037 Mdot
.37825 .07038 Mdot
.37826 .07039 Mdot
.37827 .0704 Mdot
.37828 .07041 Mdot
.37829 .07043 Mdot
.3783 .07044 Mdot
.3783 .07045 Mdot
.37831 .07046 Mdot
.37832 .07047 Mdot
.37833 .07048 Mdot
.37834 .07049 Mdot
.37835 .07051 Mdot
.37836 .07052 Mdot
.37837 .07053 Mdot
.37838 .07054 Mdot
.37839 .07055 Mdot
.3784 .07056 Mdot
.37841 .07057 Mdot
.37842 .07059 Mdot
.37843 .0706 Mdot
.37844 .07061 Mdot
.37845 .07062 Mdot
.37846 .07063 Mdot
.37847 .07064 Mdot
.37848 .07065 Mdot
.37849 .07067 Mdot
.3785 .07068 Mdot
.3785 .07069 Mdot
.37851 .0707 Mdot
.37852 .07071 Mdot
.37853 .07072 Mdot
.37854 .07073 Mdot
.37855 .07075 Mdot
.37856 .07076 Mdot
.37857 .07077 Mdot
.37858 .07078 Mdot
.37859 .07079 Mdot
.3786 .0708 Mdot
.37861 .07081 Mdot
.37862 .07083 Mdot
.37863 .07084 Mdot
.37864 .07085 Mdot
.37865 .07086 Mdot
.37866 .07087 Mdot
.37867 .07088 Mdot
.37868 .07089 Mdot
.37869 .07091 Mdot
.3787 .07092 Mdot
.3787 .07093 Mdot
.37871 .07094 Mdot
.37872 .07095 Mdot
.37873 .07096 Mdot
.37874 .07098 Mdot
.37875 .07099 Mdot
.37876 .071 Mdot
.37877 .07101 Mdot
.37878 .07102 Mdot
.37879 .07103 Mdot
.3788 .07104 Mdot
.37881 .07106 Mdot
.37882 .07107 Mdot
.37883 .07108 Mdot
.37884 .07109 Mdot
.37885 .0711 Mdot
.37886 .07111 Mdot
.37887 .07112 Mdot
.37888 .07114 Mdot
.37889 .07115 Mdot
.3789 .07116 Mdot
.3789 .07117 Mdot
.37891 .07118 Mdot
.37892 .07119 Mdot
.37893 .0712 Mdot
.37894 .07122 Mdot
.37895 .07123 Mdot
.37896 .07124 Mdot
.37897 .07125 Mdot
.37898 .07126 Mdot
.37899 .07127 Mdot
.379 .07129 Mdot
.37901 .0713 Mdot
.37902 .07131 Mdot
.37903 .07132 Mdot
.37904 .07133 Mdot
.37905 .07134 Mdot
.37906 .07135 Mdot
.37907 .07137 Mdot
.37908 .07138 Mdot
.37909 .07139 Mdot
.3791 .0714 Mdot
.3791 .07141 Mdot
.37911 .07142 Mdot
.37912 .07143 Mdot
.37913 .07145 Mdot
.37914 .07146 Mdot
.37915 .07147 Mdot
.37916 .07148 Mdot
.37917 .07149 Mdot
.37918 .0715 Mdot
.37919 .07152 Mdot
.3792 .07153 Mdot
.37921 .07154 Mdot
.37922 .07155 Mdot
.37923 .07156 Mdot
.37924 .07157 Mdot
.37925 .07158 Mdot
.37926 .0716 Mdot
.37927 .07161 Mdot
.37928 .07162 Mdot
.37929 .07163 Mdot
.3793 .07164 Mdot
.3793 .07165 Mdot
.37931 .07167 Mdot
.37932 .07168 Mdot
.37933 .07169 Mdot
.37934 .0717 Mdot
.37935 .07171 Mdot
.37936 .07172 Mdot
.37937 .07173 Mdot
.37938 .07175 Mdot
.37939 .07176 Mdot
.3794 .07177 Mdot
.37941 .07178 Mdot
.37942 .07179 Mdot
.37943 .0718 Mdot
.37944 .07182 Mdot
.37945 .07183 Mdot
.37946 .07184 Mdot
.37947 .07185 Mdot
.37948 .07186 Mdot
.37949 .07187 Mdot
.3795 .07188 Mdot
.3795 .0719 Mdot
.37951 .07191 Mdot
.37952 .07192 Mdot
.37953 .07193 Mdot
.37954 .07194 Mdot
.37955 .07195 Mdot
.37956 .07197 Mdot
.37957 .07198 Mdot
.37958 .07199 Mdot
.37959 .072 Mdot
.3796 .07201 Mdot
.37961 .07202 Mdot
.37962 .07203 Mdot
.37963 .07205 Mdot
.37964 .07206 Mdot
.37965 .07207 Mdot
.37966 .07208 Mdot
.37967 .07209 Mdot
.37968 .0721 Mdot
.37969 .07212 Mdot
.3797 .07213 Mdot
.3797 .07214 Mdot
.37971 .07215 Mdot
.37972 .07216 Mdot
.37973 .07217 Mdot
.37974 .07219 Mdot
.37975 .0722 Mdot
.37976 .07221 Mdot
.37977 .07222 Mdot
.37978 .07223 Mdot
.37979 .07224 Mdot
.3798 .07225 Mdot
.37981 .07227 Mdot
.37982 .07228 Mdot
.37983 .07229 Mdot
.37984 .0723 Mdot
.37985 .07231 Mdot
.37986 .07232 Mdot
.37987 .07234 Mdot
.37988 .07235 Mdot
.37989 .07236 Mdot
.3799 .07237 Mdot
.3799 .07238 Mdot
.37991 .07239 Mdot
.37992 .07241 Mdot
.37993 .07242 Mdot
.37994 .07243 Mdot
.37995 .07244 Mdot
.37996 .07245 Mdot
.37997 .07246 Mdot
.37998 .07248 Mdot
.37999 .07249 Mdot
.38 .0725 Mdot
.38001 .07251 Mdot
.38002 .07252 Mdot
.38003 .07253 Mdot
.38004 .07255 Mdot
.38005 .07256 Mdot
.38006 .07257 Mdot
.38007 .07258 Mdot
.38008 .07259 Mdot
.38009 .0726 Mdot
.3801 .07261 Mdot
.3801 .07263 Mdot
.38011 .07264 Mdot
.38012 .07265 Mdot
.38013 .07266 Mdot
.38014 .07267 Mdot
.38015 .07268 Mdot
.38016 .0727 Mdot
.38017 .07271 Mdot
.38018 .07272 Mdot
.38019 .07273 Mdot
.3802 .07274 Mdot
.38021 .07275 Mdot
.38022 .07277 Mdot
.38023 .07278 Mdot
.38024 .07279 Mdot
.38025 .0728 Mdot
.38026 .07281 Mdot
.38027 .07282 Mdot
.38028 .07284 Mdot
.38029 .07285 Mdot
.3803 .07286 Mdot
.3803 .07287 Mdot
.38031 .07288 Mdot
.38032 .07289 Mdot
.38033 .07291 Mdot
.38034 .07292 Mdot
.38035 .07293 Mdot
.38036 .07294 Mdot
.38037 .07295 Mdot
.38038 .07296 Mdot
.38039 .07298 Mdot
.3804 .07299 Mdot
.38041 .073 Mdot
.38042 .07301 Mdot
.38043 .07302 Mdot
.38044 .07303 Mdot
.38045 .07305 Mdot
.38046 .07306 Mdot
.38047 .07307 Mdot
.38048 .07308 Mdot
.38049 .07309 Mdot
.3805 .0731 Mdot
.3805 .07312 Mdot
.38051 .07313 Mdot
.38052 .07314 Mdot
.38053 .07315 Mdot
.38054 .07316 Mdot
.38055 .07317 Mdot
.38056 .07319 Mdot
.38057 .0732 Mdot
.38058 .07321 Mdot
.38059 .07322 Mdot
.3806 .07323 Mdot
.38061 .07324 Mdot
.38062 .07326 Mdot
.38063 .07327 Mdot
.38064 .07328 Mdot
.38065 .07329 Mdot
.38066 .0733 Mdot
.38067 .07332 Mdot
.38068 .07333 Mdot
.38069 .07334 Mdot
.3807 .07335 Mdot
.3807 .07336 Mdot
.38071 .07337 Mdot
.38072 .07339 Mdot
.38073 .0734 Mdot
.38074 .07341 Mdot
.38075 .07342 Mdot
.38076 .07343 Mdot
.38077 .07344 Mdot
.38078 .07346 Mdot
.38079 .07347 Mdot
.3808 .07348 Mdot
.38081 .07349 Mdot
.38082 .0735 Mdot
.38083 .07351 Mdot
.38084 .07353 Mdot
.38085 .07354 Mdot
.38086 .07355 Mdot
.38087 .07356 Mdot
.38088 .07357 Mdot
.38089 .07358 Mdot
.3809 .0736 Mdot
.3809 .07361 Mdot
.38091 .07362 Mdot
.38092 .07363 Mdot
.38093 .07364 Mdot
.38094 .07365 Mdot
.38095 .07367 Mdot
.38096 .07368 Mdot
.38097 .07369 Mdot
.38098 .0737 Mdot
.38099 .07371 Mdot
.381 .07373 Mdot
.38101 .07374 Mdot
.38102 .07375 Mdot
.38103 .07376 Mdot
.38104 .07377 Mdot
.38105 .07378 Mdot
.38106 .0738 Mdot
.38107 .07381 Mdot
.38108 .07382 Mdot
.38109 .07383 Mdot
.3811 .07384 Mdot
.3811 .07385 Mdot
.38111 .07387 Mdot
.38112 .07388 Mdot
.38113 .07389 Mdot
.38114 .0739 Mdot
.38115 .07391 Mdot
.38116 .07393 Mdot
.38117 .07394 Mdot
.38118 .07395 Mdot
.38119 .07396 Mdot
.3812 .07397 Mdot
.38121 .07398 Mdot
.38122 .074 Mdot
.38123 .07401 Mdot
.38124 .07402 Mdot
.38125 .07403 Mdot
.38126 .07404 Mdot
.38127 .07405 Mdot
.38128 .07407 Mdot
.38129 .07408 Mdot
.3813 .07409 Mdot
.3813 .0741 Mdot
.38131 .07411 Mdot
.38132 .07413 Mdot
.38133 .07414 Mdot
.38134 .07415 Mdot
.38135 .07416 Mdot
.38136 .07417 Mdot
.38137 .07418 Mdot
.38138 .0742 Mdot
.38139 .07421 Mdot
.3814 .07422 Mdot
.38141 .07423 Mdot
.38142 .07424 Mdot
.38143 .07426 Mdot
.38144 .07427 Mdot
.38145 .07428 Mdot
.38146 .07429 Mdot
.38147 .0743 Mdot
.38148 .07431 Mdot
.38149 .07433 Mdot
.3815 .07434 Mdot
.3815 .07435 Mdot
.38151 .07436 Mdot
.38152 .07437 Mdot
.38153 .07438 Mdot
.38154 .0744 Mdot
.38155 .07441 Mdot
.38156 .07442 Mdot
.38157 .07443 Mdot
.38158 .07444 Mdot
.38159 .07446 Mdot
.3816 .07447 Mdot
.38161 .07448 Mdot
.38162 .07449 Mdot
.38163 .0745 Mdot
.38164 .07451 Mdot
.38165 .07453 Mdot
.38166 .07454 Mdot
.38167 .07455 Mdot
.38168 .07456 Mdot
.38169 .07457 Mdot
.3817 .07459 Mdot
.3817 .0746 Mdot
.38171 .07461 Mdot
.38172 .07462 Mdot
.38173 .07463 Mdot
.38174 .07465 Mdot
.38175 .07466 Mdot
.38176 .07467 Mdot
.38177 .07468 Mdot
.38178 .07469 Mdot
.38179 .0747 Mdot
.3818 .07472 Mdot
.38181 .07473 Mdot
.38182 .07474 Mdot
.38183 .07475 Mdot
.38184 .07476 Mdot
.38185 .07478 Mdot
.38186 .07479 Mdot
.38187 .0748 Mdot
.38188 .07481 Mdot
.38189 .07482 Mdot
.3819 .07483 Mdot
.3819 .07485 Mdot
.38191 .07486 Mdot
.38192 .07487 Mdot
.38193 .07488 Mdot
.38194 .07489 Mdot
.38195 .07491 Mdot
.38196 .07492 Mdot
.38197 .07493 Mdot
.38198 .07494 Mdot
.38199 .07495 Mdot
.382 .07497 Mdot
.38201 .07498 Mdot
.38202 .07499 Mdot
.38203 .075 Mdot
.38204 .07501 Mdot
.38205 .07502 Mdot
.38206 .07504 Mdot
.38207 .07505 Mdot
.38208 .07506 Mdot
.38209 .07507 Mdot
.3821 .07508 Mdot
.3821 .0751 Mdot
.38211 .07511 Mdot
.38212 .07512 Mdot
.38213 .07513 Mdot
.38214 .07514 Mdot
.38215 .07516 Mdot
.38216 .07517 Mdot
.38217 .07518 Mdot
.38218 .07519 Mdot
.38219 .0752 Mdot
.3822 .07521 Mdot
.38221 .07523 Mdot
.38222 .07524 Mdot
.38223 .07525 Mdot
.38224 .07526 Mdot
.38225 .07527 Mdot
.38226 .07529 Mdot
.38227 .0753 Mdot
.38228 .07531 Mdot
.38229 .07532 Mdot
.3823 .07533 Mdot
.3823 .07535 Mdot
.38231 .07536 Mdot
.38232 .07537 Mdot
.38233 .07538 Mdot
.38234 .07539 Mdot
.38235 .07541 Mdot
.38236 .07542 Mdot
.38237 .07543 Mdot
.38238 .07544 Mdot
.38239 .07545 Mdot
.3824 .07546 Mdot
.38241 .07548 Mdot
.38242 .07549 Mdot
.38243 .0755 Mdot
.38244 .07551 Mdot
.38245 .07552 Mdot
.38246 .07554 Mdot
.38247 .07555 Mdot
.38248 .07556 Mdot
.38249 .07557 Mdot
.3825 .07558 Mdot
.3825 .0756 Mdot
.38251 .07561 Mdot
.38252 .07562 Mdot
.38253 .07563 Mdot
.38254 .07564 Mdot
.38255 .07566 Mdot
.38256 .07567 Mdot
.38257 .07568 Mdot
.38258 .07569 Mdot
.38259 .0757 Mdot
.3826 .07572 Mdot
.38261 .07573 Mdot
.38262 .07574 Mdot
.38263 .07575 Mdot
.38264 .07576 Mdot
.38265 .07578 Mdot
.38266 .07579 Mdot
.38267 .0758 Mdot
.38268 .07581 Mdot
.38269 .07582 Mdot
.3827 .07583 Mdot
.3827 .07585 Mdot
.38271 .07586 Mdot
.38272 .07587 Mdot
.38273 .07588 Mdot
.38274 .07589 Mdot
.38275 .07591 Mdot
.38276 .07592 Mdot
.38277 .07593 Mdot
.38278 .07594 Mdot
.38279 .07595 Mdot
.3828 .07597 Mdot
.38281 .07598 Mdot
.38282 .07599 Mdot
.38283 .076 Mdot
.38284 .07601 Mdot
.38285 .07603 Mdot
.38286 .07604 Mdot
.38287 .07605 Mdot
.38288 .07606 Mdot
.38289 .07607 Mdot
.3829 .07609 Mdot
.3829 .0761 Mdot
.38291 .07611 Mdot
.38292 .07612 Mdot
.38293 .07613 Mdot
.38294 .07615 Mdot
.38295 .07616 Mdot
.38296 .07617 Mdot
.38297 .07618 Mdot
.38298 .07619 Mdot
.38299 .07621 Mdot
.383 .07622 Mdot
.38301 .07623 Mdot
.38302 .07624 Mdot
.38303 .07625 Mdot
.38304 .07627 Mdot
.38305 .07628 Mdot
.38306 .07629 Mdot
.38307 .0763 Mdot
.38308 .07631 Mdot
.38309 .07633 Mdot
.3831 .07634 Mdot
.3831 .07635 Mdot
.38311 .07636 Mdot
.38312 .07637 Mdot
.38313 .07639 Mdot
.38314 .0764 Mdot
.38315 .07641 Mdot
.38316 .07642 Mdot
.38317 .07643 Mdot
.38318 .07645 Mdot
.38319 .07646 Mdot
.3832 .07647 Mdot
.38321 .07648 Mdot
.38322 .07649 Mdot
.38323 .07651 Mdot
.38324 .07652 Mdot
.38325 .07653 Mdot
.38326 .07654 Mdot
.38327 .07655 Mdot
.38328 .07657 Mdot
.38329 .07658 Mdot
.3833 .07659 Mdot
.3833 .0766 Mdot
.38331 .07661 Mdot
.38332 .07663 Mdot
.38333 .07664 Mdot
.38334 .07665 Mdot
.38335 .07666 Mdot
.38336 .07667 Mdot
.38337 .07669 Mdot
.38338 .0767 Mdot
.38339 .07671 Mdot
.3834 .07672 Mdot
.38341 .07673 Mdot
.38342 .07675 Mdot
.38343 .07676 Mdot
.38344 .07677 Mdot
.38345 .07678 Mdot
.38346 .0768 Mdot
.38347 .07681 Mdot
.38348 .07682 Mdot
.38349 .07683 Mdot
.3835 .07684 Mdot
.3835 .07686 Mdot
.38351 .07687 Mdot
.38352 .07688 Mdot
.38353 .07689 Mdot
.38354 .0769 Mdot
.38355 .07692 Mdot
.38356 .07693 Mdot
.38357 .07694 Mdot
.38358 .07695 Mdot
.38359 .07696 Mdot
.3836 .07698 Mdot
.38361 .07699 Mdot
.38362 .077 Mdot
.38363 .07701 Mdot
.38364 .07702 Mdot
.38365 .07704 Mdot
.38366 .07705 Mdot
.38367 .07706 Mdot
.38368 .07707 Mdot
.38369 .07708 Mdot
.3837 .0771 Mdot
.3837 .07711 Mdot
.38371 .07712 Mdot
.38372 .07713 Mdot
.38373 .07715 Mdot
.38374 .07716 Mdot
.38375 .07717 Mdot
.38376 .07718 Mdot
.38377 .07719 Mdot
.38378 .07721 Mdot
.38379 .07722 Mdot
.3838 .07723 Mdot
.38381 .07724 Mdot
.38382 .07725 Mdot
.38383 .07727 Mdot
.38384 .07728 Mdot
.38385 .07729 Mdot
.38386 .0773 Mdot
.38387 .07731 Mdot
.38388 .07733 Mdot
.38389 .07734 Mdot
.3839 .07735 Mdot
.3839 .07736 Mdot
.38391 .07737 Mdot
.38392 .07739 Mdot
.38393 .0774 Mdot
.38394 .07741 Mdot
.38395 .07742 Mdot
.38396 .07744 Mdot
.38397 .07745 Mdot
.38398 .07746 Mdot
.38399 .07747 Mdot
.384 .07748 Mdot
.38401 .0775 Mdot
.38402 .07751 Mdot
.38403 .07752 Mdot
.38404 .07753 Mdot
.38405 .07754 Mdot
.38406 .07756 Mdot
.38407 .07757 Mdot
.38408 .07758 Mdot
.38409 .07759 Mdot
.3841 .07761 Mdot
.3841 .07762 Mdot
.38411 .07763 Mdot
.38412 .07764 Mdot
.38413 .07765 Mdot
.38414 .07767 Mdot
.38415 .07768 Mdot
.38416 .07769 Mdot
.38417 .0777 Mdot
.38418 .07771 Mdot
.38419 .07773 Mdot
.3842 .07774 Mdot
.38421 .07775 Mdot
.38422 .07776 Mdot
.38423 .07778 Mdot
.38424 .07779 Mdot
.38425 .0778 Mdot
.38426 .07781 Mdot
.38427 .07782 Mdot
.38428 .07784 Mdot
.38429 .07785 Mdot
.3843 .07786 Mdot
.3843 .07787 Mdot
.38431 .07788 Mdot
.38432 .0779 Mdot
.38433 .07791 Mdot
.38434 .07792 Mdot
.38435 .07793 Mdot
.38436 .07795 Mdot
.38437 .07796 Mdot
.38438 .07797 Mdot
.38439 .07798 Mdot
.3844 .07799 Mdot
.38441 .07801 Mdot
.38442 .07802 Mdot
.38443 .07803 Mdot
.38444 .07804 Mdot
.38445 .07805 Mdot
.38446 .07807 Mdot
.38447 .07808 Mdot
.38448 .07809 Mdot
.38449 .0781 Mdot
.3845 .07812 Mdot
.3845 .07813 Mdot
.38451 .07814 Mdot
.38452 .07815 Mdot
.38453 .07816 Mdot
.38454 .07818 Mdot
.38455 .07819 Mdot
.38456 .0782 Mdot
.38457 .07821 Mdot
.38458 .07823 Mdot
.38459 .07824 Mdot
.3846 .07825 Mdot
.38461 .07826 Mdot
.38462 .07827 Mdot
.38463 .07829 Mdot
.38464 .0783 Mdot
.38465 .07831 Mdot
.38466 .07832 Mdot
.38467 .07834 Mdot
.38468 .07835 Mdot
.38469 .07836 Mdot
.3847 .07837 Mdot
.3847 .07838 Mdot
.38471 .0784 Mdot
.38472 .07841 Mdot
.38473 .07842 Mdot
.38474 .07843 Mdot
.38475 .07845 Mdot
.38476 .07846 Mdot
.38477 .07847 Mdot
.38478 .07848 Mdot
.38479 .07849 Mdot
.3848 .07851 Mdot
.38481 .07852 Mdot
.38482 .07853 Mdot
.38483 .07854 Mdot
.38484 .07856 Mdot
.38485 .07857 Mdot
.38486 .07858 Mdot
.38487 .07859 Mdot
.38488 .0786 Mdot
.38489 .07862 Mdot
.3849 .07863 Mdot
.3849 .07864 Mdot
.38491 .07865 Mdot
.38492 .07867 Mdot
.38493 .07868 Mdot
.38494 .07869 Mdot
.38495 .0787 Mdot
.38496 .07871 Mdot
.38497 .07873 Mdot
.38498 .07874 Mdot
.38499 .07875 Mdot
.385 .07876 Mdot
.38501 .07878 Mdot
.38502 .07879 Mdot
.38503 .0788 Mdot
.38504 .07881 Mdot
.38505 .07882 Mdot
.38506 .07884 Mdot
.38507 .07885 Mdot
.38508 .07886 Mdot
.38509 .07887 Mdot
.3851 .07889 Mdot
.3851 .0789 Mdot
.38511 .07891 Mdot
.38512 .07892 Mdot
.38513 .07893 Mdot
.38514 .07895 Mdot
.38515 .07896 Mdot
.38516 .07897 Mdot
.38517 .07898 Mdot
.38518 .079 Mdot
.38519 .07901 Mdot
.3852 .07902 Mdot
.38521 .07903 Mdot
.38522 .07904 Mdot
.38523 .07906 Mdot
.38524 .07907 Mdot
.38525 .07908 Mdot
.38526 .07909 Mdot
.38527 .07911 Mdot
.38528 .07912 Mdot
.38529 .07913 Mdot
.3853 .07914 Mdot
.3853 .07916 Mdot
.38531 .07917 Mdot
.38532 .07918 Mdot
.38533 .07919 Mdot
.38534 .0792 Mdot
.38535 .07922 Mdot
.38536 .07923 Mdot
.38537 .07924 Mdot
.38538 .07925 Mdot
.38539 .07927 Mdot
.3854 .07928 Mdot
.38541 .07929 Mdot
.38542 .0793 Mdot
.38543 .07932 Mdot
.38544 .07933 Mdot
.38545 .07934 Mdot
.38546 .07935 Mdot
.38547 .07936 Mdot
.38548 .07938 Mdot
.38549 .07939 Mdot
.3855 .0794 Mdot
.3855 .07941 Mdot
.38551 .07943 Mdot
.38552 .07944 Mdot
.38553 .07945 Mdot
.38554 .07946 Mdot
.38555 .07948 Mdot
.38556 .07949 Mdot
.38557 .0795 Mdot
.38558 .07951 Mdot
.38559 .07952 Mdot
.3856 .07954 Mdot
.38561 .07955 Mdot
.38562 .07956 Mdot
.38563 .07957 Mdot
.38564 .07959 Mdot
.38565 .0796 Mdot
.38566 .07961 Mdot
.38567 .07962 Mdot
.38568 .07964 Mdot
.38569 .07965 Mdot
.3857 .07966 Mdot
.3857 .07967 Mdot
.38571 .07968 Mdot
.38572 .0797 Mdot
.38573 .07971 Mdot
.38574 .07972 Mdot
.38575 .07973 Mdot
.38576 .07975 Mdot
.38577 .07976 Mdot
.38578 .07977 Mdot
.38579 .07978 Mdot
.3858 .0798 Mdot
.38581 .07981 Mdot
.38582 .07982 Mdot
.38583 .07983 Mdot
.38584 .07985 Mdot
.38585 .07986 Mdot
.38586 .07987 Mdot
.38587 .07988 Mdot
.38588 .07989 Mdot
.38589 .07991 Mdot
.3859 .07992 Mdot
.3859 .07993 Mdot
.38591 .07994 Mdot
.38592 .07996 Mdot
.38593 .07997 Mdot
.38594 .07998 Mdot
.38595 .07999 Mdot
.38596 .08001 Mdot
.38597 .08002 Mdot
.38598 .08003 Mdot
.38599 .08004 Mdot
.386 .08006 Mdot
.38601 .08007 Mdot
.38602 .08008 Mdot
.38603 .08009 Mdot
.38604 .0801 Mdot
.38605 .08012 Mdot
.38606 .08013 Mdot
.38607 .08014 Mdot
.38608 .08015 Mdot
.38609 .08017 Mdot
.3861 .08018 Mdot
.3861 .08019 Mdot
.38611 .0802 Mdot
.38612 .08022 Mdot
.38613 .08023 Mdot
.38614 .08024 Mdot
.38615 .08025 Mdot
.38616 .08027 Mdot
.38617 .08028 Mdot
.38618 .08029 Mdot
.38619 .0803 Mdot
.3862 .08032 Mdot
.38621 .08033 Mdot
.38622 .08034 Mdot
.38623 .08035 Mdot
.38624 .08036 Mdot
.38625 .08038 Mdot
.38626 .08039 Mdot
.38627 .0804 Mdot
.38628 .08041 Mdot
.38629 .08043 Mdot
.3863 .08044 Mdot
.3863 .08045 Mdot
.38631 .08046 Mdot
.38632 .08048 Mdot
.38633 .08049 Mdot
.38634 .0805 Mdot
.38635 .08051 Mdot
.38636 .08053 Mdot
.38637 .08054 Mdot
.38638 .08055 Mdot
.38639 .08056 Mdot
.3864 .08058 Mdot
.38641 .08059 Mdot
.38642 .0806 Mdot
.38643 .08061 Mdot
.38644 .08063 Mdot
.38645 .08064 Mdot
.38646 .08065 Mdot
.38647 .08066 Mdot
.38648 .08068 Mdot
.38649 .08069 Mdot
.3865 .0807 Mdot
.3865 .08071 Mdot
.38651 .08072 Mdot
.38652 .08074 Mdot
.38653 .08075 Mdot
.38654 .08076 Mdot
.38655 .08077 Mdot
.38656 .08079 Mdot
.38657 .0808 Mdot
.38658 .08081 Mdot
.38659 .08082 Mdot
.3866 .08084 Mdot
.38661 .08085 Mdot
.38662 .08086 Mdot
.38663 .08087 Mdot
.38664 .08089 Mdot
.38665 .0809 Mdot
.38666 .08091 Mdot
.38667 .08092 Mdot
.38668 .08094 Mdot
.38669 .08095 Mdot
.3867 .08096 Mdot
.3867 .08097 Mdot
.38671 .08099 Mdot
.38672 .081 Mdot
.38673 .08101 Mdot
.38674 .08102 Mdot
.38675 .08104 Mdot
.38676 .08105 Mdot
.38677 .08106 Mdot
.38678 .08107 Mdot
.38679 .08109 Mdot
.3868 .0811 Mdot
.38681 .08111 Mdot
.38682 .08112 Mdot
.38683 .08114 Mdot
.38684 .08115 Mdot
.38685 .08116 Mdot
.38686 .08117 Mdot
.38687 .08119 Mdot
.38688 .0812 Mdot
.38689 .08121 Mdot
.3869 .08122 Mdot
.3869 .08124 Mdot
.38691 .08125 Mdot
.38692 .08126 Mdot
.38693 .08127 Mdot
.38694 .08129 Mdot
.38695 .0813 Mdot
.38696 .08131 Mdot
.38697 .08132 Mdot
.38698 .08134 Mdot
.38699 .08135 Mdot
.387 .08136 Mdot
.38701 .08137 Mdot
.38702 .08139 Mdot
.38703 .0814 Mdot
.38704 .08141 Mdot
.38705 .08142 Mdot
.38706 .08144 Mdot
.38707 .08145 Mdot
.38708 .08146 Mdot
.38709 .08147 Mdot
.3871 .08149 Mdot
.3871 .0815 Mdot
.38711 .08151 Mdot
.38712 .08152 Mdot
.38713 .08154 Mdot
.38714 .08155 Mdot
.38715 .08156 Mdot
.38716 .08157 Mdot
.38717 .08159 Mdot
.38718 .0816 Mdot
.38719 .08161 Mdot
.3872 .08162 Mdot
.38721 .08164 Mdot
.38722 .08165 Mdot
.38723 .08166 Mdot
.38724 .08167 Mdot
.38725 .08169 Mdot
.38726 .0817 Mdot
.38727 .08171 Mdot
.38728 .08172 Mdot
.38729 .08174 Mdot
.3873 .08175 Mdot
.3873 .08176 Mdot
.38731 .08177 Mdot
.38732 .08179 Mdot
.38733 .0818 Mdot
.38734 .08181 Mdot
.38735 .08182 Mdot
.38736 .08184 Mdot
.38737 .08185 Mdot
.38738 .08186 Mdot
.38739 .08187 Mdot
.3874 .08189 Mdot
.38741 .0819 Mdot
.38742 .08191 Mdot
.38743 .08192 Mdot
.38744 .08194 Mdot
.38745 .08195 Mdot
.38746 .08196 Mdot
.38747 .08197 Mdot
.38748 .08199 Mdot
.38749 .082 Mdot
.3875 .08201 Mdot
.3875 .08202 Mdot
.38751 .08204 Mdot
.38752 .08205 Mdot
.38753 .08206 Mdot
.38754 .08207 Mdot
.38755 .08209 Mdot
.38756 .0821 Mdot
.38757 .08211 Mdot
.38758 .08212 Mdot
.38759 .08214 Mdot
.3876 .08215 Mdot
.38761 .08216 Mdot
.38762 .08217 Mdot
.38763 .08219 Mdot
.38764 .0822 Mdot
.38765 .08221 Mdot
.38766 .08223 Mdot
.38767 .08224 Mdot
.38768 .08225 Mdot
.38769 .08226 Mdot
.3877 .08228 Mdot
.3877 .08229 Mdot
.38771 .0823 Mdot
.38772 .08231 Mdot
.38773 .08233 Mdot
.38774 .08234 Mdot
.38775 .08235 Mdot
.38776 .08236 Mdot
.38777 .08238 Mdot
.38778 .08239 Mdot
.38779 .0824 Mdot
.3878 .08241 Mdot
.38781 .08243 Mdot
.38782 .08244 Mdot
.38783 .08245 Mdot
.38784 .08246 Mdot
.38785 .08248 Mdot
.38786 .08249 Mdot
.38787 .0825 Mdot
.38788 .08251 Mdot
.38789 .08253 Mdot
.3879 .08254 Mdot
.3879 .08255 Mdot
.38791 .08257 Mdot
.38792 .08258 Mdot
.38793 .08259 Mdot
.38794 .0826 Mdot
.38795 .08262 Mdot
.38796 .08263 Mdot
.38797 .08264 Mdot
.38798 .08265 Mdot
.38799 .08267 Mdot
.388 .08268 Mdot
.38801 .08269 Mdot
.38802 .0827 Mdot
.38803 .08272 Mdot
.38804 .08273 Mdot
.38805 .08274 Mdot
.38806 .08275 Mdot
.38807 .08277 Mdot
.38808 .08278 Mdot
.38809 .08279 Mdot
.3881 .0828 Mdot
.3881 .08282 Mdot
.38811 .08283 Mdot
.38812 .08284 Mdot
.38813 .08286 Mdot
.38814 .08287 Mdot
.38815 .08288 Mdot
.38816 .08289 Mdot
.38817 .08291 Mdot
.38818 .08292 Mdot
.38819 .08293 Mdot
.3882 .08294 Mdot
.38821 .08296 Mdot
.38822 .08297 Mdot
.38823 .08298 Mdot
.38824 .08299 Mdot
.38825 .08301 Mdot
.38826 .08302 Mdot
.38827 .08303 Mdot
.38828 .08305 Mdot
.38829 .08306 Mdot
.3883 .08307 Mdot
.3883 .08308 Mdot
.38831 .0831 Mdot
.38832 .08311 Mdot
.38833 .08312 Mdot
.38834 .08313 Mdot
.38835 .08315 Mdot
.38836 .08316 Mdot
.38837 .08317 Mdot
.38838 .08318 Mdot
.38839 .0832 Mdot
.3884 .08321 Mdot
.38841 .08322 Mdot
.38842 .08324 Mdot
.38843 .08325 Mdot
.38844 .08326 Mdot
.38845 .08327 Mdot
.38846 .08329 Mdot
.38847 .0833 Mdot
.38848 .08331 Mdot
.38849 .08332 Mdot
.3885 .08334 Mdot
.3885 .08335 Mdot
.38851 .08336 Mdot
.38852 .08337 Mdot
.38853 .08339 Mdot
.38854 .0834 Mdot
.38855 .08341 Mdot
.38856 .08343 Mdot
.38857 .08344 Mdot
.38858 .08345 Mdot
.38859 .08346 Mdot
.3886 .08348 Mdot
.38861 .08349 Mdot
.38862 .0835 Mdot
.38863 .08351 Mdot
.38864 .08353 Mdot
.38865 .08354 Mdot
.38866 .08355 Mdot
.38867 .08356 Mdot
.38868 .08358 Mdot
.38869 .08359 Mdot
.3887 .0836 Mdot
.3887 .08362 Mdot
.38871 .08363 Mdot
.38872 .08364 Mdot
.38873 .08365 Mdot
.38874 .08367 Mdot
.38875 .08368 Mdot
.38876 .08369 Mdot
.38877 .0837 Mdot
.38878 .08372 Mdot
.38879 .08373 Mdot
.3888 .08374 Mdot
.38881 .08376 Mdot
.38882 .08377 Mdot
.38883 .08378 Mdot
.38884 .08379 Mdot
.38885 .08381 Mdot
.38886 .08382 Mdot
.38887 .08383 Mdot
.38888 .08384 Mdot
.38889 .08386 Mdot
.3889 .08387 Mdot
.3889 .08388 Mdot
.38891 .0839 Mdot
.38892 .08391 Mdot
.38893 .08392 Mdot
.38894 .08393 Mdot
.38895 .08395 Mdot
.38896 .08396 Mdot
.38897 .08397 Mdot
.38898 .08398 Mdot
.38899 .084 Mdot
.389 .08401 Mdot
.38901 .08402 Mdot
.38902 .08404 Mdot
.38903 .08405 Mdot
.38904 .08406 Mdot
.38905 .08407 Mdot
.38906 .08409 Mdot
.38907 .0841 Mdot
.38908 .08411 Mdot
.38909 .08412 Mdot
.3891 .08414 Mdot
.3891 .08415 Mdot
.38911 .08416 Mdot
.38912 .08418 Mdot
.38913 .08419 Mdot
.38914 .0842 Mdot
.38915 .08421 Mdot
.38916 .08423 Mdot
.38917 .08424 Mdot
.38918 .08425 Mdot
.38919 .08427 Mdot
.3892 .08428 Mdot
.38921 .08429 Mdot
.38922 .0843 Mdot
.38923 .08432 Mdot
.38924 .08433 Mdot
.38925 .08434 Mdot
.38926 .08435 Mdot
.38927 .08437 Mdot
.38928 .08438 Mdot
.38929 .08439 Mdot
.3893 .08441 Mdot
.3893 .08442 Mdot
.38931 .08443 Mdot
.38932 .08444 Mdot
.38933 .08446 Mdot
.38934 .08447 Mdot
.38935 .08448 Mdot
.38936 .0845 Mdot
.38937 .08451 Mdot
.38938 .08452 Mdot
.38939 .08453 Mdot
.3894 .08455 Mdot
.38941 .08456 Mdot
.38942 .08457 Mdot
.38943 .08458 Mdot
.38944 .0846 Mdot
.38945 .08461 Mdot
.38946 .08462 Mdot
.38947 .08464 Mdot
.38948 .08465 Mdot
.38949 .08466 Mdot
.3895 .08467 Mdot
.3895 .08469 Mdot
.38951 .0847 Mdot
.38952 .08471 Mdot
.38953 .08473 Mdot
.38954 .08474 Mdot
.38955 .08475 Mdot
.38956 .08476 Mdot
.38957 .08478 Mdot
.38958 .08479 Mdot
.38959 .0848 Mdot
.3896 .08482 Mdot
.38961 .08483 Mdot
.38962 .08484 Mdot
.38963 .08485 Mdot
.38964 .08487 Mdot
.38965 .08488 Mdot
.38966 .08489 Mdot
.38967 .0849 Mdot
.38968 .08492 Mdot
.38969 .08493 Mdot
.3897 .08494 Mdot
.3897 .08496 Mdot
.38971 .08497 Mdot
.38972 .08498 Mdot
.38973 .08499 Mdot
.38974 .08501 Mdot
.38975 .08502 Mdot
.38976 .08503 Mdot
.38977 .08505 Mdot
.38978 .08506 Mdot
.38979 .08507 Mdot
.3898 .08508 Mdot
.38981 .0851 Mdot
.38982 .08511 Mdot
.38983 .08512 Mdot
.38984 .08514 Mdot
.38985 .08515 Mdot
.38986 .08516 Mdot
.38987 .08517 Mdot
.38988 .08519 Mdot
.38989 .0852 Mdot
.3899 .08521 Mdot
.3899 .08523 Mdot
.38991 .08524 Mdot
.38992 .08525 Mdot
.38993 .08526 Mdot
.38994 .08528 Mdot
.38995 .08529 Mdot
.38996 .0853 Mdot
.38997 .08532 Mdot
.38998 .08533 Mdot
.38999 .08534 Mdot
.39 .08535 Mdot
.39001 .08537 Mdot
.39002 .08538 Mdot
.39003 .08539 Mdot
.39004 .08541 Mdot
.39005 .08542 Mdot
.39006 .08543 Mdot
.39007 .08544 Mdot
.39008 .08546 Mdot
.39009 .08547 Mdot
.3901 .08548 Mdot
.3901 .0855 Mdot
.39011 .08551 Mdot
.39012 .08552 Mdot
.39013 .08553 Mdot
.39014 .08555 Mdot
.39015 .08556 Mdot
.39016 .08557 Mdot
.39017 .08559 Mdot
.39018 .0856 Mdot
.39019 .08561 Mdot
.3902 .08563 Mdot
.39021 .08564 Mdot
.39022 .08565 Mdot
.39023 .08566 Mdot
.39024 .08568 Mdot
.39025 .08569 Mdot
.39026 .0857 Mdot
.39027 .08572 Mdot
.39028 .08573 Mdot
.39029 .08574 Mdot
.3903 .08575 Mdot
.3903 .08577 Mdot
.39031 .08578 Mdot
.39032 .08579 Mdot
.39033 .08581 Mdot
.39034 .08582 Mdot
.39035 .08583 Mdot
.39036 .08584 Mdot
.39037 .08586 Mdot
.39038 .08587 Mdot
.39039 .08588 Mdot
.3904 .0859 Mdot
.39041 .08591 Mdot
.39042 .08592 Mdot
.39043 .08593 Mdot
.39044 .08595 Mdot
.39045 .08596 Mdot
.39046 .08597 Mdot
.39047 .08599 Mdot
.39048 .086 Mdot
.39049 .08601 Mdot
.3905 .08603 Mdot
.3905 .08604 Mdot
.39051 .08605 Mdot
.39052 .08606 Mdot
.39053 .08608 Mdot
.39054 .08609 Mdot
.39055 .0861 Mdot
.39056 .08612 Mdot
.39057 .08613 Mdot
.39058 .08614 Mdot
.39059 .08615 Mdot
.3906 .08617 Mdot
.39061 .08618 Mdot
.39062 .08619 Mdot
.39063 .08621 Mdot
.39064 .08622 Mdot
.39065 .08623 Mdot
.39066 .08625 Mdot
.39067 .08626 Mdot
.39068 .08627 Mdot
.39069 .08628 Mdot
.3907 .0863 Mdot
.3907 .08631 Mdot
.39071 .08632 Mdot
.39072 .08634 Mdot
.39073 .08635 Mdot
.39074 .08636 Mdot
.39075 .08637 Mdot
.39076 .08639 Mdot
.39077 .0864 Mdot
.39078 .08641 Mdot
.39079 .08643 Mdot
.3908 .08644 Mdot
.39081 .08645 Mdot
.39082 .08647 Mdot
.39083 .08648 Mdot
.39084 .08649 Mdot
.39085 .0865 Mdot
.39086 .08652 Mdot
.39087 .08653 Mdot
.39088 .08654 Mdot
.39089 .08656 Mdot
.3909 .08657 Mdot
.3909 .08658 Mdot
.39091 .0866 Mdot
.39092 .08661 Mdot
.39093 .08662 Mdot
.39094 .08663 Mdot
.39095 .08665 Mdot
.39096 .08666 Mdot
.39097 .08667 Mdot
.39098 .08669 Mdot
.39099 .0867 Mdot
.391 .08671 Mdot
.39101 .08673 Mdot
.39102 .08674 Mdot
.39103 .08675 Mdot
.39104 .08676 Mdot
.39105 .08678 Mdot
.39106 .08679 Mdot
.39107 .0868 Mdot
.39108 .08682 Mdot
.39109 .08683 Mdot
.3911 .08684 Mdot
.3911 .08686 Mdot
.39111 .08687 Mdot
.39112 .08688 Mdot
.39113 .08689 Mdot
.39114 .08691 Mdot
.39115 .08692 Mdot
.39116 .08693 Mdot
.39117 .08695 Mdot
.39118 .08696 Mdot
.39119 .08697 Mdot
.3912 .08699 Mdot
.39121 .087 Mdot
.39122 .08701 Mdot
.39123 .08702 Mdot
.39124 .08704 Mdot
.39125 .08705 Mdot
.39126 .08706 Mdot
.39127 .08708 Mdot
.39128 .08709 Mdot
.39129 .0871 Mdot
.3913 .08712 Mdot
.3913 .08713 Mdot
.39131 .08714 Mdot
.39132 .08715 Mdot
.39133 .08717 Mdot
.39134 .08718 Mdot
.39135 .08719 Mdot
.39136 .08721 Mdot
.39137 .08722 Mdot
.39138 .08723 Mdot
.39139 .08725 Mdot
.3914 .08726 Mdot
.39141 .08727 Mdot
.39142 .08728 Mdot
.39143 .0873 Mdot
.39144 .08731 Mdot
.39145 .08732 Mdot
.39146 .08734 Mdot
.39147 .08735 Mdot
.39148 .08736 Mdot
.39149 .08738 Mdot
.3915 .08739 Mdot
.3915 .0874 Mdot
.39151 .08742 Mdot
.39152 .08743 Mdot
.39153 .08744 Mdot
.39154 .08745 Mdot
.39155 .08747 Mdot
.39156 .08748 Mdot
.39157 .08749 Mdot
.39158 .08751 Mdot
.39159 .08752 Mdot
.3916 .08753 Mdot
.39161 .08755 Mdot
.39162 .08756 Mdot
.39163 .08757 Mdot
.39164 .08759 Mdot
.39165 .0876 Mdot
.39166 .08761 Mdot
.39167 .08762 Mdot
.39168 .08764 Mdot
.39169 .08765 Mdot
.3917 .08766 Mdot
.3917 .08768 Mdot
.39171 .08769 Mdot
.39172 .0877 Mdot
.39173 .08772 Mdot
.39174 .08773 Mdot
.39175 .08774 Mdot
.39176 .08776 Mdot
.39177 .08777 Mdot
.39178 .08778 Mdot
.39179 .08779 Mdot
.3918 .08781 Mdot
.39181 .08782 Mdot
.39182 .08783 Mdot
.39183 .08785 Mdot
.39184 .08786 Mdot
.39185 .08787 Mdot
.39186 .08789 Mdot
.39187 .0879 Mdot
.39188 .08791 Mdot
.39189 .08793 Mdot
.3919 .08794 Mdot
.3919 .08795 Mdot
.39191 .08796 Mdot
.39192 .08798 Mdot
.39193 .08799 Mdot
.39194 .088 Mdot
.39195 .08802 Mdot
.39196 .08803 Mdot
.39197 .08804 Mdot
.39198 .08806 Mdot
.39199 .08807 Mdot
.392 .08808 Mdot
.39201 .0881 Mdot
.39202 .08811 Mdot
.39203 .08812 Mdot
.39204 .08814 Mdot
.39205 .08815 Mdot
.39206 .08816 Mdot
.39207 .08817 Mdot
.39208 .08819 Mdot
.39209 .0882 Mdot
.3921 .08821 Mdot
.3921 .08823 Mdot
.39211 .08824 Mdot
.39212 .08825 Mdot
.39213 .08827 Mdot
.39214 .08828 Mdot
.39215 .08829 Mdot
.39216 .08831 Mdot
.39217 .08832 Mdot
.39218 .08833 Mdot
.39219 .08835 Mdot
.3922 .08836 Mdot
.39221 .08837 Mdot
.39222 .08838 Mdot
.39223 .0884 Mdot
.39224 .08841 Mdot
.39225 .08842 Mdot
.39226 .08844 Mdot
.39227 .08845 Mdot
.39228 .08846 Mdot
.39229 .08848 Mdot
.3923 .08849 Mdot
.3923 .0885 Mdot
.39231 .08852 Mdot
.39232 .08853 Mdot
.39233 .08854 Mdot
.39234 .08856 Mdot
.39235 .08857 Mdot
.39236 .08858 Mdot
.39237 .0886 Mdot
.39238 .08861 Mdot
.39239 .08862 Mdot
.3924 .08863 Mdot
.39241 .08865 Mdot
.39242 .08866 Mdot
.39243 .08867 Mdot
.39244 .08869 Mdot
.39245 .0887 Mdot
.39246 .08871 Mdot
.39247 .08873 Mdot
.39248 .08874 Mdot
.39249 .08875 Mdot
.3925 .08877 Mdot
.3925 .08878 Mdot
.39251 .08879 Mdot
.39252 .08881 Mdot
.39253 .08882 Mdot
.39254 .08883 Mdot
.39255 .08885 Mdot
.39256 .08886 Mdot
.39257 .08887 Mdot
.39258 .08889 Mdot
.39259 .0889 Mdot
.3926 .08891 Mdot
.39261 .08892 Mdot
.39262 .08894 Mdot
.39263 .08895 Mdot
.39264 .08896 Mdot
.39265 .08898 Mdot
.39266 .08899 Mdot
.39267 .089 Mdot
.39268 .08902 Mdot
.39269 .08903 Mdot
.3927 .08904 Mdot
.3927 .08906 Mdot
.39271 .08907 Mdot
.39272 .08908 Mdot
.39273 .0891 Mdot
.39274 .08911 Mdot
.39275 .08912 Mdot
.39276 .08914 Mdot
.39277 .08915 Mdot
.39278 .08916 Mdot
.39279 .08918 Mdot
.3928 .08919 Mdot
.39281 .0892 Mdot
.39282 .08922 Mdot
.39283 .08923 Mdot
.39284 .08924 Mdot
.39285 .08925 Mdot
.39286 .08927 Mdot
.39287 .08928 Mdot
.39288 .08929 Mdot
.39289 .08931 Mdot
.3929 .08932 Mdot
.3929 .08933 Mdot
.39291 .08935 Mdot
.39292 .08936 Mdot
.39293 .08937 Mdot
.39294 .08939 Mdot
.39295 .0894 Mdot
.39296 .08941 Mdot
.39297 .08943 Mdot
.39298 .08944 Mdot
.39299 .08945 Mdot
.393 .08947 Mdot
.39301 .08948 Mdot
.39302 .08949 Mdot
.39303 .08951 Mdot
.39304 .08952 Mdot
.39305 .08953 Mdot
.39306 .08955 Mdot
.39307 .08956 Mdot
.39308 .08957 Mdot
.39309 .08959 Mdot
.3931 .0896 Mdot
.3931 .08961 Mdot
.39311 .08963 Mdot
.39312 .08964 Mdot
.39313 .08965 Mdot
.39314 .08967 Mdot
.39315 .08968 Mdot
.39316 .08969 Mdot
.39317 .08971 Mdot
.39318 .08972 Mdot
.39319 .08973 Mdot
.3932 .08974 Mdot
.39321 .08976 Mdot
.39322 .08977 Mdot
.39323 .08978 Mdot
.39324 .0898 Mdot
.39325 .08981 Mdot
.39326 .08982 Mdot
.39327 .08984 Mdot
.39328 .08985 Mdot
.39329 .08986 Mdot
.3933 .08988 Mdot
.3933 .08989 Mdot
.39331 .0899 Mdot
.39332 .08992 Mdot
.39333 .08993 Mdot
.39334 .08994 Mdot
.39335 .08996 Mdot
.39336 .08997 Mdot
.39337 .08998 Mdot
.39338 .09 Mdot
.39339 .09001 Mdot
.3934 .09002 Mdot
.39341 .09004 Mdot
.39342 .09005 Mdot
.39343 .09006 Mdot
.39344 .09008 Mdot
.39345 .09009 Mdot
.39346 .0901 Mdot
.39347 .09012 Mdot
.39348 .09013 Mdot
.39349 .09014 Mdot
.3935 .09016 Mdot
.3935 .09017 Mdot
.39351 .09018 Mdot
.39352 .0902 Mdot
.39353 .09021 Mdot
.39354 .09022 Mdot
.39355 .09024 Mdot
.39356 .09025 Mdot
.39357 .09026 Mdot
.39358 .09028 Mdot
.39359 .09029 Mdot
.3936 .0903 Mdot
.39361 .09032 Mdot
.39362 .09033 Mdot
.39363 .09034 Mdot
.39364 .09036 Mdot
.39365 .09037 Mdot
.39366 .09038 Mdot
.39367 .0904 Mdot
.39368 .09041 Mdot
.39369 .09042 Mdot
.3937 .09044 Mdot
.3937 .09045 Mdot
.39371 .09046 Mdot
.39372 .09048 Mdot
.39373 .09049 Mdot
.39374 .0905 Mdot
.39375 .09052 Mdot
.39376 .09053 Mdot
.39377 .09054 Mdot
.39378 .09056 Mdot
.39379 .09057 Mdot
.3938 .09058 Mdot
.39381 .0906 Mdot
.39382 .09061 Mdot
.39383 .09062 Mdot
.39384 .09064 Mdot
.39385 .09065 Mdot
.39386 .09066 Mdot
.39387 .09068 Mdot
.39388 .09069 Mdot
.39389 .0907 Mdot
.3939 .09072 Mdot
.3939 .09073 Mdot
.39391 .09074 Mdot
.39392 .09076 Mdot
.39393 .09077 Mdot
.39394 .09078 Mdot
.39395 .0908 Mdot
.39396 .09081 Mdot
.39397 .09082 Mdot
.39398 .09084 Mdot
.39399 .09085 Mdot
.394 .09086 Mdot
.39401 .09088 Mdot
.39402 .09089 Mdot
.39403 .0909 Mdot
.39404 .09092 Mdot
.39405 .09093 Mdot
.39406 .09094 Mdot
.39407 .09096 Mdot
.39408 .09097 Mdot
.39409 .09098 Mdot
.3941 .091 Mdot
.3941 .09101 Mdot
.39411 .09102 Mdot
.39412 .09104 Mdot
.39413 .09105 Mdot
.39414 .09106 Mdot
.39415 .09108 Mdot
.39416 .09109 Mdot
.39417 .0911 Mdot
.39418 .09112 Mdot
.39419 .09113 Mdot
.3942 .09114 Mdot
.39421 .09116 Mdot
.39422 .09117 Mdot
.39423 .09118 Mdot
.39424 .0912 Mdot
.39425 .09121 Mdot
.39426 .09122 Mdot
.39427 .09124 Mdot
.39428 .09125 Mdot
.39429 .09126 Mdot
.3943 .09128 Mdot
.3943 .09129 Mdot
.39431 .0913 Mdot
.39432 .09132 Mdot
.39433 .09133 Mdot
.39434 .09135 Mdot
.39435 .09136 Mdot
.39436 .09137 Mdot
.39437 .09139 Mdot
.39438 .0914 Mdot
.39439 .09141 Mdot
.3944 .09143 Mdot
.39441 .09144 Mdot
.39442 .09145 Mdot
.39443 .09147 Mdot
.39444 .09148 Mdot
.39445 .09149 Mdot
.39446 .09151 Mdot
.39447 .09152 Mdot
.39448 .09153 Mdot
.39449 .09155 Mdot
.3945 .09156 Mdot
.3945 .09157 Mdot
.39451 .09159 Mdot
.39452 .0916 Mdot
.39453 .09161 Mdot
.39454 .09163 Mdot
.39455 .09164 Mdot
.39456 .09165 Mdot
.39457 .09167 Mdot
.39458 .09168 Mdot
.39459 .09169 Mdot
.3946 .09171 Mdot
.39461 .09172 Mdot
.39462 .09173 Mdot
.39463 .09175 Mdot
.39464 .09176 Mdot
.39465 .09177 Mdot
.39466 .09179 Mdot
.39467 .0918 Mdot
.39468 .09182 Mdot
.39469 .09183 Mdot
.3947 .09184 Mdot
.3947 .09186 Mdot
.39471 .09187 Mdot
.39472 .09188 Mdot
.39473 .0919 Mdot
.39474 .09191 Mdot
.39475 .09192 Mdot
.39476 .09194 Mdot
.39477 .09195 Mdot
.39478 .09196 Mdot
.39479 .09198 Mdot
.3948 .09199 Mdot
.39481 .092 Mdot
.39482 .09202 Mdot
.39483 .09203 Mdot
.39484 .09204 Mdot
.39485 .09206 Mdot
.39486 .09207 Mdot
.39487 .09208 Mdot
.39488 .0921 Mdot
.39489 .09211 Mdot
.3949 .09212 Mdot
.3949 .09214 Mdot
.39491 .09215 Mdot
.39492 .09217 Mdot
.39493 .09218 Mdot
.39494 .09219 Mdot
.39495 .09221 Mdot
.39496 .09222 Mdot
.39497 .09223 Mdot
.39498 .09225 Mdot
.39499 .09226 Mdot
.395 .09227 Mdot
.39501 .09229 Mdot
.39502 .0923 Mdot
.39503 .09231 Mdot
.39504 .09233 Mdot
.39505 .09234 Mdot
.39506 .09235 Mdot
.39507 .09237 Mdot
.39508 .09238 Mdot
.39509 .09239 Mdot
.3951 .09241 Mdot
.3951 .09242 Mdot
.39511 .09244 Mdot
.39512 .09245 Mdot
.39513 .09246 Mdot
.39514 .09248 Mdot
.39515 .09249 Mdot
.39516 .0925 Mdot
.39517 .09252 Mdot
.39518 .09253 Mdot
.39519 .09254 Mdot
.3952 .09256 Mdot
.39521 .09257 Mdot
.39522 .09258 Mdot
.39523 .0926 Mdot
.39524 .09261 Mdot
.39525 .09262 Mdot
.39526 .09264 Mdot
.39527 .09265 Mdot
.39528 .09266 Mdot
.39529 .09268 Mdot
.3953 .09269 Mdot
.3953 .09271 Mdot
.39531 .09272 Mdot
.39532 .09273 Mdot
.39533 .09275 Mdot
.39534 .09276 Mdot
.39535 .09277 Mdot
.39536 .09279 Mdot
.39537 .0928 Mdot
.39538 .09281 Mdot
.39539 .09283 Mdot
.3954 .09284 Mdot
.39541 .09285 Mdot
.39542 .09287 Mdot
.39543 .09288 Mdot
.39544 .09289 Mdot
.39545 .09291 Mdot
.39546 .09292 Mdot
.39547 .09294 Mdot
.39548 .09295 Mdot
.39549 .09296 Mdot
.3955 .09298 Mdot
.3955 .09299 Mdot
.39551 .093 Mdot
.39552 .09302 Mdot
.39553 .09303 Mdot
.39554 .09304 Mdot
.39555 .09306 Mdot
.39556 .09307 Mdot
.39557 .09308 Mdot
.39558 .0931 Mdot
.39559 .09311 Mdot
.3956 .09313 Mdot
.39561 .09314 Mdot
.39562 .09315 Mdot
.39563 .09317 Mdot
.39564 .09318 Mdot
.39565 .09319 Mdot
.39566 .09321 Mdot
.39567 .09322 Mdot
.39568 .09323 Mdot
.39569 .09325 Mdot
.3957 .09326 Mdot
.3957 .09327 Mdot
.39571 .09329 Mdot
.39572 .0933 Mdot
.39573 .09332 Mdot
.39574 .09333 Mdot
.39575 .09334 Mdot
.39576 .09336 Mdot
.39577 .09337 Mdot
.39578 .09338 Mdot
.39579 .0934 Mdot
.3958 .09341 Mdot
.39581 .09342 Mdot
.39582 .09344 Mdot
.39583 .09345 Mdot
.39584 .09346 Mdot
.39585 .09348 Mdot
.39586 .09349 Mdot
.39587 .09351 Mdot
.39588 .09352 Mdot
.39589 .09353 Mdot
.3959 .09355 Mdot
.3959 .09356 Mdot
.39591 .09357 Mdot
.39592 .09359 Mdot
.39593 .0936 Mdot
.39594 .09361 Mdot
.39595 .09363 Mdot
.39596 .09364 Mdot
.39597 .09366 Mdot
.39598 .09367 Mdot
.39599 .09368 Mdot
.396 .0937 Mdot
.39601 .09371 Mdot
.39602 .09372 Mdot
.39603 .09374 Mdot
.39604 .09375 Mdot
.39605 .09376 Mdot
.39606 .09378 Mdot
.39607 .09379 Mdot
.39608 .09381 Mdot
.39609 .09382 Mdot
.3961 .09383 Mdot
.3961 .09385 Mdot
.39611 .09386 Mdot
.39612 .09387 Mdot
.39613 .09389 Mdot
.39614 .0939 Mdot
.39615 .09391 Mdot
.39616 .09393 Mdot
.39617 .09394 Mdot
.39618 .09395 Mdot
.39619 .09397 Mdot
.3962 .09398 Mdot
.39621 .094 Mdot
.39622 .09401 Mdot
.39623 .09402 Mdot
.39624 .09404 Mdot
.39625 .09405 Mdot
.39626 .09406 Mdot
.39627 .09408 Mdot
.39628 .09409 Mdot
.39629 .09411 Mdot
.3963 .09412 Mdot
.3963 .09413 Mdot
.39631 .09415 Mdot
.39632 .09416 Mdot
.39633 .09417 Mdot
.39634 .09419 Mdot
.39635 .0942 Mdot
.39636 .09421 Mdot
.39637 .09423 Mdot
.39638 .09424 Mdot
.39639 .09426 Mdot
.3964 .09427 Mdot
.39641 .09428 Mdot
.39642 .0943 Mdot
.39643 .09431 Mdot
.39644 .09432 Mdot
.39645 .09434 Mdot
.39646 .09435 Mdot
.39647 .09436 Mdot
.39648 .09438 Mdot
.39649 .09439 Mdot
.3965 .09441 Mdot
.3965 .09442 Mdot
.39651 .09443 Mdot
.39652 .09445 Mdot
.39653 .09446 Mdot
.39654 .09447 Mdot
.39655 .09449 Mdot
.39656 .0945 Mdot
.39657 .09452 Mdot
.39658 .09453 Mdot
.39659 .09454 Mdot
.3966 .09456 Mdot
.39661 .09457 Mdot
.39662 .09458 Mdot
.39663 .0946 Mdot
.39664 .09461 Mdot
.39665 .09462 Mdot
.39666 .09464 Mdot
.39667 .09465 Mdot
.39668 .09467 Mdot
.39669 .09468 Mdot
.3967 .09469 Mdot
.3967 .09471 Mdot
.39671 .09472 Mdot
.39672 .09473 Mdot
.39673 .09475 Mdot
.39674 .09476 Mdot
.39675 .09478 Mdot
.39676 .09479 Mdot
.39677 .0948 Mdot
.39678 .09482 Mdot
.39679 .09483 Mdot
.3968 .09484 Mdot
.39681 .09486 Mdot
.39682 .09487 Mdot
.39683 .09488 Mdot
.39684 .0949 Mdot
.39685 .09491 Mdot
.39686 .09493 Mdot
.39687 .09494 Mdot
.39688 .09495 Mdot
.39689 .09497 Mdot
.3969 .09498 Mdot
.3969 .09499 Mdot
.39691 .09501 Mdot
.39692 .09502 Mdot
.39693 .09504 Mdot
.39694 .09505 Mdot
.39695 .09506 Mdot
.39696 .09508 Mdot
.39697 .09509 Mdot
.39698 .0951 Mdot
.39699 .09512 Mdot
.397 .09513 Mdot
.39701 .09515 Mdot
.39702 .09516 Mdot
.39703 .09517 Mdot
.39704 .09519 Mdot
.39705 .0952 Mdot
.39706 .09521 Mdot
.39707 .09523 Mdot
.39708 .09524 Mdot
.39709 .09526 Mdot
.3971 .09527 Mdot
.3971 .09528 Mdot
.39711 .0953 Mdot
.39712 .09531 Mdot
.39713 .09532 Mdot
.39714 .09534 Mdot
.39715 .09535 Mdot
.39716 .09537 Mdot
.39717 .09538 Mdot
.39718 .09539 Mdot
.39719 .09541 Mdot
.3972 .09542 Mdot
.39721 .09543 Mdot
.39722 .09545 Mdot
.39723 .09546 Mdot
.39724 .09548 Mdot
.39725 .09549 Mdot
.39726 .0955 Mdot
.39727 .09552 Mdot
.39728 .09553 Mdot
.39729 .09554 Mdot
.3973 .09556 Mdot
.3973 .09557 Mdot
.39731 .09559 Mdot
.39732 .0956 Mdot
.39733 .09561 Mdot
.39734 .09563 Mdot
.39735 .09564 Mdot
.39736 .09565 Mdot
.39737 .09567 Mdot
.39738 .09568 Mdot
.39739 .0957 Mdot
.3974 .09571 Mdot
.39741 .09572 Mdot
.39742 .09574 Mdot
.39743 .09575 Mdot
.39744 .09577 Mdot
.39745 .09578 Mdot
.39746 .09579 Mdot
.39747 .09581 Mdot
.39748 .09582 Mdot
.39749 .09583 Mdot
.3975 .09585 Mdot
.3975 .09586 Mdot
.39751 .09588 Mdot
.39752 .09589 Mdot
.39753 .0959 Mdot
.39754 .09592 Mdot
.39755 .09593 Mdot
.39756 .09594 Mdot
.39757 .09596 Mdot
.39758 .09597 Mdot
.39759 .09599 Mdot
.3976 .096 Mdot
.39761 .09601 Mdot
.39762 .09603 Mdot
.39763 .09604 Mdot
.39764 .09606 Mdot
.39765 .09607 Mdot
.39766 .09608 Mdot
.39767 .0961 Mdot
.39768 .09611 Mdot
.39769 .09612 Mdot
.3977 .09614 Mdot
.3977 .09615 Mdot
.39771 .09617 Mdot
.39772 .09618 Mdot
.39773 .09619 Mdot
.39774 .09621 Mdot
.39775 .09622 Mdot
.39776 .09623 Mdot
.39777 .09625 Mdot
.39778 .09626 Mdot
.39779 .09628 Mdot
.3978 .09629 Mdot
.39781 .0963 Mdot
.39782 .09632 Mdot
.39783 .09633 Mdot
.39784 .09635 Mdot
.39785 .09636 Mdot
.39786 .09637 Mdot
.39787 .09639 Mdot
.39788 .0964 Mdot
.39789 .09641 Mdot
.3979 .09643 Mdot
.3979 .09644 Mdot
.39791 .09646 Mdot
.39792 .09647 Mdot
.39793 .09648 Mdot
.39794 .0965 Mdot
.39795 .09651 Mdot
.39796 .09653 Mdot
.39797 .09654 Mdot
.39798 .09655 Mdot
.39799 .09657 Mdot
.398 .09658 Mdot
.39801 .09659 Mdot
.39802 .09661 Mdot
.39803 .09662 Mdot
.39804 .09664 Mdot
.39805 .09665 Mdot
.39806 .09666 Mdot
.39807 .09668 Mdot
.39808 .09669 Mdot
.39809 .09671 Mdot
.3981 .09672 Mdot
.3981 .09673 Mdot
.39811 .09675 Mdot
.39812 .09676 Mdot
.39813 .09678 Mdot
.39814 .09679 Mdot
.39815 .0968 Mdot
.39816 .09682 Mdot
.39817 .09683 Mdot
.39818 .09684 Mdot
.39819 .09686 Mdot
.3982 .09687 Mdot
.39821 .09689 Mdot
.39822 .0969 Mdot
.39823 .09691 Mdot
.39824 .09693 Mdot
.39825 .09694 Mdot
.39826 .09696 Mdot
.39827 .09697 Mdot
.39828 .09698 Mdot
.39829 .097 Mdot
.3983 .09701 Mdot
.3983 .09703 Mdot
.39831 .09704 Mdot
.39832 .09705 Mdot
.39833 .09707 Mdot
.39834 .09708 Mdot
.39835 .09709 Mdot
.39836 .09711 Mdot
.39837 .09712 Mdot
.39838 .09714 Mdot
.39839 .09715 Mdot
.3984 .09716 Mdot
.39841 .09718 Mdot
.39842 .09719 Mdot
.39843 .09721 Mdot
.39844 .09722 Mdot
.39845 .09723 Mdot
.39846 .09725 Mdot
.39847 .09726 Mdot
.39848 .09728 Mdot
.39849 .09729 Mdot
.3985 .0973 Mdot
.3985 .09732 Mdot
.39851 .09733 Mdot
.39852 .09735 Mdot
.39853 .09736 Mdot
.39854 .09737 Mdot
.39855 .09739 Mdot
.39856 .0974 Mdot
.39857 .09741 Mdot
.39858 .09743 Mdot
.39859 .09744 Mdot
.3986 .09746 Mdot
.39861 .09747 Mdot
.39862 .09748 Mdot
.39863 .0975 Mdot
.39864 .09751 Mdot
.39865 .09753 Mdot
.39866 .09754 Mdot
.39867 .09755 Mdot
.39868 .09757 Mdot
.39869 .09758 Mdot
.3987 .0976 Mdot
.3987 .09761 Mdot
.39871 .09762 Mdot
.39872 .09764 Mdot
.39873 .09765 Mdot
.39874 .09767 Mdot
.39875 .09768 Mdot
.39876 .09769 Mdot
.39877 .09771 Mdot
.39878 .09772 Mdot
.39879 .09774 Mdot
.3988 .09775 Mdot
.39881 .09776 Mdot
.39882 .09778 Mdot
.39883 .09779 Mdot
.39884 .09781 Mdot
.39885 .09782 Mdot
.39886 .09783 Mdot
.39887 .09785 Mdot
.39888 .09786 Mdot
.39889 .09788 Mdot
.3989 .09789 Mdot
.3989 .0979 Mdot
.39891 .09792 Mdot
.39892 .09793 Mdot
.39893 .09795 Mdot
.39894 .09796 Mdot
.39895 .09797 Mdot
.39896 .09799 Mdot
.39897 .098 Mdot
.39898 .09802 Mdot
.39899 .09803 Mdot
.399 .09804 Mdot
.39901 .09806 Mdot
.39902 .09807 Mdot
.39903 .09809 Mdot
.39904 .0981 Mdot
.39905 .09811 Mdot
.39906 .09813 Mdot
.39907 .09814 Mdot
.39908 .09816 Mdot
.39909 .09817 Mdot
.3991 .09818 Mdot
.3991 .0982 Mdot
.39911 .09821 Mdot
.39912 .09823 Mdot
.39913 .09824 Mdot
.39914 .09825 Mdot
.39915 .09827 Mdot
.39916 .09828 Mdot
.39917 .0983 Mdot
.39918 .09831 Mdot
.39919 .09832 Mdot
.3992 .09834 Mdot
.39921 .09835 Mdot
.39922 .09837 Mdot
.39923 .09838 Mdot
.39924 .09839 Mdot
.39925 .09841 Mdot
.39926 .09842 Mdot
.39927 .09844 Mdot
.39928 .09845 Mdot
.39929 .09846 Mdot
.3993 .09848 Mdot
.3993 .09849 Mdot
.39931 .09851 Mdot
.39932 .09852 Mdot
.39933 .09853 Mdot
.39934 .09855 Mdot
.39935 .09856 Mdot
.39936 .09858 Mdot
.39937 .09859 Mdot
.39938 .0986 Mdot
.39939 .09862 Mdot
.3994 .09863 Mdot
.39941 .09865 Mdot
.39942 .09866 Mdot
.39943 .09867 Mdot
.39944 .09869 Mdot
.39945 .0987 Mdot
.39946 .09872 Mdot
.39947 .09873 Mdot
.39948 .09874 Mdot
.39949 .09876 Mdot
.3995 .09877 Mdot
.3995 .09879 Mdot
.39951 .0988 Mdot
.39952 .09881 Mdot
.39953 .09883 Mdot
.39954 .09884 Mdot
.39955 .09886 Mdot
.39956 .09887 Mdot
.39957 .09888 Mdot
.39958 .0989 Mdot
.39959 .09891 Mdot
.3996 .09893 Mdot
.39961 .09894 Mdot
.39962 .09895 Mdot
.39963 .09897 Mdot
.39964 .09898 Mdot
.39965 .099 Mdot
.39966 .09901 Mdot
.39967 .09903 Mdot
.39968 .09904 Mdot
.39969 .09905 Mdot
.3997 .09907 Mdot
.3997 .09908 Mdot
.39971 .0991 Mdot
.39972 .09911 Mdot
.39973 .09912 Mdot
.39974 .09914 Mdot
.39975 .09915 Mdot
.39976 .09917 Mdot
.39977 .09918 Mdot
.39978 .09919 Mdot
.39979 .09921 Mdot
.3998 .09922 Mdot
.39981 .09924 Mdot
.39982 .09925 Mdot
.39983 .09926 Mdot
.39984 .09928 Mdot
.39985 .09929 Mdot
.39986 .09931 Mdot
.39987 .09932 Mdot
.39988 .09934 Mdot
.39989 .09935 Mdot
.3999 .09936 Mdot
.3999 .09938 Mdot
.39991 .09939 Mdot
.39992 .09941 Mdot
.39993 .09942 Mdot
.39994 .09943 Mdot
.39995 .09945 Mdot
.39996 .09946 Mdot
.39997 .09948 Mdot
.39998 .09949 Mdot
.39999 .0995 Mdot
.4 .09952 Mdot
.40001 .09953 Mdot
.40002 .09955 Mdot
.40003 .09956 Mdot
.40004 .09957 Mdot
.40005 .09959 Mdot
.40006 .0996 Mdot
.40007 .09962 Mdot
.40008 .09963 Mdot
.40009 .09965 Mdot
.4001 .09966 Mdot
.4001 .09967 Mdot
.40011 .09969 Mdot
.40012 .0997 Mdot
.40013 .09972 Mdot
.40014 .09973 Mdot
.40015 .09974 Mdot
.40016 .09976 Mdot
.40017 .09977 Mdot
.40018 .09979 Mdot
.40019 .0998 Mdot
.4002 .09981 Mdot
.40021 .09983 Mdot
.40022 .09984 Mdot
.40023 .09986 Mdot
.40024 .09987 Mdot
.40025 .09989 Mdot
.40026 .0999 Mdot
.40027 .09991 Mdot
.40028 .09993 Mdot
.40029 .09994 Mdot
.4003 .09996 Mdot
.4003 .09997 Mdot
.40031 .09998 Mdot
.40032 .1 Mdot
.40033 .10001 Mdot
.40034 .10003 Mdot
.40035 .10004 Mdot
.40036 .10006 Mdot
.40037 .10007 Mdot
.40038 .10008 Mdot
.40039 .1001 Mdot
.4004 .10011 Mdot
.40041 .10013 Mdot
.40042 .10014 Mdot
.40043 .10015 Mdot
.40044 .10017 Mdot
.40045 .10018 Mdot
.40046 .1002 Mdot
.40047 .10021 Mdot
.40048 .10023 Mdot
.40049 .10024 Mdot
.4005 .10025 Mdot
.4005 .10027 Mdot
.40051 .10028 Mdot
.40052 .1003 Mdot
.40053 .10031 Mdot
.40054 .10032 Mdot
.40055 .10034 Mdot
.40056 .10035 Mdot
.40057 .10037 Mdot
.40058 .10038 Mdot
.40059 .1004 Mdot
.4006 .10041 Mdot
.40061 .10042 Mdot
.40062 .10044 Mdot
.40063 .10045 Mdot
.40064 .10047 Mdot
.40065 .10048 Mdot
.40066 .10049 Mdot
.40067 .10051 Mdot
.40068 .10052 Mdot
.40069 .10054 Mdot
.4007 .10055 Mdot
.4007 .10057 Mdot
.40071 .10058 Mdot
.40072 .10059 Mdot
.40073 .10061 Mdot
.40074 .10062 Mdot
.40075 .10064 Mdot
.40076 .10065 Mdot
.40077 .10067 Mdot
.40078 .10068 Mdot
.40079 .10069 Mdot
.4008 .10071 Mdot
.40081 .10072 Mdot
.40082 .10074 Mdot
.40083 .10075 Mdot
.40084 .10076 Mdot
.40085 .10078 Mdot
.40086 .10079 Mdot
.40087 .10081 Mdot
.40088 .10082 Mdot
.40089 .10084 Mdot
.4009 .10085 Mdot
.4009 .10086 Mdot
.40091 .10088 Mdot
.40092 .10089 Mdot
.40093 .10091 Mdot
.40094 .10092 Mdot
.40095 .10094 Mdot
.40096 .10095 Mdot
.40097 .10096 Mdot
.40098 .10098 Mdot
.40099 .10099 Mdot
.401 .10101 Mdot
.40101 .10102 Mdot
.40102 .10104 Mdot
.40103 .10105 Mdot
.40104 .10106 Mdot
.40105 .10108 Mdot
.40106 .10109 Mdot
.40107 .10111 Mdot
.40108 .10112 Mdot
.40109 .10113 Mdot
.4011 .10115 Mdot
.4011 .10116 Mdot
.40111 .10118 Mdot
.40112 .10119 Mdot
.40113 .10121 Mdot
.40114 .10122 Mdot
.40115 .10123 Mdot
.40116 .10125 Mdot
.40117 .10126 Mdot
.40118 .10128 Mdot
.40119 .10129 Mdot
.4012 .10131 Mdot
.40121 .10132 Mdot
.40122 .10133 Mdot
.40123 .10135 Mdot
.40124 .10136 Mdot
.40125 .10138 Mdot
.40126 .10139 Mdot
.40127 .10141 Mdot
.40128 .10142 Mdot
.40129 .10143 Mdot
.4013 .10145 Mdot
.4013 .10146 Mdot
.40131 .10148 Mdot
.40132 .10149 Mdot
.40133 .10151 Mdot
.40134 .10152 Mdot
.40135 .10153 Mdot
.40136 .10155 Mdot
.40137 .10156 Mdot
.40138 .10158 Mdot
.40139 .10159 Mdot
.4014 .10161 Mdot
.40141 .10162 Mdot
.40142 .10163 Mdot
.40143 .10165 Mdot
.40144 .10166 Mdot
.40145 .10168 Mdot
.40146 .10169 Mdot
.40147 .10171 Mdot
.40148 .10172 Mdot
.40149 .10173 Mdot
.4015 .10175 Mdot
.4015 .10176 Mdot
.40151 .10178 Mdot
.40152 .10179 Mdot
.40153 .10181 Mdot
.40154 .10182 Mdot
.40155 .10183 Mdot
.40156 .10185 Mdot
.40157 .10186 Mdot
.40158 .10188 Mdot
.40159 .10189 Mdot
.4016 .10191 Mdot
.40161 .10192 Mdot
.40162 .10193 Mdot
.40163 .10195 Mdot
.40164 .10196 Mdot
.40165 .10198 Mdot
.40166 .10199 Mdot
.40167 .10201 Mdot
.40168 .10202 Mdot
.40169 .10203 Mdot
.4017 .10205 Mdot
.4017 .10206 Mdot
.40171 .10208 Mdot
.40172 .10209 Mdot
.40173 .10211 Mdot
.40174 .10212 Mdot
.40175 .10213 Mdot
.40176 .10215 Mdot
.40177 .10216 Mdot
.40178 .10218 Mdot
.40179 .10219 Mdot
.4018 .10221 Mdot
.40181 .10222 Mdot
.40182 .10224 Mdot
.40183 .10225 Mdot
.40184 .10226 Mdot
.40185 .10228 Mdot
.40186 .10229 Mdot
.40187 .10231 Mdot
.40188 .10232 Mdot
.40189 .10234 Mdot
.4019 .10235 Mdot
.4019 .10236 Mdot
.40191 .10238 Mdot
.40192 .10239 Mdot
.40193 .10241 Mdot
.40194 .10242 Mdot
.40195 .10244 Mdot
.40196 .10245 Mdot
.40197 .10246 Mdot
.40198 .10248 Mdot
.40199 .10249 Mdot
.402 .10251 Mdot
.40201 .10252 Mdot
.40202 .10254 Mdot
.40203 .10255 Mdot
.40204 .10257 Mdot
.40205 .10258 Mdot
.40206 .10259 Mdot
.40207 .10261 Mdot
.40208 .10262 Mdot
.40209 .10264 Mdot
.4021 .10265 Mdot
.4021 .10267 Mdot
.40211 .10268 Mdot
.40212 .10269 Mdot
.40213 .10271 Mdot
.40214 .10272 Mdot
.40215 .10274 Mdot
.40216 .10275 Mdot
.40217 .10277 Mdot
.40218 .10278 Mdot
.40219 .1028 Mdot
.4022 .10281 Mdot
.40221 .10282 Mdot
.40222 .10284 Mdot
.40223 .10285 Mdot
.40224 .10287 Mdot
.40225 .10288 Mdot
.40226 .1029 Mdot
.40227 .10291 Mdot
.40228 .10292 Mdot
.40229 .10294 Mdot
.4023 .10295 Mdot
.4023 .10297 Mdot
.40231 .10298 Mdot
.40232 .103 Mdot
.40233 .10301 Mdot
.40234 .10303 Mdot
.40235 .10304 Mdot
.40236 .10305 Mdot
.40237 .10307 Mdot
.40238 .10308 Mdot
.40239 .1031 Mdot
.4024 .10311 Mdot
.40241 .10313 Mdot
.40242 .10314 Mdot
.40243 .10316 Mdot
.40244 .10317 Mdot
.40245 .10318 Mdot
.40246 .1032 Mdot
.40247 .10321 Mdot
.40248 .10323 Mdot
.40249 .10324 Mdot
.4025 .10326 Mdot
.4025 .10327 Mdot
.40251 .10328 Mdot
.40252 .1033 Mdot
.40253 .10331 Mdot
.40254 .10333 Mdot
.40255 .10334 Mdot
.40256 .10336 Mdot
.40257 .10337 Mdot
.40258 .10339 Mdot
.40259 .1034 Mdot
.4026 .10341 Mdot
.40261 .10343 Mdot
.40262 .10344 Mdot
.40263 .10346 Mdot
.40264 .10347 Mdot
.40265 .10349 Mdot
.40266 .1035 Mdot
.40267 .10352 Mdot
.40268 .10353 Mdot
.40269 .10354 Mdot
.4027 .10356 Mdot
.4027 .10357 Mdot
.40271 .10359 Mdot
.40272 .1036 Mdot
.40273 .10362 Mdot
.40274 .10363 Mdot
.40275 .10365 Mdot
.40276 .10366 Mdot
.40277 .10367 Mdot
.40278 .10369 Mdot
.40279 .1037 Mdot
.4028 .10372 Mdot
.40281 .10373 Mdot
.40282 .10375 Mdot
.40283 .10376 Mdot
.40284 .10378 Mdot
.40285 .10379 Mdot
.40286 .1038 Mdot
.40287 .10382 Mdot
.40288 .10383 Mdot
.40289 .10385 Mdot
.4029 .10386 Mdot
.4029 .10388 Mdot
.40291 .10389 Mdot
.40292 .10391 Mdot
.40293 .10392 Mdot
.40294 .10394 Mdot
.40295 .10395 Mdot
.40296 .10396 Mdot
.40297 .10398 Mdot
.40298 .10399 Mdot
.40299 .10401 Mdot
.403 .10402 Mdot
.40301 .10404 Mdot
.40302 .10405 Mdot
.40303 .10407 Mdot
.40304 .10408 Mdot
.40305 .10409 Mdot
.40306 .10411 Mdot
.40307 .10412 Mdot
.40308 .10414 Mdot
.40309 .10415 Mdot
.4031 .10417 Mdot
.4031 .10418 Mdot
.40311 .1042 Mdot
.40312 .10421 Mdot
.40313 .10422 Mdot
.40314 .10424 Mdot
.40315 .10425 Mdot
.40316 .10427 Mdot
.40317 .10428 Mdot
.40318 .1043 Mdot
.40319 .10431 Mdot
.4032 .10433 Mdot
.40321 .10434 Mdot
.40322 .10436 Mdot
.40323 .10437 Mdot
.40324 .10438 Mdot
.40325 .1044 Mdot
.40326 .10441 Mdot
.40327 .10443 Mdot
.40328 .10444 Mdot
.40329 .10446 Mdot
.4033 .10447 Mdot
.4033 .10449 Mdot
.40331 .1045 Mdot
.40332 .10452 Mdot
.40333 .10453 Mdot
.40334 .10454 Mdot
.40335 .10456 Mdot
.40336 .10457 Mdot
.40337 .10459 Mdot
.40338 .1046 Mdot
.40339 .10462 Mdot
.4034 .10463 Mdot
.40341 .10465 Mdot
.40342 .10466 Mdot
.40343 .10468 Mdot
.40344 .10469 Mdot
.40345 .1047 Mdot
.40346 .10472 Mdot
.40347 .10473 Mdot
.40348 .10475 Mdot
.40349 .10476 Mdot
.4035 .10478 Mdot
.4035 .10479 Mdot
.40351 .10481 Mdot
.40352 .10482 Mdot
.40353 .10484 Mdot
.40354 .10485 Mdot
.40355 .10486 Mdot
.40356 .10488 Mdot
.40357 .10489 Mdot
.40358 .10491 Mdot
.40359 .10492 Mdot
.4036 .10494 Mdot
.40361 .10495 Mdot
.40362 .10497 Mdot
.40363 .10498 Mdot
.40364 .105 Mdot
.40365 .10501 Mdot
.40366 .10502 Mdot
.40367 .10504 Mdot
.40368 .10505 Mdot
.40369 .10507 Mdot
.4037 .10508 Mdot
.4037 .1051 Mdot
.40371 .10511 Mdot
.40372 .10513 Mdot
.40373 .10514 Mdot
.40374 .10516 Mdot
.40375 .10517 Mdot
.40376 .10518 Mdot
.40377 .1052 Mdot
.40378 .10521 Mdot
.40379 .10523 Mdot
.4038 .10524 Mdot
.40381 .10526 Mdot
.40382 .10527 Mdot
.40383 .10529 Mdot
.40384 .1053 Mdot
.40385 .10532 Mdot
.40386 .10533 Mdot
.40387 .10534 Mdot
.40388 .10536 Mdot
.40389 .10537 Mdot
.4039 .10539 Mdot
.4039 .1054 Mdot
.40391 .10542 Mdot
.40392 .10543 Mdot
.40393 .10545 Mdot
.40394 .10546 Mdot
.40395 .10548 Mdot
.40396 .10549 Mdot
.40397 .10551 Mdot
.40398 .10552 Mdot
.40399 .10553 Mdot
.404 .10555 Mdot
.40401 .10556 Mdot
.40402 .10558 Mdot
.40403 .10559 Mdot
.40404 .10561 Mdot
.40405 .10562 Mdot
.40406 .10564 Mdot
.40407 .10565 Mdot
.40408 .10567 Mdot
.40409 .10568 Mdot
.4041 .1057 Mdot
.4041 .10571 Mdot
.40411 .10572 Mdot
.40412 .10574 Mdot
.40413 .10575 Mdot
.40414 .10577 Mdot
.40415 .10578 Mdot
.40416 .1058 Mdot
.40417 .10581 Mdot
.40418 .10583 Mdot
.40419 .10584 Mdot
.4042 .10586 Mdot
.40421 .10587 Mdot
.40422 .10589 Mdot
.40423 .1059 Mdot
.40424 .10591 Mdot
.40425 .10593 Mdot
.40426 .10594 Mdot
.40427 .10596 Mdot
.40428 .10597 Mdot
.40429 .10599 Mdot
.4043 .106 Mdot
.4043 .10602 Mdot
.40431 .10603 Mdot
.40432 .10605 Mdot
.40433 .10606 Mdot
.40434 .10608 Mdot
.40435 .10609 Mdot
.40436 .10611 Mdot
.40437 .10612 Mdot
.40438 .10613 Mdot
.40439 .10615 Mdot
.4044 .10616 Mdot
.40441 .10618 Mdot
.40442 .10619 Mdot
.40443 .10621 Mdot
.40444 .10622 Mdot
.40445 .10624 Mdot
.40446 .10625 Mdot
.40447 .10627 Mdot
.40448 .10628 Mdot
.40449 .1063 Mdot
.4045 .10631 Mdot
.4045 .10633 Mdot
.40451 .10634 Mdot
.40452 .10635 Mdot
.40453 .10637 Mdot
.40454 .10638 Mdot
.40455 .1064 Mdot
.40456 .10641 Mdot
.40457 .10643 Mdot
.40458 .10644 Mdot
.40459 .10646 Mdot
.4046 .10647 Mdot
.40461 .10649 Mdot
.40462 .1065 Mdot
.40463 .10652 Mdot
.40464 .10653 Mdot
.40465 .10655 Mdot
.40466 .10656 Mdot
.40467 .10657 Mdot
.40468 .10659 Mdot
.40469 .1066 Mdot
.4047 .10662 Mdot
.4047 .10663 Mdot
.40471 .10665 Mdot
.40472 .10666 Mdot
.40473 .10668 Mdot
.40474 .10669 Mdot
.40475 .10671 Mdot
.40476 .10672 Mdot
.40477 .10674 Mdot
.40478 .10675 Mdot
.40479 .10677 Mdot
.4048 .10678 Mdot
.40481 .1068 Mdot
.40482 .10681 Mdot
.40483 .10682 Mdot
.40484 .10684 Mdot
.40485 .10685 Mdot
.40486 .10687 Mdot
.40487 .10688 Mdot
.40488 .1069 Mdot
.40489 .10691 Mdot
.4049 .10693 Mdot
.4049 .10694 Mdot
.40491 .10696 Mdot
.40492 .10697 Mdot
.40493 .10699 Mdot
.40494 .107 Mdot
.40495 .10702 Mdot
.40496 .10703 Mdot
.40497 .10705 Mdot
.40498 .10706 Mdot
.40499 .10707 Mdot
.405 .10709 Mdot
.40501 .1071 Mdot
.40502 .10712 Mdot
.40503 .10713 Mdot
.40504 .10715 Mdot
.40505 .10716 Mdot
.40506 .10718 Mdot
.40507 .10719 Mdot
.40508 .10721 Mdot
.40509 .10722 Mdot
.4051 .10724 Mdot
.4051 .10725 Mdot
.40511 .10727 Mdot
.40512 .10728 Mdot
.40513 .1073 Mdot
.40514 .10731 Mdot
.40515 .10733 Mdot
.40516 .10734 Mdot
.40517 .10736 Mdot
.40518 .10737 Mdot
.40519 .10738 Mdot
.4052 .1074 Mdot
.40521 .10741 Mdot
.40522 .10743 Mdot
.40523 .10744 Mdot
.40524 .10746 Mdot
.40525 .10747 Mdot
.40526 .10749 Mdot
.40527 .1075 Mdot
.40528 .10752 Mdot
.40529 .10753 Mdot
.4053 .10755 Mdot
.4053 .10756 Mdot
.40531 .10758 Mdot
.40532 .10759 Mdot
.40533 .10761 Mdot
.40534 .10762 Mdot
.40535 .10764 Mdot
.40536 .10765 Mdot
.40537 .10767 Mdot
.40538 .10768 Mdot
.40539 .10769 Mdot
.4054 .10771 Mdot
.40541 .10772 Mdot
.40542 .10774 Mdot
.40543 .10775 Mdot
.40544 .10777 Mdot
.40545 .10778 Mdot
.40546 .1078 Mdot
.40547 .10781 Mdot
.40548 .10783 Mdot
.40549 .10784 Mdot
.4055 .10786 Mdot
.4055 .10787 Mdot
.40551 .10789 Mdot
.40552 .1079 Mdot
.40553 .10792 Mdot
.40554 .10793 Mdot
.40555 .10795 Mdot
.40556 .10796 Mdot
.40557 .10798 Mdot
.40558 .10799 Mdot
.40559 .10801 Mdot
.4056 .10802 Mdot
.40561 .10803 Mdot
.40562 .10805 Mdot
.40563 .10806 Mdot
.40564 .10808 Mdot
.40565 .10809 Mdot
.40566 .10811 Mdot
.40567 .10812 Mdot
.40568 .10814 Mdot
.40569 .10815 Mdot
.4057 .10817 Mdot
.4057 .10818 Mdot
.40571 .1082 Mdot
.40572 .10821 Mdot
.40573 .10823 Mdot
.40574 .10824 Mdot
.40575 .10826 Mdot
.40576 .10827 Mdot
.40577 .10829 Mdot
.40578 .1083 Mdot
.40579 .10832 Mdot
.4058 .10833 Mdot
.40581 .10835 Mdot
.40582 .10836 Mdot
.40583 .10838 Mdot
.40584 .10839 Mdot
.40585 .10841 Mdot
.40586 .10842 Mdot
.40587 .10844 Mdot
.40588 .10845 Mdot
.40589 .10846 Mdot
.4059 .10848 Mdot
.4059 .10849 Mdot
.40591 .10851 Mdot
.40592 .10852 Mdot
.40593 .10854 Mdot
.40594 .10855 Mdot
.40595 .10857 Mdot
.40596 .10858 Mdot
.40597 .1086 Mdot
.40598 .10861 Mdot
.40599 .10863 Mdot
.406 .10864 Mdot
.40601 .10866 Mdot
.40602 .10867 Mdot
.40603 .10869 Mdot
.40604 .1087 Mdot
.40605 .10872 Mdot
.40606 .10873 Mdot
.40607 .10875 Mdot
.40608 .10876 Mdot
.40609 .10878 Mdot
.4061 .10879 Mdot
.4061 .10881 Mdot
.40611 .10882 Mdot
.40612 .10884 Mdot
.40613 .10885 Mdot
.40614 .10887 Mdot
.40615 .10888 Mdot
.40616 .1089 Mdot
.40617 .10891 Mdot
.40618 .10893 Mdot
.40619 .10894 Mdot
.4062 .10896 Mdot
.40621 .10897 Mdot
.40622 .10899 Mdot
.40623 .109 Mdot
.40624 .10901 Mdot
.40625 .10903 Mdot
.40626 .10904 Mdot
.40627 .10906 Mdot
.40628 .10907 Mdot
.40629 .10909 Mdot
.4063 .1091 Mdot
.4063 .10912 Mdot
.40631 .10913 Mdot
.40632 .10915 Mdot
.40633 .10916 Mdot
.40634 .10918 Mdot
.40635 .10919 Mdot
.40636 .10921 Mdot
.40637 .10922 Mdot
.40638 .10924 Mdot
.40639 .10925 Mdot
.4064 .10927 Mdot
.40641 .10928 Mdot
.40642 .1093 Mdot
.40643 .10931 Mdot
.40644 .10933 Mdot
.40645 .10934 Mdot
.40646 .10936 Mdot
.40647 .10937 Mdot
.40648 .10939 Mdot
.40649 .1094 Mdot
.4065 .10942 Mdot
.4065 .10943 Mdot
.40651 .10945 Mdot
.40652 .10946 Mdot
.40653 .10948 Mdot
.40654 .10949 Mdot
.40655 .10951 Mdot
.40656 .10952 Mdot
.40657 .10954 Mdot
.40658 .10955 Mdot
.40659 .10957 Mdot
.4066 .10958 Mdot
.40661 .1096 Mdot
.40662 .10961 Mdot
.40663 .10963 Mdot
.40664 .10964 Mdot
.40665 .10966 Mdot
.40666 .10967 Mdot
.40667 .10969 Mdot
.40668 .1097 Mdot
.40669 .10972 Mdot
.4067 .10973 Mdot
.4067 .10975 Mdot
.40671 .10976 Mdot
.40672 .10978 Mdot
.40673 .10979 Mdot
.40674 .10981 Mdot
.40675 .10982 Mdot
.40676 .10984 Mdot
.40677 .10985 Mdot
.40678 .10987 Mdot
.40679 .10988 Mdot
.4068 .1099 Mdot
.40681 .10991 Mdot
.40682 .10993 Mdot
.40683 .10994 Mdot
.40684 .10995 Mdot
.40685 .10997 Mdot
.40686 .10998 Mdot
.40687 .11 Mdot
.40688 .11001 Mdot
.40689 .11003 Mdot
.4069 .11004 Mdot
.4069 .11006 Mdot
.40691 .11007 Mdot
.40692 .11009 Mdot
.40693 .1101 Mdot
.40694 .11012 Mdot
.40695 .11013 Mdot
.40696 .11015 Mdot
.40697 .11016 Mdot
.40698 .11018 Mdot
.40699 .11019 Mdot
.407 .11021 Mdot
.40701 .11022 Mdot
.40702 .11024 Mdot
.40703 .11025 Mdot
.40704 .11027 Mdot
.40705 .11028 Mdot
.40706 .1103 Mdot
.40707 .11031 Mdot
.40708 .11033 Mdot
.40709 .11034 Mdot
.4071 .11036 Mdot
.4071 .11037 Mdot
.40711 .11039 Mdot
.40712 .1104 Mdot
.40713 .11042 Mdot
.40714 .11043 Mdot
.40715 .11045 Mdot
.40716 .11046 Mdot
.40717 .11048 Mdot
.40718 .11049 Mdot
.40719 .11051 Mdot
.4072 .11052 Mdot
.40721 .11054 Mdot
.40722 .11055 Mdot
.40723 .11057 Mdot
.40724 .11058 Mdot
.40725 .1106 Mdot
.40726 .11061 Mdot
.40727 .11063 Mdot
.40728 .11064 Mdot
.40729 .11066 Mdot
.4073 .11067 Mdot
.4073 .11069 Mdot
.40731 .1107 Mdot
.40732 .11072 Mdot
.40733 .11073 Mdot
.40734 .11075 Mdot
.40735 .11076 Mdot
.40736 .11078 Mdot
.40737 .11079 Mdot
.40738 .11081 Mdot
.40739 .11082 Mdot
.4074 .11084 Mdot
.40741 .11085 Mdot
.40742 .11087 Mdot
.40743 .11088 Mdot
.40744 .1109 Mdot
.40745 .11091 Mdot
.40746 .11093 Mdot
.40747 .11094 Mdot
.40748 .11096 Mdot
.40749 .11097 Mdot
.4075 .11099 Mdot
.4075 .11101 Mdot
.40751 .11102 Mdot
.40752 .11104 Mdot
.40753 .11105 Mdot
.40754 .11107 Mdot
.40755 .11108 Mdot
.40756 .1111 Mdot
.40757 .11111 Mdot
.40758 .11113 Mdot
.40759 .11114 Mdot
.4076 .11116 Mdot
.40761 .11117 Mdot
.40762 .11119 Mdot
.40763 .1112 Mdot
.40764 .11122 Mdot
.40765 .11123 Mdot
.40766 .11125 Mdot
.40767 .11126 Mdot
.40768 .11128 Mdot
.40769 .11129 Mdot
.4077 .11131 Mdot
.4077 .11132 Mdot
.40771 .11134 Mdot
.40772 .11135 Mdot
.40773 .11137 Mdot
.40774 .11138 Mdot
.40775 .1114 Mdot
.40776 .11141 Mdot
.40777 .11143 Mdot
.40778 .11144 Mdot
.40779 .11146 Mdot
.4078 .11147 Mdot
.40781 .11149 Mdot
.40782 .1115 Mdot
.40783 .11152 Mdot
.40784 .11153 Mdot
.40785 .11155 Mdot
.40786 .11156 Mdot
.40787 .11158 Mdot
.40788 .11159 Mdot
.40789 .11161 Mdot
.4079 .11162 Mdot
.4079 .11164 Mdot
.40791 .11165 Mdot
.40792 .11167 Mdot
.40793 .11168 Mdot
.40794 .1117 Mdot
.40795 .11171 Mdot
.40796 .11173 Mdot
.40797 .11174 Mdot
.40798 .11176 Mdot
.40799 .11177 Mdot
.408 .11179 Mdot
.40801 .1118 Mdot
.40802 .11182 Mdot
.40803 .11183 Mdot
.40804 .11185 Mdot
.40805 .11186 Mdot
.40806 .11188 Mdot
.40807 .11189 Mdot
.40808 .11191 Mdot
.40809 .11192 Mdot
.4081 .11194 Mdot
.4081 .11196 Mdot
.40811 .11197 Mdot
.40812 .11199 Mdot
.40813 .112 Mdot
.40814 .11202 Mdot
.40815 .11203 Mdot
.40816 .11205 Mdot
.40817 .11206 Mdot
.40818 .11208 Mdot
.40819 .11209 Mdot
.4082 .11211 Mdot
.40821 .11212 Mdot
.40822 .11214 Mdot
.40823 .11215 Mdot
.40824 .11217 Mdot
.40825 .11218 Mdot
.40826 .1122 Mdot
.40827 .11221 Mdot
.40828 .11223 Mdot
.40829 .11224 Mdot
.4083 .11226 Mdot
.4083 .11227 Mdot
.40831 .11229 Mdot
.40832 .1123 Mdot
.40833 .11232 Mdot
.40834 .11233 Mdot
.40835 .11235 Mdot
.40836 .11236 Mdot
.40837 .11238 Mdot
.40838 .11239 Mdot
.40839 .11241 Mdot
.4084 .11242 Mdot
.40841 .11244 Mdot
.40842 .11245 Mdot
.40843 .11247 Mdot
.40844 .11248 Mdot
.40845 .1125 Mdot
.40846 .11252 Mdot
.40847 .11253 Mdot
.40848 .11255 Mdot
.40849 .11256 Mdot
.4085 .11258 Mdot
.4085 .11259 Mdot
.40851 .11261 Mdot
.40852 .11262 Mdot
.40853 .11264 Mdot
.40854 .11265 Mdot
.40855 .11267 Mdot
.40856 .11268 Mdot
.40857 .1127 Mdot
.40858 .11271 Mdot
.40859 .11273 Mdot
.4086 .11274 Mdot
.40861 .11276 Mdot
.40862 .11277 Mdot
.40863 .11279 Mdot
.40864 .1128 Mdot
.40865 .11282 Mdot
.40866 .11283 Mdot
.40867 .11285 Mdot
.40868 .11286 Mdot
.40869 .11288 Mdot
.4087 .11289 Mdot
.4087 .11291 Mdot
.40871 .11292 Mdot
.40872 .11294 Mdot
.40873 .11296 Mdot
.40874 .11297 Mdot
.40875 .11299 Mdot
.40876 .113 Mdot
.40877 .11302 Mdot
.40878 .11303 Mdot
.40879 .11305 Mdot
.4088 .11306 Mdot
.40881 .11308 Mdot
.40882 .11309 Mdot
.40883 .11311 Mdot
.40884 .11312 Mdot
.40885 .11314 Mdot
.40886 .11315 Mdot
.40887 .11317 Mdot
.40888 .11318 Mdot
.40889 .1132 Mdot
.4089 .11321 Mdot
.4089 .11323 Mdot
.40891 .11324 Mdot
.40892 .11326 Mdot
.40893 .11327 Mdot
.40894 .11329 Mdot
.40895 .11331 Mdot
.40896 .11332 Mdot
.40897 .11334 Mdot
.40898 .11335 Mdot
.40899 .11337 Mdot
.409 .11338 Mdot
.40901 .1134 Mdot
.40902 .11341 Mdot
.40903 .11343 Mdot
.40904 .11344 Mdot
.40905 .11346 Mdot
.40906 .11347 Mdot
.40907 .11349 Mdot
.40908 .1135 Mdot
.40909 .11352 Mdot
.4091 .11353 Mdot
.4091 .11355 Mdot
.40911 .11356 Mdot
.40912 .11358 Mdot
.40913 .11359 Mdot
.40914 .11361 Mdot
.40915 .11362 Mdot
.40916 .11364 Mdot
.40917 .11366 Mdot
.40918 .11367 Mdot
.40919 .11369 Mdot
.4092 .1137 Mdot
.40921 .11372 Mdot
.40922 .11373 Mdot
.40923 .11375 Mdot
.40924 .11376 Mdot
.40925 .11378 Mdot
.40926 .11379 Mdot
.40927 .11381 Mdot
.40928 .11382 Mdot
.40929 .11384 Mdot
.4093 .11385 Mdot
.4093 .11387 Mdot
.40931 .11388 Mdot
.40932 .1139 Mdot
.40933 .11391 Mdot
.40934 .11393 Mdot
.40935 .11395 Mdot
.40936 .11396 Mdot
.40937 .11398 Mdot
.40938 .11399 Mdot
.40939 .11401 Mdot
.4094 .11402 Mdot
.40941 .11404 Mdot
.40942 .11405 Mdot
.40943 .11407 Mdot
.40944 .11408 Mdot
.40945 .1141 Mdot
.40946 .11411 Mdot
.40947 .11413 Mdot
.40948 .11414 Mdot
.40949 .11416 Mdot
.4095 .11417 Mdot
.4095 .11419 Mdot
.40951 .11421 Mdot
.40952 .11422 Mdot
.40953 .11424 Mdot
.40954 .11425 Mdot
.40955 .11427 Mdot
.40956 .11428 Mdot
.40957 .1143 Mdot
.40958 .11431 Mdot
.40959 .11433 Mdot
.4096 .11434 Mdot
.40961 .11436 Mdot
.40962 .11437 Mdot
.40963 .11439 Mdot
.40964 .1144 Mdot
.40965 .11442 Mdot
.40966 .11443 Mdot
.40967 .11445 Mdot
.40968 .11447 Mdot
.40969 .11448 Mdot
.4097 .1145 Mdot
.4097 .11451 Mdot
.40971 .11453 Mdot
.40972 .11454 Mdot
.40973 .11456 Mdot
.40974 .11457 Mdot
.40975 .11459 Mdot
.40976 .1146 Mdot
.40977 .11462 Mdot
.40978 .11463 Mdot
.40979 .11465 Mdot
.4098 .11466 Mdot
.40981 .11468 Mdot
.40982 .1147 Mdot
.40983 .11471 Mdot
.40984 .11473 Mdot
.40985 .11474 Mdot
.40986 .11476 Mdot
.40987 .11477 Mdot
.40988 .11479 Mdot
.40989 .1148 Mdot
.4099 .11482 Mdot
.4099 .11483 Mdot
.40991 .11485 Mdot
.40992 .11486 Mdot
.40993 .11488 Mdot
.40994 .11489 Mdot
.40995 .11491 Mdot
.40996 .11493 Mdot
.40997 .11494 Mdot
.40998 .11496 Mdot
.40999 .11497 Mdot
.41 .11499 Mdot
.41001 .115 Mdot
.41002 .11502 Mdot
.41003 .11503 Mdot
.41004 .11505 Mdot
.41005 .11506 Mdot
.41006 .11508 Mdot
.41007 .11509 Mdot
.41008 .11511 Mdot
.41009 .11512 Mdot
.4101 .11514 Mdot
.4101 .11516 Mdot
.41011 .11517 Mdot
.41012 .11519 Mdot
.41013 .1152 Mdot
.41014 .11522 Mdot
.41015 .11523 Mdot
.41016 .11525 Mdot
.41017 .11526 Mdot
.41018 .11528 Mdot
.41019 .11529 Mdot
.4102 .11531 Mdot
.41021 .11532 Mdot
.41022 .11534 Mdot
.41023 .11536 Mdot
.41024 .11537 Mdot
.41025 .11539 Mdot
.41026 .1154 Mdot
.41027 .11542 Mdot
.41028 .11543 Mdot
.41029 .11545 Mdot
.4103 .11546 Mdot
.4103 .11548 Mdot
.41031 .11549 Mdot
.41032 .11551 Mdot
.41033 .11552 Mdot
.41034 .11554 Mdot
.41035 .11556 Mdot
.41036 .11557 Mdot
.41037 .11559 Mdot
.41038 .1156 Mdot
.41039 .11562 Mdot
.4104 .11563 Mdot
.41041 .11565 Mdot
.41042 .11566 Mdot
.41043 .11568 Mdot
.41044 .11569 Mdot
.41045 .11571 Mdot
.41046 .11572 Mdot
.41047 .11574 Mdot
.41048 .11576 Mdot
.41049 .11577 Mdot
.4105 .11579 Mdot
.4105 .1158 Mdot
.41051 .11582 Mdot
.41052 .11583 Mdot
.41053 .11585 Mdot
.41054 .11586 Mdot
.41055 .11588 Mdot
.41056 .11589 Mdot
.41057 .11591 Mdot
.41058 .11593 Mdot
.41059 .11594 Mdot
.4106 .11596 Mdot
.41061 .11597 Mdot
.41062 .11599 Mdot
.41063 .116 Mdot
.41064 .11602 Mdot
.41065 .11603 Mdot
.41066 .11605 Mdot
.41067 .11606 Mdot
.41068 .11608 Mdot
.41069 .11609 Mdot
.4107 .11611 Mdot
.4107 .11613 Mdot
.41071 .11614 Mdot
.41072 .11616 Mdot
.41073 .11617 Mdot
.41074 .11619 Mdot
.41075 .1162 Mdot
.41076 .11622 Mdot
.41077 .11623 Mdot
.41078 .11625 Mdot
.41079 .11626 Mdot
.4108 .11628 Mdot
.41081 .1163 Mdot
.41082 .11631 Mdot
.41083 .11633 Mdot
.41084 .11634 Mdot
.41085 .11636 Mdot
.41086 .11637 Mdot
.41087 .11639 Mdot
.41088 .1164 Mdot
.41089 .11642 Mdot
.4109 .11643 Mdot
.4109 .11645 Mdot
.41091 .11647 Mdot
.41092 .11648 Mdot
.41093 .1165 Mdot
.41094 .11651 Mdot
.41095 .11653 Mdot
.41096 .11654 Mdot
.41097 .11656 Mdot
.41098 .11657 Mdot
.41099 .11659 Mdot
.411 .1166 Mdot
.41101 .11662 Mdot
.41102 .11664 Mdot
.41103 .11665 Mdot
.41104 .11667 Mdot
.41105 .11668 Mdot
.41106 .1167 Mdot
.41107 .11671 Mdot
.41108 .11673 Mdot
.41109 .11674 Mdot
.4111 .11676 Mdot
.4111 .11678 Mdot
.41111 .11679 Mdot
.41112 .11681 Mdot
.41113 .11682 Mdot
.41114 .11684 Mdot
.41115 .11685 Mdot
.41116 .11687 Mdot
.41117 .11688 Mdot
.41118 .1169 Mdot
.41119 .11691 Mdot
.4112 .11693 Mdot
.41121 .11695 Mdot
.41122 .11696 Mdot
.41123 .11698 Mdot
.41124 .11699 Mdot
.41125 .11701 Mdot
.41126 .11702 Mdot
.41127 .11704 Mdot
.41128 .11705 Mdot
.41129 .11707 Mdot
.4113 .11709 Mdot
.4113 .1171 Mdot
.41131 .11712 Mdot
.41132 .11713 Mdot
.41133 .11715 Mdot
.41134 .11716 Mdot
.41135 .11718 Mdot
.41136 .11719 Mdot
.41137 .11721 Mdot
.41138 .11722 Mdot
.41139 .11724 Mdot
.4114 .11726 Mdot
.41141 .11727 Mdot
.41142 .11729 Mdot
.41143 .1173 Mdot
.41144 .11732 Mdot
.41145 .11733 Mdot
.41146 .11735 Mdot
.41147 .11736 Mdot
.41148 .11738 Mdot
.41149 .1174 Mdot
.4115 .11741 Mdot
.4115 .11743 Mdot
.41151 .11744 Mdot
.41152 .11746 Mdot
.41153 .11747 Mdot
.41154 .11749 Mdot
.41155 .1175 Mdot
.41156 .11752 Mdot
.41157 .11754 Mdot
.41158 .11755 Mdot
.41159 .11757 Mdot
.4116 .11758 Mdot
.41161 .1176 Mdot
.41162 .11761 Mdot
.41163 .11763 Mdot
.41164 .11764 Mdot
.41165 .11766 Mdot
.41166 .11768 Mdot
.41167 .11769 Mdot
.41168 .11771 Mdot
.41169 .11772 Mdot
.4117 .11774 Mdot
.4117 .11775 Mdot
.41171 .11777 Mdot
.41172 .11778 Mdot
.41173 .1178 Mdot
.41174 .11782 Mdot
.41175 .11783 Mdot
.41176 .11785 Mdot
.41177 .11786 Mdot
.41178 .11788 Mdot
.41179 .11789 Mdot
.4118 .11791 Mdot
.41181 .11792 Mdot
.41182 .11794 Mdot
.41183 .11796 Mdot
.41184 .11797 Mdot
.41185 .11799 Mdot
.41186 .118 Mdot
.41187 .11802 Mdot
.41188 .11803 Mdot
.41189 .11805 Mdot
.4119 .11806 Mdot
.4119 .11808 Mdot
.41191 .1181 Mdot
.41192 .11811 Mdot
.41193 .11813 Mdot
.41194 .11814 Mdot
.41195 .11816 Mdot
.41196 .11817 Mdot
.41197 .11819 Mdot
.41198 .11821 Mdot
.41199 .11822 Mdot
.412 .11824 Mdot
.41201 .11825 Mdot
.41202 .11827 Mdot
.41203 .11828 Mdot
.41204 .1183 Mdot
.41205 .11831 Mdot
.41206 .11833 Mdot
.41207 .11835 Mdot
.41208 .11836 Mdot
.41209 .11838 Mdot
.4121 .11839 Mdot
.4121 .11841 Mdot
.41211 .11842 Mdot
.41212 .11844 Mdot
.41213 .11845 Mdot
.41214 .11847 Mdot
.41215 .11849 Mdot
.41216 .1185 Mdot
.41217 .11852 Mdot
.41218 .11853 Mdot
.41219 .11855 Mdot
.4122 .11856 Mdot
.41221 .11858 Mdot
.41222 .1186 Mdot
.41223 .11861 Mdot
.41224 .11863 Mdot
.41225 .11864 Mdot
.41226 .11866 Mdot
.41227 .11867 Mdot
.41228 .11869 Mdot
.41229 .1187 Mdot
.4123 .11872 Mdot
.4123 .11874 Mdot
.41231 .11875 Mdot
.41232 .11877 Mdot
.41233 .11878 Mdot
.41234 .1188 Mdot
.41235 .11881 Mdot
.41236 .11883 Mdot
.41237 .11885 Mdot
.41238 .11886 Mdot
.41239 .11888 Mdot
.4124 .11889 Mdot
.41241 .11891 Mdot
.41242 .11892 Mdot
.41243 .11894 Mdot
.41244 .11895 Mdot
.41245 .11897 Mdot
.41246 .11899 Mdot
.41247 .119 Mdot
.41248 .11902 Mdot
.41249 .11903 Mdot
.4125 .11905 Mdot
.4125 .11906 Mdot
.41251 .11908 Mdot
.41252 .1191 Mdot
.41253 .11911 Mdot
.41254 .11913 Mdot
.41255 .11914 Mdot
.41256 .11916 Mdot
.41257 .11917 Mdot
.41258 .11919 Mdot
.41259 .11921 Mdot
.4126 .11922 Mdot
.41261 .11924 Mdot
.41262 .11925 Mdot
.41263 .11927 Mdot
.41264 .11928 Mdot
.41265 .1193 Mdot
.41266 .11932 Mdot
.41267 .11933 Mdot
.41268 .11935 Mdot
.41269 .11936 Mdot
.4127 .11938 Mdot
.4127 .11939 Mdot
.41271 .11941 Mdot
.41272 .11943 Mdot
.41273 .11944 Mdot
.41274 .11946 Mdot
.41275 .11947 Mdot
.41276 .11949 Mdot
.41277 .1195 Mdot
.41278 .11952 Mdot
.41279 .11953 Mdot
.4128 .11955 Mdot
.41281 .11957 Mdot
.41282 .11958 Mdot
.41283 .1196 Mdot
.41284 .11961 Mdot
.41285 .11963 Mdot
.41286 .11964 Mdot
.41287 .11966 Mdot
.41288 .11968 Mdot
.41289 .11969 Mdot
.4129 .11971 Mdot
.4129 .11972 Mdot
.41291 .11974 Mdot
.41292 .11975 Mdot
.41293 .11977 Mdot
.41294 .11979 Mdot
.41295 .1198 Mdot
.41296 .11982 Mdot
.41297 .11983 Mdot
.41298 .11985 Mdot
.41299 .11986 Mdot
.413 .11988 Mdot
.41301 .1199 Mdot
.41302 .11991 Mdot
.41303 .11993 Mdot
.41304 .11994 Mdot
.41305 .11996 Mdot
.41306 .11997 Mdot
.41307 .11999 Mdot
.41308 .12001 Mdot
.41309 .12002 Mdot
.4131 .12004 Mdot
.4131 .12005 Mdot
.41311 .12007 Mdot
.41312 .12008 Mdot
.41313 .1201 Mdot
.41314 .12012 Mdot
.41315 .12013 Mdot
.41316 .12015 Mdot
.41317 .12016 Mdot
.41318 .12018 Mdot
.41319 .1202 Mdot
.4132 .12021 Mdot
.41321 .12023 Mdot
.41322 .12024 Mdot
.41323 .12026 Mdot
.41324 .12027 Mdot
.41325 .12029 Mdot
.41326 .12031 Mdot
.41327 .12032 Mdot
.41328 .12034 Mdot
.41329 .12035 Mdot
.4133 .12037 Mdot
.4133 .12038 Mdot
.41331 .1204 Mdot
.41332 .12042 Mdot
.41333 .12043 Mdot
.41334 .12045 Mdot
.41335 .12046 Mdot
.41336 .12048 Mdot
.41337 .12049 Mdot
.41338 .12051 Mdot
.41339 .12053 Mdot
.4134 .12054 Mdot
.41341 .12056 Mdot
.41342 .12057 Mdot
.41343 .12059 Mdot
.41344 .1206 Mdot
.41345 .12062 Mdot
.41346 .12064 Mdot
.41347 .12065 Mdot
.41348 .12067 Mdot
.41349 .12068 Mdot
.4135 .1207 Mdot
.4135 .12072 Mdot
.41351 .12073 Mdot
.41352 .12075 Mdot
.41353 .12076 Mdot
.41354 .12078 Mdot
.41355 .12079 Mdot
.41356 .12081 Mdot
.41357 .12083 Mdot
.41358 .12084 Mdot
.41359 .12086 Mdot
.4136 .12087 Mdot
.41361 .12089 Mdot
.41362 .1209 Mdot
.41363 .12092 Mdot
.41364 .12094 Mdot
.41365 .12095 Mdot
.41366 .12097 Mdot
.41367 .12098 Mdot
.41368 .121 Mdot
.41369 .12102 Mdot
.4137 .12103 Mdot
.4137 .12105 Mdot
.41371 .12106 Mdot
.41372 .12108 Mdot
.41373 .12109 Mdot
.41374 .12111 Mdot
.41375 .12113 Mdot
.41376 .12114 Mdot
.41377 .12116 Mdot
.41378 .12117 Mdot
.41379 .12119 Mdot
.4138 .12121 Mdot
.41381 .12122 Mdot
.41382 .12124 Mdot
.41383 .12125 Mdot
.41384 .12127 Mdot
.41385 .12128 Mdot
.41386 .1213 Mdot
.41387 .12132 Mdot
.41388 .12133 Mdot
.41389 .12135 Mdot
.4139 .12136 Mdot
.4139 .12138 Mdot
.41391 .1214 Mdot
.41392 .12141 Mdot
.41393 .12143 Mdot
.41394 .12144 Mdot
.41395 .12146 Mdot
.41396 .12147 Mdot
.41397 .12149 Mdot
.41398 .12151 Mdot
.41399 .12152 Mdot
.414 .12154 Mdot
.41401 .12155 Mdot
.41402 .12157 Mdot
.41403 .12159 Mdot
.41404 .1216 Mdot
.41405 .12162 Mdot
.41406 .12163 Mdot
.41407 .12165 Mdot
.41408 .12166 Mdot
.41409 .12168 Mdot
.4141 .1217 Mdot
.4141 .12171 Mdot
.41411 .12173 Mdot
.41412 .12174 Mdot
.41413 .12176 Mdot
.41414 .12178 Mdot
.41415 .12179 Mdot
.41416 .12181 Mdot
.41417 .12182 Mdot
.41418 .12184 Mdot
.41419 .12185 Mdot
.4142 .12187 Mdot
.41421 .12189 Mdot
.41422 .1219 Mdot
.41423 .12192 Mdot
.41424 .12193 Mdot
.41425 .12195 Mdot
.41426 .12197 Mdot
.41427 .12198 Mdot
.41428 .122 Mdot
.41429 .12201 Mdot
.4143 .12203 Mdot
.4143 .12205 Mdot
.41431 .12206 Mdot
.41432 .12208 Mdot
.41433 .12209 Mdot
.41434 .12211 Mdot
.41435 .12212 Mdot
.41436 .12214 Mdot
.41437 .12216 Mdot
.41438 .12217 Mdot
.41439 .12219 Mdot
.4144 .1222 Mdot
.41441 .12222 Mdot
.41442 .12224 Mdot
.41443 .12225 Mdot
.41444 .12227 Mdot
.41445 .12228 Mdot
.41446 .1223 Mdot
.41447 .12232 Mdot
.41448 .12233 Mdot
.41449 .12235 Mdot
.4145 .12236 Mdot
.4145 .12238 Mdot
.41451 .1224 Mdot
.41452 .12241 Mdot
.41453 .12243 Mdot
.41454 .12244 Mdot
.41455 .12246 Mdot
.41456 .12247 Mdot
.41457 .12249 Mdot
.41458 .12251 Mdot
.41459 .12252 Mdot
.4146 .12254 Mdot
.41461 .12255 Mdot
.41462 .12257 Mdot
.41463 .12259 Mdot
.41464 .1226 Mdot
.41465 .12262 Mdot
.41466 .12263 Mdot
.41467 .12265 Mdot
.41468 .12267 Mdot
.41469 .12268 Mdot
.4147 .1227 Mdot
.4147 .12271 Mdot
.41471 .12273 Mdot
.41472 .12275 Mdot
.41473 .12276 Mdot
.41474 .12278 Mdot
.41475 .12279 Mdot
.41476 .12281 Mdot
.41477 .12283 Mdot
.41478 .12284 Mdot
.41479 .12286 Mdot
.4148 .12287 Mdot
.41481 .12289 Mdot
.41482 .1229 Mdot
.41483 .12292 Mdot
.41484 .12294 Mdot
.41485 .12295 Mdot
.41486 .12297 Mdot
.41487 .12298 Mdot
.41488 .123 Mdot
.41489 .12302 Mdot
.4149 .12303 Mdot
.4149 .12305 Mdot
.41491 .12306 Mdot
.41492 .12308 Mdot
.41493 .1231 Mdot
.41494 .12311 Mdot
.41495 .12313 Mdot
.41496 .12314 Mdot
.41497 .12316 Mdot
.41498 .12318 Mdot
.41499 .12319 Mdot
.415 .12321 Mdot
.41501 .12322 Mdot
.41502 .12324 Mdot
.41503 .12326 Mdot
.41504 .12327 Mdot
.41505 .12329 Mdot
.41506 .1233 Mdot
.41507 .12332 Mdot
.41508 .12334 Mdot
.41509 .12335 Mdot
.4151 .12337 Mdot
.4151 .12338 Mdot
.41511 .1234 Mdot
.41512 .12342 Mdot
.41513 .12343 Mdot
.41514 .12345 Mdot
.41515 .12346 Mdot
.41516 .12348 Mdot
.41517 .1235 Mdot
.41518 .12351 Mdot
.41519 .12353 Mdot
.4152 .12354 Mdot
.41521 .12356 Mdot
.41522 .12358 Mdot
.41523 .12359 Mdot
.41524 .12361 Mdot
.41525 .12362 Mdot
.41526 .12364 Mdot
.41527 .12366 Mdot
.41528 .12367 Mdot
.41529 .12369 Mdot
.4153 .1237 Mdot
.4153 .12372 Mdot
.41531 .12374 Mdot
.41532 .12375 Mdot
.41533 .12377 Mdot
.41534 .12378 Mdot
.41535 .1238 Mdot
.41536 .12382 Mdot
.41537 .12383 Mdot
.41538 .12385 Mdot
.41539 .12386 Mdot
.4154 .12388 Mdot
.41541 .1239 Mdot
.41542 .12391 Mdot
.41543 .12393 Mdot
.41544 .12394 Mdot
.41545 .12396 Mdot
.41546 .12398 Mdot
.41547 .12399 Mdot
.41548 .12401 Mdot
.41549 .12402 Mdot
.4155 .12404 Mdot
.4155 .12406 Mdot
.41551 .12407 Mdot
.41552 .12409 Mdot
.41553 .1241 Mdot
.41554 .12412 Mdot
.41555 .12414 Mdot
.41556 .12415 Mdot
.41557 .12417 Mdot
.41558 .12418 Mdot
.41559 .1242 Mdot
.4156 .12422 Mdot
.41561 .12423 Mdot
.41562 .12425 Mdot
.41563 .12426 Mdot
.41564 .12428 Mdot
.41565 .1243 Mdot
.41566 .12431 Mdot
.41567 .12433 Mdot
.41568 .12434 Mdot
.41569 .12436 Mdot
.4157 .12438 Mdot
.4157 .12439 Mdot
.41571 .12441 Mdot
.41572 .12442 Mdot
.41573 .12444 Mdot
.41574 .12446 Mdot
.41575 .12447 Mdot
.41576 .12449 Mdot
.41577 .12451 Mdot
.41578 .12452 Mdot
.41579 .12454 Mdot
.4158 .12455 Mdot
.41581 .12457 Mdot
.41582 .12459 Mdot
.41583 .1246 Mdot
.41584 .12462 Mdot
.41585 .12463 Mdot
.41586 .12465 Mdot
.41587 .12467 Mdot
.41588 .12468 Mdot
.41589 .1247 Mdot
.4159 .12471 Mdot
.4159 .12473 Mdot
.41591 .12475 Mdot
.41592 .12476 Mdot
.41593 .12478 Mdot
.41594 .12479 Mdot
.41595 .12481 Mdot
.41596 .12483 Mdot
.41597 .12484 Mdot
.41598 .12486 Mdot
.41599 .12487 Mdot
.416 .12489 Mdot
.41601 .12491 Mdot
.41602 .12492 Mdot
.41603 .12494 Mdot
.41604 .12496 Mdot
.41605 .12497 Mdot
.41606 .12499 Mdot
.41607 .125 Mdot
.41608 .12502 Mdot
.41609 .12504 Mdot
.4161 .12505 Mdot
.4161 .12507 Mdot
.41611 .12508 Mdot
.41612 .1251 Mdot
.41613 .12512 Mdot
.41614 .12513 Mdot
.41615 .12515 Mdot
.41616 .12516 Mdot
.41617 .12518 Mdot
.41618 .1252 Mdot
.41619 .12521 Mdot
.4162 .12523 Mdot
.41621 .12525 Mdot
.41622 .12526 Mdot
.41623 .12528 Mdot
.41624 .12529 Mdot
.41625 .12531 Mdot
.41626 .12533 Mdot
.41627 .12534 Mdot
.41628 .12536 Mdot
.41629 .12537 Mdot
.4163 .12539 Mdot
.4163 .12541 Mdot
.41631 .12542 Mdot
.41632 .12544 Mdot
.41633 .12546 Mdot
.41634 .12547 Mdot
.41635 .12549 Mdot
.41636 .1255 Mdot
.41637 .12552 Mdot
.41638 .12554 Mdot
.41639 .12555 Mdot
.4164 .12557 Mdot
.41641 .12558 Mdot
.41642 .1256 Mdot
.41643 .12562 Mdot
.41644 .12563 Mdot
.41645 .12565 Mdot
.41646 .12566 Mdot
.41647 .12568 Mdot
.41648 .1257 Mdot
.41649 .12571 Mdot
.4165 .12573 Mdot
.4165 .12575 Mdot
.41651 .12576 Mdot
.41652 .12578 Mdot
.41653 .12579 Mdot
.41654 .12581 Mdot
.41655 .12583 Mdot
.41656 .12584 Mdot
.41657 .12586 Mdot
.41658 .12587 Mdot
.41659 .12589 Mdot
.4166 .12591 Mdot
.41661 .12592 Mdot
.41662 .12594 Mdot
.41663 .12596 Mdot
.41664 .12597 Mdot
.41665 .12599 Mdot
.41666 .126 Mdot
.41667 .12602 Mdot
.41668 .12604 Mdot
.41669 .12605 Mdot
.4167 .12607 Mdot
.4167 .12609 Mdot
.41671 .1261 Mdot
.41672 .12612 Mdot
.41673 .12613 Mdot
.41674 .12615 Mdot
.41675 .12617 Mdot
.41676 .12618 Mdot
.41677 .1262 Mdot
.41678 .12621 Mdot
.41679 .12623 Mdot
.4168 .12625 Mdot
.41681 .12626 Mdot
.41682 .12628 Mdot
.41683 .1263 Mdot
.41684 .12631 Mdot
.41685 .12633 Mdot
.41686 .12634 Mdot
.41687 .12636 Mdot
.41688 .12638 Mdot
.41689 .12639 Mdot
.4169 .12641 Mdot
.4169 .12643 Mdot
.41691 .12644 Mdot
.41692 .12646 Mdot
.41693 .12647 Mdot
.41694 .12649 Mdot
.41695 .12651 Mdot
.41696 .12652 Mdot
.41697 .12654 Mdot
.41698 .12655 Mdot
.41699 .12657 Mdot
.417 .12659 Mdot
.41701 .1266 Mdot
.41702 .12662 Mdot
.41703 .12664 Mdot
.41704 .12665 Mdot
.41705 .12667 Mdot
.41706 .12668 Mdot
.41707 .1267 Mdot
.41708 .12672 Mdot
.41709 .12673 Mdot
.4171 .12675 Mdot
.4171 .12677 Mdot
.41711 .12678 Mdot
.41712 .1268 Mdot
.41713 .12681 Mdot
.41714 .12683 Mdot
.41715 .12685 Mdot
.41716 .12686 Mdot
.41717 .12688 Mdot
.41718 .1269 Mdot
.41719 .12691 Mdot
.4172 .12693 Mdot
.41721 .12694 Mdot
.41722 .12696 Mdot
.41723 .12698 Mdot
.41724 .12699 Mdot
.41725 .12701 Mdot
.41726 .12703 Mdot
.41727 .12704 Mdot
.41728 .12706 Mdot
.41729 .12707 Mdot
.4173 .12709 Mdot
.4173 .12711 Mdot
.41731 .12712 Mdot
.41732 .12714 Mdot
.41733 .12716 Mdot
.41734 .12717 Mdot
.41735 .12719 Mdot
.41736 .1272 Mdot
.41737 .12722 Mdot
.41738 .12724 Mdot
.41739 .12725 Mdot
.4174 .12727 Mdot
.41741 .12729 Mdot
.41742 .1273 Mdot
.41743 .12732 Mdot
.41744 .12733 Mdot
.41745 .12735 Mdot
.41746 .12737 Mdot
.41747 .12738 Mdot
.41748 .1274 Mdot
.41749 .12742 Mdot
.4175 .12743 Mdot
.4175 .12745 Mdot
.41751 .12746 Mdot
.41752 .12748 Mdot
.41753 .1275 Mdot
.41754 .12751 Mdot
.41755 .12753 Mdot
.41756 .12755 Mdot
.41757 .12756 Mdot
.41758 .12758 Mdot
.41759 .12759 Mdot
.4176 .12761 Mdot
.41761 .12763 Mdot
.41762 .12764 Mdot
.41763 .12766 Mdot
.41764 .12768 Mdot
.41765 .12769 Mdot
.41766 .12771 Mdot
.41767 .12773 Mdot
.41768 .12774 Mdot
.41769 .12776 Mdot
.4177 .12777 Mdot
.4177 .12779 Mdot
.41771 .12781 Mdot
.41772 .12782 Mdot
.41773 .12784 Mdot
.41774 .12786 Mdot
.41775 .12787 Mdot
.41776 .12789 Mdot
.41777 .1279 Mdot
.41778 .12792 Mdot
.41779 .12794 Mdot
.4178 .12795 Mdot
.41781 .12797 Mdot
.41782 .12799 Mdot
.41783 .128 Mdot
.41784 .12802 Mdot
.41785 .12803 Mdot
.41786 .12805 Mdot
.41787 .12807 Mdot
.41788 .12808 Mdot
.41789 .1281 Mdot
.4179 .12812 Mdot
.4179 .12813 Mdot
.41791 .12815 Mdot
.41792 .12817 Mdot
.41793 .12818 Mdot
.41794 .1282 Mdot
.41795 .12821 Mdot
.41796 .12823 Mdot
.41797 .12825 Mdot
.41798 .12826 Mdot
.41799 .12828 Mdot
.418 .1283 Mdot
.41801 .12831 Mdot
.41802 .12833 Mdot
.41803 .12835 Mdot
.41804 .12836 Mdot
.41805 .12838 Mdot
.41806 .12839 Mdot
.41807 .12841 Mdot
.41808 .12843 Mdot
.41809 .12844 Mdot
.4181 .12846 Mdot
.4181 .12848 Mdot
.41811 .12849 Mdot
.41812 .12851 Mdot
.41813 .12853 Mdot
.41814 .12854 Mdot
.41815 .12856 Mdot
.41816 .12857 Mdot
.41817 .12859 Mdot
.41818 .12861 Mdot
.41819 .12862 Mdot
.4182 .12864 Mdot
.41821 .12866 Mdot
.41822 .12867 Mdot
.41823 .12869 Mdot
.41824 .1287 Mdot
.41825 .12872 Mdot
.41826 .12874 Mdot
.41827 .12875 Mdot
.41828 .12877 Mdot
.41829 .12879 Mdot
.4183 .1288 Mdot
.4183 .12882 Mdot
.41831 .12884 Mdot
.41832 .12885 Mdot
.41833 .12887 Mdot
.41834 .12889 Mdot
.41835 .1289 Mdot
.41836 .12892 Mdot
.41837 .12893 Mdot
.41838 .12895 Mdot
.41839 .12897 Mdot
.4184 .12898 Mdot
.41841 .129 Mdot
.41842 .12902 Mdot
.41843 .12903 Mdot
.41844 .12905 Mdot
.41845 .12907 Mdot
.41846 .12908 Mdot
.41847 .1291 Mdot
.41848 .12911 Mdot
.41849 .12913 Mdot
.4185 .12915 Mdot
.4185 .12916 Mdot
.41851 .12918 Mdot
.41852 .1292 Mdot
.41853 .12921 Mdot
.41854 .12923 Mdot
.41855 .12925 Mdot
.41856 .12926 Mdot
.41857 .12928 Mdot
.41858 .12929 Mdot
.41859 .12931 Mdot
.4186 .12933 Mdot
.41861 .12934 Mdot
.41862 .12936 Mdot
.41863 .12938 Mdot
.41864 .12939 Mdot
.41865 .12941 Mdot
.41866 .12943 Mdot
.41867 .12944 Mdot
.41868 .12946 Mdot
.41869 .12948 Mdot
.4187 .12949 Mdot
.4187 .12951 Mdot
.41871 .12952 Mdot
.41872 .12954 Mdot
.41873 .12956 Mdot
.41874 .12957 Mdot
.41875 .12959 Mdot
.41876 .12961 Mdot
.41877 .12962 Mdot
.41878 .12964 Mdot
.41879 .12966 Mdot
.4188 .12967 Mdot
.41881 .12969 Mdot
.41882 .12971 Mdot
.41883 .12972 Mdot
.41884 .12974 Mdot
.41885 .12975 Mdot
.41886 .12977 Mdot
.41887 .12979 Mdot
.41888 .1298 Mdot
.41889 .12982 Mdot
.4189 .12984 Mdot
.4189 .12985 Mdot
.41891 .12987 Mdot
.41892 .12989 Mdot
.41893 .1299 Mdot
.41894 .12992 Mdot
.41895 .12994 Mdot
.41896 .12995 Mdot
.41897 .12997 Mdot
.41898 .12999 Mdot
.41899 .13 Mdot
.419 .13002 Mdot
.41901 .13003 Mdot
.41902 .13005 Mdot
.41903 .13007 Mdot
.41904 .13008 Mdot
.41905 .1301 Mdot
.41906 .13012 Mdot
.41907 .13013 Mdot
.41908 .13015 Mdot
.41909 .13017 Mdot
.4191 .13018 Mdot
.4191 .1302 Mdot
.41911 .13022 Mdot
.41912 .13023 Mdot
.41913 .13025 Mdot
.41914 .13027 Mdot
.41915 .13028 Mdot
.41916 .1303 Mdot
.41917 .13031 Mdot
.41918 .13033 Mdot
.41919 .13035 Mdot
.4192 .13036 Mdot
.41921 .13038 Mdot
.41922 .1304 Mdot
.41923 .13041 Mdot
.41924 .13043 Mdot
.41925 .13045 Mdot
.41926 .13046 Mdot
.41927 .13048 Mdot
.41928 .1305 Mdot
.41929 .13051 Mdot
.4193 .13053 Mdot
.4193 .13055 Mdot
.41931 .13056 Mdot
.41932 .13058 Mdot
.41933 .13059 Mdot
.41934 .13061 Mdot
.41935 .13063 Mdot
.41936 .13064 Mdot
.41937 .13066 Mdot
.41938 .13068 Mdot
.41939 .13069 Mdot
.4194 .13071 Mdot
.41941 .13073 Mdot
.41942 .13074 Mdot
.41943 .13076 Mdot
.41944 .13078 Mdot
.41945 .13079 Mdot
.41946 .13081 Mdot
.41947 .13083 Mdot
.41948 .13084 Mdot
.41949 .13086 Mdot
.4195 .13088 Mdot
.4195 .13089 Mdot
.41951 .13091 Mdot
.41952 .13093 Mdot
.41953 .13094 Mdot
.41954 .13096 Mdot
.41955 .13097 Mdot
.41956 .13099 Mdot
.41957 .13101 Mdot
.41958 .13102 Mdot
.41959 .13104 Mdot
.4196 .13106 Mdot
.41961 .13107 Mdot
.41962 .13109 Mdot
.41963 .13111 Mdot
.41964 .13112 Mdot
.41965 .13114 Mdot
.41966 .13116 Mdot
.41967 .13117 Mdot
.41968 .13119 Mdot
.41969 .13121 Mdot
.4197 .13122 Mdot
.4197 .13124 Mdot
.41971 .13126 Mdot
.41972 .13127 Mdot
.41973 .13129 Mdot
.41974 .13131 Mdot
.41975 .13132 Mdot
.41976 .13134 Mdot
.41977 .13136 Mdot
.41978 .13137 Mdot
.41979 .13139 Mdot
.4198 .1314 Mdot
.41981 .13142 Mdot
.41982 .13144 Mdot
.41983 .13145 Mdot
.41984 .13147 Mdot
.41985 .13149 Mdot
.41986 .1315 Mdot
.41987 .13152 Mdot
.41988 .13154 Mdot
.41989 .13155 Mdot
.4199 .13157 Mdot
.4199 .13159 Mdot
.41991 .1316 Mdot
.41992 .13162 Mdot
.41993 .13164 Mdot
.41994 .13165 Mdot
.41995 .13167 Mdot
.41996 .13169 Mdot
.41997 .1317 Mdot
.41998 .13172 Mdot
.41999 .13174 Mdot
.42 .13175 Mdot
.42001 .13177 Mdot
.42002 .13179 Mdot
.42003 .1318 Mdot
.42004 .13182 Mdot
.42005 .13184 Mdot
.42006 .13185 Mdot
.42007 .13187 Mdot
.42008 .13189 Mdot
.42009 .1319 Mdot
.4201 .13192 Mdot
.4201 .13194 Mdot
.42011 .13195 Mdot
.42012 .13197 Mdot
.42013 .13199 Mdot
.42014 .132 Mdot
.42015 .13202 Mdot
.42016 .13203 Mdot
.42017 .13205 Mdot
.42018 .13207 Mdot
.42019 .13208 Mdot
.4202 .1321 Mdot
.42021 .13212 Mdot
.42022 .13213 Mdot
.42023 .13215 Mdot
.42024 .13217 Mdot
.42025 .13218 Mdot
.42026 .1322 Mdot
.42027 .13222 Mdot
.42028 .13223 Mdot
.42029 .13225 Mdot
.4203 .13227 Mdot
.4203 .13228 Mdot
.42031 .1323 Mdot
.42032 .13232 Mdot
.42033 .13233 Mdot
.42034 .13235 Mdot
.42035 .13237 Mdot
.42036 .13238 Mdot
.42037 .1324 Mdot
.42038 .13242 Mdot
.42039 .13243 Mdot
.4204 .13245 Mdot
.42041 .13247 Mdot
.42042 .13248 Mdot
.42043 .1325 Mdot
.42044 .13252 Mdot
.42045 .13253 Mdot
.42046 .13255 Mdot
.42047 .13257 Mdot
.42048 .13258 Mdot
.42049 .1326 Mdot
.4205 .13262 Mdot
.4205 .13263 Mdot
.42051 .13265 Mdot
.42052 .13267 Mdot
.42053 .13268 Mdot
.42054 .1327 Mdot
.42055 .13272 Mdot
.42056 .13273 Mdot
.42057 .13275 Mdot
.42058 .13277 Mdot
.42059 .13278 Mdot
.4206 .1328 Mdot
.42061 .13282 Mdot
.42062 .13283 Mdot
.42063 .13285 Mdot
.42064 .13287 Mdot
.42065 .13288 Mdot
.42066 .1329 Mdot
.42067 .13292 Mdot
.42068 .13293 Mdot
.42069 .13295 Mdot
.4207 .13297 Mdot
.4207 .13298 Mdot
.42071 .133 Mdot
.42072 .13302 Mdot
.42073 .13303 Mdot
.42074 .13305 Mdot
.42075 .13307 Mdot
.42076 .13308 Mdot
.42077 .1331 Mdot
.42078 .13312 Mdot
.42079 .13313 Mdot
.4208 .13315 Mdot
.42081 .13317 Mdot
.42082 .13318 Mdot
.42083 .1332 Mdot
.42084 .13322 Mdot
.42085 .13323 Mdot
.42086 .13325 Mdot
.42087 .13327 Mdot
.42088 .13328 Mdot
.42089 .1333 Mdot
.4209 .13332 Mdot
.4209 .13333 Mdot
.42091 .13335 Mdot
.42092 .13337 Mdot
.42093 .13338 Mdot
.42094 .1334 Mdot
.42095 .13342 Mdot
.42096 .13343 Mdot
.42097 .13345 Mdot
.42098 .13347 Mdot
.42099 .13348 Mdot
.421 .1335 Mdot
.42101 .13352 Mdot
.42102 .13353 Mdot
.42103 .13355 Mdot
.42104 .13357 Mdot
.42105 .13358 Mdot
.42106 .1336 Mdot
.42107 .13362 Mdot
.42108 .13363 Mdot
.42109 .13365 Mdot
.4211 .13367 Mdot
.4211 .13368 Mdot
.42111 .1337 Mdot
.42112 .13372 Mdot
.42113 .13373 Mdot
.42114 .13375 Mdot
.42115 .13377 Mdot
.42116 .13378 Mdot
.42117 .1338 Mdot
.42118 .13382 Mdot
.42119 .13383 Mdot
.4212 .13385 Mdot
.42121 .13387 Mdot
.42122 .13389 Mdot
.42123 .1339 Mdot
.42124 .13392 Mdot
.42125 .13394 Mdot
.42126 .13395 Mdot
.42127 .13397 Mdot
.42128 .13399 Mdot
.42129 .134 Mdot
.4213 .13402 Mdot
.4213 .13404 Mdot
.42131 .13405 Mdot
.42132 .13407 Mdot
.42133 .13409 Mdot
.42134 .1341 Mdot
.42135 .13412 Mdot
.42136 .13414 Mdot
.42137 .13415 Mdot
.42138 .13417 Mdot
.42139 .13419 Mdot
.4214 .1342 Mdot
.42141 .13422 Mdot
.42142 .13424 Mdot
.42143 .13425 Mdot
.42144 .13427 Mdot
.42145 .13429 Mdot
.42146 .1343 Mdot
.42147 .13432 Mdot
.42148 .13434 Mdot
.42149 .13435 Mdot
.4215 .13437 Mdot
.4215 .13439 Mdot
.42151 .1344 Mdot
.42152 .13442 Mdot
.42153 .13444 Mdot
.42154 .13445 Mdot
.42155 .13447 Mdot
.42156 .13449 Mdot
.42157 .13451 Mdot
.42158 .13452 Mdot
.42159 .13454 Mdot
.4216 .13456 Mdot
.42161 .13457 Mdot
.42162 .13459 Mdot
.42163 .13461 Mdot
.42164 .13462 Mdot
.42165 .13464 Mdot
.42166 .13466 Mdot
.42167 .13467 Mdot
.42168 .13469 Mdot
.42169 .13471 Mdot
.4217 .13472 Mdot
.4217 .13474 Mdot
.42171 .13476 Mdot
.42172 .13477 Mdot
.42173 .13479 Mdot
.42174 .13481 Mdot
.42175 .13482 Mdot
.42176 .13484 Mdot
.42177 .13486 Mdot
.42178 .13487 Mdot
.42179 .13489 Mdot
.4218 .13491 Mdot
.42181 .13492 Mdot
.42182 .13494 Mdot
.42183 .13496 Mdot
.42184 .13498 Mdot
.42185 .13499 Mdot
.42186 .13501 Mdot
.42187 .13503 Mdot
.42188 .13504 Mdot
.42189 .13506 Mdot
.4219 .13508 Mdot
.4219 .13509 Mdot
.42191 .13511 Mdot
.42192 .13513 Mdot
.42193 .13514 Mdot
.42194 .13516 Mdot
.42195 .13518 Mdot
.42196 .13519 Mdot
.42197 .13521 Mdot
.42198 .13523 Mdot
.42199 .13524 Mdot
.422 .13526 Mdot
.42201 .13528 Mdot
.42202 .13529 Mdot
.42203 .13531 Mdot
.42204 .13533 Mdot
.42205 .13535 Mdot
.42206 .13536 Mdot
.42207 .13538 Mdot
.42208 .1354 Mdot
.42209 .13541 Mdot
.4221 .13543 Mdot
.4221 .13545 Mdot
.42211 .13546 Mdot
.42212 .13548 Mdot
.42213 .1355 Mdot
.42214 .13551 Mdot
.42215 .13553 Mdot
.42216 .13555 Mdot
.42217 .13556 Mdot
.42218 .13558 Mdot
.42219 .1356 Mdot
.4222 .13561 Mdot
.42221 .13563 Mdot
.42222 .13565 Mdot
.42223 .13567 Mdot
.42224 .13568 Mdot
.42225 .1357 Mdot
.42226 .13572 Mdot
.42227 .13573 Mdot
.42228 .13575 Mdot
.42229 .13577 Mdot
.4223 .13578 Mdot
.4223 .1358 Mdot
.42231 .13582 Mdot
.42232 .13583 Mdot
.42233 .13585 Mdot
.42234 .13587 Mdot
.42235 .13588 Mdot
.42236 .1359 Mdot
.42237 .13592 Mdot
.42238 .13594 Mdot
.42239 .13595 Mdot
.4224 .13597 Mdot
.42241 .13599 Mdot
.42242 .136 Mdot
.42243 .13602 Mdot
.42244 .13604 Mdot
.42245 .13605 Mdot
.42246 .13607 Mdot
.42247 .13609 Mdot
.42248 .1361 Mdot
.42249 .13612 Mdot
.4225 .13614 Mdot
.4225 .13615 Mdot
.42251 .13617 Mdot
.42252 .13619 Mdot
.42253 .13621 Mdot
.42254 .13622 Mdot
.42255 .13624 Mdot
.42256 .13626 Mdot
.42257 .13627 Mdot
.42258 .13629 Mdot
.42259 .13631 Mdot
.4226 .13632 Mdot
.42261 .13634 Mdot
.42262 .13636 Mdot
.42263 .13637 Mdot
.42264 .13639 Mdot
.42265 .13641 Mdot
.42266 .13643 Mdot
.42267 .13644 Mdot
.42268 .13646 Mdot
.42269 .13648 Mdot
.4227 .13649 Mdot
.4227 .13651 Mdot
.42271 .13653 Mdot
.42272 .13654 Mdot
.42273 .13656 Mdot
.42274 .13658 Mdot
.42275 .13659 Mdot
.42276 .13661 Mdot
.42277 .13663 Mdot
.42278 .13665 Mdot
.42279 .13666 Mdot
.4228 .13668 Mdot
.42281 .1367 Mdot
.42282 .13671 Mdot
.42283 .13673 Mdot
.42284 .13675 Mdot
.42285 .13676 Mdot
.42286 .13678 Mdot
.42287 .1368 Mdot
.42288 .13681 Mdot
.42289 .13683 Mdot
.4229 .13685 Mdot
.4229 .13687 Mdot
.42291 .13688 Mdot
.42292 .1369 Mdot
.42293 .13692 Mdot
.42294 .13693 Mdot
.42295 .13695 Mdot
.42296 .13697 Mdot
.42297 .13698 Mdot
.42298 .137 Mdot
.42299 .13702 Mdot
.423 .13703 Mdot
.42301 .13705 Mdot
.42302 .13707 Mdot
.42303 .13709 Mdot
.42304 .1371 Mdot
.42305 .13712 Mdot
.42306 .13714 Mdot
.42307 .13715 Mdot
.42308 .13717 Mdot
.42309 .13719 Mdot
.4231 .1372 Mdot
.4231 .13722 Mdot
.42311 .13724 Mdot
.42312 .13726 Mdot
.42313 .13727 Mdot
.42314 .13729 Mdot
.42315 .13731 Mdot
.42316 .13732 Mdot
.42317 .13734 Mdot
.42318 .13736 Mdot
.42319 .13737 Mdot
.4232 .13739 Mdot
.42321 .13741 Mdot
.42322 .13742 Mdot
.42323 .13744 Mdot
.42324 .13746 Mdot
.42325 .13748 Mdot
.42326 .13749 Mdot
.42327 .13751 Mdot
.42328 .13753 Mdot
.42329 .13754 Mdot
.4233 .13756 Mdot
.4233 .13758 Mdot
.42331 .13759 Mdot
.42332 .13761 Mdot
.42333 .13763 Mdot
.42334 .13765 Mdot
.42335 .13766 Mdot
.42336 .13768 Mdot
.42337 .1377 Mdot
.42338 .13771 Mdot
.42339 .13773 Mdot
.4234 .13775 Mdot
.42341 .13776 Mdot
.42342 .13778 Mdot
.42343 .1378 Mdot
.42344 .13782 Mdot
.42345 .13783 Mdot
.42346 .13785 Mdot
.42347 .13787 Mdot
.42348 .13788 Mdot
.42349 .1379 Mdot
.4235 .13792 Mdot
.4235 .13793 Mdot
.42351 .13795 Mdot
.42352 .13797 Mdot
.42353 .13799 Mdot
.42354 .138 Mdot
.42355 .13802 Mdot
.42356 .13804 Mdot
.42357 .13805 Mdot
.42358 .13807 Mdot
.42359 .13809 Mdot
.4236 .1381 Mdot
.42361 .13812 Mdot
.42362 .13814 Mdot
.42363 .13816 Mdot
.42364 .13817 Mdot
.42365 .13819 Mdot
.42366 .13821 Mdot
.42367 .13822 Mdot
.42368 .13824 Mdot
.42369 .13826 Mdot
.4237 .13828 Mdot
.4237 .13829 Mdot
.42371 .13831 Mdot
.42372 .13833 Mdot
.42373 .13834 Mdot
.42374 .13836 Mdot
.42375 .13838 Mdot
.42376 .13839 Mdot
.42377 .13841 Mdot
.42378 .13843 Mdot
.42379 .13845 Mdot
.4238 .13846 Mdot
.42381 .13848 Mdot
.42382 .1385 Mdot
.42383 .13851 Mdot
.42384 .13853 Mdot
.42385 .13855 Mdot
.42386 .13857 Mdot
.42387 .13858 Mdot
.42388 .1386 Mdot
.42389 .13862 Mdot
.4239 .13863 Mdot
.4239 .13865 Mdot
.42391 .13867 Mdot
.42392 .13868 Mdot
.42393 .1387 Mdot
.42394 .13872 Mdot
.42395 .13874 Mdot
.42396 .13875 Mdot
.42397 .13877 Mdot
.42398 .13879 Mdot
.42399 .1388 Mdot
.424 .13882 Mdot
.42401 .13884 Mdot
.42402 .13886 Mdot
.42403 .13887 Mdot
.42404 .13889 Mdot
.42405 .13891 Mdot
.42406 .13892 Mdot
.42407 .13894 Mdot
.42408 .13896 Mdot
.42409 .13897 Mdot
.4241 .13899 Mdot
.4241 .13901 Mdot
.42411 .13903 Mdot
.42412 .13904 Mdot
.42413 .13906 Mdot
.42414 .13908 Mdot
.42415 .13909 Mdot
.42416 .13911 Mdot
.42417 .13913 Mdot
.42418 .13915 Mdot
.42419 .13916 Mdot
.4242 .13918 Mdot
.42421 .1392 Mdot
.42422 .13921 Mdot
.42423 .13923 Mdot
.42424 .13925 Mdot
.42425 .13927 Mdot
.42426 .13928 Mdot
.42427 .1393 Mdot
.42428 .13932 Mdot
.42429 .13933 Mdot
.4243 .13935 Mdot
.4243 .13937 Mdot
.42431 .13939 Mdot
.42432 .1394 Mdot
.42433 .13942 Mdot
.42434 .13944 Mdot
.42435 .13945 Mdot
.42436 .13947 Mdot
.42437 .13949 Mdot
.42438 .1395 Mdot
.42439 .13952 Mdot
.4244 .13954 Mdot
.42441 .13956 Mdot
.42442 .13957 Mdot
.42443 .13959 Mdot
.42444 .13961 Mdot
.42445 .13962 Mdot
.42446 .13964 Mdot
.42447 .13966 Mdot
.42448 .13968 Mdot
.42449 .13969 Mdot
.4245 .13971 Mdot
.4245 .13973 Mdot
.42451 .13974 Mdot
.42452 .13976 Mdot
.42453 .13978 Mdot
.42454 .1398 Mdot
.42455 .13981 Mdot
.42456 .13983 Mdot
.42457 .13985 Mdot
.42458 .13986 Mdot
.42459 .13988 Mdot
.4246 .1399 Mdot
.42461 .13992 Mdot
.42462 .13993 Mdot
.42463 .13995 Mdot
.42464 .13997 Mdot
.42465 .13998 Mdot
.42466 .14 Mdot
.42467 .14002 Mdot
.42468 .14004 Mdot
.42469 .14005 Mdot
.4247 .14007 Mdot
.4247 .14009 Mdot
.42471 .1401 Mdot
.42472 .14012 Mdot
.42473 .14014 Mdot
.42474 .14016 Mdot
.42475 .14017 Mdot
.42476 .14019 Mdot
.42477 .14021 Mdot
.42478 .14023 Mdot
.42479 .14024 Mdot
.4248 .14026 Mdot
.42481 .14028 Mdot
.42482 .14029 Mdot
.42483 .14031 Mdot
.42484 .14033 Mdot
.42485 .14035 Mdot
.42486 .14036 Mdot
.42487 .14038 Mdot
.42488 .1404 Mdot
.42489 .14041 Mdot
.4249 .14043 Mdot
.4249 .14045 Mdot
.42491 .14047 Mdot
.42492 .14048 Mdot
.42493 .1405 Mdot
.42494 .14052 Mdot
.42495 .14053 Mdot
.42496 .14055 Mdot
.42497 .14057 Mdot
.42498 .14059 Mdot
.42499 .1406 Mdot
.425 .14062 Mdot
.42501 .14064 Mdot
.42502 .14065 Mdot
.42503 .14067 Mdot
.42504 .14069 Mdot
.42505 .14071 Mdot
.42506 .14072 Mdot
.42507 .14074 Mdot
.42508 .14076 Mdot
.42509 .14078 Mdot
.4251 .14079 Mdot
.4251 .14081 Mdot
.42511 .14083 Mdot
.42512 .14084 Mdot
.42513 .14086 Mdot
.42514 .14088 Mdot
.42515 .1409 Mdot
.42516 .14091 Mdot
.42517 .14093 Mdot
.42518 .14095 Mdot
.42519 .14096 Mdot
.4252 .14098 Mdot
.42521 .141 Mdot
.42522 .14102 Mdot
.42523 .14103 Mdot
.42524 .14105 Mdot
.42525 .14107 Mdot
.42526 .14108 Mdot
.42527 .1411 Mdot
.42528 .14112 Mdot
.42529 .14114 Mdot
.4253 .14115 Mdot
.4253 .14117 Mdot
.42531 .14119 Mdot
.42532 .14121 Mdot
.42533 .14122 Mdot
.42534 .14124 Mdot
.42535 .14126 Mdot
.42536 .14127 Mdot
.42537 .14129 Mdot
.42538 .14131 Mdot
.42539 .14133 Mdot
.4254 .14134 Mdot
.42541 .14136 Mdot
.42542 .14138 Mdot
.42543 .1414 Mdot
.42544 .14141 Mdot
.42545 .14143 Mdot
.42546 .14145 Mdot
.42547 .14146 Mdot
.42548 .14148 Mdot
.42549 .1415 Mdot
.4255 .14152 Mdot
.4255 .14153 Mdot
.42551 .14155 Mdot
.42552 .14157 Mdot
.42553 .14159 Mdot
.42554 .1416 Mdot
.42555 .14162 Mdot
.42556 .14164 Mdot
.42557 .14165 Mdot
.42558 .14167 Mdot
.42559 .14169 Mdot
.4256 .14171 Mdot
.42561 .14172 Mdot
.42562 .14174 Mdot
.42563 .14176 Mdot
.42564 .14178 Mdot
.42565 .14179 Mdot
.42566 .14181 Mdot
.42567 .14183 Mdot
.42568 .14184 Mdot
.42569 .14186 Mdot
.4257 .14188 Mdot
.4257 .1419 Mdot
.42571 .14191 Mdot
.42572 .14193 Mdot
.42573 .14195 Mdot
.42574 .14197 Mdot
.42575 .14198 Mdot
.42576 .142 Mdot
.42577 .14202 Mdot
.42578 .14203 Mdot
.42579 .14205 Mdot
.4258 .14207 Mdot
.42581 .14209 Mdot
.42582 .1421 Mdot
.42583 .14212 Mdot
.42584 .14214 Mdot
.42585 .14216 Mdot
.42586 .14217 Mdot
.42587 .14219 Mdot
.42588 .14221 Mdot
.42589 .14222 Mdot
.4259 .14224 Mdot
.4259 .14226 Mdot
.42591 .14228 Mdot
.42592 .14229 Mdot
.42593 .14231 Mdot
.42594 .14233 Mdot
.42595 .14235 Mdot
.42596 .14236 Mdot
.42597 .14238 Mdot
.42598 .1424 Mdot
.42599 .14241 Mdot
.426 .14243 Mdot
.42601 .14245 Mdot
.42602 .14247 Mdot
.42603 .14248 Mdot
.42604 .1425 Mdot
.42605 .14252 Mdot
.42606 .14254 Mdot
.42607 .14255 Mdot
.42608 .14257 Mdot
.42609 .14259 Mdot
.4261 .14261 Mdot
.4261 .14262 Mdot
.42611 .14264 Mdot
.42612 .14266 Mdot
.42613 .14267 Mdot
.42614 .14269 Mdot
.42615 .14271 Mdot
.42616 .14273 Mdot
.42617 .14274 Mdot
.42618 .14276 Mdot
.42619 .14278 Mdot
.4262 .1428 Mdot
.42621 .14281 Mdot
.42622 .14283 Mdot
.42623 .14285 Mdot
.42624 .14287 Mdot
.42625 .14288 Mdot
.42626 .1429 Mdot
.42627 .14292 Mdot
.42628 .14293 Mdot
.42629 .14295 Mdot
.4263 .14297 Mdot
.4263 .14299 Mdot
.42631 .143 Mdot
.42632 .14302 Mdot
.42633 .14304 Mdot
.42634 .14306 Mdot
.42635 .14307 Mdot
.42636 .14309 Mdot
.42637 .14311 Mdot
.42638 .14313 Mdot
.42639 .14314 Mdot
.4264 .14316 Mdot
.42641 .14318 Mdot
.42642 .1432 Mdot
.42643 .14321 Mdot
.42644 .14323 Mdot
.42645 .14325 Mdot
.42646 .14326 Mdot
.42647 .14328 Mdot
.42648 .1433 Mdot
.42649 .14332 Mdot
.4265 .14333 Mdot
.4265 .14335 Mdot
.42651 .14337 Mdot
.42652 .14339 Mdot
.42653 .1434 Mdot
.42654 .14342 Mdot
.42655 .14344 Mdot
.42656 .14346 Mdot
.42657 .14347 Mdot
.42658 .14349 Mdot
.42659 .14351 Mdot
.4266 .14353 Mdot
.42661 .14354 Mdot
.42662 .14356 Mdot
.42663 .14358 Mdot
.42664 .1436 Mdot
.42665 .14361 Mdot
.42666 .14363 Mdot
.42667 .14365 Mdot
.42668 .14366 Mdot
.42669 .14368 Mdot
.4267 .1437 Mdot
.4267 .14372 Mdot
.42671 .14373 Mdot
.42672 .14375 Mdot
.42673 .14377 Mdot
.42674 .14379 Mdot
.42675 .1438 Mdot
.42676 .14382 Mdot
.42677 .14384 Mdot
.42678 .14386 Mdot
.42679 .14387 Mdot
.4268 .14389 Mdot
.42681 .14391 Mdot
.42682 .14393 Mdot
.42683 .14394 Mdot
.42684 .14396 Mdot
.42685 .14398 Mdot
.42686 .144 Mdot
.42687 .14401 Mdot
.42688 .14403 Mdot
.42689 .14405 Mdot
.4269 .14407 Mdot
.4269 .14408 Mdot
.42691 .1441 Mdot
.42692 .14412 Mdot
.42693 .14414 Mdot
.42694 .14415 Mdot
.42695 .14417 Mdot
.42696 .14419 Mdot
.42697 .1442 Mdot
.42698 .14422 Mdot
.42699 .14424 Mdot
.427 .14426 Mdot
.42701 .14427 Mdot
.42702 .14429 Mdot
.42703 .14431 Mdot
.42704 .14433 Mdot
.42705 .14434 Mdot
.42706 .14436 Mdot
.42707 .14438 Mdot
.42708 .1444 Mdot
.42709 .14441 Mdot
.4271 .14443 Mdot
.4271 .14445 Mdot
.42711 .14447 Mdot
.42712 .14448 Mdot
.42713 .1445 Mdot
.42714 .14452 Mdot
.42715 .14454 Mdot
.42716 .14455 Mdot
.42717 .14457 Mdot
.42718 .14459 Mdot
.42719 .14461 Mdot
.4272 .14462 Mdot
.42721 .14464 Mdot
.42722 .14466 Mdot
.42723 .14468 Mdot
.42724 .14469 Mdot
.42725 .14471 Mdot
.42726 .14473 Mdot
.42727 .14475 Mdot
.42728 .14476 Mdot
.42729 .14478 Mdot
.4273 .1448 Mdot
.4273 .14482 Mdot
.42731 .14483 Mdot
.42732 .14485 Mdot
.42733 .14487 Mdot
.42734 .14489 Mdot
.42735 .1449 Mdot
.42736 .14492 Mdot
.42737 .14494 Mdot
.42738 .14496 Mdot
.42739 .14497 Mdot
.4274 .14499 Mdot
.42741 .14501 Mdot
.42742 .14503 Mdot
.42743 .14504 Mdot
.42744 .14506 Mdot
.42745 .14508 Mdot
.42746 .1451 Mdot
.42747 .14511 Mdot
.42748 .14513 Mdot
.42749 .14515 Mdot
.4275 .14517 Mdot
.4275 .14518 Mdot
.42751 .1452 Mdot
.42752 .14522 Mdot
.42753 .14524 Mdot
.42754 .14525 Mdot
.42755 .14527 Mdot
.42756 .14529 Mdot
.42757 .14531 Mdot
.42758 .14532 Mdot
.42759 .14534 Mdot
.4276 .14536 Mdot
.42761 .14538 Mdot
.42762 .14539 Mdot
.42763 .14541 Mdot
.42764 .14543 Mdot
.42765 .14545 Mdot
.42766 .14546 Mdot
.42767 .14548 Mdot
.42768 .1455 Mdot
.42769 .14552 Mdot
.4277 .14553 Mdot
.4277 .14555 Mdot
.42771 .14557 Mdot
.42772 .14559 Mdot
.42773 .1456 Mdot
.42774 .14562 Mdot
.42775 .14564 Mdot
.42776 .14566 Mdot
.42777 .14567 Mdot
.42778 .14569 Mdot
.42779 .14571 Mdot
.4278 .14573 Mdot
.42781 .14574 Mdot
.42782 .14576 Mdot
.42783 .14578 Mdot
.42784 .1458 Mdot
.42785 .14581 Mdot
.42786 .14583 Mdot
.42787 .14585 Mdot
.42788 .14587 Mdot
.42789 .14588 Mdot
.4279 .1459 Mdot
.4279 .14592 Mdot
.42791 .14594 Mdot
.42792 .14595 Mdot
.42793 .14597 Mdot
.42794 .14599 Mdot
.42795 .14601 Mdot
.42796 .14602 Mdot
.42797 .14604 Mdot
.42798 .14606 Mdot
.42799 .14608 Mdot
.428 .14609 Mdot
.42801 .14611 Mdot
.42802 .14613 Mdot
.42803 .14615 Mdot
.42804 .14617 Mdot
.42805 .14618 Mdot
.42806 .1462 Mdot
.42807 .14622 Mdot
.42808 .14624 Mdot
.42809 .14625 Mdot
.4281 .14627 Mdot
.4281 .14629 Mdot
.42811 .14631 Mdot
.42812 .14632 Mdot
.42813 .14634 Mdot
.42814 .14636 Mdot
.42815 .14638 Mdot
.42816 .14639 Mdot
.42817 .14641 Mdot
.42818 .14643 Mdot
.42819 .14645 Mdot
.4282 .14646 Mdot
.42821 .14648 Mdot
.42822 .1465 Mdot
.42823 .14652 Mdot
.42824 .14653 Mdot
.42825 .14655 Mdot
.42826 .14657 Mdot
.42827 .14659 Mdot
.42828 .1466 Mdot
.42829 .14662 Mdot
.4283 .14664 Mdot
.4283 .14666 Mdot
.42831 .14668 Mdot
.42832 .14669 Mdot
.42833 .14671 Mdot
.42834 .14673 Mdot
.42835 .14675 Mdot
.42836 .14676 Mdot
.42837 .14678 Mdot
.42838 .1468 Mdot
.42839 .14682 Mdot
.4284 .14683 Mdot
.42841 .14685 Mdot
.42842 .14687 Mdot
.42843 .14689 Mdot
.42844 .1469 Mdot
.42845 .14692 Mdot
.42846 .14694 Mdot
.42847 .14696 Mdot
.42848 .14697 Mdot
.42849 .14699 Mdot
.4285 .14701 Mdot
.4285 .14703 Mdot
.42851 .14704 Mdot
.42852 .14706 Mdot
.42853 .14708 Mdot
.42854 .1471 Mdot
.42855 .14712 Mdot
.42856 .14713 Mdot
.42857 .14715 Mdot
.42858 .14717 Mdot
.42859 .14719 Mdot
.4286 .1472 Mdot
.42861 .14722 Mdot
.42862 .14724 Mdot
.42863 .14726 Mdot
.42864 .14727 Mdot
.42865 .14729 Mdot
.42866 .14731 Mdot
.42867 .14733 Mdot
.42868 .14734 Mdot
.42869 .14736 Mdot
.4287 .14738 Mdot
.4287 .1474 Mdot
.42871 .14742 Mdot
.42872 .14743 Mdot
.42873 .14745 Mdot
.42874 .14747 Mdot
.42875 .14749 Mdot
.42876 .1475 Mdot
.42877 .14752 Mdot
.42878 .14754 Mdot
.42879 .14756 Mdot
.4288 .14757 Mdot
.42881 .14759 Mdot
.42882 .14761 Mdot
.42883 .14763 Mdot
.42884 .14764 Mdot
.42885 .14766 Mdot
.42886 .14768 Mdot
.42887 .1477 Mdot
.42888 .14772 Mdot
.42889 .14773 Mdot
.4289 .14775 Mdot
.4289 .14777 Mdot
.42891 .14779 Mdot
.42892 .1478 Mdot
.42893 .14782 Mdot
.42894 .14784 Mdot
.42895 .14786 Mdot
.42896 .14787 Mdot
.42897 .14789 Mdot
.42898 .14791 Mdot
.42899 .14793 Mdot
.429 .14795 Mdot
.42901 .14796 Mdot
.42902 .14798 Mdot
.42903 .148 Mdot
.42904 .14802 Mdot
.42905 .14803 Mdot
.42906 .14805 Mdot
.42907 .14807 Mdot
.42908 .14809 Mdot
.42909 .1481 Mdot
.4291 .14812 Mdot
.4291 .14814 Mdot
.42911 .14816 Mdot
.42912 .14818 Mdot
.42913 .14819 Mdot
.42914 .14821 Mdot
.42915 .14823 Mdot
.42916 .14825 Mdot
.42917 .14826 Mdot
.42918 .14828 Mdot
.42919 .1483 Mdot
.4292 .14832 Mdot
.42921 .14833 Mdot
.42922 .14835 Mdot
.42923 .14837 Mdot
.42924 .14839 Mdot
.42925 .14841 Mdot
.42926 .14842 Mdot
.42927 .14844 Mdot
.42928 .14846 Mdot
.42929 .14848 Mdot
.4293 .14849 Mdot
.4293 .14851 Mdot
.42931 .14853 Mdot
.42932 .14855 Mdot
.42933 .14856 Mdot
.42934 .14858 Mdot
.42935 .1486 Mdot
.42936 .14862 Mdot
.42937 .14864 Mdot
.42938 .14865 Mdot
.42939 .14867 Mdot
.4294 .14869 Mdot
.42941 .14871 Mdot
.42942 .14872 Mdot
.42943 .14874 Mdot
.42944 .14876 Mdot
.42945 .14878 Mdot
.42946 .1488 Mdot
.42947 .14881 Mdot
.42948 .14883 Mdot
.42949 .14885 Mdot
.4295 .14887 Mdot
.4295 .14888 Mdot
.42951 .1489 Mdot
.42952 .14892 Mdot
.42953 .14894 Mdot
.42954 .14896 Mdot
.42955 .14897 Mdot
.42956 .14899 Mdot
.42957 .14901 Mdot
.42958 .14903 Mdot
.42959 .14904 Mdot
.4296 .14906 Mdot
.42961 .14908 Mdot
.42962 .1491 Mdot
.42963 .14912 Mdot
.42964 .14913 Mdot
.42965 .14915 Mdot
.42966 .14917 Mdot
.42967 .14919 Mdot
.42968 .1492 Mdot
.42969 .14922 Mdot
.4297 .14924 Mdot
.4297 .14926 Mdot
.42971 .14927 Mdot
.42972 .14929 Mdot
.42973 .14931 Mdot
.42974 .14933 Mdot
.42975 .14935 Mdot
.42976 .14936 Mdot
.42977 .14938 Mdot
.42978 .1494 Mdot
.42979 .14942 Mdot
.4298 .14943 Mdot
.42981 .14945 Mdot
.42982 .14947 Mdot
.42983 .14949 Mdot
.42984 .14951 Mdot
.42985 .14952 Mdot
.42986 .14954 Mdot
.42987 .14956 Mdot
.42988 .14958 Mdot
.42989 .14959 Mdot
.4299 .14961 Mdot
.4299 .14963 Mdot
.42991 .14965 Mdot
.42992 .14967 Mdot
.42993 .14968 Mdot
.42994 .1497 Mdot
.42995 .14972 Mdot
.42996 .14974 Mdot
.42997 .14976 Mdot
.42998 .14977 Mdot
.42999 .14979 Mdot
.43 .14981 Mdot
.43001 .14983 Mdot
.43002 .14984 Mdot
.43003 .14986 Mdot
.43004 .14988 Mdot
.43005 .1499 Mdot
.43006 .14992 Mdot
.43007 .14993 Mdot
.43008 .14995 Mdot
.43009 .14997 Mdot
.4301 .14999 Mdot
.4301 .15 Mdot
.43011 .15002 Mdot
.43012 .15004 Mdot
.43013 .15006 Mdot
.43014 .15008 Mdot
.43015 .15009 Mdot
.43016 .15011 Mdot
.43017 .15013 Mdot
.43018 .15015 Mdot
.43019 .15016 Mdot
.4302 .15018 Mdot
.43021 .1502 Mdot
.43022 .15022 Mdot
.43023 .15024 Mdot
.43024 .15025 Mdot
.43025 .15027 Mdot
.43026 .15029 Mdot
.43027 .15031 Mdot
.43028 .15033 Mdot
.43029 .15034 Mdot
.4303 .15036 Mdot
.4303 .15038 Mdot
.43031 .1504 Mdot
.43032 .15041 Mdot
.43033 .15043 Mdot
.43034 .15045 Mdot
.43035 .15047 Mdot
.43036 .15049 Mdot
.43037 .1505 Mdot
.43038 .15052 Mdot
.43039 .15054 Mdot
.4304 .15056 Mdot
.43041 .15058 Mdot
.43042 .15059 Mdot
.43043 .15061 Mdot
.43044 .15063 Mdot
.43045 .15065 Mdot
.43046 .15066 Mdot
.43047 .15068 Mdot
.43048 .1507 Mdot
.43049 .15072 Mdot
.4305 .15074 Mdot
.4305 .15075 Mdot
.43051 .15077 Mdot
.43052 .15079 Mdot
.43053 .15081 Mdot
.43054 .15083 Mdot
.43055 .15084 Mdot
.43056 .15086 Mdot
.43057 .15088 Mdot
.43058 .1509 Mdot
.43059 .15091 Mdot
.4306 .15093 Mdot
.43061 .15095 Mdot
.43062 .15097 Mdot
.43063 .15099 Mdot
.43064 .151 Mdot
.43065 .15102 Mdot
.43066 .15104 Mdot
.43067 .15106 Mdot
.43068 .15108 Mdot
.43069 .15109 Mdot
.4307 .15111 Mdot
.4307 .15113 Mdot
.43071 .15115 Mdot
.43072 .15117 Mdot
.43073 .15118 Mdot
.43074 .1512 Mdot
.43075 .15122 Mdot
.43076 .15124 Mdot
.43077 .15125 Mdot
.43078 .15127 Mdot
.43079 .15129 Mdot
.4308 .15131 Mdot
.43081 .15133 Mdot
.43082 .15134 Mdot
.43083 .15136 Mdot
.43084 .15138 Mdot
.43085 .1514 Mdot
.43086 .15142 Mdot
.43087 .15143 Mdot
.43088 .15145 Mdot
.43089 .15147 Mdot
.4309 .15149 Mdot
.4309 .15151 Mdot
.43091 .15152 Mdot
.43092 .15154 Mdot
.43093 .15156 Mdot
.43094 .15158 Mdot
.43095 .1516 Mdot
.43096 .15161 Mdot
.43097 .15163 Mdot
.43098 .15165 Mdot
.43099 .15167 Mdot
.431 .15168 Mdot
.43101 .1517 Mdot
.43102 .15172 Mdot
.43103 .15174 Mdot
.43104 .15176 Mdot
.43105 .15177 Mdot
.43106 .15179 Mdot
.43107 .15181 Mdot
.43108 .15183 Mdot
.43109 .15185 Mdot
.4311 .15186 Mdot
.4311 .15188 Mdot
.43111 .1519 Mdot
.43112 .15192 Mdot
.43113 .15194 Mdot
.43114 .15195 Mdot
.43115 .15197 Mdot
.43116 .15199 Mdot
.43117 .15201 Mdot
.43118 .15203 Mdot
.43119 .15204 Mdot
.4312 .15206 Mdot
.43121 .15208 Mdot
.43122 .1521 Mdot
.43123 .15212 Mdot
.43124 .15213 Mdot
.43125 .15215 Mdot
.43126 .15217 Mdot
.43127 .15219 Mdot
.43128 .15221 Mdot
.43129 .15222 Mdot
.4313 .15224 Mdot
.4313 .15226 Mdot
.43131 .15228 Mdot
.43132 .15229 Mdot
.43133 .15231 Mdot
.43134 .15233 Mdot
.43135 .15235 Mdot
.43136 .15237 Mdot
.43137 .15238 Mdot
.43138 .1524 Mdot
.43139 .15242 Mdot
.4314 .15244 Mdot
.43141 .15246 Mdot
.43142 .15247 Mdot
.43143 .15249 Mdot
.43144 .15251 Mdot
.43145 .15253 Mdot
.43146 .15255 Mdot
.43147 .15256 Mdot
.43148 .15258 Mdot
.43149 .1526 Mdot
.4315 .15262 Mdot
.4315 .15264 Mdot
.43151 .15265 Mdot
.43152 .15267 Mdot
.43153 .15269 Mdot
.43154 .15271 Mdot
.43155 .15273 Mdot
.43156 .15274 Mdot
.43157 .15276 Mdot
.43158 .15278 Mdot
.43159 .1528 Mdot
.4316 .15282 Mdot
.43161 .15283 Mdot
.43162 .15285 Mdot
.43163 .15287 Mdot
.43164 .15289 Mdot
.43165 .15291 Mdot
.43166 .15292 Mdot
.43167 .15294 Mdot
.43168 .15296 Mdot
.43169 .15298 Mdot
.4317 .153 Mdot
.4317 .15301 Mdot
.43171 .15303 Mdot
.43172 .15305 Mdot
.43173 .15307 Mdot
.43174 .15309 Mdot
.43175 .1531 Mdot
.43176 .15312 Mdot
.43177 .15314 Mdot
.43178 .15316 Mdot
.43179 .15318 Mdot
.4318 .15319 Mdot
.43181 .15321 Mdot
.43182 .15323 Mdot
.43183 .15325 Mdot
.43184 .15327 Mdot
.43185 .15328 Mdot
.43186 .1533 Mdot
.43187 .15332 Mdot
.43188 .15334 Mdot
.43189 .15336 Mdot
.4319 .15337 Mdot
.4319 .15339 Mdot
.43191 .15341 Mdot
.43192 .15343 Mdot
.43193 .15345 Mdot
.43194 .15347 Mdot
.43195 .15348 Mdot
.43196 .1535 Mdot
.43197 .15352 Mdot
.43198 .15354 Mdot
.43199 .15356 Mdot
.432 .15357 Mdot
.43201 .15359 Mdot
.43202 .15361 Mdot
.43203 .15363 Mdot
.43204 .15365 Mdot
.43205 .15366 Mdot
.43206 .15368 Mdot
.43207 .1537 Mdot
.43208 .15372 Mdot
.43209 .15374 Mdot
.4321 .15375 Mdot
.4321 .15377 Mdot
.43211 .15379 Mdot
.43212 .15381 Mdot
.43213 .15383 Mdot
.43214 .15384 Mdot
.43215 .15386 Mdot
.43216 .15388 Mdot
.43217 .1539 Mdot
.43218 .15392 Mdot
.43219 .15393 Mdot
.4322 .15395 Mdot
.43221 .15397 Mdot
.43222 .15399 Mdot
.43223 .15401 Mdot
.43224 .15403 Mdot
.43225 .15404 Mdot
.43226 .15406 Mdot
.43227 .15408 Mdot
.43228 .1541 Mdot
.43229 .15412 Mdot
.4323 .15413 Mdot
.4323 .15415 Mdot
.43231 .15417 Mdot
.43232 .15419 Mdot
.43233 .15421 Mdot
.43234 .15422 Mdot
.43235 .15424 Mdot
.43236 .15426 Mdot
.43237 .15428 Mdot
.43238 .1543 Mdot
.43239 .15431 Mdot
.4324 .15433 Mdot
.43241 .15435 Mdot
.43242 .15437 Mdot
.43243 .15439 Mdot
.43244 .1544 Mdot
.43245 .15442 Mdot
.43246 .15444 Mdot
.43247 .15446 Mdot
.43248 .15448 Mdot
.43249 .1545 Mdot
.4325 .15451 Mdot
.4325 .15453 Mdot
.43251 .15455 Mdot
.43252 .15457 Mdot
.43253 .15459 Mdot
.43254 .1546 Mdot
.43255 .15462 Mdot
.43256 .15464 Mdot
.43257 .15466 Mdot
.43258 .15468 Mdot
.43259 .15469 Mdot
.4326 .15471 Mdot
.43261 .15473 Mdot
.43262 .15475 Mdot
.43263 .15477 Mdot
.43264 .15479 Mdot
.43265 .1548 Mdot
.43266 .15482 Mdot
.43267 .15484 Mdot
.43268 .15486 Mdot
.43269 .15488 Mdot
.4327 .15489 Mdot
.4327 .15491 Mdot
.43271 .15493 Mdot
.43272 .15495 Mdot
.43273 .15497 Mdot
.43274 .15498 Mdot
.43275 .155 Mdot
.43276 .15502 Mdot
.43277 .15504 Mdot
.43278 .15506 Mdot
.43279 .15508 Mdot
.4328 .15509 Mdot
.43281 .15511 Mdot
.43282 .15513 Mdot
.43283 .15515 Mdot
.43284 .15517 Mdot
.43285 .15518 Mdot
.43286 .1552 Mdot
.43287 .15522 Mdot
.43288 .15524 Mdot
.43289 .15526 Mdot
.4329 .15528 Mdot
.4329 .15529 Mdot
.43291 .15531 Mdot
.43292 .15533 Mdot
.43293 .15535 Mdot
.43294 .15537 Mdot
.43295 .15538 Mdot
.43296 .1554 Mdot
.43297 .15542 Mdot
.43298 .15544 Mdot
.43299 .15546 Mdot
.433 .15548 Mdot
.43301 .15549 Mdot
.43302 .15551 Mdot
.43303 .15553 Mdot
.43304 .15555 Mdot
.43305 .15557 Mdot
.43306 .15558 Mdot
.43307 .1556 Mdot
.43308 .15562 Mdot
.43309 .15564 Mdot
.4331 .15566 Mdot
.4331 .15567 Mdot
.43311 .15569 Mdot
.43312 .15571 Mdot
.43313 .15573 Mdot
.43314 .15575 Mdot
.43315 .15577 Mdot
.43316 .15578 Mdot
.43317 .1558 Mdot
.43318 .15582 Mdot
.43319 .15584 Mdot
.4332 .15586 Mdot
.43321 .15588 Mdot
.43322 .15589 Mdot
.43323 .15591 Mdot
.43324 .15593 Mdot
.43325 .15595 Mdot
.43326 .15597 Mdot
.43327 .15598 Mdot
.43328 .156 Mdot
.43329 .15602 Mdot
.4333 .15604 Mdot
.4333 .15606 Mdot
.43331 .15608 Mdot
.43332 .15609 Mdot
.43333 .15611 Mdot
.43334 .15613 Mdot
.43335 .15615 Mdot
.43336 .15617 Mdot
.43337 .15618 Mdot
.43338 .1562 Mdot
.43339 .15622 Mdot
.4334 .15624 Mdot
.43341 .15626 Mdot
.43342 .15628 Mdot
.43343 .15629 Mdot
.43344 .15631 Mdot
.43345 .15633 Mdot
.43346 .15635 Mdot
.43347 .15637 Mdot
.43348 .15639 Mdot
.43349 .1564 Mdot
.4335 .15642 Mdot
.4335 .15644 Mdot
.43351 .15646 Mdot
.43352 .15648 Mdot
.43353 .15649 Mdot
.43354 .15651 Mdot
.43355 .15653 Mdot
.43356 .15655 Mdot
.43357 .15657 Mdot
.43358 .15659 Mdot
.43359 .1566 Mdot
.4336 .15662 Mdot
.43361 .15664 Mdot
.43362 .15666 Mdot
.43363 .15668 Mdot
.43364 .1567 Mdot
.43365 .15671 Mdot
.43366 .15673 Mdot
.43367 .15675 Mdot
.43368 .15677 Mdot
.43369 .15679 Mdot
.4337 .1568 Mdot
.4337 .15682 Mdot
.43371 .15684 Mdot
.43372 .15686 Mdot
.43373 .15688 Mdot
.43374 .1569 Mdot
.43375 .15691 Mdot
.43376 .15693 Mdot
.43377 .15695 Mdot
.43378 .15697 Mdot
.43379 .15699 Mdot
.4338 .15701 Mdot
.43381 .15702 Mdot
.43382 .15704 Mdot
.43383 .15706 Mdot
.43384 .15708 Mdot
.43385 .1571 Mdot
.43386 .15712 Mdot
.43387 .15713 Mdot
.43388 .15715 Mdot
.43389 .15717 Mdot
.4339 .15719 Mdot
.4339 .15721 Mdot
.43391 .15722 Mdot
.43392 .15724 Mdot
.43393 .15726 Mdot
.43394 .15728 Mdot
.43395 .1573 Mdot
.43396 .15732 Mdot
.43397 .15733 Mdot
.43398 .15735 Mdot
.43399 .15737 Mdot
.434 .15739 Mdot
.43401 .15741 Mdot
.43402 .15743 Mdot
.43403 .15744 Mdot
.43404 .15746 Mdot
.43405 .15748 Mdot
.43406 .1575 Mdot
.43407 .15752 Mdot
.43408 .15754 Mdot
.43409 .15755 Mdot
.4341 .15757 Mdot
.4341 .15759 Mdot
.43411 .15761 Mdot
.43412 .15763 Mdot
.43413 .15765 Mdot
.43414 .15766 Mdot
.43415 .15768 Mdot
.43416 .1577 Mdot
.43417 .15772 Mdot
.43418 .15774 Mdot
.43419 .15776 Mdot
.4342 .15777 Mdot
.43421 .15779 Mdot
.43422 .15781 Mdot
.43423 .15783 Mdot
.43424 .15785 Mdot
.43425 .15787 Mdot
.43426 .15788 Mdot
.43427 .1579 Mdot
.43428 .15792 Mdot
.43429 .15794 Mdot
.4343 .15796 Mdot
.4343 .15798 Mdot
.43431 .15799 Mdot
.43432 .15801 Mdot
.43433 .15803 Mdot
.43434 .15805 Mdot
.43435 .15807 Mdot
.43436 .15809 Mdot
.43437 .1581 Mdot
.43438 .15812 Mdot
.43439 .15814 Mdot
.4344 .15816 Mdot
.43441 .15818 Mdot
.43442 .1582 Mdot
.43443 .15821 Mdot
.43444 .15823 Mdot
.43445 .15825 Mdot
.43446 .15827 Mdot
.43447 .15829 Mdot
.43448 .15831 Mdot
.43449 .15832 Mdot
.4345 .15834 Mdot
.4345 .15836 Mdot
.43451 .15838 Mdot
.43452 .1584 Mdot
.43453 .15842 Mdot
.43454 .15843 Mdot
.43455 .15845 Mdot
.43456 .15847 Mdot
.43457 .15849 Mdot
.43458 .15851 Mdot
.43459 .15853 Mdot
.4346 .15854 Mdot
.43461 .15856 Mdot
.43462 .15858 Mdot
.43463 .1586 Mdot
.43464 .15862 Mdot
.43465 .15864 Mdot
.43466 .15865 Mdot
.43467 .15867 Mdot
.43468 .15869 Mdot
.43469 .15871 Mdot
.4347 .15873 Mdot
.4347 .15875 Mdot
.43471 .15876 Mdot
.43472 .15878 Mdot
.43473 .1588 Mdot
.43474 .15882 Mdot
.43475 .15884 Mdot
.43476 .15886 Mdot
.43477 .15887 Mdot
.43478 .15889 Mdot
.43479 .15891 Mdot
.4348 .15893 Mdot
.43481 .15895 Mdot
.43482 .15897 Mdot
.43483 .15899 Mdot
.43484 .159 Mdot
.43485 .15902 Mdot
.43486 .15904 Mdot
.43487 .15906 Mdot
.43488 .15908 Mdot
.43489 .1591 Mdot
.4349 .15911 Mdot
.4349 .15913 Mdot
.43491 .15915 Mdot
.43492 .15917 Mdot
.43493 .15919 Mdot
.43494 .15921 Mdot
.43495 .15922 Mdot
.43496 .15924 Mdot
.43497 .15926 Mdot
.43498 .15928 Mdot
.43499 .1593 Mdot
.435 .15932 Mdot
.43501 .15933 Mdot
.43502 .15935 Mdot
.43503 .15937 Mdot
.43504 .15939 Mdot
.43505 .15941 Mdot
.43506 .15943 Mdot
.43507 .15945 Mdot
.43508 .15946 Mdot
.43509 .15948 Mdot
.4351 .1595 Mdot
.4351 .15952 Mdot
.43511 .15954 Mdot
.43512 .15956 Mdot
.43513 .15957 Mdot
.43514 .15959 Mdot
.43515 .15961 Mdot
.43516 .15963 Mdot
.43517 .15965 Mdot
.43518 .15967 Mdot
.43519 .15968 Mdot
.4352 .1597 Mdot
.43521 .15972 Mdot
.43522 .15974 Mdot
.43523 .15976 Mdot
.43524 .15978 Mdot
.43525 .1598 Mdot
.43526 .15981 Mdot
.43527 .15983 Mdot
.43528 .15985 Mdot
.43529 .15987 Mdot
.4353 .15989 Mdot
.4353 .15991 Mdot
.43531 .15992 Mdot
.43532 .15994 Mdot
.43533 .15996 Mdot
.43534 .15998 Mdot
.43535 .16 Mdot
.43536 .16002 Mdot
.43537 .16004 Mdot
.43538 .16005 Mdot
.43539 .16007 Mdot
.4354 .16009 Mdot
.43541 .16011 Mdot
.43542 .16013 Mdot
.43543 .16015 Mdot
.43544 .16016 Mdot
.43545 .16018 Mdot
.43546 .1602 Mdot
.43547 .16022 Mdot
.43548 .16024 Mdot
.43549 .16026 Mdot
.4355 .16028 Mdot
.4355 .16029 Mdot
.43551 .16031 Mdot
.43552 .16033 Mdot
.43553 .16035 Mdot
.43554 .16037 Mdot
.43555 .16039 Mdot
.43556 .1604 Mdot
.43557 .16042 Mdot
.43558 .16044 Mdot
.43559 .16046 Mdot
.4356 .16048 Mdot
.43561 .1605 Mdot
.43562 .16052 Mdot
.43563 .16053 Mdot
.43564 .16055 Mdot
.43565 .16057 Mdot
.43566 .16059 Mdot
.43567 .16061 Mdot
.43568 .16063 Mdot
.43569 .16065 Mdot
.4357 .16066 Mdot
.4357 .16068 Mdot
.43571 .1607 Mdot
.43572 .16072 Mdot
.43573 .16074 Mdot
.43574 .16076 Mdot
.43575 .16077 Mdot
.43576 .16079 Mdot
.43577 .16081 Mdot
.43578 .16083 Mdot
.43579 .16085 Mdot
.4358 .16087 Mdot
.43581 .16089 Mdot
.43582 .1609 Mdot
.43583 .16092 Mdot
.43584 .16094 Mdot
.43585 .16096 Mdot
.43586 .16098 Mdot
.43587 .161 Mdot
.43588 .16102 Mdot
.43589 .16103 Mdot
.4359 .16105 Mdot
.4359 .16107 Mdot
.43591 .16109 Mdot
.43592 .16111 Mdot
.43593 .16113 Mdot
.43594 .16114 Mdot
.43595 .16116 Mdot
.43596 .16118 Mdot
.43597 .1612 Mdot
.43598 .16122 Mdot
.43599 .16124 Mdot
.436 .16126 Mdot
.43601 .16127 Mdot
.43602 .16129 Mdot
.43603 .16131 Mdot
.43604 .16133 Mdot
.43605 .16135 Mdot
.43606 .16137 Mdot
.43607 .16139 Mdot
.43608 .1614 Mdot
.43609 .16142 Mdot
.4361 .16144 Mdot
.4361 .16146 Mdot
.43611 .16148 Mdot
.43612 .1615 Mdot
.43613 .16152 Mdot
.43614 .16153 Mdot
.43615 .16155 Mdot
.43616 .16157 Mdot
.43617 .16159 Mdot
.43618 .16161 Mdot
.43619 .16163 Mdot
.4362 .16165 Mdot
.43621 .16166 Mdot
.43622 .16168 Mdot
.43623 .1617 Mdot
.43624 .16172 Mdot
.43625 .16174 Mdot
.43626 .16176 Mdot
.43627 .16178 Mdot
.43628 .16179 Mdot
.43629 .16181 Mdot
.4363 .16183 Mdot
.4363 .16185 Mdot
.43631 .16187 Mdot
.43632 .16189 Mdot
.43633 .16191 Mdot
.43634 .16192 Mdot
.43635 .16194 Mdot
.43636 .16196 Mdot
.43637 .16198 Mdot
.43638 .162 Mdot
.43639 .16202 Mdot
.4364 .16204 Mdot
.43641 .16205 Mdot
.43642 .16207 Mdot
.43643 .16209 Mdot
.43644 .16211 Mdot
.43645 .16213 Mdot
.43646 .16215 Mdot
.43647 .16217 Mdot
.43648 .16218 Mdot
.43649 .1622 Mdot
.4365 .16222 Mdot
.4365 .16224 Mdot
.43651 .16226 Mdot
.43652 .16228 Mdot
.43653 .1623 Mdot
.43654 .16231 Mdot
.43655 .16233 Mdot
.43656 .16235 Mdot
.43657 .16237 Mdot
.43658 .16239 Mdot
.43659 .16241 Mdot
.4366 .16243 Mdot
.43661 .16244 Mdot
.43662 .16246 Mdot
.43663 .16248 Mdot
.43664 .1625 Mdot
.43665 .16252 Mdot
.43666 .16254 Mdot
.43667 .16256 Mdot
.43668 .16258 Mdot
.43669 .16259 Mdot
.4367 .16261 Mdot
.4367 .16263 Mdot
.43671 .16265 Mdot
.43672 .16267 Mdot
.43673 .16269 Mdot
.43674 .16271 Mdot
.43675 .16272 Mdot
.43676 .16274 Mdot
.43677 .16276 Mdot
.43678 .16278 Mdot
.43679 .1628 Mdot
.4368 .16282 Mdot
.43681 .16284 Mdot
.43682 .16285 Mdot
.43683 .16287 Mdot
.43684 .16289 Mdot
.43685 .16291 Mdot
.43686 .16293 Mdot
.43687 .16295 Mdot
.43688 .16297 Mdot
.43689 .16298 Mdot
.4369 .163 Mdot
.4369 .16302 Mdot
.43691 .16304 Mdot
.43692 .16306 Mdot
.43693 .16308 Mdot
.43694 .1631 Mdot
.43695 .16312 Mdot
.43696 .16313 Mdot
.43697 .16315 Mdot
.43698 .16317 Mdot
.43699 .16319 Mdot
.437 .16321 Mdot
.43701 .16323 Mdot
.43702 .16325 Mdot
.43703 .16326 Mdot
.43704 .16328 Mdot
.43705 .1633 Mdot
.43706 .16332 Mdot
.43707 .16334 Mdot
.43708 .16336 Mdot
.43709 .16338 Mdot
.4371 .1634 Mdot
.4371 .16341 Mdot
.43711 .16343 Mdot
.43712 .16345 Mdot
.43713 .16347 Mdot
.43714 .16349 Mdot
.43715 .16351 Mdot
.43716 .16353 Mdot
.43717 .16354 Mdot
.43718 .16356 Mdot
.43719 .16358 Mdot
.4372 .1636 Mdot
.43721 .16362 Mdot
.43722 .16364 Mdot
.43723 .16366 Mdot
.43724 .16368 Mdot
.43725 .16369 Mdot
.43726 .16371 Mdot
.43727 .16373 Mdot
.43728 .16375 Mdot
.43729 .16377 Mdot
.4373 .16379 Mdot
.4373 .16381 Mdot
.43731 .16382 Mdot
.43732 .16384 Mdot
.43733 .16386 Mdot
.43734 .16388 Mdot
.43735 .1639 Mdot
.43736 .16392 Mdot
.43737 .16394 Mdot
.43738 .16396 Mdot
.43739 .16397 Mdot
.4374 .16399 Mdot
.43741 .16401 Mdot
.43742 .16403 Mdot
.43743 .16405 Mdot
.43744 .16407 Mdot
.43745 .16409 Mdot
.43746 .16411 Mdot
.43747 .16412 Mdot
.43748 .16414 Mdot
.43749 .16416 Mdot
.4375 .16418 Mdot
.4375 .1642 Mdot
.43751 .16422 Mdot
.43752 .16424 Mdot
.43753 .16426 Mdot
.43754 .16427 Mdot
.43755 .16429 Mdot
.43756 .16431 Mdot
.43757 .16433 Mdot
.43758 .16435 Mdot
.43759 .16437 Mdot
.4376 .16439 Mdot
.43761 .1644 Mdot
.43762 .16442 Mdot
.43763 .16444 Mdot
.43764 .16446 Mdot
.43765 .16448 Mdot
.43766 .1645 Mdot
.43767 .16452 Mdot
.43768 .16454 Mdot
.43769 .16455 Mdot
.4377 .16457 Mdot
.4377 .16459 Mdot
.43771 .16461 Mdot
.43772 .16463 Mdot
.43773 .16465 Mdot
.43774 .16467 Mdot
.43775 .16469 Mdot
.43776 .1647 Mdot
.43777 .16472 Mdot
.43778 .16474 Mdot
.43779 .16476 Mdot
.4378 .16478 Mdot
.43781 .1648 Mdot
.43782 .16482 Mdot
.43783 .16484 Mdot
.43784 .16485 Mdot
.43785 .16487 Mdot
.43786 .16489 Mdot
.43787 .16491 Mdot
.43788 .16493 Mdot
.43789 .16495 Mdot
.4379 .16497 Mdot
.4379 .16499 Mdot
.43791 .165 Mdot
.43792 .16502 Mdot
.43793 .16504 Mdot
.43794 .16506 Mdot
.43795 .16508 Mdot
.43796 .1651 Mdot
.43797 .16512 Mdot
.43798 .16514 Mdot
.43799 .16515 Mdot
.438 .16517 Mdot
.43801 .16519 Mdot
.43802 .16521 Mdot
.43803 .16523 Mdot
.43804 .16525 Mdot
.43805 .16527 Mdot
.43806 .16529 Mdot
.43807 .16531 Mdot
.43808 .16532 Mdot
.43809 .16534 Mdot
.4381 .16536 Mdot
.4381 .16538 Mdot
.43811 .1654 Mdot
.43812 .16542 Mdot
.43813 .16544 Mdot
.43814 .16546 Mdot
.43815 .16547 Mdot
.43816 .16549 Mdot
.43817 .16551 Mdot
.43818 .16553 Mdot
.43819 .16555 Mdot
.4382 .16557 Mdot
.43821 .16559 Mdot
.43822 .16561 Mdot
.43823 .16562 Mdot
.43824 .16564 Mdot
.43825 .16566 Mdot
.43826 .16568 Mdot
.43827 .1657 Mdot
.43828 .16572 Mdot
.43829 .16574 Mdot
.4383 .16576 Mdot
.4383 .16578 Mdot
.43831 .16579 Mdot
.43832 .16581 Mdot
.43833 .16583 Mdot
.43834 .16585 Mdot
.43835 .16587 Mdot
.43836 .16589 Mdot
.43837 .16591 Mdot
.43838 .16593 Mdot
.43839 .16594 Mdot
.4384 .16596 Mdot
.43841 .16598 Mdot
.43842 .166 Mdot
.43843 .16602 Mdot
.43844 .16604 Mdot
.43845 .16606 Mdot
.43846 .16608 Mdot
.43847 .1661 Mdot
.43848 .16611 Mdot
.43849 .16613 Mdot
.4385 .16615 Mdot
.4385 .16617 Mdot
.43851 .16619 Mdot
.43852 .16621 Mdot
.43853 .16623 Mdot
.43854 .16625 Mdot
.43855 .16626 Mdot
.43856 .16628 Mdot
.43857 .1663 Mdot
.43858 .16632 Mdot
.43859 .16634 Mdot
.4386 .16636 Mdot
.43861 .16638 Mdot
.43862 .1664 Mdot
.43863 .16642 Mdot
.43864 .16643 Mdot
.43865 .16645 Mdot
.43866 .16647 Mdot
.43867 .16649 Mdot
.43868 .16651 Mdot
.43869 .16653 Mdot
.4387 .16655 Mdot
.4387 .16657 Mdot
.43871 .16659 Mdot
.43872 .1666 Mdot
.43873 .16662 Mdot
.43874 .16664 Mdot
.43875 .16666 Mdot
.43876 .16668 Mdot
.43877 .1667 Mdot
.43878 .16672 Mdot
.43879 .16674 Mdot
.4388 .16676 Mdot
.43881 .16677 Mdot
.43882 .16679 Mdot
.43883 .16681 Mdot
.43884 .16683 Mdot
.43885 .16685 Mdot
.43886 .16687 Mdot
.43887 .16689 Mdot
.43888 .16691 Mdot
.43889 .16692 Mdot
.4389 .16694 Mdot
.4389 .16696 Mdot
.43891 .16698 Mdot
.43892 .167 Mdot
.43893 .16702 Mdot
.43894 .16704 Mdot
.43895 .16706 Mdot
.43896 .16708 Mdot
.43897 .16709 Mdot
.43898 .16711 Mdot
.43899 .16713 Mdot
.439 .16715 Mdot
.43901 .16717 Mdot
.43902 .16719 Mdot
.43903 .16721 Mdot
.43904 .16723 Mdot
.43905 .16725 Mdot
.43906 .16726 Mdot
.43907 .16728 Mdot
.43908 .1673 Mdot
.43909 .16732 Mdot
.4391 .16734 Mdot
.4391 .16736 Mdot
.43911 .16738 Mdot
.43912 .1674 Mdot
.43913 .16742 Mdot
.43914 .16744 Mdot
.43915 .16745 Mdot
.43916 .16747 Mdot
.43917 .16749 Mdot
.43918 .16751 Mdot
.43919 .16753 Mdot
.4392 .16755 Mdot
.43921 .16757 Mdot
.43922 .16759 Mdot
.43923 .16761 Mdot
.43924 .16762 Mdot
.43925 .16764 Mdot
.43926 .16766 Mdot
.43927 .16768 Mdot
.43928 .1677 Mdot
.43929 .16772 Mdot
.4393 .16774 Mdot
.4393 .16776 Mdot
.43931 .16778 Mdot
.43932 .16779 Mdot
.43933 .16781 Mdot
.43934 .16783 Mdot
.43935 .16785 Mdot
.43936 .16787 Mdot
.43937 .16789 Mdot
.43938 .16791 Mdot
.43939 .16793 Mdot
.4394 .16795 Mdot
.43941 .16797 Mdot
.43942 .16798 Mdot
.43943 .168 Mdot
.43944 .16802 Mdot
.43945 .16804 Mdot
.43946 .16806 Mdot
.43947 .16808 Mdot
.43948 .1681 Mdot
.43949 .16812 Mdot
.4395 .16814 Mdot
.4395 .16815 Mdot
.43951 .16817 Mdot
.43952 .16819 Mdot
.43953 .16821 Mdot
.43954 .16823 Mdot
.43955 .16825 Mdot
.43956 .16827 Mdot
.43957 .16829 Mdot
.43958 .16831 Mdot
.43959 .16833 Mdot
.4396 .16834 Mdot
.43961 .16836 Mdot
.43962 .16838 Mdot
.43963 .1684 Mdot
.43964 .16842 Mdot
.43965 .16844 Mdot
.43966 .16846 Mdot
.43967 .16848 Mdot
.43968 .1685 Mdot
.43969 .16852 Mdot
.4397 .16853 Mdot
.4397 .16855 Mdot
.43971 .16857 Mdot
.43972 .16859 Mdot
.43973 .16861 Mdot
.43974 .16863 Mdot
.43975 .16865 Mdot
.43976 .16867 Mdot
.43977 .16869 Mdot
.43978 .1687 Mdot
.43979 .16872 Mdot
.4398 .16874 Mdot
.43981 .16876 Mdot
.43982 .16878 Mdot
.43983 .1688 Mdot
.43984 .16882 Mdot
.43985 .16884 Mdot
.43986 .16886 Mdot
.43987 .16888 Mdot
.43988 .16889 Mdot
.43989 .16891 Mdot
.4399 .16893 Mdot
.4399 .16895 Mdot
.43991 .16897 Mdot
.43992 .16899 Mdot
.43993 .16901 Mdot
.43994 .16903 Mdot
.43995 .16905 Mdot
.43996 .16907 Mdot
.43997 .16909 Mdot
.43998 .1691 Mdot
.43999 .16912 Mdot
.44 .16914 Mdot
.44001 .16916 Mdot
.44002 .16918 Mdot
.44003 .1692 Mdot
.44004 .16922 Mdot
.44005 .16924 Mdot
.44006 .16926 Mdot
.44007 .16928 Mdot
.44008 .16929 Mdot
.44009 .16931 Mdot
.4401 .16933 Mdot
.4401 .16935 Mdot
.44011 .16937 Mdot
.44012 .16939 Mdot
.44013 .16941 Mdot
.44014 .16943 Mdot
.44015 .16945 Mdot
.44016 .16947 Mdot
.44017 .16948 Mdot
.44018 .1695 Mdot
.44019 .16952 Mdot
.4402 .16954 Mdot
.44021 .16956 Mdot
.44022 .16958 Mdot
.44023 .1696 Mdot
.44024 .16962 Mdot
.44025 .16964 Mdot
.44026 .16966 Mdot
.44027 .16967 Mdot
.44028 .16969 Mdot
.44029 .16971 Mdot
.4403 .16973 Mdot
.4403 .16975 Mdot
.44031 .16977 Mdot
.44032 .16979 Mdot
.44033 .16981 Mdot
.44034 .16983 Mdot
.44035 .16985 Mdot
.44036 .16987 Mdot
.44037 .16988 Mdot
.44038 .1699 Mdot
.44039 .16992 Mdot
.4404 .16994 Mdot
.44041 .16996 Mdot
.44042 .16998 Mdot
.44043 .17 Mdot
.44044 .17002 Mdot
.44045 .17004 Mdot
.44046 .17006 Mdot
.44047 .17008 Mdot
.44048 .17009 Mdot
.44049 .17011 Mdot
.4405 .17013 Mdot
.4405 .17015 Mdot
.44051 .17017 Mdot
.44052 .17019 Mdot
.44053 .17021 Mdot
.44054 .17023 Mdot
.44055 .17025 Mdot
.44056 .17027 Mdot
.44057 .17029 Mdot
.44058 .1703 Mdot
.44059 .17032 Mdot
.4406 .17034 Mdot
.44061 .17036 Mdot
.44062 .17038 Mdot
.44063 .1704 Mdot
.44064 .17042 Mdot
.44065 .17044 Mdot
.44066 .17046 Mdot
.44067 .17048 Mdot
.44068 .1705 Mdot
.44069 .17051 Mdot
.4407 .17053 Mdot
.4407 .17055 Mdot
.44071 .17057 Mdot
.44072 .17059 Mdot
.44073 .17061 Mdot
.44074 .17063 Mdot
.44075 .17065 Mdot
.44076 .17067 Mdot
.44077 .17069 Mdot
.44078 .17071 Mdot
.44079 .17072 Mdot
.4408 .17074 Mdot
.44081 .17076 Mdot
.44082 .17078 Mdot
.44083 .1708 Mdot
.44084 .17082 Mdot
.44085 .17084 Mdot
.44086 .17086 Mdot
.44087 .17088 Mdot
.44088 .1709 Mdot
.44089 .17092 Mdot
.4409 .17093 Mdot
.4409 .17095 Mdot
.44091 .17097 Mdot
.44092 .17099 Mdot
.44093 .17101 Mdot
.44094 .17103 Mdot
.44095 .17105 Mdot
.44096 .17107 Mdot
.44097 .17109 Mdot
.44098 .17111 Mdot
.44099 .17113 Mdot
.441 .17115 Mdot
.44101 .17116 Mdot
.44102 .17118 Mdot
.44103 .1712 Mdot
.44104 .17122 Mdot
.44105 .17124 Mdot
.44106 .17126 Mdot
.44107 .17128 Mdot
.44108 .1713 Mdot
.44109 .17132 Mdot
.4411 .17134 Mdot
.4411 .17136 Mdot
.44111 .17137 Mdot
.44112 .17139 Mdot
.44113 .17141 Mdot
.44114 .17143 Mdot
.44115 .17145 Mdot
.44116 .17147 Mdot
.44117 .17149 Mdot
.44118 .17151 Mdot
.44119 .17153 Mdot
.4412 .17155 Mdot
.44121 .17157 Mdot
.44122 .17159 Mdot
.44123 .1716 Mdot
.44124 .17162 Mdot
.44125 .17164 Mdot
.44126 .17166 Mdot
.44127 .17168 Mdot
.44128 .1717 Mdot
.44129 .17172 Mdot
.4413 .17174 Mdot
.4413 .17176 Mdot
.44131 .17178 Mdot
.44132 .1718 Mdot
.44133 .17182 Mdot
.44134 .17183 Mdot
.44135 .17185 Mdot
.44136 .17187 Mdot
.44137 .17189 Mdot
.44138 .17191 Mdot
.44139 .17193 Mdot
.4414 .17195 Mdot
.44141 .17197 Mdot
.44142 .17199 Mdot
.44143 .17201 Mdot
.44144 .17203 Mdot
.44145 .17205 Mdot
.44146 .17207 Mdot
.44147 .17208 Mdot
.44148 .1721 Mdot
.44149 .17212 Mdot
.4415 .17214 Mdot
.4415 .17216 Mdot
.44151 .17218 Mdot
.44152 .1722 Mdot
.44153 .17222 Mdot
.44154 .17224 Mdot
.44155 .17226 Mdot
.44156 .17228 Mdot
.44157 .1723 Mdot
.44158 .17231 Mdot
.44159 .17233 Mdot
.4416 .17235 Mdot
.44161 .17237 Mdot
.44162 .17239 Mdot
.44163 .17241 Mdot
.44164 .17243 Mdot
.44165 .17245 Mdot
.44166 .17247 Mdot
.44167 .17249 Mdot
.44168 .17251 Mdot
.44169 .17253 Mdot
.4417 .17255 Mdot
.4417 .17256 Mdot
.44171 .17258 Mdot
.44172 .1726 Mdot
.44173 .17262 Mdot
.44174 .17264 Mdot
.44175 .17266 Mdot
.44176 .17268 Mdot
.44177 .1727 Mdot
.44178 .17272 Mdot
.44179 .17274 Mdot
.4418 .17276 Mdot
.44181 .17278 Mdot
.44182 .1728 Mdot
.44183 .17281 Mdot
.44184 .17283 Mdot
.44185 .17285 Mdot
.44186 .17287 Mdot
.44187 .17289 Mdot
.44188 .17291 Mdot
.44189 .17293 Mdot
.4419 .17295 Mdot
.4419 .17297 Mdot
.44191 .17299 Mdot
.44192 .17301 Mdot
.44193 .17303 Mdot
.44194 .17305 Mdot
.44195 .17306 Mdot
.44196 .17308 Mdot
.44197 .1731 Mdot
.44198 .17312 Mdot
.44199 .17314 Mdot
.442 .17316 Mdot
.44201 .17318 Mdot
.44202 .1732 Mdot
.44203 .17322 Mdot
.44204 .17324 Mdot
.44205 .17326 Mdot
.44206 .17328 Mdot
.44207 .1733 Mdot
.44208 .17331 Mdot
.44209 .17333 Mdot
.4421 .17335 Mdot
.4421 .17337 Mdot
.44211 .17339 Mdot
.44212 .17341 Mdot
.44213 .17343 Mdot
.44214 .17345 Mdot
.44215 .17347 Mdot
.44216 .17349 Mdot
.44217 .17351 Mdot
.44218 .17353 Mdot
.44219 .17355 Mdot
.4422 .17357 Mdot
.44221 .17358 Mdot
.44222 .1736 Mdot
.44223 .17362 Mdot
.44224 .17364 Mdot
.44225 .17366 Mdot
.44226 .17368 Mdot
.44227 .1737 Mdot
.44228 .17372 Mdot
.44229 .17374 Mdot
.4423 .17376 Mdot
.4423 .17378 Mdot
.44231 .1738 Mdot
.44232 .17382 Mdot
.44233 .17384 Mdot
.44234 .17385 Mdot
.44235 .17387 Mdot
.44236 .17389 Mdot
.44237 .17391 Mdot
.44238 .17393 Mdot
.44239 .17395 Mdot
.4424 .17397 Mdot
.44241 .17399 Mdot
.44242 .17401 Mdot
.44243 .17403 Mdot
.44244 .17405 Mdot
.44245 .17407 Mdot
.44246 .17409 Mdot
.44247 .17411 Mdot
.44248 .17413 Mdot
.44249 .17414 Mdot
.4425 .17416 Mdot
.4425 .17418 Mdot
.44251 .1742 Mdot
.44252 .17422 Mdot
.44253 .17424 Mdot
.44254 .17426 Mdot
.44255 .17428 Mdot
.44256 .1743 Mdot
.44257 .17432 Mdot
.44258 .17434 Mdot
.44259 .17436 Mdot
.4426 .17438 Mdot
.44261 .1744 Mdot
.44262 .17442 Mdot
.44263 .17443 Mdot
.44264 .17445 Mdot
.44265 .17447 Mdot
.44266 .17449 Mdot
.44267 .17451 Mdot
.44268 .17453 Mdot
.44269 .17455 Mdot
.4427 .17457 Mdot
.4427 .17459 Mdot
.44271 .17461 Mdot
.44272 .17463 Mdot
.44273 .17465 Mdot
.44274 .17467 Mdot
.44275 .17469 Mdot
.44276 .17471 Mdot
.44277 .17472 Mdot
.44278 .17474 Mdot
.44279 .17476 Mdot
.4428 .17478 Mdot
.44281 .1748 Mdot
.44282 .17482 Mdot
.44283 .17484 Mdot
.44284 .17486 Mdot
.44285 .17488 Mdot
.44286 .1749 Mdot
.44287 .17492 Mdot
.44288 .17494 Mdot
.44289 .17496 Mdot
.4429 .17498 Mdot
.4429 .175 Mdot
.44291 .17501 Mdot
.44292 .17503 Mdot
.44293 .17505 Mdot
.44294 .17507 Mdot
.44295 .17509 Mdot
.44296 .17511 Mdot
.44297 .17513 Mdot
.44298 .17515 Mdot
.44299 .17517 Mdot
.443 .17519 Mdot
.44301 .17521 Mdot
.44302 .17523 Mdot
.44303 .17525 Mdot
.44304 .17527 Mdot
.44305 .17529 Mdot
.44306 .17531 Mdot
.44307 .17532 Mdot
.44308 .17534 Mdot
.44309 .17536 Mdot
.4431 .17538 Mdot
.4431 .1754 Mdot
.44311 .17542 Mdot
.44312 .17544 Mdot
.44313 .17546 Mdot
.44314 .17548 Mdot
.44315 .1755 Mdot
.44316 .17552 Mdot
.44317 .17554 Mdot
.44318 .17556 Mdot
.44319 .17558 Mdot
.4432 .1756 Mdot
.44321 .17562 Mdot
.44322 .17564 Mdot
.44323 .17565 Mdot
.44324 .17567 Mdot
.44325 .17569 Mdot
.44326 .17571 Mdot
.44327 .17573 Mdot
.44328 .17575 Mdot
.44329 .17577 Mdot
.4433 .17579 Mdot
.4433 .17581 Mdot
.44331 .17583 Mdot
.44332 .17585 Mdot
.44333 .17587 Mdot
.44334 .17589 Mdot
.44335 .17591 Mdot
.44336 .17593 Mdot
.44337 .17595 Mdot
.44338 .17597 Mdot
.44339 .17598 Mdot
.4434 .176 Mdot
.44341 .17602 Mdot
.44342 .17604 Mdot
.44343 .17606 Mdot
.44344 .17608 Mdot
.44345 .1761 Mdot
.44346 .17612 Mdot
.44347 .17614 Mdot
.44348 .17616 Mdot
.44349 .17618 Mdot
.4435 .1762 Mdot
.4435 .17622 Mdot
.44351 .17624 Mdot
.44352 .17626 Mdot
.44353 .17628 Mdot
.44354 .1763 Mdot
.44355 .17632 Mdot
.44356 .17633 Mdot
.44357 .17635 Mdot
.44358 .17637 Mdot
.44359 .17639 Mdot
.4436 .17641 Mdot
.44361 .17643 Mdot
.44362 .17645 Mdot
.44363 .17647 Mdot
.44364 .17649 Mdot
.44365 .17651 Mdot
.44366 .17653 Mdot
.44367 .17655 Mdot
.44368 .17657 Mdot
.44369 .17659 Mdot
.4437 .17661 Mdot
.4437 .17663 Mdot
.44371 .17665 Mdot
.44372 .17667 Mdot
.44373 .17668 Mdot
.44374 .1767 Mdot
.44375 .17672 Mdot
.44376 .17674 Mdot
.44377 .17676 Mdot
.44378 .17678 Mdot
.44379 .1768 Mdot
.4438 .17682 Mdot
.44381 .17684 Mdot
.44382 .17686 Mdot
.44383 .17688 Mdot
.44384 .1769 Mdot
.44385 .17692 Mdot
.44386 .17694 Mdot
.44387 .17696 Mdot
.44388 .17698 Mdot
.44389 .177 Mdot
.4439 .17702 Mdot
.4439 .17704 Mdot
.44391 .17705 Mdot
.44392 .17707 Mdot
.44393 .17709 Mdot
.44394 .17711 Mdot
.44395 .17713 Mdot
.44396 .17715 Mdot
.44397 .17717 Mdot
.44398 .17719 Mdot
.44399 .17721 Mdot
.444 .17723 Mdot
.44401 .17725 Mdot
.44402 .17727 Mdot
.44403 .17729 Mdot
.44404 .17731 Mdot
.44405 .17733 Mdot
.44406 .17735 Mdot
.44407 .17737 Mdot
.44408 .17739 Mdot
.44409 .17741 Mdot
.4441 .17743 Mdot
.4441 .17744 Mdot
.44411 .17746 Mdot
.44412 .17748 Mdot
.44413 .1775 Mdot
.44414 .17752 Mdot
.44415 .17754 Mdot
.44416 .17756 Mdot
.44417 .17758 Mdot
.44418 .1776 Mdot
.44419 .17762 Mdot
.4442 .17764 Mdot
.44421 .17766 Mdot
.44422 .17768 Mdot
.44423 .1777 Mdot
.44424 .17772 Mdot
.44425 .17774 Mdot
.44426 .17776 Mdot
.44427 .17778 Mdot
.44428 .1778 Mdot
.44429 .17782 Mdot
.4443 .17784 Mdot
.4443 .17785 Mdot
.44431 .17787 Mdot
.44432 .17789 Mdot
.44433 .17791 Mdot
.44434 .17793 Mdot
.44435 .17795 Mdot
.44436 .17797 Mdot
.44437 .17799 Mdot
.44438 .17801 Mdot
.44439 .17803 Mdot
.4444 .17805 Mdot
.44441 .17807 Mdot
.44442 .17809 Mdot
.44443 .17811 Mdot
.44444 .17813 Mdot
.44445 .17815 Mdot
.44446 .17817 Mdot
.44447 .17819 Mdot
.44448 .17821 Mdot
.44449 .17823 Mdot
.4445 .17825 Mdot
.4445 .17827 Mdot
.44451 .17828 Mdot
.44452 .1783 Mdot
.44453 .17832 Mdot
.44454 .17834 Mdot
.44455 .17836 Mdot
.44456 .17838 Mdot
.44457 .1784 Mdot
.44458 .17842 Mdot
.44459 .17844 Mdot
.4446 .17846 Mdot
.44461 .17848 Mdot
.44462 .1785 Mdot
.44463 .17852 Mdot
.44464 .17854 Mdot
.44465 .17856 Mdot
.44466 .17858 Mdot
.44467 .1786 Mdot
.44468 .17862 Mdot
.44469 .17864 Mdot
.4447 .17866 Mdot
.4447 .17868 Mdot
.44471 .1787 Mdot
.44472 .17872 Mdot
.44473 .17873 Mdot
.44474 .17875 Mdot
.44475 .17877 Mdot
.44476 .17879 Mdot
.44477 .17881 Mdot
.44478 .17883 Mdot
.44479 .17885 Mdot
.4448 .17887 Mdot
.44481 .17889 Mdot
.44482 .17891 Mdot
.44483 .17893 Mdot
.44484 .17895 Mdot
.44485 .17897 Mdot
.44486 .17899 Mdot
.44487 .17901 Mdot
.44488 .17903 Mdot
.44489 .17905 Mdot
.4449 .17907 Mdot
.4449 .17909 Mdot
.44491 .17911 Mdot
.44492 .17913 Mdot
.44493 .17915 Mdot
.44494 .17917 Mdot
.44495 .17919 Mdot
.44496 .17921 Mdot
.44497 .17922 Mdot
.44498 .17924 Mdot
.44499 .17926 Mdot
.445 .17928 Mdot
.44501 .1793 Mdot
.44502 .17932 Mdot
.44503 .17934 Mdot
.44504 .17936 Mdot
.44505 .17938 Mdot
.44506 .1794 Mdot
.44507 .17942 Mdot
.44508 .17944 Mdot
.44509 .17946 Mdot
.4451 .17948 Mdot
.4451 .1795 Mdot
.44511 .17952 Mdot
.44512 .17954 Mdot
.44513 .17956 Mdot
.44514 .17958 Mdot
.44515 .1796 Mdot
.44516 .17962 Mdot
.44517 .17964 Mdot
.44518 .17966 Mdot
.44519 .17968 Mdot
.4452 .1797 Mdot
.44521 .17972 Mdot
.44522 .17974 Mdot
.44523 .17975 Mdot
.44524 .17977 Mdot
.44525 .17979 Mdot
.44526 .17981 Mdot
.44527 .17983 Mdot
.44528 .17985 Mdot
.44529 .17987 Mdot
.4453 .17989 Mdot
.4453 .17991 Mdot
.44531 .17993 Mdot
.44532 .17995 Mdot
.44533 .17997 Mdot
.44534 .17999 Mdot
.44535 .18001 Mdot
.44536 .18003 Mdot
.44537 .18005 Mdot
.44538 .18007 Mdot
.44539 .18009 Mdot
.4454 .18011 Mdot
.44541 .18013 Mdot
.44542 .18015 Mdot
.44543 .18017 Mdot
.44544 .18019 Mdot
.44545 .18021 Mdot
.44546 .18023 Mdot
.44547 .18025 Mdot
.44548 .18027 Mdot
.44549 .18029 Mdot
.4455 .18031 Mdot
.4455 .18032 Mdot
.44551 .18034 Mdot
.44552 .18036 Mdot
.44553 .18038 Mdot
.44554 .1804 Mdot
.44555 .18042 Mdot
.44556 .18044 Mdot
.44557 .18046 Mdot
.44558 .18048 Mdot
.44559 .1805 Mdot
.4456 .18052 Mdot
.44561 .18054 Mdot
.44562 .18056 Mdot
.44563 .18058 Mdot
.44564 .1806 Mdot
.44565 .18062 Mdot
.44566 .18064 Mdot
.44567 .18066 Mdot
.44568 .18068 Mdot
.44569 .1807 Mdot
.4457 .18072 Mdot
.4457 .18074 Mdot
.44571 .18076 Mdot
.44572 .18078 Mdot
.44573 .1808 Mdot
.44574 .18082 Mdot
.44575 .18084 Mdot
.44576 .18086 Mdot
.44577 .18088 Mdot
.44578 .1809 Mdot
.44579 .18092 Mdot
.4458 .18094 Mdot
.44581 .18096 Mdot
.44582 .18097 Mdot
.44583 .18099 Mdot
.44584 .18101 Mdot
.44585 .18103 Mdot
.44586 .18105 Mdot
.44587 .18107 Mdot
.44588 .18109 Mdot
.44589 .18111 Mdot
.4459 .18113 Mdot
.4459 .18115 Mdot
.44591 .18117 Mdot
.44592 .18119 Mdot
.44593 .18121 Mdot
.44594 .18123 Mdot
.44595 .18125 Mdot
.44596 .18127 Mdot
.44597 .18129 Mdot
.44598 .18131 Mdot
.44599 .18133 Mdot
.446 .18135 Mdot
.44601 .18137 Mdot
.44602 .18139 Mdot
.44603 .18141 Mdot
.44604 .18143 Mdot
.44605 .18145 Mdot
.44606 .18147 Mdot
.44607 .18149 Mdot
.44608 .18151 Mdot
.44609 .18153 Mdot
.4461 .18155 Mdot
.4461 .18157 Mdot
.44611 .18159 Mdot
.44612 .18161 Mdot
.44613 .18163 Mdot
.44614 .18165 Mdot
.44615 .18167 Mdot
.44616 .18169 Mdot
.44617 .18171 Mdot
.44618 .18172 Mdot
.44619 .18174 Mdot
.4462 .18176 Mdot
.44621 .18178 Mdot
.44622 .1818 Mdot
.44623 .18182 Mdot
.44624 .18184 Mdot
.44625 .18186 Mdot
.44626 .18188 Mdot
.44627 .1819 Mdot
.44628 .18192 Mdot
.44629 .18194 Mdot
.4463 .18196 Mdot
.4463 .18198 Mdot
.44631 .182 Mdot
.44632 .18202 Mdot
.44633 .18204 Mdot
.44634 .18206 Mdot
.44635 .18208 Mdot
.44636 .1821 Mdot
.44637 .18212 Mdot
.44638 .18214 Mdot
.44639 .18216 Mdot
.4464 .18218 Mdot
.44641 .1822 Mdot
.44642 .18222 Mdot
.44643 .18224 Mdot
.44644 .18226 Mdot
.44645 .18228 Mdot
.44646 .1823 Mdot
.44647 .18232 Mdot
.44648 .18234 Mdot
.44649 .18236 Mdot
.4465 .18238 Mdot
.4465 .1824 Mdot
.44651 .18242 Mdot
.44652 .18244 Mdot
.44653 .18246 Mdot
.44654 .18248 Mdot
.44655 .1825 Mdot
.44656 .18252 Mdot
.44657 .18254 Mdot
.44658 .18256 Mdot
.44659 .18258 Mdot
.4466 .1826 Mdot
.44661 .18262 Mdot
.44662 .18263 Mdot
.44663 .18265 Mdot
.44664 .18267 Mdot
.44665 .18269 Mdot
.44666 .18271 Mdot
.44667 .18273 Mdot
.44668 .18275 Mdot
.44669 .18277 Mdot
.4467 .18279 Mdot
.4467 .18281 Mdot
.44671 .18283 Mdot
.44672 .18285 Mdot
.44673 .18287 Mdot
.44674 .18289 Mdot
.44675 .18291 Mdot
.44676 .18293 Mdot
.44677 .18295 Mdot
.44678 .18297 Mdot
.44679 .18299 Mdot
.4468 .18301 Mdot
.44681 .18303 Mdot
.44682 .18305 Mdot
.44683 .18307 Mdot
.44684 .18309 Mdot
.44685 .18311 Mdot
.44686 .18313 Mdot
.44687 .18315 Mdot
.44688 .18317 Mdot
.44689 .18319 Mdot
.4469 .18321 Mdot
.4469 .18323 Mdot
.44691 .18325 Mdot
.44692 .18327 Mdot
.44693 .18329 Mdot
.44694 .18331 Mdot
.44695 .18333 Mdot
.44696 .18335 Mdot
.44697 .18337 Mdot
.44698 .18339 Mdot
.44699 .18341 Mdot
.447 .18343 Mdot
.44701 .18345 Mdot
.44702 .18347 Mdot
.44703 .18349 Mdot
.44704 .18351 Mdot
.44705 .18353 Mdot
.44706 .18355 Mdot
.44707 .18357 Mdot
.44708 .18359 Mdot
.44709 .18361 Mdot
.4471 .18363 Mdot
.4471 .18365 Mdot
.44711 .18367 Mdot
.44712 .18369 Mdot
.44713 .18371 Mdot
.44714 .18373 Mdot
.44715 .18375 Mdot
.44716 .18377 Mdot
.44717 .18379 Mdot
.44718 .18381 Mdot
.44719 .18383 Mdot
.4472 .18385 Mdot
.44721 .18387 Mdot
.44722 .18389 Mdot
.44723 .18391 Mdot
.44724 .18393 Mdot
.44725 .18394 Mdot
.44726 .18396 Mdot
.44727 .18398 Mdot
.44728 .184 Mdot
.44729 .18402 Mdot
.4473 .18404 Mdot
.4473 .18406 Mdot
.44731 .18408 Mdot
.44732 .1841 Mdot
.44733 .18412 Mdot
.44734 .18414 Mdot
.44735 .18416 Mdot
.44736 .18418 Mdot
.44737 .1842 Mdot
.44738 .18422 Mdot
.44739 .18424 Mdot
.4474 .18426 Mdot
.44741 .18428 Mdot
.44742 .1843 Mdot
.44743 .18432 Mdot
.44744 .18434 Mdot
.44745 .18436 Mdot
.44746 .18438 Mdot
.44747 .1844 Mdot
.44748 .18442 Mdot
.44749 .18444 Mdot
.4475 .18446 Mdot
.4475 .18448 Mdot
.44751 .1845 Mdot
.44752 .18452 Mdot
.44753 .18454 Mdot
.44754 .18456 Mdot
.44755 .18458 Mdot
.44756 .1846 Mdot
.44757 .18462 Mdot
.44758 .18464 Mdot
.44759 .18466 Mdot
.4476 .18468 Mdot
.44761 .1847 Mdot
.44762 .18472 Mdot
.44763 .18474 Mdot
.44764 .18476 Mdot
.44765 .18478 Mdot
.44766 .1848 Mdot
.44767 .18482 Mdot
.44768 .18484 Mdot
.44769 .18486 Mdot
.4477 .18488 Mdot
.4477 .1849 Mdot
.44771 .18492 Mdot
.44772 .18494 Mdot
.44773 .18496 Mdot
.44774 .18498 Mdot
.44775 .185 Mdot
.44776 .18502 Mdot
.44777 .18504 Mdot
.44778 .18506 Mdot
.44779 .18508 Mdot
.4478 .1851 Mdot
.44781 .18512 Mdot
.44782 .18514 Mdot
.44783 .18516 Mdot
.44784 .18518 Mdot
.44785 .1852 Mdot
.44786 .18522 Mdot
.44787 .18524 Mdot
.44788 .18526 Mdot
.44789 .18528 Mdot
.4479 .1853 Mdot
.4479 .18532 Mdot
.44791 .18534 Mdot
.44792 .18536 Mdot
.44793 .18538 Mdot
.44794 .1854 Mdot
.44795 .18542 Mdot
.44796 .18544 Mdot
.44797 .18546 Mdot
.44798 .18548 Mdot
.44799 .1855 Mdot
.448 .18552 Mdot
.44801 .18554 Mdot
.44802 .18556 Mdot
.44803 .18558 Mdot
.44804 .1856 Mdot
.44805 .18562 Mdot
.44806 .18564 Mdot
.44807 .18566 Mdot
.44808 .18568 Mdot
.44809 .1857 Mdot
.4481 .18572 Mdot
.4481 .18574 Mdot
.44811 .18576 Mdot
.44812 .18578 Mdot
.44813 .1858 Mdot
.44814 .18582 Mdot
.44815 .18584 Mdot
.44816 .18586 Mdot
.44817 .18588 Mdot
.44818 .1859 Mdot
.44819 .18592 Mdot
.4482 .18594 Mdot
.44821 .18596 Mdot
.44822 .18598 Mdot
.44823 .186 Mdot
.44824 .18602 Mdot
.44825 .18604 Mdot
.44826 .18606 Mdot
.44827 .18608 Mdot
.44828 .1861 Mdot
.44829 .18612 Mdot
.4483 .18614 Mdot
.4483 .18616 Mdot
.44831 .18618 Mdot
.44832 .1862 Mdot
.44833 .18622 Mdot
.44834 .18624 Mdot
.44835 .18626 Mdot
.44836 .18628 Mdot
.44837 .1863 Mdot
.44838 .18632 Mdot
.44839 .18634 Mdot
.4484 .18636 Mdot
.44841 .18638 Mdot
.44842 .1864 Mdot
.44843 .18642 Mdot
.44844 .18644 Mdot
.44845 .18646 Mdot
.44846 .18648 Mdot
.44847 .1865 Mdot
.44848 .18652 Mdot
.44849 .18654 Mdot
.4485 .18656 Mdot
.4485 .18658 Mdot
.44851 .1866 Mdot
.44852 .18662 Mdot
.44853 .18664 Mdot
.44854 .18666 Mdot
.44855 .18668 Mdot
.44856 .1867 Mdot
.44857 .18672 Mdot
.44858 .18674 Mdot
.44859 .18676 Mdot
.4486 .18678 Mdot
.44861 .1868 Mdot
.44862 .18682 Mdot
.44863 .18684 Mdot
.44864 .18686 Mdot
.44865 .18688 Mdot
.44866 .1869 Mdot
.44867 .18692 Mdot
.44868 .18694 Mdot
.44869 .18696 Mdot
.4487 .18698 Mdot
.4487 .187 Mdot
.44871 .18702 Mdot
.44872 .18704 Mdot
.44873 .18706 Mdot
.44874 .18708 Mdot
.44875 .1871 Mdot
.44876 .18712 Mdot
.44877 .18714 Mdot
.44878 .18716 Mdot
.44879 .18718 Mdot
.4488 .1872 Mdot
.44881 .18722 Mdot
.44882 .18724 Mdot
.44883 .18726 Mdot
.44884 .18728 Mdot
.44885 .1873 Mdot
.44886 .18732 Mdot
.44887 .18734 Mdot
.44888 .18736 Mdot
.44889 .18738 Mdot
.4489 .1874 Mdot
.4489 .18742 Mdot
.44891 .18744 Mdot
.44892 .18746 Mdot
.44893 .18748 Mdot
.44894 .1875 Mdot
.44895 .18752 Mdot
.44896 .18754 Mdot
.44897 .18756 Mdot
.44898 .18758 Mdot
.44899 .1876 Mdot
.449 .18762 Mdot
.44901 .18764 Mdot
.44902 .18766 Mdot
.44903 .18768 Mdot
.44904 .1877 Mdot
.44905 .18772 Mdot
.44906 .18774 Mdot
.44907 .18776 Mdot
.44908 .18778 Mdot
.44909 .1878 Mdot
.4491 .18782 Mdot
.4491 .18784 Mdot
.44911 .18786 Mdot
.44912 .18788 Mdot
.44913 .1879 Mdot
.44914 .18792 Mdot
.44915 .18794 Mdot
.44916 .18796 Mdot
.44917 .18798 Mdot
.44918 .18801 Mdot
.44919 .18803 Mdot
.4492 .18805 Mdot
.44921 .18807 Mdot
.44922 .18809 Mdot
.44923 .18811 Mdot
.44924 .18813 Mdot
.44925 .18815 Mdot
.44926 .18817 Mdot
.44927 .18819 Mdot
.44928 .18821 Mdot
.44929 .18823 Mdot
.4493 .18825 Mdot
.4493 .18827 Mdot
.44931 .18829 Mdot
.44932 .18831 Mdot
.44933 .18833 Mdot
.44934 .18835 Mdot
.44935 .18837 Mdot
.44936 .18839 Mdot
.44937 .18841 Mdot
.44938 .18843 Mdot
.44939 .18845 Mdot
.4494 .18847 Mdot
.44941 .18849 Mdot
.44942 .18851 Mdot
.44943 .18853 Mdot
.44944 .18855 Mdot
.44945 .18857 Mdot
.44946 .18859 Mdot
.44947 .18861 Mdot
.44948 .18863 Mdot
.44949 .18865 Mdot
.4495 .18867 Mdot
.4495 .18869 Mdot
.44951 .18871 Mdot
.44952 .18873 Mdot
.44953 .18875 Mdot
.44954 .18877 Mdot
.44955 .18879 Mdot
.44956 .18881 Mdot
.44957 .18883 Mdot
.44958 .18885 Mdot
.44959 .18887 Mdot
.4496 .18889 Mdot
.44961 .18891 Mdot
.44962 .18893 Mdot
.44963 .18895 Mdot
.44964 .18897 Mdot
.44965 .18899 Mdot
.44966 .18901 Mdot
.44967 .18903 Mdot
.44968 .18905 Mdot
.44969 .18907 Mdot
.4497 .18909 Mdot
.4497 .18911 Mdot
.44971 .18913 Mdot
.44972 .18915 Mdot
.44973 .18917 Mdot
.44974 .18919 Mdot
.44975 .18921 Mdot
.44976 .18923 Mdot
.44977 .18925 Mdot
.44978 .18927 Mdot
.44979 .18929 Mdot
.4498 .18931 Mdot
.44981 .18934 Mdot
.44982 .18936 Mdot
.44983 .18938 Mdot
.44984 .1894 Mdot
.44985 .18942 Mdot
.44986 .18944 Mdot
.44987 .18946 Mdot
.44988 .18948 Mdot
.44989 .1895 Mdot
.4499 .18952 Mdot
.4499 .18954 Mdot
.44991 .18956 Mdot
.44992 .18958 Mdot
.44993 .1896 Mdot
.44994 .18962 Mdot
.44995 .18964 Mdot
.44996 .18966 Mdot
.44997 .18968 Mdot
.44998 .1897 Mdot
.44999 .18972 Mdot
.45 .18974 Mdot
.45001 .18976 Mdot
.45002 .18978 Mdot
.45003 .1898 Mdot
.45004 .18982 Mdot
.45005 .18984 Mdot
.45006 .18986 Mdot
.45007 .18988 Mdot
.45008 .1899 Mdot
.45009 .18992 Mdot
.4501 .18994 Mdot
.4501 .18996 Mdot
.45011 .18998 Mdot
.45012 .19 Mdot
.45013 .19002 Mdot
.45014 .19004 Mdot
.45015 .19006 Mdot
.45016 .19008 Mdot
.45017 .1901 Mdot
.45018 .19012 Mdot
.45019 .19014 Mdot
.4502 .19016 Mdot
.45021 .19018 Mdot
.45022 .1902 Mdot
.45023 .19022 Mdot
.45024 .19024 Mdot
.45025 .19027 Mdot
.45026 .19029 Mdot
.45027 .19031 Mdot
.45028 .19033 Mdot
.45029 .19035 Mdot
.4503 .19037 Mdot
.4503 .19039 Mdot
.45031 .19041 Mdot
.45032 .19043 Mdot
.45033 .19045 Mdot
.45034 .19047 Mdot
.45035 .19049 Mdot
.45036 .19051 Mdot
.45037 .19053 Mdot
.45038 .19055 Mdot
.45039 .19057 Mdot
.4504 .19059 Mdot
.45041 .19061 Mdot
.45042 .19063 Mdot
.45043 .19065 Mdot
.45044 .19067 Mdot
.45045 .19069 Mdot
.45046 .19071 Mdot
.45047 .19073 Mdot
.45048 .19075 Mdot
.45049 .19077 Mdot
.4505 .19079 Mdot
.4505 .19081 Mdot
.45051 .19083 Mdot
.45052 .19085 Mdot
.45053 .19087 Mdot
.45054 .19089 Mdot
.45055 .19091 Mdot
.45056 .19093 Mdot
.45057 .19095 Mdot
.45058 .19097 Mdot
.45059 .19099 Mdot
.4506 .19101 Mdot
.45061 .19104 Mdot
.45062 .19106 Mdot
.45063 .19108 Mdot
.45064 .1911 Mdot
.45065 .19112 Mdot
.45066 .19114 Mdot
.45067 .19116 Mdot
.45068 .19118 Mdot
.45069 .1912 Mdot
.4507 .19122 Mdot
.4507 .19124 Mdot
.45071 .19126 Mdot
.45072 .19128 Mdot
.45073 .1913 Mdot
.45074 .19132 Mdot
.45075 .19134 Mdot
.45076 .19136 Mdot
.45077 .19138 Mdot
.45078 .1914 Mdot
.45079 .19142 Mdot
.4508 .19144 Mdot
.45081 .19146 Mdot
.45082 .19148 Mdot
.45083 .1915 Mdot
.45084 .19152 Mdot
.45085 .19154 Mdot
.45086 .19156 Mdot
.45087 .19158 Mdot
.45088 .1916 Mdot
.45089 .19162 Mdot
.4509 .19164 Mdot
.4509 .19166 Mdot
.45091 .19168 Mdot
.45092 .19171 Mdot
.45093 .19173 Mdot
.45094 .19175 Mdot
.45095 .19177 Mdot
.45096 .19179 Mdot
.45097 .19181 Mdot
.45098 .19183 Mdot
.45099 .19185 Mdot
.451 .19187 Mdot
.45101 .19189 Mdot
.45102 .19191 Mdot
.45103 .19193 Mdot
.45104 .19195 Mdot
.45105 .19197 Mdot
.45106 .19199 Mdot
.45107 .19201 Mdot
.45108 .19203 Mdot
.45109 .19205 Mdot
.4511 .19207 Mdot
.4511 .19209 Mdot
.45111 .19211 Mdot
.45112 .19213 Mdot
.45113 .19215 Mdot
.45114 .19217 Mdot
.45115 .19219 Mdot
.45116 .19221 Mdot
.45117 .19223 Mdot
.45118 .19225 Mdot
.45119 .19227 Mdot
.4512 .19229 Mdot
.45121 .19232 Mdot
.45122 .19234 Mdot
.45123 .19236 Mdot
.45124 .19238 Mdot
.45125 .1924 Mdot
.45126 .19242 Mdot
.45127 .19244 Mdot
.45128 .19246 Mdot
.45129 .19248 Mdot
.4513 .1925 Mdot
.4513 .19252 Mdot
.45131 .19254 Mdot
.45132 .19256 Mdot
.45133 .19258 Mdot
.45134 .1926 Mdot
.45135 .19262 Mdot
.45136 .19264 Mdot
.45137 .19266 Mdot
.45138 .19268 Mdot
.45139 .1927 Mdot
.4514 .19272 Mdot
.45141 .19274 Mdot
.45142 .19276 Mdot
.45143 .19278 Mdot
.45144 .1928 Mdot
.45145 .19282 Mdot
.45146 .19284 Mdot
.45147 .19287 Mdot
.45148 .19289 Mdot
.45149 .19291 Mdot
.4515 .19293 Mdot
.4515 .19295 Mdot
.45151 .19297 Mdot
.45152 .19299 Mdot
.45153 .19301 Mdot
.45154 .19303 Mdot
.45155 .19305 Mdot
.45156 .19307 Mdot
.45157 .19309 Mdot
.45158 .19311 Mdot
.45159 .19313 Mdot
.4516 .19315 Mdot
.45161 .19317 Mdot
.45162 .19319 Mdot
.45163 .19321 Mdot
.45164 .19323 Mdot
.45165 .19325 Mdot
.45166 .19327 Mdot
.45167 .19329 Mdot
.45168 .19331 Mdot
.45169 .19333 Mdot
.4517 .19335 Mdot
.4517 .19338 Mdot
.45171 .1934 Mdot
.45172 .19342 Mdot
.45173 .19344 Mdot
.45174 .19346 Mdot
.45175 .19348 Mdot
.45176 .1935 Mdot
.45177 .19352 Mdot
.45178 .19354 Mdot
.45179 .19356 Mdot
.4518 .19358 Mdot
.45181 .1936 Mdot
.45182 .19362 Mdot
.45183 .19364 Mdot
.45184 .19366 Mdot
.45185 .19368 Mdot
.45186 .1937 Mdot
.45187 .19372 Mdot
.45188 .19374 Mdot
.45189 .19376 Mdot
.4519 .19378 Mdot
.4519 .1938 Mdot
.45191 .19382 Mdot
.45192 .19385 Mdot
.45193 .19387 Mdot
.45194 .19389 Mdot
.45195 .19391 Mdot
.45196 .19393 Mdot
.45197 .19395 Mdot
.45198 .19397 Mdot
.45199 .19399 Mdot
.452 .19401 Mdot
.45201 .19403 Mdot
.45202 .19405 Mdot
.45203 .19407 Mdot
.45204 .19409 Mdot
.45205 .19411 Mdot
.45206 .19413 Mdot
.45207 .19415 Mdot
.45208 .19417 Mdot
.45209 .19419 Mdot
.4521 .19421 Mdot
.4521 .19423 Mdot
.45211 .19425 Mdot
.45212 .19427 Mdot
.45213 .1943 Mdot
.45214 .19432 Mdot
.45215 .19434 Mdot
.45216 .19436 Mdot
.45217 .19438 Mdot
.45218 .1944 Mdot
.45219 .19442 Mdot
.4522 .19444 Mdot
.45221 .19446 Mdot
.45222 .19448 Mdot
.45223 .1945 Mdot
.45224 .19452 Mdot
.45225 .19454 Mdot
.45226 .19456 Mdot
.45227 .19458 Mdot
.45228 .1946 Mdot
.45229 .19462 Mdot
.4523 .19464 Mdot
.4523 .19466 Mdot
.45231 .19468 Mdot
.45232 .1947 Mdot
.45233 .19473 Mdot
.45234 .19475 Mdot
.45235 .19477 Mdot
.45236 .19479 Mdot
.45237 .19481 Mdot
.45238 .19483 Mdot
.45239 .19485 Mdot
.4524 .19487 Mdot
.45241 .19489 Mdot
.45242 .19491 Mdot
.45243 .19493 Mdot
.45244 .19495 Mdot
.45245 .19497 Mdot
.45246 .19499 Mdot
.45247 .19501 Mdot
.45248 .19503 Mdot
.45249 .19505 Mdot
.4525 .19507 Mdot
.4525 .19509 Mdot
.45251 .19511 Mdot
.45252 .19514 Mdot
.45253 .19516 Mdot
.45254 .19518 Mdot
.45255 .1952 Mdot
.45256 .19522 Mdot
.45257 .19524 Mdot
.45258 .19526 Mdot
.45259 .19528 Mdot
.4526 .1953 Mdot
.45261 .19532 Mdot
.45262 .19534 Mdot
.45263 .19536 Mdot
.45264 .19538 Mdot
.45265 .1954 Mdot
.45266 .19542 Mdot
.45267 .19544 Mdot
.45268 .19546 Mdot
.45269 .19548 Mdot
.4527 .1955 Mdot
.4527 .19553 Mdot
.45271 .19555 Mdot
.45272 .19557 Mdot
.45273 .19559 Mdot
.45274 .19561 Mdot
.45275 .19563 Mdot
.45276 .19565 Mdot
.45277 .19567 Mdot
.45278 .19569 Mdot
.45279 .19571 Mdot
.4528 .19573 Mdot
.45281 .19575 Mdot
.45282 .19577 Mdot
.45283 .19579 Mdot
.45284 .19581 Mdot
.45285 .19583 Mdot
.45286 .19585 Mdot
.45287 .19587 Mdot
.45288 .19589 Mdot
.45289 .19592 Mdot
.4529 .19594 Mdot
.4529 .19596 Mdot
.45291 .19598 Mdot
.45292 .196 Mdot
.45293 .19602 Mdot
.45294 .19604 Mdot
.45295 .19606 Mdot
.45296 .19608 Mdot
.45297 .1961 Mdot
.45298 .19612 Mdot
.45299 .19614 Mdot
.453 .19616 Mdot
.45301 .19618 Mdot
.45302 .1962 Mdot
.45303 .19622 Mdot
.45304 .19624 Mdot
.45305 .19627 Mdot
.45306 .19629 Mdot
.45307 .19631 Mdot
.45308 .19633 Mdot
.45309 .19635 Mdot
.4531 .19637 Mdot
.4531 .19639 Mdot
.45311 .19641 Mdot
.45312 .19643 Mdot
.45313 .19645 Mdot
.45314 .19647 Mdot
.45315 .19649 Mdot
.45316 .19651 Mdot
.45317 .19653 Mdot
.45318 .19655 Mdot
.45319 .19657 Mdot
.4532 .19659 Mdot
.45321 .19661 Mdot
.45322 .19664 Mdot
.45323 .19666 Mdot
.45324 .19668 Mdot
.45325 .1967 Mdot
.45326 .19672 Mdot
.45327 .19674 Mdot
.45328 .19676 Mdot
.45329 .19678 Mdot
.4533 .1968 Mdot
.4533 .19682 Mdot
.45331 .19684 Mdot
.45332 .19686 Mdot
.45333 .19688 Mdot
.45334 .1969 Mdot
.45335 .19692 Mdot
.45336 .19694 Mdot
.45337 .19697 Mdot
.45338 .19699 Mdot
.45339 .19701 Mdot
.4534 .19703 Mdot
.45341 .19705 Mdot
.45342 .19707 Mdot
.45343 .19709 Mdot
.45344 .19711 Mdot
.45345 .19713 Mdot
.45346 .19715 Mdot
.45347 .19717 Mdot
.45348 .19719 Mdot
.45349 .19721 Mdot
.4535 .19723 Mdot
.4535 .19725 Mdot
.45351 .19727 Mdot
.45352 .1973 Mdot
.45353 .19732 Mdot
.45354 .19734 Mdot
.45355 .19736 Mdot
.45356 .19738 Mdot
.45357 .1974 Mdot
.45358 .19742 Mdot
.45359 .19744 Mdot
.4536 .19746 Mdot
.45361 .19748 Mdot
.45362 .1975 Mdot
.45363 .19752 Mdot
.45364 .19754 Mdot
.45365 .19756 Mdot
.45366 .19758 Mdot
.45367 .1976 Mdot
.45368 .19763 Mdot
.45369 .19765 Mdot
.4537 .19767 Mdot
.4537 .19769 Mdot
.45371 .19771 Mdot
.45372 .19773 Mdot
.45373 .19775 Mdot
.45374 .19777 Mdot
.45375 .19779 Mdot
.45376 .19781 Mdot
.45377 .19783 Mdot
.45378 .19785 Mdot
.45379 .19787 Mdot
.4538 .19789 Mdot
.45381 .19791 Mdot
.45382 .19794 Mdot
.45383 .19796 Mdot
.45384 .19798 Mdot
.45385 .198 Mdot
.45386 .19802 Mdot
.45387 .19804 Mdot
.45388 .19806 Mdot
.45389 .19808 Mdot
.4539 .1981 Mdot
.4539 .19812 Mdot
.45391 .19814 Mdot
.45392 .19816 Mdot
.45393 .19818 Mdot
.45394 .1982 Mdot
.45395 .19822 Mdot
.45396 .19825 Mdot
.45397 .19827 Mdot
.45398 .19829 Mdot
.45399 .19831 Mdot
.454 .19833 Mdot
.45401 .19835 Mdot
.45402 .19837 Mdot
.45403 .19839 Mdot
.45404 .19841 Mdot
.45405 .19843 Mdot
.45406 .19845 Mdot
.45407 .19847 Mdot
.45408 .19849 Mdot
.45409 .19851 Mdot
.4541 .19854 Mdot
.4541 .19856 Mdot
.45411 .19858 Mdot
.45412 .1986 Mdot
.45413 .19862 Mdot
.45414 .19864 Mdot
.45415 .19866 Mdot
.45416 .19868 Mdot
.45417 .1987 Mdot
.45418 .19872 Mdot
.45419 .19874 Mdot
.4542 .19876 Mdot
.45421 .19878 Mdot
.45422 .1988 Mdot
.45423 .19882 Mdot
.45424 .19885 Mdot
.45425 .19887 Mdot
.45426 .19889 Mdot
.45427 .19891 Mdot
.45428 .19893 Mdot
.45429 .19895 Mdot
.4543 .19897 Mdot
.4543 .19899 Mdot
.45431 .19901 Mdot
.45432 .19903 Mdot
.45433 .19905 Mdot
.45434 .19907 Mdot
.45435 .19909 Mdot
.45436 .19911 Mdot
.45437 .19914 Mdot
.45438 .19916 Mdot
.45439 .19918 Mdot
.4544 .1992 Mdot
.45441 .19922 Mdot
.45442 .19924 Mdot
.45443 .19926 Mdot
.45444 .19928 Mdot
.45445 .1993 Mdot
.45446 .19932 Mdot
.45447 .19934 Mdot
.45448 .19936 Mdot
.45449 .19938 Mdot
.4545 .19941 Mdot
.4545 .19943 Mdot
.45451 .19945 Mdot
.45452 .19947 Mdot
.45453 .19949 Mdot
.45454 .19951 Mdot
.45455 .19953 Mdot
.45456 .19955 Mdot
.45457 .19957 Mdot
.45458 .19959 Mdot
.45459 .19961 Mdot
.4546 .19963 Mdot
.45461 .19965 Mdot
.45462 .19968 Mdot
.45463 .1997 Mdot
.45464 .19972 Mdot
.45465 .19974 Mdot
.45466 .19976 Mdot
.45467 .19978 Mdot
.45468 .1998 Mdot
.45469 .19982 Mdot
.4547 .19984 Mdot
.4547 .19986 Mdot
.45471 .19988 Mdot
.45472 .1999 Mdot
.45473 .19992 Mdot
.45474 .19995 Mdot
.45475 .19997 Mdot
.45476 .19999 Mdot
.45477 .20001 Mdot
.45478 .20003 Mdot
.45479 .20005 Mdot
.4548 .20007 Mdot
.45481 .20009 Mdot
.45482 .20011 Mdot
.45483 .20013 Mdot
.45484 .20015 Mdot
.45485 .20017 Mdot
.45486 .20019 Mdot
.45487 .20022 Mdot
.45488 .20024 Mdot
.45489 .20026 Mdot
.4549 .20028 Mdot
.4549 .2003 Mdot
.45491 .20032 Mdot
.45492 .20034 Mdot
.45493 .20036 Mdot
.45494 .20038 Mdot
.45495 .2004 Mdot
.45496 .20042 Mdot
.45497 .20044 Mdot
.45498 .20046 Mdot
.45499 .20049 Mdot
.455 .20051 Mdot
.45501 .20053 Mdot
.45502 .20055 Mdot
.45503 .20057 Mdot
.45504 .20059 Mdot
.45505 .20061 Mdot
.45506 .20063 Mdot
.45507 .20065 Mdot
.45508 .20067 Mdot
.45509 .20069 Mdot
.4551 .20071 Mdot
.4551 .20074 Mdot
.45511 .20076 Mdot
.45512 .20078 Mdot
.45513 .2008 Mdot
.45514 .20082 Mdot
.45515 .20084 Mdot
.45516 .20086 Mdot
.45517 .20088 Mdot
.45518 .2009 Mdot
.45519 .20092 Mdot
.4552 .20094 Mdot
.45521 .20096 Mdot
.45522 .20099 Mdot
.45523 .20101 Mdot
.45524 .20103 Mdot
.45525 .20105 Mdot
.45526 .20107 Mdot
.45527 .20109 Mdot
.45528 .20111 Mdot
.45529 .20113 Mdot
.4553 .20115 Mdot
.4553 .20117 Mdot
.45531 .20119 Mdot
.45532 .20121 Mdot
.45533 .20124 Mdot
.45534 .20126 Mdot
.45535 .20128 Mdot
.45536 .2013 Mdot
.45537 .20132 Mdot
.45538 .20134 Mdot
.45539 .20136 Mdot
.4554 .20138 Mdot
.45541 .2014 Mdot
.45542 .20142 Mdot
.45543 .20144 Mdot
.45544 .20146 Mdot
.45545 .20149 Mdot
.45546 .20151 Mdot
.45547 .20153 Mdot
.45548 .20155 Mdot
.45549 .20157 Mdot
.4555 .20159 Mdot
.4555 .20161 Mdot
.45551 .20163 Mdot
.45552 .20165 Mdot
.45553 .20167 Mdot
.45554 .20169 Mdot
.45555 .20171 Mdot
.45556 .20174 Mdot
.45557 .20176 Mdot
.45558 .20178 Mdot
.45559 .2018 Mdot
.4556 .20182 Mdot
.45561 .20184 Mdot
.45562 .20186 Mdot
.45563 .20188 Mdot
.45564 .2019 Mdot
.45565 .20192 Mdot
.45566 .20194 Mdot
.45567 .20197 Mdot
.45568 .20199 Mdot
.45569 .20201 Mdot
.4557 .20203 Mdot
.4557 .20205 Mdot
.45571 .20207 Mdot
.45572 .20209 Mdot
.45573 .20211 Mdot
.45574 .20213 Mdot
.45575 .20215 Mdot
.45576 .20217 Mdot
.45577 .2022 Mdot
.45578 .20222 Mdot
.45579 .20224 Mdot
.4558 .20226 Mdot
.45581 .20228 Mdot
.45582 .2023 Mdot
.45583 .20232 Mdot
.45584 .20234 Mdot
.45585 .20236 Mdot
.45586 .20238 Mdot
.45587 .2024 Mdot
.45588 .20243 Mdot
.45589 .20245 Mdot
.4559 .20247 Mdot
.4559 .20249 Mdot
.45591 .20251 Mdot
.45592 .20253 Mdot
.45593 .20255 Mdot
.45594 .20257 Mdot
.45595 .20259 Mdot
.45596 .20261 Mdot
.45597 .20263 Mdot
.45598 .20266 Mdot
.45599 .20268 Mdot
.456 .2027 Mdot
.45601 .20272 Mdot
.45602 .20274 Mdot
.45603 .20276 Mdot
.45604 .20278 Mdot
.45605 .2028 Mdot
.45606 .20282 Mdot
.45607 .20284 Mdot
.45608 .20286 Mdot
.45609 .20289 Mdot
.4561 .20291 Mdot
.4561 .20293 Mdot
.45611 .20295 Mdot
.45612 .20297 Mdot
.45613 .20299 Mdot
.45614 .20301 Mdot
.45615 .20303 Mdot
.45616 .20305 Mdot
.45617 .20307 Mdot
.45618 .20309 Mdot
.45619 .20312 Mdot
.4562 .20314 Mdot
.45621 .20316 Mdot
.45622 .20318 Mdot
.45623 .2032 Mdot
.45624 .20322 Mdot
.45625 .20324 Mdot
.45626 .20326 Mdot
.45627 .20328 Mdot
.45628 .2033 Mdot
.45629 .20333 Mdot
.4563 .20335 Mdot
.4563 .20337 Mdot
.45631 .20339 Mdot
.45632 .20341 Mdot
.45633 .20343 Mdot
.45634 .20345 Mdot
.45635 .20347 Mdot
.45636 .20349 Mdot
.45637 .20351 Mdot
.45638 .20353 Mdot
.45639 .20356 Mdot
.4564 .20358 Mdot
.45641 .2036 Mdot
.45642 .20362 Mdot
.45643 .20364 Mdot
.45644 .20366 Mdot
.45645 .20368 Mdot
.45646 .2037 Mdot
.45647 .20372 Mdot
.45648 .20374 Mdot
.45649 .20377 Mdot
.4565 .20379 Mdot
.4565 .20381 Mdot
.45651 .20383 Mdot
.45652 .20385 Mdot
.45653 .20387 Mdot
.45654 .20389 Mdot
.45655 .20391 Mdot
.45656 .20393 Mdot
.45657 .20395 Mdot
.45658 .20398 Mdot
.45659 .204 Mdot
.4566 .20402 Mdot
.45661 .20404 Mdot
.45662 .20406 Mdot
.45663 .20408 Mdot
.45664 .2041 Mdot
.45665 .20412 Mdot
.45666 .20414 Mdot
.45667 .20416 Mdot
.45668 .20419 Mdot
.45669 .20421 Mdot
.4567 .20423 Mdot
.4567 .20425 Mdot
.45671 .20427 Mdot
.45672 .20429 Mdot
.45673 .20431 Mdot
.45674 .20433 Mdot
.45675 .20435 Mdot
.45676 .20437 Mdot
.45677 .2044 Mdot
.45678 .20442 Mdot
.45679 .20444 Mdot
.4568 .20446 Mdot
.45681 .20448 Mdot
.45682 .2045 Mdot
.45683 .20452 Mdot
.45684 .20454 Mdot
.45685 .20456 Mdot
.45686 .20458 Mdot
.45687 .20461 Mdot
.45688 .20463 Mdot
.45689 .20465 Mdot
.4569 .20467 Mdot
.4569 .20469 Mdot
.45691 .20471 Mdot
.45692 .20473 Mdot
.45693 .20475 Mdot
.45694 .20477 Mdot
.45695 .20479 Mdot
.45696 .20482 Mdot
.45697 .20484 Mdot
.45698 .20486 Mdot
.45699 .20488 Mdot
.457 .2049 Mdot
.45701 .20492 Mdot
.45702 .20494 Mdot
.45703 .20496 Mdot
.45704 .20498 Mdot
.45705 .20501 Mdot
.45706 .20503 Mdot
.45707 .20505 Mdot
.45708 .20507 Mdot
.45709 .20509 Mdot
.4571 .20511 Mdot
.4571 .20513 Mdot
.45711 .20515 Mdot
.45712 .20517 Mdot
.45713 .20519 Mdot
.45714 .20522 Mdot
.45715 .20524 Mdot
.45716 .20526 Mdot
.45717 .20528 Mdot
.45718 .2053 Mdot
.45719 .20532 Mdot
.4572 .20534 Mdot
.45721 .20536 Mdot
.45722 .20538 Mdot
.45723 .20541 Mdot
.45724 .20543 Mdot
.45725 .20545 Mdot
.45726 .20547 Mdot
.45727 .20549 Mdot
.45728 .20551 Mdot
.45729 .20553 Mdot
.4573 .20555 Mdot
.4573 .20557 Mdot
.45731 .20559 Mdot
.45732 .20562 Mdot
.45733 .20564 Mdot
.45734 .20566 Mdot
.45735 .20568 Mdot
.45736 .2057 Mdot
.45737 .20572 Mdot
.45738 .20574 Mdot
.45739 .20576 Mdot
.4574 .20578 Mdot
.45741 .20581 Mdot
.45742 .20583 Mdot
.45743 .20585 Mdot
.45744 .20587 Mdot
.45745 .20589 Mdot
.45746 .20591 Mdot
.45747 .20593 Mdot
.45748 .20595 Mdot
.45749 .20597 Mdot
.4575 .206 Mdot
.4575 .20602 Mdot
.45751 .20604 Mdot
.45752 .20606 Mdot
.45753 .20608 Mdot
.45754 .2061 Mdot
.45755 .20612 Mdot
.45756 .20614 Mdot
.45757 .20616 Mdot
.45758 .20619 Mdot
.45759 .20621 Mdot
.4576 .20623 Mdot
.45761 .20625 Mdot
.45762 .20627 Mdot
.45763 .20629 Mdot
.45764 .20631 Mdot
.45765 .20633 Mdot
.45766 .20635 Mdot
.45767 .20638 Mdot
.45768 .2064 Mdot
.45769 .20642 Mdot
.4577 .20644 Mdot
.4577 .20646 Mdot
.45771 .20648 Mdot
.45772 .2065 Mdot
.45773 .20652 Mdot
.45774 .20654 Mdot
.45775 .20657 Mdot
.45776 .20659 Mdot
.45777 .20661 Mdot
.45778 .20663 Mdot
.45779 .20665 Mdot
.4578 .20667 Mdot
.45781 .20669 Mdot
.45782 .20671 Mdot
.45783 .20673 Mdot
.45784 .20676 Mdot
.45785 .20678 Mdot
.45786 .2068 Mdot
.45787 .20682 Mdot
.45788 .20684 Mdot
.45789 .20686 Mdot
.4579 .20688 Mdot
.4579 .2069 Mdot
.45791 .20693 Mdot
.45792 .20695 Mdot
.45793 .20697 Mdot
.45794 .20699 Mdot
.45795 .20701 Mdot
.45796 .20703 Mdot
.45797 .20705 Mdot
.45798 .20707 Mdot
.45799 .20709 Mdot
.458 .20712 Mdot
.45801 .20714 Mdot
.45802 .20716 Mdot
.45803 .20718 Mdot
.45804 .2072 Mdot
.45805 .20722 Mdot
.45806 .20724 Mdot
.45807 .20726 Mdot
.45808 .20728 Mdot
.45809 .20731 Mdot
.4581 .20733 Mdot
.4581 .20735 Mdot
.45811 .20737 Mdot
.45812 .20739 Mdot
.45813 .20741 Mdot
.45814 .20743 Mdot
.45815 .20745 Mdot
.45816 .20748 Mdot
.45817 .2075 Mdot
.45818 .20752 Mdot
.45819 .20754 Mdot
.4582 .20756 Mdot
.45821 .20758 Mdot
.45822 .2076 Mdot
.45823 .20762 Mdot
.45824 .20764 Mdot
.45825 .20767 Mdot
.45826 .20769 Mdot
.45827 .20771 Mdot
.45828 .20773 Mdot
.45829 .20775 Mdot
.4583 .20777 Mdot
.4583 .20779 Mdot
.45831 .20781 Mdot
.45832 .20784 Mdot
.45833 .20786 Mdot
.45834 .20788 Mdot
.45835 .2079 Mdot
.45836 .20792 Mdot
.45837 .20794 Mdot
.45838 .20796 Mdot
.45839 .20798 Mdot
.4584 .208 Mdot
.45841 .20803 Mdot
.45842 .20805 Mdot
.45843 .20807 Mdot
.45844 .20809 Mdot
.45845 .20811 Mdot
.45846 .20813 Mdot
.45847 .20815 Mdot
.45848 .20817 Mdot
.45849 .2082 Mdot
.4585 .20822 Mdot
.4585 .20824 Mdot
.45851 .20826 Mdot
.45852 .20828 Mdot
.45853 .2083 Mdot
.45854 .20832 Mdot
.45855 .20834 Mdot
.45856 .20837 Mdot
.45857 .20839 Mdot
.45858 .20841 Mdot
.45859 .20843 Mdot
.4586 .20845 Mdot
.45861 .20847 Mdot
.45862 .20849 Mdot
.45863 .20851 Mdot
.45864 .20854 Mdot
.45865 .20856 Mdot
.45866 .20858 Mdot
.45867 .2086 Mdot
.45868 .20862 Mdot
.45869 .20864 Mdot
.4587 .20866 Mdot
.4587 .20868 Mdot
.45871 .20871 Mdot
.45872 .20873 Mdot
.45873 .20875 Mdot
.45874 .20877 Mdot
.45875 .20879 Mdot
.45876 .20881 Mdot
.45877 .20883 Mdot
.45878 .20885 Mdot
.45879 .20888 Mdot
.4588 .2089 Mdot
.45881 .20892 Mdot
.45882 .20894 Mdot
.45883 .20896 Mdot
.45884 .20898 Mdot
.45885 .209 Mdot
.45886 .20902 Mdot
.45887 .20905 Mdot
.45888 .20907 Mdot
.45889 .20909 Mdot
.4589 .20911 Mdot
.4589 .20913 Mdot
.45891 .20915 Mdot
.45892 .20917 Mdot
.45893 .20919 Mdot
.45894 .20922 Mdot
.45895 .20924 Mdot
.45896 .20926 Mdot
.45897 .20928 Mdot
.45898 .2093 Mdot
.45899 .20932 Mdot
.459 .20934 Mdot
.45901 .20936 Mdot
.45902 .20939 Mdot
.45903 .20941 Mdot
.45904 .20943 Mdot
.45905 .20945 Mdot
.45906 .20947 Mdot
.45907 .20949 Mdot
.45908 .20951 Mdot
.45909 .20953 Mdot
.4591 .20956 Mdot
.4591 .20958 Mdot
.45911 .2096 Mdot
.45912 .20962 Mdot
.45913 .20964 Mdot
.45914 .20966 Mdot
.45915 .20968 Mdot
.45916 .2097 Mdot
.45917 .20973 Mdot
.45918 .20975 Mdot
.45919 .20977 Mdot
.4592 .20979 Mdot
.45921 .20981 Mdot
.45922 .20983 Mdot
.45923 .20985 Mdot
.45924 .20988 Mdot
.45925 .2099 Mdot
.45926 .20992 Mdot
.45927 .20994 Mdot
.45928 .20996 Mdot
.45929 .20998 Mdot
.4593 .21 Mdot
.4593 .21002 Mdot
.45931 .21005 Mdot
.45932 .21007 Mdot
.45933 .21009 Mdot
.45934 .21011 Mdot
.45935 .21013 Mdot
.45936 .21015 Mdot
.45937 .21017 Mdot
.45938 .21019 Mdot
.45939 .21022 Mdot
.4594 .21024 Mdot
.45941 .21026 Mdot
.45942 .21028 Mdot
.45943 .2103 Mdot
.45944 .21032 Mdot
.45945 .21034 Mdot
.45946 .21037 Mdot
.45947 .21039 Mdot
.45948 .21041 Mdot
.45949 .21043 Mdot
.4595 .21045 Mdot
.4595 .21047 Mdot
.45951 .21049 Mdot
.45952 .21051 Mdot
.45953 .21054 Mdot
.45954 .21056 Mdot
.45955 .21058 Mdot
.45956 .2106 Mdot
.45957 .21062 Mdot
.45958 .21064 Mdot
.45959 .21066 Mdot
.4596 .21069 Mdot
.45961 .21071 Mdot
.45962 .21073 Mdot
.45963 .21075 Mdot
.45964 .21077 Mdot
.45965 .21079 Mdot
.45966 .21081 Mdot
.45967 .21083 Mdot
.45968 .21086 Mdot
.45969 .21088 Mdot
.4597 .2109 Mdot
.4597 .21092 Mdot
.45971 .21094 Mdot
.45972 .21096 Mdot
.45973 .21098 Mdot
.45974 .21101 Mdot
.45975 .21103 Mdot
.45976 .21105 Mdot
.45977 .21107 Mdot
.45978 .21109 Mdot
.45979 .21111 Mdot
.4598 .21113 Mdot
.45981 .21116 Mdot
.45982 .21118 Mdot
.45983 .2112 Mdot
.45984 .21122 Mdot
.45985 .21124 Mdot
.45986 .21126 Mdot
.45987 .21128 Mdot
.45988 .21131 Mdot
.45989 .21133 Mdot
.4599 .21135 Mdot
.4599 .21137 Mdot
.45991 .21139 Mdot
.45992 .21141 Mdot
.45993 .21143 Mdot
.45994 .21145 Mdot
.45995 .21148 Mdot
.45996 .2115 Mdot
.45997 .21152 Mdot
.45998 .21154 Mdot
.45999 .21156 Mdot
.46 .21158 Mdot
.46001 .2116 Mdot
.46002 .21163 Mdot
.46003 .21165 Mdot
.46004 .21167 Mdot
.46005 .21169 Mdot
.46006 .21171 Mdot
.46007 .21173 Mdot
.46008 .21175 Mdot
.46009 .21178 Mdot
.4601 .2118 Mdot
.4601 .21182 Mdot
.46011 .21184 Mdot
.46012 .21186 Mdot
.46013 .21188 Mdot
.46014 .2119 Mdot
.46015 .21193 Mdot
.46016 .21195 Mdot
.46017 .21197 Mdot
.46018 .21199 Mdot
.46019 .21201 Mdot
.4602 .21203 Mdot
.46021 .21205 Mdot
.46022 .21208 Mdot
.46023 .2121 Mdot
.46024 .21212 Mdot
.46025 .21214 Mdot
.46026 .21216 Mdot
.46027 .21218 Mdot
.46028 .2122 Mdot
.46029 .21223 Mdot
.4603 .21225 Mdot
.4603 .21227 Mdot
.46031 .21229 Mdot
.46032 .21231 Mdot
.46033 .21233 Mdot
.46034 .21235 Mdot
.46035 .21238 Mdot
.46036 .2124 Mdot
.46037 .21242 Mdot
.46038 .21244 Mdot
.46039 .21246 Mdot
.4604 .21248 Mdot
.46041 .2125 Mdot
.46042 .21253 Mdot
.46043 .21255 Mdot
.46044 .21257 Mdot
.46045 .21259 Mdot
.46046 .21261 Mdot
.46047 .21263 Mdot
.46048 .21265 Mdot
.46049 .21268 Mdot
.4605 .2127 Mdot
.4605 .21272 Mdot
.46051 .21274 Mdot
.46052 .21276 Mdot
.46053 .21278 Mdot
.46054 .2128 Mdot
.46055 .21283 Mdot
.46056 .21285 Mdot
.46057 .21287 Mdot
.46058 .21289 Mdot
.46059 .21291 Mdot
.4606 .21293 Mdot
.46061 .21295 Mdot
.46062 .21298 Mdot
.46063 .213 Mdot
.46064 .21302 Mdot
.46065 .21304 Mdot
.46066 .21306 Mdot
.46067 .21308 Mdot
.46068 .2131 Mdot
.46069 .21313 Mdot
.4607 .21315 Mdot
.4607 .21317 Mdot
.46071 .21319 Mdot
.46072 .21321 Mdot
.46073 .21323 Mdot
.46074 .21325 Mdot
.46075 .21328 Mdot
.46076 .2133 Mdot
.46077 .21332 Mdot
.46078 .21334 Mdot
.46079 .21336 Mdot
.4608 .21338 Mdot
.46081 .21341 Mdot
.46082 .21343 Mdot
.46083 .21345 Mdot
.46084 .21347 Mdot
.46085 .21349 Mdot
.46086 .21351 Mdot
.46087 .21353 Mdot
.46088 .21356 Mdot
.46089 .21358 Mdot
.4609 .2136 Mdot
.4609 .21362 Mdot
.46091 .21364 Mdot
.46092 .21366 Mdot
.46093 .21368 Mdot
.46094 .21371 Mdot
.46095 .21373 Mdot
.46096 .21375 Mdot
.46097 .21377 Mdot
.46098 .21379 Mdot
.46099 .21381 Mdot
.461 .21384 Mdot
.46101 .21386 Mdot
.46102 .21388 Mdot
.46103 .2139 Mdot
.46104 .21392 Mdot
.46105 .21394 Mdot
.46106 .21396 Mdot
.46107 .21399 Mdot
.46108 .21401 Mdot
.46109 .21403 Mdot
.4611 .21405 Mdot
.4611 .21407 Mdot
.46111 .21409 Mdot
.46112 .21411 Mdot
.46113 .21414 Mdot
.46114 .21416 Mdot
.46115 .21418 Mdot
.46116 .2142 Mdot
.46117 .21422 Mdot
.46118 .21424 Mdot
.46119 .21427 Mdot
.4612 .21429 Mdot
.46121 .21431 Mdot
.46122 .21433 Mdot
.46123 .21435 Mdot
.46124 .21437 Mdot
.46125 .21439 Mdot
.46126 .21442 Mdot
.46127 .21444 Mdot
.46128 .21446 Mdot
.46129 .21448 Mdot
.4613 .2145 Mdot
.4613 .21452 Mdot
.46131 .21455 Mdot
.46132 .21457 Mdot
.46133 .21459 Mdot
.46134 .21461 Mdot
.46135 .21463 Mdot
.46136 .21465 Mdot
.46137 .21467 Mdot
.46138 .2147 Mdot
.46139 .21472 Mdot
.4614 .21474 Mdot
.46141 .21476 Mdot
.46142 .21478 Mdot
.46143 .2148 Mdot
.46144 .21483 Mdot
.46145 .21485 Mdot
.46146 .21487 Mdot
.46147 .21489 Mdot
.46148 .21491 Mdot
.46149 .21493 Mdot
.4615 .21496 Mdot
.4615 .21498 Mdot
.46151 .215 Mdot
.46152 .21502 Mdot
.46153 .21504 Mdot
.46154 .21506 Mdot
.46155 .21508 Mdot
.46156 .21511 Mdot
.46157 .21513 Mdot
.46158 .21515 Mdot
.46159 .21517 Mdot
.4616 .21519 Mdot
.46161 .21521 Mdot
.46162 .21524 Mdot
.46163 .21526 Mdot
.46164 .21528 Mdot
.46165 .2153 Mdot
.46166 .21532 Mdot
.46167 .21534 Mdot
.46168 .21537 Mdot
.46169 .21539 Mdot
.4617 .21541 Mdot
.4617 .21543 Mdot
.46171 .21545 Mdot
.46172 .21547 Mdot
.46173 .21549 Mdot
.46174 .21552 Mdot
.46175 .21554 Mdot
.46176 .21556 Mdot
.46177 .21558 Mdot
.46178 .2156 Mdot
.46179 .21562 Mdot
.4618 .21565 Mdot
.46181 .21567 Mdot
.46182 .21569 Mdot
.46183 .21571 Mdot
.46184 .21573 Mdot
.46185 .21575 Mdot
.46186 .21578 Mdot
.46187 .2158 Mdot
.46188 .21582 Mdot
.46189 .21584 Mdot
.4619 .21586 Mdot
.4619 .21588 Mdot
.46191 .21591 Mdot
.46192 .21593 Mdot
.46193 .21595 Mdot
.46194 .21597 Mdot
.46195 .21599 Mdot
.46196 .21601 Mdot
.46197 .21603 Mdot
.46198 .21606 Mdot
.46199 .21608 Mdot
.462 .2161 Mdot
.46201 .21612 Mdot
.46202 .21614 Mdot
.46203 .21616 Mdot
.46204 .21619 Mdot
.46205 .21621 Mdot
.46206 .21623 Mdot
.46207 .21625 Mdot
.46208 .21627 Mdot
.46209 .21629 Mdot
.4621 .21632 Mdot
.4621 .21634 Mdot
.46211 .21636 Mdot
.46212 .21638 Mdot
.46213 .2164 Mdot
.46214 .21642 Mdot
.46215 .21645 Mdot
.46216 .21647 Mdot
.46217 .21649 Mdot
.46218 .21651 Mdot
.46219 .21653 Mdot
.4622 .21655 Mdot
.46221 .21658 Mdot
.46222 .2166 Mdot
.46223 .21662 Mdot
.46224 .21664 Mdot
.46225 .21666 Mdot
.46226 .21668 Mdot
.46227 .21671 Mdot
.46228 .21673 Mdot
.46229 .21675 Mdot
.4623 .21677 Mdot
.4623 .21679 Mdot
.46231 .21681 Mdot
.46232 .21684 Mdot
.46233 .21686 Mdot
.46234 .21688 Mdot
.46235 .2169 Mdot
.46236 .21692 Mdot
.46237 .21694 Mdot
.46238 .21697 Mdot
.46239 .21699 Mdot
.4624 .21701 Mdot
.46241 .21703 Mdot
.46242 .21705 Mdot
.46243 .21707 Mdot
.46244 .2171 Mdot
.46245 .21712 Mdot
.46246 .21714 Mdot
.46247 .21716 Mdot
.46248 .21718 Mdot
.46249 .2172 Mdot
.4625 .21723 Mdot
.4625 .21725 Mdot
.46251 .21727 Mdot
.46252 .21729 Mdot
.46253 .21731 Mdot
.46254 .21733 Mdot
.46255 .21736 Mdot
.46256 .21738 Mdot
.46257 .2174 Mdot
.46258 .21742 Mdot
.46259 .21744 Mdot
.4626 .21746 Mdot
.46261 .21749 Mdot
.46262 .21751 Mdot
.46263 .21753 Mdot
.46264 .21755 Mdot
.46265 .21757 Mdot
.46266 .21759 Mdot
.46267 .21762 Mdot
.46268 .21764 Mdot
.46269 .21766 Mdot
.4627 .21768 Mdot
.4627 .2177 Mdot
.46271 .21772 Mdot
.46272 .21775 Mdot
.46273 .21777 Mdot
.46274 .21779 Mdot
.46275 .21781 Mdot
.46276 .21783 Mdot
.46277 .21785 Mdot
.46278 .21788 Mdot
.46279 .2179 Mdot
.4628 .21792 Mdot
.46281 .21794 Mdot
.46282 .21796 Mdot
.46283 .21799 Mdot
.46284 .21801 Mdot
.46285 .21803 Mdot
.46286 .21805 Mdot
.46287 .21807 Mdot
.46288 .21809 Mdot
.46289 .21812 Mdot
.4629 .21814 Mdot
.4629 .21816 Mdot
.46291 .21818 Mdot
.46292 .2182 Mdot
.46293 .21822 Mdot
.46294 .21825 Mdot
.46295 .21827 Mdot
.46296 .21829 Mdot
.46297 .21831 Mdot
.46298 .21833 Mdot
.46299 .21835 Mdot
.463 .21838 Mdot
.46301 .2184 Mdot
.46302 .21842 Mdot
.46303 .21844 Mdot
.46304 .21846 Mdot
.46305 .21849 Mdot
.46306 .21851 Mdot
.46307 .21853 Mdot
.46308 .21855 Mdot
.46309 .21857 Mdot
.4631 .21859 Mdot
.4631 .21862 Mdot
.46311 .21864 Mdot
.46312 .21866 Mdot
.46313 .21868 Mdot
.46314 .2187 Mdot
.46315 .21872 Mdot
.46316 .21875 Mdot
.46317 .21877 Mdot
.46318 .21879 Mdot
.46319 .21881 Mdot
.4632 .21883 Mdot
.46321 .21886 Mdot
.46322 .21888 Mdot
.46323 .2189 Mdot
.46324 .21892 Mdot
.46325 .21894 Mdot
.46326 .21896 Mdot
.46327 .21899 Mdot
.46328 .21901 Mdot
.46329 .21903 Mdot
.4633 .21905 Mdot
.4633 .21907 Mdot
.46331 .21909 Mdot
.46332 .21912 Mdot
.46333 .21914 Mdot
.46334 .21916 Mdot
.46335 .21918 Mdot
.46336 .2192 Mdot
.46337 .21923 Mdot
.46338 .21925 Mdot
.46339 .21927 Mdot
.4634 .21929 Mdot
.46341 .21931 Mdot
.46342 .21933 Mdot
.46343 .21936 Mdot
.46344 .21938 Mdot
.46345 .2194 Mdot
.46346 .21942 Mdot
.46347 .21944 Mdot
.46348 .21946 Mdot
.46349 .21949 Mdot
.4635 .21951 Mdot
.4635 .21953 Mdot
.46351 .21955 Mdot
.46352 .21957 Mdot
.46353 .2196 Mdot
.46354 .21962 Mdot
.46355 .21964 Mdot
.46356 .21966 Mdot
.46357 .21968 Mdot
.46358 .2197 Mdot
.46359 .21973 Mdot
.4636 .21975 Mdot
.46361 .21977 Mdot
.46362 .21979 Mdot
.46363 .21981 Mdot
.46364 .21984 Mdot
.46365 .21986 Mdot
.46366 .21988 Mdot
.46367 .2199 Mdot
.46368 .21992 Mdot
.46369 .21994 Mdot
.4637 .21997 Mdot
.4637 .21999 Mdot
.46371 .22001 Mdot
.46372 .22003 Mdot
.46373 .22005 Mdot
.46374 .22008 Mdot
.46375 .2201 Mdot
.46376 .22012 Mdot
.46377 .22014 Mdot
.46378 .22016 Mdot
.46379 .22018 Mdot
.4638 .22021 Mdot
.46381 .22023 Mdot
.46382 .22025 Mdot
.46383 .22027 Mdot
.46384 .22029 Mdot
.46385 .22032 Mdot
.46386 .22034 Mdot
.46387 .22036 Mdot
.46388 .22038 Mdot
.46389 .2204 Mdot
.4639 .22043 Mdot
.4639 .22045 Mdot
.46391 .22047 Mdot
.46392 .22049 Mdot
.46393 .22051 Mdot
.46394 .22053 Mdot
.46395 .22056 Mdot
.46396 .22058 Mdot
.46397 .2206 Mdot
.46398 .22062 Mdot
.46399 .22064 Mdot
.464 .22067 Mdot
.46401 .22069 Mdot
.46402 .22071 Mdot
.46403 .22073 Mdot
.46404 .22075 Mdot
.46405 .22077 Mdot
.46406 .2208 Mdot
.46407 .22082 Mdot
.46408 .22084 Mdot
.46409 .22086 Mdot
.4641 .22088 Mdot
.4641 .22091 Mdot
.46411 .22093 Mdot
.46412 .22095 Mdot
.46413 .22097 Mdot
.46414 .22099 Mdot
.46415 .22102 Mdot
.46416 .22104 Mdot
.46417 .22106 Mdot
.46418 .22108 Mdot
.46419 .2211 Mdot
.4642 .22112 Mdot
.46421 .22115 Mdot
.46422 .22117 Mdot
.46423 .22119 Mdot
.46424 .22121 Mdot
.46425 .22123 Mdot
.46426 .22126 Mdot
.46427 .22128 Mdot
.46428 .2213 Mdot
.46429 .22132 Mdot
.4643 .22134 Mdot
.4643 .22137 Mdot
.46431 .22139 Mdot
.46432 .22141 Mdot
.46433 .22143 Mdot
.46434 .22145 Mdot
.46435 .22147 Mdot
.46436 .2215 Mdot
.46437 .22152 Mdot
.46438 .22154 Mdot
.46439 .22156 Mdot
.4644 .22158 Mdot
.46441 .22161 Mdot
.46442 .22163 Mdot
.46443 .22165 Mdot
.46444 .22167 Mdot
.46445 .22169 Mdot
.46446 .22172 Mdot
.46447 .22174 Mdot
.46448 .22176 Mdot
.46449 .22178 Mdot
.4645 .2218 Mdot
.4645 .22183 Mdot
.46451 .22185 Mdot
.46452 .22187 Mdot
.46453 .22189 Mdot
.46454 .22191 Mdot
.46455 .22193 Mdot
.46456 .22196 Mdot
.46457 .22198 Mdot
.46458 .222 Mdot
.46459 .22202 Mdot
.4646 .22204 Mdot
.46461 .22207 Mdot
.46462 .22209 Mdot
.46463 .22211 Mdot
.46464 .22213 Mdot
.46465 .22215 Mdot
.46466 .22218 Mdot
.46467 .2222 Mdot
.46468 .22222 Mdot
.46469 .22224 Mdot
.4647 .22226 Mdot
.4647 .22229 Mdot
.46471 .22231 Mdot
.46472 .22233 Mdot
.46473 .22235 Mdot
.46474 .22237 Mdot
.46475 .2224 Mdot
.46476 .22242 Mdot
.46477 .22244 Mdot
.46478 .22246 Mdot
.46479 .22248 Mdot
.4648 .22251 Mdot
.46481 .22253 Mdot
.46482 .22255 Mdot
.46483 .22257 Mdot
.46484 .22259 Mdot
.46485 .22262 Mdot
.46486 .22264 Mdot
.46487 .22266 Mdot
.46488 .22268 Mdot
.46489 .2227 Mdot
.4649 .22272 Mdot
.4649 .22275 Mdot
.46491 .22277 Mdot
.46492 .22279 Mdot
.46493 .22281 Mdot
.46494 .22283 Mdot
.46495 .22286 Mdot
.46496 .22288 Mdot
.46497 .2229 Mdot
.46498 .22292 Mdot
.46499 .22294 Mdot
.465 .22297 Mdot
.46501 .22299 Mdot
.46502 .22301 Mdot
.46503 .22303 Mdot
.46504 .22305 Mdot
.46505 .22308 Mdot
.46506 .2231 Mdot
.46507 .22312 Mdot
.46508 .22314 Mdot
.46509 .22316 Mdot
.4651 .22319 Mdot
.4651 .22321 Mdot
.46511 .22323 Mdot
.46512 .22325 Mdot
.46513 .22327 Mdot
.46514 .2233 Mdot
.46515 .22332 Mdot
.46516 .22334 Mdot
.46517 .22336 Mdot
.46518 .22338 Mdot
.46519 .22341 Mdot
.4652 .22343 Mdot
.46521 .22345 Mdot
.46522 .22347 Mdot
.46523 .22349 Mdot
.46524 .22352 Mdot
.46525 .22354 Mdot
.46526 .22356 Mdot
.46527 .22358 Mdot
.46528 .2236 Mdot
.46529 .22363 Mdot
.4653 .22365 Mdot
.4653 .22367 Mdot
.46531 .22369 Mdot
.46532 .22371 Mdot
.46533 .22374 Mdot
.46534 .22376 Mdot
.46535 .22378 Mdot
.46536 .2238 Mdot
.46537 .22382 Mdot
.46538 .22385 Mdot
.46539 .22387 Mdot
.4654 .22389 Mdot
.46541 .22391 Mdot
.46542 .22393 Mdot
.46543 .22396 Mdot
.46544 .22398 Mdot
.46545 .224 Mdot
.46546 .22402 Mdot
.46547 .22404 Mdot
.46548 .22407 Mdot
.46549 .22409 Mdot
.4655 .22411 Mdot
.4655 .22413 Mdot
.46551 .22415 Mdot
.46552 .22418 Mdot
.46553 .2242 Mdot
.46554 .22422 Mdot
.46555 .22424 Mdot
.46556 .22426 Mdot
.46557 .22429 Mdot
.46558 .22431 Mdot
.46559 .22433 Mdot
.4656 .22435 Mdot
.46561 .22438 Mdot
.46562 .2244 Mdot
.46563 .22442 Mdot
.46564 .22444 Mdot
.46565 .22446 Mdot
.46566 .22449 Mdot
.46567 .22451 Mdot
.46568 .22453 Mdot
.46569 .22455 Mdot
.4657 .22457 Mdot
.4657 .2246 Mdot
.46571 .22462 Mdot
.46572 .22464 Mdot
.46573 .22466 Mdot
.46574 .22468 Mdot
.46575 .22471 Mdot
.46576 .22473 Mdot
.46577 .22475 Mdot
.46578 .22477 Mdot
.46579 .22479 Mdot
.4658 .22482 Mdot
.46581 .22484 Mdot
.46582 .22486 Mdot
.46583 .22488 Mdot
.46584 .2249 Mdot
.46585 .22493 Mdot
.46586 .22495 Mdot
.46587 .22497 Mdot
.46588 .22499 Mdot
.46589 .22501 Mdot
.4659 .22504 Mdot
.4659 .22506 Mdot
.46591 .22508 Mdot
.46592 .2251 Mdot
.46593 .22513 Mdot
.46594 .22515 Mdot
.46595 .22517 Mdot
.46596 .22519 Mdot
.46597 .22521 Mdot
.46598 .22524 Mdot
.46599 .22526 Mdot
.466 .22528 Mdot
.46601 .2253 Mdot
.46602 .22532 Mdot
.46603 .22535 Mdot
.46604 .22537 Mdot
.46605 .22539 Mdot
.46606 .22541 Mdot
.46607 .22543 Mdot
.46608 .22546 Mdot
.46609 .22548 Mdot
.4661 .2255 Mdot
.4661 .22552 Mdot
.46611 .22554 Mdot
.46612 .22557 Mdot
.46613 .22559 Mdot
.46614 .22561 Mdot
.46615 .22563 Mdot
.46616 .22566 Mdot
.46617 .22568 Mdot
.46618 .2257 Mdot
.46619 .22572 Mdot
.4662 .22574 Mdot
.46621 .22577 Mdot
.46622 .22579 Mdot
.46623 .22581 Mdot
.46624 .22583 Mdot
.46625 .22585 Mdot
.46626 .22588 Mdot
.46627 .2259 Mdot
.46628 .22592 Mdot
.46629 .22594 Mdot
.4663 .22597 Mdot
.4663 .22599 Mdot
.46631 .22601 Mdot
.46632 .22603 Mdot
.46633 .22605 Mdot
.46634 .22608 Mdot
.46635 .2261 Mdot
.46636 .22612 Mdot
.46637 .22614 Mdot
.46638 .22616 Mdot
.46639 .22619 Mdot
.4664 .22621 Mdot
.46641 .22623 Mdot
.46642 .22625 Mdot
.46643 .22627 Mdot
.46644 .2263 Mdot
.46645 .22632 Mdot
.46646 .22634 Mdot
.46647 .22636 Mdot
.46648 .22639 Mdot
.46649 .22641 Mdot
.4665 .22643 Mdot
.4665 .22645 Mdot
.46651 .22647 Mdot
.46652 .2265 Mdot
.46653 .22652 Mdot
.46654 .22654 Mdot
.46655 .22656 Mdot
.46656 .22658 Mdot
.46657 .22661 Mdot
.46658 .22663 Mdot
.46659 .22665 Mdot
.4666 .22667 Mdot
.46661 .2267 Mdot
.46662 .22672 Mdot
.46663 .22674 Mdot
.46664 .22676 Mdot
.46665 .22678 Mdot
.46666 .22681 Mdot
.46667 .22683 Mdot
.46668 .22685 Mdot
.46669 .22687 Mdot
.4667 .2269 Mdot
.4667 .22692 Mdot
.46671 .22694 Mdot
.46672 .22696 Mdot
.46673 .22698 Mdot
.46674 .22701 Mdot
.46675 .22703 Mdot
.46676 .22705 Mdot
.46677 .22707 Mdot
.46678 .22709 Mdot
.46679 .22712 Mdot
.4668 .22714 Mdot
.46681 .22716 Mdot
.46682 .22718 Mdot
.46683 .22721 Mdot
.46684 .22723 Mdot
.46685 .22725 Mdot
.46686 .22727 Mdot
.46687 .22729 Mdot
.46688 .22732 Mdot
.46689 .22734 Mdot
.4669 .22736 Mdot
.4669 .22738 Mdot
.46691 .22741 Mdot
.46692 .22743 Mdot
.46693 .22745 Mdot
.46694 .22747 Mdot
.46695 .22749 Mdot
.46696 .22752 Mdot
.46697 .22754 Mdot
.46698 .22756 Mdot
.46699 .22758 Mdot
.467 .22761 Mdot
.46701 .22763 Mdot
.46702 .22765 Mdot
.46703 .22767 Mdot
.46704 .22769 Mdot
.46705 .22772 Mdot
.46706 .22774 Mdot
.46707 .22776 Mdot
.46708 .22778 Mdot
.46709 .22781 Mdot
.4671 .22783 Mdot
.4671 .22785 Mdot
.46711 .22787 Mdot
.46712 .22789 Mdot
.46713 .22792 Mdot
.46714 .22794 Mdot
.46715 .22796 Mdot
.46716 .22798 Mdot
.46717 .22801 Mdot
.46718 .22803 Mdot
.46719 .22805 Mdot
.4672 .22807 Mdot
.46721 .22809 Mdot
.46722 .22812 Mdot
.46723 .22814 Mdot
.46724 .22816 Mdot
.46725 .22818 Mdot
.46726 .22821 Mdot
.46727 .22823 Mdot
.46728 .22825 Mdot
.46729 .22827 Mdot
.4673 .22829 Mdot
.4673 .22832 Mdot
.46731 .22834 Mdot
.46732 .22836 Mdot
.46733 .22838 Mdot
.46734 .22841 Mdot
.46735 .22843 Mdot
.46736 .22845 Mdot
.46737 .22847 Mdot
.46738 .22849 Mdot
.46739 .22852 Mdot
.4674 .22854 Mdot
.46741 .22856 Mdot
.46742 .22858 Mdot
.46743 .22861 Mdot
.46744 .22863 Mdot
.46745 .22865 Mdot
.46746 .22867 Mdot
.46747 .22869 Mdot
.46748 .22872 Mdot
.46749 .22874 Mdot
.4675 .22876 Mdot
.4675 .22878 Mdot
.46751 .22881 Mdot
.46752 .22883 Mdot
.46753 .22885 Mdot
.46754 .22887 Mdot
.46755 .22889 Mdot
.46756 .22892 Mdot
.46757 .22894 Mdot
.46758 .22896 Mdot
.46759 .22898 Mdot
.4676 .22901 Mdot
.46761 .22903 Mdot
.46762 .22905 Mdot
.46763 .22907 Mdot
.46764 .2291 Mdot
.46765 .22912 Mdot
.46766 .22914 Mdot
.46767 .22916 Mdot
.46768 .22918 Mdot
.46769 .22921 Mdot
.4677 .22923 Mdot
.4677 .22925 Mdot
.46771 .22927 Mdot
.46772 .2293 Mdot
.46773 .22932 Mdot
.46774 .22934 Mdot
.46775 .22936 Mdot
.46776 .22939 Mdot
.46777 .22941 Mdot
.46778 .22943 Mdot
.46779 .22945 Mdot
.4678 .22947 Mdot
.46781 .2295 Mdot
.46782 .22952 Mdot
.46783 .22954 Mdot
.46784 .22956 Mdot
.46785 .22959 Mdot
.46786 .22961 Mdot
.46787 .22963 Mdot
.46788 .22965 Mdot
.46789 .22968 Mdot
.4679 .2297 Mdot
.4679 .22972 Mdot
.46791 .22974 Mdot
.46792 .22976 Mdot
.46793 .22979 Mdot
.46794 .22981 Mdot
.46795 .22983 Mdot
.46796 .22985 Mdot
.46797 .22988 Mdot
.46798 .2299 Mdot
.46799 .22992 Mdot
.468 .22994 Mdot
.46801 .22997 Mdot
.46802 .22999 Mdot
.46803 .23001 Mdot
.46804 .23003 Mdot
.46805 .23005 Mdot
.46806 .23008 Mdot
.46807 .2301 Mdot
.46808 .23012 Mdot
.46809 .23014 Mdot
.4681 .23017 Mdot
.4681 .23019 Mdot
.46811 .23021 Mdot
.46812 .23023 Mdot
.46813 .23026 Mdot
.46814 .23028 Mdot
.46815 .2303 Mdot
.46816 .23032 Mdot
.46817 .23034 Mdot
.46818 .23037 Mdot
.46819 .23039 Mdot
.4682 .23041 Mdot
.46821 .23043 Mdot
.46822 .23046 Mdot
.46823 .23048 Mdot
.46824 .2305 Mdot
.46825 .23052 Mdot
.46826 .23055 Mdot
.46827 .23057 Mdot
.46828 .23059 Mdot
.46829 .23061 Mdot
.4683 .23064 Mdot
.4683 .23066 Mdot
.46831 .23068 Mdot
.46832 .2307 Mdot
.46833 .23072 Mdot
.46834 .23075 Mdot
.46835 .23077 Mdot
.46836 .23079 Mdot
.46837 .23081 Mdot
.46838 .23084 Mdot
.46839 .23086 Mdot
.4684 .23088 Mdot
.46841 .2309 Mdot
.46842 .23093 Mdot
.46843 .23095 Mdot
.46844 .23097 Mdot
.46845 .23099 Mdot
.46846 .23102 Mdot
.46847 .23104 Mdot
.46848 .23106 Mdot
.46849 .23108 Mdot
.4685 .2311 Mdot
.4685 .23113 Mdot
.46851 .23115 Mdot
.46852 .23117 Mdot
.46853 .23119 Mdot
.46854 .23122 Mdot
.46855 .23124 Mdot
.46856 .23126 Mdot
.46857 .23128 Mdot
.46858 .23131 Mdot
.46859 .23133 Mdot
.4686 .23135 Mdot
.46861 .23137 Mdot
.46862 .2314 Mdot
.46863 .23142 Mdot
.46864 .23144 Mdot
.46865 .23146 Mdot
.46866 .23149 Mdot
.46867 .23151 Mdot
.46868 .23153 Mdot
.46869 .23155 Mdot
.4687 .23158 Mdot
.4687 .2316 Mdot
.46871 .23162 Mdot
.46872 .23164 Mdot
.46873 .23166 Mdot
.46874 .23169 Mdot
.46875 .23171 Mdot
.46876 .23173 Mdot
.46877 .23175 Mdot
.46878 .23178 Mdot
.46879 .2318 Mdot
.4688 .23182 Mdot
.46881 .23184 Mdot
.46882 .23187 Mdot
.46883 .23189 Mdot
.46884 .23191 Mdot
.46885 .23193 Mdot
.46886 .23196 Mdot
.46887 .23198 Mdot
.46888 .232 Mdot
.46889 .23202 Mdot
.4689 .23205 Mdot
.4689 .23207 Mdot
.46891 .23209 Mdot
.46892 .23211 Mdot
.46893 .23214 Mdot
.46894 .23216 Mdot
.46895 .23218 Mdot
.46896 .2322 Mdot
.46897 .23223 Mdot
.46898 .23225 Mdot
.46899 .23227 Mdot
.469 .23229 Mdot
.46901 .23231 Mdot
.46902 .23234 Mdot
.46903 .23236 Mdot
.46904 .23238 Mdot
.46905 .2324 Mdot
.46906 .23243 Mdot
.46907 .23245 Mdot
.46908 .23247 Mdot
.46909 .23249 Mdot
.4691 .23252 Mdot
.4691 .23254 Mdot
.46911 .23256 Mdot
.46912 .23258 Mdot
.46913 .23261 Mdot
.46914 .23263 Mdot
.46915 .23265 Mdot
.46916 .23267 Mdot
.46917 .2327 Mdot
.46918 .23272 Mdot
.46919 .23274 Mdot
.4692 .23276 Mdot
.46921 .23279 Mdot
.46922 .23281 Mdot
.46923 .23283 Mdot
.46924 .23285 Mdot
.46925 .23288 Mdot
.46926 .2329 Mdot
.46927 .23292 Mdot
.46928 .23294 Mdot
.46929 .23297 Mdot
.4693 .23299 Mdot
.4693 .23301 Mdot
.46931 .23303 Mdot
.46932 .23306 Mdot
.46933 .23308 Mdot
.46934 .2331 Mdot
.46935 .23312 Mdot
.46936 .23315 Mdot
.46937 .23317 Mdot
.46938 .23319 Mdot
.46939 .23321 Mdot
.4694 .23324 Mdot
.46941 .23326 Mdot
.46942 .23328 Mdot
.46943 .2333 Mdot
.46944 .23333 Mdot
.46945 .23335 Mdot
.46946 .23337 Mdot
.46947 .23339 Mdot
.46948 .23342 Mdot
.46949 .23344 Mdot
.4695 .23346 Mdot
.4695 .23348 Mdot
.46951 .23351 Mdot
.46952 .23353 Mdot
.46953 .23355 Mdot
.46954 .23357 Mdot
.46955 .2336 Mdot
.46956 .23362 Mdot
.46957 .23364 Mdot
.46958 .23366 Mdot
.46959 .23369 Mdot
.4696 .23371 Mdot
.46961 .23373 Mdot
.46962 .23375 Mdot
.46963 .23378 Mdot
.46964 .2338 Mdot
.46965 .23382 Mdot
.46966 .23384 Mdot
.46967 .23387 Mdot
.46968 .23389 Mdot
.46969 .23391 Mdot
.4697 .23393 Mdot
.4697 .23396 Mdot
.46971 .23398 Mdot
.46972 .234 Mdot
.46973 .23402 Mdot
.46974 .23405 Mdot
.46975 .23407 Mdot
.46976 .23409 Mdot
.46977 .23411 Mdot
.46978 .23414 Mdot
.46979 .23416 Mdot
.4698 .23418 Mdot
.46981 .2342 Mdot
.46982 .23423 Mdot
.46983 .23425 Mdot
.46984 .23427 Mdot
.46985 .23429 Mdot
.46986 .23432 Mdot
.46987 .23434 Mdot
.46988 .23436 Mdot
.46989 .23438 Mdot
.4699 .23441 Mdot
.4699 .23443 Mdot
.46991 .23445 Mdot
.46992 .23447 Mdot
.46993 .2345 Mdot
.46994 .23452 Mdot
.46995 .23454 Mdot
.46996 .23456 Mdot
.46997 .23459 Mdot
.46998 .23461 Mdot
.46999 .23463 Mdot
.47 .23465 Mdot
.47001 .23468 Mdot
.47002 .2347 Mdot
.47003 .23472 Mdot
.47004 .23474 Mdot
.47005 .23477 Mdot
.47006 .23479 Mdot
.47007 .23481 Mdot
.47008 .23483 Mdot
.47009 .23486 Mdot
.4701 .23488 Mdot
.4701 .2349 Mdot
.47011 .23492 Mdot
.47012 .23495 Mdot
.47013 .23497 Mdot
.47014 .23499 Mdot
.47015 .23502 Mdot
.47016 .23504 Mdot
.47017 .23506 Mdot
.47018 .23508 Mdot
.47019 .23511 Mdot
.4702 .23513 Mdot
.47021 .23515 Mdot
.47022 .23517 Mdot
.47023 .2352 Mdot
.47024 .23522 Mdot
.47025 .23524 Mdot
.47026 .23526 Mdot
.47027 .23529 Mdot
.47028 .23531 Mdot
.47029 .23533 Mdot
.4703 .23535 Mdot
.4703 .23538 Mdot
.47031 .2354 Mdot
.47032 .23542 Mdot
.47033 .23544 Mdot
.47034 .23547 Mdot
.47035 .23549 Mdot
.47036 .23551 Mdot
.47037 .23553 Mdot
.47038 .23556 Mdot
.47039 .23558 Mdot
.4704 .2356 Mdot
.47041 .23562 Mdot
.47042 .23565 Mdot
.47043 .23567 Mdot
.47044 .23569 Mdot
.47045 .23572 Mdot
.47046 .23574 Mdot
.47047 .23576 Mdot
.47048 .23578 Mdot
.47049 .23581 Mdot
.4705 .23583 Mdot
.4705 .23585 Mdot
.47051 .23587 Mdot
.47052 .2359 Mdot
.47053 .23592 Mdot
.47054 .23594 Mdot
.47055 .23596 Mdot
.47056 .23599 Mdot
.47057 .23601 Mdot
.47058 .23603 Mdot
.47059 .23605 Mdot
.4706 .23608 Mdot
.47061 .2361 Mdot
.47062 .23612 Mdot
.47063 .23614 Mdot
.47064 .23617 Mdot
.47065 .23619 Mdot
.47066 .23621 Mdot
.47067 .23624 Mdot
.47068 .23626 Mdot
.47069 .23628 Mdot
.4707 .2363 Mdot
.4707 .23633 Mdot
.47071 .23635 Mdot
.47072 .23637 Mdot
.47073 .23639 Mdot
.47074 .23642 Mdot
.47075 .23644 Mdot
.47076 .23646 Mdot
.47077 .23648 Mdot
.47078 .23651 Mdot
.47079 .23653 Mdot
.4708 .23655 Mdot
.47081 .23657 Mdot
.47082 .2366 Mdot
.47083 .23662 Mdot
.47084 .23664 Mdot
.47085 .23667 Mdot
.47086 .23669 Mdot
.47087 .23671 Mdot
.47088 .23673 Mdot
.47089 .23676 Mdot
.4709 .23678 Mdot
.4709 .2368 Mdot
.47091 .23682 Mdot
.47092 .23685 Mdot
.47093 .23687 Mdot
.47094 .23689 Mdot
.47095 .23691 Mdot
.47096 .23694 Mdot
.47097 .23696 Mdot
.47098 .23698 Mdot
.47099 .23701 Mdot
.471 .23703 Mdot
.47101 .23705 Mdot
.47102 .23707 Mdot
.47103 .2371 Mdot
.47104 .23712 Mdot
.47105 .23714 Mdot
.47106 .23716 Mdot
.47107 .23719 Mdot
.47108 .23721 Mdot
.47109 .23723 Mdot
.4711 .23725 Mdot
.4711 .23728 Mdot
.47111 .2373 Mdot
.47112 .23732 Mdot
.47113 .23735 Mdot
.47114 .23737 Mdot
.47115 .23739 Mdot
.47116 .23741 Mdot
.47117 .23744 Mdot
.47118 .23746 Mdot
.47119 .23748 Mdot
.4712 .2375 Mdot
.47121 .23753 Mdot
.47122 .23755 Mdot
.47123 .23757 Mdot
.47124 .23759 Mdot
.47125 .23762 Mdot
.47126 .23764 Mdot
.47127 .23766 Mdot
.47128 .23769 Mdot
.47129 .23771 Mdot
.4713 .23773 Mdot
.4713 .23775 Mdot
.47131 .23778 Mdot
.47132 .2378 Mdot
.47133 .23782 Mdot
.47134 .23784 Mdot
.47135 .23787 Mdot
.47136 .23789 Mdot
.47137 .23791 Mdot
.47138 .23794 Mdot
.47139 .23796 Mdot
.4714 .23798 Mdot
.47141 .238 Mdot
.47142 .23803 Mdot
.47143 .23805 Mdot
.47144 .23807 Mdot
.47145 .23809 Mdot
.47146 .23812 Mdot
.47147 .23814 Mdot
.47148 .23816 Mdot
.47149 .23819 Mdot
.4715 .23821 Mdot
.4715 .23823 Mdot
.47151 .23825 Mdot
.47152 .23828 Mdot
.47153 .2383 Mdot
.47154 .23832 Mdot
.47155 .23834 Mdot
.47156 .23837 Mdot
.47157 .23839 Mdot
.47158 .23841 Mdot
.47159 .23844 Mdot
.4716 .23846 Mdot
.47161 .23848 Mdot
.47162 .2385 Mdot
.47163 .23853 Mdot
.47164 .23855 Mdot
.47165 .23857 Mdot
.47166 .23859 Mdot
.47167 .23862 Mdot
.47168 .23864 Mdot
.47169 .23866 Mdot
.4717 .23869 Mdot
.4717 .23871 Mdot
.47171 .23873 Mdot
.47172 .23875 Mdot
.47173 .23878 Mdot
.47174 .2388 Mdot
.47175 .23882 Mdot
.47176 .23884 Mdot
.47177 .23887 Mdot
.47178 .23889 Mdot
.47179 .23891 Mdot
.4718 .23894 Mdot
.47181 .23896 Mdot
.47182 .23898 Mdot
.47183 .239 Mdot
.47184 .23903 Mdot
.47185 .23905 Mdot
.47186 .23907 Mdot
.47187 .2391 Mdot
.47188 .23912 Mdot
.47189 .23914 Mdot
.4719 .23916 Mdot
.4719 .23919 Mdot
.47191 .23921 Mdot
.47192 .23923 Mdot
.47193 .23925 Mdot
.47194 .23928 Mdot
.47195 .2393 Mdot
.47196 .23932 Mdot
.47197 .23935 Mdot
.47198 .23937 Mdot
.47199 .23939 Mdot
.472 .23941 Mdot
.47201 .23944 Mdot
.47202 .23946 Mdot
.47203 .23948 Mdot
.47204 .2395 Mdot
.47205 .23953 Mdot
.47206 .23955 Mdot
.47207 .23957 Mdot
.47208 .2396 Mdot
.47209 .23962 Mdot
.4721 .23964 Mdot
.4721 .23966 Mdot
.47211 .23969 Mdot
.47212 .23971 Mdot
.47213 .23973 Mdot
.47214 .23976 Mdot
.47215 .23978 Mdot
.47216 .2398 Mdot
.47217 .23982 Mdot
.47218 .23985 Mdot
.47219 .23987 Mdot
.4722 .23989 Mdot
.47221 .23992 Mdot
.47222 .23994 Mdot
.47223 .23996 Mdot
.47224 .23998 Mdot
.47225 .24001 Mdot
.47226 .24003 Mdot
.47227 .24005 Mdot
.47228 .24007 Mdot
.47229 .2401 Mdot
.4723 .24012 Mdot
.4723 .24014 Mdot
.47231 .24017 Mdot
.47232 .24019 Mdot
.47233 .24021 Mdot
.47234 .24023 Mdot
.47235 .24026 Mdot
.47236 .24028 Mdot
.47237 .2403 Mdot
.47238 .24033 Mdot
.47239 .24035 Mdot
.4724 .24037 Mdot
.47241 .24039 Mdot
.47242 .24042 Mdot
.47243 .24044 Mdot
.47244 .24046 Mdot
.47245 .24049 Mdot
.47246 .24051 Mdot
.47247 .24053 Mdot
.47248 .24055 Mdot
.47249 .24058 Mdot
.4725 .2406 Mdot
.4725 .24062 Mdot
.47251 .24065 Mdot
.47252 .24067 Mdot
.47253 .24069 Mdot
.47254 .24071 Mdot
.47255 .24074 Mdot
.47256 .24076 Mdot
.47257 .24078 Mdot
.47258 .24081 Mdot
.47259 .24083 Mdot
.4726 .24085 Mdot
.47261 .24087 Mdot
.47262 .2409 Mdot
.47263 .24092 Mdot
.47264 .24094 Mdot
.47265 .24097 Mdot
.47266 .24099 Mdot
.47267 .24101 Mdot
.47268 .24103 Mdot
.47269 .24106 Mdot
.4727 .24108 Mdot
.4727 .2411 Mdot
.47271 .24113 Mdot
.47272 .24115 Mdot
.47273 .24117 Mdot
.47274 .24119 Mdot
.47275 .24122 Mdot
.47276 .24124 Mdot
.47277 .24126 Mdot
.47278 .24129 Mdot
.47279 .24131 Mdot
.4728 .24133 Mdot
.47281 .24135 Mdot
.47282 .24138 Mdot
.47283 .2414 Mdot
.47284 .24142 Mdot
.47285 .24145 Mdot
.47286 .24147 Mdot
.47287 .24149 Mdot
.47288 .24151 Mdot
.47289 .24154 Mdot
.4729 .24156 Mdot
.4729 .24158 Mdot
.47291 .24161 Mdot
.47292 .24163 Mdot
.47293 .24165 Mdot
.47294 .24167 Mdot
.47295 .2417 Mdot
.47296 .24172 Mdot
.47297 .24174 Mdot
.47298 .24177 Mdot
.47299 .24179 Mdot
.473 .24181 Mdot
.47301 .24183 Mdot
.47302 .24186 Mdot
.47303 .24188 Mdot
.47304 .2419 Mdot
.47305 .24193 Mdot
.47306 .24195 Mdot
.47307 .24197 Mdot
.47308 .24199 Mdot
.47309 .24202 Mdot
.4731 .24204 Mdot
.4731 .24206 Mdot
.47311 .24209 Mdot
.47312 .24211 Mdot
.47313 .24213 Mdot
.47314 .24216 Mdot
.47315 .24218 Mdot
.47316 .2422 Mdot
.47317 .24222 Mdot
.47318 .24225 Mdot
.47319 .24227 Mdot
.4732 .24229 Mdot
.47321 .24232 Mdot
.47322 .24234 Mdot
.47323 .24236 Mdot
.47324 .24238 Mdot
.47325 .24241 Mdot
.47326 .24243 Mdot
.47327 .24245 Mdot
.47328 .24248 Mdot
.47329 .2425 Mdot
.4733 .24252 Mdot
.4733 .24254 Mdot
.47331 .24257 Mdot
.47332 .24259 Mdot
.47333 .24261 Mdot
.47334 .24264 Mdot
.47335 .24266 Mdot
.47336 .24268 Mdot
.47337 .24271 Mdot
.47338 .24273 Mdot
.47339 .24275 Mdot
.4734 .24277 Mdot
.47341 .2428 Mdot
.47342 .24282 Mdot
.47343 .24284 Mdot
.47344 .24287 Mdot
.47345 .24289 Mdot
.47346 .24291 Mdot
.47347 .24293 Mdot
.47348 .24296 Mdot
.47349 .24298 Mdot
.4735 .243 Mdot
.4735 .24303 Mdot
.47351 .24305 Mdot
.47352 .24307 Mdot
.47353 .2431 Mdot
.47354 .24312 Mdot
.47355 .24314 Mdot
.47356 .24316 Mdot
.47357 .24319 Mdot
.47358 .24321 Mdot
.47359 .24323 Mdot
.4736 .24326 Mdot
.47361 .24328 Mdot
.47362 .2433 Mdot
.47363 .24333 Mdot
.47364 .24335 Mdot
.47365 .24337 Mdot
.47366 .24339 Mdot
.47367 .24342 Mdot
.47368 .24344 Mdot
.47369 .24346 Mdot
.4737 .24349 Mdot
.4737 .24351 Mdot
.47371 .24353 Mdot
.47372 .24355 Mdot
.47373 .24358 Mdot
.47374 .2436 Mdot
.47375 .24362 Mdot
.47376 .24365 Mdot
.47377 .24367 Mdot
.47378 .24369 Mdot
.47379 .24372 Mdot
.4738 .24374 Mdot
.47381 .24376 Mdot
.47382 .24378 Mdot
.47383 .24381 Mdot
.47384 .24383 Mdot
.47385 .24385 Mdot
.47386 .24388 Mdot
.47387 .2439 Mdot
.47388 .24392 Mdot
.47389 .24395 Mdot
.4739 .24397 Mdot
.4739 .24399 Mdot
.47391 .24401 Mdot
.47392 .24404 Mdot
.47393 .24406 Mdot
.47394 .24408 Mdot
.47395 .24411 Mdot
.47396 .24413 Mdot
.47397 .24415 Mdot
.47398 .24418 Mdot
.47399 .2442 Mdot
.474 .24422 Mdot
.47401 .24424 Mdot
.47402 .24427 Mdot
.47403 .24429 Mdot
.47404 .24431 Mdot
.47405 .24434 Mdot
.47406 .24436 Mdot
.47407 .24438 Mdot
.47408 .24441 Mdot
.47409 .24443 Mdot
.4741 .24445 Mdot
.4741 .24447 Mdot
.47411 .2445 Mdot
.47412 .24452 Mdot
.47413 .24454 Mdot
.47414 .24457 Mdot
.47415 .24459 Mdot
.47416 .24461 Mdot
.47417 .24464 Mdot
.47418 .24466 Mdot
.47419 .24468 Mdot
.4742 .2447 Mdot
.47421 .24473 Mdot
.47422 .24475 Mdot
.47423 .24477 Mdot
.47424 .2448 Mdot
.47425 .24482 Mdot
.47426 .24484 Mdot
.47427 .24487 Mdot
.47428 .24489 Mdot
.47429 .24491 Mdot
.4743 .24494 Mdot
.4743 .24496 Mdot
.47431 .24498 Mdot
.47432 .245 Mdot
.47433 .24503 Mdot
.47434 .24505 Mdot
.47435 .24507 Mdot
.47436 .2451 Mdot
.47437 .24512 Mdot
.47438 .24514 Mdot
.47439 .24517 Mdot
.4744 .24519 Mdot
.47441 .24521 Mdot
.47442 .24523 Mdot
.47443 .24526 Mdot
.47444 .24528 Mdot
.47445 .2453 Mdot
.47446 .24533 Mdot
.47447 .24535 Mdot
.47448 .24537 Mdot
.47449 .2454 Mdot
.4745 .24542 Mdot
.4745 .24544 Mdot
.47451 .24547 Mdot
.47452 .24549 Mdot
.47453 .24551 Mdot
.47454 .24553 Mdot
.47455 .24556 Mdot
.47456 .24558 Mdot
.47457 .2456 Mdot
.47458 .24563 Mdot
.47459 .24565 Mdot
.4746 .24567 Mdot
.47461 .2457 Mdot
.47462 .24572 Mdot
.47463 .24574 Mdot
.47464 .24577 Mdot
.47465 .24579 Mdot
.47466 .24581 Mdot
.47467 .24583 Mdot
.47468 .24586 Mdot
.47469 .24588 Mdot
.4747 .2459 Mdot
.4747 .24593 Mdot
.47471 .24595 Mdot
.47472 .24597 Mdot
.47473 .246 Mdot
.47474 .24602 Mdot
.47475 .24604 Mdot
.47476 .24607 Mdot
.47477 .24609 Mdot
.47478 .24611 Mdot
.47479 .24613 Mdot
.4748 .24616 Mdot
.47481 .24618 Mdot
.47482 .2462 Mdot
.47483 .24623 Mdot
.47484 .24625 Mdot
.47485 .24627 Mdot
.47486 .2463 Mdot
.47487 .24632 Mdot
.47488 .24634 Mdot
.47489 .24637 Mdot
.4749 .24639 Mdot
.4749 .24641 Mdot
.47491 .24644 Mdot
.47492 .24646 Mdot
.47493 .24648 Mdot
.47494 .2465 Mdot
.47495 .24653 Mdot
.47496 .24655 Mdot
.47497 .24657 Mdot
.47498 .2466 Mdot
.47499 .24662 Mdot
.475 .24664 Mdot
.47501 .24667 Mdot
.47502 .24669 Mdot
.47503 .24671 Mdot
.47504 .24674 Mdot
.47505 .24676 Mdot
.47506 .24678 Mdot
.47507 .24681 Mdot
.47508 .24683 Mdot
.47509 .24685 Mdot
.4751 .24687 Mdot
.4751 .2469 Mdot
.47511 .24692 Mdot
.47512 .24694 Mdot
.47513 .24697 Mdot
.47514 .24699 Mdot
.47515 .24701 Mdot
.47516 .24704 Mdot
.47517 .24706 Mdot
.47518 .24708 Mdot
.47519 .24711 Mdot
.4752 .24713 Mdot
.47521 .24715 Mdot
.47522 .24718 Mdot
.47523 .2472 Mdot
.47524 .24722 Mdot
.47525 .24724 Mdot
.47526 .24727 Mdot
.47527 .24729 Mdot
.47528 .24731 Mdot
.47529 .24734 Mdot
.4753 .24736 Mdot
.4753 .24738 Mdot
.47531 .24741 Mdot
.47532 .24743 Mdot
.47533 .24745 Mdot
.47534 .24748 Mdot
.47535 .2475 Mdot
.47536 .24752 Mdot
.47537 .24755 Mdot
.47538 .24757 Mdot
.47539 .24759 Mdot
.4754 .24762 Mdot
.47541 .24764 Mdot
.47542 .24766 Mdot
.47543 .24768 Mdot
.47544 .24771 Mdot
.47545 .24773 Mdot
.47546 .24775 Mdot
.47547 .24778 Mdot
.47548 .2478 Mdot
.47549 .24782 Mdot
.4755 .24785 Mdot
.4755 .24787 Mdot
.47551 .24789 Mdot
.47552 .24792 Mdot
.47553 .24794 Mdot
.47554 .24796 Mdot
.47555 .24799 Mdot
.47556 .24801 Mdot
.47557 .24803 Mdot
.47558 .24806 Mdot
.47559 .24808 Mdot
.4756 .2481 Mdot
.47561 .24813 Mdot
.47562 .24815 Mdot
.47563 .24817 Mdot
.47564 .24819 Mdot
.47565 .24822 Mdot
.47566 .24824 Mdot
.47567 .24826 Mdot
.47568 .24829 Mdot
.47569 .24831 Mdot
.4757 .24833 Mdot
.4757 .24836 Mdot
.47571 .24838 Mdot
.47572 .2484 Mdot
.47573 .24843 Mdot
.47574 .24845 Mdot
.47575 .24847 Mdot
.47576 .2485 Mdot
.47577 .24852 Mdot
.47578 .24854 Mdot
.47579 .24857 Mdot
.4758 .24859 Mdot
.47581 .24861 Mdot
.47582 .24864 Mdot
.47583 .24866 Mdot
.47584 .24868 Mdot
.47585 .24871 Mdot
.47586 .24873 Mdot
.47587 .24875 Mdot
.47588 .24878 Mdot
.47589 .2488 Mdot
.4759 .24882 Mdot
.4759 .24884 Mdot
.47591 .24887 Mdot
.47592 .24889 Mdot
.47593 .24891 Mdot
.47594 .24894 Mdot
.47595 .24896 Mdot
.47596 .24898 Mdot
.47597 .24901 Mdot
.47598 .24903 Mdot
.47599 .24905 Mdot
.476 .24908 Mdot
.47601 .2491 Mdot
.47602 .24912 Mdot
.47603 .24915 Mdot
.47604 .24917 Mdot
.47605 .24919 Mdot
.47606 .24922 Mdot
.47607 .24924 Mdot
.47608 .24926 Mdot
.47609 .24929 Mdot
.4761 .24931 Mdot
.4761 .24933 Mdot
.47611 .24936 Mdot
.47612 .24938 Mdot
.47613 .2494 Mdot
.47614 .24943 Mdot
.47615 .24945 Mdot
.47616 .24947 Mdot
.47617 .2495 Mdot
.47618 .24952 Mdot
.47619 .24954 Mdot
.4762 .24957 Mdot
.47621 .24959 Mdot
.47622 .24961 Mdot
.47623 .24963 Mdot
.47624 .24966 Mdot
.47625 .24968 Mdot
.47626 .2497 Mdot
.47627 .24973 Mdot
.47628 .24975 Mdot
.47629 .24977 Mdot
.4763 .2498 Mdot
.4763 .24982 Mdot
.47631 .24984 Mdot
.47632 .24987 Mdot
.47633 .24989 Mdot
.47634 .24991 Mdot
.47635 .24994 Mdot
.47636 .24996 Mdot
.47637 .24998 Mdot
.47638 .25001 Mdot
.47639 .25003 Mdot
.4764 .25005 Mdot
.47641 .25008 Mdot
.47642 .2501 Mdot
.47643 .25012 Mdot
.47644 .25015 Mdot
.47645 .25017 Mdot
.47646 .25019 Mdot
.47647 .25022 Mdot
.47648 .25024 Mdot
.47649 .25026 Mdot
.4765 .25029 Mdot
.4765 .25031 Mdot
.47651 .25033 Mdot
.47652 .25036 Mdot
.47653 .25038 Mdot
.47654 .2504 Mdot
.47655 .25043 Mdot
.47656 .25045 Mdot
.47657 .25047 Mdot
.47658 .2505 Mdot
.47659 .25052 Mdot
.4766 .25054 Mdot
.47661 .25057 Mdot
.47662 .25059 Mdot
.47663 .25061 Mdot
.47664 .25064 Mdot
.47665 .25066 Mdot
.47666 .25068 Mdot
.47667 .25071 Mdot
.47668 .25073 Mdot
.47669 .25075 Mdot
.4767 .25078 Mdot
.4767 .2508 Mdot
.47671 .25082 Mdot
.47672 .25085 Mdot
.47673 .25087 Mdot
.47674 .25089 Mdot
.47675 .25092 Mdot
.47676 .25094 Mdot
.47677 .25096 Mdot
.47678 .25099 Mdot
.47679 .25101 Mdot
.4768 .25103 Mdot
.47681 .25106 Mdot
.47682 .25108 Mdot
.47683 .2511 Mdot
.47684 .25113 Mdot
.47685 .25115 Mdot
.47686 .25117 Mdot
.47687 .2512 Mdot
.47688 .25122 Mdot
.47689 .25124 Mdot
.4769 .25127 Mdot
.4769 .25129 Mdot
.47691 .25131 Mdot
.47692 .25134 Mdot
.47693 .25136 Mdot
.47694 .25138 Mdot
.47695 .25141 Mdot
.47696 .25143 Mdot
.47697 .25145 Mdot
.47698 .25148 Mdot
.47699 .2515 Mdot
.477 .25152 Mdot
.47701 .25155 Mdot
.47702 .25157 Mdot
.47703 .25159 Mdot
.47704 .25162 Mdot
.47705 .25164 Mdot
.47706 .25166 Mdot
.47707 .25169 Mdot
.47708 .25171 Mdot
.47709 .25173 Mdot
.4771 .25176 Mdot
.4771 .25178 Mdot
.47711 .2518 Mdot
.47712 .25183 Mdot
.47713 .25185 Mdot
.47714 .25187 Mdot
.47715 .2519 Mdot
.47716 .25192 Mdot
.47717 .25194 Mdot
.47718 .25197 Mdot
.47719 .25199 Mdot
.4772 .25201 Mdot
.47721 .25204 Mdot
.47722 .25206 Mdot
.47723 .25208 Mdot
.47724 .25211 Mdot
.47725 .25213 Mdot
.47726 .25215 Mdot
.47727 .25218 Mdot
.47728 .2522 Mdot
.47729 .25222 Mdot
.4773 .25225 Mdot
.4773 .25227 Mdot
.47731 .25229 Mdot
.47732 .25232 Mdot
.47733 .25234 Mdot
.47734 .25236 Mdot
.47735 .25239 Mdot
.47736 .25241 Mdot
.47737 .25243 Mdot
.47738 .25246 Mdot
.47739 .25248 Mdot
.4774 .2525 Mdot
.47741 .25253 Mdot
.47742 .25255 Mdot
.47743 .25257 Mdot
.47744 .2526 Mdot
.47745 .25262 Mdot
.47746 .25264 Mdot
.47747 .25267 Mdot
.47748 .25269 Mdot
.47749 .25271 Mdot
.4775 .25274 Mdot
.4775 .25276 Mdot
.47751 .25279 Mdot
.47752 .25281 Mdot
.47753 .25283 Mdot
.47754 .25286 Mdot
.47755 .25288 Mdot
.47756 .2529 Mdot
.47757 .25293 Mdot
.47758 .25295 Mdot
.47759 .25297 Mdot
.4776 .253 Mdot
.47761 .25302 Mdot
.47762 .25304 Mdot
.47763 .25307 Mdot
.47764 .25309 Mdot
.47765 .25311 Mdot
.47766 .25314 Mdot
.47767 .25316 Mdot
.47768 .25318 Mdot
.47769 .25321 Mdot
.4777 .25323 Mdot
.4777 .25325 Mdot
.47771 .25328 Mdot
.47772 .2533 Mdot
.47773 .25332 Mdot
.47774 .25335 Mdot
.47775 .25337 Mdot
.47776 .25339 Mdot
.47777 .25342 Mdot
.47778 .25344 Mdot
.47779 .25346 Mdot
.4778 .25349 Mdot
.47781 .25351 Mdot
.47782 .25353 Mdot
.47783 .25356 Mdot
.47784 .25358 Mdot
.47785 .2536 Mdot
.47786 .25363 Mdot
.47787 .25365 Mdot
.47788 .25368 Mdot
.47789 .2537 Mdot
.4779 .25372 Mdot
.4779 .25375 Mdot
.47791 .25377 Mdot
.47792 .25379 Mdot
.47793 .25382 Mdot
.47794 .25384 Mdot
.47795 .25386 Mdot
.47796 .25389 Mdot
.47797 .25391 Mdot
.47798 .25393 Mdot
.47799 .25396 Mdot
.478 .25398 Mdot
.47801 .254 Mdot
.47802 .25403 Mdot
.47803 .25405 Mdot
.47804 .25407 Mdot
.47805 .2541 Mdot
.47806 .25412 Mdot
.47807 .25414 Mdot
.47808 .25417 Mdot
.47809 .25419 Mdot
.4781 .25421 Mdot
.4781 .25424 Mdot
.47811 .25426 Mdot
.47812 .25429 Mdot
.47813 .25431 Mdot
.47814 .25433 Mdot
.47815 .25436 Mdot
.47816 .25438 Mdot
.47817 .2544 Mdot
.47818 .25443 Mdot
.47819 .25445 Mdot
.4782 .25447 Mdot
.47821 .2545 Mdot
.47822 .25452 Mdot
.47823 .25454 Mdot
.47824 .25457 Mdot
.47825 .25459 Mdot
.47826 .25461 Mdot
.47827 .25464 Mdot
.47828 .25466 Mdot
.47829 .25468 Mdot
.4783 .25471 Mdot
.4783 .25473 Mdot
.47831 .25475 Mdot
.47832 .25478 Mdot
.47833 .2548 Mdot
.47834 .25483 Mdot
.47835 .25485 Mdot
.47836 .25487 Mdot
.47837 .2549 Mdot
.47838 .25492 Mdot
.47839 .25494 Mdot
.4784 .25497 Mdot
.47841 .25499 Mdot
.47842 .25501 Mdot
.47843 .25504 Mdot
.47844 .25506 Mdot
.47845 .25508 Mdot
.47846 .25511 Mdot
.47847 .25513 Mdot
.47848 .25515 Mdot
.47849 .25518 Mdot
.4785 .2552 Mdot
.4785 .25523 Mdot
.47851 .25525 Mdot
.47852 .25527 Mdot
.47853 .2553 Mdot
.47854 .25532 Mdot
.47855 .25534 Mdot
.47856 .25537 Mdot
.47857 .25539 Mdot
.47858 .25541 Mdot
.47859 .25544 Mdot
.4786 .25546 Mdot
.47861 .25548 Mdot
.47862 .25551 Mdot
.47863 .25553 Mdot
.47864 .25555 Mdot
.47865 .25558 Mdot
.47866 .2556 Mdot
.47867 .25563 Mdot
.47868 .25565 Mdot
.47869 .25567 Mdot
.4787 .2557 Mdot
.4787 .25572 Mdot
.47871 .25574 Mdot
.47872 .25577 Mdot
.47873 .25579 Mdot
.47874 .25581 Mdot
.47875 .25584 Mdot
.47876 .25586 Mdot
.47877 .25588 Mdot
.47878 .25591 Mdot
.47879 .25593 Mdot
.4788 .25595 Mdot
.47881 .25598 Mdot
.47882 .256 Mdot
.47883 .25603 Mdot
.47884 .25605 Mdot
.47885 .25607 Mdot
.47886 .2561 Mdot
.47887 .25612 Mdot
.47888 .25614 Mdot
.47889 .25617 Mdot
.4789 .25619 Mdot
.4789 .25621 Mdot
.47891 .25624 Mdot
.47892 .25626 Mdot
.47893 .25628 Mdot
.47894 .25631 Mdot
.47895 .25633 Mdot
.47896 .25636 Mdot
.47897 .25638 Mdot
.47898 .2564 Mdot
.47899 .25643 Mdot
.479 .25645 Mdot
.47901 .25647 Mdot
.47902 .2565 Mdot
.47903 .25652 Mdot
.47904 .25654 Mdot
.47905 .25657 Mdot
.47906 .25659 Mdot
.47907 .25661 Mdot
.47908 .25664 Mdot
.47909 .25666 Mdot
.4791 .25669 Mdot
.4791 .25671 Mdot
.47911 .25673 Mdot
.47912 .25676 Mdot
.47913 .25678 Mdot
.47914 .2568 Mdot
.47915 .25683 Mdot
.47916 .25685 Mdot
.47917 .25687 Mdot
.47918 .2569 Mdot
.47919 .25692 Mdot
.4792 .25694 Mdot
.47921 .25697 Mdot
.47922 .25699 Mdot
.47923 .25702 Mdot
.47924 .25704 Mdot
.47925 .25706 Mdot
.47926 .25709 Mdot
.47927 .25711 Mdot
.47928 .25713 Mdot
.47929 .25716 Mdot
.4793 .25718 Mdot
.4793 .2572 Mdot
.47931 .25723 Mdot
.47932 .25725 Mdot
.47933 .25728 Mdot
.47934 .2573 Mdot
.47935 .25732 Mdot
.47936 .25735 Mdot
.47937 .25737 Mdot
.47938 .25739 Mdot
.47939 .25742 Mdot
.4794 .25744 Mdot
.47941 .25746 Mdot
.47942 .25749 Mdot
.47943 .25751 Mdot
.47944 .25754 Mdot
.47945 .25756 Mdot
.47946 .25758 Mdot
.47947 .25761 Mdot
.47948 .25763 Mdot
.47949 .25765 Mdot
.4795 .25768 Mdot
.4795 .2577 Mdot
.47951 .25772 Mdot
.47952 .25775 Mdot
.47953 .25777 Mdot
.47954 .25779 Mdot
.47955 .25782 Mdot
.47956 .25784 Mdot
.47957 .25787 Mdot
.47958 .25789 Mdot
.47959 .25791 Mdot
.4796 .25794 Mdot
.47961 .25796 Mdot
.47962 .25798 Mdot
.47963 .25801 Mdot
.47964 .25803 Mdot
.47965 .25806 Mdot
.47966 .25808 Mdot
.47967 .2581 Mdot
.47968 .25813 Mdot
.47969 .25815 Mdot
.4797 .25817 Mdot
.4797 .2582 Mdot
.47971 .25822 Mdot
.47972 .25824 Mdot
.47973 .25827 Mdot
.47974 .25829 Mdot
.47975 .25832 Mdot
.47976 .25834 Mdot
.47977 .25836 Mdot
.47978 .25839 Mdot
.47979 .25841 Mdot
.4798 .25843 Mdot
.47981 .25846 Mdot
.47982 .25848 Mdot
.47983 .2585 Mdot
.47984 .25853 Mdot
.47985 .25855 Mdot
.47986 .25858 Mdot
.47987 .2586 Mdot
.47988 .25862 Mdot
.47989 .25865 Mdot
.4799 .25867 Mdot
.4799 .25869 Mdot
.47991 .25872 Mdot
.47992 .25874 Mdot
.47993 .25876 Mdot
.47994 .25879 Mdot
.47995 .25881 Mdot
.47996 .25884 Mdot
.47997 .25886 Mdot
.47998 .25888 Mdot
.47999 .25891 Mdot
.48 .25893 Mdot
.48001 .25895 Mdot
.48002 .25898 Mdot
.48003 .259 Mdot
.48004 .25903 Mdot
.48005 .25905 Mdot
.48006 .25907 Mdot
.48007 .2591 Mdot
.48008 .25912 Mdot
.48009 .25914 Mdot
.4801 .25917 Mdot
.4801 .25919 Mdot
.48011 .25922 Mdot
.48012 .25924 Mdot
.48013 .25926 Mdot
.48014 .25929 Mdot
.48015 .25931 Mdot
.48016 .25933 Mdot
.48017 .25936 Mdot
.48018 .25938 Mdot
.48019 .2594 Mdot
.4802 .25943 Mdot
.48021 .25945 Mdot
.48022 .25948 Mdot
.48023 .2595 Mdot
.48024 .25952 Mdot
.48025 .25955 Mdot
.48026 .25957 Mdot
.48027 .25959 Mdot
.48028 .25962 Mdot
.48029 .25964 Mdot
.4803 .25967 Mdot
.4803 .25969 Mdot
.48031 .25971 Mdot
.48032 .25974 Mdot
.48033 .25976 Mdot
.48034 .25978 Mdot
.48035 .25981 Mdot
.48036 .25983 Mdot
.48037 .25986 Mdot
.48038 .25988 Mdot
.48039 .2599 Mdot
.4804 .25993 Mdot
.48041 .25995 Mdot
.48042 .25997 Mdot
.48043 .26 Mdot
.48044 .26002 Mdot
.48045 .26005 Mdot
.48046 .26007 Mdot
.48047 .26009 Mdot
.48048 .26012 Mdot
.48049 .26014 Mdot
.4805 .26016 Mdot
.4805 .26019 Mdot
.48051 .26021 Mdot
.48052 .26024 Mdot
.48053 .26026 Mdot
.48054 .26028 Mdot
.48055 .26031 Mdot
.48056 .26033 Mdot
.48057 .26035 Mdot
.48058 .26038 Mdot
.48059 .2604 Mdot
.4806 .26043 Mdot
.48061 .26045 Mdot
.48062 .26047 Mdot
.48063 .2605 Mdot
.48064 .26052 Mdot
.48065 .26054 Mdot
.48066 .26057 Mdot
.48067 .26059 Mdot
.48068 .26062 Mdot
.48069 .26064 Mdot
.4807 .26066 Mdot
.4807 .26069 Mdot
.48071 .26071 Mdot
.48072 .26073 Mdot
.48073 .26076 Mdot
.48074 .26078 Mdot
.48075 .26081 Mdot
.48076 .26083 Mdot
.48077 .26085 Mdot
.48078 .26088 Mdot
.48079 .2609 Mdot
.4808 .26092 Mdot
.48081 .26095 Mdot
.48082 .26097 Mdot
.48083 .261 Mdot
.48084 .26102 Mdot
.48085 .26104 Mdot
.48086 .26107 Mdot
.48087 .26109 Mdot
.48088 .26111 Mdot
.48089 .26114 Mdot
.4809 .26116 Mdot
.4809 .26119 Mdot
.48091 .26121 Mdot
.48092 .26123 Mdot
.48093 .26126 Mdot
.48094 .26128 Mdot
.48095 .2613 Mdot
.48096 .26133 Mdot
.48097 .26135 Mdot
.48098 .26138 Mdot
.48099 .2614 Mdot
.481 .26142 Mdot
.48101 .26145 Mdot
.48102 .26147 Mdot
.48103 .2615 Mdot
.48104 .26152 Mdot
.48105 .26154 Mdot
.48106 .26157 Mdot
.48107 .26159 Mdot
.48108 .26161 Mdot
.48109 .26164 Mdot
.4811 .26166 Mdot
.4811 .26169 Mdot
.48111 .26171 Mdot
.48112 .26173 Mdot
.48113 .26176 Mdot
.48114 .26178 Mdot
.48115 .2618 Mdot
.48116 .26183 Mdot
.48117 .26185 Mdot
.48118 .26188 Mdot
.48119 .2619 Mdot
.4812 .26192 Mdot
.48121 .26195 Mdot
.48122 .26197 Mdot
.48123 .262 Mdot
.48124 .26202 Mdot
.48125 .26204 Mdot
.48126 .26207 Mdot
.48127 .26209 Mdot
.48128 .26211 Mdot
.48129 .26214 Mdot
.4813 .26216 Mdot
.4813 .26219 Mdot
.48131 .26221 Mdot
.48132 .26223 Mdot
.48133 .26226 Mdot
.48134 .26228 Mdot
.48135 .26231 Mdot
.48136 .26233 Mdot
.48137 .26235 Mdot
.48138 .26238 Mdot
.48139 .2624 Mdot
.4814 .26242 Mdot
.48141 .26245 Mdot
.48142 .26247 Mdot
.48143 .2625 Mdot
.48144 .26252 Mdot
.48145 .26254 Mdot
.48146 .26257 Mdot
.48147 .26259 Mdot
.48148 .26262 Mdot
.48149 .26264 Mdot
.4815 .26266 Mdot
.4815 .26269 Mdot
.48151 .26271 Mdot
.48152 .26273 Mdot
.48153 .26276 Mdot
.48154 .26278 Mdot
.48155 .26281 Mdot
.48156 .26283 Mdot
.48157 .26285 Mdot
.48158 .26288 Mdot
.48159 .2629 Mdot
.4816 .26293 Mdot
.48161 .26295 Mdot
.48162 .26297 Mdot
.48163 .263 Mdot
.48164 .26302 Mdot
.48165 .26304 Mdot
.48166 .26307 Mdot
.48167 .26309 Mdot
.48168 .26312 Mdot
.48169 .26314 Mdot
.4817 .26316 Mdot
.4817 .26319 Mdot
.48171 .26321 Mdot
.48172 .26324 Mdot
.48173 .26326 Mdot
.48174 .26328 Mdot
.48175 .26331 Mdot
.48176 .26333 Mdot
.48177 .26335 Mdot
.48178 .26338 Mdot
.48179 .2634 Mdot
.4818 .26343 Mdot
.48181 .26345 Mdot
.48182 .26347 Mdot
.48183 .2635 Mdot
.48184 .26352 Mdot
.48185 .26355 Mdot
.48186 .26357 Mdot
.48187 .26359 Mdot
.48188 .26362 Mdot
.48189 .26364 Mdot
.4819 .26367 Mdot
.4819 .26369 Mdot
.48191 .26371 Mdot
.48192 .26374 Mdot
.48193 .26376 Mdot
.48194 .26379 Mdot
.48195 .26381 Mdot
.48196 .26383 Mdot
.48197 .26386 Mdot
.48198 .26388 Mdot
.48199 .2639 Mdot
.482 .26393 Mdot
.48201 .26395 Mdot
.48202 .26398 Mdot
.48203 .264 Mdot
.48204 .26402 Mdot
.48205 .26405 Mdot
.48206 .26407 Mdot
.48207 .2641 Mdot
.48208 .26412 Mdot
.48209 .26414 Mdot
.4821 .26417 Mdot
.4821 .26419 Mdot
.48211 .26422 Mdot
.48212 .26424 Mdot
.48213 .26426 Mdot
.48214 .26429 Mdot
.48215 .26431 Mdot
.48216 .26434 Mdot
.48217 .26436 Mdot
.48218 .26438 Mdot
.48219 .26441 Mdot
.4822 .26443 Mdot
.48221 .26445 Mdot
.48222 .26448 Mdot
.48223 .2645 Mdot
.48224 .26453 Mdot
.48225 .26455 Mdot
.48226 .26457 Mdot
.48227 .2646 Mdot
.48228 .26462 Mdot
.48229 .26465 Mdot
.4823 .26467 Mdot
.4823 .26469 Mdot
.48231 .26472 Mdot
.48232 .26474 Mdot
.48233 .26477 Mdot
.48234 .26479 Mdot
.48235 .26481 Mdot
.48236 .26484 Mdot
.48237 .26486 Mdot
.48238 .26489 Mdot
.48239 .26491 Mdot
.4824 .26493 Mdot
.48241 .26496 Mdot
.48242 .26498 Mdot
.48243 .26501 Mdot
.48244 .26503 Mdot
.48245 .26505 Mdot
.48246 .26508 Mdot
.48247 .2651 Mdot
.48248 .26513 Mdot
.48249 .26515 Mdot
.4825 .26517 Mdot
.4825 .2652 Mdot
.48251 .26522 Mdot
.48252 .26525 Mdot
.48253 .26527 Mdot
.48254 .26529 Mdot
.48255 .26532 Mdot
.48256 .26534 Mdot
.48257 .26537 Mdot
.48258 .26539 Mdot
.48259 .26541 Mdot
.4826 .26544 Mdot
.48261 .26546 Mdot
.48262 .26548 Mdot
.48263 .26551 Mdot
.48264 .26553 Mdot
.48265 .26556 Mdot
.48266 .26558 Mdot
.48267 .2656 Mdot
.48268 .26563 Mdot
.48269 .26565 Mdot
.4827 .26568 Mdot
.4827 .2657 Mdot
.48271 .26572 Mdot
.48272 .26575 Mdot
.48273 .26577 Mdot
.48274 .2658 Mdot
.48275 .26582 Mdot
.48276 .26584 Mdot
.48277 .26587 Mdot
.48278 .26589 Mdot
.48279 .26592 Mdot
.4828 .26594 Mdot
.48281 .26596 Mdot
.48282 .26599 Mdot
.48283 .26601 Mdot
.48284 .26604 Mdot
.48285 .26606 Mdot
.48286 .26608 Mdot
.48287 .26611 Mdot
.48288 .26613 Mdot
.48289 .26616 Mdot
.4829 .26618 Mdot
.4829 .2662 Mdot
.48291 .26623 Mdot
.48292 .26625 Mdot
.48293 .26628 Mdot
.48294 .2663 Mdot
.48295 .26632 Mdot
.48296 .26635 Mdot
.48297 .26637 Mdot
.48298 .2664 Mdot
.48299 .26642 Mdot
.483 .26645 Mdot
.48301 .26647 Mdot
.48302 .26649 Mdot
.48303 .26652 Mdot
.48304 .26654 Mdot
.48305 .26657 Mdot
.48306 .26659 Mdot
.48307 .26661 Mdot
.48308 .26664 Mdot
.48309 .26666 Mdot
.4831 .26669 Mdot
.4831 .26671 Mdot
.48311 .26673 Mdot
.48312 .26676 Mdot
.48313 .26678 Mdot
.48314 .26681 Mdot
.48315 .26683 Mdot
.48316 .26685 Mdot
.48317 .26688 Mdot
.48318 .2669 Mdot
.48319 .26693 Mdot
.4832 .26695 Mdot
.48321 .26697 Mdot
.48322 .267 Mdot
.48323 .26702 Mdot
.48324 .26705 Mdot
.48325 .26707 Mdot
.48326 .26709 Mdot
.48327 .26712 Mdot
.48328 .26714 Mdot
.48329 .26717 Mdot
.4833 .26719 Mdot
.4833 .26721 Mdot
.48331 .26724 Mdot
.48332 .26726 Mdot
.48333 .26729 Mdot
.48334 .26731 Mdot
.48335 .26733 Mdot
.48336 .26736 Mdot
.48337 .26738 Mdot
.48338 .26741 Mdot
.48339 .26743 Mdot
.4834 .26745 Mdot
.48341 .26748 Mdot
.48342 .2675 Mdot
.48343 .26753 Mdot
.48344 .26755 Mdot
.48345 .26758 Mdot
.48346 .2676 Mdot
.48347 .26762 Mdot
.48348 .26765 Mdot
.48349 .26767 Mdot
.4835 .2677 Mdot
.4835 .26772 Mdot
.48351 .26774 Mdot
.48352 .26777 Mdot
.48353 .26779 Mdot
.48354 .26782 Mdot
.48355 .26784 Mdot
.48356 .26786 Mdot
.48357 .26789 Mdot
.48358 .26791 Mdot
.48359 .26794 Mdot
.4836 .26796 Mdot
.48361 .26798 Mdot
.48362 .26801 Mdot
.48363 .26803 Mdot
.48364 .26806 Mdot
.48365 .26808 Mdot
.48366 .26811 Mdot
.48367 .26813 Mdot
.48368 .26815 Mdot
.48369 .26818 Mdot
.4837 .2682 Mdot
.4837 .26823 Mdot
.48371 .26825 Mdot
.48372 .26827 Mdot
.48373 .2683 Mdot
.48374 .26832 Mdot
.48375 .26835 Mdot
.48376 .26837 Mdot
.48377 .26839 Mdot
.48378 .26842 Mdot
.48379 .26844 Mdot
.4838 .26847 Mdot
.48381 .26849 Mdot
.48382 .26851 Mdot
.48383 .26854 Mdot
.48384 .26856 Mdot
.48385 .26859 Mdot
.48386 .26861 Mdot
.48387 .26864 Mdot
.48388 .26866 Mdot
.48389 .26868 Mdot
.4839 .26871 Mdot
.4839 .26873 Mdot
.48391 .26876 Mdot
.48392 .26878 Mdot
.48393 .2688 Mdot
.48394 .26883 Mdot
.48395 .26885 Mdot
.48396 .26888 Mdot
.48397 .2689 Mdot
.48398 .26893 Mdot
.48399 .26895 Mdot
.484 .26897 Mdot
.48401 .269 Mdot
.48402 .26902 Mdot
.48403 .26905 Mdot
.48404 .26907 Mdot
.48405 .26909 Mdot
.48406 .26912 Mdot
.48407 .26914 Mdot
.48408 .26917 Mdot
.48409 .26919 Mdot
.4841 .26921 Mdot
.4841 .26924 Mdot
.48411 .26926 Mdot
.48412 .26929 Mdot
.48413 .26931 Mdot
.48414 .26934 Mdot
.48415 .26936 Mdot
.48416 .26938 Mdot
.48417 .26941 Mdot
.48418 .26943 Mdot
.48419 .26946 Mdot
.4842 .26948 Mdot
.48421 .2695 Mdot
.48422 .26953 Mdot
.48423 .26955 Mdot
.48424 .26958 Mdot
.48425 .2696 Mdot
.48426 .26963 Mdot
.48427 .26965 Mdot
.48428 .26967 Mdot
.48429 .2697 Mdot
.4843 .26972 Mdot
.4843 .26975 Mdot
.48431 .26977 Mdot
.48432 .26979 Mdot
.48433 .26982 Mdot
.48434 .26984 Mdot
.48435 .26987 Mdot
.48436 .26989 Mdot
.48437 .26992 Mdot
.48438 .26994 Mdot
.48439 .26996 Mdot
.4844 .26999 Mdot
.48441 .27001 Mdot
.48442 .27004 Mdot
.48443 .27006 Mdot
.48444 .27008 Mdot
.48445 .27011 Mdot
.48446 .27013 Mdot
.48447 .27016 Mdot
.48448 .27018 Mdot
.48449 .27021 Mdot
.4845 .27023 Mdot
.4845 .27025 Mdot
.48451 .27028 Mdot
.48452 .2703 Mdot
.48453 .27033 Mdot
.48454 .27035 Mdot
.48455 .27037 Mdot
.48456 .2704 Mdot
.48457 .27042 Mdot
.48458 .27045 Mdot
.48459 .27047 Mdot
.4846 .2705 Mdot
.48461 .27052 Mdot
.48462 .27054 Mdot
.48463 .27057 Mdot
.48464 .27059 Mdot
.48465 .27062 Mdot
.48466 .27064 Mdot
.48467 .27067 Mdot
.48468 .27069 Mdot
.48469 .27071 Mdot
.4847 .27074 Mdot
.4847 .27076 Mdot
.48471 .27079 Mdot
.48472 .27081 Mdot
.48473 .27083 Mdot
.48474 .27086 Mdot
.48475 .27088 Mdot
.48476 .27091 Mdot
.48477 .27093 Mdot
.48478 .27096 Mdot
.48479 .27098 Mdot
.4848 .271 Mdot
.48481 .27103 Mdot
.48482 .27105 Mdot
.48483 .27108 Mdot
.48484 .2711 Mdot
.48485 .27113 Mdot
.48486 .27115 Mdot
.48487 .27117 Mdot
.48488 .2712 Mdot
.48489 .27122 Mdot
.4849 .27125 Mdot
.4849 .27127 Mdot
.48491 .2713 Mdot
.48492 .27132 Mdot
.48493 .27134 Mdot
.48494 .27137 Mdot
.48495 .27139 Mdot
.48496 .27142 Mdot
.48497 .27144 Mdot
.48498 .27146 Mdot
.48499 .27149 Mdot
.485 .27151 Mdot
.48501 .27154 Mdot
.48502 .27156 Mdot
.48503 .27159 Mdot
.48504 .27161 Mdot
.48505 .27163 Mdot
.48506 .27166 Mdot
.48507 .27168 Mdot
.48508 .27171 Mdot
.48509 .27173 Mdot
.4851 .27176 Mdot
.4851 .27178 Mdot
.48511 .2718 Mdot
.48512 .27183 Mdot
.48513 .27185 Mdot
.48514 .27188 Mdot
.48515 .2719 Mdot
.48516 .27193 Mdot
.48517 .27195 Mdot
.48518 .27197 Mdot
.48519 .272 Mdot
.4852 .27202 Mdot
.48521 .27205 Mdot
.48522 .27207 Mdot
.48523 .2721 Mdot
.48524 .27212 Mdot
.48525 .27214 Mdot
.48526 .27217 Mdot
.48527 .27219 Mdot
.48528 .27222 Mdot
.48529 .27224 Mdot
.4853 .27227 Mdot
.4853 .27229 Mdot
.48531 .27231 Mdot
.48532 .27234 Mdot
.48533 .27236 Mdot
.48534 .27239 Mdot
.48535 .27241 Mdot
.48536 .27244 Mdot
.48537 .27246 Mdot
.48538 .27248 Mdot
.48539 .27251 Mdot
.4854 .27253 Mdot
.48541 .27256 Mdot
.48542 .27258 Mdot
.48543 .27261 Mdot
.48544 .27263 Mdot
.48545 .27265 Mdot
.48546 .27268 Mdot
.48547 .2727 Mdot
.48548 .27273 Mdot
.48549 .27275 Mdot
.4855 .27278 Mdot
.4855 .2728 Mdot
.48551 .27282 Mdot
.48552 .27285 Mdot
.48553 .27287 Mdot
.48554 .2729 Mdot
.48555 .27292 Mdot
.48556 .27295 Mdot
.48557 .27297 Mdot
.48558 .27299 Mdot
.48559 .27302 Mdot
.4856 .27304 Mdot
.48561 .27307 Mdot
.48562 .27309 Mdot
.48563 .27312 Mdot
.48564 .27314 Mdot
.48565 .27316 Mdot
.48566 .27319 Mdot
.48567 .27321 Mdot
.48568 .27324 Mdot
.48569 .27326 Mdot
.4857 .27329 Mdot
.4857 .27331 Mdot
.48571 .27333 Mdot
.48572 .27336 Mdot
.48573 .27338 Mdot
.48574 .27341 Mdot
.48575 .27343 Mdot
.48576 .27346 Mdot
.48577 .27348 Mdot
.48578 .27351 Mdot
.48579 .27353 Mdot
.4858 .27355 Mdot
.48581 .27358 Mdot
.48582 .2736 Mdot
.48583 .27363 Mdot
.48584 .27365 Mdot
.48585 .27368 Mdot
.48586 .2737 Mdot
.48587 .27372 Mdot
.48588 .27375 Mdot
.48589 .27377 Mdot
.4859 .2738 Mdot
.4859 .27382 Mdot
.48591 .27385 Mdot
.48592 .27387 Mdot
.48593 .27389 Mdot
.48594 .27392 Mdot
.48595 .27394 Mdot
.48596 .27397 Mdot
.48597 .27399 Mdot
.48598 .27402 Mdot
.48599 .27404 Mdot
.486 .27406 Mdot
.48601 .27409 Mdot
.48602 .27411 Mdot
.48603 .27414 Mdot
.48604 .27416 Mdot
.48605 .27419 Mdot
.48606 .27421 Mdot
.48607 .27424 Mdot
.48608 .27426 Mdot
.48609 .27428 Mdot
.4861 .27431 Mdot
.4861 .27433 Mdot
.48611 .27436 Mdot
.48612 .27438 Mdot
.48613 .27441 Mdot
.48614 .27443 Mdot
.48615 .27445 Mdot
.48616 .27448 Mdot
.48617 .2745 Mdot
.48618 .27453 Mdot
.48619 .27455 Mdot
.4862 .27458 Mdot
.48621 .2746 Mdot
.48622 .27463 Mdot
.48623 .27465 Mdot
.48624 .27467 Mdot
.48625 .2747 Mdot
.48626 .27472 Mdot
.48627 .27475 Mdot
.48628 .27477 Mdot
.48629 .2748 Mdot
.4863 .27482 Mdot
.4863 .27484 Mdot
.48631 .27487 Mdot
.48632 .27489 Mdot
.48633 .27492 Mdot
.48634 .27494 Mdot
.48635 .27497 Mdot
.48636 .27499 Mdot
.48637 .27502 Mdot
.48638 .27504 Mdot
.48639 .27506 Mdot
.4864 .27509 Mdot
.48641 .27511 Mdot
.48642 .27514 Mdot
.48643 .27516 Mdot
.48644 .27519 Mdot
.48645 .27521 Mdot
.48646 .27524 Mdot
.48647 .27526 Mdot
.48648 .27528 Mdot
.48649 .27531 Mdot
.4865 .27533 Mdot
.4865 .27536 Mdot
.48651 .27538 Mdot
.48652 .27541 Mdot
.48653 .27543 Mdot
.48654 .27546 Mdot
.48655 .27548 Mdot
.48656 .2755 Mdot
.48657 .27553 Mdot
.48658 .27555 Mdot
.48659 .27558 Mdot
.4866 .2756 Mdot
.48661 .27563 Mdot
.48662 .27565 Mdot
.48663 .27567 Mdot
.48664 .2757 Mdot
.48665 .27572 Mdot
.48666 .27575 Mdot
.48667 .27577 Mdot
.48668 .2758 Mdot
.48669 .27582 Mdot
.4867 .27585 Mdot
.4867 .27587 Mdot
.48671 .27589 Mdot
.48672 .27592 Mdot
.48673 .27594 Mdot
.48674 .27597 Mdot
.48675 .27599 Mdot
.48676 .27602 Mdot
.48677 .27604 Mdot
.48678 .27607 Mdot
.48679 .27609 Mdot
.4868 .27611 Mdot
.48681 .27614 Mdot
.48682 .27616 Mdot
.48683 .27619 Mdot
.48684 .27621 Mdot
.48685 .27624 Mdot
.48686 .27626 Mdot
.48687 .27629 Mdot
.48688 .27631 Mdot
.48689 .27633 Mdot
.4869 .27636 Mdot
.4869 .27638 Mdot
.48691 .27641 Mdot
.48692 .27643 Mdot
.48693 .27646 Mdot
.48694 .27648 Mdot
.48695 .27651 Mdot
.48696 .27653 Mdot
.48697 .27655 Mdot
.48698 .27658 Mdot
.48699 .2766 Mdot
.487 .27663 Mdot
.48701 .27665 Mdot
.48702 .27668 Mdot
.48703 .2767 Mdot
.48704 .27673 Mdot
.48705 .27675 Mdot
.48706 .27678 Mdot
.48707 .2768 Mdot
.48708 .27682 Mdot
.48709 .27685 Mdot
.4871 .27687 Mdot
.4871 .2769 Mdot
.48711 .27692 Mdot
.48712 .27695 Mdot
.48713 .27697 Mdot
.48714 .277 Mdot
.48715 .27702 Mdot
.48716 .27704 Mdot
.48717 .27707 Mdot
.48718 .27709 Mdot
.48719 .27712 Mdot
.4872 .27714 Mdot
.48721 .27717 Mdot
.48722 .27719 Mdot
.48723 .27722 Mdot
.48724 .27724 Mdot
.48725 .27726 Mdot
.48726 .27729 Mdot
.48727 .27731 Mdot
.48728 .27734 Mdot
.48729 .27736 Mdot
.4873 .27739 Mdot
.4873 .27741 Mdot
.48731 .27744 Mdot
.48732 .27746 Mdot
.48733 .27749 Mdot
.48734 .27751 Mdot
.48735 .27753 Mdot
.48736 .27756 Mdot
.48737 .27758 Mdot
.48738 .27761 Mdot
.48739 .27763 Mdot
.4874 .27766 Mdot
.48741 .27768 Mdot
.48742 .27771 Mdot
.48743 .27773 Mdot
.48744 .27775 Mdot
.48745 .27778 Mdot
.48746 .2778 Mdot
.48747 .27783 Mdot
.48748 .27785 Mdot
.48749 .27788 Mdot
.4875 .2779 Mdot
.4875 .27793 Mdot
.48751 .27795 Mdot
.48752 .27798 Mdot
.48753 .278 Mdot
.48754 .27802 Mdot
.48755 .27805 Mdot
.48756 .27807 Mdot
.48757 .2781 Mdot
.48758 .27812 Mdot
.48759 .27815 Mdot
.4876 .27817 Mdot
.48761 .2782 Mdot
.48762 .27822 Mdot
.48763 .27825 Mdot
.48764 .27827 Mdot
.48765 .27829 Mdot
.48766 .27832 Mdot
.48767 .27834 Mdot
.48768 .27837 Mdot
.48769 .27839 Mdot
.4877 .27842 Mdot
.4877 .27844 Mdot
.48771 .27847 Mdot
.48772 .27849 Mdot
.48773 .27852 Mdot
.48774 .27854 Mdot
.48775 .27856 Mdot
.48776 .27859 Mdot
.48777 .27861 Mdot
.48778 .27864 Mdot
.48779 .27866 Mdot
.4878 .27869 Mdot
.48781 .27871 Mdot
.48782 .27874 Mdot
.48783 .27876 Mdot
.48784 .27879 Mdot
.48785 .27881 Mdot
.48786 .27883 Mdot
.48787 .27886 Mdot
.48788 .27888 Mdot
.48789 .27891 Mdot
.4879 .27893 Mdot
.4879 .27896 Mdot
.48791 .27898 Mdot
.48792 .27901 Mdot
.48793 .27903 Mdot
.48794 .27906 Mdot
.48795 .27908 Mdot
.48796 .2791 Mdot
.48797 .27913 Mdot
.48798 .27915 Mdot
.48799 .27918 Mdot
.488 .2792 Mdot
.48801 .27923 Mdot
.48802 .27925 Mdot
.48803 .27928 Mdot
.48804 .2793 Mdot
.48805 .27933 Mdot
.48806 .27935 Mdot
.48807 .27938 Mdot
.48808 .2794 Mdot
.48809 .27942 Mdot
.4881 .27945 Mdot
.4881 .27947 Mdot
.48811 .2795 Mdot
.48812 .27952 Mdot
.48813 .27955 Mdot
.48814 .27957 Mdot
.48815 .2796 Mdot
.48816 .27962 Mdot
.48817 .27965 Mdot
.48818 .27967 Mdot
.48819 .27969 Mdot
.4882 .27972 Mdot
.48821 .27974 Mdot
.48822 .27977 Mdot
.48823 .27979 Mdot
.48824 .27982 Mdot
.48825 .27984 Mdot
.48826 .27987 Mdot
.48827 .27989 Mdot
.48828 .27992 Mdot
.48829 .27994 Mdot
.4883 .27997 Mdot
.4883 .27999 Mdot
.48831 .28001 Mdot
.48832 .28004 Mdot
.48833 .28006 Mdot
.48834 .28009 Mdot
.48835 .28011 Mdot
.48836 .28014 Mdot
.48837 .28016 Mdot
.48838 .28019 Mdot
.48839 .28021 Mdot
.4884 .28024 Mdot
.48841 .28026 Mdot
.48842 .28029 Mdot
.48843 .28031 Mdot
.48844 .28033 Mdot
.48845 .28036 Mdot
.48846 .28038 Mdot
.48847 .28041 Mdot
.48848 .28043 Mdot
.48849 .28046 Mdot
.4885 .28048 Mdot
.4885 .28051 Mdot
.48851 .28053 Mdot
.48852 .28056 Mdot
.48853 .28058 Mdot
.48854 .28061 Mdot
.48855 .28063 Mdot
.48856 .28066 Mdot
.48857 .28068 Mdot
.48858 .2807 Mdot
.48859 .28073 Mdot
.4886 .28075 Mdot
.48861 .28078 Mdot
.48862 .2808 Mdot
.48863 .28083 Mdot
.48864 .28085 Mdot
.48865 .28088 Mdot
.48866 .2809 Mdot
.48867 .28093 Mdot
.48868 .28095 Mdot
.48869 .28098 Mdot
.4887 .281 Mdot
.4887 .28102 Mdot
.48871 .28105 Mdot
.48872 .28107 Mdot
.48873 .2811 Mdot
.48874 .28112 Mdot
.48875 .28115 Mdot
.48876 .28117 Mdot
.48877 .2812 Mdot
.48878 .28122 Mdot
.48879 .28125 Mdot
.4888 .28127 Mdot
.48881 .2813 Mdot
.48882 .28132 Mdot
.48883 .28135 Mdot
.48884 .28137 Mdot
.48885 .28139 Mdot
.48886 .28142 Mdot
.48887 .28144 Mdot
.48888 .28147 Mdot
.48889 .28149 Mdot
.4889 .28152 Mdot
.4889 .28154 Mdot
.48891 .28157 Mdot
.48892 .28159 Mdot
.48893 .28162 Mdot
.48894 .28164 Mdot
.48895 .28167 Mdot
.48896 .28169 Mdot
.48897 .28172 Mdot
.48898 .28174 Mdot
.48899 .28177 Mdot
.489 .28179 Mdot
.48901 .28181 Mdot
.48902 .28184 Mdot
.48903 .28186 Mdot
.48904 .28189 Mdot
.48905 .28191 Mdot
.48906 .28194 Mdot
.48907 .28196 Mdot
.48908 .28199 Mdot
.48909 .28201 Mdot
.4891 .28204 Mdot
.4891 .28206 Mdot
.48911 .28209 Mdot
.48912 .28211 Mdot
.48913 .28214 Mdot
.48914 .28216 Mdot
.48915 .28218 Mdot
.48916 .28221 Mdot
.48917 .28223 Mdot
.48918 .28226 Mdot
.48919 .28228 Mdot
.4892 .28231 Mdot
.48921 .28233 Mdot
.48922 .28236 Mdot
.48923 .28238 Mdot
.48924 .28241 Mdot
.48925 .28243 Mdot
.48926 .28246 Mdot
.48927 .28248 Mdot
.48928 .28251 Mdot
.48929 .28253 Mdot
.4893 .28256 Mdot
.4893 .28258 Mdot
.48931 .2826 Mdot
.48932 .28263 Mdot
.48933 .28265 Mdot
.48934 .28268 Mdot
.48935 .2827 Mdot
.48936 .28273 Mdot
.48937 .28275 Mdot
.48938 .28278 Mdot
.48939 .2828 Mdot
.4894 .28283 Mdot
.48941 .28285 Mdot
.48942 .28288 Mdot
.48943 .2829 Mdot
.48944 .28293 Mdot
.48945 .28295 Mdot
.48946 .28298 Mdot
.48947 .283 Mdot
.48948 .28303 Mdot
.48949 .28305 Mdot
.4895 .28307 Mdot
.4895 .2831 Mdot
.48951 .28312 Mdot
.48952 .28315 Mdot
.48953 .28317 Mdot
.48954 .2832 Mdot
.48955 .28322 Mdot
.48956 .28325 Mdot
.48957 .28327 Mdot
.48958 .2833 Mdot
.48959 .28332 Mdot
.4896 .28335 Mdot
.48961 .28337 Mdot
.48962 .2834 Mdot
.48963 .28342 Mdot
.48964 .28345 Mdot
.48965 .28347 Mdot
.48966 .2835 Mdot
.48967 .28352 Mdot
.48968 .28355 Mdot
.48969 .28357 Mdot
.4897 .28359 Mdot
.4897 .28362 Mdot
.48971 .28364 Mdot
.48972 .28367 Mdot
.48973 .28369 Mdot
.48974 .28372 Mdot
.48975 .28374 Mdot
.48976 .28377 Mdot
.48977 .28379 Mdot
.48978 .28382 Mdot
.48979 .28384 Mdot
.4898 .28387 Mdot
.48981 .28389 Mdot
.48982 .28392 Mdot
.48983 .28394 Mdot
.48984 .28397 Mdot
.48985 .28399 Mdot
.48986 .28402 Mdot
.48987 .28404 Mdot
.48988 .28407 Mdot
.48989 .28409 Mdot
.4899 .28412 Mdot
.4899 .28414 Mdot
.48991 .28416 Mdot
.48992 .28419 Mdot
.48993 .28421 Mdot
.48994 .28424 Mdot
.48995 .28426 Mdot
.48996 .28429 Mdot
.48997 .28431 Mdot
.48998 .28434 Mdot
.48999 .28436 Mdot
.49 .28439 Mdot
.49001 .28441 Mdot
.49002 .28444 Mdot
.49003 .28446 Mdot
.49004 .28449 Mdot
.49005 .28451 Mdot
.49006 .28454 Mdot
.49007 .28456 Mdot
.49008 .28459 Mdot
.49009 .28461 Mdot
.4901 .28464 Mdot
.4901 .28466 Mdot
.49011 .28469 Mdot
.49012 .28471 Mdot
.49013 .28474 Mdot
.49014 .28476 Mdot
.49015 .28478 Mdot
.49016 .28481 Mdot
.49017 .28483 Mdot
.49018 .28486 Mdot
.49019 .28488 Mdot
.4902 .28491 Mdot
.49021 .28493 Mdot
.49022 .28496 Mdot
.49023 .28498 Mdot
.49024 .28501 Mdot
.49025 .28503 Mdot
.49026 .28506 Mdot
.49027 .28508 Mdot
.49028 .28511 Mdot
.49029 .28513 Mdot
.4903 .28516 Mdot
.4903 .28518 Mdot
.49031 .28521 Mdot
.49032 .28523 Mdot
.49033 .28526 Mdot
.49034 .28528 Mdot
.49035 .28531 Mdot
.49036 .28533 Mdot
.49037 .28536 Mdot
.49038 .28538 Mdot
.49039 .28541 Mdot
.4904 .28543 Mdot
.49041 .28546 Mdot
.49042 .28548 Mdot
.49043 .2855 Mdot
.49044 .28553 Mdot
.49045 .28555 Mdot
.49046 .28558 Mdot
.49047 .2856 Mdot
.49048 .28563 Mdot
.49049 .28565 Mdot
.4905 .28568 Mdot
.4905 .2857 Mdot
.49051 .28573 Mdot
.49052 .28575 Mdot
.49053 .28578 Mdot
.49054 .2858 Mdot
.49055 .28583 Mdot
.49056 .28585 Mdot
.49057 .28588 Mdot
.49058 .2859 Mdot
.49059 .28593 Mdot
.4906 .28595 Mdot
.49061 .28598 Mdot
.49062 .286 Mdot
.49063 .28603 Mdot
.49064 .28605 Mdot
.49065 .28608 Mdot
.49066 .2861 Mdot
.49067 .28613 Mdot
.49068 .28615 Mdot
.49069 .28618 Mdot
.4907 .2862 Mdot
.4907 .28623 Mdot
.49071 .28625 Mdot
.49072 .28628 Mdot
.49073 .2863 Mdot
.49074 .28633 Mdot
.49075 .28635 Mdot
.49076 .28638 Mdot
.49077 .2864 Mdot
.49078 .28642 Mdot
.49079 .28645 Mdot
.4908 .28647 Mdot
.49081 .2865 Mdot
.49082 .28652 Mdot
.49083 .28655 Mdot
.49084 .28657 Mdot
.49085 .2866 Mdot
.49086 .28662 Mdot
.49087 .28665 Mdot
.49088 .28667 Mdot
.49089 .2867 Mdot
.4909 .28672 Mdot
.4909 .28675 Mdot
.49091 .28677 Mdot
.49092 .2868 Mdot
.49093 .28682 Mdot
.49094 .28685 Mdot
.49095 .28687 Mdot
.49096 .2869 Mdot
.49097 .28692 Mdot
.49098 .28695 Mdot
.49099 .28697 Mdot
.491 .287 Mdot
.49101 .28702 Mdot
.49102 .28705 Mdot
.49103 .28707 Mdot
.49104 .2871 Mdot
.49105 .28712 Mdot
.49106 .28715 Mdot
.49107 .28717 Mdot
.49108 .2872 Mdot
.49109 .28722 Mdot
.4911 .28725 Mdot
.4911 .28727 Mdot
.49111 .2873 Mdot
.49112 .28732 Mdot
.49113 .28735 Mdot
.49114 .28737 Mdot
.49115 .2874 Mdot
.49116 .28742 Mdot
.49117 .28745 Mdot
.49118 .28747 Mdot
.49119 .2875 Mdot
.4912 .28752 Mdot
.49121 .28755 Mdot
.49122 .28757 Mdot
.49123 .2876 Mdot
.49124 .28762 Mdot
.49125 .28765 Mdot
.49126 .28767 Mdot
.49127 .2877 Mdot
.49128 .28772 Mdot
.49129 .28775 Mdot
.4913 .28777 Mdot
.4913 .28779 Mdot
.49131 .28782 Mdot
.49132 .28784 Mdot
.49133 .28787 Mdot
.49134 .28789 Mdot
.49135 .28792 Mdot
.49136 .28794 Mdot
.49137 .28797 Mdot
.49138 .28799 Mdot
.49139 .28802 Mdot
.4914 .28804 Mdot
.49141 .28807 Mdot
.49142 .28809 Mdot
.49143 .28812 Mdot
.49144 .28814 Mdot
.49145 .28817 Mdot
.49146 .28819 Mdot
.49147 .28822 Mdot
.49148 .28824 Mdot
.49149 .28827 Mdot
.4915 .28829 Mdot
.4915 .28832 Mdot
.49151 .28834 Mdot
.49152 .28837 Mdot
.49153 .28839 Mdot
.49154 .28842 Mdot
.49155 .28844 Mdot
.49156 .28847 Mdot
.49157 .28849 Mdot
.49158 .28852 Mdot
.49159 .28854 Mdot
.4916 .28857 Mdot
.49161 .28859 Mdot
.49162 .28862 Mdot
.49163 .28864 Mdot
.49164 .28867 Mdot
.49165 .28869 Mdot
.49166 .28872 Mdot
.49167 .28874 Mdot
.49168 .28877 Mdot
.49169 .28879 Mdot
.4917 .28882 Mdot
.4917 .28884 Mdot
.49171 .28887 Mdot
.49172 .28889 Mdot
.49173 .28892 Mdot
.49174 .28894 Mdot
.49175 .28897 Mdot
.49176 .28899 Mdot
.49177 .28902 Mdot
.49178 .28904 Mdot
.49179 .28907 Mdot
.4918 .28909 Mdot
.49181 .28912 Mdot
.49182 .28914 Mdot
.49183 .28917 Mdot
.49184 .28919 Mdot
.49185 .28922 Mdot
.49186 .28924 Mdot
.49187 .28927 Mdot
.49188 .28929 Mdot
.49189 .28932 Mdot
.4919 .28934 Mdot
.4919 .28937 Mdot
.49191 .28939 Mdot
.49192 .28942 Mdot
.49193 .28944 Mdot
.49194 .28947 Mdot
.49195 .28949 Mdot
.49196 .28952 Mdot
.49197 .28954 Mdot
.49198 .28957 Mdot
.49199 .28959 Mdot
.492 .28962 Mdot
.49201 .28964 Mdot
.49202 .28967 Mdot
.49203 .28969 Mdot
.49204 .28972 Mdot
.49205 .28974 Mdot
.49206 .28977 Mdot
.49207 .28979 Mdot
.49208 .28982 Mdot
.49209 .28984 Mdot
.4921 .28987 Mdot
.4921 .28989 Mdot
.49211 .28992 Mdot
.49212 .28994 Mdot
.49213 .28997 Mdot
.49214 .28999 Mdot
.49215 .29002 Mdot
.49216 .29004 Mdot
.49217 .29007 Mdot
.49218 .29009 Mdot
.49219 .29012 Mdot
.4922 .29014 Mdot
.49221 .29017 Mdot
.49222 .29019 Mdot
.49223 .29022 Mdot
.49224 .29024 Mdot
.49225 .29027 Mdot
.49226 .29029 Mdot
.49227 .29032 Mdot
.49228 .29034 Mdot
.49229 .29037 Mdot
.4923 .29039 Mdot
.4923 .29042 Mdot
.49231 .29044 Mdot
.49232 .29047 Mdot
.49233 .29049 Mdot
.49234 .29052 Mdot
.49235 .29054 Mdot
.49236 .29057 Mdot
.49237 .29059 Mdot
.49238 .29062 Mdot
.49239 .29065 Mdot
.4924 .29067 Mdot
.49241 .2907 Mdot
.49242 .29072 Mdot
.49243 .29075 Mdot
.49244 .29077 Mdot
.49245 .2908 Mdot
.49246 .29082 Mdot
.49247 .29085 Mdot
.49248 .29087 Mdot
.49249 .2909 Mdot
.4925 .29092 Mdot
.4925 .29095 Mdot
.49251 .29097 Mdot
.49252 .291 Mdot
.49253 .29102 Mdot
.49254 .29105 Mdot
.49255 .29107 Mdot
.49256 .2911 Mdot
.49257 .29112 Mdot
.49258 .29115 Mdot
.49259 .29117 Mdot
.4926 .2912 Mdot
.49261 .29122 Mdot
.49262 .29125 Mdot
.49263 .29127 Mdot
.49264 .2913 Mdot
.49265 .29132 Mdot
.49266 .29135 Mdot
.49267 .29137 Mdot
.49268 .2914 Mdot
.49269 .29142 Mdot
.4927 .29145 Mdot
.4927 .29147 Mdot
.49271 .2915 Mdot
.49272 .29152 Mdot
.49273 .29155 Mdot
.49274 .29157 Mdot
.49275 .2916 Mdot
.49276 .29162 Mdot
.49277 .29165 Mdot
.49278 .29167 Mdot
.49279 .2917 Mdot
.4928 .29172 Mdot
.49281 .29175 Mdot
.49282 .29177 Mdot
.49283 .2918 Mdot
.49284 .29182 Mdot
.49285 .29185 Mdot
.49286 .29187 Mdot
.49287 .2919 Mdot
.49288 .29192 Mdot
.49289 .29195 Mdot
.4929 .29197 Mdot
.4929 .292 Mdot
.49291 .29203 Mdot
.49292 .29205 Mdot
.49293 .29208 Mdot
.49294 .2921 Mdot
.49295 .29213 Mdot
.49296 .29215 Mdot
.49297 .29218 Mdot
.49298 .2922 Mdot
.49299 .29223 Mdot
.493 .29225 Mdot
.49301 .29228 Mdot
.49302 .2923 Mdot
.49303 .29233 Mdot
.49304 .29235 Mdot
.49305 .29238 Mdot
.49306 .2924 Mdot
.49307 .29243 Mdot
.49308 .29245 Mdot
.49309 .29248 Mdot
.4931 .2925 Mdot
.4931 .29253 Mdot
.49311 .29255 Mdot
.49312 .29258 Mdot
.49313 .2926 Mdot
.49314 .29263 Mdot
.49315 .29265 Mdot
.49316 .29268 Mdot
.49317 .2927 Mdot
.49318 .29273 Mdot
.49319 .29275 Mdot
.4932 .29278 Mdot
.49321 .2928 Mdot
.49322 .29283 Mdot
.49323 .29285 Mdot
.49324 .29288 Mdot
.49325 .2929 Mdot
.49326 .29293 Mdot
.49327 .29296 Mdot
.49328 .29298 Mdot
.49329 .29301 Mdot
.4933 .29303 Mdot
.4933 .29306 Mdot
.49331 .29308 Mdot
.49332 .29311 Mdot
.49333 .29313 Mdot
.49334 .29316 Mdot
.49335 .29318 Mdot
.49336 .29321 Mdot
.49337 .29323 Mdot
.49338 .29326 Mdot
.49339 .29328 Mdot
.4934 .29331 Mdot
.49341 .29333 Mdot
.49342 .29336 Mdot
.49343 .29338 Mdot
.49344 .29341 Mdot
.49345 .29343 Mdot
.49346 .29346 Mdot
.49347 .29348 Mdot
.49348 .29351 Mdot
.49349 .29353 Mdot
.4935 .29356 Mdot
.4935 .29358 Mdot
.49351 .29361 Mdot
.49352 .29363 Mdot
.49353 .29366 Mdot
.49354 .29369 Mdot
.49355 .29371 Mdot
.49356 .29374 Mdot
.49357 .29376 Mdot
.49358 .29379 Mdot
.49359 .29381 Mdot
.4936 .29384 Mdot
.49361 .29386 Mdot
.49362 .29389 Mdot
.49363 .29391 Mdot
.49364 .29394 Mdot
.49365 .29396 Mdot
.49366 .29399 Mdot
.49367 .29401 Mdot
.49368 .29404 Mdot
.49369 .29406 Mdot
.4937 .29409 Mdot
.4937 .29411 Mdot
.49371 .29414 Mdot
.49372 .29416 Mdot
.49373 .29419 Mdot
.49374 .29421 Mdot
.49375 .29424 Mdot
.49376 .29426 Mdot
.49377 .29429 Mdot
.49378 .29432 Mdot
.49379 .29434 Mdot
.4938 .29437 Mdot
.49381 .29439 Mdot
.49382 .29442 Mdot
.49383 .29444 Mdot
.49384 .29447 Mdot
.49385 .29449 Mdot
.49386 .29452 Mdot
.49387 .29454 Mdot
.49388 .29457 Mdot
.49389 .29459 Mdot
.4939 .29462 Mdot
.4939 .29464 Mdot
.49391 .29467 Mdot
.49392 .29469 Mdot
.49393 .29472 Mdot
.49394 .29474 Mdot
.49395 .29477 Mdot
.49396 .29479 Mdot
.49397 .29482 Mdot
.49398 .29484 Mdot
.49399 .29487 Mdot
.494 .2949 Mdot
.49401 .29492 Mdot
.49402 .29495 Mdot
.49403 .29497 Mdot
.49404 .295 Mdot
.49405 .29502 Mdot
.49406 .29505 Mdot
.49407 .29507 Mdot
.49408 .2951 Mdot
.49409 .29512 Mdot
.4941 .29515 Mdot
.4941 .29517 Mdot
.49411 .2952 Mdot
.49412 .29522 Mdot
.49413 .29525 Mdot
.49414 .29527 Mdot
.49415 .2953 Mdot
.49416 .29532 Mdot
.49417 .29535 Mdot
.49418 .29537 Mdot
.49419 .2954 Mdot
.4942 .29543 Mdot
.49421 .29545 Mdot
.49422 .29548 Mdot
.49423 .2955 Mdot
.49424 .29553 Mdot
.49425 .29555 Mdot
.49426 .29558 Mdot
.49427 .2956 Mdot
.49428 .29563 Mdot
.49429 .29565 Mdot
.4943 .29568 Mdot
.4943 .2957 Mdot
.49431 .29573 Mdot
.49432 .29575 Mdot
.49433 .29578 Mdot
.49434 .2958 Mdot
.49435 .29583 Mdot
.49436 .29585 Mdot
.49437 .29588 Mdot
.49438 .29591 Mdot
.49439 .29593 Mdot
.4944 .29596 Mdot
.49441 .29598 Mdot
.49442 .29601 Mdot
.49443 .29603 Mdot
.49444 .29606 Mdot
.49445 .29608 Mdot
.49446 .29611 Mdot
.49447 .29613 Mdot
.49448 .29616 Mdot
.49449 .29618 Mdot
.4945 .29621 Mdot
.4945 .29623 Mdot
.49451 .29626 Mdot
.49452 .29628 Mdot
.49453 .29631 Mdot
.49454 .29634 Mdot
.49455 .29636 Mdot
.49456 .29639 Mdot
.49457 .29641 Mdot
.49458 .29644 Mdot
.49459 .29646 Mdot
.4946 .29649 Mdot
.49461 .29651 Mdot
.49462 .29654 Mdot
.49463 .29656 Mdot
.49464 .29659 Mdot
.49465 .29661 Mdot
.49466 .29664 Mdot
.49467 .29666 Mdot
.49468 .29669 Mdot
.49469 .29671 Mdot
.4947 .29674 Mdot
.4947 .29677 Mdot
.49471 .29679 Mdot
.49472 .29682 Mdot
.49473 .29684 Mdot
.49474 .29687 Mdot
.49475 .29689 Mdot
.49476 .29692 Mdot
.49477 .29694 Mdot
.49478 .29697 Mdot
.49479 .29699 Mdot
.4948 .29702 Mdot
.49481 .29704 Mdot
.49482 .29707 Mdot
.49483 .29709 Mdot
.49484 .29712 Mdot
.49485 .29715 Mdot
.49486 .29717 Mdot
.49487 .2972 Mdot
.49488 .29722 Mdot
.49489 .29725 Mdot
.4949 .29727 Mdot
.4949 .2973 Mdot
.49491 .29732 Mdot
.49492 .29735 Mdot
.49493 .29737 Mdot
.49494 .2974 Mdot
.49495 .29742 Mdot
.49496 .29745 Mdot
.49497 .29747 Mdot
.49498 .2975 Mdot
.49499 .29753 Mdot
.495 .29755 Mdot
.49501 .29758 Mdot
.49502 .2976 Mdot
.49503 .29763 Mdot
.49504 .29765 Mdot
.49505 .29768 Mdot
.49506 .2977 Mdot
.49507 .29773 Mdot
.49508 .29775 Mdot
.49509 .29778 Mdot
.4951 .2978 Mdot
.4951 .29783 Mdot
.49511 .29785 Mdot
.49512 .29788 Mdot
.49513 .29791 Mdot
.49514 .29793 Mdot
.49515 .29796 Mdot
.49516 .29798 Mdot
.49517 .29801 Mdot
.49518 .29803 Mdot
.49519 .29806 Mdot
.4952 .29808 Mdot
.49521 .29811 Mdot
.49522 .29813 Mdot
.49523 .29816 Mdot
.49524 .29818 Mdot
.49525 .29821 Mdot
.49526 .29824 Mdot
.49527 .29826 Mdot
.49528 .29829 Mdot
.49529 .29831 Mdot
.4953 .29834 Mdot
.4953 .29836 Mdot
.49531 .29839 Mdot
.49532 .29841 Mdot
.49533 .29844 Mdot
.49534 .29846 Mdot
.49535 .29849 Mdot
.49536 .29851 Mdot
.49537 .29854 Mdot
.49538 .29857 Mdot
.49539 .29859 Mdot
.4954 .29862 Mdot
.49541 .29864 Mdot
.49542 .29867 Mdot
.49543 .29869 Mdot
.49544 .29872 Mdot
.49545 .29874 Mdot
.49546 .29877 Mdot
.49547 .29879 Mdot
.49548 .29882 Mdot
.49549 .29884 Mdot
.4955 .29887 Mdot
.4955 .2989 Mdot
.49551 .29892 Mdot
.49552 .29895 Mdot
.49553 .29897 Mdot
.49554 .299 Mdot
.49555 .29902 Mdot
.49556 .29905 Mdot
.49557 .29907 Mdot
.49558 .2991 Mdot
.49559 .29912 Mdot
.4956 .29915 Mdot
.49561 .29917 Mdot
.49562 .2992 Mdot
.49563 .29923 Mdot
.49564 .29925 Mdot
.49565 .29928 Mdot
.49566 .2993 Mdot
.49567 .29933 Mdot
.49568 .29935 Mdot
.49569 .29938 Mdot
.4957 .2994 Mdot
.4957 .29943 Mdot
.49571 .29945 Mdot
.49572 .29948 Mdot
.49573 .29951 Mdot
.49574 .29953 Mdot
.49575 .29956 Mdot
.49576 .29958 Mdot
.49577 .29961 Mdot
.49578 .29963 Mdot
.49579 .29966 Mdot
.4958 .29968 Mdot
.49581 .29971 Mdot
.49582 .29973 Mdot
.49583 .29976 Mdot
.49584 .29978 Mdot
.49585 .29981 Mdot
.49586 .29984 Mdot
.49587 .29986 Mdot
.49588 .29989 Mdot
.49589 .29991 Mdot
.4959 .29994 Mdot
.4959 .29996 Mdot
.49591 .29999 Mdot
.49592 .30001 Mdot
.49593 .30004 Mdot
.49594 .30006 Mdot
.49595 .30009 Mdot
.49596 .30012 Mdot
.49597 .30014 Mdot
.49598 .30017 Mdot
.49599 .30019 Mdot
.496 .30022 Mdot
.49601 .30024 Mdot
.49602 .30027 Mdot
.49603 .30029 Mdot
.49604 .30032 Mdot
.49605 .30034 Mdot
.49606 .30037 Mdot
.49607 .3004 Mdot
.49608 .30042 Mdot
.49609 .30045 Mdot
.4961 .30047 Mdot
.4961 .3005 Mdot
.49611 .30052 Mdot
.49612 .30055 Mdot
.49613 .30057 Mdot
.49614 .3006 Mdot
.49615 .30062 Mdot
.49616 .30065 Mdot
.49617 .30068 Mdot
.49618 .3007 Mdot
.49619 .30073 Mdot
.4962 .30075 Mdot
.49621 .30078 Mdot
.49622 .3008 Mdot
.49623 .30083 Mdot
.49624 .30085 Mdot
.49625 .30088 Mdot
.49626 .30091 Mdot
.49627 .30093 Mdot
.49628 .30096 Mdot
.49629 .30098 Mdot
.4963 .30101 Mdot
.4963 .30103 Mdot
.49631 .30106 Mdot
.49632 .30108 Mdot
.49633 .30111 Mdot
.49634 .30113 Mdot
.49635 .30116 Mdot
.49636 .30119 Mdot
.49637 .30121 Mdot
.49638 .30124 Mdot
.49639 .30126 Mdot
.4964 .30129 Mdot
.49641 .30131 Mdot
.49642 .30134 Mdot
.49643 .30136 Mdot
.49644 .30139 Mdot
.49645 .30141 Mdot
.49646 .30144 Mdot
.49647 .30147 Mdot
.49648 .30149 Mdot
.49649 .30152 Mdot
.4965 .30154 Mdot
.4965 .30157 Mdot
.49651 .30159 Mdot
.49652 .30162 Mdot
.49653 .30164 Mdot
.49654 .30167 Mdot
.49655 .3017 Mdot
.49656 .30172 Mdot
.49657 .30175 Mdot
.49658 .30177 Mdot
.49659 .3018 Mdot
.4966 .30182 Mdot
.49661 .30185 Mdot
.49662 .30187 Mdot
.49663 .3019 Mdot
.49664 .30193 Mdot
.49665 .30195 Mdot
.49666 .30198 Mdot
.49667 .302 Mdot
.49668 .30203 Mdot
.49669 .30205 Mdot
.4967 .30208 Mdot
.4967 .3021 Mdot
.49671 .30213 Mdot
.49672 .30215 Mdot
.49673 .30218 Mdot
.49674 .30221 Mdot
.49675 .30223 Mdot
.49676 .30226 Mdot
.49677 .30228 Mdot
.49678 .30231 Mdot
.49679 .30233 Mdot
.4968 .30236 Mdot
.49681 .30238 Mdot
.49682 .30241 Mdot
.49683 .30244 Mdot
.49684 .30246 Mdot
.49685 .30249 Mdot
.49686 .30251 Mdot
.49687 .30254 Mdot
.49688 .30256 Mdot
.49689 .30259 Mdot
.4969 .30261 Mdot
.4969 .30264 Mdot
.49691 .30267 Mdot
.49692 .30269 Mdot
.49693 .30272 Mdot
.49694 .30274 Mdot
.49695 .30277 Mdot
.49696 .30279 Mdot
.49697 .30282 Mdot
.49698 .30284 Mdot
.49699 .30287 Mdot
.497 .3029 Mdot
.49701 .30292 Mdot
.49702 .30295 Mdot
.49703 .30297 Mdot
.49704 .303 Mdot
.49705 .30302 Mdot
.49706 .30305 Mdot
.49707 .30307 Mdot
.49708 .3031 Mdot
.49709 .30313 Mdot
.4971 .30315 Mdot
.4971 .30318 Mdot
.49711 .3032 Mdot
.49712 .30323 Mdot
.49713 .30325 Mdot
.49714 .30328 Mdot
.49715 .3033 Mdot
.49716 .30333 Mdot
.49717 .30336 Mdot
.49718 .30338 Mdot
.49719 .30341 Mdot
.4972 .30343 Mdot
.49721 .30346 Mdot
.49722 .30348 Mdot
.49723 .30351 Mdot
.49724 .30354 Mdot
.49725 .30356 Mdot
.49726 .30359 Mdot
.49727 .30361 Mdot
.49728 .30364 Mdot
.49729 .30366 Mdot
.4973 .30369 Mdot
.4973 .30371 Mdot
.49731 .30374 Mdot
.49732 .30377 Mdot
.49733 .30379 Mdot
.49734 .30382 Mdot
.49735 .30384 Mdot
.49736 .30387 Mdot
.49737 .30389 Mdot
.49738 .30392 Mdot
.49739 .30394 Mdot
.4974 .30397 Mdot
.49741 .304 Mdot
.49742 .30402 Mdot
.49743 .30405 Mdot
.49744 .30407 Mdot
.49745 .3041 Mdot
.49746 .30412 Mdot
.49747 .30415 Mdot
.49748 .30418 Mdot
.49749 .3042 Mdot
.4975 .30423 Mdot
.4975 .30425 Mdot
.49751 .30428 Mdot
.49752 .3043 Mdot
.49753 .30433 Mdot
.49754 .30435 Mdot
.49755 .30438 Mdot
.49756 .30441 Mdot
.49757 .30443 Mdot
.49758 .30446 Mdot
.49759 .30448 Mdot
.4976 .30451 Mdot
.49761 .30453 Mdot
.49762 .30456 Mdot
.49763 .30458 Mdot
.49764 .30461 Mdot
.49765 .30464 Mdot
.49766 .30466 Mdot
.49767 .30469 Mdot
.49768 .30471 Mdot
.49769 .30474 Mdot
.4977 .30476 Mdot
.4977 .30479 Mdot
.49771 .30482 Mdot
.49772 .30484 Mdot
.49773 .30487 Mdot
.49774 .30489 Mdot
.49775 .30492 Mdot
.49776 .30494 Mdot
.49777 .30497 Mdot
.49778 .305 Mdot
.49779 .30502 Mdot
.4978 .30505 Mdot
.49781 .30507 Mdot
.49782 .3051 Mdot
.49783 .30512 Mdot
.49784 .30515 Mdot
.49785 .30517 Mdot
.49786 .3052 Mdot
.49787 .30523 Mdot
.49788 .30525 Mdot
.49789 .30528 Mdot
.4979 .3053 Mdot
.4979 .30533 Mdot
.49791 .30535 Mdot
.49792 .30538 Mdot
.49793 .30541 Mdot
.49794 .30543 Mdot
.49795 .30546 Mdot
.49796 .30548 Mdot
.49797 .30551 Mdot
.49798 .30553 Mdot
.49799 .30556 Mdot
.498 .30559 Mdot
.49801 .30561 Mdot
.49802 .30564 Mdot
.49803 .30566 Mdot
.49804 .30569 Mdot
.49805 .30571 Mdot
.49806 .30574 Mdot
.49807 .30576 Mdot
.49808 .30579 Mdot
.49809 .30582 Mdot
.4981 .30584 Mdot
.4981 .30587 Mdot
.49811 .30589 Mdot
.49812 .30592 Mdot
.49813 .30594 Mdot
.49814 .30597 Mdot
.49815 .306 Mdot
.49816 .30602 Mdot
.49817 .30605 Mdot
.49818 .30607 Mdot
.49819 .3061 Mdot
.4982 .30612 Mdot
.49821 .30615 Mdot
.49822 .30618 Mdot
.49823 .3062 Mdot
.49824 .30623 Mdot
.49825 .30625 Mdot
.49826 .30628 Mdot
.49827 .3063 Mdot
.49828 .30633 Mdot
.49829 .30636 Mdot
.4983 .30638 Mdot
.4983 .30641 Mdot
.49831 .30643 Mdot
.49832 .30646 Mdot
.49833 .30648 Mdot
.49834 .30651 Mdot
.49835 .30654 Mdot
.49836 .30656 Mdot
.49837 .30659 Mdot
.49838 .30661 Mdot
.49839 .30664 Mdot
.4984 .30666 Mdot
.49841 .30669 Mdot
.49842 .30672 Mdot
.49843 .30674 Mdot
.49844 .30677 Mdot
.49845 .30679 Mdot
.49846 .30682 Mdot
.49847 .30684 Mdot
.49848 .30687 Mdot
.49849 .3069 Mdot
.4985 .30692 Mdot
.4985 .30695 Mdot
.49851 .30697 Mdot
.49852 .307 Mdot
.49853 .30702 Mdot
.49854 .30705 Mdot
.49855 .30708 Mdot
.49856 .3071 Mdot
.49857 .30713 Mdot
.49858 .30715 Mdot
.49859 .30718 Mdot
.4986 .3072 Mdot
.49861 .30723 Mdot
.49862 .30726 Mdot
.49863 .30728 Mdot
.49864 .30731 Mdot
.49865 .30733 Mdot
.49866 .30736 Mdot
.49867 .30738 Mdot
.49868 .30741 Mdot
.49869 .30744 Mdot
.4987 .30746 Mdot
.4987 .30749 Mdot
.49871 .30751 Mdot
.49872 .30754 Mdot
.49873 .30756 Mdot
.49874 .30759 Mdot
.49875 .30762 Mdot
.49876 .30764 Mdot
.49877 .30767 Mdot
.49878 .30769 Mdot
.49879 .30772 Mdot
.4988 .30775 Mdot
.49881 .30777 Mdot
.49882 .3078 Mdot
.49883 .30782 Mdot
.49884 .30785 Mdot
.49885 .30787 Mdot
.49886 .3079 Mdot
.49887 .30793 Mdot
.49888 .30795 Mdot
.49889 .30798 Mdot
.4989 .308 Mdot
.4989 .30803 Mdot
.49891 .30805 Mdot
.49892 .30808 Mdot
.49893 .30811 Mdot
.49894 .30813 Mdot
.49895 .30816 Mdot
.49896 .30818 Mdot
.49897 .30821 Mdot
.49898 .30823 Mdot
.49899 .30826 Mdot
.499 .30829 Mdot
.49901 .30831 Mdot
.49902 .30834 Mdot
.49903 .30836 Mdot
.49904 .30839 Mdot
.49905 .30841 Mdot
.49906 .30844 Mdot
.49907 .30847 Mdot
.49908 .30849 Mdot
.49909 .30852 Mdot
.4991 .30854 Mdot
.4991 .30857 Mdot
.49911 .3086 Mdot
.49912 .30862 Mdot
.49913 .30865 Mdot
.49914 .30867 Mdot
.49915 .3087 Mdot
.49916 .30872 Mdot
.49917 .30875 Mdot
.49918 .30878 Mdot
.49919 .3088 Mdot
.4992 .30883 Mdot
.49921 .30885 Mdot
.49922 .30888 Mdot
.49923 .30891 Mdot
.49924 .30893 Mdot
.49925 .30896 Mdot
.49926 .30898 Mdot
.49927 .30901 Mdot
.49928 .30903 Mdot
.49929 .30906 Mdot
.4993 .30909 Mdot
.4993 .30911 Mdot
.49931 .30914 Mdot
.49932 .30916 Mdot
.49933 .30919 Mdot
.49934 .30921 Mdot
.49935 .30924 Mdot
.49936 .30927 Mdot
.49937 .30929 Mdot
.49938 .30932 Mdot
.49939 .30934 Mdot
.4994 .30937 Mdot
.49941 .3094 Mdot
.49942 .30942 Mdot
.49943 .30945 Mdot
.49944 .30947 Mdot
.49945 .3095 Mdot
.49946 .30952 Mdot
.49947 .30955 Mdot
.49948 .30958 Mdot
.49949 .3096 Mdot
.4995 .30963 Mdot
.4995 .30965 Mdot
.49951 .30968 Mdot
.49952 .30971 Mdot
.49953 .30973 Mdot
.49954 .30976 Mdot
.49955 .30978 Mdot
.49956 .30981 Mdot
.49957 .30983 Mdot
.49958 .30986 Mdot
.49959 .30989 Mdot
.4996 .30991 Mdot
.49961 .30994 Mdot
.49962 .30996 Mdot
.49963 .30999 Mdot
.49964 .31002 Mdot
.49965 .31004 Mdot
.49966 .31007 Mdot
.49967 .31009 Mdot
.49968 .31012 Mdot
.49969 .31014 Mdot
.4997 .31017 Mdot
.4997 .3102 Mdot
.49971 .31022 Mdot
.49972 .31025 Mdot
.49973 .31027 Mdot
.49974 .3103 Mdot
.49975 .31033 Mdot
.49976 .31035 Mdot
.49977 .31038 Mdot
.49978 .3104 Mdot
.49979 .31043 Mdot
.4998 .31045 Mdot
.49981 .31048 Mdot
.49982 .31051 Mdot
.49983 .31053 Mdot
.49984 .31056 Mdot
.49985 .31058 Mdot
.49986 .31061 Mdot
.49987 .31064 Mdot
.49988 .31066 Mdot
.49989 .31069 Mdot
.4999 .31071 Mdot
.4999 .31074 Mdot
.49991 .31077 Mdot
.49992 .31079 Mdot
.49993 .31082 Mdot
.49994 .31084 Mdot
.49995 .31087 Mdot
.49996 .31089 Mdot
.49997 .31092 Mdot
.49998 .31095 Mdot
.49999 .31097 Mdot
.5 .311 Mdot
.50001 .31102 Mdot
.50002 .31105 Mdot
.50003 .31108 Mdot
.50004 .3111 Mdot
.50005 .31113 Mdot
.50006 .31115 Mdot
.50007 .31118 Mdot
.50008 .31121 Mdot
.50009 .31123 Mdot
.5001 .31126 Mdot
.5001 .31128 Mdot
.50011 .31131 Mdot
.50012 .31133 Mdot
.50013 .31136 Mdot
.50014 .31139 Mdot
.50015 .31141 Mdot
.50016 .31144 Mdot
.50017 .31146 Mdot
.50018 .31149 Mdot
.50019 .31152 Mdot
.5002 .31154 Mdot
.50021 .31157 Mdot
.50022 .31159 Mdot
.50023 .31162 Mdot
.50024 .31164 Mdot
.50025 .31167 Mdot
.50026 .3117 Mdot
.50027 .31172 Mdot
.50028 .31175 Mdot
.50029 .31177 Mdot
.5003 .3118 Mdot
.5003 .31183 Mdot
.50031 .31185 Mdot
.50032 .31188 Mdot
.50033 .3119 Mdot
.50034 .31193 Mdot
.50035 .31196 Mdot
.50036 .31198 Mdot
.50037 .31201 Mdot
.50038 .31203 Mdot
.50039 .31206 Mdot
.5004 .31208 Mdot
.50041 .31211 Mdot
.50042 .31214 Mdot
.50043 .31216 Mdot
.50044 .31219 Mdot
.50045 .31221 Mdot
.50046 .31224 Mdot
.50047 .31227 Mdot
.50048 .31229 Mdot
.50049 .31232 Mdot
.5005 .31234 Mdot
.5005 .31237 Mdot
.50051 .31239 Mdot
.50052 .31242 Mdot
.50053 .31245 Mdot
.50054 .31247 Mdot
.50055 .3125 Mdot
.50056 .31252 Mdot
.50057 .31255 Mdot
.50058 .31258 Mdot
.50059 .3126 Mdot
.5006 .31263 Mdot
.50061 .31265 Mdot
.50062 .31268 Mdot
.50063 .3127 Mdot
.50064 .31273 Mdot
.50065 .31276 Mdot
.50066 .31278 Mdot
.50067 .31281 Mdot
.50068 .31283 Mdot
.50069 .31286 Mdot
.5007 .31288 Mdot
.5007 .31291 Mdot
.50071 .31294 Mdot
.50072 .31296 Mdot
.50073 .31299 Mdot
.50074 .31301 Mdot
.50075 .31304 Mdot
.50076 .31307 Mdot
.50077 .31309 Mdot
.50078 .31312 Mdot
.50079 .31314 Mdot
.5008 .31317 Mdot
.50081 .31319 Mdot
.50082 .31322 Mdot
.50083 .31325 Mdot
.50084 .31327 Mdot
.50085 .3133 Mdot
.50086 .31332 Mdot
.50087 .31335 Mdot
.50088 .31338 Mdot
.50089 .3134 Mdot
.5009 .31343 Mdot
.5009 .31345 Mdot
.50091 .31348 Mdot
.50092 .3135 Mdot
.50093 .31353 Mdot
.50094 .31356 Mdot
.50095 .31358 Mdot
.50096 .31361 Mdot
.50097 .31363 Mdot
.50098 .31366 Mdot
.50099 .31368 Mdot
.501 .31371 Mdot
.50101 .31374 Mdot
.50102 .31376 Mdot
.50103 .31379 Mdot
.50104 .31381 Mdot
.50105 .31384 Mdot
.50106 .31386 Mdot
.50107 .31389 Mdot
.50108 .31392 Mdot
.50109 .31394 Mdot
.5011 .31397 Mdot
.5011 .31399 Mdot
.50111 .31402 Mdot
.50112 .31405 Mdot
.50113 .31407 Mdot
.50114 .3141 Mdot
.50115 .31412 Mdot
.50116 .31415 Mdot
.50117 .31417 Mdot
.50118 .3142 Mdot
.50119 .31423 Mdot
.5012 .31425 Mdot
.50121 .31428 Mdot
.50122 .3143 Mdot
.50123 .31433 Mdot
.50124 .31435 Mdot
.50125 .31438 Mdot
.50126 .31441 Mdot
.50127 .31443 Mdot
.50128 .31446 Mdot
.50129 .31448 Mdot
.5013 .31451 Mdot
.5013 .31453 Mdot
.50131 .31456 Mdot
.50132 .31459 Mdot
.50133 .31461 Mdot
.50134 .31464 Mdot
.50135 .31466 Mdot
.50136 .31469 Mdot
.50137 .31471 Mdot
.50138 .31474 Mdot
.50139 .31477 Mdot
.5014 .31479 Mdot
.50141 .31482 Mdot
.50142 .31484 Mdot
.50143 .31487 Mdot
.50144 .31489 Mdot
.50145 .31492 Mdot
.50146 .31495 Mdot
.50147 .31497 Mdot
.50148 .315 Mdot
.50149 .31502 Mdot
.5015 .31505 Mdot
.5015 .31507 Mdot
.50151 .3151 Mdot
.50152 .31513 Mdot
.50153 .31515 Mdot
.50154 .31518 Mdot
.50155 .3152 Mdot
.50156 .31523 Mdot
.50157 .31525 Mdot
.50158 .31528 Mdot
.50159 .31531 Mdot
.5016 .31533 Mdot
.50161 .31536 Mdot
.50162 .31538 Mdot
.50163 .31541 Mdot
.50164 .31543 Mdot
.50165 .31546 Mdot
.50166 .31549 Mdot
.50167 .31551 Mdot
.50168 .31554 Mdot
.50169 .31556 Mdot
.5017 .31559 Mdot
.5017 .31561 Mdot
.50171 .31564 Mdot
.50172 .31567 Mdot
.50173 .31569 Mdot
.50174 .31572 Mdot
.50175 .31574 Mdot
.50176 .31577 Mdot
.50177 .31579 Mdot
.50178 .31582 Mdot
.50179 .31585 Mdot
.5018 .31587 Mdot
.50181 .3159 Mdot
.50182 .31592 Mdot
.50183 .31595 Mdot
.50184 .31597 Mdot
.50185 .316 Mdot
.50186 .31603 Mdot
.50187 .31605 Mdot
.50188 .31608 Mdot
.50189 .3161 Mdot
.5019 .31613 Mdot
.5019 .31615 Mdot
.50191 .31618 Mdot
.50192 .31621 Mdot
.50193 .31623 Mdot
.50194 .31626 Mdot
.50195 .31628 Mdot
.50196 .31631 Mdot
.50197 .31633 Mdot
.50198 .31636 Mdot
.50199 .31639 Mdot
.502 .31641 Mdot
.50201 .31644 Mdot
.50202 .31646 Mdot
.50203 .31649 Mdot
.50204 .31651 Mdot
.50205 .31654 Mdot
.50206 .31656 Mdot
.50207 .31659 Mdot
.50208 .31662 Mdot
.50209 .31664 Mdot
.5021 .31667 Mdot
.5021 .31669 Mdot
.50211 .31672 Mdot
.50212 .31674 Mdot
.50213 .31677 Mdot
.50214 .3168 Mdot
.50215 .31682 Mdot
.50216 .31685 Mdot
.50217 .31687 Mdot
.50218 .3169 Mdot
.50219 .31692 Mdot
.5022 .31695 Mdot
.50221 .31697 Mdot
.50222 .317 Mdot
.50223 .31703 Mdot
.50224 .31705 Mdot
.50225 .31708 Mdot
.50226 .3171 Mdot
.50227 .31713 Mdot
.50228 .31715 Mdot
.50229 .31718 Mdot
.5023 .31721 Mdot
.5023 .31723 Mdot
.50231 .31726 Mdot
.50232 .31728 Mdot
.50233 .31731 Mdot
.50234 .31733 Mdot
.50235 .31736 Mdot
.50236 .31739 Mdot
.50237 .31741 Mdot
.50238 .31744 Mdot
.50239 .31746 Mdot
.5024 .31749 Mdot
.50241 .31751 Mdot
.50242 .31754 Mdot
.50243 .31756 Mdot
.50244 .31759 Mdot
.50245 .31762 Mdot
.50246 .31764 Mdot
.50247 .31767 Mdot
.50248 .31769 Mdot
.50249 .31772 Mdot
.5025 .31774 Mdot
.5025 .31777 Mdot
.50251 .31779 Mdot
.50252 .31782 Mdot
.50253 .31785 Mdot
.50254 .31787 Mdot
.50255 .3179 Mdot
.50256 .31792 Mdot
.50257 .31795 Mdot
.50258 .31797 Mdot
.50259 .318 Mdot
.5026 .31803 Mdot
.50261 .31805 Mdot
.50262 .31808 Mdot
.50263 .3181 Mdot
.50264 .31813 Mdot
.50265 .31815 Mdot
.50266 .31818 Mdot
.50267 .3182 Mdot
.50268 .31823 Mdot
.50269 .31826 Mdot
.5027 .31828 Mdot
.5027 .31831 Mdot
.50271 .31833 Mdot
.50272 .31836 Mdot
.50273 .31838 Mdot
.50274 .31841 Mdot
.50275 .31843 Mdot
.50276 .31846 Mdot
.50277 .31849 Mdot
.50278 .31851 Mdot
.50279 .31854 Mdot
.5028 .31856 Mdot
.50281 .31859 Mdot
.50282 .31861 Mdot
.50283 .31864 Mdot
.50284 .31866 Mdot
.50285 .31869 Mdot
.50286 .31872 Mdot
.50287 .31874 Mdot
.50288 .31877 Mdot
.50289 .31879 Mdot
.5029 .31882 Mdot
.5029 .31884 Mdot
.50291 .31887 Mdot
.50292 .31889 Mdot
.50293 .31892 Mdot
.50294 .31895 Mdot
.50295 .31897 Mdot
.50296 .319 Mdot
.50297 .31902 Mdot
.50298 .31905 Mdot
.50299 .31907 Mdot
.503 .3191 Mdot
.50301 .31912 Mdot
.50302 .31915 Mdot
.50303 .31918 Mdot
.50304 .3192 Mdot
.50305 .31923 Mdot
.50306 .31925 Mdot
.50307 .31928 Mdot
.50308 .3193 Mdot
.50309 .31933 Mdot
.5031 .31935 Mdot
.5031 .31938 Mdot
.50311 .31941 Mdot
.50312 .31943 Mdot
.50313 .31946 Mdot
.50314 .31948 Mdot
.50315 .31951 Mdot
.50316 .31953 Mdot
.50317 .31956 Mdot
.50318 .31958 Mdot
.50319 .31961 Mdot
.5032 .31964 Mdot
.50321 .31966 Mdot
.50322 .31969 Mdot
.50323 .31971 Mdot
.50324 .31974 Mdot
.50325 .31976 Mdot
.50326 .31979 Mdot
.50327 .31981 Mdot
.50328 .31984 Mdot
.50329 .31987 Mdot
.5033 .31989 Mdot
.5033 .31992 Mdot
.50331 .31994 Mdot
.50332 .31997 Mdot
.50333 .31999 Mdot
.50334 .32002 Mdot
.50335 .32004 Mdot
.50336 .32007 Mdot
.50337 .3201 Mdot
.50338 .32012 Mdot
.50339 .32015 Mdot
.5034 .32017 Mdot
.50341 .3202 Mdot
.50342 .32022 Mdot
.50343 .32025 Mdot
.50344 .32027 Mdot
.50345 .3203 Mdot
.50346 .32032 Mdot
.50347 .32035 Mdot
.50348 .32038 Mdot
.50349 .3204 Mdot
.5035 .32043 Mdot
.5035 .32045 Mdot
.50351 .32048 Mdot
.50352 .3205 Mdot
.50353 .32053 Mdot
.50354 .32055 Mdot
.50355 .32058 Mdot
.50356 .32061 Mdot
.50357 .32063 Mdot
.50358 .32066 Mdot
.50359 .32068 Mdot
.5036 .32071 Mdot
.50361 .32073 Mdot
.50362 .32076 Mdot
.50363 .32078 Mdot
.50364 .32081 Mdot
.50365 .32083 Mdot
.50366 .32086 Mdot
.50367 .32089 Mdot
.50368 .32091 Mdot
.50369 .32094 Mdot
.5037 .32096 Mdot
.5037 .32099 Mdot
.50371 .32101 Mdot
.50372 .32104 Mdot
.50373 .32106 Mdot
.50374 .32109 Mdot
.50375 .32111 Mdot
.50376 .32114 Mdot
.50377 .32117 Mdot
.50378 .32119 Mdot
.50379 .32122 Mdot
.5038 .32124 Mdot
.50381 .32127 Mdot
.50382 .32129 Mdot
.50383 .32132 Mdot
.50384 .32134 Mdot
.50385 .32137 Mdot
.50386 .32139 Mdot
.50387 .32142 Mdot
.50388 .32145 Mdot
.50389 .32147 Mdot
.5039 .3215 Mdot
.5039 .32152 Mdot
.50391 .32155 Mdot
.50392 .32157 Mdot
.50393 .3216 Mdot
.50394 .32162 Mdot
.50395 .32165 Mdot
.50396 .32167 Mdot
.50397 .3217 Mdot
.50398 .32173 Mdot
.50399 .32175 Mdot
.504 .32178 Mdot
.50401 .3218 Mdot
.50402 .32183 Mdot
.50403 .32185 Mdot
.50404 .32188 Mdot
.50405 .3219 Mdot
.50406 .32193 Mdot
.50407 .32195 Mdot
.50408 .32198 Mdot
.50409 .32201 Mdot
.5041 .32203 Mdot
.5041 .32206 Mdot
.50411 .32208 Mdot
.50412 .32211 Mdot
.50413 .32213 Mdot
.50414 .32216 Mdot
.50415 .32218 Mdot
.50416 .32221 Mdot
.50417 .32223 Mdot
.50418 .32226 Mdot
.50419 .32229 Mdot
.5042 .32231 Mdot
.50421 .32234 Mdot
.50422 .32236 Mdot
.50423 .32239 Mdot
.50424 .32241 Mdot
.50425 .32244 Mdot
.50426 .32246 Mdot
.50427 .32249 Mdot
.50428 .32251 Mdot
.50429 .32254 Mdot
.5043 .32256 Mdot
.5043 .32259 Mdot
.50431 .32262 Mdot
.50432 .32264 Mdot
.50433 .32267 Mdot
.50434 .32269 Mdot
.50435 .32272 Mdot
.50436 .32274 Mdot
.50437 .32277 Mdot
.50438 .32279 Mdot
.50439 .32282 Mdot
.5044 .32284 Mdot
.50441 .32287 Mdot
.50442 .32289 Mdot
.50443 .32292 Mdot
.50444 .32295 Mdot
.50445 .32297 Mdot
.50446 .323 Mdot
.50447 .32302 Mdot
.50448 .32305 Mdot
.50449 .32307 Mdot
.5045 .3231 Mdot
.5045 .32312 Mdot
.50451 .32315 Mdot
.50452 .32317 Mdot
.50453 .3232 Mdot
.50454 .32322 Mdot
.50455 .32325 Mdot
.50456 .32328 Mdot
.50457 .3233 Mdot
.50458 .32333 Mdot
.50459 .32335 Mdot
.5046 .32338 Mdot
.50461 .3234 Mdot
.50462 .32343 Mdot
.50463 .32345 Mdot
.50464 .32348 Mdot
.50465 .3235 Mdot
.50466 .32353 Mdot
.50467 .32355 Mdot
.50468 .32358 Mdot
.50469 .32361 Mdot
.5047 .32363 Mdot
.5047 .32366 Mdot
.50471 .32368 Mdot
.50472 .32371 Mdot
.50473 .32373 Mdot
.50474 .32376 Mdot
.50475 .32378 Mdot
.50476 .32381 Mdot
.50477 .32383 Mdot
.50478 .32386 Mdot
.50479 .32388 Mdot
.5048 .32391 Mdot
.50481 .32394 Mdot
.50482 .32396 Mdot
.50483 .32399 Mdot
.50484 .32401 Mdot
.50485 .32404 Mdot
.50486 .32406 Mdot
.50487 .32409 Mdot
.50488 .32411 Mdot
.50489 .32414 Mdot
.5049 .32416 Mdot
.5049 .32419 Mdot
.50491 .32421 Mdot
.50492 .32424 Mdot
.50493 .32426 Mdot
.50494 .32429 Mdot
.50495 .32432 Mdot
.50496 .32434 Mdot
.50497 .32437 Mdot
.50498 .32439 Mdot
.50499 .32442 Mdot
.505 .32444 Mdot
.50501 .32447 Mdot
.50502 .32449 Mdot
.50503 .32452 Mdot
.50504 .32454 Mdot
.50505 .32457 Mdot
.50506 .32459 Mdot
.50507 .32462 Mdot
.50508 .32464 Mdot
.50509 .32467 Mdot
.5051 .3247 Mdot
.5051 .32472 Mdot
.50511 .32475 Mdot
.50512 .32477 Mdot
.50513 .3248 Mdot
.50514 .32482 Mdot
.50515 .32485 Mdot
.50516 .32487 Mdot
.50517 .3249 Mdot
.50518 .32492 Mdot
.50519 .32495 Mdot
.5052 .32497 Mdot
.50521 .325 Mdot
.50522 .32502 Mdot
.50523 .32505 Mdot
.50524 .32507 Mdot
.50525 .3251 Mdot
.50526 .32513 Mdot
.50527 .32515 Mdot
.50528 .32518 Mdot
.50529 .3252 Mdot
.5053 .32523 Mdot
.5053 .32525 Mdot
.50531 .32528 Mdot
.50532 .3253 Mdot
.50533 .32533 Mdot
.50534 .32535 Mdot
.50535 .32538 Mdot
.50536 .3254 Mdot
.50537 .32543 Mdot
.50538 .32545 Mdot
.50539 .32548 Mdot
.5054 .3255 Mdot
.50541 .32553 Mdot
.50542 .32556 Mdot
.50543 .32558 Mdot
.50544 .32561 Mdot
.50545 .32563 Mdot
.50546 .32566 Mdot
.50547 .32568 Mdot
.50548 .32571 Mdot
.50549 .32573 Mdot
.5055 .32576 Mdot
.5055 .32578 Mdot
.50551 .32581 Mdot
.50552 .32583 Mdot
.50553 .32586 Mdot
.50554 .32588 Mdot
.50555 .32591 Mdot
.50556 .32593 Mdot
.50557 .32596 Mdot
.50558 .32599 Mdot
.50559 .32601 Mdot
.5056 .32604 Mdot
.50561 .32606 Mdot
.50562 .32609 Mdot
.50563 .32611 Mdot
.50564 .32614 Mdot
.50565 .32616 Mdot
.50566 .32619 Mdot
.50567 .32621 Mdot
.50568 .32624 Mdot
.50569 .32626 Mdot
.5057 .32629 Mdot
.5057 .32631 Mdot
.50571 .32634 Mdot
.50572 .32636 Mdot
.50573 .32639 Mdot
.50574 .32641 Mdot
.50575 .32644 Mdot
.50576 .32646 Mdot
.50577 .32649 Mdot
.50578 .32652 Mdot
.50579 .32654 Mdot
.5058 .32657 Mdot
.50581 .32659 Mdot
.50582 .32662 Mdot
.50583 .32664 Mdot
.50584 .32667 Mdot
.50585 .32669 Mdot
.50586 .32672 Mdot
.50587 .32674 Mdot
.50588 .32677 Mdot
.50589 .32679 Mdot
.5059 .32682 Mdot
.5059 .32684 Mdot
.50591 .32687 Mdot
.50592 .32689 Mdot
.50593 .32692 Mdot
.50594 .32694 Mdot
.50595 .32697 Mdot
.50596 .32699 Mdot
.50597 .32702 Mdot
.50598 .32705 Mdot
.50599 .32707 Mdot
.506 .3271 Mdot
.50601 .32712 Mdot
.50602 .32715 Mdot
.50603 .32717 Mdot
.50604 .3272 Mdot
.50605 .32722 Mdot
.50606 .32725 Mdot
.50607 .32727 Mdot
.50608 .3273 Mdot
.50609 .32732 Mdot
.5061 .32735 Mdot
.5061 .32737 Mdot
.50611 .3274 Mdot
.50612 .32742 Mdot
.50613 .32745 Mdot
.50614 .32747 Mdot
.50615 .3275 Mdot
.50616 .32752 Mdot
.50617 .32755 Mdot
.50618 .32757 Mdot
.50619 .3276 Mdot
.5062 .32762 Mdot
.50621 .32765 Mdot
.50622 .32768 Mdot
.50623 .3277 Mdot
.50624 .32773 Mdot
.50625 .32775 Mdot
.50626 .32778 Mdot
.50627 .3278 Mdot
.50628 .32783 Mdot
.50629 .32785 Mdot
.5063 .32788 Mdot
.5063 .3279 Mdot
.50631 .32793 Mdot
.50632 .32795 Mdot
.50633 .32798 Mdot
.50634 .328 Mdot
.50635 .32803 Mdot
.50636 .32805 Mdot
.50637 .32808 Mdot
.50638 .3281 Mdot
.50639 .32813 Mdot
.5064 .32815 Mdot
.50641 .32818 Mdot
.50642 .3282 Mdot
.50643 .32823 Mdot
.50644 .32825 Mdot
.50645 .32828 Mdot
.50646 .3283 Mdot
.50647 .32833 Mdot
.50648 .32836 Mdot
.50649 .32838 Mdot
.5065 .32841 Mdot
.5065 .32843 Mdot
.50651 .32846 Mdot
.50652 .32848 Mdot
.50653 .32851 Mdot
.50654 .32853 Mdot
.50655 .32856 Mdot
.50656 .32858 Mdot
.50657 .32861 Mdot
.50658 .32863 Mdot
.50659 .32866 Mdot
.5066 .32868 Mdot
.50661 .32871 Mdot
.50662 .32873 Mdot
.50663 .32876 Mdot
.50664 .32878 Mdot
.50665 .32881 Mdot
.50666 .32883 Mdot
.50667 .32886 Mdot
.50668 .32888 Mdot
.50669 .32891 Mdot
.5067 .32893 Mdot
.5067 .32896 Mdot
.50671 .32898 Mdot
.50672 .32901 Mdot
.50673 .32903 Mdot
.50674 .32906 Mdot
.50675 .32908 Mdot
.50676 .32911 Mdot
.50677 .32913 Mdot
.50678 .32916 Mdot
.50679 .32918 Mdot
.5068 .32921 Mdot
.50681 .32924 Mdot
.50682 .32926 Mdot
.50683 .32929 Mdot
.50684 .32931 Mdot
.50685 .32934 Mdot
.50686 .32936 Mdot
.50687 .32939 Mdot
.50688 .32941 Mdot
.50689 .32944 Mdot
.5069 .32946 Mdot
.5069 .32949 Mdot
.50691 .32951 Mdot
.50692 .32954 Mdot
.50693 .32956 Mdot
.50694 .32959 Mdot
.50695 .32961 Mdot
.50696 .32964 Mdot
.50697 .32966 Mdot
.50698 .32969 Mdot
.50699 .32971 Mdot
.507 .32974 Mdot
.50701 .32976 Mdot
.50702 .32979 Mdot
.50703 .32981 Mdot
.50704 .32984 Mdot
.50705 .32986 Mdot
.50706 .32989 Mdot
.50707 .32991 Mdot
.50708 .32994 Mdot
.50709 .32996 Mdot
.5071 .32999 Mdot
.5071 .33001 Mdot
.50711 .33004 Mdot
.50712 .33006 Mdot
.50713 .33009 Mdot
.50714 .33011 Mdot
.50715 .33014 Mdot
.50716 .33016 Mdot
.50717 .33019 Mdot
.50718 .33021 Mdot
.50719 .33024 Mdot
.5072 .33026 Mdot
.50721 .33029 Mdot
.50722 .33031 Mdot
.50723 .33034 Mdot
.50724 .33036 Mdot
.50725 .33039 Mdot
.50726 .33041 Mdot
.50727 .33044 Mdot
.50728 .33047 Mdot
.50729 .33049 Mdot
.5073 .33052 Mdot
.5073 .33054 Mdot
.50731 .33057 Mdot
.50732 .33059 Mdot
.50733 .33062 Mdot
.50734 .33064 Mdot
.50735 .33067 Mdot
.50736 .33069 Mdot
.50737 .33072 Mdot
.50738 .33074 Mdot
.50739 .33077 Mdot
.5074 .33079 Mdot
.50741 .33082 Mdot
.50742 .33084 Mdot
.50743 .33087 Mdot
.50744 .33089 Mdot
.50745 .33092 Mdot
.50746 .33094 Mdot
.50747 .33097 Mdot
.50748 .33099 Mdot
.50749 .33102 Mdot
.5075 .33104 Mdot
.5075 .33107 Mdot
.50751 .33109 Mdot
.50752 .33112 Mdot
.50753 .33114 Mdot
.50754 .33117 Mdot
.50755 .33119 Mdot
.50756 .33122 Mdot
.50757 .33124 Mdot
.50758 .33127 Mdot
.50759 .33129 Mdot
.5076 .33132 Mdot
.50761 .33134 Mdot
.50762 .33137 Mdot
.50763 .33139 Mdot
.50764 .33142 Mdot
.50765 .33144 Mdot
.50766 .33147 Mdot
.50767 .33149 Mdot
.50768 .33152 Mdot
.50769 .33154 Mdot
.5077 .33157 Mdot
.5077 .33159 Mdot
.50771 .33162 Mdot
.50772 .33164 Mdot
.50773 .33167 Mdot
.50774 .33169 Mdot
.50775 .33172 Mdot
.50776 .33174 Mdot
.50777 .33177 Mdot
.50778 .33179 Mdot
.50779 .33182 Mdot
.5078 .33184 Mdot
.50781 .33187 Mdot
.50782 .33189 Mdot
.50783 .33192 Mdot
.50784 .33194 Mdot
.50785 .33197 Mdot
.50786 .33199 Mdot
.50787 .33202 Mdot
.50788 .33204 Mdot
.50789 .33207 Mdot
.5079 .33209 Mdot
.5079 .33212 Mdot
.50791 .33214 Mdot
.50792 .33217 Mdot
.50793 .33219 Mdot
.50794 .33222 Mdot
.50795 .33224 Mdot
.50796 .33227 Mdot
.50797 .33229 Mdot
.50798 .33232 Mdot
.50799 .33234 Mdot
.508 .33237 Mdot
.50801 .33239 Mdot
.50802 .33242 Mdot
.50803 .33244 Mdot
.50804 .33247 Mdot
.50805 .33249 Mdot
.50806 .33252 Mdot
.50807 .33254 Mdot
.50808 .33257 Mdot
.50809 .33259 Mdot
.5081 .33262 Mdot
.5081 .33264 Mdot
.50811 .33267 Mdot
.50812 .33269 Mdot
.50813 .33272 Mdot
.50814 .33274 Mdot
.50815 .33277 Mdot
.50816 .33279 Mdot
.50817 .33282 Mdot
.50818 .33284 Mdot
.50819 .33287 Mdot
.5082 .33289 Mdot
.50821 .33292 Mdot
.50822 .33294 Mdot
.50823 .33297 Mdot
.50824 .33299 Mdot
.50825 .33302 Mdot
.50826 .33304 Mdot
.50827 .33307 Mdot
.50828 .33309 Mdot
.50829 .33312 Mdot
.5083 .33314 Mdot
.5083 .33317 Mdot
.50831 .33319 Mdot
.50832 .33322 Mdot
.50833 .33324 Mdot
.50834 .33327 Mdot
.50835 .33329 Mdot
.50836 .33332 Mdot
.50837 .33334 Mdot
.50838 .33337 Mdot
.50839 .33339 Mdot
.5084 .33342 Mdot
.50841 .33344 Mdot
.50842 .33347 Mdot
.50843 .33349 Mdot
.50844 .33352 Mdot
.50845 .33354 Mdot
.50846 .33357 Mdot
.50847 .33359 Mdot
.50848 .33362 Mdot
.50849 .33364 Mdot
.5085 .33367 Mdot
.5085 .33369 Mdot
.50851 .33372 Mdot
.50852 .33374 Mdot
.50853 .33377 Mdot
.50854 .33379 Mdot
.50855 .33382 Mdot
.50856 .33384 Mdot
.50857 .33387 Mdot
.50858 .33389 Mdot
.50859 .33392 Mdot
.5086 .33394 Mdot
.50861 .33396 Mdot
.50862 .33399 Mdot
.50863 .33401 Mdot
.50864 .33404 Mdot
.50865 .33406 Mdot
.50866 .33409 Mdot
.50867 .33411 Mdot
.50868 .33414 Mdot
.50869 .33416 Mdot
.5087 .33419 Mdot
.5087 .33421 Mdot
.50871 .33424 Mdot
.50872 .33426 Mdot
.50873 .33429 Mdot
.50874 .33431 Mdot
.50875 .33434 Mdot
.50876 .33436 Mdot
.50877 .33439 Mdot
.50878 .33441 Mdot
.50879 .33444 Mdot
.5088 .33446 Mdot
.50881 .33449 Mdot
.50882 .33451 Mdot
.50883 .33454 Mdot
.50884 .33456 Mdot
.50885 .33459 Mdot
.50886 .33461 Mdot
.50887 .33464 Mdot
.50888 .33466 Mdot
.50889 .33469 Mdot
.5089 .33471 Mdot
.5089 .33474 Mdot
.50891 .33476 Mdot
.50892 .33479 Mdot
.50893 .33481 Mdot
.50894 .33484 Mdot
.50895 .33486 Mdot
.50896 .33489 Mdot
.50897 .33491 Mdot
.50898 .33494 Mdot
.50899 .33496 Mdot
.509 .33499 Mdot
.50901 .33501 Mdot
.50902 .33504 Mdot
.50903 .33506 Mdot
.50904 .33509 Mdot
.50905 .33511 Mdot
.50906 .33514 Mdot
.50907 .33516 Mdot
.50908 .33518 Mdot
.50909 .33521 Mdot
.5091 .33523 Mdot
.5091 .33526 Mdot
.50911 .33528 Mdot
.50912 .33531 Mdot
.50913 .33533 Mdot
.50914 .33536 Mdot
.50915 .33538 Mdot
.50916 .33541 Mdot
.50917 .33543 Mdot
.50918 .33546 Mdot
.50919 .33548 Mdot
.5092 .33551 Mdot
.50921 .33553 Mdot
.50922 .33556 Mdot
.50923 .33558 Mdot
.50924 .33561 Mdot
.50925 .33563 Mdot
.50926 .33566 Mdot
.50927 .33568 Mdot
.50928 .33571 Mdot
.50929 .33573 Mdot
.5093 .33576 Mdot
.5093 .33578 Mdot
.50931 .33581 Mdot
.50932 .33583 Mdot
.50933 .33586 Mdot
.50934 .33588 Mdot
.50935 .33591 Mdot
.50936 .33593 Mdot
.50937 .33596 Mdot
.50938 .33598 Mdot
.50939 .33601 Mdot
.5094 .33603 Mdot
.50941 .33605 Mdot
.50942 .33608 Mdot
.50943 .3361 Mdot
.50944 .33613 Mdot
.50945 .33615 Mdot
.50946 .33618 Mdot
.50947 .3362 Mdot
.50948 .33623 Mdot
.50949 .33625 Mdot
.5095 .33628 Mdot
.5095 .3363 Mdot
.50951 .33633 Mdot
.50952 .33635 Mdot
.50953 .33638 Mdot
.50954 .3364 Mdot
.50955 .33643 Mdot
.50956 .33645 Mdot
.50957 .33648 Mdot
.50958 .3365 Mdot
.50959 .33653 Mdot
.5096 .33655 Mdot
.50961 .33658 Mdot
.50962 .3366 Mdot
.50963 .33663 Mdot
.50964 .33665 Mdot
.50965 .33668 Mdot
.50966 .3367 Mdot
.50967 .33672 Mdot
.50968 .33675 Mdot
.50969 .33677 Mdot
.5097 .3368 Mdot
.5097 .33682 Mdot
.50971 .33685 Mdot
.50972 .33687 Mdot
.50973 .3369 Mdot
.50974 .33692 Mdot
.50975 .33695 Mdot
.50976 .33697 Mdot
.50977 .337 Mdot
.50978 .33702 Mdot
.50979 .33705 Mdot
.5098 .33707 Mdot
.50981 .3371 Mdot
.50982 .33712 Mdot
.50983 .33715 Mdot
.50984 .33717 Mdot
.50985 .3372 Mdot
.50986 .33722 Mdot
.50987 .33725 Mdot
.50988 .33727 Mdot
.50989 .3373 Mdot
.5099 .33732 Mdot
.5099 .33734 Mdot
.50991 .33737 Mdot
.50992 .33739 Mdot
.50993 .33742 Mdot
.50994 .33744 Mdot
.50995 .33747 Mdot
.50996 .33749 Mdot
.50997 .33752 Mdot
.50998 .33754 Mdot
.50999 .33757 Mdot
.51 .33759 Mdot
.51001 .33762 Mdot
.51002 .33764 Mdot
.51003 .33767 Mdot
.51004 .33769 Mdot
.51005 .33772 Mdot
.51006 .33774 Mdot
.51007 .33777 Mdot
.51008 .33779 Mdot
.51009 .33782 Mdot
.5101 .33784 Mdot
.5101 .33786 Mdot
.51011 .33789 Mdot
.51012 .33791 Mdot
.51013 .33794 Mdot
.51014 .33796 Mdot
.51015 .33799 Mdot
.51016 .33801 Mdot
.51017 .33804 Mdot
.51018 .33806 Mdot
.51019 .33809 Mdot
.5102 .33811 Mdot
.51021 .33814 Mdot
.51022 .33816 Mdot
.51023 .33819 Mdot
.51024 .33821 Mdot
.51025 .33824 Mdot
.51026 .33826 Mdot
.51027 .33829 Mdot
.51028 .33831 Mdot
.51029 .33833 Mdot
.5103 .33836 Mdot
.5103 .33838 Mdot
.51031 .33841 Mdot
.51032 .33843 Mdot
.51033 .33846 Mdot
.51034 .33848 Mdot
.51035 .33851 Mdot
.51036 .33853 Mdot
.51037 .33856 Mdot
.51038 .33858 Mdot
.51039 .33861 Mdot
.5104 .33863 Mdot
.51041 .33866 Mdot
.51042 .33868 Mdot
.51043 .33871 Mdot
.51044 .33873 Mdot
.51045 .33876 Mdot
.51046 .33878 Mdot
.51047 .3388 Mdot
.51048 .33883 Mdot
.51049 .33885 Mdot
.5105 .33888 Mdot
.5105 .3389 Mdot
.51051 .33893 Mdot
.51052 .33895 Mdot
.51053 .33898 Mdot
.51054 .339 Mdot
.51055 .33903 Mdot
.51056 .33905 Mdot
.51057 .33908 Mdot
.51058 .3391 Mdot
.51059 .33913 Mdot
.5106 .33915 Mdot
.51061 .33918 Mdot
.51062 .3392 Mdot
.51063 .33922 Mdot
.51064 .33925 Mdot
.51065 .33927 Mdot
.51066 .3393 Mdot
.51067 .33932 Mdot
.51068 .33935 Mdot
.51069 .33937 Mdot
.5107 .3394 Mdot
.5107 .33942 Mdot
.51071 .33945 Mdot
.51072 .33947 Mdot
.51073 .3395 Mdot
.51074 .33952 Mdot
.51075 .33955 Mdot
.51076 .33957 Mdot
.51077 .33959 Mdot
.51078 .33962 Mdot
.51079 .33964 Mdot
.5108 .33967 Mdot
.51081 .33969 Mdot
.51082 .33972 Mdot
.51083 .33974 Mdot
.51084 .33977 Mdot
.51085 .33979 Mdot
.51086 .33982 Mdot
.51087 .33984 Mdot
.51088 .33987 Mdot
.51089 .33989 Mdot
.5109 .33992 Mdot
.5109 .33994 Mdot
.51091 .33997 Mdot
.51092 .33999 Mdot
.51093 .34001 Mdot
.51094 .34004 Mdot
.51095 .34006 Mdot
.51096 .34009 Mdot
.51097 .34011 Mdot
.51098 .34014 Mdot
.51099 .34016 Mdot
.511 .34019 Mdot
.51101 .34021 Mdot
.51102 .34024 Mdot
.51103 .34026 Mdot
.51104 .34029 Mdot
.51105 .34031 Mdot
.51106 .34033 Mdot
.51107 .34036 Mdot
.51108 .34038 Mdot
.51109 .34041 Mdot
.5111 .34043 Mdot
.5111 .34046 Mdot
.51111 .34048 Mdot
.51112 .34051 Mdot
.51113 .34053 Mdot
.51114 .34056 Mdot
.51115 .34058 Mdot
.51116 .34061 Mdot
.51117 .34063 Mdot
.51118 .34066 Mdot
.51119 .34068 Mdot
.5112 .3407 Mdot
.51121 .34073 Mdot
.51122 .34075 Mdot
.51123 .34078 Mdot
.51124 .3408 Mdot
.51125 .34083 Mdot
.51126 .34085 Mdot
.51127 .34088 Mdot
.51128 .3409 Mdot
.51129 .34093 Mdot
.5113 .34095 Mdot
.5113 .34098 Mdot
.51131 .341 Mdot
.51132 .34102 Mdot
.51133 .34105 Mdot
.51134 .34107 Mdot
.51135 .3411 Mdot
.51136 .34112 Mdot
.51137 .34115 Mdot
.51138 .34117 Mdot
.51139 .3412 Mdot
.5114 .34122 Mdot
.51141 .34125 Mdot
.51142 .34127 Mdot
.51143 .3413 Mdot
.51144 .34132 Mdot
.51145 .34134 Mdot
.51146 .34137 Mdot
.51147 .34139 Mdot
.51148 .34142 Mdot
.51149 .34144 Mdot
.5115 .34147 Mdot
.5115 .34149 Mdot
.51151 .34152 Mdot
.51152 .34154 Mdot
.51153 .34157 Mdot
.51154 .34159 Mdot
.51155 .34162 Mdot
.51156 .34164 Mdot
.51157 .34166 Mdot
.51158 .34169 Mdot
.51159 .34171 Mdot
.5116 .34174 Mdot
.51161 .34176 Mdot
.51162 .34179 Mdot
.51163 .34181 Mdot
.51164 .34184 Mdot
.51165 .34186 Mdot
.51166 .34189 Mdot
.51167 .34191 Mdot
.51168 .34193 Mdot
.51169 .34196 Mdot
.5117 .34198 Mdot
.5117 .34201 Mdot
.51171 .34203 Mdot
.51172 .34206 Mdot
.51173 .34208 Mdot
.51174 .34211 Mdot
.51175 .34213 Mdot
.51176 .34216 Mdot
.51177 .34218 Mdot
.51178 .3422 Mdot
.51179 .34223 Mdot
.5118 .34225 Mdot
.51181 .34228 Mdot
.51182 .3423 Mdot
.51183 .34233 Mdot
.51184 .34235 Mdot
.51185 .34238 Mdot
.51186 .3424 Mdot
.51187 .34243 Mdot
.51188 .34245 Mdot
.51189 .34248 Mdot
.5119 .3425 Mdot
.5119 .34252 Mdot
.51191 .34255 Mdot
.51192 .34257 Mdot
.51193 .3426 Mdot
.51194 .34262 Mdot
.51195 .34265 Mdot
.51196 .34267 Mdot
.51197 .3427 Mdot
.51198 .34272 Mdot
.51199 .34275 Mdot
.512 .34277 Mdot
.51201 .34279 Mdot
.51202 .34282 Mdot
.51203 .34284 Mdot
.51204 .34287 Mdot
.51205 .34289 Mdot
.51206 .34292 Mdot
.51207 .34294 Mdot
.51208 .34297 Mdot
.51209 .34299 Mdot
.5121 .34302 Mdot
.5121 .34304 Mdot
.51211 .34306 Mdot
.51212 .34309 Mdot
.51213 .34311 Mdot
.51214 .34314 Mdot
.51215 .34316 Mdot
.51216 .34319 Mdot
.51217 .34321 Mdot
.51218 .34324 Mdot
.51219 .34326 Mdot
.5122 .34328 Mdot
.51221 .34331 Mdot
.51222 .34333 Mdot
.51223 .34336 Mdot
.51224 .34338 Mdot
.51225 .34341 Mdot
.51226 .34343 Mdot
.51227 .34346 Mdot
.51228 .34348 Mdot
.51229 .34351 Mdot
.5123 .34353 Mdot
.5123 .34355 Mdot
.51231 .34358 Mdot
.51232 .3436 Mdot
.51233 .34363 Mdot
.51234 .34365 Mdot
.51235 .34368 Mdot
.51236 .3437 Mdot
.51237 .34373 Mdot
.51238 .34375 Mdot
.51239 .34377 Mdot
.5124 .3438 Mdot
.51241 .34382 Mdot
.51242 .34385 Mdot
.51243 .34387 Mdot
.51244 .3439 Mdot
.51245 .34392 Mdot
.51246 .34395 Mdot
.51247 .34397 Mdot
.51248 .344 Mdot
.51249 .34402 Mdot
.5125 .34404 Mdot
.5125 .34407 Mdot
.51251 .34409 Mdot
.51252 .34412 Mdot
.51253 .34414 Mdot
.51254 .34417 Mdot
.51255 .34419 Mdot
.51256 .34422 Mdot
.51257 .34424 Mdot
.51258 .34426 Mdot
.51259 .34429 Mdot
.5126 .34431 Mdot
.51261 .34434 Mdot
.51262 .34436 Mdot
.51263 .34439 Mdot
.51264 .34441 Mdot
.51265 .34444 Mdot
.51266 .34446 Mdot
.51267 .34448 Mdot
.51268 .34451 Mdot
.51269 .34453 Mdot
.5127 .34456 Mdot
.5127 .34458 Mdot
.51271 .34461 Mdot
.51272 .34463 Mdot
.51273 .34466 Mdot
.51274 .34468 Mdot
.51275 .34471 Mdot
.51276 .34473 Mdot
.51277 .34475 Mdot
.51278 .34478 Mdot
.51279 .3448 Mdot
.5128 .34483 Mdot
.51281 .34485 Mdot
.51282 .34488 Mdot
.51283 .3449 Mdot
.51284 .34493 Mdot
.51285 .34495 Mdot
.51286 .34497 Mdot
.51287 .345 Mdot
.51288 .34502 Mdot
.51289 .34505 Mdot
.5129 .34507 Mdot
.5129 .3451 Mdot
.51291 .34512 Mdot
.51292 .34515 Mdot
.51293 .34517 Mdot
.51294 .34519 Mdot
.51295 .34522 Mdot
.51296 .34524 Mdot
.51297 .34527 Mdot
.51298 .34529 Mdot
.51299 .34532 Mdot
.513 .34534 Mdot
.51301 .34536 Mdot
.51302 .34539 Mdot
.51303 .34541 Mdot
.51304 .34544 Mdot
.51305 .34546 Mdot
.51306 .34549 Mdot
.51307 .34551 Mdot
.51308 .34554 Mdot
.51309 .34556 Mdot
.5131 .34558 Mdot
.5131 .34561 Mdot
.51311 .34563 Mdot
.51312 .34566 Mdot
.51313 .34568 Mdot
.51314 .34571 Mdot
.51315 .34573 Mdot
.51316 .34576 Mdot
.51317 .34578 Mdot
.51318 .3458 Mdot
.51319 .34583 Mdot
.5132 .34585 Mdot
.51321 .34588 Mdot
.51322 .3459 Mdot
.51323 .34593 Mdot
.51324 .34595 Mdot
.51325 .34598 Mdot
.51326 .346 Mdot
.51327 .34602 Mdot
.51328 .34605 Mdot
.51329 .34607 Mdot
.5133 .3461 Mdot
.5133 .34612 Mdot
.51331 .34615 Mdot
.51332 .34617 Mdot
.51333 .34619 Mdot
.51334 .34622 Mdot
.51335 .34624 Mdot
.51336 .34627 Mdot
.51337 .34629 Mdot
.51338 .34632 Mdot
.51339 .34634 Mdot
.5134 .34637 Mdot
.51341 .34639 Mdot
.51342 .34641 Mdot
.51343 .34644 Mdot
.51344 .34646 Mdot
.51345 .34649 Mdot
.51346 .34651 Mdot
.51347 .34654 Mdot
.51348 .34656 Mdot
.51349 .34658 Mdot
.5135 .34661 Mdot
.5135 .34663 Mdot
.51351 .34666 Mdot
.51352 .34668 Mdot
.51353 .34671 Mdot
.51354 .34673 Mdot
.51355 .34676 Mdot
.51356 .34678 Mdot
.51357 .3468 Mdot
.51358 .34683 Mdot
.51359 .34685 Mdot
.5136 .34688 Mdot
.51361 .3469 Mdot
.51362 .34693 Mdot
.51363 .34695 Mdot
.51364 .34697 Mdot
.51365 .347 Mdot
.51366 .34702 Mdot
.51367 .34705 Mdot
.51368 .34707 Mdot
.51369 .3471 Mdot
.5137 .34712 Mdot
.5137 .34715 Mdot
.51371 .34717 Mdot
.51372 .34719 Mdot
.51373 .34722 Mdot
.51374 .34724 Mdot
.51375 .34727 Mdot
.51376 .34729 Mdot
.51377 .34732 Mdot
.51378 .34734 Mdot
.51379 .34736 Mdot
.5138 .34739 Mdot
.51381 .34741 Mdot
.51382 .34744 Mdot
.51383 .34746 Mdot
.51384 .34749 Mdot
.51385 .34751 Mdot
.51386 .34753 Mdot
.51387 .34756 Mdot
.51388 .34758 Mdot
.51389 .34761 Mdot
.5139 .34763 Mdot
.5139 .34766 Mdot
.51391 .34768 Mdot
.51392 .3477 Mdot
.51393 .34773 Mdot
.51394 .34775 Mdot
.51395 .34778 Mdot
.51396 .3478 Mdot
.51397 .34783 Mdot
.51398 .34785 Mdot
.51399 .34788 Mdot
.514 .3479 Mdot
.51401 .34792 Mdot
.51402 .34795 Mdot
.51403 .34797 Mdot
.51404 .348 Mdot
.51405 .34802 Mdot
.51406 .34805 Mdot
.51407 .34807 Mdot
.51408 .34809 Mdot
.51409 .34812 Mdot
.5141 .34814 Mdot
.5141 .34817 Mdot
.51411 .34819 Mdot
.51412 .34822 Mdot
.51413 .34824 Mdot
.51414 .34826 Mdot
.51415 .34829 Mdot
.51416 .34831 Mdot
.51417 .34834 Mdot
.51418 .34836 Mdot
.51419 .34839 Mdot
.5142 .34841 Mdot
.51421 .34843 Mdot
.51422 .34846 Mdot
.51423 .34848 Mdot
.51424 .34851 Mdot
.51425 .34853 Mdot
.51426 .34856 Mdot
.51427 .34858 Mdot
.51428 .3486 Mdot
.51429 .34863 Mdot
.5143 .34865 Mdot
.5143 .34868 Mdot
.51431 .3487 Mdot
.51432 .34873 Mdot
.51433 .34875 Mdot
.51434 .34877 Mdot
.51435 .3488 Mdot
.51436 .34882 Mdot
.51437 .34885 Mdot
.51438 .34887 Mdot
.51439 .3489 Mdot
.5144 .34892 Mdot
.51441 .34894 Mdot
.51442 .34897 Mdot
.51443 .34899 Mdot
.51444 .34902 Mdot
.51445 .34904 Mdot
.51446 .34907 Mdot
.51447 .34909 Mdot
.51448 .34911 Mdot
.51449 .34914 Mdot
.5145 .34916 Mdot
.5145 .34919 Mdot
.51451 .34921 Mdot
.51452 .34923 Mdot
.51453 .34926 Mdot
.51454 .34928 Mdot
.51455 .34931 Mdot
.51456 .34933 Mdot
.51457 .34936 Mdot
.51458 .34938 Mdot
.51459 .3494 Mdot
.5146 .34943 Mdot
.51461 .34945 Mdot
.51462 .34948 Mdot
.51463 .3495 Mdot
.51464 .34953 Mdot
.51465 .34955 Mdot
.51466 .34957 Mdot
.51467 .3496 Mdot
.51468 .34962 Mdot
.51469 .34965 Mdot
.5147 .34967 Mdot
.5147 .3497 Mdot
.51471 .34972 Mdot
.51472 .34974 Mdot
.51473 .34977 Mdot
.51474 .34979 Mdot
.51475 .34982 Mdot
.51476 .34984 Mdot
.51477 .34987 Mdot
.51478 .34989 Mdot
.51479 .34991 Mdot
.5148 .34994 Mdot
.51481 .34996 Mdot
.51482 .34999 Mdot
.51483 .35001 Mdot
.51484 .35003 Mdot
.51485 .35006 Mdot
.51486 .35008 Mdot
.51487 .35011 Mdot
.51488 .35013 Mdot
.51489 .35016 Mdot
.5149 .35018 Mdot
.5149 .3502 Mdot
.51491 .35023 Mdot
.51492 .35025 Mdot
.51493 .35028 Mdot
.51494 .3503 Mdot
.51495 .35033 Mdot
.51496 .35035 Mdot
.51497 .35037 Mdot
.51498 .3504 Mdot
.51499 .35042 Mdot
.515 .35045 Mdot
.51501 .35047 Mdot
.51502 .35049 Mdot
.51503 .35052 Mdot
.51504 .35054 Mdot
.51505 .35057 Mdot
.51506 .35059 Mdot
.51507 .35062 Mdot
.51508 .35064 Mdot
.51509 .35066 Mdot
.5151 .35069 Mdot
.5151 .35071 Mdot
.51511 .35074 Mdot
.51512 .35076 Mdot
.51513 .35078 Mdot
.51514 .35081 Mdot
.51515 .35083 Mdot
.51516 .35086 Mdot
.51517 .35088 Mdot
.51518 .35091 Mdot
.51519 .35093 Mdot
.5152 .35095 Mdot
.51521 .35098 Mdot
.51522 .351 Mdot
.51523 .35103 Mdot
.51524 .35105 Mdot
.51525 .35108 Mdot
.51526 .3511 Mdot
.51527 .35112 Mdot
.51528 .35115 Mdot
.51529 .35117 Mdot
.5153 .3512 Mdot
.5153 .35122 Mdot
.51531 .35124 Mdot
.51532 .35127 Mdot
.51533 .35129 Mdot
.51534 .35132 Mdot
.51535 .35134 Mdot
.51536 .35137 Mdot
.51537 .35139 Mdot
.51538 .35141 Mdot
.51539 .35144 Mdot
.5154 .35146 Mdot
.51541 .35149 Mdot
.51542 .35151 Mdot
.51543 .35153 Mdot
.51544 .35156 Mdot
.51545 .35158 Mdot
.51546 .35161 Mdot
.51547 .35163 Mdot
.51548 .35165 Mdot
.51549 .35168 Mdot
.5155 .3517 Mdot
.5155 .35173 Mdot
.51551 .35175 Mdot
.51552 .35178 Mdot
.51553 .3518 Mdot
.51554 .35182 Mdot
.51555 .35185 Mdot
.51556 .35187 Mdot
.51557 .3519 Mdot
.51558 .35192 Mdot
.51559 .35194 Mdot
.5156 .35197 Mdot
.51561 .35199 Mdot
.51562 .35202 Mdot
.51563 .35204 Mdot
.51564 .35207 Mdot
.51565 .35209 Mdot
.51566 .35211 Mdot
.51567 .35214 Mdot
.51568 .35216 Mdot
.51569 .35219 Mdot
.5157 .35221 Mdot
.5157 .35223 Mdot
.51571 .35226 Mdot
.51572 .35228 Mdot
.51573 .35231 Mdot
.51574 .35233 Mdot
.51575 .35235 Mdot
.51576 .35238 Mdot
.51577 .3524 Mdot
.51578 .35243 Mdot
.51579 .35245 Mdot
.5158 .35248 Mdot
.51581 .3525 Mdot
.51582 .35252 Mdot
.51583 .35255 Mdot
.51584 .35257 Mdot
.51585 .3526 Mdot
.51586 .35262 Mdot
.51587 .35264 Mdot
.51588 .35267 Mdot
.51589 .35269 Mdot
.5159 .35272 Mdot
.5159 .35274 Mdot
.51591 .35276 Mdot
.51592 .35279 Mdot
.51593 .35281 Mdot
.51594 .35284 Mdot
.51595 .35286 Mdot
.51596 .35288 Mdot
.51597 .35291 Mdot
.51598 .35293 Mdot
.51599 .35296 Mdot
.516 .35298 Mdot
.51601 .35301 Mdot
.51602 .35303 Mdot
.51603 .35305 Mdot
.51604 .35308 Mdot
.51605 .3531 Mdot
.51606 .35313 Mdot
.51607 .35315 Mdot
.51608 .35317 Mdot
.51609 .3532 Mdot
.5161 .35322 Mdot
.5161 .35325 Mdot
.51611 .35327 Mdot
.51612 .35329 Mdot
.51613 .35332 Mdot
.51614 .35334 Mdot
.51615 .35337 Mdot
.51616 .35339 Mdot
.51617 .35341 Mdot
.51618 .35344 Mdot
.51619 .35346 Mdot
.5162 .35349 Mdot
.51621 .35351 Mdot
.51622 .35353 Mdot
.51623 .35356 Mdot
.51624 .35358 Mdot
.51625 .35361 Mdot
.51626 .35363 Mdot
.51627 .35366 Mdot
.51628 .35368 Mdot
.51629 .3537 Mdot
.5163 .35373 Mdot
.5163 .35375 Mdot
.51631 .35378 Mdot
.51632 .3538 Mdot
.51633 .35382 Mdot
.51634 .35385 Mdot
.51635 .35387 Mdot
.51636 .3539 Mdot
.51637 .35392 Mdot
.51638 .35394 Mdot
.51639 .35397 Mdot
.5164 .35399 Mdot
.51641 .35402 Mdot
.51642 .35404 Mdot
.51643 .35406 Mdot
.51644 .35409 Mdot
.51645 .35411 Mdot
.51646 .35414 Mdot
.51647 .35416 Mdot
.51648 .35418 Mdot
.51649 .35421 Mdot
.5165 .35423 Mdot
.5165 .35426 Mdot
.51651 .35428 Mdot
.51652 .3543 Mdot
.51653 .35433 Mdot
.51654 .35435 Mdot
.51655 .35438 Mdot
.51656 .3544 Mdot
.51657 .35442 Mdot
.51658 .35445 Mdot
.51659 .35447 Mdot
.5166 .3545 Mdot
.51661 .35452 Mdot
.51662 .35454 Mdot
.51663 .35457 Mdot
.51664 .35459 Mdot
.51665 .35462 Mdot
.51666 .35464 Mdot
.51667 .35466 Mdot
.51668 .35469 Mdot
.51669 .35471 Mdot
.5167 .35474 Mdot
.5167 .35476 Mdot
.51671 .35478 Mdot
.51672 .35481 Mdot
.51673 .35483 Mdot
.51674 .35486 Mdot
.51675 .35488 Mdot
.51676 .3549 Mdot
.51677 .35493 Mdot
.51678 .35495 Mdot
.51679 .35498 Mdot
.5168 .355 Mdot
.51681 .35502 Mdot
.51682 .35505 Mdot
.51683 .35507 Mdot
.51684 .3551 Mdot
.51685 .35512 Mdot
.51686 .35514 Mdot
.51687 .35517 Mdot
.51688 .35519 Mdot
.51689 .35522 Mdot
.5169 .35524 Mdot
.5169 .35526 Mdot
.51691 .35529 Mdot
.51692 .35531 Mdot
.51693 .35534 Mdot
.51694 .35536 Mdot
.51695 .35538 Mdot
.51696 .35541 Mdot
.51697 .35543 Mdot
.51698 .35546 Mdot
.51699 .35548 Mdot
.517 .3555 Mdot
.51701 .35553 Mdot
.51702 .35555 Mdot
.51703 .35558 Mdot
.51704 .3556 Mdot
.51705 .35562 Mdot
.51706 .35565 Mdot
.51707 .35567 Mdot
.51708 .3557 Mdot
.51709 .35572 Mdot
.5171 .35574 Mdot
.5171 .35577 Mdot
.51711 .35579 Mdot
.51712 .35582 Mdot
.51713 .35584 Mdot
.51714 .35586 Mdot
.51715 .35589 Mdot
.51716 .35591 Mdot
.51717 .35594 Mdot
.51718 .35596 Mdot
.51719 .35598 Mdot
.5172 .35601 Mdot
.51721 .35603 Mdot
.51722 .35606 Mdot
.51723 .35608 Mdot
.51724 .3561 Mdot
.51725 .35613 Mdot
.51726 .35615 Mdot
.51727 .35617 Mdot
.51728 .3562 Mdot
.51729 .35622 Mdot
.5173 .35625 Mdot
.5173 .35627 Mdot
.51731 .35629 Mdot
.51732 .35632 Mdot
.51733 .35634 Mdot
.51734 .35637 Mdot
.51735 .35639 Mdot
.51736 .35641 Mdot
.51737 .35644 Mdot
.51738 .35646 Mdot
.51739 .35649 Mdot
.5174 .35651 Mdot
.51741 .35653 Mdot
.51742 .35656 Mdot
.51743 .35658 Mdot
.51744 .35661 Mdot
.51745 .35663 Mdot
.51746 .35665 Mdot
.51747 .35668 Mdot
.51748 .3567 Mdot
.51749 .35673 Mdot
.5175 .35675 Mdot
.5175 .35677 Mdot
.51751 .3568 Mdot
.51752 .35682 Mdot
.51753 .35684 Mdot
.51754 .35687 Mdot
.51755 .35689 Mdot
.51756 .35692 Mdot
.51757 .35694 Mdot
.51758 .35696 Mdot
.51759 .35699 Mdot
.5176 .35701 Mdot
.51761 .35704 Mdot
.51762 .35706 Mdot
.51763 .35708 Mdot
.51764 .35711 Mdot
.51765 .35713 Mdot
.51766 .35716 Mdot
.51767 .35718 Mdot
.51768 .3572 Mdot
.51769 .35723 Mdot
.5177 .35725 Mdot
.5177 .35727 Mdot
.51771 .3573 Mdot
.51772 .35732 Mdot
.51773 .35735 Mdot
.51774 .35737 Mdot
.51775 .35739 Mdot
.51776 .35742 Mdot
.51777 .35744 Mdot
.51778 .35747 Mdot
.51779 .35749 Mdot
.5178 .35751 Mdot
.51781 .35754 Mdot
.51782 .35756 Mdot
.51783 .35759 Mdot
.51784 .35761 Mdot
.51785 .35763 Mdot
.51786 .35766 Mdot
.51787 .35768 Mdot
.51788 .3577 Mdot
.51789 .35773 Mdot
.5179 .35775 Mdot
.5179 .35778 Mdot
.51791 .3578 Mdot
.51792 .35782 Mdot
.51793 .35785 Mdot
.51794 .35787 Mdot
.51795 .3579 Mdot
.51796 .35792 Mdot
.51797 .35794 Mdot
.51798 .35797 Mdot
.51799 .35799 Mdot
.518 .35801 Mdot
.51801 .35804 Mdot
.51802 .35806 Mdot
.51803 .35809 Mdot
.51804 .35811 Mdot
.51805 .35813 Mdot
.51806 .35816 Mdot
.51807 .35818 Mdot
.51808 .35821 Mdot
.51809 .35823 Mdot
.5181 .35825 Mdot
.5181 .35828 Mdot
.51811 .3583 Mdot
.51812 .35833 Mdot
.51813 .35835 Mdot
.51814 .35837 Mdot
.51815 .3584 Mdot
.51816 .35842 Mdot
.51817 .35844 Mdot
.51818 .35847 Mdot
.51819 .35849 Mdot
.5182 .35852 Mdot
.51821 .35854 Mdot
.51822 .35856 Mdot
.51823 .35859 Mdot
.51824 .35861 Mdot
.51825 .35863 Mdot
.51826 .35866 Mdot
.51827 .35868 Mdot
.51828 .35871 Mdot
.51829 .35873 Mdot
.5183 .35875 Mdot
.5183 .35878 Mdot
.51831 .3588 Mdot
.51832 .35883 Mdot
.51833 .35885 Mdot
.51834 .35887 Mdot
.51835 .3589 Mdot
.51836 .35892 Mdot
.51837 .35894 Mdot
.51838 .35897 Mdot
.51839 .35899 Mdot
.5184 .35902 Mdot
.51841 .35904 Mdot
.51842 .35906 Mdot
.51843 .35909 Mdot
.51844 .35911 Mdot
.51845 .35914 Mdot
.51846 .35916 Mdot
.51847 .35918 Mdot
.51848 .35921 Mdot
.51849 .35923 Mdot
.5185 .35925 Mdot
.5185 .35928 Mdot
.51851 .3593 Mdot
.51852 .35933 Mdot
.51853 .35935 Mdot
.51854 .35937 Mdot
.51855 .3594 Mdot
.51856 .35942 Mdot
.51857 .35944 Mdot
.51858 .35947 Mdot
.51859 .35949 Mdot
.5186 .35952 Mdot
.51861 .35954 Mdot
.51862 .35956 Mdot
.51863 .35959 Mdot
.51864 .35961 Mdot
.51865 .35963 Mdot
.51866 .35966 Mdot
.51867 .35968 Mdot
.51868 .35971 Mdot
.51869 .35973 Mdot
.5187 .35975 Mdot
.5187 .35978 Mdot
.51871 .3598 Mdot
.51872 .35982 Mdot
.51873 .35985 Mdot
.51874 .35987 Mdot
.51875 .3599 Mdot
.51876 .35992 Mdot
.51877 .35994 Mdot
.51878 .35997 Mdot
.51879 .35999 Mdot
.5188 .36002 Mdot
.51881 .36004 Mdot
.51882 .36006 Mdot
.51883 .36009 Mdot
.51884 .36011 Mdot
.51885 .36013 Mdot
.51886 .36016 Mdot
.51887 .36018 Mdot
.51888 .36021 Mdot
.51889 .36023 Mdot
.5189 .36025 Mdot
.5189 .36028 Mdot
.51891 .3603 Mdot
.51892 .36032 Mdot
.51893 .36035 Mdot
.51894 .36037 Mdot
.51895 .3604 Mdot
.51896 .36042 Mdot
.51897 .36044 Mdot
.51898 .36047 Mdot
.51899 .36049 Mdot
.519 .36051 Mdot
.51901 .36054 Mdot
.51902 .36056 Mdot
.51903 .36059 Mdot
.51904 .36061 Mdot
.51905 .36063 Mdot
.51906 .36066 Mdot
.51907 .36068 Mdot
.51908 .3607 Mdot
.51909 .36073 Mdot
.5191 .36075 Mdot
.5191 .36077 Mdot
.51911 .3608 Mdot
.51912 .36082 Mdot
.51913 .36085 Mdot
.51914 .36087 Mdot
.51915 .36089 Mdot
.51916 .36092 Mdot
.51917 .36094 Mdot
.51918 .36096 Mdot
.51919 .36099 Mdot
.5192 .36101 Mdot
.51921 .36104 Mdot
.51922 .36106 Mdot
.51923 .36108 Mdot
.51924 .36111 Mdot
.51925 .36113 Mdot
.51926 .36115 Mdot
.51927 .36118 Mdot
.51928 .3612 Mdot
.51929 .36123 Mdot
.5193 .36125 Mdot
.5193 .36127 Mdot
.51931 .3613 Mdot
.51932 .36132 Mdot
.51933 .36134 Mdot
.51934 .36137 Mdot
.51935 .36139 Mdot
.51936 .36142 Mdot
.51937 .36144 Mdot
.51938 .36146 Mdot
.51939 .36149 Mdot
.5194 .36151 Mdot
.51941 .36153 Mdot
.51942 .36156 Mdot
.51943 .36158 Mdot
.51944 .3616 Mdot
.51945 .36163 Mdot
.51946 .36165 Mdot
.51947 .36168 Mdot
.51948 .3617 Mdot
.51949 .36172 Mdot
.5195 .36175 Mdot
.5195 .36177 Mdot
.51951 .36179 Mdot
.51952 .36182 Mdot
.51953 .36184 Mdot
.51954 .36187 Mdot
.51955 .36189 Mdot
.51956 .36191 Mdot
.51957 .36194 Mdot
.51958 .36196 Mdot
.51959 .36198 Mdot
.5196 .36201 Mdot
.51961 .36203 Mdot
.51962 .36205 Mdot
.51963 .36208 Mdot
.51964 .3621 Mdot
.51965 .36213 Mdot
.51966 .36215 Mdot
.51967 .36217 Mdot
.51968 .3622 Mdot
.51969 .36222 Mdot
.5197 .36224 Mdot
.5197 .36227 Mdot
.51971 .36229 Mdot
.51972 .36231 Mdot
.51973 .36234 Mdot
.51974 .36236 Mdot
.51975 .36239 Mdot
.51976 .36241 Mdot
.51977 .36243 Mdot
.51978 .36246 Mdot
.51979 .36248 Mdot
.5198 .3625 Mdot
.51981 .36253 Mdot
.51982 .36255 Mdot
.51983 .36258 Mdot
.51984 .3626 Mdot
.51985 .36262 Mdot
.51986 .36265 Mdot
.51987 .36267 Mdot
.51988 .36269 Mdot
.51989 .36272 Mdot
.5199 .36274 Mdot
.5199 .36276 Mdot
.51991 .36279 Mdot
.51992 .36281 Mdot
.51993 .36284 Mdot
.51994 .36286 Mdot
.51995 .36288 Mdot
.51996 .36291 Mdot
.51997 .36293 Mdot
.51998 .36295 Mdot
.51999 .36298 Mdot
.52 .363 Mdot
.52001 .36302 Mdot
.52002 .36305 Mdot
.52003 .36307 Mdot
.52004 .3631 Mdot
.52005 .36312 Mdot
.52006 .36314 Mdot
.52007 .36317 Mdot
.52008 .36319 Mdot
.52009 .36321 Mdot
.5201 .36324 Mdot
.5201 .36326 Mdot
.52011 .36328 Mdot
.52012 .36331 Mdot
.52013 .36333 Mdot
.52014 .36335 Mdot
.52015 .36338 Mdot
.52016 .3634 Mdot
.52017 .36343 Mdot
.52018 .36345 Mdot
.52019 .36347 Mdot
.5202 .3635 Mdot
.52021 .36352 Mdot
.52022 .36354 Mdot
.52023 .36357 Mdot
.52024 .36359 Mdot
.52025 .36361 Mdot
.52026 .36364 Mdot
.52027 .36366 Mdot
.52028 .36369 Mdot
.52029 .36371 Mdot
.5203 .36373 Mdot
.5203 .36376 Mdot
.52031 .36378 Mdot
.52032 .3638 Mdot
.52033 .36383 Mdot
.52034 .36385 Mdot
.52035 .36387 Mdot
.52036 .3639 Mdot
.52037 .36392 Mdot
.52038 .36394 Mdot
.52039 .36397 Mdot
.5204 .36399 Mdot
.52041 .36402 Mdot
.52042 .36404 Mdot
.52043 .36406 Mdot
.52044 .36409 Mdot
.52045 .36411 Mdot
.52046 .36413 Mdot
.52047 .36416 Mdot
.52048 .36418 Mdot
.52049 .3642 Mdot
.5205 .36423 Mdot
.5205 .36425 Mdot
.52051 .36427 Mdot
.52052 .3643 Mdot
.52053 .36432 Mdot
.52054 .36435 Mdot
.52055 .36437 Mdot
.52056 .36439 Mdot
.52057 .36442 Mdot
.52058 .36444 Mdot
.52059 .36446 Mdot
.5206 .36449 Mdot
.52061 .36451 Mdot
.52062 .36453 Mdot
.52063 .36456 Mdot
.52064 .36458 Mdot
.52065 .3646 Mdot
.52066 .36463 Mdot
.52067 .36465 Mdot
.52068 .36468 Mdot
.52069 .3647 Mdot
.5207 .36472 Mdot
.5207 .36475 Mdot
.52071 .36477 Mdot
.52072 .36479 Mdot
.52073 .36482 Mdot
.52074 .36484 Mdot
.52075 .36486 Mdot
.52076 .36489 Mdot
.52077 .36491 Mdot
.52078 .36493 Mdot
.52079 .36496 Mdot
.5208 .36498 Mdot
.52081 .365 Mdot
.52082 .36503 Mdot
.52083 .36505 Mdot
.52084 .36508 Mdot
.52085 .3651 Mdot
.52086 .36512 Mdot
.52087 .36515 Mdot
.52088 .36517 Mdot
.52089 .36519 Mdot
.5209 .36522 Mdot
.5209 .36524 Mdot
.52091 .36526 Mdot
.52092 .36529 Mdot
.52093 .36531 Mdot
.52094 .36533 Mdot
.52095 .36536 Mdot
.52096 .36538 Mdot
.52097 .3654 Mdot
.52098 .36543 Mdot
.52099 .36545 Mdot
.521 .36548 Mdot
.52101 .3655 Mdot
.52102 .36552 Mdot
.52103 .36555 Mdot
.52104 .36557 Mdot
.52105 .36559 Mdot
.52106 .36562 Mdot
.52107 .36564 Mdot
.52108 .36566 Mdot
.52109 .36569 Mdot
.5211 .36571 Mdot
.5211 .36573 Mdot
.52111 .36576 Mdot
.52112 .36578 Mdot
.52113 .3658 Mdot
.52114 .36583 Mdot
.52115 .36585 Mdot
.52116 .36587 Mdot
.52117 .3659 Mdot
.52118 .36592 Mdot
.52119 .36595 Mdot
.5212 .36597 Mdot
.52121 .36599 Mdot
.52122 .36602 Mdot
.52123 .36604 Mdot
.52124 .36606 Mdot
.52125 .36609 Mdot
.52126 .36611 Mdot
.52127 .36613 Mdot
.52128 .36616 Mdot
.52129 .36618 Mdot
.5213 .3662 Mdot
.5213 .36623 Mdot
.52131 .36625 Mdot
.52132 .36627 Mdot
.52133 .3663 Mdot
.52134 .36632 Mdot
.52135 .36634 Mdot
.52136 .36637 Mdot
.52137 .36639 Mdot
.52138 .36641 Mdot
.52139 .36644 Mdot
.5214 .36646 Mdot
.52141 .36649 Mdot
.52142 .36651 Mdot
.52143 .36653 Mdot
.52144 .36656 Mdot
.52145 .36658 Mdot
.52146 .3666 Mdot
.52147 .36663 Mdot
.52148 .36665 Mdot
.52149 .36667 Mdot
.5215 .3667 Mdot
.5215 .36672 Mdot
.52151 .36674 Mdot
.52152 .36677 Mdot
.52153 .36679 Mdot
.52154 .36681 Mdot
.52155 .36684 Mdot
.52156 .36686 Mdot
.52157 .36688 Mdot
.52158 .36691 Mdot
.52159 .36693 Mdot
.5216 .36695 Mdot
.52161 .36698 Mdot
.52162 .367 Mdot
.52163 .36702 Mdot
.52164 .36705 Mdot
.52165 .36707 Mdot
.52166 .36709 Mdot
.52167 .36712 Mdot
.52168 .36714 Mdot
.52169 .36717 Mdot
.5217 .36719 Mdot
.5217 .36721 Mdot
.52171 .36724 Mdot
.52172 .36726 Mdot
.52173 .36728 Mdot
.52174 .36731 Mdot
.52175 .36733 Mdot
.52176 .36735 Mdot
.52177 .36738 Mdot
.52178 .3674 Mdot
.52179 .36742 Mdot
.5218 .36745 Mdot
.52181 .36747 Mdot
.52182 .36749 Mdot
.52183 .36752 Mdot
.52184 .36754 Mdot
.52185 .36756 Mdot
.52186 .36759 Mdot
.52187 .36761 Mdot
.52188 .36763 Mdot
.52189 .36766 Mdot
.5219 .36768 Mdot
.5219 .3677 Mdot
.52191 .36773 Mdot
.52192 .36775 Mdot
.52193 .36777 Mdot
.52194 .3678 Mdot
.52195 .36782 Mdot
.52196 .36784 Mdot
.52197 .36787 Mdot
.52198 .36789 Mdot
.52199 .36791 Mdot
.522 .36794 Mdot
.52201 .36796 Mdot
.52202 .36798 Mdot
.52203 .36801 Mdot
.52204 .36803 Mdot
.52205 .36805 Mdot
.52206 .36808 Mdot
.52207 .3681 Mdot
.52208 .36812 Mdot
.52209 .36815 Mdot
.5221 .36817 Mdot
.5221 .36819 Mdot
.52211 .36822 Mdot
.52212 .36824 Mdot
.52213 .36827 Mdot
.52214 .36829 Mdot
.52215 .36831 Mdot
.52216 .36834 Mdot
.52217 .36836 Mdot
.52218 .36838 Mdot
.52219 .36841 Mdot
.5222 .36843 Mdot
.52221 .36845 Mdot
.52222 .36848 Mdot
.52223 .3685 Mdot
.52224 .36852 Mdot
.52225 .36855 Mdot
.52226 .36857 Mdot
.52227 .36859 Mdot
.52228 .36862 Mdot
.52229 .36864 Mdot
.5223 .36866 Mdot
.5223 .36869 Mdot
.52231 .36871 Mdot
.52232 .36873 Mdot
.52233 .36876 Mdot
.52234 .36878 Mdot
.52235 .3688 Mdot
.52236 .36883 Mdot
.52237 .36885 Mdot
.52238 .36887 Mdot
.52239 .3689 Mdot
.5224 .36892 Mdot
.52241 .36894 Mdot
.52242 .36897 Mdot
.52243 .36899 Mdot
.52244 .36901 Mdot
.52245 .36904 Mdot
.52246 .36906 Mdot
.52247 .36908 Mdot
.52248 .36911 Mdot
.52249 .36913 Mdot
.5225 .36915 Mdot
.5225 .36918 Mdot
.52251 .3692 Mdot
.52252 .36922 Mdot
.52253 .36925 Mdot
.52254 .36927 Mdot
.52255 .36929 Mdot
.52256 .36932 Mdot
.52257 .36934 Mdot
.52258 .36936 Mdot
.52259 .36939 Mdot
.5226 .36941 Mdot
.52261 .36943 Mdot
.52262 .36946 Mdot
.52263 .36948 Mdot
.52264 .3695 Mdot
.52265 .36953 Mdot
.52266 .36955 Mdot
.52267 .36957 Mdot
.52268 .3696 Mdot
.52269 .36962 Mdot
.5227 .36964 Mdot
.5227 .36967 Mdot
.52271 .36969 Mdot
.52272 .36971 Mdot
.52273 .36974 Mdot
.52274 .36976 Mdot
.52275 .36978 Mdot
.52276 .36981 Mdot
.52277 .36983 Mdot
.52278 .36985 Mdot
.52279 .36988 Mdot
.5228 .3699 Mdot
.52281 .36992 Mdot
.52282 .36995 Mdot
.52283 .36997 Mdot
.52284 .36999 Mdot
.52285 .37002 Mdot
.52286 .37004 Mdot
.52287 .37006 Mdot
.52288 .37009 Mdot
.52289 .37011 Mdot
.5229 .37013 Mdot
.5229 .37016 Mdot
.52291 .37018 Mdot
.52292 .3702 Mdot
.52293 .37023 Mdot
.52294 .37025 Mdot
.52295 .37027 Mdot
.52296 .37029 Mdot
.52297 .37032 Mdot
.52298 .37034 Mdot
.52299 .37036 Mdot
.523 .37039 Mdot
.52301 .37041 Mdot
.52302 .37043 Mdot
.52303 .37046 Mdot
.52304 .37048 Mdot
.52305 .3705 Mdot
.52306 .37053 Mdot
.52307 .37055 Mdot
.52308 .37057 Mdot
.52309 .3706 Mdot
.5231 .37062 Mdot
.5231 .37064 Mdot
.52311 .37067 Mdot
.52312 .37069 Mdot
.52313 .37071 Mdot
.52314 .37074 Mdot
.52315 .37076 Mdot
.52316 .37078 Mdot
.52317 .37081 Mdot
.52318 .37083 Mdot
.52319 .37085 Mdot
.5232 .37088 Mdot
.52321 .3709 Mdot
.52322 .37092 Mdot
.52323 .37095 Mdot
.52324 .37097 Mdot
.52325 .37099 Mdot
.52326 .37102 Mdot
.52327 .37104 Mdot
.52328 .37106 Mdot
.52329 .37109 Mdot
.5233 .37111 Mdot
.5233 .37113 Mdot
.52331 .37116 Mdot
.52332 .37118 Mdot
.52333 .3712 Mdot
.52334 .37123 Mdot
.52335 .37125 Mdot
.52336 .37127 Mdot
.52337 .3713 Mdot
.52338 .37132 Mdot
.52339 .37134 Mdot
.5234 .37136 Mdot
.52341 .37139 Mdot
.52342 .37141 Mdot
.52343 .37143 Mdot
.52344 .37146 Mdot
.52345 .37148 Mdot
.52346 .3715 Mdot
.52347 .37153 Mdot
.52348 .37155 Mdot
.52349 .37157 Mdot
.5235 .3716 Mdot
.5235 .37162 Mdot
.52351 .37164 Mdot
.52352 .37167 Mdot
.52353 .37169 Mdot
.52354 .37171 Mdot
.52355 .37174 Mdot
.52356 .37176 Mdot
.52357 .37178 Mdot
.52358 .37181 Mdot
.52359 .37183 Mdot
.5236 .37185 Mdot
.52361 .37188 Mdot
.52362 .3719 Mdot
.52363 .37192 Mdot
.52364 .37195 Mdot
.52365 .37197 Mdot
.52366 .37199 Mdot
.52367 .37201 Mdot
.52368 .37204 Mdot
.52369 .37206 Mdot
.5237 .37208 Mdot
.5237 .37211 Mdot
.52371 .37213 Mdot
.52372 .37215 Mdot
.52373 .37218 Mdot
.52374 .3722 Mdot
.52375 .37222 Mdot
.52376 .37225 Mdot
.52377 .37227 Mdot
.52378 .37229 Mdot
.52379 .37232 Mdot
.5238 .37234 Mdot
.52381 .37236 Mdot
.52382 .37239 Mdot
.52383 .37241 Mdot
.52384 .37243 Mdot
.52385 .37246 Mdot
.52386 .37248 Mdot
.52387 .3725 Mdot
.52388 .37252 Mdot
.52389 .37255 Mdot
.5239 .37257 Mdot
.5239 .37259 Mdot
.52391 .37262 Mdot
.52392 .37264 Mdot
.52393 .37266 Mdot
.52394 .37269 Mdot
.52395 .37271 Mdot
.52396 .37273 Mdot
.52397 .37276 Mdot
.52398 .37278 Mdot
.52399 .3728 Mdot
.524 .37283 Mdot
.52401 .37285 Mdot
.52402 .37287 Mdot
.52403 .3729 Mdot
.52404 .37292 Mdot
.52405 .37294 Mdot
.52406 .37297 Mdot
.52407 .37299 Mdot
.52408 .37301 Mdot
.52409 .37303 Mdot
.5241 .37306 Mdot
.5241 .37308 Mdot
.52411 .3731 Mdot
.52412 .37313 Mdot
.52413 .37315 Mdot
.52414 .37317 Mdot
.52415 .3732 Mdot
.52416 .37322 Mdot
.52417 .37324 Mdot
.52418 .37327 Mdot
.52419 .37329 Mdot
.5242 .37331 Mdot
.52421 .37334 Mdot
.52422 .37336 Mdot
.52423 .37338 Mdot
.52424 .3734 Mdot
.52425 .37343 Mdot
.52426 .37345 Mdot
.52427 .37347 Mdot
.52428 .3735 Mdot
.52429 .37352 Mdot
.5243 .37354 Mdot
.5243 .37357 Mdot
.52431 .37359 Mdot
.52432 .37361 Mdot
.52433 .37364 Mdot
.52434 .37366 Mdot
.52435 .37368 Mdot
.52436 .37371 Mdot
.52437 .37373 Mdot
.52438 .37375 Mdot
.52439 .37377 Mdot
.5244 .3738 Mdot
.52441 .37382 Mdot
.52442 .37384 Mdot
.52443 .37387 Mdot
.52444 .37389 Mdot
.52445 .37391 Mdot
.52446 .37394 Mdot
.52447 .37396 Mdot
.52448 .37398 Mdot
.52449 .37401 Mdot
.5245 .37403 Mdot
.5245 .37405 Mdot
.52451 .37408 Mdot
.52452 .3741 Mdot
.52453 .37412 Mdot
.52454 .37414 Mdot
.52455 .37417 Mdot
.52456 .37419 Mdot
.52457 .37421 Mdot
.52458 .37424 Mdot
.52459 .37426 Mdot
.5246 .37428 Mdot
.52461 .37431 Mdot
.52462 .37433 Mdot
.52463 .37435 Mdot
.52464 .37438 Mdot
.52465 .3744 Mdot
.52466 .37442 Mdot
.52467 .37444 Mdot
.52468 .37447 Mdot
.52469 .37449 Mdot
.5247 .37451 Mdot
.5247 .37454 Mdot
.52471 .37456 Mdot
.52472 .37458 Mdot
.52473 .37461 Mdot
.52474 .37463 Mdot
.52475 .37465 Mdot
.52476 .37468 Mdot
.52477 .3747 Mdot
.52478 .37472 Mdot
.52479 .37474 Mdot
.5248 .37477 Mdot
.52481 .37479 Mdot
.52482 .37481 Mdot
.52483 .37484 Mdot
.52484 .37486 Mdot
.52485 .37488 Mdot
.52486 .37491 Mdot
.52487 .37493 Mdot
.52488 .37495 Mdot
.52489 .37498 Mdot
.5249 .375 Mdot
.5249 .37502 Mdot
.52491 .37504 Mdot
.52492 .37507 Mdot
.52493 .37509 Mdot
.52494 .37511 Mdot
.52495 .37514 Mdot
.52496 .37516 Mdot
.52497 .37518 Mdot
.52498 .37521 Mdot
.52499 .37523 Mdot
.525 .37525 Mdot
.52501 .37528 Mdot
.52502 .3753 Mdot
.52503 .37532 Mdot
.52504 .37534 Mdot
.52505 .37537 Mdot
.52506 .37539 Mdot
.52507 .37541 Mdot
.52508 .37544 Mdot
.52509 .37546 Mdot
.5251 .37548 Mdot
.5251 .37551 Mdot
.52511 .37553 Mdot
.52512 .37555 Mdot
.52513 .37557 Mdot
.52514 .3756 Mdot
.52515 .37562 Mdot
.52516 .37564 Mdot
.52517 .37567 Mdot
.52518 .37569 Mdot
.52519 .37571 Mdot
.5252 .37574 Mdot
.52521 .37576 Mdot
.52522 .37578 Mdot
.52523 .3758 Mdot
.52524 .37583 Mdot
.52525 .37585 Mdot
.52526 .37587 Mdot
.52527 .3759 Mdot
.52528 .37592 Mdot
.52529 .37594 Mdot
.5253 .37597 Mdot
.5253 .37599 Mdot
.52531 .37601 Mdot
.52532 .37604 Mdot
.52533 .37606 Mdot
.52534 .37608 Mdot
.52535 .3761 Mdot
.52536 .37613 Mdot
.52537 .37615 Mdot
.52538 .37617 Mdot
.52539 .3762 Mdot
.5254 .37622 Mdot
.52541 .37624 Mdot
.52542 .37627 Mdot
.52543 .37629 Mdot
.52544 .37631 Mdot
.52545 .37633 Mdot
.52546 .37636 Mdot
.52547 .37638 Mdot
.52548 .3764 Mdot
.52549 .37643 Mdot
.5255 .37645 Mdot
.5255 .37647 Mdot
.52551 .3765 Mdot
.52552 .37652 Mdot
.52553 .37654 Mdot
.52554 .37656 Mdot
.52555 .37659 Mdot
.52556 .37661 Mdot
.52557 .37663 Mdot
.52558 .37666 Mdot
.52559 .37668 Mdot
.5256 .3767 Mdot
.52561 .37672 Mdot
.52562 .37675 Mdot
.52563 .37677 Mdot
.52564 .37679 Mdot
.52565 .37682 Mdot
.52566 .37684 Mdot
.52567 .37686 Mdot
.52568 .37689 Mdot
.52569 .37691 Mdot
.5257 .37693 Mdot
.5257 .37695 Mdot
.52571 .37698 Mdot
.52572 .377 Mdot
.52573 .37702 Mdot
.52574 .37705 Mdot
.52575 .37707 Mdot
.52576 .37709 Mdot
.52577 .37712 Mdot
.52578 .37714 Mdot
.52579 .37716 Mdot
.5258 .37718 Mdot
.52581 .37721 Mdot
.52582 .37723 Mdot
.52583 .37725 Mdot
.52584 .37728 Mdot
.52585 .3773 Mdot
.52586 .37732 Mdot
.52587 .37734 Mdot
.52588 .37737 Mdot
.52589 .37739 Mdot
.5259 .37741 Mdot
.5259 .37744 Mdot
.52591 .37746 Mdot
.52592 .37748 Mdot
.52593 .37751 Mdot
.52594 .37753 Mdot
.52595 .37755 Mdot
.52596 .37757 Mdot
.52597 .3776 Mdot
.52598 .37762 Mdot
.52599 .37764 Mdot
.526 .37767 Mdot
.52601 .37769 Mdot
.52602 .37771 Mdot
.52603 .37773 Mdot
.52604 .37776 Mdot
.52605 .37778 Mdot
.52606 .3778 Mdot
.52607 .37783 Mdot
.52608 .37785 Mdot
.52609 .37787 Mdot
.5261 .3779 Mdot
.5261 .37792 Mdot
.52611 .37794 Mdot
.52612 .37796 Mdot
.52613 .37799 Mdot
.52614 .37801 Mdot
.52615 .37803 Mdot
.52616 .37806 Mdot
.52617 .37808 Mdot
.52618 .3781 Mdot
.52619 .37812 Mdot
.5262 .37815 Mdot
.52621 .37817 Mdot
.52622 .37819 Mdot
.52623 .37822 Mdot
.52624 .37824 Mdot
.52625 .37826 Mdot
.52626 .37828 Mdot
.52627 .37831 Mdot
.52628 .37833 Mdot
.52629 .37835 Mdot
.5263 .37838 Mdot
.5263 .3784 Mdot
.52631 .37842 Mdot
.52632 .37844 Mdot
.52633 .37847 Mdot
.52634 .37849 Mdot
.52635 .37851 Mdot
.52636 .37854 Mdot
.52637 .37856 Mdot
.52638 .37858 Mdot
.52639 .37861 Mdot
.5264 .37863 Mdot
.52641 .37865 Mdot
.52642 .37867 Mdot
.52643 .3787 Mdot
.52644 .37872 Mdot
.52645 .37874 Mdot
.52646 .37877 Mdot
.52647 .37879 Mdot
.52648 .37881 Mdot
.52649 .37883 Mdot
.5265 .37886 Mdot
.5265 .37888 Mdot
.52651 .3789 Mdot
.52652 .37893 Mdot
.52653 .37895 Mdot
.52654 .37897 Mdot
.52655 .37899 Mdot
.52656 .37902 Mdot
.52657 .37904 Mdot
.52658 .37906 Mdot
.52659 .37909 Mdot
.5266 .37911 Mdot
.52661 .37913 Mdot
.52662 .37915 Mdot
.52663 .37918 Mdot
.52664 .3792 Mdot
.52665 .37922 Mdot
.52666 .37925 Mdot
.52667 .37927 Mdot
.52668 .37929 Mdot
.52669 .37931 Mdot
.5267 .37934 Mdot
.5267 .37936 Mdot
.52671 .37938 Mdot
.52672 .37941 Mdot
.52673 .37943 Mdot
.52674 .37945 Mdot
.52675 .37947 Mdot
.52676 .3795 Mdot
.52677 .37952 Mdot
.52678 .37954 Mdot
.52679 .37957 Mdot
.5268 .37959 Mdot
.52681 .37961 Mdot
.52682 .37963 Mdot
.52683 .37966 Mdot
.52684 .37968 Mdot
.52685 .3797 Mdot
.52686 .37973 Mdot
.52687 .37975 Mdot
.52688 .37977 Mdot
.52689 .37979 Mdot
.5269 .37982 Mdot
.5269 .37984 Mdot
.52691 .37986 Mdot
.52692 .37988 Mdot
.52693 .37991 Mdot
.52694 .37993 Mdot
.52695 .37995 Mdot
.52696 .37998 Mdot
.52697 .38 Mdot
.52698 .38002 Mdot
.52699 .38004 Mdot
.527 .38007 Mdot
.52701 .38009 Mdot
.52702 .38011 Mdot
.52703 .38014 Mdot
.52704 .38016 Mdot
.52705 .38018 Mdot
.52706 .3802 Mdot
.52707 .38023 Mdot
.52708 .38025 Mdot
.52709 .38027 Mdot
.5271 .3803 Mdot
.5271 .38032 Mdot
.52711 .38034 Mdot
.52712 .38036 Mdot
.52713 .38039 Mdot
.52714 .38041 Mdot
.52715 .38043 Mdot
.52716 .38046 Mdot
.52717 .38048 Mdot
.52718 .3805 Mdot
.52719 .38052 Mdot
.5272 .38055 Mdot
.52721 .38057 Mdot
.52722 .38059 Mdot
.52723 .38061 Mdot
.52724 .38064 Mdot
.52725 .38066 Mdot
.52726 .38068 Mdot
.52727 .38071 Mdot
.52728 .38073 Mdot
.52729 .38075 Mdot
.5273 .38077 Mdot
.5273 .3808 Mdot
.52731 .38082 Mdot
.52732 .38084 Mdot
.52733 .38087 Mdot
.52734 .38089 Mdot
.52735 .38091 Mdot
.52736 .38093 Mdot
.52737 .38096 Mdot
.52738 .38098 Mdot
.52739 .381 Mdot
.5274 .38102 Mdot
.52741 .38105 Mdot
.52742 .38107 Mdot
.52743 .38109 Mdot
.52744 .38112 Mdot
.52745 .38114 Mdot
.52746 .38116 Mdot
.52747 .38118 Mdot
.52748 .38121 Mdot
.52749 .38123 Mdot
.5275 .38125 Mdot
.5275 .38127 Mdot
.52751 .3813 Mdot
.52752 .38132 Mdot
.52753 .38134 Mdot
.52754 .38137 Mdot
.52755 .38139 Mdot
.52756 .38141 Mdot
.52757 .38143 Mdot
.52758 .38146 Mdot
.52759 .38148 Mdot
.5276 .3815 Mdot
.52761 .38153 Mdot
.52762 .38155 Mdot
.52763 .38157 Mdot
.52764 .38159 Mdot
.52765 .38162 Mdot
.52766 .38164 Mdot
.52767 .38166 Mdot
.52768 .38168 Mdot
.52769 .38171 Mdot
.5277 .38173 Mdot
.5277 .38175 Mdot
.52771 .38178 Mdot
.52772 .3818 Mdot
.52773 .38182 Mdot
.52774 .38184 Mdot
.52775 .38187 Mdot
.52776 .38189 Mdot
.52777 .38191 Mdot
.52778 .38193 Mdot
.52779 .38196 Mdot
.5278 .38198 Mdot
.52781 .382 Mdot
.52782 .38203 Mdot
.52783 .38205 Mdot
.52784 .38207 Mdot
.52785 .38209 Mdot
.52786 .38212 Mdot
.52787 .38214 Mdot
.52788 .38216 Mdot
.52789 .38218 Mdot
.5279 .38221 Mdot
.5279 .38223 Mdot
.52791 .38225 Mdot
.52792 .38228 Mdot
.52793 .3823 Mdot
.52794 .38232 Mdot
.52795 .38234 Mdot
.52796 .38237 Mdot
.52797 .38239 Mdot
.52798 .38241 Mdot
.52799 .38243 Mdot
.528 .38246 Mdot
.52801 .38248 Mdot
.52802 .3825 Mdot
.52803 .38252 Mdot
.52804 .38255 Mdot
.52805 .38257 Mdot
.52806 .38259 Mdot
.52807 .38262 Mdot
.52808 .38264 Mdot
.52809 .38266 Mdot
.5281 .38268 Mdot
.5281 .38271 Mdot
.52811 .38273 Mdot
.52812 .38275 Mdot
.52813 .38277 Mdot
.52814 .3828 Mdot
.52815 .38282 Mdot
.52816 .38284 Mdot
.52817 .38287 Mdot
.52818 .38289 Mdot
.52819 .38291 Mdot
.5282 .38293 Mdot
.52821 .38296 Mdot
.52822 .38298 Mdot
.52823 .383 Mdot
.52824 .38302 Mdot
.52825 .38305 Mdot
.52826 .38307 Mdot
.52827 .38309 Mdot
.52828 .38311 Mdot
.52829 .38314 Mdot
.5283 .38316 Mdot
.5283 .38318 Mdot
.52831 .38321 Mdot
.52832 .38323 Mdot
.52833 .38325 Mdot
.52834 .38327 Mdot
.52835 .3833 Mdot
.52836 .38332 Mdot
.52837 .38334 Mdot
.52838 .38336 Mdot
.52839 .38339 Mdot
.5284 .38341 Mdot
.52841 .38343 Mdot
.52842 .38345 Mdot
.52843 .38348 Mdot
.52844 .3835 Mdot
.52845 .38352 Mdot
.52846 .38354 Mdot
.52847 .38357 Mdot
.52848 .38359 Mdot
.52849 .38361 Mdot
.5285 .38364 Mdot
.5285 .38366 Mdot
.52851 .38368 Mdot
.52852 .3837 Mdot
.52853 .38373 Mdot
.52854 .38375 Mdot
.52855 .38377 Mdot
.52856 .38379 Mdot
.52857 .38382 Mdot
.52858 .38384 Mdot
.52859 .38386 Mdot
.5286 .38388 Mdot
.52861 .38391 Mdot
.52862 .38393 Mdot
.52863 .38395 Mdot
.52864 .38397 Mdot
.52865 .384 Mdot
.52866 .38402 Mdot
.52867 .38404 Mdot
.52868 .38407 Mdot
.52869 .38409 Mdot
.5287 .38411 Mdot
.5287 .38413 Mdot
.52871 .38416 Mdot
.52872 .38418 Mdot
.52873 .3842 Mdot
.52874 .38422 Mdot
.52875 .38425 Mdot
.52876 .38427 Mdot
.52877 .38429 Mdot
.52878 .38431 Mdot
.52879 .38434 Mdot
.5288 .38436 Mdot
.52881 .38438 Mdot
.52882 .3844 Mdot
.52883 .38443 Mdot
.52884 .38445 Mdot
.52885 .38447 Mdot
.52886 .38449 Mdot
.52887 .38452 Mdot
.52888 .38454 Mdot
.52889 .38456 Mdot
.5289 .38459 Mdot
.5289 .38461 Mdot
.52891 .38463 Mdot
.52892 .38465 Mdot
.52893 .38468 Mdot
.52894 .3847 Mdot
.52895 .38472 Mdot
.52896 .38474 Mdot
.52897 .38477 Mdot
.52898 .38479 Mdot
.52899 .38481 Mdot
.529 .38483 Mdot
.52901 .38486 Mdot
.52902 .38488 Mdot
.52903 .3849 Mdot
.52904 .38492 Mdot
.52905 .38495 Mdot
.52906 .38497 Mdot
.52907 .38499 Mdot
.52908 .38501 Mdot
.52909 .38504 Mdot
.5291 .38506 Mdot
.5291 .38508 Mdot
.52911 .3851 Mdot
.52912 .38513 Mdot
.52913 .38515 Mdot
.52914 .38517 Mdot
.52915 .38519 Mdot
.52916 .38522 Mdot
.52917 .38524 Mdot
.52918 .38526 Mdot
.52919 .38529 Mdot
.5292 .38531 Mdot
.52921 .38533 Mdot
.52922 .38535 Mdot
.52923 .38538 Mdot
.52924 .3854 Mdot
.52925 .38542 Mdot
.52926 .38544 Mdot
.52927 .38547 Mdot
.52928 .38549 Mdot
.52929 .38551 Mdot
.5293 .38553 Mdot
.5293 .38556 Mdot
.52931 .38558 Mdot
.52932 .3856 Mdot
.52933 .38562 Mdot
.52934 .38565 Mdot
.52935 .38567 Mdot
.52936 .38569 Mdot
.52937 .38571 Mdot
.52938 .38574 Mdot
.52939 .38576 Mdot
.5294 .38578 Mdot
.52941 .3858 Mdot
.52942 .38583 Mdot
.52943 .38585 Mdot
.52944 .38587 Mdot
.52945 .38589 Mdot
.52946 .38592 Mdot
.52947 .38594 Mdot
.52948 .38596 Mdot
.52949 .38598 Mdot
.5295 .38601 Mdot
.5295 .38603 Mdot
.52951 .38605 Mdot
.52952 .38607 Mdot
.52953 .3861 Mdot
.52954 .38612 Mdot
.52955 .38614 Mdot
.52956 .38616 Mdot
.52957 .38619 Mdot
.52958 .38621 Mdot
.52959 .38623 Mdot
.5296 .38625 Mdot
.52961 .38628 Mdot
.52962 .3863 Mdot
.52963 .38632 Mdot
.52964 .38634 Mdot
.52965 .38637 Mdot
.52966 .38639 Mdot
.52967 .38641 Mdot
.52968 .38643 Mdot
.52969 .38646 Mdot
.5297 .38648 Mdot
.5297 .3865 Mdot
.52971 .38652 Mdot
.52972 .38655 Mdot
.52973 .38657 Mdot
.52974 .38659 Mdot
.52975 .38661 Mdot
.52976 .38664 Mdot
.52977 .38666 Mdot
.52978 .38668 Mdot
.52979 .3867 Mdot
.5298 .38673 Mdot
.52981 .38675 Mdot
.52982 .38677 Mdot
.52983 .38679 Mdot
.52984 .38682 Mdot
.52985 .38684 Mdot
.52986 .38686 Mdot
.52987 .38688 Mdot
.52988 .38691 Mdot
.52989 .38693 Mdot
.5299 .38695 Mdot
.5299 .38697 Mdot
.52991 .387 Mdot
.52992 .38702 Mdot
.52993 .38704 Mdot
.52994 .38706 Mdot
.52995 .38709 Mdot
.52996 .38711 Mdot
.52997 .38713 Mdot
.52998 .38715 Mdot
.52999 .38718 Mdot
.53 .3872 Mdot
.53001 .38722 Mdot
.53002 .38724 Mdot
.53003 .38727 Mdot
.53004 .38729 Mdot
.53005 .38731 Mdot
.53006 .38733 Mdot
.53007 .38736 Mdot
.53008 .38738 Mdot
.53009 .3874 Mdot
.5301 .38742 Mdot
.5301 .38745 Mdot
.53011 .38747 Mdot
.53012 .38749 Mdot
.53013 .38751 Mdot
.53014 .38754 Mdot
.53015 .38756 Mdot
.53016 .38758 Mdot
.53017 .3876 Mdot
.53018 .38762 Mdot
.53019 .38765 Mdot
.5302 .38767 Mdot
.53021 .38769 Mdot
.53022 .38771 Mdot
.53023 .38774 Mdot
.53024 .38776 Mdot
.53025 .38778 Mdot
.53026 .3878 Mdot
.53027 .38783 Mdot
.53028 .38785 Mdot
.53029 .38787 Mdot
.5303 .38789 Mdot
.5303 .38792 Mdot
.53031 .38794 Mdot
.53032 .38796 Mdot
.53033 .38798 Mdot
.53034 .38801 Mdot
.53035 .38803 Mdot
.53036 .38805 Mdot
.53037 .38807 Mdot
.53038 .3881 Mdot
.53039 .38812 Mdot
.5304 .38814 Mdot
.53041 .38816 Mdot
.53042 .38819 Mdot
.53043 .38821 Mdot
.53044 .38823 Mdot
.53045 .38825 Mdot
.53046 .38828 Mdot
.53047 .3883 Mdot
.53048 .38832 Mdot
.53049 .38834 Mdot
.5305 .38836 Mdot
.5305 .38839 Mdot
.53051 .38841 Mdot
.53052 .38843 Mdot
.53053 .38845 Mdot
.53054 .38848 Mdot
.53055 .3885 Mdot
.53056 .38852 Mdot
.53057 .38854 Mdot
.53058 .38857 Mdot
.53059 .38859 Mdot
.5306 .38861 Mdot
.53061 .38863 Mdot
.53062 .38866 Mdot
.53063 .38868 Mdot
.53064 .3887 Mdot
.53065 .38872 Mdot
.53066 .38875 Mdot
.53067 .38877 Mdot
.53068 .38879 Mdot
.53069 .38881 Mdot
.5307 .38884 Mdot
.5307 .38886 Mdot
.53071 .38888 Mdot
.53072 .3889 Mdot
.53073 .38892 Mdot
.53074 .38895 Mdot
.53075 .38897 Mdot
.53076 .38899 Mdot
.53077 .38901 Mdot
.53078 .38904 Mdot
.53079 .38906 Mdot
.5308 .38908 Mdot
.53081 .3891 Mdot
.53082 .38913 Mdot
.53083 .38915 Mdot
.53084 .38917 Mdot
.53085 .38919 Mdot
.53086 .38922 Mdot
.53087 .38924 Mdot
.53088 .38926 Mdot
.53089 .38928 Mdot
.5309 .3893 Mdot
.5309 .38933 Mdot
.53091 .38935 Mdot
.53092 .38937 Mdot
.53093 .38939 Mdot
.53094 .38942 Mdot
.53095 .38944 Mdot
.53096 .38946 Mdot
.53097 .38948 Mdot
.53098 .38951 Mdot
.53099 .38953 Mdot
.531 .38955 Mdot
.53101 .38957 Mdot
.53102 .3896 Mdot
.53103 .38962 Mdot
.53104 .38964 Mdot
.53105 .38966 Mdot
.53106 .38968 Mdot
.53107 .38971 Mdot
.53108 .38973 Mdot
.53109 .38975 Mdot
.5311 .38977 Mdot
.5311 .3898 Mdot
.53111 .38982 Mdot
.53112 .38984 Mdot
.53113 .38986 Mdot
.53114 .38989 Mdot
.53115 .38991 Mdot
.53116 .38993 Mdot
.53117 .38995 Mdot
.53118 .38998 Mdot
.53119 .39 Mdot
.5312 .39002 Mdot
.53121 .39004 Mdot
.53122 .39006 Mdot
.53123 .39009 Mdot
.53124 .39011 Mdot
.53125 .39013 Mdot
.53126 .39015 Mdot
.53127 .39018 Mdot
.53128 .3902 Mdot
.53129 .39022 Mdot
.5313 .39024 Mdot
.5313 .39027 Mdot
.53131 .39029 Mdot
.53132 .39031 Mdot
.53133 .39033 Mdot
.53134 .39035 Mdot
.53135 .39038 Mdot
.53136 .3904 Mdot
.53137 .39042 Mdot
.53138 .39044 Mdot
.53139 .39047 Mdot
.5314 .39049 Mdot
.53141 .39051 Mdot
.53142 .39053 Mdot
.53143 .39056 Mdot
.53144 .39058 Mdot
.53145 .3906 Mdot
.53146 .39062 Mdot
.53147 .39064 Mdot
.53148 .39067 Mdot
.53149 .39069 Mdot
.5315 .39071 Mdot
.5315 .39073 Mdot
.53151 .39076 Mdot
.53152 .39078 Mdot
.53153 .3908 Mdot
.53154 .39082 Mdot
.53155 .39084 Mdot
.53156 .39087 Mdot
.53157 .39089 Mdot
.53158 .39091 Mdot
.53159 .39093 Mdot
.5316 .39096 Mdot
.53161 .39098 Mdot
.53162 .391 Mdot
.53163 .39102 Mdot
.53164 .39105 Mdot
.53165 .39107 Mdot
.53166 .39109 Mdot
.53167 .39111 Mdot
.53168 .39113 Mdot
.53169 .39116 Mdot
.5317 .39118 Mdot
.5317 .3912 Mdot
.53171 .39122 Mdot
.53172 .39125 Mdot
.53173 .39127 Mdot
.53174 .39129 Mdot
.53175 .39131 Mdot
.53176 .39133 Mdot
.53177 .39136 Mdot
.53178 .39138 Mdot
.53179 .3914 Mdot
.5318 .39142 Mdot
.53181 .39145 Mdot
.53182 .39147 Mdot
.53183 .39149 Mdot
.53184 .39151 Mdot
.53185 .39153 Mdot
.53186 .39156 Mdot
.53187 .39158 Mdot
.53188 .3916 Mdot
.53189 .39162 Mdot
.5319 .39165 Mdot
.5319 .39167 Mdot
.53191 .39169 Mdot
.53192 .39171 Mdot
.53193 .39174 Mdot
.53194 .39176 Mdot
.53195 .39178 Mdot
.53196 .3918 Mdot
.53197 .39182 Mdot
.53198 .39185 Mdot
.53199 .39187 Mdot
.532 .39189 Mdot
.53201 .39191 Mdot
.53202 .39194 Mdot
.53203 .39196 Mdot
.53204 .39198 Mdot
.53205 .392 Mdot
.53206 .39202 Mdot
.53207 .39205 Mdot
.53208 .39207 Mdot
.53209 .39209 Mdot
.5321 .39211 Mdot
.5321 .39214 Mdot
.53211 .39216 Mdot
.53212 .39218 Mdot
.53213 .3922 Mdot
.53214 .39222 Mdot
.53215 .39225 Mdot
.53216 .39227 Mdot
.53217 .39229 Mdot
.53218 .39231 Mdot
.53219 .39233 Mdot
.5322 .39236 Mdot
.53221 .39238 Mdot
.53222 .3924 Mdot
.53223 .39242 Mdot
.53224 .39245 Mdot
.53225 .39247 Mdot
.53226 .39249 Mdot
.53227 .39251 Mdot
.53228 .39253 Mdot
.53229 .39256 Mdot
.5323 .39258 Mdot
.5323 .3926 Mdot
.53231 .39262 Mdot
.53232 .39265 Mdot
.53233 .39267 Mdot
.53234 .39269 Mdot
.53235 .39271 Mdot
.53236 .39273 Mdot
.53237 .39276 Mdot
.53238 .39278 Mdot
.53239 .3928 Mdot
.5324 .39282 Mdot
.53241 .39285 Mdot
.53242 .39287 Mdot
.53243 .39289 Mdot
.53244 .39291 Mdot
.53245 .39293 Mdot
.53246 .39296 Mdot
.53247 .39298 Mdot
.53248 .393 Mdot
.53249 .39302 Mdot
.5325 .39304 Mdot
.5325 .39307 Mdot
.53251 .39309 Mdot
.53252 .39311 Mdot
.53253 .39313 Mdot
.53254 .39316 Mdot
.53255 .39318 Mdot
.53256 .3932 Mdot
.53257 .39322 Mdot
.53258 .39324 Mdot
.53259 .39327 Mdot
.5326 .39329 Mdot
.53261 .39331 Mdot
.53262 .39333 Mdot
.53263 .39336 Mdot
.53264 .39338 Mdot
.53265 .3934 Mdot
.53266 .39342 Mdot
.53267 .39344 Mdot
.53268 .39347 Mdot
.53269 .39349 Mdot
.5327 .39351 Mdot
.5327 .39353 Mdot
.53271 .39355 Mdot
.53272 .39358 Mdot
.53273 .3936 Mdot
.53274 .39362 Mdot
.53275 .39364 Mdot
.53276 .39367 Mdot
.53277 .39369 Mdot
.53278 .39371 Mdot
.53279 .39373 Mdot
.5328 .39375 Mdot
.53281 .39378 Mdot
.53282 .3938 Mdot
.53283 .39382 Mdot
.53284 .39384 Mdot
.53285 .39386 Mdot
.53286 .39389 Mdot
.53287 .39391 Mdot
.53288 .39393 Mdot
.53289 .39395 Mdot
.5329 .39398 Mdot
.5329 .394 Mdot
.53291 .39402 Mdot
.53292 .39404 Mdot
.53293 .39406 Mdot
.53294 .39409 Mdot
.53295 .39411 Mdot
.53296 .39413 Mdot
.53297 .39415 Mdot
.53298 .39417 Mdot
.53299 .3942 Mdot
.533 .39422 Mdot
.53301 .39424 Mdot
.53302 .39426 Mdot
.53303 .39428 Mdot
.53304 .39431 Mdot
.53305 .39433 Mdot
.53306 .39435 Mdot
.53307 .39437 Mdot
.53308 .3944 Mdot
.53309 .39442 Mdot
.5331 .39444 Mdot
.5331 .39446 Mdot
.53311 .39448 Mdot
.53312 .39451 Mdot
.53313 .39453 Mdot
.53314 .39455 Mdot
.53315 .39457 Mdot
.53316 .39459 Mdot
.53317 .39462 Mdot
.53318 .39464 Mdot
.53319 .39466 Mdot
.5332 .39468 Mdot
.53321 .3947 Mdot
.53322 .39473 Mdot
.53323 .39475 Mdot
.53324 .39477 Mdot
.53325 .39479 Mdot
.53326 .39481 Mdot
.53327 .39484 Mdot
.53328 .39486 Mdot
.53329 .39488 Mdot
.5333 .3949 Mdot
.5333 .39493 Mdot
.53331 .39495 Mdot
.53332 .39497 Mdot
.53333 .39499 Mdot
.53334 .39501 Mdot
.53335 .39504 Mdot
.53336 .39506 Mdot
.53337 .39508 Mdot
.53338 .3951 Mdot
.53339 .39512 Mdot
.5334 .39515 Mdot
.53341 .39517 Mdot
.53342 .39519 Mdot
.53343 .39521 Mdot
.53344 .39523 Mdot
.53345 .39526 Mdot
.53346 .39528 Mdot
.53347 .3953 Mdot
.53348 .39532 Mdot
.53349 .39534 Mdot
.5335 .39537 Mdot
.5335 .39539 Mdot
.53351 .39541 Mdot
.53352 .39543 Mdot
.53353 .39545 Mdot
.53354 .39548 Mdot
.53355 .3955 Mdot
.53356 .39552 Mdot
.53357 .39554 Mdot
.53358 .39556 Mdot
.53359 .39559 Mdot
.5336 .39561 Mdot
.53361 .39563 Mdot
.53362 .39565 Mdot
.53363 .39568 Mdot
.53364 .3957 Mdot
.53365 .39572 Mdot
.53366 .39574 Mdot
.53367 .39576 Mdot
.53368 .39579 Mdot
.53369 .39581 Mdot
.5337 .39583 Mdot
.5337 .39585 Mdot
.53371 .39587 Mdot
.53372 .3959 Mdot
.53373 .39592 Mdot
.53374 .39594 Mdot
.53375 .39596 Mdot
.53376 .39598 Mdot
.53377 .39601 Mdot
.53378 .39603 Mdot
.53379 .39605 Mdot
.5338 .39607 Mdot
.53381 .39609 Mdot
.53382 .39612 Mdot
.53383 .39614 Mdot
.53384 .39616 Mdot
.53385 .39618 Mdot
.53386 .3962 Mdot
.53387 .39623 Mdot
.53388 .39625 Mdot
.53389 .39627 Mdot
.5339 .39629 Mdot
.5339 .39631 Mdot
.53391 .39634 Mdot
.53392 .39636 Mdot
.53393 .39638 Mdot
.53394 .3964 Mdot
.53395 .39642 Mdot
.53396 .39645 Mdot
.53397 .39647 Mdot
.53398 .39649 Mdot
.53399 .39651 Mdot
.534 .39653 Mdot
.53401 .39656 Mdot
.53402 .39658 Mdot
.53403 .3966 Mdot
.53404 .39662 Mdot
.53405 .39664 Mdot
.53406 .39667 Mdot
.53407 .39669 Mdot
.53408 .39671 Mdot
.53409 .39673 Mdot
.5341 .39675 Mdot
.5341 .39678 Mdot
.53411 .3968 Mdot
.53412 .39682 Mdot
.53413 .39684 Mdot
.53414 .39686 Mdot
.53415 .39689 Mdot
.53416 .39691 Mdot
.53417 .39693 Mdot
.53418 .39695 Mdot
.53419 .39697 Mdot
.5342 .397 Mdot
.53421 .39702 Mdot
.53422 .39704 Mdot
.53423 .39706 Mdot
.53424 .39708 Mdot
.53425 .3971 Mdot
.53426 .39713 Mdot
.53427 .39715 Mdot
.53428 .39717 Mdot
.53429 .39719 Mdot
.5343 .39721 Mdot
.5343 .39724 Mdot
.53431 .39726 Mdot
.53432 .39728 Mdot
.53433 .3973 Mdot
.53434 .39732 Mdot
.53435 .39735 Mdot
.53436 .39737 Mdot
.53437 .39739 Mdot
.53438 .39741 Mdot
.53439 .39743 Mdot
.5344 .39746 Mdot
.53441 .39748 Mdot
.53442 .3975 Mdot
.53443 .39752 Mdot
.53444 .39754 Mdot
.53445 .39757 Mdot
.53446 .39759 Mdot
.53447 .39761 Mdot
.53448 .39763 Mdot
.53449 .39765 Mdot
.5345 .39768 Mdot
.5345 .3977 Mdot
.53451 .39772 Mdot
.53452 .39774 Mdot
.53453 .39776 Mdot
.53454 .39779 Mdot
.53455 .39781 Mdot
.53456 .39783 Mdot
.53457 .39785 Mdot
.53458 .39787 Mdot
.53459 .39789 Mdot
.5346 .39792 Mdot
.53461 .39794 Mdot
.53462 .39796 Mdot
.53463 .39798 Mdot
.53464 .398 Mdot
.53465 .39803 Mdot
.53466 .39805 Mdot
.53467 .39807 Mdot
.53468 .39809 Mdot
.53469 .39811 Mdot
.5347 .39814 Mdot
.5347 .39816 Mdot
.53471 .39818 Mdot
.53472 .3982 Mdot
.53473 .39822 Mdot
.53474 .39825 Mdot
.53475 .39827 Mdot
.53476 .39829 Mdot
.53477 .39831 Mdot
.53478 .39833 Mdot
.53479 .39835 Mdot
.5348 .39838 Mdot
.53481 .3984 Mdot
.53482 .39842 Mdot
.53483 .39844 Mdot
.53484 .39846 Mdot
.53485 .39849 Mdot
.53486 .39851 Mdot
.53487 .39853 Mdot
.53488 .39855 Mdot
.53489 .39857 Mdot
.5349 .3986 Mdot
.5349 .39862 Mdot
.53491 .39864 Mdot
.53492 .39866 Mdot
.53493 .39868 Mdot
.53494 .39871 Mdot
.53495 .39873 Mdot
.53496 .39875 Mdot
.53497 .39877 Mdot
.53498 .39879 Mdot
.53499 .39881 Mdot
.535 .39884 Mdot
.53501 .39886 Mdot
.53502 .39888 Mdot
.53503 .3989 Mdot
.53504 .39892 Mdot
.53505 .39895 Mdot
.53506 .39897 Mdot
.53507 .39899 Mdot
.53508 .39901 Mdot
.53509 .39903 Mdot
.5351 .39906 Mdot
.5351 .39908 Mdot
.53511 .3991 Mdot
.53512 .39912 Mdot
.53513 .39914 Mdot
.53514 .39916 Mdot
.53515 .39919 Mdot
.53516 .39921 Mdot
.53517 .39923 Mdot
.53518 .39925 Mdot
.53519 .39927 Mdot
.5352 .3993 Mdot
.53521 .39932 Mdot
.53522 .39934 Mdot
.53523 .39936 Mdot
.53524 .39938 Mdot
.53525 .3994 Mdot
.53526 .39943 Mdot
.53527 .39945 Mdot
.53528 .39947 Mdot
.53529 .39949 Mdot
.5353 .39951 Mdot
.5353 .39954 Mdot
.53531 .39956 Mdot
.53532 .39958 Mdot
.53533 .3996 Mdot
.53534 .39962 Mdot
.53535 .39964 Mdot
.53536 .39967 Mdot
.53537 .39969 Mdot
.53538 .39971 Mdot
.53539 .39973 Mdot
.5354 .39975 Mdot
.53541 .39978 Mdot
.53542 .3998 Mdot
.53543 .39982 Mdot
.53544 .39984 Mdot
.53545 .39986 Mdot
.53546 .39989 Mdot
.53547 .39991 Mdot
.53548 .39993 Mdot
.53549 .39995 Mdot
.5355 .39997 Mdot
.5355 .39999 Mdot
.53551 .40002 Mdot
.53552 .40004 Mdot
.53553 .40006 Mdot
.53554 .40008 Mdot
.53555 .4001 Mdot
.53556 .40012 Mdot
.53557 .40015 Mdot
.53558 .40017 Mdot
.53559 .40019 Mdot
.5356 .40021 Mdot
.53561 .40023 Mdot
.53562 .40026 Mdot
.53563 .40028 Mdot
.53564 .4003 Mdot
.53565 .40032 Mdot
.53566 .40034 Mdot
.53567 .40036 Mdot
.53568 .40039 Mdot
.53569 .40041 Mdot
.5357 .40043 Mdot
.5357 .40045 Mdot
.53571 .40047 Mdot
.53572 .4005 Mdot
.53573 .40052 Mdot
.53574 .40054 Mdot
.53575 .40056 Mdot
.53576 .40058 Mdot
.53577 .4006 Mdot
.53578 .40063 Mdot
.53579 .40065 Mdot
.5358 .40067 Mdot
.53581 .40069 Mdot
.53582 .40071 Mdot
.53583 .40074 Mdot
.53584 .40076 Mdot
.53585 .40078 Mdot
.53586 .4008 Mdot
.53587 .40082 Mdot
.53588 .40084 Mdot
.53589 .40087 Mdot
.5359 .40089 Mdot
.5359 .40091 Mdot
.53591 .40093 Mdot
.53592 .40095 Mdot
.53593 .40097 Mdot
.53594 .401 Mdot
.53595 .40102 Mdot
.53596 .40104 Mdot
.53597 .40106 Mdot
.53598 .40108 Mdot
.53599 .40111 Mdot
.536 .40113 Mdot
.53601 .40115 Mdot
.53602 .40117 Mdot
.53603 .40119 Mdot
.53604 .40121 Mdot
.53605 .40124 Mdot
.53606 .40126 Mdot
.53607 .40128 Mdot
.53608 .4013 Mdot
.53609 .40132 Mdot
.5361 .40134 Mdot
.5361 .40137 Mdot
.53611 .40139 Mdot
.53612 .40141 Mdot
.53613 .40143 Mdot
.53614 .40145 Mdot
.53615 .40147 Mdot
.53616 .4015 Mdot
.53617 .40152 Mdot
.53618 .40154 Mdot
.53619 .40156 Mdot
.5362 .40158 Mdot
.53621 .40161 Mdot
.53622 .40163 Mdot
.53623 .40165 Mdot
.53624 .40167 Mdot
.53625 .40169 Mdot
.53626 .40171 Mdot
.53627 .40174 Mdot
.53628 .40176 Mdot
.53629 .40178 Mdot
.5363 .4018 Mdot
.5363 .40182 Mdot
.53631 .40184 Mdot
.53632 .40187 Mdot
.53633 .40189 Mdot
.53634 .40191 Mdot
.53635 .40193 Mdot
.53636 .40195 Mdot
.53637 .40197 Mdot
.53638 .402 Mdot
.53639 .40202 Mdot
.5364 .40204 Mdot
.53641 .40206 Mdot
.53642 .40208 Mdot
.53643 .4021 Mdot
.53644 .40213 Mdot
.53645 .40215 Mdot
.53646 .40217 Mdot
.53647 .40219 Mdot
.53648 .40221 Mdot
.53649 .40223 Mdot
.5365 .40226 Mdot
.5365 .40228 Mdot
.53651 .4023 Mdot
.53652 .40232 Mdot
.53653 .40234 Mdot
.53654 .40236 Mdot
.53655 .40239 Mdot
.53656 .40241 Mdot
.53657 .40243 Mdot
.53658 .40245 Mdot
.53659 .40247 Mdot
.5366 .4025 Mdot
.53661 .40252 Mdot
.53662 .40254 Mdot
.53663 .40256 Mdot
.53664 .40258 Mdot
.53665 .4026 Mdot
.53666 .40263 Mdot
.53667 .40265 Mdot
.53668 .40267 Mdot
.53669 .40269 Mdot
.5367 .40271 Mdot
.5367 .40273 Mdot
.53671 .40276 Mdot
.53672 .40278 Mdot
.53673 .4028 Mdot
.53674 .40282 Mdot
.53675 .40284 Mdot
.53676 .40286 Mdot
.53677 .40289 Mdot
.53678 .40291 Mdot
.53679 .40293 Mdot
.5368 .40295 Mdot
.53681 .40297 Mdot
.53682 .40299 Mdot
.53683 .40302 Mdot
.53684 .40304 Mdot
.53685 .40306 Mdot
.53686 .40308 Mdot
.53687 .4031 Mdot
.53688 .40312 Mdot
.53689 .40315 Mdot
.5369 .40317 Mdot
.5369 .40319 Mdot
.53691 .40321 Mdot
.53692 .40323 Mdot
.53693 .40325 Mdot
.53694 .40327 Mdot
.53695 .4033 Mdot
.53696 .40332 Mdot
.53697 .40334 Mdot
.53698 .40336 Mdot
.53699 .40338 Mdot
.537 .4034 Mdot
.53701 .40343 Mdot
.53702 .40345 Mdot
.53703 .40347 Mdot
.53704 .40349 Mdot
.53705 .40351 Mdot
.53706 .40353 Mdot
.53707 .40356 Mdot
.53708 .40358 Mdot
.53709 .4036 Mdot
.5371 .40362 Mdot
.5371 .40364 Mdot
.53711 .40366 Mdot
.53712 .40369 Mdot
.53713 .40371 Mdot
.53714 .40373 Mdot
.53715 .40375 Mdot
.53716 .40377 Mdot
.53717 .40379 Mdot
.53718 .40382 Mdot
.53719 .40384 Mdot
.5372 .40386 Mdot
.53721 .40388 Mdot
.53722 .4039 Mdot
.53723 .40392 Mdot
.53724 .40395 Mdot
.53725 .40397 Mdot
.53726 .40399 Mdot
.53727 .40401 Mdot
.53728 .40403 Mdot
.53729 .40405 Mdot
.5373 .40407 Mdot
.5373 .4041 Mdot
.53731 .40412 Mdot
.53732 .40414 Mdot
.53733 .40416 Mdot
.53734 .40418 Mdot
.53735 .4042 Mdot
.53736 .40423 Mdot
.53737 .40425 Mdot
.53738 .40427 Mdot
.53739 .40429 Mdot
.5374 .40431 Mdot
.53741 .40433 Mdot
.53742 .40436 Mdot
.53743 .40438 Mdot
.53744 .4044 Mdot
.53745 .40442 Mdot
.53746 .40444 Mdot
.53747 .40446 Mdot
.53748 .40449 Mdot
.53749 .40451 Mdot
.5375 .40453 Mdot
.5375 .40455 Mdot
.53751 .40457 Mdot
.53752 .40459 Mdot
.53753 .40461 Mdot
.53754 .40464 Mdot
.53755 .40466 Mdot
.53756 .40468 Mdot
.53757 .4047 Mdot
.53758 .40472 Mdot
.53759 .40474 Mdot
.5376 .40477 Mdot
.53761 .40479 Mdot
.53762 .40481 Mdot
.53763 .40483 Mdot
.53764 .40485 Mdot
.53765 .40487 Mdot
.53766 .40489 Mdot
.53767 .40492 Mdot
.53768 .40494 Mdot
.53769 .40496 Mdot
.5377 .40498 Mdot
.5377 .405 Mdot
.53771 .40502 Mdot
.53772 .40505 Mdot
.53773 .40507 Mdot
.53774 .40509 Mdot
.53775 .40511 Mdot
.53776 .40513 Mdot
.53777 .40515 Mdot
.53778 .40518 Mdot
.53779 .4052 Mdot
.5378 .40522 Mdot
.53781 .40524 Mdot
.53782 .40526 Mdot
.53783 .40528 Mdot
.53784 .4053 Mdot
.53785 .40533 Mdot
.53786 .40535 Mdot
.53787 .40537 Mdot
.53788 .40539 Mdot
.53789 .40541 Mdot
.5379 .40543 Mdot
.5379 .40546 Mdot
.53791 .40548 Mdot
.53792 .4055 Mdot
.53793 .40552 Mdot
.53794 .40554 Mdot
.53795 .40556 Mdot
.53796 .40558 Mdot
.53797 .40561 Mdot
.53798 .40563 Mdot
.53799 .40565 Mdot
.538 .40567 Mdot
.53801 .40569 Mdot
.53802 .40571 Mdot
.53803 .40573 Mdot
.53804 .40576 Mdot
.53805 .40578 Mdot
.53806 .4058 Mdot
.53807 .40582 Mdot
.53808 .40584 Mdot
.53809 .40586 Mdot
.5381 .40589 Mdot
.5381 .40591 Mdot
.53811 .40593 Mdot
.53812 .40595 Mdot
.53813 .40597 Mdot
.53814 .40599 Mdot
.53815 .40601 Mdot
.53816 .40604 Mdot
.53817 .40606 Mdot
.53818 .40608 Mdot
.53819 .4061 Mdot
.5382 .40612 Mdot
.53821 .40614 Mdot
.53822 .40616 Mdot
.53823 .40619 Mdot
.53824 .40621 Mdot
.53825 .40623 Mdot
.53826 .40625 Mdot
.53827 .40627 Mdot
.53828 .40629 Mdot
.53829 .40632 Mdot
.5383 .40634 Mdot
.5383 .40636 Mdot
.53831 .40638 Mdot
.53832 .4064 Mdot
.53833 .40642 Mdot
.53834 .40644 Mdot
.53835 .40647 Mdot
.53836 .40649 Mdot
.53837 .40651 Mdot
.53838 .40653 Mdot
.53839 .40655 Mdot
.5384 .40657 Mdot
.53841 .40659 Mdot
.53842 .40662 Mdot
.53843 .40664 Mdot
.53844 .40666 Mdot
.53845 .40668 Mdot
.53846 .4067 Mdot
.53847 .40672 Mdot
.53848 .40674 Mdot
.53849 .40677 Mdot
.5385 .40679 Mdot
.5385 .40681 Mdot
.53851 .40683 Mdot
.53852 .40685 Mdot
.53853 .40687 Mdot
.53854 .40689 Mdot
.53855 .40692 Mdot
.53856 .40694 Mdot
.53857 .40696 Mdot
.53858 .40698 Mdot
.53859 .407 Mdot
.5386 .40702 Mdot
.53861 .40705 Mdot
.53862 .40707 Mdot
.53863 .40709 Mdot
.53864 .40711 Mdot
.53865 .40713 Mdot
.53866 .40715 Mdot
.53867 .40717 Mdot
.53868 .4072 Mdot
.53869 .40722 Mdot
.5387 .40724 Mdot
.5387 .40726 Mdot
.53871 .40728 Mdot
.53872 .4073 Mdot
.53873 .40732 Mdot
.53874 .40735 Mdot
.53875 .40737 Mdot
.53876 .40739 Mdot
.53877 .40741 Mdot
.53878 .40743 Mdot
.53879 .40745 Mdot
.5388 .40747 Mdot
.53881 .4075 Mdot
.53882 .40752 Mdot
.53883 .40754 Mdot
.53884 .40756 Mdot
.53885 .40758 Mdot
.53886 .4076 Mdot
.53887 .40762 Mdot
.53888 .40765 Mdot
.53889 .40767 Mdot
.5389 .40769 Mdot
.5389 .40771 Mdot
.53891 .40773 Mdot
.53892 .40775 Mdot
.53893 .40777 Mdot
.53894 .40779 Mdot
.53895 .40782 Mdot
.53896 .40784 Mdot
.53897 .40786 Mdot
.53898 .40788 Mdot
.53899 .4079 Mdot
.539 .40792 Mdot
.53901 .40794 Mdot
.53902 .40797 Mdot
.53903 .40799 Mdot
.53904 .40801 Mdot
.53905 .40803 Mdot
.53906 .40805 Mdot
.53907 .40807 Mdot
.53908 .40809 Mdot
.53909 .40812 Mdot
.5391 .40814 Mdot
.5391 .40816 Mdot
.53911 .40818 Mdot
.53912 .4082 Mdot
.53913 .40822 Mdot
.53914 .40824 Mdot
.53915 .40827 Mdot
.53916 .40829 Mdot
.53917 .40831 Mdot
.53918 .40833 Mdot
.53919 .40835 Mdot
.5392 .40837 Mdot
.53921 .40839 Mdot
.53922 .40842 Mdot
.53923 .40844 Mdot
.53924 .40846 Mdot
.53925 .40848 Mdot
.53926 .4085 Mdot
.53927 .40852 Mdot
.53928 .40854 Mdot
.53929 .40856 Mdot
.5393 .40859 Mdot
.5393 .40861 Mdot
.53931 .40863 Mdot
.53932 .40865 Mdot
.53933 .40867 Mdot
.53934 .40869 Mdot
.53935 .40871 Mdot
.53936 .40874 Mdot
.53937 .40876 Mdot
.53938 .40878 Mdot
.53939 .4088 Mdot
.5394 .40882 Mdot
.53941 .40884 Mdot
.53942 .40886 Mdot
.53943 .40889 Mdot
.53944 .40891 Mdot
.53945 .40893 Mdot
.53946 .40895 Mdot
.53947 .40897 Mdot
.53948 .40899 Mdot
.53949 .40901 Mdot
.5395 .40903 Mdot
.5395 .40906 Mdot
.53951 .40908 Mdot
.53952 .4091 Mdot
.53953 .40912 Mdot
.53954 .40914 Mdot
.53955 .40916 Mdot
.53956 .40918 Mdot
.53957 .40921 Mdot
.53958 .40923 Mdot
.53959 .40925 Mdot
.5396 .40927 Mdot
.53961 .40929 Mdot
.53962 .40931 Mdot
.53963 .40933 Mdot
.53964 .40935 Mdot
.53965 .40938 Mdot
.53966 .4094 Mdot
.53967 .40942 Mdot
.53968 .40944 Mdot
.53969 .40946 Mdot
.5397 .40948 Mdot
.5397 .4095 Mdot
.53971 .40953 Mdot
.53972 .40955 Mdot
.53973 .40957 Mdot
.53974 .40959 Mdot
.53975 .40961 Mdot
.53976 .40963 Mdot
.53977 .40965 Mdot
.53978 .40967 Mdot
.53979 .4097 Mdot
.5398 .40972 Mdot
.53981 .40974 Mdot
.53982 .40976 Mdot
.53983 .40978 Mdot
.53984 .4098 Mdot
.53985 .40982 Mdot
.53986 .40984 Mdot
.53987 .40987 Mdot
.53988 .40989 Mdot
.53989 .40991 Mdot
.5399 .40993 Mdot
.5399 .40995 Mdot
.53991 .40997 Mdot
.53992 .40999 Mdot
.53993 .41001 Mdot
.53994 .41004 Mdot
.53995 .41006 Mdot
.53996 .41008 Mdot
.53997 .4101 Mdot
.53998 .41012 Mdot
.53999 .41014 Mdot
.54 .41016 Mdot
.54001 .41019 Mdot
.54002 .41021 Mdot
.54003 .41023 Mdot
.54004 .41025 Mdot
.54005 .41027 Mdot
.54006 .41029 Mdot
.54007 .41031 Mdot
.54008 .41033 Mdot
.54009 .41036 Mdot
.5401 .41038 Mdot
.5401 .4104 Mdot
.54011 .41042 Mdot
.54012 .41044 Mdot
.54013 .41046 Mdot
.54014 .41048 Mdot
.54015 .4105 Mdot
.54016 .41053 Mdot
.54017 .41055 Mdot
.54018 .41057 Mdot
.54019 .41059 Mdot
.5402 .41061 Mdot
.54021 .41063 Mdot
.54022 .41065 Mdot
.54023 .41067 Mdot
.54024 .4107 Mdot
.54025 .41072 Mdot
.54026 .41074 Mdot
.54027 .41076 Mdot
.54028 .41078 Mdot
.54029 .4108 Mdot
.5403 .41082 Mdot
.5403 .41084 Mdot
.54031 .41087 Mdot
.54032 .41089 Mdot
.54033 .41091 Mdot
.54034 .41093 Mdot
.54035 .41095 Mdot
.54036 .41097 Mdot
.54037 .41099 Mdot
.54038 .41101 Mdot
.54039 .41104 Mdot
.5404 .41106 Mdot
.54041 .41108 Mdot
.54042 .4111 Mdot
.54043 .41112 Mdot
.54044 .41114 Mdot
.54045 .41116 Mdot
.54046 .41118 Mdot
.54047 .41121 Mdot
.54048 .41123 Mdot
.54049 .41125 Mdot
.5405 .41127 Mdot
.5405 .41129 Mdot
.54051 .41131 Mdot
.54052 .41133 Mdot
.54053 .41135 Mdot
.54054 .41137 Mdot
.54055 .4114 Mdot
.54056 .41142 Mdot
.54057 .41144 Mdot
.54058 .41146 Mdot
.54059 .41148 Mdot
.5406 .4115 Mdot
.54061 .41152 Mdot
.54062 .41154 Mdot
.54063 .41157 Mdot
.54064 .41159 Mdot
.54065 .41161 Mdot
.54066 .41163 Mdot
.54067 .41165 Mdot
.54068 .41167 Mdot
.54069 .41169 Mdot
.5407 .41171 Mdot
.5407 .41174 Mdot
.54071 .41176 Mdot
.54072 .41178 Mdot
.54073 .4118 Mdot
.54074 .41182 Mdot
.54075 .41184 Mdot
.54076 .41186 Mdot
.54077 .41188 Mdot
.54078 .4119 Mdot
.54079 .41193 Mdot
.5408 .41195 Mdot
.54081 .41197 Mdot
.54082 .41199 Mdot
.54083 .41201 Mdot
.54084 .41203 Mdot
.54085 .41205 Mdot
.54086 .41207 Mdot
.54087 .4121 Mdot
.54088 .41212 Mdot
.54089 .41214 Mdot
.5409 .41216 Mdot
.5409 .41218 Mdot
.54091 .4122 Mdot
.54092 .41222 Mdot
.54093 .41224 Mdot
.54094 .41226 Mdot
.54095 .41229 Mdot
.54096 .41231 Mdot
.54097 .41233 Mdot
.54098 .41235 Mdot
.54099 .41237 Mdot
.541 .41239 Mdot
.54101 .41241 Mdot
.54102 .41243 Mdot
.54103 .41246 Mdot
.54104 .41248 Mdot
.54105 .4125 Mdot
.54106 .41252 Mdot
.54107 .41254 Mdot
.54108 .41256 Mdot
.54109 .41258 Mdot
.5411 .4126 Mdot
.5411 .41262 Mdot
.54111 .41265 Mdot
.54112 .41267 Mdot
.54113 .41269 Mdot
.54114 .41271 Mdot
.54115 .41273 Mdot
.54116 .41275 Mdot
.54117 .41277 Mdot
.54118 .41279 Mdot
.54119 .41281 Mdot
.5412 .41284 Mdot
.54121 .41286 Mdot
.54122 .41288 Mdot
.54123 .4129 Mdot
.54124 .41292 Mdot
.54125 .41294 Mdot
.54126 .41296 Mdot
.54127 .41298 Mdot
.54128 .41301 Mdot
.54129 .41303 Mdot
.5413 .41305 Mdot
.5413 .41307 Mdot
.54131 .41309 Mdot
.54132 .41311 Mdot
.54133 .41313 Mdot
.54134 .41315 Mdot
.54135 .41317 Mdot
.54136 .4132 Mdot
.54137 .41322 Mdot
.54138 .41324 Mdot
.54139 .41326 Mdot
.5414 .41328 Mdot
.54141 .4133 Mdot
.54142 .41332 Mdot
.54143 .41334 Mdot
.54144 .41336 Mdot
.54145 .41339 Mdot
.54146 .41341 Mdot
.54147 .41343 Mdot
.54148 .41345 Mdot
.54149 .41347 Mdot
.5415 .41349 Mdot
.5415 .41351 Mdot
.54151 .41353 Mdot
.54152 .41355 Mdot
.54153 .41358 Mdot
.54154 .4136 Mdot
.54155 .41362 Mdot
.54156 .41364 Mdot
.54157 .41366 Mdot
.54158 .41368 Mdot
.54159 .4137 Mdot
.5416 .41372 Mdot
.54161 .41374 Mdot
.54162 .41376 Mdot
.54163 .41379 Mdot
.54164 .41381 Mdot
.54165 .41383 Mdot
.54166 .41385 Mdot
.54167 .41387 Mdot
.54168 .41389 Mdot
.54169 .41391 Mdot
.5417 .41393 Mdot
.5417 .41395 Mdot
.54171 .41398 Mdot
.54172 .414 Mdot
.54173 .41402 Mdot
.54174 .41404 Mdot
.54175 .41406 Mdot
.54176 .41408 Mdot
.54177 .4141 Mdot
.54178 .41412 Mdot
.54179 .41414 Mdot
.5418 .41417 Mdot
.54181 .41419 Mdot
.54182 .41421 Mdot
.54183 .41423 Mdot
.54184 .41425 Mdot
.54185 .41427 Mdot
.54186 .41429 Mdot
.54187 .41431 Mdot
.54188 .41433 Mdot
.54189 .41435 Mdot
.5419 .41438 Mdot
.5419 .4144 Mdot
.54191 .41442 Mdot
.54192 .41444 Mdot
.54193 .41446 Mdot
.54194 .41448 Mdot
.54195 .4145 Mdot
.54196 .41452 Mdot
.54197 .41454 Mdot
.54198 .41457 Mdot
.54199 .41459 Mdot
.542 .41461 Mdot
.54201 .41463 Mdot
.54202 .41465 Mdot
.54203 .41467 Mdot
.54204 .41469 Mdot
.54205 .41471 Mdot
.54206 .41473 Mdot
.54207 .41475 Mdot
.54208 .41478 Mdot
.54209 .4148 Mdot
.5421 .41482 Mdot
.5421 .41484 Mdot
.54211 .41486 Mdot
.54212 .41488 Mdot
.54213 .4149 Mdot
.54214 .41492 Mdot
.54215 .41494 Mdot
.54216 .41496 Mdot
.54217 .41499 Mdot
.54218 .41501 Mdot
.54219 .41503 Mdot
.5422 .41505 Mdot
.54221 .41507 Mdot
.54222 .41509 Mdot
.54223 .41511 Mdot
.54224 .41513 Mdot
.54225 .41515 Mdot
.54226 .41518 Mdot
.54227 .4152 Mdot
.54228 .41522 Mdot
.54229 .41524 Mdot
.5423 .41526 Mdot
.5423 .41528 Mdot
.54231 .4153 Mdot
.54232 .41532 Mdot
.54233 .41534 Mdot
.54234 .41536 Mdot
.54235 .41539 Mdot
.54236 .41541 Mdot
.54237 .41543 Mdot
.54238 .41545 Mdot
.54239 .41547 Mdot
.5424 .41549 Mdot
.54241 .41551 Mdot
.54242 .41553 Mdot
.54243 .41555 Mdot
.54244 .41557 Mdot
.54245 .4156 Mdot
.54246 .41562 Mdot
.54247 .41564 Mdot
.54248 .41566 Mdot
.54249 .41568 Mdot
.5425 .4157 Mdot
.5425 .41572 Mdot
.54251 .41574 Mdot
.54252 .41576 Mdot
.54253 .41578 Mdot
.54254 .4158 Mdot
.54255 .41583 Mdot
.54256 .41585 Mdot
.54257 .41587 Mdot
.54258 .41589 Mdot
.54259 .41591 Mdot
.5426 .41593 Mdot
.54261 .41595 Mdot
.54262 .41597 Mdot
.54263 .41599 Mdot
.54264 .41601 Mdot
.54265 .41604 Mdot
.54266 .41606 Mdot
.54267 .41608 Mdot
.54268 .4161 Mdot
.54269 .41612 Mdot
.5427 .41614 Mdot
.5427 .41616 Mdot
.54271 .41618 Mdot
.54272 .4162 Mdot
.54273 .41622 Mdot
.54274 .41625 Mdot
.54275 .41627 Mdot
.54276 .41629 Mdot
.54277 .41631 Mdot
.54278 .41633 Mdot
.54279 .41635 Mdot
.5428 .41637 Mdot
.54281 .41639 Mdot
.54282 .41641 Mdot
.54283 .41643 Mdot
.54284 .41645 Mdot
.54285 .41648 Mdot
.54286 .4165 Mdot
.54287 .41652 Mdot
.54288 .41654 Mdot
.54289 .41656 Mdot
.5429 .41658 Mdot
.5429 .4166 Mdot
.54291 .41662 Mdot
.54292 .41664 Mdot
.54293 .41666 Mdot
.54294 .41668 Mdot
.54295 .41671 Mdot
.54296 .41673 Mdot
.54297 .41675 Mdot
.54298 .41677 Mdot
.54299 .41679 Mdot
.543 .41681 Mdot
.54301 .41683 Mdot
.54302 .41685 Mdot
.54303 .41687 Mdot
.54304 .41689 Mdot
.54305 .41691 Mdot
.54306 .41694 Mdot
.54307 .41696 Mdot
.54308 .41698 Mdot
.54309 .417 Mdot
.5431 .41702 Mdot
.5431 .41704 Mdot
.54311 .41706 Mdot
.54312 .41708 Mdot
.54313 .4171 Mdot
.54314 .41712 Mdot
.54315 .41714 Mdot
.54316 .41717 Mdot
.54317 .41719 Mdot
.54318 .41721 Mdot
.54319 .41723 Mdot
.5432 .41725 Mdot
.54321 .41727 Mdot
.54322 .41729 Mdot
.54323 .41731 Mdot
.54324 .41733 Mdot
.54325 .41735 Mdot
.54326 .41737 Mdot
.54327 .4174 Mdot
.54328 .41742 Mdot
.54329 .41744 Mdot
.5433 .41746 Mdot
.5433 .41748 Mdot
.54331 .4175 Mdot
.54332 .41752 Mdot
.54333 .41754 Mdot
.54334 .41756 Mdot
.54335 .41758 Mdot
.54336 .4176 Mdot
.54337 .41763 Mdot
.54338 .41765 Mdot
.54339 .41767 Mdot
.5434 .41769 Mdot
.54341 .41771 Mdot
.54342 .41773 Mdot
.54343 .41775 Mdot
.54344 .41777 Mdot
.54345 .41779 Mdot
.54346 .41781 Mdot
.54347 .41783 Mdot
.54348 .41785 Mdot
.54349 .41788 Mdot
.5435 .4179 Mdot
.5435 .41792 Mdot
.54351 .41794 Mdot
.54352 .41796 Mdot
.54353 .41798 Mdot
.54354 .418 Mdot
.54355 .41802 Mdot
.54356 .41804 Mdot
.54357 .41806 Mdot
.54358 .41808 Mdot
.54359 .41811 Mdot
.5436 .41813 Mdot
.54361 .41815 Mdot
.54362 .41817 Mdot
.54363 .41819 Mdot
.54364 .41821 Mdot
.54365 .41823 Mdot
.54366 .41825 Mdot
.54367 .41827 Mdot
.54368 .41829 Mdot
.54369 .41831 Mdot
.5437 .41833 Mdot
.5437 .41836 Mdot
.54371 .41838 Mdot
.54372 .4184 Mdot
.54373 .41842 Mdot
.54374 .41844 Mdot
.54375 .41846 Mdot
.54376 .41848 Mdot
.54377 .4185 Mdot
.54378 .41852 Mdot
.54379 .41854 Mdot
.5438 .41856 Mdot
.54381 .41858 Mdot
.54382 .41861 Mdot
.54383 .41863 Mdot
.54384 .41865 Mdot
.54385 .41867 Mdot
.54386 .41869 Mdot
.54387 .41871 Mdot
.54388 .41873 Mdot
.54389 .41875 Mdot
.5439 .41877 Mdot
.5439 .41879 Mdot
.54391 .41881 Mdot
.54392 .41883 Mdot
.54393 .41886 Mdot
.54394 .41888 Mdot
.54395 .4189 Mdot
.54396 .41892 Mdot
.54397 .41894 Mdot
.54398 .41896 Mdot
.54399 .41898 Mdot
.544 .419 Mdot
.54401 .41902 Mdot
.54402 .41904 Mdot
.54403 .41906 Mdot
.54404 .41908 Mdot
.54405 .4191 Mdot
.54406 .41913 Mdot
.54407 .41915 Mdot
.54408 .41917 Mdot
.54409 .41919 Mdot
.5441 .41921 Mdot
.5441 .41923 Mdot
.54411 .41925 Mdot
.54412 .41927 Mdot
.54413 .41929 Mdot
.54414 .41931 Mdot
.54415 .41933 Mdot
.54416 .41935 Mdot
.54417 .41937 Mdot
.54418 .4194 Mdot
.54419 .41942 Mdot
.5442 .41944 Mdot
.54421 .41946 Mdot
.54422 .41948 Mdot
.54423 .4195 Mdot
.54424 .41952 Mdot
.54425 .41954 Mdot
.54426 .41956 Mdot
.54427 .41958 Mdot
.54428 .4196 Mdot
.54429 .41962 Mdot
.5443 .41964 Mdot
.5443 .41967 Mdot
.54431 .41969 Mdot
.54432 .41971 Mdot
.54433 .41973 Mdot
.54434 .41975 Mdot
.54435 .41977 Mdot
.54436 .41979 Mdot
.54437 .41981 Mdot
.54438 .41983 Mdot
.54439 .41985 Mdot
.5444 .41987 Mdot
.54441 .41989 Mdot
.54442 .41991 Mdot
.54443 .41994 Mdot
.54444 .41996 Mdot
.54445 .41998 Mdot
.54446 .42 Mdot
.54447 .42002 Mdot
.54448 .42004 Mdot
.54449 .42006 Mdot
.5445 .42008 Mdot
.5445 .4201 Mdot
.54451 .42012 Mdot
.54452 .42014 Mdot
.54453 .42016 Mdot
.54454 .42018 Mdot
.54455 .42021 Mdot
.54456 .42023 Mdot
.54457 .42025 Mdot
.54458 .42027 Mdot
.54459 .42029 Mdot
.5446 .42031 Mdot
.54461 .42033 Mdot
.54462 .42035 Mdot
.54463 .42037 Mdot
.54464 .42039 Mdot
.54465 .42041 Mdot
.54466 .42043 Mdot
.54467 .42045 Mdot
.54468 .42047 Mdot
.54469 .4205 Mdot
.5447 .42052 Mdot
.5447 .42054 Mdot
.54471 .42056 Mdot
.54472 .42058 Mdot
.54473 .4206 Mdot
.54474 .42062 Mdot
.54475 .42064 Mdot
.54476 .42066 Mdot
.54477 .42068 Mdot
.54478 .4207 Mdot
.54479 .42072 Mdot
.5448 .42074 Mdot
.54481 .42076 Mdot
.54482 .42079 Mdot
.54483 .42081 Mdot
.54484 .42083 Mdot
.54485 .42085 Mdot
.54486 .42087 Mdot
.54487 .42089 Mdot
.54488 .42091 Mdot
.54489 .42093 Mdot
.5449 .42095 Mdot
.5449 .42097 Mdot
.54491 .42099 Mdot
.54492 .42101 Mdot
.54493 .42103 Mdot
.54494 .42105 Mdot
.54495 .42108 Mdot
.54496 .4211 Mdot
.54497 .42112 Mdot
.54498 .42114 Mdot
.54499 .42116 Mdot
.545 .42118 Mdot
.54501 .4212 Mdot
.54502 .42122 Mdot
.54503 .42124 Mdot
.54504 .42126 Mdot
.54505 .42128 Mdot
.54506 .4213 Mdot
.54507 .42132 Mdot
.54508 .42134 Mdot
.54509 .42136 Mdot
.5451 .42139 Mdot
.5451 .42141 Mdot
.54511 .42143 Mdot
.54512 .42145 Mdot
.54513 .42147 Mdot
.54514 .42149 Mdot
.54515 .42151 Mdot
.54516 .42153 Mdot
.54517 .42155 Mdot
.54518 .42157 Mdot
.54519 .42159 Mdot
.5452 .42161 Mdot
.54521 .42163 Mdot
.54522 .42165 Mdot
.54523 .42167 Mdot
.54524 .4217 Mdot
.54525 .42172 Mdot
.54526 .42174 Mdot
.54527 .42176 Mdot
.54528 .42178 Mdot
.54529 .4218 Mdot
.5453 .42182 Mdot
.5453 .42184 Mdot
.54531 .42186 Mdot
.54532 .42188 Mdot
.54533 .4219 Mdot
.54534 .42192 Mdot
.54535 .42194 Mdot
.54536 .42196 Mdot
.54537 .42198 Mdot
.54538 .422 Mdot
.54539 .42203 Mdot
.5454 .42205 Mdot
.54541 .42207 Mdot
.54542 .42209 Mdot
.54543 .42211 Mdot
.54544 .42213 Mdot
.54545 .42215 Mdot
.54546 .42217 Mdot
.54547 .42219 Mdot
.54548 .42221 Mdot
.54549 .42223 Mdot
.5455 .42225 Mdot
.5455 .42227 Mdot
.54551 .42229 Mdot
.54552 .42231 Mdot
.54553 .42233 Mdot
.54554 .42236 Mdot
.54555 .42238 Mdot
.54556 .4224 Mdot
.54557 .42242 Mdot
.54558 .42244 Mdot
.54559 .42246 Mdot
.5456 .42248 Mdot
.54561 .4225 Mdot
.54562 .42252 Mdot
.54563 .42254 Mdot
.54564 .42256 Mdot
.54565 .42258 Mdot
.54566 .4226 Mdot
.54567 .42262 Mdot
.54568 .42264 Mdot
.54569 .42266 Mdot
.5457 .42269 Mdot
.5457 .42271 Mdot
.54571 .42273 Mdot
.54572 .42275 Mdot
.54573 .42277 Mdot
.54574 .42279 Mdot
.54575 .42281 Mdot
.54576 .42283 Mdot
.54577 .42285 Mdot
.54578 .42287 Mdot
.54579 .42289 Mdot
.5458 .42291 Mdot
.54581 .42293 Mdot
.54582 .42295 Mdot
.54583 .42297 Mdot
.54584 .42299 Mdot
.54585 .42301 Mdot
.54586 .42304 Mdot
.54587 .42306 Mdot
.54588 .42308 Mdot
.54589 .4231 Mdot
.5459 .42312 Mdot
.5459 .42314 Mdot
.54591 .42316 Mdot
.54592 .42318 Mdot
.54593 .4232 Mdot
.54594 .42322 Mdot
.54595 .42324 Mdot
.54596 .42326 Mdot
.54597 .42328 Mdot
.54598 .4233 Mdot
.54599 .42332 Mdot
.546 .42334 Mdot
.54601 .42336 Mdot
.54602 .42338 Mdot
.54603 .42341 Mdot
.54604 .42343 Mdot
.54605 .42345 Mdot
.54606 .42347 Mdot
.54607 .42349 Mdot
.54608 .42351 Mdot
.54609 .42353 Mdot
.5461 .42355 Mdot
.5461 .42357 Mdot
.54611 .42359 Mdot
.54612 .42361 Mdot
.54613 .42363 Mdot
.54614 .42365 Mdot
.54615 .42367 Mdot
.54616 .42369 Mdot
.54617 .42371 Mdot
.54618 .42373 Mdot
.54619 .42375 Mdot
.5462 .42378 Mdot
.54621 .4238 Mdot
.54622 .42382 Mdot
.54623 .42384 Mdot
.54624 .42386 Mdot
.54625 .42388 Mdot
.54626 .4239 Mdot
.54627 .42392 Mdot
.54628 .42394 Mdot
.54629 .42396 Mdot
.5463 .42398 Mdot
.5463 .424 Mdot
.54631 .42402 Mdot
.54632 .42404 Mdot
.54633 .42406 Mdot
.54634 .42408 Mdot
.54635 .4241 Mdot
.54636 .42412 Mdot
.54637 .42414 Mdot
.54638 .42417 Mdot
.54639 .42419 Mdot
.5464 .42421 Mdot
.54641 .42423 Mdot
.54642 .42425 Mdot
.54643 .42427 Mdot
.54644 .42429 Mdot
.54645 .42431 Mdot
.54646 .42433 Mdot
.54647 .42435 Mdot
.54648 .42437 Mdot
.54649 .42439 Mdot
.5465 .42441 Mdot
.5465 .42443 Mdot
.54651 .42445 Mdot
.54652 .42447 Mdot
.54653 .42449 Mdot
.54654 .42451 Mdot
.54655 .42453 Mdot
.54656 .42455 Mdot
.54657 .42458 Mdot
.54658 .4246 Mdot
.54659 .42462 Mdot
.5466 .42464 Mdot
.54661 .42466 Mdot
.54662 .42468 Mdot
.54663 .4247 Mdot
.54664 .42472 Mdot
.54665 .42474 Mdot
.54666 .42476 Mdot
.54667 .42478 Mdot
.54668 .4248 Mdot
.54669 .42482 Mdot
.5467 .42484 Mdot
.5467 .42486 Mdot
.54671 .42488 Mdot
.54672 .4249 Mdot
.54673 .42492 Mdot
.54674 .42494 Mdot
.54675 .42496 Mdot
.54676 .42498 Mdot
.54677 .42501 Mdot
.54678 .42503 Mdot
.54679 .42505 Mdot
.5468 .42507 Mdot
.54681 .42509 Mdot
.54682 .42511 Mdot
.54683 .42513 Mdot
.54684 .42515 Mdot
.54685 .42517 Mdot
.54686 .42519 Mdot
.54687 .42521 Mdot
.54688 .42523 Mdot
.54689 .42525 Mdot
.5469 .42527 Mdot
.5469 .42529 Mdot
.54691 .42531 Mdot
.54692 .42533 Mdot
.54693 .42535 Mdot
.54694 .42537 Mdot
.54695 .42539 Mdot
.54696 .42541 Mdot
.54697 .42543 Mdot
.54698 .42546 Mdot
.54699 .42548 Mdot
.547 .4255 Mdot
.54701 .42552 Mdot
.54702 .42554 Mdot
.54703 .42556 Mdot
.54704 .42558 Mdot
.54705 .4256 Mdot
.54706 .42562 Mdot
.54707 .42564 Mdot
.54708 .42566 Mdot
.54709 .42568 Mdot
.5471 .4257 Mdot
.5471 .42572 Mdot
.54711 .42574 Mdot
.54712 .42576 Mdot
.54713 .42578 Mdot
.54714 .4258 Mdot
.54715 .42582 Mdot
.54716 .42584 Mdot
.54717 .42586 Mdot
.54718 .42588 Mdot
.54719 .4259 Mdot
.5472 .42593 Mdot
.54721 .42595 Mdot
.54722 .42597 Mdot
.54723 .42599 Mdot
.54724 .42601 Mdot
.54725 .42603 Mdot
.54726 .42605 Mdot
.54727 .42607 Mdot
.54728 .42609 Mdot
.54729 .42611 Mdot
.5473 .42613 Mdot
.5473 .42615 Mdot
.54731 .42617 Mdot
.54732 .42619 Mdot
.54733 .42621 Mdot
.54734 .42623 Mdot
.54735 .42625 Mdot
.54736 .42627 Mdot
.54737 .42629 Mdot
.54738 .42631 Mdot
.54739 .42633 Mdot
.5474 .42635 Mdot
.54741 .42637 Mdot
.54742 .42639 Mdot
.54743 .42641 Mdot
.54744 .42644 Mdot
.54745 .42646 Mdot
.54746 .42648 Mdot
.54747 .4265 Mdot
.54748 .42652 Mdot
.54749 .42654 Mdot
.5475 .42656 Mdot
.5475 .42658 Mdot
.54751 .4266 Mdot
.54752 .42662 Mdot
.54753 .42664 Mdot
.54754 .42666 Mdot
.54755 .42668 Mdot
.54756 .4267 Mdot
.54757 .42672 Mdot
.54758 .42674 Mdot
.54759 .42676 Mdot
.5476 .42678 Mdot
.54761 .4268 Mdot
.54762 .42682 Mdot
.54763 .42684 Mdot
.54764 .42686 Mdot
.54765 .42688 Mdot
.54766 .4269 Mdot
.54767 .42692 Mdot
.54768 .42694 Mdot
.54769 .42696 Mdot
.5477 .42699 Mdot
.5477 .42701 Mdot
.54771 .42703 Mdot
.54772 .42705 Mdot
.54773 .42707 Mdot
.54774 .42709 Mdot
.54775 .42711 Mdot
.54776 .42713 Mdot
.54777 .42715 Mdot
.54778 .42717 Mdot
.54779 .42719 Mdot
.5478 .42721 Mdot
.54781 .42723 Mdot
.54782 .42725 Mdot
.54783 .42727 Mdot
.54784 .42729 Mdot
.54785 .42731 Mdot
.54786 .42733 Mdot
.54787 .42735 Mdot
.54788 .42737 Mdot
.54789 .42739 Mdot
.5479 .42741 Mdot
.5479 .42743 Mdot
.54791 .42745 Mdot
.54792 .42747 Mdot
.54793 .42749 Mdot
.54794 .42751 Mdot
.54795 .42753 Mdot
.54796 .42755 Mdot
.54797 .42758 Mdot
.54798 .4276 Mdot
.54799 .42762 Mdot
.548 .42764 Mdot
.54801 .42766 Mdot
.54802 .42768 Mdot
.54803 .4277 Mdot
.54804 .42772 Mdot
.54805 .42774 Mdot
.54806 .42776 Mdot
.54807 .42778 Mdot
.54808 .4278 Mdot
.54809 .42782 Mdot
.5481 .42784 Mdot
.5481 .42786 Mdot
.54811 .42788 Mdot
.54812 .4279 Mdot
.54813 .42792 Mdot
.54814 .42794 Mdot
.54815 .42796 Mdot
.54816 .42798 Mdot
.54817 .428 Mdot
.54818 .42802 Mdot
.54819 .42804 Mdot
.5482 .42806 Mdot
.54821 .42808 Mdot
.54822 .4281 Mdot
.54823 .42812 Mdot
.54824 .42814 Mdot
.54825 .42816 Mdot
.54826 .42818 Mdot
.54827 .4282 Mdot
.54828 .42822 Mdot
.54829 .42825 Mdot
.5483 .42827 Mdot
.5483 .42829 Mdot
.54831 .42831 Mdot
.54832 .42833 Mdot
.54833 .42835 Mdot
.54834 .42837 Mdot
.54835 .42839 Mdot
.54836 .42841 Mdot
.54837 .42843 Mdot
.54838 .42845 Mdot
.54839 .42847 Mdot
.5484 .42849 Mdot
.54841 .42851 Mdot
.54842 .42853 Mdot
.54843 .42855 Mdot
.54844 .42857 Mdot
.54845 .42859 Mdot
.54846 .42861 Mdot
.54847 .42863 Mdot
.54848 .42865 Mdot
.54849 .42867 Mdot
.5485 .42869 Mdot
.5485 .42871 Mdot
.54851 .42873 Mdot
.54852 .42875 Mdot
.54853 .42877 Mdot
.54854 .42879 Mdot
.54855 .42881 Mdot
.54856 .42883 Mdot
.54857 .42885 Mdot
.54858 .42887 Mdot
.54859 .42889 Mdot
.5486 .42891 Mdot
.54861 .42893 Mdot
.54862 .42895 Mdot
.54863 .42897 Mdot
.54864 .42899 Mdot
.54865 .42902 Mdot
.54866 .42904 Mdot
.54867 .42906 Mdot
.54868 .42908 Mdot
.54869 .4291 Mdot
.5487 .42912 Mdot
.5487 .42914 Mdot
.54871 .42916 Mdot
.54872 .42918 Mdot
.54873 .4292 Mdot
.54874 .42922 Mdot
.54875 .42924 Mdot
.54876 .42926 Mdot
.54877 .42928 Mdot
.54878 .4293 Mdot
.54879 .42932 Mdot
.5488 .42934 Mdot
.54881 .42936 Mdot
.54882 .42938 Mdot
.54883 .4294 Mdot
.54884 .42942 Mdot
.54885 .42944 Mdot
.54886 .42946 Mdot
.54887 .42948 Mdot
.54888 .4295 Mdot
.54889 .42952 Mdot
.5489 .42954 Mdot
.5489 .42956 Mdot
.54891 .42958 Mdot
.54892 .4296 Mdot
.54893 .42962 Mdot
.54894 .42964 Mdot
.54895 .42966 Mdot
.54896 .42968 Mdot
.54897 .4297 Mdot
.54898 .42972 Mdot
.54899 .42974 Mdot
.549 .42976 Mdot
.54901 .42978 Mdot
.54902 .4298 Mdot
.54903 .42982 Mdot
.54904 .42984 Mdot
.54905 .42986 Mdot
.54906 .42988 Mdot
.54907 .4299 Mdot
.54908 .42992 Mdot
.54909 .42995 Mdot
.5491 .42997 Mdot
.5491 .42999 Mdot
.54911 .43001 Mdot
.54912 .43003 Mdot
.54913 .43005 Mdot
.54914 .43007 Mdot
.54915 .43009 Mdot
.54916 .43011 Mdot
.54917 .43013 Mdot
.54918 .43015 Mdot
.54919 .43017 Mdot
.5492 .43019 Mdot
.54921 .43021 Mdot
.54922 .43023 Mdot
.54923 .43025 Mdot
.54924 .43027 Mdot
.54925 .43029 Mdot
.54926 .43031 Mdot
.54927 .43033 Mdot
.54928 .43035 Mdot
.54929 .43037 Mdot
.5493 .43039 Mdot
.5493 .43041 Mdot
.54931 .43043 Mdot
.54932 .43045 Mdot
.54933 .43047 Mdot
.54934 .43049 Mdot
.54935 .43051 Mdot
.54936 .43053 Mdot
.54937 .43055 Mdot
.54938 .43057 Mdot
.54939 .43059 Mdot
.5494 .43061 Mdot
.54941 .43063 Mdot
.54942 .43065 Mdot
.54943 .43067 Mdot
.54944 .43069 Mdot
.54945 .43071 Mdot
.54946 .43073 Mdot
.54947 .43075 Mdot
.54948 .43077 Mdot
.54949 .43079 Mdot
.5495 .43081 Mdot
.5495 .43083 Mdot
.54951 .43085 Mdot
.54952 .43087 Mdot
.54953 .43089 Mdot
.54954 .43091 Mdot
.54955 .43093 Mdot
.54956 .43095 Mdot
.54957 .43097 Mdot
.54958 .43099 Mdot
.54959 .43101 Mdot
.5496 .43103 Mdot
.54961 .43105 Mdot
.54962 .43107 Mdot
.54963 .43109 Mdot
.54964 .43111 Mdot
.54965 .43113 Mdot
.54966 .43115 Mdot
.54967 .43117 Mdot
.54968 .43119 Mdot
.54969 .43121 Mdot
.5497 .43123 Mdot
.5497 .43125 Mdot
.54971 .43128 Mdot
.54972 .4313 Mdot
.54973 .43132 Mdot
.54974 .43134 Mdot
.54975 .43136 Mdot
.54976 .43138 Mdot
.54977 .4314 Mdot
.54978 .43142 Mdot
.54979 .43144 Mdot
.5498 .43146 Mdot
.54981 .43148 Mdot
.54982 .4315 Mdot
.54983 .43152 Mdot
.54984 .43154 Mdot
.54985 .43156 Mdot
.54986 .43158 Mdot
.54987 .4316 Mdot
.54988 .43162 Mdot
.54989 .43164 Mdot
.5499 .43166 Mdot
.5499 .43168 Mdot
.54991 .4317 Mdot
.54992 .43172 Mdot
.54993 .43174 Mdot
.54994 .43176 Mdot
.54995 .43178 Mdot
.54996 .4318 Mdot
.54997 .43182 Mdot
.54998 .43184 Mdot
.54999 .43186 Mdot
.55 .43188 Mdot
.55001 .4319 Mdot
.55002 .43192 Mdot
.55003 .43194 Mdot
.55004 .43196 Mdot
.55005 .43198 Mdot
.55006 .432 Mdot
.55007 .43202 Mdot
.55008 .43204 Mdot
.55009 .43206 Mdot
.5501 .43208 Mdot
.5501 .4321 Mdot
.55011 .43212 Mdot
.55012 .43214 Mdot
.55013 .43216 Mdot
.55014 .43218 Mdot
.55015 .4322 Mdot
.55016 .43222 Mdot
.55017 .43224 Mdot
.55018 .43226 Mdot
.55019 .43228 Mdot
.5502 .4323 Mdot
.55021 .43232 Mdot
.55022 .43234 Mdot
.55023 .43236 Mdot
.55024 .43238 Mdot
.55025 .4324 Mdot
.55026 .43242 Mdot
.55027 .43244 Mdot
.55028 .43246 Mdot
.55029 .43248 Mdot
.5503 .4325 Mdot
.5503 .43252 Mdot
.55031 .43254 Mdot
.55032 .43256 Mdot
.55033 .43258 Mdot
.55034 .4326 Mdot
.55035 .43262 Mdot
.55036 .43264 Mdot
.55037 .43266 Mdot
.55038 .43268 Mdot
.55039 .4327 Mdot
.5504 .43272 Mdot
.55041 .43274 Mdot
.55042 .43276 Mdot
.55043 .43278 Mdot
.55044 .4328 Mdot
.55045 .43282 Mdot
.55046 .43284 Mdot
.55047 .43286 Mdot
.55048 .43288 Mdot
.55049 .4329 Mdot
.5505 .43292 Mdot
.5505 .43294 Mdot
.55051 .43296 Mdot
.55052 .43298 Mdot
.55053 .433 Mdot
.55054 .43302 Mdot
.55055 .43304 Mdot
.55056 .43306 Mdot
.55057 .43308 Mdot
.55058 .4331 Mdot
.55059 .43312 Mdot
.5506 .43314 Mdot
.55061 .43316 Mdot
.55062 .43318 Mdot
.55063 .4332 Mdot
.55064 .43322 Mdot
.55065 .43324 Mdot
.55066 .43326 Mdot
.55067 .43328 Mdot
.55068 .4333 Mdot
.55069 .43332 Mdot
.5507 .43334 Mdot
.5507 .43336 Mdot
.55071 .43338 Mdot
.55072 .4334 Mdot
.55073 .43342 Mdot
.55074 .43344 Mdot
.55075 .43346 Mdot
.55076 .43348 Mdot
.55077 .4335 Mdot
.55078 .43352 Mdot
.55079 .43354 Mdot
.5508 .43356 Mdot
.55081 .43358 Mdot
.55082 .4336 Mdot
.55083 .43362 Mdot
.55084 .43364 Mdot
.55085 .43366 Mdot
.55086 .43368 Mdot
.55087 .4337 Mdot
.55088 .43372 Mdot
.55089 .43374 Mdot
.5509 .43376 Mdot
.5509 .43378 Mdot
.55091 .4338 Mdot
.55092 .43382 Mdot
.55093 .43384 Mdot
.55094 .43386 Mdot
.55095 .43388 Mdot
.55096 .4339 Mdot
.55097 .43392 Mdot
.55098 .43394 Mdot
.55099 .43396 Mdot
.551 .43398 Mdot
.55101 .434 Mdot
.55102 .43402 Mdot
.55103 .43404 Mdot
.55104 .43406 Mdot
.55105 .43408 Mdot
.55106 .4341 Mdot
.55107 .43412 Mdot
.55108 .43414 Mdot
.55109 .43416 Mdot
.5511 .43418 Mdot
.5511 .4342 Mdot
.55111 .43422 Mdot
.55112 .43424 Mdot
.55113 .43426 Mdot
.55114 .43428 Mdot
.55115 .4343 Mdot
.55116 .43432 Mdot
.55117 .43434 Mdot
.55118 .43436 Mdot
.55119 .43438 Mdot
.5512 .4344 Mdot
.55121 .43442 Mdot
.55122 .43444 Mdot
.55123 .43446 Mdot
.55124 .43448 Mdot
.55125 .4345 Mdot
.55126 .43452 Mdot
.55127 .43454 Mdot
.55128 .43456 Mdot
.55129 .43458 Mdot
.5513 .4346 Mdot
.5513 .43462 Mdot
.55131 .43464 Mdot
.55132 .43466 Mdot
.55133 .43468 Mdot
.55134 .4347 Mdot
.55135 .43472 Mdot
.55136 .43474 Mdot
.55137 .43476 Mdot
.55138 .43478 Mdot
.55139 .4348 Mdot
.5514 .43482 Mdot
.55141 .43484 Mdot
.55142 .43486 Mdot
.55143 .43488 Mdot
.55144 .4349 Mdot
.55145 .43492 Mdot
.55146 .43494 Mdot
.55147 .43496 Mdot
.55148 .43498 Mdot
.55149 .435 Mdot
.5515 .43502 Mdot
.5515 .43504 Mdot
.55151 .43506 Mdot
.55152 .43508 Mdot
.55153 .4351 Mdot
.55154 .43512 Mdot
.55155 .43514 Mdot
.55156 .43516 Mdot
.55157 .43518 Mdot
.55158 .4352 Mdot
.55159 .43522 Mdot
.5516 .43523 Mdot
.55161 .43525 Mdot
.55162 .43527 Mdot
.55163 .43529 Mdot
.55164 .43531 Mdot
.55165 .43533 Mdot
.55166 .43535 Mdot
.55167 .43537 Mdot
.55168 .43539 Mdot
.55169 .43541 Mdot
.5517 .43543 Mdot
.5517 .43545 Mdot
.55171 .43547 Mdot
.55172 .43549 Mdot
.55173 .43551 Mdot
.55174 .43553 Mdot
.55175 .43555 Mdot
.55176 .43557 Mdot
.55177 .43559 Mdot
.55178 .43561 Mdot
.55179 .43563 Mdot
.5518 .43565 Mdot
.55181 .43567 Mdot
.55182 .43569 Mdot
.55183 .43571 Mdot
.55184 .43573 Mdot
.55185 .43575 Mdot
.55186 .43577 Mdot
.55187 .43579 Mdot
.55188 .43581 Mdot
.55189 .43583 Mdot
.5519 .43585 Mdot
.5519 .43587 Mdot
.55191 .43589 Mdot
.55192 .43591 Mdot
.55193 .43593 Mdot
.55194 .43595 Mdot
.55195 .43597 Mdot
.55196 .43599 Mdot
.55197 .43601 Mdot
.55198 .43603 Mdot
.55199 .43605 Mdot
.552 .43607 Mdot
.55201 .43609 Mdot
.55202 .43611 Mdot
.55203 .43613 Mdot
.55204 .43615 Mdot
.55205 .43617 Mdot
.55206 .43619 Mdot
.55207 .43621 Mdot
.55208 .43623 Mdot
.55209 .43625 Mdot
.5521 .43627 Mdot
.5521 .43629 Mdot
.55211 .43631 Mdot
.55212 .43633 Mdot
.55213 .43635 Mdot
.55214 .43637 Mdot
.55215 .43639 Mdot
.55216 .43641 Mdot
.55217 .43643 Mdot
.55218 .43645 Mdot
.55219 .43647 Mdot
.5522 .43649 Mdot
.55221 .43651 Mdot
.55222 .43653 Mdot
.55223 .43654 Mdot
.55224 .43656 Mdot
.55225 .43658 Mdot
.55226 .4366 Mdot
.55227 .43662 Mdot
.55228 .43664 Mdot
.55229 .43666 Mdot
.5523 .43668 Mdot
.5523 .4367 Mdot
.55231 .43672 Mdot
.55232 .43674 Mdot
.55233 .43676 Mdot
.55234 .43678 Mdot
.55235 .4368 Mdot
.55236 .43682 Mdot
.55237 .43684 Mdot
.55238 .43686 Mdot
.55239 .43688 Mdot
.5524 .4369 Mdot
.55241 .43692 Mdot
.55242 .43694 Mdot
.55243 .43696 Mdot
.55244 .43698 Mdot
.55245 .437 Mdot
.55246 .43702 Mdot
.55247 .43704 Mdot
.55248 .43706 Mdot
.55249 .43708 Mdot
.5525 .4371 Mdot
.5525 .43712 Mdot
.55251 .43714 Mdot
.55252 .43716 Mdot
.55253 .43718 Mdot
.55254 .4372 Mdot
.55255 .43722 Mdot
.55256 .43724 Mdot
.55257 .43726 Mdot
.55258 .43728 Mdot
.55259 .4373 Mdot
.5526 .43732 Mdot
.55261 .43734 Mdot
.55262 .43736 Mdot
.55263 .43738 Mdot
.55264 .4374 Mdot
.55265 .43742 Mdot
.55266 .43744 Mdot
.55267 .43745 Mdot
.55268 .43747 Mdot
.55269 .43749 Mdot
.5527 .43751 Mdot
.5527 .43753 Mdot
.55271 .43755 Mdot
.55272 .43757 Mdot
.55273 .43759 Mdot
.55274 .43761 Mdot
.55275 .43763 Mdot
.55276 .43765 Mdot
.55277 .43767 Mdot
.55278 .43769 Mdot
.55279 .43771 Mdot
.5528 .43773 Mdot
.55281 .43775 Mdot
.55282 .43777 Mdot
.55283 .43779 Mdot
.55284 .43781 Mdot
.55285 .43783 Mdot
.55286 .43785 Mdot
.55287 .43787 Mdot
.55288 .43789 Mdot
.55289 .43791 Mdot
.5529 .43793 Mdot
.5529 .43795 Mdot
.55291 .43797 Mdot
.55292 .43799 Mdot
.55293 .43801 Mdot
.55294 .43803 Mdot
.55295 .43805 Mdot
.55296 .43807 Mdot
.55297 .43809 Mdot
.55298 .43811 Mdot
.55299 .43813 Mdot
.553 .43815 Mdot
.55301 .43817 Mdot
.55302 .43819 Mdot
.55303 .4382 Mdot
.55304 .43822 Mdot
.55305 .43824 Mdot
.55306 .43826 Mdot
.55307 .43828 Mdot
.55308 .4383 Mdot
.55309 .43832 Mdot
.5531 .43834 Mdot
.5531 .43836 Mdot
.55311 .43838 Mdot
.55312 .4384 Mdot
.55313 .43842 Mdot
.55314 .43844 Mdot
.55315 .43846 Mdot
.55316 .43848 Mdot
.55317 .4385 Mdot
.55318 .43852 Mdot
.55319 .43854 Mdot
.5532 .43856 Mdot
.55321 .43858 Mdot
.55322 .4386 Mdot
.55323 .43862 Mdot
.55324 .43864 Mdot
.55325 .43866 Mdot
.55326 .43868 Mdot
.55327 .4387 Mdot
.55328 .43872 Mdot
.55329 .43874 Mdot
.5533 .43876 Mdot
.5533 .43878 Mdot
.55331 .4388 Mdot
.55332 .43882 Mdot
.55333 .43883 Mdot
.55334 .43885 Mdot
.55335 .43887 Mdot
.55336 .43889 Mdot
.55337 .43891 Mdot
.55338 .43893 Mdot
.55339 .43895 Mdot
.5534 .43897 Mdot
.55341 .43899 Mdot
.55342 .43901 Mdot
.55343 .43903 Mdot
.55344 .43905 Mdot
.55345 .43907 Mdot
.55346 .43909 Mdot
.55347 .43911 Mdot
.55348 .43913 Mdot
.55349 .43915 Mdot
.5535 .43917 Mdot
.5535 .43919 Mdot
.55351 .43921 Mdot
.55352 .43923 Mdot
.55353 .43925 Mdot
.55354 .43927 Mdot
.55355 .43929 Mdot
.55356 .43931 Mdot
.55357 .43933 Mdot
.55358 .43935 Mdot
.55359 .43937 Mdot
.5536 .43939 Mdot
.55361 .4394 Mdot
.55362 .43942 Mdot
.55363 .43944 Mdot
.55364 .43946 Mdot
.55365 .43948 Mdot
.55366 .4395 Mdot
.55367 .43952 Mdot
.55368 .43954 Mdot
.55369 .43956 Mdot
.5537 .43958 Mdot
.5537 .4396 Mdot
.55371 .43962 Mdot
.55372 .43964 Mdot
.55373 .43966 Mdot
.55374 .43968 Mdot
.55375 .4397 Mdot
.55376 .43972 Mdot
.55377 .43974 Mdot
.55378 .43976 Mdot
.55379 .43978 Mdot
.5538 .4398 Mdot
.55381 .43982 Mdot
.55382 .43984 Mdot
.55383 .43986 Mdot
.55384 .43988 Mdot
.55385 .4399 Mdot
.55386 .43992 Mdot
.55387 .43993 Mdot
.55388 .43995 Mdot
.55389 .43997 Mdot
.5539 .43999 Mdot
.5539 .44001 Mdot
.55391 .44003 Mdot
.55392 .44005 Mdot
.55393 .44007 Mdot
.55394 .44009 Mdot
.55395 .44011 Mdot
.55396 .44013 Mdot
.55397 .44015 Mdot
.55398 .44017 Mdot
.55399 .44019 Mdot
.554 .44021 Mdot
.55401 .44023 Mdot
.55402 .44025 Mdot
.55403 .44027 Mdot
.55404 .44029 Mdot
.55405 .44031 Mdot
.55406 .44033 Mdot
.55407 .44035 Mdot
.55408 .44037 Mdot
.55409 .44039 Mdot
.5541 .44041 Mdot
.5541 .44042 Mdot
.55411 .44044 Mdot
.55412 .44046 Mdot
.55413 .44048 Mdot
.55414 .4405 Mdot
.55415 .44052 Mdot
.55416 .44054 Mdot
.55417 .44056 Mdot
.55418 .44058 Mdot
.55419 .4406 Mdot
.5542 .44062 Mdot
.55421 .44064 Mdot
.55422 .44066 Mdot
.55423 .44068 Mdot
.55424 .4407 Mdot
.55425 .44072 Mdot
.55426 .44074 Mdot
.55427 .44076 Mdot
.55428 .44078 Mdot
.55429 .4408 Mdot
.5543 .44082 Mdot
.5543 .44084 Mdot
.55431 .44086 Mdot
.55432 .44087 Mdot
.55433 .44089 Mdot
.55434 .44091 Mdot
.55435 .44093 Mdot
.55436 .44095 Mdot
.55437 .44097 Mdot
.55438 .44099 Mdot
.55439 .44101 Mdot
.5544 .44103 Mdot
.55441 .44105 Mdot
.55442 .44107 Mdot
.55443 .44109 Mdot
.55444 .44111 Mdot
.55445 .44113 Mdot
.55446 .44115 Mdot
.55447 .44117 Mdot
.55448 .44119 Mdot
.55449 .44121 Mdot
.5545 .44123 Mdot
.5545 .44125 Mdot
.55451 .44127 Mdot
.55452 .44129 Mdot
.55453 .4413 Mdot
.55454 .44132 Mdot
.55455 .44134 Mdot
.55456 .44136 Mdot
.55457 .44138 Mdot
.55458 .4414 Mdot
.55459 .44142 Mdot
.5546 .44144 Mdot
.55461 .44146 Mdot
.55462 .44148 Mdot
.55463 .4415 Mdot
.55464 .44152 Mdot
.55465 .44154 Mdot
.55466 .44156 Mdot
.55467 .44158 Mdot
.55468 .4416 Mdot
.55469 .44162 Mdot
.5547 .44164 Mdot
.5547 .44166 Mdot
.55471 .44168 Mdot
.55472 .4417 Mdot
.55473 .44171 Mdot
.55474 .44173 Mdot
.55475 .44175 Mdot
.55476 .44177 Mdot
.55477 .44179 Mdot
.55478 .44181 Mdot
.55479 .44183 Mdot
.5548 .44185 Mdot
.55481 .44187 Mdot
.55482 .44189 Mdot
.55483 .44191 Mdot
.55484 .44193 Mdot
.55485 .44195 Mdot
.55486 .44197 Mdot
.55487 .44199 Mdot
.55488 .44201 Mdot
.55489 .44203 Mdot
.5549 .44205 Mdot
.5549 .44207 Mdot
.55491 .44209 Mdot
.55492 .4421 Mdot
.55493 .44212 Mdot
.55494 .44214 Mdot
.55495 .44216 Mdot
.55496 .44218 Mdot
.55497 .4422 Mdot
.55498 .44222 Mdot
.55499 .44224 Mdot
.555 .44226 Mdot
.55501 .44228 Mdot
.55502 .4423 Mdot
.55503 .44232 Mdot
.55504 .44234 Mdot
.55505 .44236 Mdot
.55506 .44238 Mdot
.55507 .4424 Mdot
.55508 .44242 Mdot
.55509 .44244 Mdot
.5551 .44246 Mdot
.5551 .44247 Mdot
.55511 .44249 Mdot
.55512 .44251 Mdot
.55513 .44253 Mdot
.55514 .44255 Mdot
.55515 .44257 Mdot
.55516 .44259 Mdot
.55517 .44261 Mdot
.55518 .44263 Mdot
.55519 .44265 Mdot
.5552 .44267 Mdot
.55521 .44269 Mdot
.55522 .44271 Mdot
.55523 .44273 Mdot
.55524 .44275 Mdot
.55525 .44277 Mdot
.55526 .44279 Mdot
.55527 .44281 Mdot
.55528 .44282 Mdot
.55529 .44284 Mdot
.5553 .44286 Mdot
.5553 .44288 Mdot
.55531 .4429 Mdot
.55532 .44292 Mdot
.55533 .44294 Mdot
.55534 .44296 Mdot
.55535 .44298 Mdot
.55536 .443 Mdot
.55537 .44302 Mdot
.55538 .44304 Mdot
.55539 .44306 Mdot
.5554 .44308 Mdot
.55541 .4431 Mdot
.55542 .44312 Mdot
.55543 .44314 Mdot
.55544 .44315 Mdot
.55545 .44317 Mdot
.55546 .44319 Mdot
.55547 .44321 Mdot
.55548 .44323 Mdot
.55549 .44325 Mdot
.5555 .44327 Mdot
.5555 .44329 Mdot
.55551 .44331 Mdot
.55552 .44333 Mdot
.55553 .44335 Mdot
.55554 .44337 Mdot
.55555 .44339 Mdot
.55556 .44341 Mdot
.55557 .44343 Mdot
.55558 .44345 Mdot
.55559 .44347 Mdot
.5556 .44348 Mdot
.55561 .4435 Mdot
.55562 .44352 Mdot
.55563 .44354 Mdot
.55564 .44356 Mdot
.55565 .44358 Mdot
.55566 .4436 Mdot
.55567 .44362 Mdot
.55568 .44364 Mdot
.55569 .44366 Mdot
.5557 .44368 Mdot
.5557 .4437 Mdot
.55571 .44372 Mdot
.55572 .44374 Mdot
.55573 .44376 Mdot
.55574 .44378 Mdot
.55575 .4438 Mdot
.55576 .44381 Mdot
.55577 .44383 Mdot
.55578 .44385 Mdot
.55579 .44387 Mdot
.5558 .44389 Mdot
.55581 .44391 Mdot
.55582 .44393 Mdot
.55583 .44395 Mdot
.55584 .44397 Mdot
.55585 .44399 Mdot
.55586 .44401 Mdot
.55587 .44403 Mdot
.55588 .44405 Mdot
.55589 .44407 Mdot
.5559 .44409 Mdot
.5559 .44411 Mdot
.55591 .44412 Mdot
.55592 .44414 Mdot
.55593 .44416 Mdot
.55594 .44418 Mdot
.55595 .4442 Mdot
.55596 .44422 Mdot
.55597 .44424 Mdot
.55598 .44426 Mdot
.55599 .44428 Mdot
.556 .4443 Mdot
.55601 .44432 Mdot
.55602 .44434 Mdot
.55603 .44436 Mdot
.55604 .44438 Mdot
.55605 .4444 Mdot
.55606 .44441 Mdot
.55607 .44443 Mdot
.55608 .44445 Mdot
.55609 .44447 Mdot
.5561 .44449 Mdot
.5561 .44451 Mdot
.55611 .44453 Mdot
.55612 .44455 Mdot
.55613 .44457 Mdot
.55614 .44459 Mdot
.55615 .44461 Mdot
.55616 .44463 Mdot
.55617 .44465 Mdot
.55618 .44467 Mdot
.55619 .44469 Mdot
.5562 .4447 Mdot
.55621 .44472 Mdot
.55622 .44474 Mdot
.55623 .44476 Mdot
.55624 .44478 Mdot
.55625 .4448 Mdot
.55626 .44482 Mdot
.55627 .44484 Mdot
.55628 .44486 Mdot
.55629 .44488 Mdot
.5563 .4449 Mdot
.5563 .44492 Mdot
.55631 .44494 Mdot
.55632 .44496 Mdot
.55633 .44498 Mdot
.55634 .44499 Mdot
.55635 .44501 Mdot
.55636 .44503 Mdot
.55637 .44505 Mdot
.55638 .44507 Mdot
.55639 .44509 Mdot
.5564 .44511 Mdot
.55641 .44513 Mdot
.55642 .44515 Mdot
.55643 .44517 Mdot
.55644 .44519 Mdot
.55645 .44521 Mdot
.55646 .44523 Mdot
.55647 .44525 Mdot
.55648 .44526 Mdot
.55649 .44528 Mdot
.5565 .4453 Mdot
.5565 .44532 Mdot
.55651 .44534 Mdot
.55652 .44536 Mdot
.55653 .44538 Mdot
.55654 .4454 Mdot
.55655 .44542 Mdot
.55656 .44544 Mdot
.55657 .44546 Mdot
.55658 .44548 Mdot
.55659 .4455 Mdot
.5566 .44552 Mdot
.55661 .44553 Mdot
.55662 .44555 Mdot
.55663 .44557 Mdot
.55664 .44559 Mdot
.55665 .44561 Mdot
.55666 .44563 Mdot
.55667 .44565 Mdot
.55668 .44567 Mdot
.55669 .44569 Mdot
.5567 .44571 Mdot
.5567 .44573 Mdot
.55671 .44575 Mdot
.55672 .44577 Mdot
.55673 .44579 Mdot
.55674 .4458 Mdot
.55675 .44582 Mdot
.55676 .44584 Mdot
.55677 .44586 Mdot
.55678 .44588 Mdot
.55679 .4459 Mdot
.5568 .44592 Mdot
.55681 .44594 Mdot
.55682 .44596 Mdot
.55683 .44598 Mdot
.55684 .446 Mdot
.55685 .44602 Mdot
.55686 .44604 Mdot
.55687 .44605 Mdot
.55688 .44607 Mdot
.55689 .44609 Mdot
.5569 .44611 Mdot
.5569 .44613 Mdot
.55691 .44615 Mdot
.55692 .44617 Mdot
.55693 .44619 Mdot
.55694 .44621 Mdot
.55695 .44623 Mdot
.55696 .44625 Mdot
.55697 .44627 Mdot
.55698 .44629 Mdot
.55699 .4463 Mdot
.557 .44632 Mdot
.55701 .44634 Mdot
.55702 .44636 Mdot
.55703 .44638 Mdot
.55704 .4464 Mdot
.55705 .44642 Mdot
.55706 .44644 Mdot
.55707 .44646 Mdot
.55708 .44648 Mdot
.55709 .4465 Mdot
.5571 .44652 Mdot
.5571 .44654 Mdot
.55711 .44655 Mdot
.55712 .44657 Mdot
.55713 .44659 Mdot
.55714 .44661 Mdot
.55715 .44663 Mdot
.55716 .44665 Mdot
.55717 .44667 Mdot
.55718 .44669 Mdot
.55719 .44671 Mdot
.5572 .44673 Mdot
.55721 .44675 Mdot
.55722 .44677 Mdot
.55723 .44679 Mdot
.55724 .4468 Mdot
.55725 .44682 Mdot
.55726 .44684 Mdot
.55727 .44686 Mdot
.55728 .44688 Mdot
.55729 .4469 Mdot
.5573 .44692 Mdot
.5573 .44694 Mdot
.55731 .44696 Mdot
.55732 .44698 Mdot
.55733 .447 Mdot
.55734 .44702 Mdot
.55735 .44703 Mdot
.55736 .44705 Mdot
.55737 .44707 Mdot
.55738 .44709 Mdot
.55739 .44711 Mdot
.5574 .44713 Mdot
.55741 .44715 Mdot
.55742 .44717 Mdot
.55743 .44719 Mdot
.55744 .44721 Mdot
.55745 .44723 Mdot
.55746 .44725 Mdot
.55747 .44726 Mdot
.55748 .44728 Mdot
.55749 .4473 Mdot
.5575 .44732 Mdot
.5575 .44734 Mdot
.55751 .44736 Mdot
.55752 .44738 Mdot
.55753 .4474 Mdot
.55754 .44742 Mdot
.55755 .44744 Mdot
.55756 .44746 Mdot
.55757 .44748 Mdot
.55758 .44749 Mdot
.55759 .44751 Mdot
.5576 .44753 Mdot
.55761 .44755 Mdot
.55762 .44757 Mdot
.55763 .44759 Mdot
.55764 .44761 Mdot
.55765 .44763 Mdot
.55766 .44765 Mdot
.55767 .44767 Mdot
.55768 .44769 Mdot
.55769 .44771 Mdot
.5577 .44772 Mdot
.5577 .44774 Mdot
.55771 .44776 Mdot
.55772 .44778 Mdot
.55773 .4478 Mdot
.55774 .44782 Mdot
.55775 .44784 Mdot
.55776 .44786 Mdot
.55777 .44788 Mdot
.55778 .4479 Mdot
.55779 .44792 Mdot
.5578 .44794 Mdot
.55781 .44795 Mdot
.55782 .44797 Mdot
.55783 .44799 Mdot
.55784 .44801 Mdot
.55785 .44803 Mdot
.55786 .44805 Mdot
.55787 .44807 Mdot
.55788 .44809 Mdot
.55789 .44811 Mdot
.5579 .44813 Mdot
.5579 .44815 Mdot
.55791 .44816 Mdot
.55792 .44818 Mdot
.55793 .4482 Mdot
.55794 .44822 Mdot
.55795 .44824 Mdot
.55796 .44826 Mdot
.55797 .44828 Mdot
.55798 .4483 Mdot
.55799 .44832 Mdot
.558 .44834 Mdot
.55801 .44836 Mdot
.55802 .44837 Mdot
.55803 .44839 Mdot
.55804 .44841 Mdot
.55805 .44843 Mdot
.55806 .44845 Mdot
.55807 .44847 Mdot
.55808 .44849 Mdot
.55809 .44851 Mdot
.5581 .44853 Mdot
.5581 .44855 Mdot
.55811 .44857 Mdot
.55812 .44859 Mdot
.55813 .4486 Mdot
.55814 .44862 Mdot
.55815 .44864 Mdot
.55816 .44866 Mdot
.55817 .44868 Mdot
.55818 .4487 Mdot
.55819 .44872 Mdot
.5582 .44874 Mdot
.55821 .44876 Mdot
.55822 .44878 Mdot
.55823 .4488 Mdot
.55824 .44881 Mdot
.55825 .44883 Mdot
.55826 .44885 Mdot
.55827 .44887 Mdot
.55828 .44889 Mdot
.55829 .44891 Mdot
.5583 .44893 Mdot
.5583 .44895 Mdot
.55831 .44897 Mdot
.55832 .44899 Mdot
.55833 .449 Mdot
.55834 .44902 Mdot
.55835 .44904 Mdot
.55836 .44906 Mdot
.55837 .44908 Mdot
.55838 .4491 Mdot
.55839 .44912 Mdot
.5584 .44914 Mdot
.55841 .44916 Mdot
.55842 .44918 Mdot
.55843 .4492 Mdot
.55844 .44921 Mdot
.55845 .44923 Mdot
.55846 .44925 Mdot
.55847 .44927 Mdot
.55848 .44929 Mdot
.55849 .44931 Mdot
.5585 .44933 Mdot
.5585 .44935 Mdot
.55851 .44937 Mdot
.55852 .44939 Mdot
.55853 .4494 Mdot
.55854 .44942 Mdot
.55855 .44944 Mdot
.55856 .44946 Mdot
.55857 .44948 Mdot
.55858 .4495 Mdot
.55859 .44952 Mdot
.5586 .44954 Mdot
.55861 .44956 Mdot
.55862 .44958 Mdot
.55863 .4496 Mdot
.55864 .44961 Mdot
.55865 .44963 Mdot
.55866 .44965 Mdot
.55867 .44967 Mdot
.55868 .44969 Mdot
.55869 .44971 Mdot
.5587 .44973 Mdot
.5587 .44975 Mdot
.55871 .44977 Mdot
.55872 .44979 Mdot
.55873 .4498 Mdot
.55874 .44982 Mdot
.55875 .44984 Mdot
.55876 .44986 Mdot
.55877 .44988 Mdot
.55878 .4499 Mdot
.55879 .44992 Mdot
.5588 .44994 Mdot
.55881 .44996 Mdot
.55882 .44998 Mdot
.55883 .44999 Mdot
.55884 .45001 Mdot
.55885 .45003 Mdot
.55886 .45005 Mdot
.55887 .45007 Mdot
.55888 .45009 Mdot
.55889 .45011 Mdot
.5589 .45013 Mdot
.5589 .45015 Mdot
.55891 .45017 Mdot
.55892 .45018 Mdot
.55893 .4502 Mdot
.55894 .45022 Mdot
.55895 .45024 Mdot
.55896 .45026 Mdot
.55897 .45028 Mdot
.55898 .4503 Mdot
.55899 .45032 Mdot
.559 .45034 Mdot
.55901 .45036 Mdot
.55902 .45037 Mdot
.55903 .45039 Mdot
.55904 .45041 Mdot
.55905 .45043 Mdot
.55906 .45045 Mdot
.55907 .45047 Mdot
.55908 .45049 Mdot
.55909 .45051 Mdot
.5591 .45053 Mdot
.5591 .45055 Mdot
.55911 .45056 Mdot
.55912 .45058 Mdot
.55913 .4506 Mdot
.55914 .45062 Mdot
.55915 .45064 Mdot
.55916 .45066 Mdot
.55917 .45068 Mdot
.55918 .4507 Mdot
.55919 .45072 Mdot
.5592 .45074 Mdot
.55921 .45075 Mdot
.55922 .45077 Mdot
.55923 .45079 Mdot
.55924 .45081 Mdot
.55925 .45083 Mdot
.55926 .45085 Mdot
.55927 .45087 Mdot
.55928 .45089 Mdot
.55929 .45091 Mdot
.5593 .45092 Mdot
.5593 .45094 Mdot
.55931 .45096 Mdot
.55932 .45098 Mdot
.55933 .451 Mdot
.55934 .45102 Mdot
.55935 .45104 Mdot
.55936 .45106 Mdot
.55937 .45108 Mdot
.55938 .4511 Mdot
.55939 .45111 Mdot
.5594 .45113 Mdot
.55941 .45115 Mdot
.55942 .45117 Mdot
.55943 .45119 Mdot
.55944 .45121 Mdot
.55945 .45123 Mdot
.55946 .45125 Mdot
.55947 .45127 Mdot
.55948 .45128 Mdot
.55949 .4513 Mdot
.5595 .45132 Mdot
.5595 .45134 Mdot
.55951 .45136 Mdot
.55952 .45138 Mdot
.55953 .4514 Mdot
.55954 .45142 Mdot
.55955 .45144 Mdot
.55956 .45145 Mdot
.55957 .45147 Mdot
.55958 .45149 Mdot
.55959 .45151 Mdot
.5596 .45153 Mdot
.55961 .45155 Mdot
.55962 .45157 Mdot
.55963 .45159 Mdot
.55964 .45161 Mdot
.55965 .45162 Mdot
.55966 .45164 Mdot
.55967 .45166 Mdot
.55968 .45168 Mdot
.55969 .4517 Mdot
.5597 .45172 Mdot
.5597 .45174 Mdot
.55971 .45176 Mdot
.55972 .45178 Mdot
.55973 .4518 Mdot
.55974 .45181 Mdot
.55975 .45183 Mdot
.55976 .45185 Mdot
.55977 .45187 Mdot
.55978 .45189 Mdot
.55979 .45191 Mdot
.5598 .45193 Mdot
.55981 .45195 Mdot
.55982 .45197 Mdot
.55983 .45198 Mdot
.55984 .452 Mdot
.55985 .45202 Mdot
.55986 .45204 Mdot
.55987 .45206 Mdot
.55988 .45208 Mdot
.55989 .4521 Mdot
.5599 .45212 Mdot
.5599 .45214 Mdot
.55991 .45215 Mdot
.55992 .45217 Mdot
.55993 .45219 Mdot
.55994 .45221 Mdot
.55995 .45223 Mdot
.55996 .45225 Mdot
.55997 .45227 Mdot
.55998 .45229 Mdot
.55999 .4523 Mdot
.56 .45232 Mdot
.56001 .45234 Mdot
.56002 .45236 Mdot
.56003 .45238 Mdot
.56004 .4524 Mdot
.56005 .45242 Mdot
.56006 .45244 Mdot
.56007 .45246 Mdot
.56008 .45247 Mdot
.56009 .45249 Mdot
.5601 .45251 Mdot
.5601 .45253 Mdot
.56011 .45255 Mdot
.56012 .45257 Mdot
.56013 .45259 Mdot
.56014 .45261 Mdot
.56015 .45263 Mdot
.56016 .45264 Mdot
.56017 .45266 Mdot
.56018 .45268 Mdot
.56019 .4527 Mdot
.5602 .45272 Mdot
.56021 .45274 Mdot
.56022 .45276 Mdot
.56023 .45278 Mdot
.56024 .45279 Mdot
.56025 .45281 Mdot
.56026 .45283 Mdot
.56027 .45285 Mdot
.56028 .45287 Mdot
.56029 .45289 Mdot
.5603 .45291 Mdot
.5603 .45293 Mdot
.56031 .45295 Mdot
.56032 .45296 Mdot
.56033 .45298 Mdot
.56034 .453 Mdot
.56035 .45302 Mdot
.56036 .45304 Mdot
.56037 .45306 Mdot
.56038 .45308 Mdot
.56039 .4531 Mdot
.5604 .45311 Mdot
.56041 .45313 Mdot
.56042 .45315 Mdot
.56043 .45317 Mdot
.56044 .45319 Mdot
.56045 .45321 Mdot
.56046 .45323 Mdot
.56047 .45325 Mdot
.56048 .45327 Mdot
.56049 .45328 Mdot
.5605 .4533 Mdot
.5605 .45332 Mdot
.56051 .45334 Mdot
.56052 .45336 Mdot
.56053 .45338 Mdot
.56054 .4534 Mdot
.56055 .45342 Mdot
.56056 .45343 Mdot
.56057 .45345 Mdot
.56058 .45347 Mdot
.56059 .45349 Mdot
.5606 .45351 Mdot
.56061 .45353 Mdot
.56062 .45355 Mdot
.56063 .45357 Mdot
.56064 .45358 Mdot
.56065 .4536 Mdot
.56066 .45362 Mdot
.56067 .45364 Mdot
.56068 .45366 Mdot
.56069 .45368 Mdot
.5607 .4537 Mdot
.5607 .45372 Mdot
.56071 .45374 Mdot
.56072 .45375 Mdot
.56073 .45377 Mdot
.56074 .45379 Mdot
.56075 .45381 Mdot
.56076 .45383 Mdot
.56077 .45385 Mdot
.56078 .45387 Mdot
.56079 .45389 Mdot
.5608 .4539 Mdot
.56081 .45392 Mdot
.56082 .45394 Mdot
.56083 .45396 Mdot
.56084 .45398 Mdot
.56085 .454 Mdot
.56086 .45402 Mdot
.56087 .45404 Mdot
.56088 .45405 Mdot
.56089 .45407 Mdot
.5609 .45409 Mdot
.5609 .45411 Mdot
.56091 .45413 Mdot
.56092 .45415 Mdot
.56093 .45417 Mdot
.56094 .45419 Mdot
.56095 .4542 Mdot
.56096 .45422 Mdot
.56097 .45424 Mdot
.56098 .45426 Mdot
.56099 .45428 Mdot
.561 .4543 Mdot
.56101 .45432 Mdot
.56102 .45434 Mdot
.56103 .45435 Mdot
.56104 .45437 Mdot
.56105 .45439 Mdot
.56106 .45441 Mdot
.56107 .45443 Mdot
.56108 .45445 Mdot
.56109 .45447 Mdot
.5611 .45449 Mdot
.5611 .4545 Mdot
.56111 .45452 Mdot
.56112 .45454 Mdot
.56113 .45456 Mdot
.56114 .45458 Mdot
.56115 .4546 Mdot
.56116 .45462 Mdot
.56117 .45464 Mdot
.56118 .45465 Mdot
.56119 .45467 Mdot
.5612 .45469 Mdot
.56121 .45471 Mdot
.56122 .45473 Mdot
.56123 .45475 Mdot
.56124 .45477 Mdot
.56125 .45478 Mdot
.56126 .4548 Mdot
.56127 .45482 Mdot
.56128 .45484 Mdot
.56129 .45486 Mdot
.5613 .45488 Mdot
.5613 .4549 Mdot
.56131 .45492 Mdot
.56132 .45493 Mdot
.56133 .45495 Mdot
.56134 .45497 Mdot
.56135 .45499 Mdot
.56136 .45501 Mdot
.56137 .45503 Mdot
.56138 .45505 Mdot
.56139 .45507 Mdot
.5614 .45508 Mdot
.56141 .4551 Mdot
.56142 .45512 Mdot
.56143 .45514 Mdot
.56144 .45516 Mdot
.56145 .45518 Mdot
.56146 .4552 Mdot
.56147 .45521 Mdot
.56148 .45523 Mdot
.56149 .45525 Mdot
.5615 .45527 Mdot
.5615 .45529 Mdot
.56151 .45531 Mdot
.56152 .45533 Mdot
.56153 .45535 Mdot
.56154 .45536 Mdot
.56155 .45538 Mdot
.56156 .4554 Mdot
.56157 .45542 Mdot
.56158 .45544 Mdot
.56159 .45546 Mdot
.5616 .45548 Mdot
.56161 .4555 Mdot
.56162 .45551 Mdot
.56163 .45553 Mdot
.56164 .45555 Mdot
.56165 .45557 Mdot
.56166 .45559 Mdot
.56167 .45561 Mdot
.56168 .45563 Mdot
.56169 .45564 Mdot
.5617 .45566 Mdot
.5617 .45568 Mdot
.56171 .4557 Mdot
.56172 .45572 Mdot
.56173 .45574 Mdot
.56174 .45576 Mdot
.56175 .45577 Mdot
.56176 .45579 Mdot
.56177 .45581 Mdot
.56178 .45583 Mdot
.56179 .45585 Mdot
.5618 .45587 Mdot
.56181 .45589 Mdot
.56182 .45591 Mdot
.56183 .45592 Mdot
.56184 .45594 Mdot
.56185 .45596 Mdot
.56186 .45598 Mdot
.56187 .456 Mdot
.56188 .45602 Mdot
.56189 .45604 Mdot
.5619 .45605 Mdot
.5619 .45607 Mdot
.56191 .45609 Mdot
.56192 .45611 Mdot
.56193 .45613 Mdot
.56194 .45615 Mdot
.56195 .45617 Mdot
.56196 .45618 Mdot
.56197 .4562 Mdot
.56198 .45622 Mdot
.56199 .45624 Mdot
.562 .45626 Mdot
.56201 .45628 Mdot
.56202 .4563 Mdot
.56203 .45632 Mdot
.56204 .45633 Mdot
.56205 .45635 Mdot
.56206 .45637 Mdot
.56207 .45639 Mdot
.56208 .45641 Mdot
.56209 .45643 Mdot
.5621 .45645 Mdot
.5621 .45646 Mdot
.56211 .45648 Mdot
.56212 .4565 Mdot
.56213 .45652 Mdot
.56214 .45654 Mdot
.56215 .45656 Mdot
.56216 .45658 Mdot
.56217 .45659 Mdot
.56218 .45661 Mdot
.56219 .45663 Mdot
.5622 .45665 Mdot
.56221 .45667 Mdot
.56222 .45669 Mdot
.56223 .45671 Mdot
.56224 .45672 Mdot
.56225 .45674 Mdot
.56226 .45676 Mdot
.56227 .45678 Mdot
.56228 .4568 Mdot
.56229 .45682 Mdot
.5623 .45684 Mdot
.5623 .45685 Mdot
.56231 .45687 Mdot
.56232 .45689 Mdot
.56233 .45691 Mdot
.56234 .45693 Mdot
.56235 .45695 Mdot
.56236 .45697 Mdot
.56237 .45698 Mdot
.56238 .457 Mdot
.56239 .45702 Mdot
.5624 .45704 Mdot
.56241 .45706 Mdot
.56242 .45708 Mdot
.56243 .4571 Mdot
.56244 .45711 Mdot
.56245 .45713 Mdot
.56246 .45715 Mdot
.56247 .45717 Mdot
.56248 .45719 Mdot
.56249 .45721 Mdot
.5625 .45723 Mdot
.5625 .45724 Mdot
.56251 .45726 Mdot
.56252 .45728 Mdot
.56253 .4573 Mdot
.56254 .45732 Mdot
.56255 .45734 Mdot
.56256 .45736 Mdot
.56257 .45737 Mdot
.56258 .45739 Mdot
.56259 .45741 Mdot
.5626 .45743 Mdot
.56261 .45745 Mdot
.56262 .45747 Mdot
.56263 .45749 Mdot
.56264 .4575 Mdot
.56265 .45752 Mdot
.56266 .45754 Mdot
.56267 .45756 Mdot
.56268 .45758 Mdot
.56269 .4576 Mdot
.5627 .45762 Mdot
.5627 .45763 Mdot
.56271 .45765 Mdot
.56272 .45767 Mdot
.56273 .45769 Mdot
.56274 .45771 Mdot
.56275 .45773 Mdot
.56276 .45775 Mdot
.56277 .45776 Mdot
.56278 .45778 Mdot
.56279 .4578 Mdot
.5628 .45782 Mdot
.56281 .45784 Mdot
.56282 .45786 Mdot
.56283 .45787 Mdot
.56284 .45789 Mdot
.56285 .45791 Mdot
.56286 .45793 Mdot
.56287 .45795 Mdot
.56288 .45797 Mdot
.56289 .45799 Mdot
.5629 .458 Mdot
.5629 .45802 Mdot
.56291 .45804 Mdot
.56292 .45806 Mdot
.56293 .45808 Mdot
.56294 .4581 Mdot
.56295 .45812 Mdot
.56296 .45813 Mdot
.56297 .45815 Mdot
.56298 .45817 Mdot
.56299 .45819 Mdot
.563 .45821 Mdot
.56301 .45823 Mdot
.56302 .45824 Mdot
.56303 .45826 Mdot
.56304 .45828 Mdot
.56305 .4583 Mdot
.56306 .45832 Mdot
.56307 .45834 Mdot
.56308 .45836 Mdot
.56309 .45837 Mdot
.5631 .45839 Mdot
.5631 .45841 Mdot
.56311 .45843 Mdot
.56312 .45845 Mdot
.56313 .45847 Mdot
.56314 .45849 Mdot
.56315 .4585 Mdot
.56316 .45852 Mdot
.56317 .45854 Mdot
.56318 .45856 Mdot
.56319 .45858 Mdot
.5632 .4586 Mdot
.56321 .45861 Mdot
.56322 .45863 Mdot
.56323 .45865 Mdot
.56324 .45867 Mdot
.56325 .45869 Mdot
.56326 .45871 Mdot
.56327 .45873 Mdot
.56328 .45874 Mdot
.56329 .45876 Mdot
.5633 .45878 Mdot
.5633 .4588 Mdot
.56331 .45882 Mdot
.56332 .45884 Mdot
.56333 .45885 Mdot
.56334 .45887 Mdot
.56335 .45889 Mdot
.56336 .45891 Mdot
.56337 .45893 Mdot
.56338 .45895 Mdot
.56339 .45897 Mdot
.5634 .45898 Mdot
.56341 .459 Mdot
.56342 .45902 Mdot
.56343 .45904 Mdot
.56344 .45906 Mdot
.56345 .45908 Mdot
.56346 .45909 Mdot
.56347 .45911 Mdot
.56348 .45913 Mdot
.56349 .45915 Mdot
.5635 .45917 Mdot
.5635 .45919 Mdot
.56351 .45921 Mdot
.56352 .45922 Mdot
.56353 .45924 Mdot
.56354 .45926 Mdot
.56355 .45928 Mdot
.56356 .4593 Mdot
.56357 .45932 Mdot
.56358 .45933 Mdot
.56359 .45935 Mdot
.5636 .45937 Mdot
.56361 .45939 Mdot
.56362 .45941 Mdot
.56363 .45943 Mdot
.56364 .45944 Mdot
.56365 .45946 Mdot
.56366 .45948 Mdot
.56367 .4595 Mdot
.56368 .45952 Mdot
.56369 .45954 Mdot
.5637 .45956 Mdot
.5637 .45957 Mdot
.56371 .45959 Mdot
.56372 .45961 Mdot
.56373 .45963 Mdot
.56374 .45965 Mdot
.56375 .45967 Mdot
.56376 .45968 Mdot
.56377 .4597 Mdot
.56378 .45972 Mdot
.56379 .45974 Mdot
.5638 .45976 Mdot
.56381 .45978 Mdot
.56382 .45979 Mdot
.56383 .45981 Mdot
.56384 .45983 Mdot
.56385 .45985 Mdot
.56386 .45987 Mdot
.56387 .45989 Mdot
.56388 .4599 Mdot
.56389 .45992 Mdot
.5639 .45994 Mdot
.5639 .45996 Mdot
.56391 .45998 Mdot
.56392 .46 Mdot
.56393 .46002 Mdot
.56394 .46003 Mdot
.56395 .46005 Mdot
.56396 .46007 Mdot
.56397 .46009 Mdot
.56398 .46011 Mdot
.56399 .46013 Mdot
.564 .46014 Mdot
.56401 .46016 Mdot
.56402 .46018 Mdot
.56403 .4602 Mdot
.56404 .46022 Mdot
.56405 .46024 Mdot
.56406 .46025 Mdot
.56407 .46027 Mdot
.56408 .46029 Mdot
.56409 .46031 Mdot
.5641 .46033 Mdot
.5641 .46035 Mdot
.56411 .46036 Mdot
.56412 .46038 Mdot
.56413 .4604 Mdot
.56414 .46042 Mdot
.56415 .46044 Mdot
.56416 .46046 Mdot
.56417 .46047 Mdot
.56418 .46049 Mdot
.56419 .46051 Mdot
.5642 .46053 Mdot
.56421 .46055 Mdot
.56422 .46057 Mdot
.56423 .46058 Mdot
.56424 .4606 Mdot
.56425 .46062 Mdot
.56426 .46064 Mdot
.56427 .46066 Mdot
.56428 .46068 Mdot
.56429 .46069 Mdot
.5643 .46071 Mdot
.5643 .46073 Mdot
.56431 .46075 Mdot
.56432 .46077 Mdot
.56433 .46079 Mdot
.56434 .4608 Mdot
.56435 .46082 Mdot
.56436 .46084 Mdot
.56437 .46086 Mdot
.56438 .46088 Mdot
.56439 .4609 Mdot
.5644 .46091 Mdot
.56441 .46093 Mdot
.56442 .46095 Mdot
.56443 .46097 Mdot
.56444 .46099 Mdot
.56445 .46101 Mdot
.56446 .46102 Mdot
.56447 .46104 Mdot
.56448 .46106 Mdot
.56449 .46108 Mdot
.5645 .4611 Mdot
.5645 .46112 Mdot
.56451 .46113 Mdot
.56452 .46115 Mdot
.56453 .46117 Mdot
.56454 .46119 Mdot
.56455 .46121 Mdot
.56456 .46123 Mdot
.56457 .46124 Mdot
.56458 .46126 Mdot
.56459 .46128 Mdot
.5646 .4613 Mdot
.56461 .46132 Mdot
.56462 .46134 Mdot
.56463 .46135 Mdot
.56464 .46137 Mdot
.56465 .46139 Mdot
.56466 .46141 Mdot
.56467 .46143 Mdot
.56468 .46145 Mdot
.56469 .46146 Mdot
.5647 .46148 Mdot
.5647 .4615 Mdot
.56471 .46152 Mdot
.56472 .46154 Mdot
.56473 .46155 Mdot
.56474 .46157 Mdot
.56475 .46159 Mdot
.56476 .46161 Mdot
.56477 .46163 Mdot
.56478 .46165 Mdot
.56479 .46166 Mdot
.5648 .46168 Mdot
.56481 .4617 Mdot
.56482 .46172 Mdot
.56483 .46174 Mdot
.56484 .46176 Mdot
.56485 .46177 Mdot
.56486 .46179 Mdot
.56487 .46181 Mdot
.56488 .46183 Mdot
.56489 .46185 Mdot
.5649 .46187 Mdot
.5649 .46188 Mdot
.56491 .4619 Mdot
.56492 .46192 Mdot
.56493 .46194 Mdot
.56494 .46196 Mdot
.56495 .46198 Mdot
.56496 .46199 Mdot
.56497 .46201 Mdot
.56498 .46203 Mdot
.56499 .46205 Mdot
.565 .46207 Mdot
.56501 .46208 Mdot
.56502 .4621 Mdot
.56503 .46212 Mdot
.56504 .46214 Mdot
.56505 .46216 Mdot
.56506 .46218 Mdot
.56507 .46219 Mdot
.56508 .46221 Mdot
.56509 .46223 Mdot
.5651 .46225 Mdot
.5651 .46227 Mdot
.56511 .46229 Mdot
.56512 .4623 Mdot
.56513 .46232 Mdot
.56514 .46234 Mdot
.56515 .46236 Mdot
.56516 .46238 Mdot
.56517 .46239 Mdot
.56518 .46241 Mdot
.56519 .46243 Mdot
.5652 .46245 Mdot
.56521 .46247 Mdot
.56522 .46249 Mdot
.56523 .4625 Mdot
.56524 .46252 Mdot
.56525 .46254 Mdot
.56526 .46256 Mdot
.56527 .46258 Mdot
.56528 .4626 Mdot
.56529 .46261 Mdot
.5653 .46263 Mdot
.5653 .46265 Mdot
.56531 .46267 Mdot
.56532 .46269 Mdot
.56533 .4627 Mdot
.56534 .46272 Mdot
.56535 .46274 Mdot
.56536 .46276 Mdot
.56537 .46278 Mdot
.56538 .4628 Mdot
.56539 .46281 Mdot
.5654 .46283 Mdot
.56541 .46285 Mdot
.56542 .46287 Mdot
.56543 .46289 Mdot
.56544 .4629 Mdot
.56545 .46292 Mdot
.56546 .46294 Mdot
.56547 .46296 Mdot
.56548 .46298 Mdot
.56549 .463 Mdot
.5655 .46301 Mdot
.5655 .46303 Mdot
.56551 .46305 Mdot
.56552 .46307 Mdot
.56553 .46309 Mdot
.56554 .4631 Mdot
.56555 .46312 Mdot
.56556 .46314 Mdot
.56557 .46316 Mdot
.56558 .46318 Mdot
.56559 .4632 Mdot
.5656 .46321 Mdot
.56561 .46323 Mdot
.56562 .46325 Mdot
.56563 .46327 Mdot
.56564 .46329 Mdot
.56565 .4633 Mdot
.56566 .46332 Mdot
.56567 .46334 Mdot
.56568 .46336 Mdot
.56569 .46338 Mdot
.5657 .4634 Mdot
.5657 .46341 Mdot
.56571 .46343 Mdot
.56572 .46345 Mdot
.56573 .46347 Mdot
.56574 .46349 Mdot
.56575 .4635 Mdot
.56576 .46352 Mdot
.56577 .46354 Mdot
.56578 .46356 Mdot
.56579 .46358 Mdot
.5658 .4636 Mdot
.56581 .46361 Mdot
.56582 .46363 Mdot
.56583 .46365 Mdot
.56584 .46367 Mdot
.56585 .46369 Mdot
.56586 .4637 Mdot
.56587 .46372 Mdot
.56588 .46374 Mdot
.56589 .46376 Mdot
.5659 .46378 Mdot
.5659 .4638 Mdot
.56591 .46381 Mdot
.56592 .46383 Mdot
.56593 .46385 Mdot
.56594 .46387 Mdot
.56595 .46389 Mdot
.56596 .4639 Mdot
.56597 .46392 Mdot
.56598 .46394 Mdot
.56599 .46396 Mdot
.566 .46398 Mdot
.56601 .46399 Mdot
.56602 .46401 Mdot
.56603 .46403 Mdot
.56604 .46405 Mdot
.56605 .46407 Mdot
.56606 .46409 Mdot
.56607 .4641 Mdot
.56608 .46412 Mdot
.56609 .46414 Mdot
.5661 .46416 Mdot
.5661 .46418 Mdot
.56611 .46419 Mdot
.56612 .46421 Mdot
.56613 .46423 Mdot
.56614 .46425 Mdot
.56615 .46427 Mdot
.56616 .46428 Mdot
.56617 .4643 Mdot
.56618 .46432 Mdot
.56619 .46434 Mdot
.5662 .46436 Mdot
.56621 .46437 Mdot
.56622 .46439 Mdot
.56623 .46441 Mdot
.56624 .46443 Mdot
.56625 .46445 Mdot
.56626 .46447 Mdot
.56627 .46448 Mdot
.56628 .4645 Mdot
.56629 .46452 Mdot
.5663 .46454 Mdot
.5663 .46456 Mdot
.56631 .46457 Mdot
.56632 .46459 Mdot
.56633 .46461 Mdot
.56634 .46463 Mdot
.56635 .46465 Mdot
.56636 .46466 Mdot
.56637 .46468 Mdot
.56638 .4647 Mdot
.56639 .46472 Mdot
.5664 .46474 Mdot
.56641 .46475 Mdot
.56642 .46477 Mdot
.56643 .46479 Mdot
.56644 .46481 Mdot
.56645 .46483 Mdot
.56646 .46485 Mdot
.56647 .46486 Mdot
.56648 .46488 Mdot
.56649 .4649 Mdot
.5665 .46492 Mdot
.5665 .46494 Mdot
.56651 .46495 Mdot
.56652 .46497 Mdot
.56653 .46499 Mdot
.56654 .46501 Mdot
.56655 .46503 Mdot
.56656 .46504 Mdot
.56657 .46506 Mdot
.56658 .46508 Mdot
.56659 .4651 Mdot
.5666 .46512 Mdot
.56661 .46513 Mdot
.56662 .46515 Mdot
.56663 .46517 Mdot
.56664 .46519 Mdot
.56665 .46521 Mdot
.56666 .46522 Mdot
.56667 .46524 Mdot
.56668 .46526 Mdot
.56669 .46528 Mdot
.5667 .4653 Mdot
.5667 .46531 Mdot
.56671 .46533 Mdot
.56672 .46535 Mdot
.56673 .46537 Mdot
.56674 .46539 Mdot
.56675 .4654 Mdot
.56676 .46542 Mdot
.56677 .46544 Mdot
.56678 .46546 Mdot
.56679 .46548 Mdot
.5668 .4655 Mdot
.56681 .46551 Mdot
.56682 .46553 Mdot
.56683 .46555 Mdot
.56684 .46557 Mdot
.56685 .46559 Mdot
.56686 .4656 Mdot
.56687 .46562 Mdot
.56688 .46564 Mdot
.56689 .46566 Mdot
.5669 .46568 Mdot
.5669 .46569 Mdot
.56691 .46571 Mdot
.56692 .46573 Mdot
.56693 .46575 Mdot
.56694 .46577 Mdot
.56695 .46578 Mdot
.56696 .4658 Mdot
.56697 .46582 Mdot
.56698 .46584 Mdot
.56699 .46586 Mdot
.567 .46587 Mdot
.56701 .46589 Mdot
.56702 .46591 Mdot
.56703 .46593 Mdot
.56704 .46595 Mdot
.56705 .46596 Mdot
.56706 .46598 Mdot
.56707 .466 Mdot
.56708 .46602 Mdot
.56709 .46604 Mdot
.5671 .46605 Mdot
.5671 .46607 Mdot
.56711 .46609 Mdot
.56712 .46611 Mdot
.56713 .46613 Mdot
.56714 .46614 Mdot
.56715 .46616 Mdot
.56716 .46618 Mdot
.56717 .4662 Mdot
.56718 .46622 Mdot
.56719 .46623 Mdot
.5672 .46625 Mdot
.56721 .46627 Mdot
.56722 .46629 Mdot
.56723 .46631 Mdot
.56724 .46632 Mdot
.56725 .46634 Mdot
.56726 .46636 Mdot
.56727 .46638 Mdot
.56728 .4664 Mdot
.56729 .46641 Mdot
.5673 .46643 Mdot
.5673 .46645 Mdot
.56731 .46647 Mdot
.56732 .46648 Mdot
.56733 .4665 Mdot
.56734 .46652 Mdot
.56735 .46654 Mdot
.56736 .46656 Mdot
.56737 .46657 Mdot
.56738 .46659 Mdot
.56739 .46661 Mdot
.5674 .46663 Mdot
.56741 .46665 Mdot
.56742 .46666 Mdot
.56743 .46668 Mdot
.56744 .4667 Mdot
.56745 .46672 Mdot
.56746 .46674 Mdot
.56747 .46675 Mdot
.56748 .46677 Mdot
.56749 .46679 Mdot
.5675 .46681 Mdot
.5675 .46683 Mdot
.56751 .46684 Mdot
.56752 .46686 Mdot
.56753 .46688 Mdot
.56754 .4669 Mdot
.56755 .46692 Mdot
.56756 .46693 Mdot
.56757 .46695 Mdot
.56758 .46697 Mdot
.56759 .46699 Mdot
.5676 .46701 Mdot
.56761 .46702 Mdot
.56762 .46704 Mdot
.56763 .46706 Mdot
.56764 .46708 Mdot
.56765 .4671 Mdot
.56766 .46711 Mdot
.56767 .46713 Mdot
.56768 .46715 Mdot
.56769 .46717 Mdot
.5677 .46718 Mdot
.5677 .4672 Mdot
.56771 .46722 Mdot
.56772 .46724 Mdot
.56773 .46726 Mdot
.56774 .46727 Mdot
.56775 .46729 Mdot
.56776 .46731 Mdot
.56777 .46733 Mdot
.56778 .46735 Mdot
.56779 .46736 Mdot
.5678 .46738 Mdot
.56781 .4674 Mdot
.56782 .46742 Mdot
.56783 .46744 Mdot
.56784 .46745 Mdot
.56785 .46747 Mdot
.56786 .46749 Mdot
.56787 .46751 Mdot
.56788 .46752 Mdot
.56789 .46754 Mdot
.5679 .46756 Mdot
.5679 .46758 Mdot
.56791 .4676 Mdot
.56792 .46761 Mdot
.56793 .46763 Mdot
.56794 .46765 Mdot
.56795 .46767 Mdot
.56796 .46769 Mdot
.56797 .4677 Mdot
.56798 .46772 Mdot
.56799 .46774 Mdot
.568 .46776 Mdot
.56801 .46778 Mdot
.56802 .46779 Mdot
.56803 .46781 Mdot
.56804 .46783 Mdot
.56805 .46785 Mdot
.56806 .46786 Mdot
.56807 .46788 Mdot
.56808 .4679 Mdot
.56809 .46792 Mdot
.5681 .46794 Mdot
.5681 .46795 Mdot
.56811 .46797 Mdot
.56812 .46799 Mdot
.56813 .46801 Mdot
.56814 .46803 Mdot
.56815 .46804 Mdot
.56816 .46806 Mdot
.56817 .46808 Mdot
.56818 .4681 Mdot
.56819 .46811 Mdot
.5682 .46813 Mdot
.56821 .46815 Mdot
.56822 .46817 Mdot
.56823 .46819 Mdot
.56824 .4682 Mdot
.56825 .46822 Mdot
.56826 .46824 Mdot
.56827 .46826 Mdot
.56828 .46828 Mdot
.56829 .46829 Mdot
.5683 .46831 Mdot
.5683 .46833 Mdot
.56831 .46835 Mdot
.56832 .46836 Mdot
.56833 .46838 Mdot
.56834 .4684 Mdot
.56835 .46842 Mdot
.56836 .46844 Mdot
.56837 .46845 Mdot
.56838 .46847 Mdot
.56839 .46849 Mdot
.5684 .46851 Mdot
.56841 .46853 Mdot
.56842 .46854 Mdot
.56843 .46856 Mdot
.56844 .46858 Mdot
.56845 .4686 Mdot
.56846 .46861 Mdot
.56847 .46863 Mdot
.56848 .46865 Mdot
.56849 .46867 Mdot
.5685 .46869 Mdot
.5685 .4687 Mdot
.56851 .46872 Mdot
.56852 .46874 Mdot
.56853 .46876 Mdot
.56854 .46877 Mdot
.56855 .46879 Mdot
.56856 .46881 Mdot
.56857 .46883 Mdot
.56858 .46885 Mdot
.56859 .46886 Mdot
.5686 .46888 Mdot
.56861 .4689 Mdot
.56862 .46892 Mdot
.56863 .46894 Mdot
.56864 .46895 Mdot
.56865 .46897 Mdot
.56866 .46899 Mdot
.56867 .46901 Mdot
.56868 .46902 Mdot
.56869 .46904 Mdot
.5687 .46906 Mdot
.5687 .46908 Mdot
.56871 .4691 Mdot
.56872 .46911 Mdot
.56873 .46913 Mdot
.56874 .46915 Mdot
.56875 .46917 Mdot
.56876 .46918 Mdot
.56877 .4692 Mdot
.56878 .46922 Mdot
.56879 .46924 Mdot
.5688 .46926 Mdot
.56881 .46927 Mdot
.56882 .46929 Mdot
.56883 .46931 Mdot
.56884 .46933 Mdot
.56885 .46934 Mdot
.56886 .46936 Mdot
.56887 .46938 Mdot
.56888 .4694 Mdot
.56889 .46942 Mdot
.5689 .46943 Mdot
.5689 .46945 Mdot
.56891 .46947 Mdot
.56892 .46949 Mdot
.56893 .4695 Mdot
.56894 .46952 Mdot
.56895 .46954 Mdot
.56896 .46956 Mdot
.56897 .46958 Mdot
.56898 .46959 Mdot
.56899 .46961 Mdot
.569 .46963 Mdot
.56901 .46965 Mdot
.56902 .46966 Mdot
.56903 .46968 Mdot
.56904 .4697 Mdot
.56905 .46972 Mdot
.56906 .46974 Mdot
.56907 .46975 Mdot
.56908 .46977 Mdot
.56909 .46979 Mdot
.5691 .46981 Mdot
.5691 .46982 Mdot
.56911 .46984 Mdot
.56912 .46986 Mdot
.56913 .46988 Mdot
.56914 .46989 Mdot
.56915 .46991 Mdot
.56916 .46993 Mdot
.56917 .46995 Mdot
.56918 .46997 Mdot
.56919 .46998 Mdot
.5692 .47 Mdot
.56921 .47002 Mdot
.56922 .47004 Mdot
.56923 .47005 Mdot
.56924 .47007 Mdot
.56925 .47009 Mdot
.56926 .47011 Mdot
.56927 .47013 Mdot
.56928 .47014 Mdot
.56929 .47016 Mdot
.5693 .47018 Mdot
.5693 .4702 Mdot
.56931 .47021 Mdot
.56932 .47023 Mdot
.56933 .47025 Mdot
.56934 .47027 Mdot
.56935 .47029 Mdot
.56936 .4703 Mdot
.56937 .47032 Mdot
.56938 .47034 Mdot
.56939 .47036 Mdot
.5694 .47037 Mdot
.56941 .47039 Mdot
.56942 .47041 Mdot
.56943 .47043 Mdot
.56944 .47044 Mdot
.56945 .47046 Mdot
.56946 .47048 Mdot
.56947 .4705 Mdot
.56948 .47052 Mdot
.56949 .47053 Mdot
.5695 .47055 Mdot
.5695 .47057 Mdot
.56951 .47059 Mdot
.56952 .4706 Mdot
.56953 .47062 Mdot
.56954 .47064 Mdot
.56955 .47066 Mdot
.56956 .47067 Mdot
.56957 .47069 Mdot
.56958 .47071 Mdot
.56959 .47073 Mdot
.5696 .47075 Mdot
.56961 .47076 Mdot
.56962 .47078 Mdot
.56963 .4708 Mdot
.56964 .47082 Mdot
.56965 .47083 Mdot
.56966 .47085 Mdot
.56967 .47087 Mdot
.56968 .47089 Mdot
.56969 .4709 Mdot
.5697 .47092 Mdot
.5697 .47094 Mdot
.56971 .47096 Mdot
.56972 .47098 Mdot
.56973 .47099 Mdot
.56974 .47101 Mdot
.56975 .47103 Mdot
.56976 .47105 Mdot
.56977 .47106 Mdot
.56978 .47108 Mdot
.56979 .4711 Mdot
.5698 .47112 Mdot
.56981 .47113 Mdot
.56982 .47115 Mdot
.56983 .47117 Mdot
.56984 .47119 Mdot
.56985 .4712 Mdot
.56986 .47122 Mdot
.56987 .47124 Mdot
.56988 .47126 Mdot
.56989 .47128 Mdot
.5699 .47129 Mdot
.5699 .47131 Mdot
.56991 .47133 Mdot
.56992 .47135 Mdot
.56993 .47136 Mdot
.56994 .47138 Mdot
.56995 .4714 Mdot
.56996 .47142 Mdot
.56997 .47143 Mdot
.56998 .47145 Mdot
.56999 .47147 Mdot
.57 .47149 Mdot
.57001 .4715 Mdot
.57002 .47152 Mdot
.57003 .47154 Mdot
.57004 .47156 Mdot
.57005 .47158 Mdot
.57006 .47159 Mdot
.57007 .47161 Mdot
.57008 .47163 Mdot
.57009 .47165 Mdot
.5701 .47166 Mdot
.5701 .47168 Mdot
.57011 .4717 Mdot
.57012 .47172 Mdot
.57013 .47173 Mdot
.57014 .47175 Mdot
.57015 .47177 Mdot
.57016 .47179 Mdot
.57017 .4718 Mdot
.57018 .47182 Mdot
.57019 .47184 Mdot
.5702 .47186 Mdot
.57021 .47187 Mdot
.57022 .47189 Mdot
.57023 .47191 Mdot
.57024 .47193 Mdot
.57025 .47195 Mdot
.57026 .47196 Mdot
.57027 .47198 Mdot
.57028 .472 Mdot
.57029 .47202 Mdot
.5703 .47203 Mdot
.5703 .47205 Mdot
.57031 .47207 Mdot
.57032 .47209 Mdot
.57033 .4721 Mdot
.57034 .47212 Mdot
.57035 .47214 Mdot
.57036 .47216 Mdot
.57037 .47217 Mdot
.57038 .47219 Mdot
.57039 .47221 Mdot
.5704 .47223 Mdot
.57041 .47224 Mdot
.57042 .47226 Mdot
.57043 .47228 Mdot
.57044 .4723 Mdot
.57045 .47231 Mdot
.57046 .47233 Mdot
.57047 .47235 Mdot
.57048 .47237 Mdot
.57049 .47238 Mdot
.5705 .4724 Mdot
.5705 .47242 Mdot
.57051 .47244 Mdot
.57052 .47246 Mdot
.57053 .47247 Mdot
.57054 .47249 Mdot
.57055 .47251 Mdot
.57056 .47253 Mdot
.57057 .47254 Mdot
.57058 .47256 Mdot
.57059 .47258 Mdot
.5706 .4726 Mdot
.57061 .47261 Mdot
.57062 .47263 Mdot
.57063 .47265 Mdot
.57064 .47267 Mdot
.57065 .47268 Mdot
.57066 .4727 Mdot
.57067 .47272 Mdot
.57068 .47274 Mdot
.57069 .47275 Mdot
.5707 .47277 Mdot
.5707 .47279 Mdot
.57071 .47281 Mdot
.57072 .47282 Mdot
.57073 .47284 Mdot
.57074 .47286 Mdot
.57075 .47288 Mdot
.57076 .47289 Mdot
.57077 .47291 Mdot
.57078 .47293 Mdot
.57079 .47295 Mdot
.5708 .47296 Mdot
.57081 .47298 Mdot
.57082 .473 Mdot
.57083 .47302 Mdot
.57084 .47303 Mdot
.57085 .47305 Mdot
.57086 .47307 Mdot
.57087 .47309 Mdot
.57088 .4731 Mdot
.57089 .47312 Mdot
.5709 .47314 Mdot
.5709 .47316 Mdot
.57091 .47317 Mdot
.57092 .47319 Mdot
.57093 .47321 Mdot
.57094 .47323 Mdot
.57095 .47324 Mdot
.57096 .47326 Mdot
.57097 .47328 Mdot
.57098 .4733 Mdot
.57099 .47331 Mdot
.571 .47333 Mdot
.57101 .47335 Mdot
.57102 .47337 Mdot
.57103 .47338 Mdot
.57104 .4734 Mdot
.57105 .47342 Mdot
.57106 .47344 Mdot
.57107 .47345 Mdot
.57108 .47347 Mdot
.57109 .47349 Mdot
.5711 .47351 Mdot
.5711 .47352 Mdot
.57111 .47354 Mdot
.57112 .47356 Mdot
.57113 .47358 Mdot
.57114 .47359 Mdot
.57115 .47361 Mdot
.57116 .47363 Mdot
.57117 .47365 Mdot
.57118 .47366 Mdot
.57119 .47368 Mdot
.5712 .4737 Mdot
.57121 .47372 Mdot
.57122 .47373 Mdot
.57123 .47375 Mdot
.57124 .47377 Mdot
.57125 .47379 Mdot
.57126 .4738 Mdot
.57127 .47382 Mdot
.57128 .47384 Mdot
.57129 .47386 Mdot
.5713 .47387 Mdot
.5713 .47389 Mdot
.57131 .47391 Mdot
.57132 .47393 Mdot
.57133 .47394 Mdot
.57134 .47396 Mdot
.57135 .47398 Mdot
.57136 .474 Mdot
.57137 .47401 Mdot
.57138 .47403 Mdot
.57139 .47405 Mdot
.5714 .47407 Mdot
.57141 .47408 Mdot
.57142 .4741 Mdot
.57143 .47412 Mdot
.57144 .47414 Mdot
.57145 .47415 Mdot
.57146 .47417 Mdot
.57147 .47419 Mdot
.57148 .47421 Mdot
.57149 .47422 Mdot
.5715 .47424 Mdot
.5715 .47426 Mdot
.57151 .47428 Mdot
.57152 .47429 Mdot
.57153 .47431 Mdot
.57154 .47433 Mdot
.57155 .47435 Mdot
.57156 .47436 Mdot
.57157 .47438 Mdot
.57158 .4744 Mdot
.57159 .47442 Mdot
.5716 .47443 Mdot
.57161 .47445 Mdot
.57162 .47447 Mdot
.57163 .47449 Mdot
.57164 .4745 Mdot
.57165 .47452 Mdot
.57166 .47454 Mdot
.57167 .47456 Mdot
.57168 .47457 Mdot
.57169 .47459 Mdot
.5717 .47461 Mdot
.5717 .47463 Mdot
.57171 .47464 Mdot
.57172 .47466 Mdot
.57173 .47468 Mdot
.57174 .47469 Mdot
.57175 .47471 Mdot
.57176 .47473 Mdot
.57177 .47475 Mdot
.57178 .47476 Mdot
.57179 .47478 Mdot
.5718 .4748 Mdot
.57181 .47482 Mdot
.57182 .47483 Mdot
.57183 .47485 Mdot
.57184 .47487 Mdot
.57185 .47489 Mdot
.57186 .4749 Mdot
.57187 .47492 Mdot
.57188 .47494 Mdot
.57189 .47496 Mdot
.5719 .47497 Mdot
.5719 .47499 Mdot
.57191 .47501 Mdot
.57192 .47503 Mdot
.57193 .47504 Mdot
.57194 .47506 Mdot
.57195 .47508 Mdot
.57196 .4751 Mdot
.57197 .47511 Mdot
.57198 .47513 Mdot
.57199 .47515 Mdot
.572 .47516 Mdot
.57201 .47518 Mdot
.57202 .4752 Mdot
.57203 .47522 Mdot
.57204 .47523 Mdot
.57205 .47525 Mdot
.57206 .47527 Mdot
.57207 .47529 Mdot
.57208 .4753 Mdot
.57209 .47532 Mdot
.5721 .47534 Mdot
.5721 .47536 Mdot
.57211 .47537 Mdot
.57212 .47539 Mdot
.57213 .47541 Mdot
.57214 .47543 Mdot
.57215 .47544 Mdot
.57216 .47546 Mdot
.57217 .47548 Mdot
.57218 .47549 Mdot
.57219 .47551 Mdot
.5722 .47553 Mdot
.57221 .47555 Mdot
.57222 .47556 Mdot
.57223 .47558 Mdot
.57224 .4756 Mdot
.57225 .47562 Mdot
.57226 .47563 Mdot
.57227 .47565 Mdot
.57228 .47567 Mdot
.57229 .47569 Mdot
.5723 .4757 Mdot
.5723 .47572 Mdot
.57231 .47574 Mdot
.57232 .47576 Mdot
.57233 .47577 Mdot
.57234 .47579 Mdot
.57235 .47581 Mdot
.57236 .47582 Mdot
.57237 .47584 Mdot
.57238 .47586 Mdot
.57239 .47588 Mdot
.5724 .47589 Mdot
.57241 .47591 Mdot
.57242 .47593 Mdot
.57243 .47595 Mdot
.57244 .47596 Mdot
.57245 .47598 Mdot
.57246 .476 Mdot
.57247 .47602 Mdot
.57248 .47603 Mdot
.57249 .47605 Mdot
.5725 .47607 Mdot
.5725 .47608 Mdot
.57251 .4761 Mdot
.57252 .47612 Mdot
.57253 .47614 Mdot
.57254 .47615 Mdot
.57255 .47617 Mdot
.57256 .47619 Mdot
.57257 .47621 Mdot
.57258 .47622 Mdot
.57259 .47624 Mdot
.5726 .47626 Mdot
.57261 .47628 Mdot
.57262 .47629 Mdot
.57263 .47631 Mdot
.57264 .47633 Mdot
.57265 .47634 Mdot
.57266 .47636 Mdot
.57267 .47638 Mdot
.57268 .4764 Mdot
.57269 .47641 Mdot
.5727 .47643 Mdot
.5727 .47645 Mdot
.57271 .47647 Mdot
.57272 .47648 Mdot
.57273 .4765 Mdot
.57274 .47652 Mdot
.57275 .47653 Mdot
.57276 .47655 Mdot
.57277 .47657 Mdot
.57278 .47659 Mdot
.57279 .4766 Mdot
.5728 .47662 Mdot
.57281 .47664 Mdot
.57282 .47666 Mdot
.57283 .47667 Mdot
.57284 .47669 Mdot
.57285 .47671 Mdot
.57286 .47672 Mdot
.57287 .47674 Mdot
.57288 .47676 Mdot
.57289 .47678 Mdot
.5729 .47679 Mdot
.5729 .47681 Mdot
.57291 .47683 Mdot
.57292 .47685 Mdot
.57293 .47686 Mdot
.57294 .47688 Mdot
.57295 .4769 Mdot
.57296 .47691 Mdot
.57297 .47693 Mdot
.57298 .47695 Mdot
.57299 .47697 Mdot
.573 .47698 Mdot
.57301 .477 Mdot
.57302 .47702 Mdot
.57303 .47704 Mdot
.57304 .47705 Mdot
.57305 .47707 Mdot
.57306 .47709 Mdot
.57307 .4771 Mdot
.57308 .47712 Mdot
.57309 .47714 Mdot
.5731 .47716 Mdot
.5731 .47717 Mdot
.57311 .47719 Mdot
.57312 .47721 Mdot
.57313 .47723 Mdot
.57314 .47724 Mdot
.57315 .47726 Mdot
.57316 .47728 Mdot
.57317 .47729 Mdot
.57318 .47731 Mdot
.57319 .47733 Mdot
.5732 .47735 Mdot
.57321 .47736 Mdot
.57322 .47738 Mdot
.57323 .4774 Mdot
.57324 .47742 Mdot
.57325 .47743 Mdot
.57326 .47745 Mdot
.57327 .47747 Mdot
.57328 .47748 Mdot
.57329 .4775 Mdot
.5733 .47752 Mdot
.5733 .47754 Mdot
.57331 .47755 Mdot
.57332 .47757 Mdot
.57333 .47759 Mdot
.57334 .4776 Mdot
.57335 .47762 Mdot
.57336 .47764 Mdot
.57337 .47766 Mdot
.57338 .47767 Mdot
.57339 .47769 Mdot
.5734 .47771 Mdot
.57341 .47773 Mdot
.57342 .47774 Mdot
.57343 .47776 Mdot
.57344 .47778 Mdot
.57345 .47779 Mdot
.57346 .47781 Mdot
.57347 .47783 Mdot
.57348 .47785 Mdot
.57349 .47786 Mdot
.5735 .47788 Mdot
.5735 .4779 Mdot
.57351 .47791 Mdot
.57352 .47793 Mdot
.57353 .47795 Mdot
.57354 .47797 Mdot
.57355 .47798 Mdot
.57356 .478 Mdot
.57357 .47802 Mdot
.57358 .47804 Mdot
.57359 .47805 Mdot
.5736 .47807 Mdot
.57361 .47809 Mdot
.57362 .4781 Mdot
.57363 .47812 Mdot
.57364 .47814 Mdot
.57365 .47816 Mdot
.57366 .47817 Mdot
.57367 .47819 Mdot
.57368 .47821 Mdot
.57369 .47822 Mdot
.5737 .47824 Mdot
.5737 .47826 Mdot
.57371 .47828 Mdot
.57372 .47829 Mdot
.57373 .47831 Mdot
.57374 .47833 Mdot
.57375 .47834 Mdot
.57376 .47836 Mdot
.57377 .47838 Mdot
.57378 .4784 Mdot
.57379 .47841 Mdot
.5738 .47843 Mdot
.57381 .47845 Mdot
.57382 .47846 Mdot
.57383 .47848 Mdot
.57384 .4785 Mdot
.57385 .47852 Mdot
.57386 .47853 Mdot
.57387 .47855 Mdot
.57388 .47857 Mdot
.57389 .47858 Mdot
.5739 .4786 Mdot
.5739 .47862 Mdot
.57391 .47864 Mdot
.57392 .47865 Mdot
.57393 .47867 Mdot
.57394 .47869 Mdot
.57395 .4787 Mdot
.57396 .47872 Mdot
.57397 .47874 Mdot
.57398 .47876 Mdot
.57399 .47877 Mdot
.574 .47879 Mdot
.57401 .47881 Mdot
.57402 .47882 Mdot
.57403 .47884 Mdot
.57404 .47886 Mdot
.57405 .47888 Mdot
.57406 .47889 Mdot
.57407 .47891 Mdot
.57408 .47893 Mdot
.57409 .47894 Mdot
.5741 .47896 Mdot
.5741 .47898 Mdot
.57411 .479 Mdot
.57412 .47901 Mdot
.57413 .47903 Mdot
.57414 .47905 Mdot
.57415 .47906 Mdot
.57416 .47908 Mdot
.57417 .4791 Mdot
.57418 .47912 Mdot
.57419 .47913 Mdot
.5742 .47915 Mdot
.57421 .47917 Mdot
.57422 .47918 Mdot
.57423 .4792 Mdot
.57424 .47922 Mdot
.57425 .47924 Mdot
.57426 .47925 Mdot
.57427 .47927 Mdot
.57428 .47929 Mdot
.57429 .4793 Mdot
.5743 .47932 Mdot
.5743 .47934 Mdot
.57431 .47936 Mdot
.57432 .47937 Mdot
.57433 .47939 Mdot
.57434 .47941 Mdot
.57435 .47942 Mdot
.57436 .47944 Mdot
.57437 .47946 Mdot
.57438 .47948 Mdot
.57439 .47949 Mdot
.5744 .47951 Mdot
.57441 .47953 Mdot
.57442 .47954 Mdot
.57443 .47956 Mdot
.57444 .47958 Mdot
.57445 .47959 Mdot
.57446 .47961 Mdot
.57447 .47963 Mdot
.57448 .47965 Mdot
.57449 .47966 Mdot
.5745 .47968 Mdot
.5745 .4797 Mdot
.57451 .47971 Mdot
.57452 .47973 Mdot
.57453 .47975 Mdot
.57454 .47977 Mdot
.57455 .47978 Mdot
.57456 .4798 Mdot
.57457 .47982 Mdot
.57458 .47983 Mdot
.57459 .47985 Mdot
.5746 .47987 Mdot
.57461 .47989 Mdot
.57462 .4799 Mdot
.57463 .47992 Mdot
.57464 .47994 Mdot
.57465 .47995 Mdot
.57466 .47997 Mdot
.57467 .47999 Mdot
.57468 .48 Mdot
.57469 .48002 Mdot
.5747 .48004 Mdot
.5747 .48006 Mdot
.57471 .48007 Mdot
.57472 .48009 Mdot
.57473 .48011 Mdot
.57474 .48012 Mdot
.57475 .48014 Mdot
.57476 .48016 Mdot
.57477 .48018 Mdot
.57478 .48019 Mdot
.57479 .48021 Mdot
.5748 .48023 Mdot
.57481 .48024 Mdot
.57482 .48026 Mdot
.57483 .48028 Mdot
.57484 .48029 Mdot
.57485 .48031 Mdot
.57486 .48033 Mdot
.57487 .48035 Mdot
.57488 .48036 Mdot
.57489 .48038 Mdot
.5749 .4804 Mdot
.5749 .48041 Mdot
.57491 .48043 Mdot
.57492 .48045 Mdot
.57493 .48046 Mdot
.57494 .48048 Mdot
.57495 .4805 Mdot
.57496 .48052 Mdot
.57497 .48053 Mdot
.57498 .48055 Mdot
.57499 .48057 Mdot
.575 .48058 Mdot
.57501 .4806 Mdot
.57502 .48062 Mdot
.57503 .48063 Mdot
.57504 .48065 Mdot
.57505 .48067 Mdot
.57506 .48069 Mdot
.57507 .4807 Mdot
.57508 .48072 Mdot
.57509 .48074 Mdot
.5751 .48075 Mdot
.5751 .48077 Mdot
.57511 .48079 Mdot
.57512 .48081 Mdot
.57513 .48082 Mdot
.57514 .48084 Mdot
.57515 .48086 Mdot
.57516 .48087 Mdot
.57517 .48089 Mdot
.57518 .48091 Mdot
.57519 .48092 Mdot
.5752 .48094 Mdot
.57521 .48096 Mdot
.57522 .48098 Mdot
.57523 .48099 Mdot
.57524 .48101 Mdot
.57525 .48103 Mdot
.57526 .48104 Mdot
.57527 .48106 Mdot
.57528 .48108 Mdot
.57529 .48109 Mdot
.5753 .48111 Mdot
.5753 .48113 Mdot
.57531 .48114 Mdot
.57532 .48116 Mdot
.57533 .48118 Mdot
.57534 .4812 Mdot
.57535 .48121 Mdot
.57536 .48123 Mdot
.57537 .48125 Mdot
.57538 .48126 Mdot
.57539 .48128 Mdot
.5754 .4813 Mdot
.57541 .48131 Mdot
.57542 .48133 Mdot
.57543 .48135 Mdot
.57544 .48137 Mdot
.57545 .48138 Mdot
.57546 .4814 Mdot
.57547 .48142 Mdot
.57548 .48143 Mdot
.57549 .48145 Mdot
.5755 .48147 Mdot
.5755 .48148 Mdot
.57551 .4815 Mdot
.57552 .48152 Mdot
.57553 .48154 Mdot
.57554 .48155 Mdot
.57555 .48157 Mdot
.57556 .48159 Mdot
.57557 .4816 Mdot
.57558 .48162 Mdot
.57559 .48164 Mdot
.5756 .48165 Mdot
.57561 .48167 Mdot
.57562 .48169 Mdot
.57563 .4817 Mdot
.57564 .48172 Mdot
.57565 .48174 Mdot
.57566 .48176 Mdot
.57567 .48177 Mdot
.57568 .48179 Mdot
.57569 .48181 Mdot
.5757 .48182 Mdot
.5757 .48184 Mdot
.57571 .48186 Mdot
.57572 .48187 Mdot
.57573 .48189 Mdot
.57574 .48191 Mdot
.57575 .48192 Mdot
.57576 .48194 Mdot
.57577 .48196 Mdot
.57578 .48198 Mdot
.57579 .48199 Mdot
.5758 .48201 Mdot
.57581 .48203 Mdot
.57582 .48204 Mdot
.57583 .48206 Mdot
.57584 .48208 Mdot
.57585 .48209 Mdot
.57586 .48211 Mdot
.57587 .48213 Mdot
.57588 .48214 Mdot
.57589 .48216 Mdot
.5759 .48218 Mdot
.5759 .4822 Mdot
.57591 .48221 Mdot
.57592 .48223 Mdot
.57593 .48225 Mdot
.57594 .48226 Mdot
.57595 .48228 Mdot
.57596 .4823 Mdot
.57597 .48231 Mdot
.57598 .48233 Mdot
.57599 .48235 Mdot
.576 .48236 Mdot
.57601 .48238 Mdot
.57602 .4824 Mdot
.57603 .48242 Mdot
.57604 .48243 Mdot
.57605 .48245 Mdot
.57606 .48247 Mdot
.57607 .48248 Mdot
.57608 .4825 Mdot
.57609 .48252 Mdot
.5761 .48253 Mdot
.5761 .48255 Mdot
.57611 .48257 Mdot
.57612 .48258 Mdot
.57613 .4826 Mdot
.57614 .48262 Mdot
.57615 .48263 Mdot
.57616 .48265 Mdot
.57617 .48267 Mdot
.57618 .48269 Mdot
.57619 .4827 Mdot
.5762 .48272 Mdot
.57621 .48274 Mdot
.57622 .48275 Mdot
.57623 .48277 Mdot
.57624 .48279 Mdot
.57625 .4828 Mdot
.57626 .48282 Mdot
.57627 .48284 Mdot
.57628 .48285 Mdot
.57629 .48287 Mdot
.5763 .48289 Mdot
.5763 .4829 Mdot
.57631 .48292 Mdot
.57632 .48294 Mdot
.57633 .48295 Mdot
.57634 .48297 Mdot
.57635 .48299 Mdot
.57636 .48301 Mdot
.57637 .48302 Mdot
.57638 .48304 Mdot
.57639 .48306 Mdot
.5764 .48307 Mdot
.57641 .48309 Mdot
.57642 .48311 Mdot
.57643 .48312 Mdot
.57644 .48314 Mdot
.57645 .48316 Mdot
.57646 .48317 Mdot
.57647 .48319 Mdot
.57648 .48321 Mdot
.57649 .48322 Mdot
.5765 .48324 Mdot
.5765 .48326 Mdot
.57651 .48327 Mdot
.57652 .48329 Mdot
.57653 .48331 Mdot
.57654 .48333 Mdot
.57655 .48334 Mdot
.57656 .48336 Mdot
.57657 .48338 Mdot
.57658 .48339 Mdot
.57659 .48341 Mdot
.5766 .48343 Mdot
.57661 .48344 Mdot
.57662 .48346 Mdot
.57663 .48348 Mdot
.57664 .48349 Mdot
.57665 .48351 Mdot
.57666 .48353 Mdot
.57667 .48354 Mdot
.57668 .48356 Mdot
.57669 .48358 Mdot
.5767 .48359 Mdot
.5767 .48361 Mdot
.57671 .48363 Mdot
.57672 .48364 Mdot
.57673 .48366 Mdot
.57674 .48368 Mdot
.57675 .4837 Mdot
.57676 .48371 Mdot
.57677 .48373 Mdot
.57678 .48375 Mdot
.57679 .48376 Mdot
.5768 .48378 Mdot
.57681 .4838 Mdot
.57682 .48381 Mdot
.57683 .48383 Mdot
.57684 .48385 Mdot
.57685 .48386 Mdot
.57686 .48388 Mdot
.57687 .4839 Mdot
.57688 .48391 Mdot
.57689 .48393 Mdot
.5769 .48395 Mdot
.5769 .48396 Mdot
.57691 .48398 Mdot
.57692 .484 Mdot
.57693 .48401 Mdot
.57694 .48403 Mdot
.57695 .48405 Mdot
.57696 .48406 Mdot
.57697 .48408 Mdot
.57698 .4841 Mdot
.57699 .48412 Mdot
.577 .48413 Mdot
.57701 .48415 Mdot
.57702 .48417 Mdot
.57703 .48418 Mdot
.57704 .4842 Mdot
.57705 .48422 Mdot
.57706 .48423 Mdot
.57707 .48425 Mdot
.57708 .48427 Mdot
.57709 .48428 Mdot
.5771 .4843 Mdot
.5771 .48432 Mdot
.57711 .48433 Mdot
.57712 .48435 Mdot
.57713 .48437 Mdot
.57714 .48438 Mdot
.57715 .4844 Mdot
.57716 .48442 Mdot
.57717 .48443 Mdot
.57718 .48445 Mdot
.57719 .48447 Mdot
.5772 .48448 Mdot
.57721 .4845 Mdot
.57722 .48452 Mdot
.57723 .48453 Mdot
.57724 .48455 Mdot
.57725 .48457 Mdot
.57726 .48458 Mdot
.57727 .4846 Mdot
.57728 .48462 Mdot
.57729 .48463 Mdot
.5773 .48465 Mdot
.5773 .48467 Mdot
.57731 .48468 Mdot
.57732 .4847 Mdot
.57733 .48472 Mdot
.57734 .48473 Mdot
.57735 .48475 Mdot
.57736 .48477 Mdot
.57737 .48478 Mdot
.57738 .4848 Mdot
.57739 .48482 Mdot
.5774 .48484 Mdot
.57741 .48485 Mdot
.57742 .48487 Mdot
.57743 .48489 Mdot
.57744 .4849 Mdot
.57745 .48492 Mdot
.57746 .48494 Mdot
.57747 .48495 Mdot
.57748 .48497 Mdot
.57749 .48499 Mdot
.5775 .485 Mdot
.5775 .48502 Mdot
.57751 .48504 Mdot
.57752 .48505 Mdot
.57753 .48507 Mdot
.57754 .48509 Mdot
.57755 .4851 Mdot
.57756 .48512 Mdot
.57757 .48514 Mdot
.57758 .48515 Mdot
.57759 .48517 Mdot
.5776 .48519 Mdot
.57761 .4852 Mdot
.57762 .48522 Mdot
.57763 .48524 Mdot
.57764 .48525 Mdot
.57765 .48527 Mdot
.57766 .48529 Mdot
.57767 .4853 Mdot
.57768 .48532 Mdot
.57769 .48534 Mdot
.5777 .48535 Mdot
.5777 .48537 Mdot
.57771 .48539 Mdot
.57772 .4854 Mdot
.57773 .48542 Mdot
.57774 .48544 Mdot
.57775 .48545 Mdot
.57776 .48547 Mdot
.57777 .48549 Mdot
.57778 .4855 Mdot
.57779 .48552 Mdot
.5778 .48554 Mdot
.57781 .48555 Mdot
.57782 .48557 Mdot
.57783 .48559 Mdot
.57784 .4856 Mdot
.57785 .48562 Mdot
.57786 .48564 Mdot
.57787 .48565 Mdot
.57788 .48567 Mdot
.57789 .48569 Mdot
.5779 .4857 Mdot
.5779 .48572 Mdot
.57791 .48574 Mdot
.57792 .48575 Mdot
.57793 .48577 Mdot
.57794 .48579 Mdot
.57795 .4858 Mdot
.57796 .48582 Mdot
.57797 .48584 Mdot
.57798 .48585 Mdot
.57799 .48587 Mdot
.578 .48589 Mdot
.57801 .4859 Mdot
.57802 .48592 Mdot
.57803 .48594 Mdot
.57804 .48595 Mdot
.57805 .48597 Mdot
.57806 .48599 Mdot
.57807 .486 Mdot
.57808 .48602 Mdot
.57809 .48604 Mdot
.5781 .48605 Mdot
.5781 .48607 Mdot
.57811 .48609 Mdot
.57812 .4861 Mdot
.57813 .48612 Mdot
.57814 .48614 Mdot
.57815 .48615 Mdot
.57816 .48617 Mdot
.57817 .48619 Mdot
.57818 .4862 Mdot
.57819 .48622 Mdot
.5782 .48624 Mdot
.57821 .48625 Mdot
.57822 .48627 Mdot
.57823 .48629 Mdot
.57824 .4863 Mdot
.57825 .48632 Mdot
.57826 .48634 Mdot
.57827 .48635 Mdot
.57828 .48637 Mdot
.57829 .48639 Mdot
.5783 .4864 Mdot
.5783 .48642 Mdot
.57831 .48643 Mdot
.57832 .48645 Mdot
.57833 .48647 Mdot
.57834 .48648 Mdot
.57835 .4865 Mdot
.57836 .48652 Mdot
.57837 .48653 Mdot
.57838 .48655 Mdot
.57839 .48657 Mdot
.5784 .48658 Mdot
.57841 .4866 Mdot
.57842 .48662 Mdot
.57843 .48663 Mdot
.57844 .48665 Mdot
.57845 .48667 Mdot
.57846 .48668 Mdot
.57847 .4867 Mdot
.57848 .48672 Mdot
.57849 .48673 Mdot
.5785 .48675 Mdot
.5785 .48677 Mdot
.57851 .48678 Mdot
.57852 .4868 Mdot
.57853 .48682 Mdot
.57854 .48683 Mdot
.57855 .48685 Mdot
.57856 .48687 Mdot
.57857 .48688 Mdot
.57858 .4869 Mdot
.57859 .48692 Mdot
.5786 .48693 Mdot
.57861 .48695 Mdot
.57862 .48697 Mdot
.57863 .48698 Mdot
.57864 .487 Mdot
.57865 .48702 Mdot
.57866 .48703 Mdot
.57867 .48705 Mdot
.57868 .48707 Mdot
.57869 .48708 Mdot
.5787 .4871 Mdot
.5787 .48711 Mdot
.57871 .48713 Mdot
.57872 .48715 Mdot
.57873 .48716 Mdot
.57874 .48718 Mdot
.57875 .4872 Mdot
.57876 .48721 Mdot
.57877 .48723 Mdot
.57878 .48725 Mdot
.57879 .48726 Mdot
.5788 .48728 Mdot
.57881 .4873 Mdot
.57882 .48731 Mdot
.57883 .48733 Mdot
.57884 .48735 Mdot
.57885 .48736 Mdot
.57886 .48738 Mdot
.57887 .4874 Mdot
.57888 .48741 Mdot
.57889 .48743 Mdot
.5789 .48745 Mdot
.5789 .48746 Mdot
.57891 .48748 Mdot
.57892 .4875 Mdot
.57893 .48751 Mdot
.57894 .48753 Mdot
.57895 .48755 Mdot
.57896 .48756 Mdot
.57897 .48758 Mdot
.57898 .48759 Mdot
.57899 .48761 Mdot
.579 .48763 Mdot
.57901 .48764 Mdot
.57902 .48766 Mdot
.57903 .48768 Mdot
.57904 .48769 Mdot
.57905 .48771 Mdot
.57906 .48773 Mdot
.57907 .48774 Mdot
.57908 .48776 Mdot
.57909 .48778 Mdot
.5791 .48779 Mdot
.5791 .48781 Mdot
.57911 .48783 Mdot
.57912 .48784 Mdot
.57913 .48786 Mdot
.57914 .48788 Mdot
.57915 .48789 Mdot
.57916 .48791 Mdot
.57917 .48792 Mdot
.57918 .48794 Mdot
.57919 .48796 Mdot
.5792 .48797 Mdot
.57921 .48799 Mdot
.57922 .48801 Mdot
.57923 .48802 Mdot
.57924 .48804 Mdot
.57925 .48806 Mdot
.57926 .48807 Mdot
.57927 .48809 Mdot
.57928 .48811 Mdot
.57929 .48812 Mdot
.5793 .48814 Mdot
.5793 .48816 Mdot
.57931 .48817 Mdot
.57932 .48819 Mdot
.57933 .48821 Mdot
.57934 .48822 Mdot
.57935 .48824 Mdot
.57936 .48825 Mdot
.57937 .48827 Mdot
.57938 .48829 Mdot
.57939 .4883 Mdot
.5794 .48832 Mdot
.57941 .48834 Mdot
.57942 .48835 Mdot
.57943 .48837 Mdot
.57944 .48839 Mdot
.57945 .4884 Mdot
.57946 .48842 Mdot
.57947 .48844 Mdot
.57948 .48845 Mdot
.57949 .48847 Mdot
.5795 .48849 Mdot
.5795 .4885 Mdot
.57951 .48852 Mdot
.57952 .48853 Mdot
.57953 .48855 Mdot
.57954 .48857 Mdot
.57955 .48858 Mdot
.57956 .4886 Mdot
.57957 .48862 Mdot
.57958 .48863 Mdot
.57959 .48865 Mdot
.5796 .48867 Mdot
.57961 .48868 Mdot
.57962 .4887 Mdot
.57963 .48872 Mdot
.57964 .48873 Mdot
.57965 .48875 Mdot
.57966 .48876 Mdot
.57967 .48878 Mdot
.57968 .4888 Mdot
.57969 .48881 Mdot
.5797 .48883 Mdot
.5797 .48885 Mdot
.57971 .48886 Mdot
.57972 .48888 Mdot
.57973 .4889 Mdot
.57974 .48891 Mdot
.57975 .48893 Mdot
.57976 .48895 Mdot
.57977 .48896 Mdot
.57978 .48898 Mdot
.57979 .489 Mdot
.5798 .48901 Mdot
.57981 .48903 Mdot
.57982 .48904 Mdot
.57983 .48906 Mdot
.57984 .48908 Mdot
.57985 .48909 Mdot
.57986 .48911 Mdot
.57987 .48913 Mdot
.57988 .48914 Mdot
.57989 .48916 Mdot
.5799 .48918 Mdot
.5799 .48919 Mdot
.57991 .48921 Mdot
.57992 .48922 Mdot
.57993 .48924 Mdot
.57994 .48926 Mdot
.57995 .48927 Mdot
.57996 .48929 Mdot
.57997 .48931 Mdot
.57998 .48932 Mdot
.57999 .48934 Mdot
.58 .48936 Mdot
.58001 .48937 Mdot
.58002 .48939 Mdot
.58003 .48941 Mdot
.58004 .48942 Mdot
.58005 .48944 Mdot
.58006 .48945 Mdot
.58007 .48947 Mdot
.58008 .48949 Mdot
.58009 .4895 Mdot
.5801 .48952 Mdot
.5801 .48954 Mdot
.58011 .48955 Mdot
.58012 .48957 Mdot
.58013 .48959 Mdot
.58014 .4896 Mdot
.58015 .48962 Mdot
.58016 .48963 Mdot
.58017 .48965 Mdot
.58018 .48967 Mdot
.58019 .48968 Mdot
.5802 .4897 Mdot
.58021 .48972 Mdot
.58022 .48973 Mdot
.58023 .48975 Mdot
.58024 .48977 Mdot
.58025 .48978 Mdot
.58026 .4898 Mdot
.58027 .48981 Mdot
.58028 .48983 Mdot
.58029 .48985 Mdot
.5803 .48986 Mdot
.5803 .48988 Mdot
.58031 .4899 Mdot
.58032 .48991 Mdot
.58033 .48993 Mdot
.58034 .48995 Mdot
.58035 .48996 Mdot
.58036 .48998 Mdot
.58037 .48999 Mdot
.58038 .49001 Mdot
.58039 .49003 Mdot
.5804 .49004 Mdot
.58041 .49006 Mdot
.58042 .49008 Mdot
.58043 .49009 Mdot
.58044 .49011 Mdot
.58045 .49013 Mdot
.58046 .49014 Mdot
.58047 .49016 Mdot
.58048 .49017 Mdot
.58049 .49019 Mdot
.5805 .49021 Mdot
.5805 .49022 Mdot
.58051 .49024 Mdot
.58052 .49026 Mdot
.58053 .49027 Mdot
.58054 .49029 Mdot
.58055 .49031 Mdot
.58056 .49032 Mdot
.58057 .49034 Mdot
.58058 .49035 Mdot
.58059 .49037 Mdot
.5806 .49039 Mdot
.58061 .4904 Mdot
.58062 .49042 Mdot
.58063 .49044 Mdot
.58064 .49045 Mdot
.58065 .49047 Mdot
.58066 .49048 Mdot
.58067 .4905 Mdot
.58068 .49052 Mdot
.58069 .49053 Mdot
.5807 .49055 Mdot
.5807 .49057 Mdot
.58071 .49058 Mdot
.58072 .4906 Mdot
.58073 .49062 Mdot
.58074 .49063 Mdot
.58075 .49065 Mdot
.58076 .49066 Mdot
.58077 .49068 Mdot
.58078 .4907 Mdot
.58079 .49071 Mdot
.5808 .49073 Mdot
.58081 .49075 Mdot
.58082 .49076 Mdot
.58083 .49078 Mdot
.58084 .49079 Mdot
.58085 .49081 Mdot
.58086 .49083 Mdot
.58087 .49084 Mdot
.58088 .49086 Mdot
.58089 .49088 Mdot
.5809 .49089 Mdot
.5809 .49091 Mdot
.58091 .49092 Mdot
.58092 .49094 Mdot
.58093 .49096 Mdot
.58094 .49097 Mdot
.58095 .49099 Mdot
.58096 .49101 Mdot
.58097 .49102 Mdot
.58098 .49104 Mdot
.58099 .49106 Mdot
.581 .49107 Mdot
.58101 .49109 Mdot
.58102 .4911 Mdot
.58103 .49112 Mdot
.58104 .49114 Mdot
.58105 .49115 Mdot
.58106 .49117 Mdot
.58107 .49119 Mdot
.58108 .4912 Mdot
.58109 .49122 Mdot
.5811 .49123 Mdot
.5811 .49125 Mdot
.58111 .49127 Mdot
.58112 .49128 Mdot
.58113 .4913 Mdot
.58114 .49132 Mdot
.58115 .49133 Mdot
.58116 .49135 Mdot
.58117 .49136 Mdot
.58118 .49138 Mdot
.58119 .4914 Mdot
.5812 .49141 Mdot
.58121 .49143 Mdot
.58122 .49145 Mdot
.58123 .49146 Mdot
.58124 .49148 Mdot
.58125 .49149 Mdot
.58126 .49151 Mdot
.58127 .49153 Mdot
.58128 .49154 Mdot
.58129 .49156 Mdot
.5813 .49158 Mdot
.5813 .49159 Mdot
.58131 .49161 Mdot
.58132 .49162 Mdot
.58133 .49164 Mdot
.58134 .49166 Mdot
.58135 .49167 Mdot
.58136 .49169 Mdot
.58137 .49171 Mdot
.58138 .49172 Mdot
.58139 .49174 Mdot
.5814 .49175 Mdot
.58141 .49177 Mdot
.58142 .49179 Mdot
.58143 .4918 Mdot
.58144 .49182 Mdot
.58145 .49184 Mdot
.58146 .49185 Mdot
.58147 .49187 Mdot
.58148 .49188 Mdot
.58149 .4919 Mdot
.5815 .49192 Mdot
.5815 .49193 Mdot
.58151 .49195 Mdot
.58152 .49196 Mdot
.58153 .49198 Mdot
.58154 .492 Mdot
.58155 .49201 Mdot
.58156 .49203 Mdot
.58157 .49205 Mdot
.58158 .49206 Mdot
.58159 .49208 Mdot
.5816 .49209 Mdot
.58161 .49211 Mdot
.58162 .49213 Mdot
.58163 .49214 Mdot
.58164 .49216 Mdot
.58165 .49218 Mdot
.58166 .49219 Mdot
.58167 .49221 Mdot
.58168 .49222 Mdot
.58169 .49224 Mdot
.5817 .49226 Mdot
.5817 .49227 Mdot
.58171 .49229 Mdot
.58172 .4923 Mdot
.58173 .49232 Mdot
.58174 .49234 Mdot
.58175 .49235 Mdot
.58176 .49237 Mdot
.58177 .49239 Mdot
.58178 .4924 Mdot
.58179 .49242 Mdot
.5818 .49243 Mdot
.58181 .49245 Mdot
.58182 .49247 Mdot
.58183 .49248 Mdot
.58184 .4925 Mdot
.58185 .49252 Mdot
.58186 .49253 Mdot
.58187 .49255 Mdot
.58188 .49256 Mdot
.58189 .49258 Mdot
.5819 .4926 Mdot
.5819 .49261 Mdot
.58191 .49263 Mdot
.58192 .49264 Mdot
.58193 .49266 Mdot
.58194 .49268 Mdot
.58195 .49269 Mdot
.58196 .49271 Mdot
.58197 .49273 Mdot
.58198 .49274 Mdot
.58199 .49276 Mdot
.582 .49277 Mdot
.58201 .49279 Mdot
.58202 .49281 Mdot
.58203 .49282 Mdot
.58204 .49284 Mdot
.58205 .49285 Mdot
.58206 .49287 Mdot
.58207 .49289 Mdot
.58208 .4929 Mdot
.58209 .49292 Mdot
.5821 .49294 Mdot
.5821 .49295 Mdot
.58211 .49297 Mdot
.58212 .49298 Mdot
.58213 .493 Mdot
.58214 .49302 Mdot
.58215 .49303 Mdot
.58216 .49305 Mdot
.58217 .49306 Mdot
.58218 .49308 Mdot
.58219 .4931 Mdot
.5822 .49311 Mdot
.58221 .49313 Mdot
.58222 .49314 Mdot
.58223 .49316 Mdot
.58224 .49318 Mdot
.58225 .49319 Mdot
.58226 .49321 Mdot
.58227 .49323 Mdot
.58228 .49324 Mdot
.58229 .49326 Mdot
.5823 .49327 Mdot
.5823 .49329 Mdot
.58231 .49331 Mdot
.58232 .49332 Mdot
.58233 .49334 Mdot
.58234 .49335 Mdot
.58235 .49337 Mdot
.58236 .49339 Mdot
.58237 .4934 Mdot
.58238 .49342 Mdot
.58239 .49343 Mdot
.5824 .49345 Mdot
.58241 .49347 Mdot
.58242 .49348 Mdot
.58243 .4935 Mdot
.58244 .49352 Mdot
.58245 .49353 Mdot
.58246 .49355 Mdot
.58247 .49356 Mdot
.58248 .49358 Mdot
.58249 .4936 Mdot
.5825 .49361 Mdot
.5825 .49363 Mdot
.58251 .49364 Mdot
.58252 .49366 Mdot
.58253 .49368 Mdot
.58254 .49369 Mdot
.58255 .49371 Mdot
.58256 .49372 Mdot
.58257 .49374 Mdot
.58258 .49376 Mdot
.58259 .49377 Mdot
.5826 .49379 Mdot
.58261 .4938 Mdot
.58262 .49382 Mdot
.58263 .49384 Mdot
.58264 .49385 Mdot
.58265 .49387 Mdot
.58266 .49389 Mdot
.58267 .4939 Mdot
.58268 .49392 Mdot
.58269 .49393 Mdot
.5827 .49395 Mdot
.5827 .49397 Mdot
.58271 .49398 Mdot
.58272 .494 Mdot
.58273 .49401 Mdot
.58274 .49403 Mdot
.58275 .49405 Mdot
.58276 .49406 Mdot
.58277 .49408 Mdot
.58278 .49409 Mdot
.58279 .49411 Mdot
.5828 .49413 Mdot
.58281 .49414 Mdot
.58282 .49416 Mdot
.58283 .49417 Mdot
.58284 .49419 Mdot
.58285 .49421 Mdot
.58286 .49422 Mdot
.58287 .49424 Mdot
.58288 .49425 Mdot
.58289 .49427 Mdot
.5829 .49429 Mdot
.5829 .4943 Mdot
.58291 .49432 Mdot
.58292 .49433 Mdot
.58293 .49435 Mdot
.58294 .49437 Mdot
.58295 .49438 Mdot
.58296 .4944 Mdot
.58297 .49441 Mdot
.58298 .49443 Mdot
.58299 .49445 Mdot
.583 .49446 Mdot
.58301 .49448 Mdot
.58302 .4945 Mdot
.58303 .49451 Mdot
.58304 .49453 Mdot
.58305 .49454 Mdot
.58306 .49456 Mdot
.58307 .49458 Mdot
.58308 .49459 Mdot
.58309 .49461 Mdot
.5831 .49462 Mdot
.5831 .49464 Mdot
.58311 .49466 Mdot
.58312 .49467 Mdot
.58313 .49469 Mdot
.58314 .4947 Mdot
.58315 .49472 Mdot
.58316 .49474 Mdot
.58317 .49475 Mdot
.58318 .49477 Mdot
.58319 .49478 Mdot
.5832 .4948 Mdot
.58321 .49482 Mdot
.58322 .49483 Mdot
.58323 .49485 Mdot
.58324 .49486 Mdot
.58325 .49488 Mdot
.58326 .4949 Mdot
.58327 .49491 Mdot
.58328 .49493 Mdot
.58329 .49494 Mdot
.5833 .49496 Mdot
.5833 .49498 Mdot
.58331 .49499 Mdot
.58332 .49501 Mdot
.58333 .49502 Mdot
.58334 .49504 Mdot
.58335 .49506 Mdot
.58336 .49507 Mdot
.58337 .49509 Mdot
.58338 .4951 Mdot
.58339 .49512 Mdot
.5834 .49514 Mdot
.58341 .49515 Mdot
.58342 .49517 Mdot
.58343 .49518 Mdot
.58344 .4952 Mdot
.58345 .49521 Mdot
.58346 .49523 Mdot
.58347 .49525 Mdot
.58348 .49526 Mdot
.58349 .49528 Mdot
.5835 .49529 Mdot
.5835 .49531 Mdot
.58351 .49533 Mdot
.58352 .49534 Mdot
.58353 .49536 Mdot
.58354 .49537 Mdot
.58355 .49539 Mdot
.58356 .49541 Mdot
.58357 .49542 Mdot
.58358 .49544 Mdot
.58359 .49545 Mdot
.5836 .49547 Mdot
.58361 .49549 Mdot
.58362 .4955 Mdot
.58363 .49552 Mdot
.58364 .49553 Mdot
.58365 .49555 Mdot
.58366 .49557 Mdot
.58367 .49558 Mdot
.58368 .4956 Mdot
.58369 .49561 Mdot
.5837 .49563 Mdot
.5837 .49565 Mdot
.58371 .49566 Mdot
.58372 .49568 Mdot
.58373 .49569 Mdot
.58374 .49571 Mdot
.58375 .49573 Mdot
.58376 .49574 Mdot
.58377 .49576 Mdot
.58378 .49577 Mdot
.58379 .49579 Mdot
.5838 .49581 Mdot
.58381 .49582 Mdot
.58382 .49584 Mdot
.58383 .49585 Mdot
.58384 .49587 Mdot
.58385 .49588 Mdot
.58386 .4959 Mdot
.58387 .49592 Mdot
.58388 .49593 Mdot
.58389 .49595 Mdot
.5839 .49596 Mdot
.5839 .49598 Mdot
.58391 .496 Mdot
.58392 .49601 Mdot
.58393 .49603 Mdot
.58394 .49604 Mdot
.58395 .49606 Mdot
.58396 .49608 Mdot
.58397 .49609 Mdot
.58398 .49611 Mdot
.58399 .49612 Mdot
.584 .49614 Mdot
.58401 .49616 Mdot
.58402 .49617 Mdot
.58403 .49619 Mdot
.58404 .4962 Mdot
.58405 .49622 Mdot
.58406 .49623 Mdot
.58407 .49625 Mdot
.58408 .49627 Mdot
.58409 .49628 Mdot
.5841 .4963 Mdot
.5841 .49631 Mdot
.58411 .49633 Mdot
.58412 .49635 Mdot
.58413 .49636 Mdot
.58414 .49638 Mdot
.58415 .49639 Mdot
.58416 .49641 Mdot
.58417 .49643 Mdot
.58418 .49644 Mdot
.58419 .49646 Mdot
.5842 .49647 Mdot
.58421 .49649 Mdot
.58422 .4965 Mdot
.58423 .49652 Mdot
.58424 .49654 Mdot
.58425 .49655 Mdot
.58426 .49657 Mdot
.58427 .49658 Mdot
.58428 .4966 Mdot
.58429 .49662 Mdot
.5843 .49663 Mdot
.5843 .49665 Mdot
.58431 .49666 Mdot
.58432 .49668 Mdot
.58433 .4967 Mdot
.58434 .49671 Mdot
.58435 .49673 Mdot
.58436 .49674 Mdot
.58437 .49676 Mdot
.58438 .49677 Mdot
.58439 .49679 Mdot
.5844 .49681 Mdot
.58441 .49682 Mdot
.58442 .49684 Mdot
.58443 .49685 Mdot
.58444 .49687 Mdot
.58445 .49689 Mdot
.58446 .4969 Mdot
.58447 .49692 Mdot
.58448 .49693 Mdot
.58449 .49695 Mdot
.5845 .49696 Mdot
.5845 .49698 Mdot
.58451 .497 Mdot
.58452 .49701 Mdot
.58453 .49703 Mdot
.58454 .49704 Mdot
.58455 .49706 Mdot
.58456 .49708 Mdot
.58457 .49709 Mdot
.58458 .49711 Mdot
.58459 .49712 Mdot
.5846 .49714 Mdot
.58461 .49715 Mdot
.58462 .49717 Mdot
.58463 .49719 Mdot
.58464 .4972 Mdot
.58465 .49722 Mdot
.58466 .49723 Mdot
.58467 .49725 Mdot
.58468 .49727 Mdot
.58469 .49728 Mdot
.5847 .4973 Mdot
.5847 .49731 Mdot
.58471 .49733 Mdot
.58472 .49734 Mdot
.58473 .49736 Mdot
.58474 .49738 Mdot
.58475 .49739 Mdot
.58476 .49741 Mdot
.58477 .49742 Mdot
.58478 .49744 Mdot
.58479 .49745 Mdot
.5848 .49747 Mdot
.58481 .49749 Mdot
.58482 .4975 Mdot
.58483 .49752 Mdot
.58484 .49753 Mdot
.58485 .49755 Mdot
.58486 .49757 Mdot
.58487 .49758 Mdot
.58488 .4976 Mdot
.58489 .49761 Mdot
.5849 .49763 Mdot
.5849 .49764 Mdot
.58491 .49766 Mdot
.58492 .49768 Mdot
.58493 .49769 Mdot
.58494 .49771 Mdot
.58495 .49772 Mdot
.58496 .49774 Mdot
.58497 .49775 Mdot
.58498 .49777 Mdot
.58499 .49779 Mdot
.585 .4978 Mdot
.58501 .49782 Mdot
.58502 .49783 Mdot
.58503 .49785 Mdot
.58504 .49787 Mdot
.58505 .49788 Mdot
.58506 .4979 Mdot
.58507 .49791 Mdot
.58508 .49793 Mdot
.58509 .49794 Mdot
.5851 .49796 Mdot
.5851 .49798 Mdot
.58511 .49799 Mdot
.58512 .49801 Mdot
.58513 .49802 Mdot
.58514 .49804 Mdot
.58515 .49805 Mdot
.58516 .49807 Mdot
.58517 .49809 Mdot
.58518 .4981 Mdot
.58519 .49812 Mdot
.5852 .49813 Mdot
.58521 .49815 Mdot
.58522 .49816 Mdot
.58523 .49818 Mdot
.58524 .4982 Mdot
.58525 .49821 Mdot
.58526 .49823 Mdot
.58527 .49824 Mdot
.58528 .49826 Mdot
.58529 .49828 Mdot
.5853 .49829 Mdot
.5853 .49831 Mdot
.58531 .49832 Mdot
.58532 .49834 Mdot
.58533 .49835 Mdot
.58534 .49837 Mdot
.58535 .49839 Mdot
.58536 .4984 Mdot
.58537 .49842 Mdot
.58538 .49843 Mdot
.58539 .49845 Mdot
.5854 .49846 Mdot
.58541 .49848 Mdot
.58542 .4985 Mdot
.58543 .49851 Mdot
.58544 .49853 Mdot
.58545 .49854 Mdot
.58546 .49856 Mdot
.58547 .49857 Mdot
.58548 .49859 Mdot
.58549 .49861 Mdot
.5855 .49862 Mdot
.5855 .49864 Mdot
.58551 .49865 Mdot
.58552 .49867 Mdot
.58553 .49868 Mdot
.58554 .4987 Mdot
.58555 .49872 Mdot
.58556 .49873 Mdot
.58557 .49875 Mdot
.58558 .49876 Mdot
.58559 .49878 Mdot
.5856 .49879 Mdot
.58561 .49881 Mdot
.58562 .49883 Mdot
.58563 .49884 Mdot
.58564 .49886 Mdot
.58565 .49887 Mdot
.58566 .49889 Mdot
.58567 .4989 Mdot
.58568 .49892 Mdot
.58569 .49894 Mdot
.5857 .49895 Mdot
.5857 .49897 Mdot
.58571 .49898 Mdot
.58572 .499 Mdot
.58573 .49901 Mdot
.58574 .49903 Mdot
.58575 .49905 Mdot
.58576 .49906 Mdot
.58577 .49908 Mdot
.58578 .49909 Mdot
.58579 .49911 Mdot
.5858 .49912 Mdot
.58581 .49914 Mdot
.58582 .49915 Mdot
.58583 .49917 Mdot
.58584 .49919 Mdot
.58585 .4992 Mdot
.58586 .49922 Mdot
.58587 .49923 Mdot
.58588 .49925 Mdot
.58589 .49926 Mdot
.5859 .49928 Mdot
.5859 .4993 Mdot
.58591 .49931 Mdot
.58592 .49933 Mdot
.58593 .49934 Mdot
.58594 .49936 Mdot
.58595 .49937 Mdot
.58596 .49939 Mdot
.58597 .49941 Mdot
.58598 .49942 Mdot
.58599 .49944 Mdot
.586 .49945 Mdot
.58601 .49947 Mdot
.58602 .49948 Mdot
.58603 .4995 Mdot
.58604 .49952 Mdot
.58605 .49953 Mdot
.58606 .49955 Mdot
.58607 .49956 Mdot
.58608 .49958 Mdot
.58609 .49959 Mdot
.5861 .49961 Mdot
.5861 .49962 Mdot
.58611 .49964 Mdot
.58612 .49966 Mdot
.58613 .49967 Mdot
.58614 .49969 Mdot
.58615 .4997 Mdot
.58616 .49972 Mdot
.58617 .49973 Mdot
.58618 .49975 Mdot
.58619 .49977 Mdot
.5862 .49978 Mdot
.58621 .4998 Mdot
.58622 .49981 Mdot
.58623 .49983 Mdot
.58624 .49984 Mdot
.58625 .49986 Mdot
.58626 .49987 Mdot
.58627 .49989 Mdot
.58628 .49991 Mdot
.58629 .49992 Mdot
.5863 .49994 Mdot
.5863 .49995 Mdot
.58631 .49997 Mdot
.58632 .49998 Mdot
.58633 .5 Mdot
.58634 .50002 Mdot
.58635 .50003 Mdot
.58636 .50005 Mdot
.58637 .50006 Mdot
.58638 .50008 Mdot
.58639 .50009 Mdot
.5864 .50011 Mdot
.58641 .50012 Mdot
.58642 .50014 Mdot
.58643 .50016 Mdot
.58644 .50017 Mdot
.58645 .50019 Mdot
.58646 .5002 Mdot
.58647 .50022 Mdot
.58648 .50023 Mdot
.58649 .50025 Mdot
.5865 .50026 Mdot
.5865 .50028 Mdot
.58651 .5003 Mdot
.58652 .50031 Mdot
.58653 .50033 Mdot
.58654 .50034 Mdot
.58655 .50036 Mdot
.58656 .50037 Mdot
.58657 .50039 Mdot
.58658 .50041 Mdot
.58659 .50042 Mdot
.5866 .50044 Mdot
.58661 .50045 Mdot
.58662 .50047 Mdot
.58663 .50048 Mdot
.58664 .5005 Mdot
.58665 .50051 Mdot
.58666 .50053 Mdot
.58667 .50055 Mdot
.58668 .50056 Mdot
.58669 .50058 Mdot
.5867 .50059 Mdot
.5867 .50061 Mdot
.58671 .50062 Mdot
.58672 .50064 Mdot
.58673 .50065 Mdot
.58674 .50067 Mdot
.58675 .50069 Mdot
.58676 .5007 Mdot
.58677 .50072 Mdot
.58678 .50073 Mdot
.58679 .50075 Mdot
.5868 .50076 Mdot
.58681 .50078 Mdot
.58682 .50079 Mdot
.58683 .50081 Mdot
.58684 .50083 Mdot
.58685 .50084 Mdot
.58686 .50086 Mdot
.58687 .50087 Mdot
.58688 .50089 Mdot
.58689 .5009 Mdot
.5869 .50092 Mdot
.5869 .50093 Mdot
.58691 .50095 Mdot
.58692 .50097 Mdot
.58693 .50098 Mdot
.58694 .501 Mdot
.58695 .50101 Mdot
.58696 .50103 Mdot
.58697 .50104 Mdot
.58698 .50106 Mdot
.58699 .50107 Mdot
.587 .50109 Mdot
.58701 .5011 Mdot
.58702 .50112 Mdot
.58703 .50114 Mdot
.58704 .50115 Mdot
.58705 .50117 Mdot
.58706 .50118 Mdot
.58707 .5012 Mdot
.58708 .50121 Mdot
.58709 .50123 Mdot
.5871 .50124 Mdot
.5871 .50126 Mdot
.58711 .50128 Mdot
.58712 .50129 Mdot
.58713 .50131 Mdot
.58714 .50132 Mdot
.58715 .50134 Mdot
.58716 .50135 Mdot
.58717 .50137 Mdot
.58718 .50138 Mdot
.58719 .5014 Mdot
.5872 .50142 Mdot
.58721 .50143 Mdot
.58722 .50145 Mdot
.58723 .50146 Mdot
.58724 .50148 Mdot
.58725 .50149 Mdot
.58726 .50151 Mdot
.58727 .50152 Mdot
.58728 .50154 Mdot
.58729 .50155 Mdot
.5873 .50157 Mdot
.5873 .50159 Mdot
.58731 .5016 Mdot
.58732 .50162 Mdot
.58733 .50163 Mdot
.58734 .50165 Mdot
.58735 .50166 Mdot
.58736 .50168 Mdot
.58737 .50169 Mdot
.58738 .50171 Mdot
.58739 .50173 Mdot
.5874 .50174 Mdot
.58741 .50176 Mdot
.58742 .50177 Mdot
.58743 .50179 Mdot
.58744 .5018 Mdot
.58745 .50182 Mdot
.58746 .50183 Mdot
.58747 .50185 Mdot
.58748 .50186 Mdot
.58749 .50188 Mdot
.5875 .5019 Mdot
.5875 .50191 Mdot
.58751 .50193 Mdot
.58752 .50194 Mdot
.58753 .50196 Mdot
.58754 .50197 Mdot
.58755 .50199 Mdot
.58756 .502 Mdot
.58757 .50202 Mdot
.58758 .50203 Mdot
.58759 .50205 Mdot
.5876 .50207 Mdot
.58761 .50208 Mdot
.58762 .5021 Mdot
.58763 .50211 Mdot
.58764 .50213 Mdot
.58765 .50214 Mdot
.58766 .50216 Mdot
.58767 .50217 Mdot
.58768 .50219 Mdot
.58769 .5022 Mdot
.5877 .50222 Mdot
.5877 .50224 Mdot
.58771 .50225 Mdot
.58772 .50227 Mdot
.58773 .50228 Mdot
.58774 .5023 Mdot
.58775 .50231 Mdot
.58776 .50233 Mdot
.58777 .50234 Mdot
.58778 .50236 Mdot
.58779 .50237 Mdot
.5878 .50239 Mdot
.58781 .5024 Mdot
.58782 .50242 Mdot
.58783 .50244 Mdot
.58784 .50245 Mdot
.58785 .50247 Mdot
.58786 .50248 Mdot
.58787 .5025 Mdot
.58788 .50251 Mdot
.58789 .50253 Mdot
.5879 .50254 Mdot
.5879 .50256 Mdot
.58791 .50257 Mdot
.58792 .50259 Mdot
.58793 .50261 Mdot
.58794 .50262 Mdot
.58795 .50264 Mdot
.58796 .50265 Mdot
.58797 .50267 Mdot
.58798 .50268 Mdot
.58799 .5027 Mdot
.588 .50271 Mdot
.58801 .50273 Mdot
.58802 .50274 Mdot
.58803 .50276 Mdot
.58804 .50277 Mdot
.58805 .50279 Mdot
.58806 .50281 Mdot
.58807 .50282 Mdot
.58808 .50284 Mdot
.58809 .50285 Mdot
.5881 .50287 Mdot
.5881 .50288 Mdot
.58811 .5029 Mdot
.58812 .50291 Mdot
.58813 .50293 Mdot
.58814 .50294 Mdot
.58815 .50296 Mdot
.58816 .50297 Mdot
.58817 .50299 Mdot
.58818 .50301 Mdot
.58819 .50302 Mdot
.5882 .50304 Mdot
.58821 .50305 Mdot
.58822 .50307 Mdot
.58823 .50308 Mdot
.58824 .5031 Mdot
.58825 .50311 Mdot
.58826 .50313 Mdot
.58827 .50314 Mdot
.58828 .50316 Mdot
.58829 .50317 Mdot
.5883 .50319 Mdot
.5883 .50321 Mdot
.58831 .50322 Mdot
.58832 .50324 Mdot
.58833 .50325 Mdot
.58834 .50327 Mdot
.58835 .50328 Mdot
.58836 .5033 Mdot
.58837 .50331 Mdot
.58838 .50333 Mdot
.58839 .50334 Mdot
.5884 .50336 Mdot
.58841 .50337 Mdot
.58842 .50339 Mdot
.58843 .50341 Mdot
.58844 .50342 Mdot
.58845 .50344 Mdot
.58846 .50345 Mdot
.58847 .50347 Mdot
.58848 .50348 Mdot
.58849 .5035 Mdot
.5885 .50351 Mdot
.5885 .50353 Mdot
.58851 .50354 Mdot
.58852 .50356 Mdot
.58853 .50357 Mdot
.58854 .50359 Mdot
.58855 .5036 Mdot
.58856 .50362 Mdot
.58857 .50364 Mdot
.58858 .50365 Mdot
.58859 .50367 Mdot
.5886 .50368 Mdot
.58861 .5037 Mdot
.58862 .50371 Mdot
.58863 .50373 Mdot
.58864 .50374 Mdot
.58865 .50376 Mdot
.58866 .50377 Mdot
.58867 .50379 Mdot
.58868 .5038 Mdot
.58869 .50382 Mdot
.5887 .50383 Mdot
.5887 .50385 Mdot
.58871 .50387 Mdot
.58872 .50388 Mdot
.58873 .5039 Mdot
.58874 .50391 Mdot
.58875 .50393 Mdot
.58876 .50394 Mdot
.58877 .50396 Mdot
.58878 .50397 Mdot
.58879 .50399 Mdot
.5888 .504 Mdot
.58881 .50402 Mdot
.58882 .50403 Mdot
.58883 .50405 Mdot
.58884 .50406 Mdot
.58885 .50408 Mdot
.58886 .50409 Mdot
.58887 .50411 Mdot
.58888 .50413 Mdot
.58889 .50414 Mdot
.5889 .50416 Mdot
.5889 .50417 Mdot
.58891 .50419 Mdot
.58892 .5042 Mdot
.58893 .50422 Mdot
.58894 .50423 Mdot
.58895 .50425 Mdot
.58896 .50426 Mdot
.58897 .50428 Mdot
.58898 .50429 Mdot
.58899 .50431 Mdot
.589 .50432 Mdot
.58901 .50434 Mdot
.58902 .50435 Mdot
.58903 .50437 Mdot
.58904 .50439 Mdot
.58905 .5044 Mdot
.58906 .50442 Mdot
.58907 .50443 Mdot
.58908 .50445 Mdot
.58909 .50446 Mdot
.5891 .50448 Mdot
.5891 .50449 Mdot
.58911 .50451 Mdot
.58912 .50452 Mdot
.58913 .50454 Mdot
.58914 .50455 Mdot
.58915 .50457 Mdot
.58916 .50458 Mdot
.58917 .5046 Mdot
.58918 .50461 Mdot
.58919 .50463 Mdot
.5892 .50464 Mdot
.58921 .50466 Mdot
.58922 .50468 Mdot
.58923 .50469 Mdot
.58924 .50471 Mdot
.58925 .50472 Mdot
.58926 .50474 Mdot
.58927 .50475 Mdot
.58928 .50477 Mdot
.58929 .50478 Mdot
.5893 .5048 Mdot
.5893 .50481 Mdot
.58931 .50483 Mdot
.58932 .50484 Mdot
.58933 .50486 Mdot
.58934 .50487 Mdot
.58935 .50489 Mdot
.58936 .5049 Mdot
.58937 .50492 Mdot
.58938 .50493 Mdot
.58939 .50495 Mdot
.5894 .50496 Mdot
.58941 .50498 Mdot
.58942 .505 Mdot
.58943 .50501 Mdot
.58944 .50503 Mdot
.58945 .50504 Mdot
.58946 .50506 Mdot
.58947 .50507 Mdot
.58948 .50509 Mdot
.58949 .5051 Mdot
.5895 .50512 Mdot
.5895 .50513 Mdot
.58951 .50515 Mdot
.58952 .50516 Mdot
.58953 .50518 Mdot
.58954 .50519 Mdot
.58955 .50521 Mdot
.58956 .50522 Mdot
.58957 .50524 Mdot
.58958 .50525 Mdot
.58959 .50527 Mdot
.5896 .50528 Mdot
.58961 .5053 Mdot
.58962 .50531 Mdot
.58963 .50533 Mdot
.58964 .50535 Mdot
.58965 .50536 Mdot
.58966 .50538 Mdot
.58967 .50539 Mdot
.58968 .50541 Mdot
.58969 .50542 Mdot
.5897 .50544 Mdot
.5897 .50545 Mdot
.58971 .50547 Mdot
.58972 .50548 Mdot
.58973 .5055 Mdot
.58974 .50551 Mdot
.58975 .50553 Mdot
.58976 .50554 Mdot
.58977 .50556 Mdot
.58978 .50557 Mdot
.58979 .50559 Mdot
.5898 .5056 Mdot
.58981 .50562 Mdot
.58982 .50563 Mdot
.58983 .50565 Mdot
.58984 .50566 Mdot
.58985 .50568 Mdot
.58986 .50569 Mdot
.58987 .50571 Mdot
.58988 .50572 Mdot
.58989 .50574 Mdot
.5899 .50576 Mdot
.5899 .50577 Mdot
.58991 .50579 Mdot
.58992 .5058 Mdot
.58993 .50582 Mdot
.58994 .50583 Mdot
.58995 .50585 Mdot
.58996 .50586 Mdot
.58997 .50588 Mdot
.58998 .50589 Mdot
.58999 .50591 Mdot
.59 .50592 Mdot
.59001 .50594 Mdot
.59002 .50595 Mdot
.59003 .50597 Mdot
.59004 .50598 Mdot
.59005 .506 Mdot
.59006 .50601 Mdot
.59007 .50603 Mdot
.59008 .50604 Mdot
.59009 .50606 Mdot
.5901 .50607 Mdot
.5901 .50609 Mdot
.59011 .5061 Mdot
.59012 .50612 Mdot
.59013 .50613 Mdot
.59014 .50615 Mdot
.59015 .50616 Mdot
.59016 .50618 Mdot
.59017 .50619 Mdot
.59018 .50621 Mdot
.59019 .50622 Mdot
.5902 .50624 Mdot
.59021 .50625 Mdot
.59022 .50627 Mdot
.59023 .50629 Mdot
.59024 .5063 Mdot
.59025 .50632 Mdot
.59026 .50633 Mdot
.59027 .50635 Mdot
.59028 .50636 Mdot
.59029 .50638 Mdot
.5903 .50639 Mdot
.5903 .50641 Mdot
.59031 .50642 Mdot
.59032 .50644 Mdot
.59033 .50645 Mdot
.59034 .50647 Mdot
.59035 .50648 Mdot
.59036 .5065 Mdot
.59037 .50651 Mdot
.59038 .50653 Mdot
.59039 .50654 Mdot
.5904 .50656 Mdot
.59041 .50657 Mdot
.59042 .50659 Mdot
.59043 .5066 Mdot
.59044 .50662 Mdot
.59045 .50663 Mdot
.59046 .50665 Mdot
.59047 .50666 Mdot
.59048 .50668 Mdot
.59049 .50669 Mdot
.5905 .50671 Mdot
.5905 .50672 Mdot
.59051 .50674 Mdot
.59052 .50675 Mdot
.59053 .50677 Mdot
.59054 .50678 Mdot
.59055 .5068 Mdot
.59056 .50681 Mdot
.59057 .50683 Mdot
.59058 .50684 Mdot
.59059 .50686 Mdot
.5906 .50687 Mdot
.59061 .50689 Mdot
.59062 .5069 Mdot
.59063 .50692 Mdot
.59064 .50693 Mdot
.59065 .50695 Mdot
.59066 .50696 Mdot
.59067 .50698 Mdot
.59068 .50699 Mdot
.59069 .50701 Mdot
.5907 .50702 Mdot
.5907 .50704 Mdot
.59071 .50706 Mdot
.59072 .50707 Mdot
.59073 .50709 Mdot
.59074 .5071 Mdot
.59075 .50712 Mdot
.59076 .50713 Mdot
.59077 .50715 Mdot
.59078 .50716 Mdot
.59079 .50718 Mdot
.5908 .50719 Mdot
.59081 .50721 Mdot
.59082 .50722 Mdot
.59083 .50724 Mdot
.59084 .50725 Mdot
.59085 .50727 Mdot
.59086 .50728 Mdot
.59087 .5073 Mdot
.59088 .50731 Mdot
.59089 .50733 Mdot
.5909 .50734 Mdot
.5909 .50736 Mdot
.59091 .50737 Mdot
.59092 .50739 Mdot
.59093 .5074 Mdot
.59094 .50742 Mdot
.59095 .50743 Mdot
.59096 .50745 Mdot
.59097 .50746 Mdot
.59098 .50748 Mdot
.59099 .50749 Mdot
.591 .50751 Mdot
.59101 .50752 Mdot
.59102 .50754 Mdot
.59103 .50755 Mdot
.59104 .50757 Mdot
.59105 .50758 Mdot
.59106 .5076 Mdot
.59107 .50761 Mdot
.59108 .50763 Mdot
.59109 .50764 Mdot
.5911 .50766 Mdot
.5911 .50767 Mdot
.59111 .50769 Mdot
.59112 .5077 Mdot
.59113 .50772 Mdot
.59114 .50773 Mdot
.59115 .50775 Mdot
.59116 .50776 Mdot
.59117 .50778 Mdot
.59118 .50779 Mdot
.59119 .50781 Mdot
.5912 .50782 Mdot
.59121 .50784 Mdot
.59122 .50785 Mdot
.59123 .50787 Mdot
.59124 .50788 Mdot
.59125 .5079 Mdot
.59126 .50791 Mdot
.59127 .50793 Mdot
.59128 .50794 Mdot
.59129 .50796 Mdot
.5913 .50797 Mdot
.5913 .50799 Mdot
.59131 .508 Mdot
.59132 .50802 Mdot
.59133 .50803 Mdot
.59134 .50805 Mdot
.59135 .50806 Mdot
.59136 .50808 Mdot
.59137 .50809 Mdot
.59138 .50811 Mdot
.59139 .50812 Mdot
.5914 .50814 Mdot
.59141 .50815 Mdot
.59142 .50817 Mdot
.59143 .50818 Mdot
.59144 .5082 Mdot
.59145 .50821 Mdot
.59146 .50823 Mdot
.59147 .50824 Mdot
.59148 .50826 Mdot
.59149 .50827 Mdot
.5915 .50829 Mdot
.5915 .5083 Mdot
.59151 .50832 Mdot
.59152 .50833 Mdot
.59153 .50835 Mdot
.59154 .50836 Mdot
.59155 .50838 Mdot
.59156 .50839 Mdot
.59157 .50841 Mdot
.59158 .50842 Mdot
.59159 .50844 Mdot
.5916 .50845 Mdot
.59161 .50847 Mdot
.59162 .50848 Mdot
.59163 .5085 Mdot
.59164 .50851 Mdot
.59165 .50853 Mdot
.59166 .50854 Mdot
.59167 .50856 Mdot
.59168 .50857 Mdot
.59169 .50859 Mdot
.5917 .5086 Mdot
.5917 .50862 Mdot
.59171 .50863 Mdot
.59172 .50865 Mdot
.59173 .50866 Mdot
.59174 .50868 Mdot
.59175 .50869 Mdot
.59176 .50871 Mdot
.59177 .50872 Mdot
.59178 .50873 Mdot
.59179 .50875 Mdot
.5918 .50876 Mdot
.59181 .50878 Mdot
.59182 .50879 Mdot
.59183 .50881 Mdot
.59184 .50882 Mdot
.59185 .50884 Mdot
.59186 .50885 Mdot
.59187 .50887 Mdot
.59188 .50888 Mdot
.59189 .5089 Mdot
.5919 .50891 Mdot
.5919 .50893 Mdot
.59191 .50894 Mdot
.59192 .50896 Mdot
.59193 .50897 Mdot
.59194 .50899 Mdot
.59195 .509 Mdot
.59196 .50902 Mdot
.59197 .50903 Mdot
.59198 .50905 Mdot
.59199 .50906 Mdot
.592 .50908 Mdot
.59201 .50909 Mdot
.59202 .50911 Mdot
.59203 .50912 Mdot
.59204 .50914 Mdot
.59205 .50915 Mdot
.59206 .50917 Mdot
.59207 .50918 Mdot
.59208 .5092 Mdot
.59209 .50921 Mdot
.5921 .50923 Mdot
.5921 .50924 Mdot
.59211 .50926 Mdot
.59212 .50927 Mdot
.59213 .50929 Mdot
.59214 .5093 Mdot
.59215 .50932 Mdot
.59216 .50933 Mdot
.59217 .50935 Mdot
.59218 .50936 Mdot
.59219 .50938 Mdot
.5922 .50939 Mdot
.59221 .50941 Mdot
.59222 .50942 Mdot
.59223 .50944 Mdot
.59224 .50945 Mdot
.59225 .50947 Mdot
.59226 .50948 Mdot
.59227 .50949 Mdot
.59228 .50951 Mdot
.59229 .50952 Mdot
.5923 .50954 Mdot
.5923 .50955 Mdot
.59231 .50957 Mdot
.59232 .50958 Mdot
.59233 .5096 Mdot
.59234 .50961 Mdot
.59235 .50963 Mdot
.59236 .50964 Mdot
.59237 .50966 Mdot
.59238 .50967 Mdot
.59239 .50969 Mdot
.5924 .5097 Mdot
.59241 .50972 Mdot
.59242 .50973 Mdot
.59243 .50975 Mdot
.59244 .50976 Mdot
.59245 .50978 Mdot
.59246 .50979 Mdot
.59247 .50981 Mdot
.59248 .50982 Mdot
.59249 .50984 Mdot
.5925 .50985 Mdot
.5925 .50987 Mdot
.59251 .50988 Mdot
.59252 .5099 Mdot
.59253 .50991 Mdot
.59254 .50993 Mdot
.59255 .50994 Mdot
.59256 .50996 Mdot
.59257 .50997 Mdot
.59258 .50998 Mdot
.59259 .51 Mdot
.5926 .51001 Mdot
.59261 .51003 Mdot
.59262 .51004 Mdot
.59263 .51006 Mdot
.59264 .51007 Mdot
.59265 .51009 Mdot
.59266 .5101 Mdot
.59267 .51012 Mdot
.59268 .51013 Mdot
.59269 .51015 Mdot
.5927 .51016 Mdot
.5927 .51018 Mdot
.59271 .51019 Mdot
.59272 .51021 Mdot
.59273 .51022 Mdot
.59274 .51024 Mdot
.59275 .51025 Mdot
.59276 .51027 Mdot
.59277 .51028 Mdot
.59278 .5103 Mdot
.59279 .51031 Mdot
.5928 .51033 Mdot
.59281 .51034 Mdot
.59282 .51036 Mdot
.59283 .51037 Mdot
.59284 .51038 Mdot
.59285 .5104 Mdot
.59286 .51041 Mdot
.59287 .51043 Mdot
.59288 .51044 Mdot
.59289 .51046 Mdot
.5929 .51047 Mdot
.5929 .51049 Mdot
.59291 .5105 Mdot
.59292 .51052 Mdot
.59293 .51053 Mdot
.59294 .51055 Mdot
.59295 .51056 Mdot
.59296 .51058 Mdot
.59297 .51059 Mdot
.59298 .51061 Mdot
.59299 .51062 Mdot
.593 .51064 Mdot
.59301 .51065 Mdot
.59302 .51067 Mdot
.59303 .51068 Mdot
.59304 .5107 Mdot
.59305 .51071 Mdot
.59306 .51073 Mdot
.59307 .51074 Mdot
.59308 .51075 Mdot
.59309 .51077 Mdot
.5931 .51078 Mdot
.5931 .5108 Mdot
.59311 .51081 Mdot
.59312 .51083 Mdot
.59313 .51084 Mdot
.59314 .51086 Mdot
.59315 .51087 Mdot
.59316 .51089 Mdot
.59317 .5109 Mdot
.59318 .51092 Mdot
.59319 .51093 Mdot
.5932 .51095 Mdot
.59321 .51096 Mdot
.59322 .51098 Mdot
.59323 .51099 Mdot
.59324 .51101 Mdot
.59325 .51102 Mdot
.59326 .51104 Mdot
.59327 .51105 Mdot
.59328 .51106 Mdot
.59329 .51108 Mdot
.5933 .51109 Mdot
.5933 .51111 Mdot
.59331 .51112 Mdot
.59332 .51114 Mdot
.59333 .51115 Mdot
.59334 .51117 Mdot
.59335 .51118 Mdot
.59336 .5112 Mdot
.59337 .51121 Mdot
.59338 .51123 Mdot
.59339 .51124 Mdot
.5934 .51126 Mdot
.59341 .51127 Mdot
.59342 .51129 Mdot
.59343 .5113 Mdot
.59344 .51131 Mdot
.59345 .51133 Mdot
.59346 .51134 Mdot
.59347 .51136 Mdot
.59348 .51137 Mdot
.59349 .51139 Mdot
.5935 .5114 Mdot
.5935 .51142 Mdot
.59351 .51143 Mdot
.59352 .51145 Mdot
.59353 .51146 Mdot
.59354 .51148 Mdot
.59355 .51149 Mdot
.59356 .51151 Mdot
.59357 .51152 Mdot
.59358 .51154 Mdot
.59359 .51155 Mdot
.5936 .51157 Mdot
.59361 .51158 Mdot
.59362 .51159 Mdot
.59363 .51161 Mdot
.59364 .51162 Mdot
.59365 .51164 Mdot
.59366 .51165 Mdot
.59367 .51167 Mdot
.59368 .51168 Mdot
.59369 .5117 Mdot
.5937 .51171 Mdot
.5937 .51173 Mdot
.59371 .51174 Mdot
.59372 .51176 Mdot
.59373 .51177 Mdot
.59374 .51179 Mdot
.59375 .5118 Mdot
.59376 .51181 Mdot
.59377 .51183 Mdot
.59378 .51184 Mdot
.59379 .51186 Mdot
.5938 .51187 Mdot
.59381 .51189 Mdot
.59382 .5119 Mdot
.59383 .51192 Mdot
.59384 .51193 Mdot
.59385 .51195 Mdot
.59386 .51196 Mdot
.59387 .51198 Mdot
.59388 .51199 Mdot
.59389 .51201 Mdot
.5939 .51202 Mdot
.5939 .51204 Mdot
.59391 .51205 Mdot
.59392 .51206 Mdot
.59393 .51208 Mdot
.59394 .51209 Mdot
.59395 .51211 Mdot
.59396 .51212 Mdot
.59397 .51214 Mdot
.59398 .51215 Mdot
.59399 .51217 Mdot
.594 .51218 Mdot
.59401 .5122 Mdot
.59402 .51221 Mdot
.59403 .51223 Mdot
.59404 .51224 Mdot
.59405 .51225 Mdot
.59406 .51227 Mdot
.59407 .51228 Mdot
.59408 .5123 Mdot
.59409 .51231 Mdot
.5941 .51233 Mdot
.5941 .51234 Mdot
.59411 .51236 Mdot
.59412 .51237 Mdot
.59413 .51239 Mdot
.59414 .5124 Mdot
.59415 .51242 Mdot
.59416 .51243 Mdot
.59417 .51245 Mdot
.59418 .51246 Mdot
.59419 .51247 Mdot
.5942 .51249 Mdot
.59421 .5125 Mdot
.59422 .51252 Mdot
.59423 .51253 Mdot
.59424 .51255 Mdot
.59425 .51256 Mdot
.59426 .51258 Mdot
.59427 .51259 Mdot
.59428 .51261 Mdot
.59429 .51262 Mdot
.5943 .51264 Mdot
.5943 .51265 Mdot
.59431 .51266 Mdot
.59432 .51268 Mdot
.59433 .51269 Mdot
.59434 .51271 Mdot
.59435 .51272 Mdot
.59436 .51274 Mdot
.59437 .51275 Mdot
.59438 .51277 Mdot
.59439 .51278 Mdot
.5944 .5128 Mdot
.59441 .51281 Mdot
.59442 .51283 Mdot
.59443 .51284 Mdot
.59444 .51285 Mdot
.59445 .51287 Mdot
.59446 .51288 Mdot
.59447 .5129 Mdot
.59448 .51291 Mdot
.59449 .51293 Mdot
.5945 .51294 Mdot
.5945 .51296 Mdot
.59451 .51297 Mdot
.59452 .51299 Mdot
.59453 .513 Mdot
.59454 .51302 Mdot
.59455 .51303 Mdot
.59456 .51304 Mdot
.59457 .51306 Mdot
.59458 .51307 Mdot
.59459 .51309 Mdot
.5946 .5131 Mdot
.59461 .51312 Mdot
.59462 .51313 Mdot
.59463 .51315 Mdot
.59464 .51316 Mdot
.59465 .51318 Mdot
.59466 .51319 Mdot
.59467 .5132 Mdot
.59468 .51322 Mdot
.59469 .51323 Mdot
.5947 .51325 Mdot
.5947 .51326 Mdot
.59471 .51328 Mdot
.59472 .51329 Mdot
.59473 .51331 Mdot
.59474 .51332 Mdot
.59475 .51334 Mdot
.59476 .51335 Mdot
.59477 .51336 Mdot
.59478 .51338 Mdot
.59479 .51339 Mdot
.5948 .51341 Mdot
.59481 .51342 Mdot
.59482 .51344 Mdot
.59483 .51345 Mdot
.59484 .51347 Mdot
.59485 .51348 Mdot
.59486 .5135 Mdot
.59487 .51351 Mdot
.59488 .51352 Mdot
.59489 .51354 Mdot
.5949 .51355 Mdot
.5949 .51357 Mdot
.59491 .51358 Mdot
.59492 .5136 Mdot
.59493 .51361 Mdot
.59494 .51363 Mdot
.59495 .51364 Mdot
.59496 .51366 Mdot
.59497 .51367 Mdot
.59498 .51368 Mdot
.59499 .5137 Mdot
.595 .51371 Mdot
.59501 .51373 Mdot
.59502 .51374 Mdot
.59503 .51376 Mdot
.59504 .51377 Mdot
.59505 .51379 Mdot
.59506 .5138 Mdot
.59507 .51382 Mdot
.59508 .51383 Mdot
.59509 .51384 Mdot
.5951 .51386 Mdot
.5951 .51387 Mdot
.59511 .51389 Mdot
.59512 .5139 Mdot
.59513 .51392 Mdot
.59514 .51393 Mdot
.59515 .51395 Mdot
.59516 .51396 Mdot
.59517 .51398 Mdot
.59518 .51399 Mdot
.59519 .514 Mdot
.5952 .51402 Mdot
.59521 .51403 Mdot
.59522 .51405 Mdot
.59523 .51406 Mdot
.59524 .51408 Mdot
.59525 .51409 Mdot
.59526 .51411 Mdot
.59527 .51412 Mdot
.59528 .51413 Mdot
.59529 .51415 Mdot
.5953 .51416 Mdot
.5953 .51418 Mdot
.59531 .51419 Mdot
.59532 .51421 Mdot
.59533 .51422 Mdot
.59534 .51424 Mdot
.59535 .51425 Mdot
.59536 .51427 Mdot
.59537 .51428 Mdot
.59538 .51429 Mdot
.59539 .51431 Mdot
.5954 .51432 Mdot
.59541 .51434 Mdot
.59542 .51435 Mdot
.59543 .51437 Mdot
.59544 .51438 Mdot
.59545 .5144 Mdot
.59546 .51441 Mdot
.59547 .51442 Mdot
.59548 .51444 Mdot
.59549 .51445 Mdot
.5955 .51447 Mdot
.5955 .51448 Mdot
.59551 .5145 Mdot
.59552 .51451 Mdot
.59553 .51453 Mdot
.59554 .51454 Mdot
.59555 .51455 Mdot
.59556 .51457 Mdot
.59557 .51458 Mdot
.59558 .5146 Mdot
.59559 .51461 Mdot
.5956 .51463 Mdot
.59561 .51464 Mdot
.59562 .51466 Mdot
.59563 .51467 Mdot
.59564 .51468 Mdot
.59565 .5147 Mdot
.59566 .51471 Mdot
.59567 .51473 Mdot
.59568 .51474 Mdot
.59569 .51476 Mdot
.5957 .51477 Mdot
.5957 .51479 Mdot
.59571 .5148 Mdot
.59572 .51481 Mdot
.59573 .51483 Mdot
.59574 .51484 Mdot
.59575 .51486 Mdot
.59576 .51487 Mdot
.59577 .51489 Mdot
.59578 .5149 Mdot
.59579 .51492 Mdot
.5958 .51493 Mdot
.59581 .51494 Mdot
.59582 .51496 Mdot
.59583 .51497 Mdot
.59584 .51499 Mdot
.59585 .515 Mdot
.59586 .51502 Mdot
.59587 .51503 Mdot
.59588 .51505 Mdot
.59589 .51506 Mdot
.5959 .51507 Mdot
.5959 .51509 Mdot
.59591 .5151 Mdot
.59592 .51512 Mdot
.59593 .51513 Mdot
.59594 .51515 Mdot
.59595 .51516 Mdot
.59596 .51518 Mdot
.59597 .51519 Mdot
.59598 .5152 Mdot
.59599 .51522 Mdot
.596 .51523 Mdot
.59601 .51525 Mdot
.59602 .51526 Mdot
.59603 .51528 Mdot
.59604 .51529 Mdot
.59605 .5153 Mdot
.59606 .51532 Mdot
.59607 .51533 Mdot
.59608 .51535 Mdot
.59609 .51536 Mdot
.5961 .51538 Mdot
.5961 .51539 Mdot
.59611 .51541 Mdot
.59612 .51542 Mdot
.59613 .51543 Mdot
.59614 .51545 Mdot
.59615 .51546 Mdot
.59616 .51548 Mdot
.59617 .51549 Mdot
.59618 .51551 Mdot
.59619 .51552 Mdot
.5962 .51554 Mdot
.59621 .51555 Mdot
.59622 .51556 Mdot
.59623 .51558 Mdot
.59624 .51559 Mdot
.59625 .51561 Mdot
.59626 .51562 Mdot
.59627 .51564 Mdot
.59628 .51565 Mdot
.59629 .51566 Mdot
.5963 .51568 Mdot
.5963 .51569 Mdot
.59631 .51571 Mdot
.59632 .51572 Mdot
.59633 .51574 Mdot
.59634 .51575 Mdot
.59635 .51577 Mdot
.59636 .51578 Mdot
.59637 .51579 Mdot
.59638 .51581 Mdot
.59639 .51582 Mdot
.5964 .51584 Mdot
.59641 .51585 Mdot
.59642 .51587 Mdot
.59643 .51588 Mdot
.59644 .51589 Mdot
.59645 .51591 Mdot
.59646 .51592 Mdot
.59647 .51594 Mdot
.59648 .51595 Mdot
.59649 .51597 Mdot
.5965 .51598 Mdot
.5965 .51599 Mdot
.59651 .51601 Mdot
.59652 .51602 Mdot
.59653 .51604 Mdot
.59654 .51605 Mdot
.59655 .51607 Mdot
.59656 .51608 Mdot
.59657 .5161 Mdot
.59658 .51611 Mdot
.59659 .51612 Mdot
.5966 .51614 Mdot
.59661 .51615 Mdot
.59662 .51617 Mdot
.59663 .51618 Mdot
.59664 .5162 Mdot
.59665 .51621 Mdot
.59666 .51622 Mdot
.59667 .51624 Mdot
.59668 .51625 Mdot
.59669 .51627 Mdot
.5967 .51628 Mdot
.5967 .5163 Mdot
.59671 .51631 Mdot
.59672 .51632 Mdot
.59673 .51634 Mdot
.59674 .51635 Mdot
.59675 .51637 Mdot
.59676 .51638 Mdot
.59677 .5164 Mdot
.59678 .51641 Mdot
.59679 .51642 Mdot
.5968 .51644 Mdot
.59681 .51645 Mdot
.59682 .51647 Mdot
.59683 .51648 Mdot
.59684 .5165 Mdot
.59685 .51651 Mdot
.59686 .51652 Mdot
.59687 .51654 Mdot
.59688 .51655 Mdot
.59689 .51657 Mdot
.5969 .51658 Mdot
.5969 .5166 Mdot
.59691 .51661 Mdot
.59692 .51662 Mdot
.59693 .51664 Mdot
.59694 .51665 Mdot
.59695 .51667 Mdot
.59696 .51668 Mdot
.59697 .5167 Mdot
.59698 .51671 Mdot
.59699 .51672 Mdot
.597 .51674 Mdot
.59701 .51675 Mdot
.59702 .51677 Mdot
.59703 .51678 Mdot
.59704 .5168 Mdot
.59705 .51681 Mdot
.59706 .51682 Mdot
.59707 .51684 Mdot
.59708 .51685 Mdot
.59709 .51687 Mdot
.5971 .51688 Mdot
.5971 .5169 Mdot
.59711 .51691 Mdot
.59712 .51692 Mdot
.59713 .51694 Mdot
.59714 .51695 Mdot
.59715 .51697 Mdot
.59716 .51698 Mdot
.59717 .517 Mdot
.59718 .51701 Mdot
.59719 .51702 Mdot
.5972 .51704 Mdot
.59721 .51705 Mdot
.59722 .51707 Mdot
.59723 .51708 Mdot
.59724 .5171 Mdot
.59725 .51711 Mdot
.59726 .51712 Mdot
.59727 .51714 Mdot
.59728 .51715 Mdot
.59729 .51717 Mdot
.5973 .51718 Mdot
.5973 .5172 Mdot
.59731 .51721 Mdot
.59732 .51722 Mdot
.59733 .51724 Mdot
.59734 .51725 Mdot
.59735 .51727 Mdot
.59736 .51728 Mdot
.59737 .51729 Mdot
.59738 .51731 Mdot
.59739 .51732 Mdot
.5974 .51734 Mdot
.59741 .51735 Mdot
.59742 .51737 Mdot
.59743 .51738 Mdot
.59744 .51739 Mdot
.59745 .51741 Mdot
.59746 .51742 Mdot
.59747 .51744 Mdot
.59748 .51745 Mdot
.59749 .51747 Mdot
.5975 .51748 Mdot
.5975 .51749 Mdot
.59751 .51751 Mdot
.59752 .51752 Mdot
.59753 .51754 Mdot
.59754 .51755 Mdot
.59755 .51757 Mdot
.59756 .51758 Mdot
.59757 .51759 Mdot
.59758 .51761 Mdot
.59759 .51762 Mdot
.5976 .51764 Mdot
.59761 .51765 Mdot
.59762 .51766 Mdot
.59763 .51768 Mdot
.59764 .51769 Mdot
.59765 .51771 Mdot
.59766 .51772 Mdot
.59767 .51774 Mdot
.59768 .51775 Mdot
.59769 .51776 Mdot
.5977 .51778 Mdot
.5977 .51779 Mdot
.59771 .51781 Mdot
.59772 .51782 Mdot
.59773 .51783 Mdot
.59774 .51785 Mdot
.59775 .51786 Mdot
.59776 .51788 Mdot
.59777 .51789 Mdot
.59778 .51791 Mdot
.59779 .51792 Mdot
.5978 .51793 Mdot
.59781 .51795 Mdot
.59782 .51796 Mdot
.59783 .51798 Mdot
.59784 .51799 Mdot
.59785 .518 Mdot
.59786 .51802 Mdot
.59787 .51803 Mdot
.59788 .51805 Mdot
.59789 .51806 Mdot
.5979 .51808 Mdot
.5979 .51809 Mdot
.59791 .5181 Mdot
.59792 .51812 Mdot
.59793 .51813 Mdot
.59794 .51815 Mdot
.59795 .51816 Mdot
.59796 .51817 Mdot
.59797 .51819 Mdot
.59798 .5182 Mdot
.59799 .51822 Mdot
.598 .51823 Mdot
.59801 .51825 Mdot
.59802 .51826 Mdot
.59803 .51827 Mdot
.59804 .51829 Mdot
.59805 .5183 Mdot
.59806 .51832 Mdot
.59807 .51833 Mdot
.59808 .51834 Mdot
.59809 .51836 Mdot
.5981 .51837 Mdot
.5981 .51839 Mdot
.59811 .5184 Mdot
.59812 .51842 Mdot
.59813 .51843 Mdot
.59814 .51844 Mdot
.59815 .51846 Mdot
.59816 .51847 Mdot
.59817 .51849 Mdot
.59818 .5185 Mdot
.59819 .51851 Mdot
.5982 .51853 Mdot
.59821 .51854 Mdot
.59822 .51856 Mdot
.59823 .51857 Mdot
.59824 .51859 Mdot
.59825 .5186 Mdot
.59826 .51861 Mdot
.59827 .51863 Mdot
.59828 .51864 Mdot
.59829 .51866 Mdot
.5983 .51867 Mdot
.5983 .51868 Mdot
.59831 .5187 Mdot
.59832 .51871 Mdot
.59833 .51873 Mdot
.59834 .51874 Mdot
.59835 .51875 Mdot
.59836 .51877 Mdot
.59837 .51878 Mdot
.59838 .5188 Mdot
.59839 .51881 Mdot
.5984 .51883 Mdot
.59841 .51884 Mdot
.59842 .51885 Mdot
.59843 .51887 Mdot
.59844 .51888 Mdot
.59845 .5189 Mdot
.59846 .51891 Mdot
.59847 .51892 Mdot
.59848 .51894 Mdot
.59849 .51895 Mdot
.5985 .51897 Mdot
.5985 .51898 Mdot
.59851 .51899 Mdot
.59852 .51901 Mdot
.59853 .51902 Mdot
.59854 .51904 Mdot
.59855 .51905 Mdot
.59856 .51906 Mdot
.59857 .51908 Mdot
.59858 .51909 Mdot
.59859 .51911 Mdot
.5986 .51912 Mdot
.59861 .51914 Mdot
.59862 .51915 Mdot
.59863 .51916 Mdot
.59864 .51918 Mdot
.59865 .51919 Mdot
.59866 .51921 Mdot
.59867 .51922 Mdot
.59868 .51923 Mdot
.59869 .51925 Mdot
.5987 .51926 Mdot
.5987 .51928 Mdot
.59871 .51929 Mdot
.59872 .5193 Mdot
.59873 .51932 Mdot
.59874 .51933 Mdot
.59875 .51935 Mdot
.59876 .51936 Mdot
.59877 .51937 Mdot
.59878 .51939 Mdot
.59879 .5194 Mdot
.5988 .51942 Mdot
.59881 .51943 Mdot
.59882 .51944 Mdot
.59883 .51946 Mdot
.59884 .51947 Mdot
.59885 .51949 Mdot
.59886 .5195 Mdot
.59887 .51951 Mdot
.59888 .51953 Mdot
.59889 .51954 Mdot
.5989 .51956 Mdot
.5989 .51957 Mdot
.59891 .51958 Mdot
.59892 .5196 Mdot
.59893 .51961 Mdot
.59894 .51963 Mdot
.59895 .51964 Mdot
.59896 .51966 Mdot
.59897 .51967 Mdot
.59898 .51968 Mdot
.59899 .5197 Mdot
.599 .51971 Mdot
.59901 .51973 Mdot
.59902 .51974 Mdot
.59903 .51975 Mdot
.59904 .51977 Mdot
.59905 .51978 Mdot
.59906 .5198 Mdot
.59907 .51981 Mdot
.59908 .51982 Mdot
.59909 .51984 Mdot
.5991 .51985 Mdot
.5991 .51987 Mdot
.59911 .51988 Mdot
.59912 .51989 Mdot
.59913 .51991 Mdot
.59914 .51992 Mdot
.59915 .51994 Mdot
.59916 .51995 Mdot
.59917 .51996 Mdot
.59918 .51998 Mdot
.59919 .51999 Mdot
.5992 .52001 Mdot
.59921 .52002 Mdot
.59922 .52003 Mdot
.59923 .52005 Mdot
.59924 .52006 Mdot
.59925 .52008 Mdot
.59926 .52009 Mdot
.59927 .5201 Mdot
.59928 .52012 Mdot
.59929 .52013 Mdot
.5993 .52015 Mdot
.5993 .52016 Mdot
.59931 .52017 Mdot
.59932 .52019 Mdot
.59933 .5202 Mdot
.59934 .52022 Mdot
.59935 .52023 Mdot
.59936 .52024 Mdot
.59937 .52026 Mdot
.59938 .52027 Mdot
.59939 .52029 Mdot
.5994 .5203 Mdot
.59941 .52031 Mdot
.59942 .52033 Mdot
.59943 .52034 Mdot
.59944 .52036 Mdot
.59945 .52037 Mdot
.59946 .52038 Mdot
.59947 .5204 Mdot
.59948 .52041 Mdot
.59949 .52043 Mdot
.5995 .52044 Mdot
.5995 .52045 Mdot
.59951 .52047 Mdot
.59952 .52048 Mdot
.59953 .5205 Mdot
.59954 .52051 Mdot
.59955 .52052 Mdot
.59956 .52054 Mdot
.59957 .52055 Mdot
.59958 .52056 Mdot
.59959 .52058 Mdot
.5996 .52059 Mdot
.59961 .52061 Mdot
.59962 .52062 Mdot
.59963 .52063 Mdot
.59964 .52065 Mdot
.59965 .52066 Mdot
.59966 .52068 Mdot
.59967 .52069 Mdot
.59968 .5207 Mdot
.59969 .52072 Mdot
.5997 .52073 Mdot
.5997 .52075 Mdot
.59971 .52076 Mdot
.59972 .52077 Mdot
.59973 .52079 Mdot
.59974 .5208 Mdot
.59975 .52082 Mdot
.59976 .52083 Mdot
.59977 .52084 Mdot
.59978 .52086 Mdot
.59979 .52087 Mdot
.5998 .52089 Mdot
.59981 .5209 Mdot
.59982 .52091 Mdot
.59983 .52093 Mdot
.59984 .52094 Mdot
.59985 .52096 Mdot
.59986 .52097 Mdot
.59987 .52098 Mdot
.59988 .521 Mdot
.59989 .52101 Mdot
.5999 .52102 Mdot
.5999 .52104 Mdot
.59991 .52105 Mdot
.59992 .52107 Mdot
.59993 .52108 Mdot
.59994 .52109 Mdot
.59995 .52111 Mdot
.59996 .52112 Mdot
.59997 .52114 Mdot
.59998 .52115 Mdot
.59999 .52116 Mdot
.6 .52118 Mdot
.60001 .52119 Mdot
.60002 .52121 Mdot
.60003 .52122 Mdot
.60004 .52123 Mdot
.60005 .52125 Mdot
.60006 .52126 Mdot
.60007 .52128 Mdot
.60008 .52129 Mdot
.60009 .5213 Mdot
.6001 .52132 Mdot
.6001 .52133 Mdot
.60011 .52134 Mdot
.60012 .52136 Mdot
.60013 .52137 Mdot
.60014 .52139 Mdot
.60015 .5214 Mdot
.60016 .52141 Mdot
.60017 .52143 Mdot
.60018 .52144 Mdot
.60019 .52146 Mdot
.6002 .52147 Mdot
.60021 .52148 Mdot
.60022 .5215 Mdot
.60023 .52151 Mdot
.60024 .52153 Mdot
.60025 .52154 Mdot
.60026 .52155 Mdot
.60027 .52157 Mdot
.60028 .52158 Mdot
.60029 .52159 Mdot
.6003 .52161 Mdot
.6003 .52162 Mdot
.60031 .52164 Mdot
.60032 .52165 Mdot
.60033 .52166 Mdot
.60034 .52168 Mdot
.60035 .52169 Mdot
.60036 .52171 Mdot
.60037 .52172 Mdot
.60038 .52173 Mdot
.60039 .52175 Mdot
.6004 .52176 Mdot
.60041 .52177 Mdot
.60042 .52179 Mdot
.60043 .5218 Mdot
.60044 .52182 Mdot
.60045 .52183 Mdot
.60046 .52184 Mdot
.60047 .52186 Mdot
.60048 .52187 Mdot
.60049 .52189 Mdot
.6005 .5219 Mdot
.6005 .52191 Mdot
.60051 .52193 Mdot
.60052 .52194 Mdot
.60053 .52195 Mdot
.60054 .52197 Mdot
.60055 .52198 Mdot
.60056 .522 Mdot
.60057 .52201 Mdot
.60058 .52202 Mdot
.60059 .52204 Mdot
.6006 .52205 Mdot
.60061 .52207 Mdot
.60062 .52208 Mdot
.60063 .52209 Mdot
.60064 .52211 Mdot
.60065 .52212 Mdot
.60066 .52213 Mdot
.60067 .52215 Mdot
.60068 .52216 Mdot
.60069 .52218 Mdot
.6007 .52219 Mdot
.6007 .5222 Mdot
.60071 .52222 Mdot
.60072 .52223 Mdot
.60073 .52224 Mdot
.60074 .52226 Mdot
.60075 .52227 Mdot
.60076 .52229 Mdot
.60077 .5223 Mdot
.60078 .52231 Mdot
.60079 .52233 Mdot
.6008 .52234 Mdot
.60081 .52236 Mdot
.60082 .52237 Mdot
.60083 .52238 Mdot
.60084 .5224 Mdot
.60085 .52241 Mdot
.60086 .52242 Mdot
.60087 .52244 Mdot
.60088 .52245 Mdot
.60089 .52247 Mdot
.6009 .52248 Mdot
.6009 .52249 Mdot
.60091 .52251 Mdot
.60092 .52252 Mdot
.60093 .52253 Mdot
.60094 .52255 Mdot
.60095 .52256 Mdot
.60096 .52258 Mdot
.60097 .52259 Mdot
.60098 .5226 Mdot
.60099 .52262 Mdot
.601 .52263 Mdot
.60101 .52264 Mdot
.60102 .52266 Mdot
.60103 .52267 Mdot
.60104 .52269 Mdot
.60105 .5227 Mdot
.60106 .52271 Mdot
.60107 .52273 Mdot
.60108 .52274 Mdot
.60109 .52276 Mdot
.6011 .52277 Mdot
.6011 .52278 Mdot
.60111 .5228 Mdot
.60112 .52281 Mdot
.60113 .52282 Mdot
.60114 .52284 Mdot
.60115 .52285 Mdot
.60116 .52287 Mdot
.60117 .52288 Mdot
.60118 .52289 Mdot
.60119 .52291 Mdot
.6012 .52292 Mdot
.60121 .52293 Mdot
.60122 .52295 Mdot
.60123 .52296 Mdot
.60124 .52298 Mdot
.60125 .52299 Mdot
.60126 .523 Mdot
.60127 .52302 Mdot
.60128 .52303 Mdot
.60129 .52304 Mdot
.6013 .52306 Mdot
.6013 .52307 Mdot
.60131 .52309 Mdot
.60132 .5231 Mdot
.60133 .52311 Mdot
.60134 .52313 Mdot
.60135 .52314 Mdot
.60136 .52315 Mdot
.60137 .52317 Mdot
.60138 .52318 Mdot
.60139 .5232 Mdot
.6014 .52321 Mdot
.60141 .52322 Mdot
.60142 .52324 Mdot
.60143 .52325 Mdot
.60144 .52326 Mdot
.60145 .52328 Mdot
.60146 .52329 Mdot
.60147 .5233 Mdot
.60148 .52332 Mdot
.60149 .52333 Mdot
.6015 .52335 Mdot
.6015 .52336 Mdot
.60151 .52337 Mdot
.60152 .52339 Mdot
.60153 .5234 Mdot
.60154 .52341 Mdot
.60155 .52343 Mdot
.60156 .52344 Mdot
.60157 .52346 Mdot
.60158 .52347 Mdot
.60159 .52348 Mdot
.6016 .5235 Mdot
.60161 .52351 Mdot
.60162 .52352 Mdot
.60163 .52354 Mdot
.60164 .52355 Mdot
.60165 .52357 Mdot
.60166 .52358 Mdot
.60167 .52359 Mdot
.60168 .52361 Mdot
.60169 .52362 Mdot
.6017 .52363 Mdot
.6017 .52365 Mdot
.60171 .52366 Mdot
.60172 .52367 Mdot
.60173 .52369 Mdot
.60174 .5237 Mdot
.60175 .52372 Mdot
.60176 .52373 Mdot
.60177 .52374 Mdot
.60178 .52376 Mdot
.60179 .52377 Mdot
.6018 .52378 Mdot
.60181 .5238 Mdot
.60182 .52381 Mdot
.60183 .52383 Mdot
.60184 .52384 Mdot
.60185 .52385 Mdot
.60186 .52387 Mdot
.60187 .52388 Mdot
.60188 .52389 Mdot
.60189 .52391 Mdot
.6019 .52392 Mdot
.6019 .52393 Mdot
.60191 .52395 Mdot
.60192 .52396 Mdot
.60193 .52398 Mdot
.60194 .52399 Mdot
.60195 .524 Mdot
.60196 .52402 Mdot
.60197 .52403 Mdot
.60198 .52404 Mdot
.60199 .52406 Mdot
.602 .52407 Mdot
.60201 .52409 Mdot
.60202 .5241 Mdot
.60203 .52411 Mdot
.60204 .52413 Mdot
.60205 .52414 Mdot
.60206 .52415 Mdot
.60207 .52417 Mdot
.60208 .52418 Mdot
.60209 .52419 Mdot
.6021 .52421 Mdot
.6021 .52422 Mdot
.60211 .52424 Mdot
.60212 .52425 Mdot
.60213 .52426 Mdot
.60214 .52428 Mdot
.60215 .52429 Mdot
.60216 .5243 Mdot
.60217 .52432 Mdot
.60218 .52433 Mdot
.60219 .52434 Mdot
.6022 .52436 Mdot
.60221 .52437 Mdot
.60222 .52439 Mdot
.60223 .5244 Mdot
.60224 .52441 Mdot
.60225 .52443 Mdot
.60226 .52444 Mdot
.60227 .52445 Mdot
.60228 .52447 Mdot
.60229 .52448 Mdot
.6023 .52449 Mdot
.6023 .52451 Mdot
.60231 .52452 Mdot
.60232 .52453 Mdot
.60233 .52455 Mdot
.60234 .52456 Mdot
.60235 .52458 Mdot
.60236 .52459 Mdot
.60237 .5246 Mdot
.60238 .52462 Mdot
.60239 .52463 Mdot
.6024 .52464 Mdot
.60241 .52466 Mdot
.60242 .52467 Mdot
.60243 .52468 Mdot
.60244 .5247 Mdot
.60245 .52471 Mdot
.60246 .52473 Mdot
.60247 .52474 Mdot
.60248 .52475 Mdot
.60249 .52477 Mdot
.6025 .52478 Mdot
.6025 .52479 Mdot
.60251 .52481 Mdot
.60252 .52482 Mdot
.60253 .52483 Mdot
.60254 .52485 Mdot
.60255 .52486 Mdot
.60256 .52487 Mdot
.60257 .52489 Mdot
.60258 .5249 Mdot
.60259 .52492 Mdot
.6026 .52493 Mdot
.60261 .52494 Mdot
.60262 .52496 Mdot
.60263 .52497 Mdot
.60264 .52498 Mdot
.60265 .525 Mdot
.60266 .52501 Mdot
.60267 .52502 Mdot
.60268 .52504 Mdot
.60269 .52505 Mdot
.6027 .52506 Mdot
.6027 .52508 Mdot
.60271 .52509 Mdot
.60272 .52511 Mdot
.60273 .52512 Mdot
.60274 .52513 Mdot
.60275 .52515 Mdot
.60276 .52516 Mdot
.60277 .52517 Mdot
.60278 .52519 Mdot
.60279 .5252 Mdot
.6028 .52521 Mdot
.60281 .52523 Mdot
.60282 .52524 Mdot
.60283 .52525 Mdot
.60284 .52527 Mdot
.60285 .52528 Mdot
.60286 .5253 Mdot
.60287 .52531 Mdot
.60288 .52532 Mdot
.60289 .52534 Mdot
.6029 .52535 Mdot
.6029 .52536 Mdot
.60291 .52538 Mdot
.60292 .52539 Mdot
.60293 .5254 Mdot
.60294 .52542 Mdot
.60295 .52543 Mdot
.60296 .52544 Mdot
.60297 .52546 Mdot
.60298 .52547 Mdot
.60299 .52548 Mdot
.603 .5255 Mdot
.60301 .52551 Mdot
.60302 .52553 Mdot
.60303 .52554 Mdot
.60304 .52555 Mdot
.60305 .52557 Mdot
.60306 .52558 Mdot
.60307 .52559 Mdot
.60308 .52561 Mdot
.60309 .52562 Mdot
.6031 .52563 Mdot
.6031 .52565 Mdot
.60311 .52566 Mdot
.60312 .52567 Mdot
.60313 .52569 Mdot
.60314 .5257 Mdot
.60315 .52571 Mdot
.60316 .52573 Mdot
.60317 .52574 Mdot
.60318 .52576 Mdot
.60319 .52577 Mdot
.6032 .52578 Mdot
.60321 .5258 Mdot
.60322 .52581 Mdot
.60323 .52582 Mdot
.60324 .52584 Mdot
.60325 .52585 Mdot
.60326 .52586 Mdot
.60327 .52588 Mdot
.60328 .52589 Mdot
.60329 .5259 Mdot
.6033 .52592 Mdot
.6033 .52593 Mdot
.60331 .52594 Mdot
.60332 .52596 Mdot
.60333 .52597 Mdot
.60334 .52598 Mdot
.60335 .526 Mdot
.60336 .52601 Mdot
.60337 .52603 Mdot
.60338 .52604 Mdot
.60339 .52605 Mdot
.6034 .52607 Mdot
.60341 .52608 Mdot
.60342 .52609 Mdot
.60343 .52611 Mdot
.60344 .52612 Mdot
.60345 .52613 Mdot
.60346 .52615 Mdot
.60347 .52616 Mdot
.60348 .52617 Mdot
.60349 .52619 Mdot
.6035 .5262 Mdot
.6035 .52621 Mdot
.60351 .52623 Mdot
.60352 .52624 Mdot
.60353 .52625 Mdot
.60354 .52627 Mdot
.60355 .52628 Mdot
.60356 .52629 Mdot
.60357 .52631 Mdot
.60358 .52632 Mdot
.60359 .52633 Mdot
.6036 .52635 Mdot
.60361 .52636 Mdot
.60362 .52638 Mdot
.60363 .52639 Mdot
.60364 .5264 Mdot
.60365 .52642 Mdot
.60366 .52643 Mdot
.60367 .52644 Mdot
.60368 .52646 Mdot
.60369 .52647 Mdot
.6037 .52648 Mdot
.6037 .5265 Mdot
.60371 .52651 Mdot
.60372 .52652 Mdot
.60373 .52654 Mdot
.60374 .52655 Mdot
.60375 .52656 Mdot
.60376 .52658 Mdot
.60377 .52659 Mdot
.60378 .5266 Mdot
.60379 .52662 Mdot
.6038 .52663 Mdot
.60381 .52664 Mdot
.60382 .52666 Mdot
.60383 .52667 Mdot
.60384 .52668 Mdot
.60385 .5267 Mdot
.60386 .52671 Mdot
.60387 .52672 Mdot
.60388 .52674 Mdot
.60389 .52675 Mdot
.6039 .52676 Mdot
.6039 .52678 Mdot
.60391 .52679 Mdot
.60392 .52681 Mdot
.60393 .52682 Mdot
.60394 .52683 Mdot
.60395 .52685 Mdot
.60396 .52686 Mdot
.60397 .52687 Mdot
.60398 .52689 Mdot
.60399 .5269 Mdot
.604 .52691 Mdot
.60401 .52693 Mdot
.60402 .52694 Mdot
.60403 .52695 Mdot
.60404 .52697 Mdot
.60405 .52698 Mdot
.60406 .52699 Mdot
.60407 .52701 Mdot
.60408 .52702 Mdot
.60409 .52703 Mdot
.6041 .52705 Mdot
.6041 .52706 Mdot
.60411 .52707 Mdot
.60412 .52709 Mdot
.60413 .5271 Mdot
.60414 .52711 Mdot
.60415 .52713 Mdot
.60416 .52714 Mdot
.60417 .52715 Mdot
.60418 .52717 Mdot
.60419 .52718 Mdot
.6042 .52719 Mdot
.60421 .52721 Mdot
.60422 .52722 Mdot
.60423 .52723 Mdot
.60424 .52725 Mdot
.60425 .52726 Mdot
.60426 .52727 Mdot
.60427 .52729 Mdot
.60428 .5273 Mdot
.60429 .52731 Mdot
.6043 .52733 Mdot
.6043 .52734 Mdot
.60431 .52735 Mdot
.60432 .52737 Mdot
.60433 .52738 Mdot
.60434 .52739 Mdot
.60435 .52741 Mdot
.60436 .52742 Mdot
.60437 .52743 Mdot
.60438 .52745 Mdot
.60439 .52746 Mdot
.6044 .52747 Mdot
.60441 .52749 Mdot
.60442 .5275 Mdot
.60443 .52751 Mdot
.60444 .52753 Mdot
.60445 .52754 Mdot
.60446 .52755 Mdot
.60447 .52757 Mdot
.60448 .52758 Mdot
.60449 .52759 Mdot
.6045 .52761 Mdot
.6045 .52762 Mdot
.60451 .52763 Mdot
.60452 .52765 Mdot
.60453 .52766 Mdot
.60454 .52767 Mdot
.60455 .52769 Mdot
.60456 .5277 Mdot
.60457 .52771 Mdot
.60458 .52773 Mdot
.60459 .52774 Mdot
.6046 .52775 Mdot
.60461 .52777 Mdot
.60462 .52778 Mdot
.60463 .52779 Mdot
.60464 .52781 Mdot
.60465 .52782 Mdot
.60466 .52783 Mdot
.60467 .52785 Mdot
.60468 .52786 Mdot
.60469 .52787 Mdot
.6047 .52789 Mdot
.6047 .5279 Mdot
.60471 .52791 Mdot
.60472 .52793 Mdot
.60473 .52794 Mdot
.60474 .52795 Mdot
.60475 .52797 Mdot
.60476 .52798 Mdot
.60477 .52799 Mdot
.60478 .52801 Mdot
.60479 .52802 Mdot
.6048 .52803 Mdot
.60481 .52805 Mdot
.60482 .52806 Mdot
.60483 .52807 Mdot
.60484 .52809 Mdot
.60485 .5281 Mdot
.60486 .52811 Mdot
.60487 .52813 Mdot
.60488 .52814 Mdot
.60489 .52815 Mdot
.6049 .52817 Mdot
.6049 .52818 Mdot
.60491 .52819 Mdot
.60492 .52821 Mdot
.60493 .52822 Mdot
.60494 .52823 Mdot
.60495 .52825 Mdot
.60496 .52826 Mdot
.60497 .52827 Mdot
.60498 .52829 Mdot
.60499 .5283 Mdot
.605 .52831 Mdot
.60501 .52833 Mdot
.60502 .52834 Mdot
.60503 .52835 Mdot
.60504 .52837 Mdot
.60505 .52838 Mdot
.60506 .52839 Mdot
.60507 .52841 Mdot
.60508 .52842 Mdot
.60509 .52843 Mdot
.6051 .52845 Mdot
.6051 .52846 Mdot
.60511 .52847 Mdot
.60512 .52849 Mdot
.60513 .5285 Mdot
.60514 .52851 Mdot
.60515 .52853 Mdot
.60516 .52854 Mdot
.60517 .52855 Mdot
.60518 .52857 Mdot
.60519 .52858 Mdot
.6052 .52859 Mdot
.60521 .52861 Mdot
.60522 .52862 Mdot
.60523 .52863 Mdot
.60524 .52864 Mdot
.60525 .52866 Mdot
.60526 .52867 Mdot
.60527 .52868 Mdot
.60528 .5287 Mdot
.60529 .52871 Mdot
.6053 .52872 Mdot
.6053 .52874 Mdot
.60531 .52875 Mdot
.60532 .52876 Mdot
.60533 .52878 Mdot
.60534 .52879 Mdot
.60535 .5288 Mdot
.60536 .52882 Mdot
.60537 .52883 Mdot
.60538 .52884 Mdot
.60539 .52886 Mdot
.6054 .52887 Mdot
.60541 .52888 Mdot
.60542 .5289 Mdot
.60543 .52891 Mdot
.60544 .52892 Mdot
.60545 .52894 Mdot
.60546 .52895 Mdot
.60547 .52896 Mdot
.60548 .52898 Mdot
.60549 .52899 Mdot
.6055 .529 Mdot
.6055 .52902 Mdot
.60551 .52903 Mdot
.60552 .52904 Mdot
.60553 .52905 Mdot
.60554 .52907 Mdot
.60555 .52908 Mdot
.60556 .52909 Mdot
.60557 .52911 Mdot
.60558 .52912 Mdot
.60559 .52913 Mdot
.6056 .52915 Mdot
.60561 .52916 Mdot
.60562 .52917 Mdot
.60563 .52919 Mdot
.60564 .5292 Mdot
.60565 .52921 Mdot
.60566 .52923 Mdot
.60567 .52924 Mdot
.60568 .52925 Mdot
.60569 .52927 Mdot
.6057 .52928 Mdot
.6057 .52929 Mdot
.60571 .52931 Mdot
.60572 .52932 Mdot
.60573 .52933 Mdot
.60574 .52935 Mdot
.60575 .52936 Mdot
.60576 .52937 Mdot
.60577 .52938 Mdot
.60578 .5294 Mdot
.60579 .52941 Mdot
.6058 .52942 Mdot
.60581 .52944 Mdot
.60582 .52945 Mdot
.60583 .52946 Mdot
.60584 .52948 Mdot
.60585 .52949 Mdot
.60586 .5295 Mdot
.60587 .52952 Mdot
.60588 .52953 Mdot
.60589 .52954 Mdot
.6059 .52956 Mdot
.6059 .52957 Mdot
.60591 .52958 Mdot
.60592 .5296 Mdot
.60593 .52961 Mdot
.60594 .52962 Mdot
.60595 .52964 Mdot
.60596 .52965 Mdot
.60597 .52966 Mdot
.60598 .52967 Mdot
.60599 .52969 Mdot
.606 .5297 Mdot
.60601 .52971 Mdot
.60602 .52973 Mdot
.60603 .52974 Mdot
.60604 .52975 Mdot
.60605 .52977 Mdot
.60606 .52978 Mdot
.60607 .52979 Mdot
.60608 .52981 Mdot
.60609 .52982 Mdot
.6061 .52983 Mdot
.6061 .52985 Mdot
.60611 .52986 Mdot
.60612 .52987 Mdot
.60613 .52988 Mdot
.60614 .5299 Mdot
.60615 .52991 Mdot
.60616 .52992 Mdot
.60617 .52994 Mdot
.60618 .52995 Mdot
.60619 .52996 Mdot
.6062 .52998 Mdot
.60621 .52999 Mdot
.60622 .53 Mdot
.60623 .53002 Mdot
.60624 .53003 Mdot
.60625 .53004 Mdot
.60626 .53006 Mdot
.60627 .53007 Mdot
.60628 .53008 Mdot
.60629 .53009 Mdot
.6063 .53011 Mdot
.6063 .53012 Mdot
.60631 .53013 Mdot
.60632 .53015 Mdot
.60633 .53016 Mdot
.60634 .53017 Mdot
.60635 .53019 Mdot
.60636 .5302 Mdot
.60637 .53021 Mdot
.60638 .53023 Mdot
.60639 .53024 Mdot
.6064 .53025 Mdot
.60641 .53027 Mdot
.60642 .53028 Mdot
.60643 .53029 Mdot
.60644 .5303 Mdot
.60645 .53032 Mdot
.60646 .53033 Mdot
.60647 .53034 Mdot
.60648 .53036 Mdot
.60649 .53037 Mdot
.6065 .53038 Mdot
.6065 .5304 Mdot
.60651 .53041 Mdot
.60652 .53042 Mdot
.60653 .53044 Mdot
.60654 .53045 Mdot
.60655 .53046 Mdot
.60656 .53047 Mdot
.60657 .53049 Mdot
.60658 .5305 Mdot
.60659 .53051 Mdot
.6066 .53053 Mdot
.60661 .53054 Mdot
.60662 .53055 Mdot
.60663 .53057 Mdot
.60664 .53058 Mdot
.60665 .53059 Mdot
.60666 .53061 Mdot
.60667 .53062 Mdot
.60668 .53063 Mdot
.60669 .53064 Mdot
.6067 .53066 Mdot
.6067 .53067 Mdot
.60671 .53068 Mdot
.60672 .5307 Mdot
.60673 .53071 Mdot
.60674 .53072 Mdot
.60675 .53074 Mdot
.60676 .53075 Mdot
.60677 .53076 Mdot
.60678 .53078 Mdot
.60679 .53079 Mdot
.6068 .5308 Mdot
.60681 .53081 Mdot
.60682 .53083 Mdot
.60683 .53084 Mdot
.60684 .53085 Mdot
.60685 .53087 Mdot
.60686 .53088 Mdot
.60687 .53089 Mdot
.60688 .53091 Mdot
.60689 .53092 Mdot
.6069 .53093 Mdot
.6069 .53095 Mdot
.60691 .53096 Mdot
.60692 .53097 Mdot
.60693 .53098 Mdot
.60694 .531 Mdot
.60695 .53101 Mdot
.60696 .53102 Mdot
.60697 .53104 Mdot
.60698 .53105 Mdot
.60699 .53106 Mdot
.607 .53108 Mdot
.60701 .53109 Mdot
.60702 .5311 Mdot
.60703 .53111 Mdot
.60704 .53113 Mdot
.60705 .53114 Mdot
.60706 .53115 Mdot
.60707 .53117 Mdot
.60708 .53118 Mdot
.60709 .53119 Mdot
.6071 .53121 Mdot
.6071 .53122 Mdot
.60711 .53123 Mdot
.60712 .53124 Mdot
.60713 .53126 Mdot
.60714 .53127 Mdot
.60715 .53128 Mdot
.60716 .5313 Mdot
.60717 .53131 Mdot
.60718 .53132 Mdot
.60719 .53134 Mdot
.6072 .53135 Mdot
.60721 .53136 Mdot
.60722 .53137 Mdot
.60723 .53139 Mdot
.60724 .5314 Mdot
.60725 .53141 Mdot
.60726 .53143 Mdot
.60727 .53144 Mdot
.60728 .53145 Mdot
.60729 .53147 Mdot
.6073 .53148 Mdot
.6073 .53149 Mdot
.60731 .5315 Mdot
.60732 .53152 Mdot
.60733 .53153 Mdot
.60734 .53154 Mdot
.60735 .53156 Mdot
.60736 .53157 Mdot
.60737 .53158 Mdot
.60738 .5316 Mdot
.60739 .53161 Mdot
.6074 .53162 Mdot
.60741 .53163 Mdot
.60742 .53165 Mdot
.60743 .53166 Mdot
.60744 .53167 Mdot
.60745 .53169 Mdot
.60746 .5317 Mdot
.60747 .53171 Mdot
.60748 .53173 Mdot
.60749 .53174 Mdot
.6075 .53175 Mdot
.6075 .53176 Mdot
.60751 .53178 Mdot
.60752 .53179 Mdot
.60753 .5318 Mdot
.60754 .53182 Mdot
.60755 .53183 Mdot
.60756 .53184 Mdot
.60757 .53185 Mdot
.60758 .53187 Mdot
.60759 .53188 Mdot
.6076 .53189 Mdot
.60761 .53191 Mdot
.60762 .53192 Mdot
.60763 .53193 Mdot
.60764 .53195 Mdot
.60765 .53196 Mdot
.60766 .53197 Mdot
.60767 .53198 Mdot
.60768 .532 Mdot
.60769 .53201 Mdot
.6077 .53202 Mdot
.6077 .53204 Mdot
.60771 .53205 Mdot
.60772 .53206 Mdot
.60773 .53207 Mdot
.60774 .53209 Mdot
.60775 .5321 Mdot
.60776 .53211 Mdot
.60777 .53213 Mdot
.60778 .53214 Mdot
.60779 .53215 Mdot
.6078 .53217 Mdot
.60781 .53218 Mdot
.60782 .53219 Mdot
.60783 .5322 Mdot
.60784 .53222 Mdot
.60785 .53223 Mdot
.60786 .53224 Mdot
.60787 .53226 Mdot
.60788 .53227 Mdot
.60789 .53228 Mdot
.6079 .53229 Mdot
.6079 .53231 Mdot
.60791 .53232 Mdot
.60792 .53233 Mdot
.60793 .53235 Mdot
.60794 .53236 Mdot
.60795 .53237 Mdot
.60796 .53239 Mdot
.60797 .5324 Mdot
.60798 .53241 Mdot
.60799 .53242 Mdot
.608 .53244 Mdot
.60801 .53245 Mdot
.60802 .53246 Mdot
.60803 .53248 Mdot
.60804 .53249 Mdot
.60805 .5325 Mdot
.60806 .53251 Mdot
.60807 .53253 Mdot
.60808 .53254 Mdot
.60809 .53255 Mdot
.6081 .53257 Mdot
.6081 .53258 Mdot
.60811 .53259 Mdot
.60812 .5326 Mdot
.60813 .53262 Mdot
.60814 .53263 Mdot
.60815 .53264 Mdot
.60816 .53266 Mdot
.60817 .53267 Mdot
.60818 .53268 Mdot
.60819 .53269 Mdot
.6082 .53271 Mdot
.60821 .53272 Mdot
.60822 .53273 Mdot
.60823 .53275 Mdot
.60824 .53276 Mdot
.60825 .53277 Mdot
.60826 .53278 Mdot
.60827 .5328 Mdot
.60828 .53281 Mdot
.60829 .53282 Mdot
.6083 .53284 Mdot
.6083 .53285 Mdot
.60831 .53286 Mdot
.60832 .53287 Mdot
.60833 .53289 Mdot
.60834 .5329 Mdot
.60835 .53291 Mdot
.60836 .53293 Mdot
.60837 .53294 Mdot
.60838 .53295 Mdot
.60839 .53296 Mdot
.6084 .53298 Mdot
.60841 .53299 Mdot
.60842 .533 Mdot
.60843 .53302 Mdot
.60844 .53303 Mdot
.60845 .53304 Mdot
.60846 .53305 Mdot
.60847 .53307 Mdot
.60848 .53308 Mdot
.60849 .53309 Mdot
.6085 .53311 Mdot
.6085 .53312 Mdot
.60851 .53313 Mdot
.60852 .53314 Mdot
.60853 .53316 Mdot
.60854 .53317 Mdot
.60855 .53318 Mdot
.60856 .5332 Mdot
.60857 .53321 Mdot
.60858 .53322 Mdot
.60859 .53323 Mdot
.6086 .53325 Mdot
.60861 .53326 Mdot
.60862 .53327 Mdot
.60863 .53329 Mdot
.60864 .5333 Mdot
.60865 .53331 Mdot
.60866 .53332 Mdot
.60867 .53334 Mdot
.60868 .53335 Mdot
.60869 .53336 Mdot
.6087 .53338 Mdot
.6087 .53339 Mdot
.60871 .5334 Mdot
.60872 .53341 Mdot
.60873 .53343 Mdot
.60874 .53344 Mdot
.60875 .53345 Mdot
.60876 .53347 Mdot
.60877 .53348 Mdot
.60878 .53349 Mdot
.60879 .5335 Mdot
.6088 .53352 Mdot
.60881 .53353 Mdot
.60882 .53354 Mdot
.60883 .53355 Mdot
.60884 .53357 Mdot
.60885 .53358 Mdot
.60886 .53359 Mdot
.60887 .53361 Mdot
.60888 .53362 Mdot
.60889 .53363 Mdot
.6089 .53364 Mdot
.6089 .53366 Mdot
.60891 .53367 Mdot
.60892 .53368 Mdot
.60893 .5337 Mdot
.60894 .53371 Mdot
.60895 .53372 Mdot
.60896 .53373 Mdot
.60897 .53375 Mdot
.60898 .53376 Mdot
.60899 .53377 Mdot
.609 .53378 Mdot
.60901 .5338 Mdot
.60902 .53381 Mdot
.60903 .53382 Mdot
.60904 .53384 Mdot
.60905 .53385 Mdot
.60906 .53386 Mdot
.60907 .53387 Mdot
.60908 .53389 Mdot
.60909 .5339 Mdot
.6091 .53391 Mdot
.6091 .53393 Mdot
.60911 .53394 Mdot
.60912 .53395 Mdot
.60913 .53396 Mdot
.60914 .53398 Mdot
.60915 .53399 Mdot
.60916 .534 Mdot
.60917 .53401 Mdot
.60918 .53403 Mdot
.60919 .53404 Mdot
.6092 .53405 Mdot
.60921 .53407 Mdot
.60922 .53408 Mdot
.60923 .53409 Mdot
.60924 .5341 Mdot
.60925 .53412 Mdot
.60926 .53413 Mdot
.60927 .53414 Mdot
.60928 .53415 Mdot
.60929 .53417 Mdot
.6093 .53418 Mdot
.6093 .53419 Mdot
.60931 .53421 Mdot
.60932 .53422 Mdot
.60933 .53423 Mdot
.60934 .53424 Mdot
.60935 .53426 Mdot
.60936 .53427 Mdot
.60937 .53428 Mdot
.60938 .53429 Mdot
.60939 .53431 Mdot
.6094 .53432 Mdot
.60941 .53433 Mdot
.60942 .53435 Mdot
.60943 .53436 Mdot
.60944 .53437 Mdot
.60945 .53438 Mdot
.60946 .5344 Mdot
.60947 .53441 Mdot
.60948 .53442 Mdot
.60949 .53443 Mdot
.6095 .53445 Mdot
.6095 .53446 Mdot
.60951 .53447 Mdot
.60952 .53449 Mdot
.60953 .5345 Mdot
.60954 .53451 Mdot
.60955 .53452 Mdot
.60956 .53454 Mdot
.60957 .53455 Mdot
.60958 .53456 Mdot
.60959 .53457 Mdot
.6096 .53459 Mdot
.60961 .5346 Mdot
.60962 .53461 Mdot
.60963 .53463 Mdot
.60964 .53464 Mdot
.60965 .53465 Mdot
.60966 .53466 Mdot
.60967 .53468 Mdot
.60968 .53469 Mdot
.60969 .5347 Mdot
.6097 .53471 Mdot
.6097 .53473 Mdot
.60971 .53474 Mdot
.60972 .53475 Mdot
.60973 .53477 Mdot
.60974 .53478 Mdot
.60975 .53479 Mdot
.60976 .5348 Mdot
.60977 .53482 Mdot
.60978 .53483 Mdot
.60979 .53484 Mdot
.6098 .53485 Mdot
.60981 .53487 Mdot
.60982 .53488 Mdot
.60983 .53489 Mdot
.60984 .5349 Mdot
.60985 .53492 Mdot
.60986 .53493 Mdot
.60987 .53494 Mdot
.60988 .53496 Mdot
.60989 .53497 Mdot
.6099 .53498 Mdot
.6099 .53499 Mdot
.60991 .53501 Mdot
.60992 .53502 Mdot
.60993 .53503 Mdot
.60994 .53504 Mdot
.60995 .53506 Mdot
.60996 .53507 Mdot
.60997 .53508 Mdot
.60998 .53509 Mdot
.60999 .53511 Mdot
.61 .53512 Mdot
.61001 .53513 Mdot
.61002 .53515 Mdot
.61003 .53516 Mdot
.61004 .53517 Mdot
.61005 .53518 Mdot
.61006 .5352 Mdot
.61007 .53521 Mdot
.61008 .53522 Mdot
.61009 .53523 Mdot
.6101 .53525 Mdot
.6101 .53526 Mdot
.61011 .53527 Mdot
.61012 .53528 Mdot
.61013 .5353 Mdot
.61014 .53531 Mdot
.61015 .53532 Mdot
.61016 .53533 Mdot
.61017 .53535 Mdot
.61018 .53536 Mdot
.61019 .53537 Mdot
.6102 .53539 Mdot
.61021 .5354 Mdot
.61022 .53541 Mdot
.61023 .53542 Mdot
.61024 .53544 Mdot
.61025 .53545 Mdot
.61026 .53546 Mdot
.61027 .53547 Mdot
.61028 .53549 Mdot
.61029 .5355 Mdot
.6103 .53551 Mdot
.6103 .53552 Mdot
.61031 .53554 Mdot
.61032 .53555 Mdot
.61033 .53556 Mdot
.61034 .53557 Mdot
.61035 .53559 Mdot
.61036 .5356 Mdot
.61037 .53561 Mdot
.61038 .53563 Mdot
.61039 .53564 Mdot
.6104 .53565 Mdot
.61041 .53566 Mdot
.61042 .53568 Mdot
.61043 .53569 Mdot
.61044 .5357 Mdot
.61045 .53571 Mdot
.61046 .53573 Mdot
.61047 .53574 Mdot
.61048 .53575 Mdot
.61049 .53576 Mdot
.6105 .53578 Mdot
.6105 .53579 Mdot
.61051 .5358 Mdot
.61052 .53581 Mdot
.61053 .53583 Mdot
.61054 .53584 Mdot
.61055 .53585 Mdot
.61056 .53586 Mdot
.61057 .53588 Mdot
.61058 .53589 Mdot
.61059 .5359 Mdot
.6106 .53591 Mdot
.61061 .53593 Mdot
.61062 .53594 Mdot
.61063 .53595 Mdot
.61064 .53596 Mdot
.61065 .53598 Mdot
.61066 .53599 Mdot
.61067 .536 Mdot
.61068 .53602 Mdot
.61069 .53603 Mdot
.6107 .53604 Mdot
.6107 .53605 Mdot
.61071 .53607 Mdot
.61072 .53608 Mdot
.61073 .53609 Mdot
.61074 .5361 Mdot
.61075 .53612 Mdot
.61076 .53613 Mdot
.61077 .53614 Mdot
.61078 .53615 Mdot
.61079 .53617 Mdot
.6108 .53618 Mdot
.61081 .53619 Mdot
.61082 .5362 Mdot
.61083 .53622 Mdot
.61084 .53623 Mdot
.61085 .53624 Mdot
.61086 .53625 Mdot
.61087 .53627 Mdot
.61088 .53628 Mdot
.61089 .53629 Mdot
.6109 .5363 Mdot
.6109 .53632 Mdot
.61091 .53633 Mdot
.61092 .53634 Mdot
.61093 .53635 Mdot
.61094 .53637 Mdot
.61095 .53638 Mdot
.61096 .53639 Mdot
.61097 .5364 Mdot
.61098 .53642 Mdot
.61099 .53643 Mdot
.611 .53644 Mdot
.61101 .53645 Mdot
.61102 .53647 Mdot
.61103 .53648 Mdot
.61104 .53649 Mdot
.61105 .5365 Mdot
.61106 .53652 Mdot
.61107 .53653 Mdot
.61108 .53654 Mdot
.61109 .53655 Mdot
.6111 .53657 Mdot
.6111 .53658 Mdot
.61111 .53659 Mdot
.61112 .5366 Mdot
.61113 .53662 Mdot
.61114 .53663 Mdot
.61115 .53664 Mdot
.61116 .53665 Mdot
.61117 .53667 Mdot
.61118 .53668 Mdot
.61119 .53669 Mdot
.6112 .5367 Mdot
.61121 .53672 Mdot
.61122 .53673 Mdot
.61123 .53674 Mdot
.61124 .53675 Mdot
.61125 .53677 Mdot
.61126 .53678 Mdot
.61127 .53679 Mdot
.61128 .5368 Mdot
.61129 .53682 Mdot
.6113 .53683 Mdot
.6113 .53684 Mdot
.61131 .53685 Mdot
.61132 .53687 Mdot
.61133 .53688 Mdot
.61134 .53689 Mdot
.61135 .5369 Mdot
.61136 .53692 Mdot
.61137 .53693 Mdot
.61138 .53694 Mdot
.61139 .53695 Mdot
.6114 .53697 Mdot
.61141 .53698 Mdot
.61142 .53699 Mdot
.61143 .537 Mdot
.61144 .53702 Mdot
.61145 .53703 Mdot
.61146 .53704 Mdot
.61147 .53705 Mdot
.61148 .53707 Mdot
.61149 .53708 Mdot
.6115 .53709 Mdot
.6115 .5371 Mdot
.61151 .53712 Mdot
.61152 .53713 Mdot
.61153 .53714 Mdot
.61154 .53715 Mdot
.61155 .53717 Mdot
.61156 .53718 Mdot
.61157 .53719 Mdot
.61158 .5372 Mdot
.61159 .53722 Mdot
.6116 .53723 Mdot
.61161 .53724 Mdot
.61162 .53725 Mdot
.61163 .53727 Mdot
.61164 .53728 Mdot
.61165 .53729 Mdot
.61166 .5373 Mdot
.61167 .53732 Mdot
.61168 .53733 Mdot
.61169 .53734 Mdot
.6117 .53735 Mdot
.6117 .53737 Mdot
.61171 .53738 Mdot
.61172 .53739 Mdot
.61173 .5374 Mdot
.61174 .53742 Mdot
.61175 .53743 Mdot
.61176 .53744 Mdot
.61177 .53745 Mdot
.61178 .53746 Mdot
.61179 .53748 Mdot
.6118 .53749 Mdot
.61181 .5375 Mdot
.61182 .53751 Mdot
.61183 .53753 Mdot
.61184 .53754 Mdot
.61185 .53755 Mdot
.61186 .53756 Mdot
.61187 .53758 Mdot
.61188 .53759 Mdot
.61189 .5376 Mdot
.6119 .53761 Mdot
.6119 .53763 Mdot
.61191 .53764 Mdot
.61192 .53765 Mdot
.61193 .53766 Mdot
.61194 .53768 Mdot
.61195 .53769 Mdot
.61196 .5377 Mdot
.61197 .53771 Mdot
.61198 .53773 Mdot
.61199 .53774 Mdot
.612 .53775 Mdot
.61201 .53776 Mdot
.61202 .53778 Mdot
.61203 .53779 Mdot
.61204 .5378 Mdot
.61205 .53781 Mdot
.61206 .53782 Mdot
.61207 .53784 Mdot
.61208 .53785 Mdot
.61209 .53786 Mdot
.6121 .53787 Mdot
.6121 .53789 Mdot
.61211 .5379 Mdot
.61212 .53791 Mdot
.61213 .53792 Mdot
.61214 .53794 Mdot
.61215 .53795 Mdot
.61216 .53796 Mdot
.61217 .53797 Mdot
.61218 .53799 Mdot
.61219 .538 Mdot
.6122 .53801 Mdot
.61221 .53802 Mdot
.61222 .53804 Mdot
.61223 .53805 Mdot
.61224 .53806 Mdot
.61225 .53807 Mdot
.61226 .53808 Mdot
.61227 .5381 Mdot
.61228 .53811 Mdot
.61229 .53812 Mdot
.6123 .53813 Mdot
.6123 .53815 Mdot
.61231 .53816 Mdot
.61232 .53817 Mdot
.61233 .53818 Mdot
.61234 .5382 Mdot
.61235 .53821 Mdot
.61236 .53822 Mdot
.61237 .53823 Mdot
.61238 .53825 Mdot
.61239 .53826 Mdot
.6124 .53827 Mdot
.61241 .53828 Mdot
.61242 .53829 Mdot
.61243 .53831 Mdot
.61244 .53832 Mdot
.61245 .53833 Mdot
.61246 .53834 Mdot
.61247 .53836 Mdot
.61248 .53837 Mdot
.61249 .53838 Mdot
.6125 .53839 Mdot
.6125 .53841 Mdot
.61251 .53842 Mdot
.61252 .53843 Mdot
.61253 .53844 Mdot
.61254 .53846 Mdot
.61255 .53847 Mdot
.61256 .53848 Mdot
.61257 .53849 Mdot
.61258 .5385 Mdot
.61259 .53852 Mdot
.6126 .53853 Mdot
.61261 .53854 Mdot
.61262 .53855 Mdot
.61263 .53857 Mdot
.61264 .53858 Mdot
.61265 .53859 Mdot
.61266 .5386 Mdot
.61267 .53862 Mdot
.61268 .53863 Mdot
.61269 .53864 Mdot
.6127 .53865 Mdot
.6127 .53866 Mdot
.61271 .53868 Mdot
.61272 .53869 Mdot
.61273 .5387 Mdot
.61274 .53871 Mdot
.61275 .53873 Mdot
.61276 .53874 Mdot
.61277 .53875 Mdot
.61278 .53876 Mdot
.61279 .53878 Mdot
.6128 .53879 Mdot
.61281 .5388 Mdot
.61282 .53881 Mdot
.61283 .53882 Mdot
.61284 .53884 Mdot
.61285 .53885 Mdot
.61286 .53886 Mdot
.61287 .53887 Mdot
.61288 .53889 Mdot
.61289 .5389 Mdot
.6129 .53891 Mdot
.6129 .53892 Mdot
.61291 .53894 Mdot
.61292 .53895 Mdot
.61293 .53896 Mdot
.61294 .53897 Mdot
.61295 .53898 Mdot
.61296 .539 Mdot
.61297 .53901 Mdot
.61298 .53902 Mdot
.61299 .53903 Mdot
.613 .53905 Mdot
.61301 .53906 Mdot
.61302 .53907 Mdot
.61303 .53908 Mdot
.61304 .5391 Mdot
.61305 .53911 Mdot
.61306 .53912 Mdot
.61307 .53913 Mdot
.61308 .53914 Mdot
.61309 .53916 Mdot
.6131 .53917 Mdot
.6131 .53918 Mdot
.61311 .53919 Mdot
.61312 .53921 Mdot
.61313 .53922 Mdot
.61314 .53923 Mdot
.61315 .53924 Mdot
.61316 .53925 Mdot
.61317 .53927 Mdot
.61318 .53928 Mdot
.61319 .53929 Mdot
.6132 .5393 Mdot
.61321 .53932 Mdot
.61322 .53933 Mdot
.61323 .53934 Mdot
.61324 .53935 Mdot
.61325 .53936 Mdot
.61326 .53938 Mdot
.61327 .53939 Mdot
.61328 .5394 Mdot
.61329 .53941 Mdot
.6133 .53943 Mdot
.6133 .53944 Mdot
.61331 .53945 Mdot
.61332 .53946 Mdot
.61333 .53947 Mdot
.61334 .53949 Mdot
.61335 .5395 Mdot
.61336 .53951 Mdot
.61337 .53952 Mdot
.61338 .53954 Mdot
.61339 .53955 Mdot
.6134 .53956 Mdot
.61341 .53957 Mdot
.61342 .53959 Mdot
.61343 .5396 Mdot
.61344 .53961 Mdot
.61345 .53962 Mdot
.61346 .53963 Mdot
.61347 .53965 Mdot
.61348 .53966 Mdot
.61349 .53967 Mdot
.6135 .53968 Mdot
.6135 .53969 Mdot
.61351 .53971 Mdot
.61352 .53972 Mdot
.61353 .53973 Mdot
.61354 .53974 Mdot
.61355 .53976 Mdot
.61356 .53977 Mdot
.61357 .53978 Mdot
.61358 .53979 Mdot
.61359 .5398 Mdot
.6136 .53982 Mdot
.61361 .53983 Mdot
.61362 .53984 Mdot
.61363 .53985 Mdot
.61364 .53987 Mdot
.61365 .53988 Mdot
.61366 .53989 Mdot
.61367 .5399 Mdot
.61368 .53991 Mdot
.61369 .53993 Mdot
.6137 .53994 Mdot
.6137 .53995 Mdot
.61371 .53996 Mdot
.61372 .53998 Mdot
.61373 .53999 Mdot
.61374 .54 Mdot
.61375 .54001 Mdot
.61376 .54002 Mdot
.61377 .54004 Mdot
.61378 .54005 Mdot
.61379 .54006 Mdot
.6138 .54007 Mdot
.61381 .54009 Mdot
.61382 .5401 Mdot
.61383 .54011 Mdot
.61384 .54012 Mdot
.61385 .54013 Mdot
.61386 .54015 Mdot
.61387 .54016 Mdot
.61388 .54017 Mdot
.61389 .54018 Mdot
.6139 .54019 Mdot
.6139 .54021 Mdot
.61391 .54022 Mdot
.61392 .54023 Mdot
.61393 .54024 Mdot
.61394 .54026 Mdot
.61395 .54027 Mdot
.61396 .54028 Mdot
.61397 .54029 Mdot
.61398 .5403 Mdot
.61399 .54032 Mdot
.614 .54033 Mdot
.61401 .54034 Mdot
.61402 .54035 Mdot
.61403 .54036 Mdot
.61404 .54038 Mdot
.61405 .54039 Mdot
.61406 .5404 Mdot
.61407 .54041 Mdot
.61408 .54043 Mdot
.61409 .54044 Mdot
.6141 .54045 Mdot
.6141 .54046 Mdot
.61411 .54047 Mdot
.61412 .54049 Mdot
.61413 .5405 Mdot
.61414 .54051 Mdot
.61415 .54052 Mdot
.61416 .54053 Mdot
.61417 .54055 Mdot
.61418 .54056 Mdot
.61419 .54057 Mdot
.6142 .54058 Mdot
.61421 .5406 Mdot
.61422 .54061 Mdot
.61423 .54062 Mdot
.61424 .54063 Mdot
.61425 .54064 Mdot
.61426 .54066 Mdot
.61427 .54067 Mdot
.61428 .54068 Mdot
.61429 .54069 Mdot
.6143 .5407 Mdot
.6143 .54072 Mdot
.61431 .54073 Mdot
.61432 .54074 Mdot
.61433 .54075 Mdot
.61434 .54077 Mdot
.61435 .54078 Mdot
.61436 .54079 Mdot
.61437 .5408 Mdot
.61438 .54081 Mdot
.61439 .54083 Mdot
.6144 .54084 Mdot
.61441 .54085 Mdot
.61442 .54086 Mdot
.61443 .54087 Mdot
.61444 .54089 Mdot
.61445 .5409 Mdot
.61446 .54091 Mdot
.61447 .54092 Mdot
.61448 .54093 Mdot
.61449 .54095 Mdot
.6145 .54096 Mdot
.6145 .54097 Mdot
.61451 .54098 Mdot
.61452 .54099 Mdot
.61453 .54101 Mdot
.61454 .54102 Mdot
.61455 .54103 Mdot
.61456 .54104 Mdot
.61457 .54106 Mdot
.61458 .54107 Mdot
.61459 .54108 Mdot
.6146 .54109 Mdot
.61461 .5411 Mdot
.61462 .54112 Mdot
.61463 .54113 Mdot
.61464 .54114 Mdot
.61465 .54115 Mdot
.61466 .54116 Mdot
.61467 .54118 Mdot
.61468 .54119 Mdot
.61469 .5412 Mdot
.6147 .54121 Mdot
.6147 .54122 Mdot
.61471 .54124 Mdot
.61472 .54125 Mdot
.61473 .54126 Mdot
.61474 .54127 Mdot
.61475 .54128 Mdot
.61476 .5413 Mdot
.61477 .54131 Mdot
.61478 .54132 Mdot
.61479 .54133 Mdot
.6148 .54134 Mdot
.61481 .54136 Mdot
.61482 .54137 Mdot
.61483 .54138 Mdot
.61484 .54139 Mdot
.61485 .54141 Mdot
.61486 .54142 Mdot
.61487 .54143 Mdot
.61488 .54144 Mdot
.61489 .54145 Mdot
.6149 .54147 Mdot
.6149 .54148 Mdot
.61491 .54149 Mdot
.61492 .5415 Mdot
.61493 .54151 Mdot
.61494 .54153 Mdot
.61495 .54154 Mdot
.61496 .54155 Mdot
.61497 .54156 Mdot
.61498 .54157 Mdot
.61499 .54159 Mdot
.615 .5416 Mdot
.61501 .54161 Mdot
.61502 .54162 Mdot
.61503 .54163 Mdot
.61504 .54165 Mdot
.61505 .54166 Mdot
.61506 .54167 Mdot
.61507 .54168 Mdot
.61508 .54169 Mdot
.61509 .54171 Mdot
.6151 .54172 Mdot
.6151 .54173 Mdot
.61511 .54174 Mdot
.61512 .54175 Mdot
.61513 .54177 Mdot
.61514 .54178 Mdot
.61515 .54179 Mdot
.61516 .5418 Mdot
.61517 .54181 Mdot
.61518 .54183 Mdot
.61519 .54184 Mdot
.6152 .54185 Mdot
.61521 .54186 Mdot
.61522 .54187 Mdot
.61523 .54189 Mdot
.61524 .5419 Mdot
.61525 .54191 Mdot
.61526 .54192 Mdot
.61527 .54193 Mdot
.61528 .54195 Mdot
.61529 .54196 Mdot
.6153 .54197 Mdot
.6153 .54198 Mdot
.61531 .54199 Mdot
.61532 .54201 Mdot
.61533 .54202 Mdot
.61534 .54203 Mdot
.61535 .54204 Mdot
.61536 .54205 Mdot
.61537 .54207 Mdot
.61538 .54208 Mdot
.61539 .54209 Mdot
.6154 .5421 Mdot
.61541 .54211 Mdot
.61542 .54213 Mdot
.61543 .54214 Mdot
.61544 .54215 Mdot
.61545 .54216 Mdot
.61546 .54217 Mdot
.61547 .54219 Mdot
.61548 .5422 Mdot
.61549 .54221 Mdot
.6155 .54222 Mdot
.6155 .54223 Mdot
.61551 .54225 Mdot
.61552 .54226 Mdot
.61553 .54227 Mdot
.61554 .54228 Mdot
.61555 .54229 Mdot
.61556 .54231 Mdot
.61557 .54232 Mdot
.61558 .54233 Mdot
.61559 .54234 Mdot
.6156 .54235 Mdot
.61561 .54236 Mdot
.61562 .54238 Mdot
.61563 .54239 Mdot
.61564 .5424 Mdot
.61565 .54241 Mdot
.61566 .54242 Mdot
.61567 .54244 Mdot
.61568 .54245 Mdot
.61569 .54246 Mdot
.6157 .54247 Mdot
.6157 .54248 Mdot
.61571 .5425 Mdot
.61572 .54251 Mdot
.61573 .54252 Mdot
.61574 .54253 Mdot
.61575 .54254 Mdot
.61576 .54256 Mdot
.61577 .54257 Mdot
.61578 .54258 Mdot
.61579 .54259 Mdot
.6158 .5426 Mdot
.61581 .54262 Mdot
.61582 .54263 Mdot
.61583 .54264 Mdot
.61584 .54265 Mdot
.61585 .54266 Mdot
.61586 .54268 Mdot
.61587 .54269 Mdot
.61588 .5427 Mdot
.61589 .54271 Mdot
.6159 .54272 Mdot
.6159 .54273 Mdot
.61591 .54275 Mdot
.61592 .54276 Mdot
.61593 .54277 Mdot
.61594 .54278 Mdot
.61595 .54279 Mdot
.61596 .54281 Mdot
.61597 .54282 Mdot
.61598 .54283 Mdot
.61599 .54284 Mdot
.616 .54285 Mdot
.61601 .54287 Mdot
.61602 .54288 Mdot
.61603 .54289 Mdot
.61604 .5429 Mdot
.61605 .54291 Mdot
.61606 .54293 Mdot
.61607 .54294 Mdot
.61608 .54295 Mdot
.61609 .54296 Mdot
.6161 .54297 Mdot
.6161 .54298 Mdot
.61611 .543 Mdot
.61612 .54301 Mdot
.61613 .54302 Mdot
.61614 .54303 Mdot
.61615 .54304 Mdot
.61616 .54306 Mdot
.61617 .54307 Mdot
.61618 .54308 Mdot
.61619 .54309 Mdot
.6162 .5431 Mdot
.61621 .54312 Mdot
.61622 .54313 Mdot
.61623 .54314 Mdot
.61624 .54315 Mdot
.61625 .54316 Mdot
.61626 .54317 Mdot
.61627 .54319 Mdot
.61628 .5432 Mdot
.61629 .54321 Mdot
.6163 .54322 Mdot
.6163 .54323 Mdot
.61631 .54325 Mdot
.61632 .54326 Mdot
.61633 .54327 Mdot
.61634 .54328 Mdot
.61635 .54329 Mdot
.61636 .54331 Mdot
.61637 .54332 Mdot
.61638 .54333 Mdot
.61639 .54334 Mdot
.6164 .54335 Mdot
.61641 .54336 Mdot
.61642 .54338 Mdot
.61643 .54339 Mdot
.61644 .5434 Mdot
.61645 .54341 Mdot
.61646 .54342 Mdot
.61647 .54344 Mdot
.61648 .54345 Mdot
.61649 .54346 Mdot
.6165 .54347 Mdot
.6165 .54348 Mdot
.61651 .54349 Mdot
.61652 .54351 Mdot
.61653 .54352 Mdot
.61654 .54353 Mdot
.61655 .54354 Mdot
.61656 .54355 Mdot
.61657 .54357 Mdot
.61658 .54358 Mdot
.61659 .54359 Mdot
.6166 .5436 Mdot
.61661 .54361 Mdot
.61662 .54362 Mdot
.61663 .54364 Mdot
.61664 .54365 Mdot
.61665 .54366 Mdot
.61666 .54367 Mdot
.61667 .54368 Mdot
.61668 .5437 Mdot
.61669 .54371 Mdot
.6167 .54372 Mdot
.6167 .54373 Mdot
.61671 .54374 Mdot
.61672 .54375 Mdot
.61673 .54377 Mdot
.61674 .54378 Mdot
.61675 .54379 Mdot
.61676 .5438 Mdot
.61677 .54381 Mdot
.61678 .54383 Mdot
.61679 .54384 Mdot
.6168 .54385 Mdot
.61681 .54386 Mdot
.61682 .54387 Mdot
.61683 .54388 Mdot
.61684 .5439 Mdot
.61685 .54391 Mdot
.61686 .54392 Mdot
.61687 .54393 Mdot
.61688 .54394 Mdot
.61689 .54396 Mdot
.6169 .54397 Mdot
.6169 .54398 Mdot
.61691 .54399 Mdot
.61692 .544 Mdot
.61693 .54401 Mdot
.61694 .54403 Mdot
.61695 .54404 Mdot
.61696 .54405 Mdot
.61697 .54406 Mdot
.61698 .54407 Mdot
.61699 .54408 Mdot
.617 .5441 Mdot
.61701 .54411 Mdot
.61702 .54412 Mdot
.61703 .54413 Mdot
.61704 .54414 Mdot
.61705 .54416 Mdot
.61706 .54417 Mdot
.61707 .54418 Mdot
.61708 .54419 Mdot
.61709 .5442 Mdot
.6171 .54421 Mdot
.6171 .54423 Mdot
.61711 .54424 Mdot
.61712 .54425 Mdot
.61713 .54426 Mdot
.61714 .54427 Mdot
.61715 .54428 Mdot
.61716 .5443 Mdot
.61717 .54431 Mdot
.61718 .54432 Mdot
.61719 .54433 Mdot
.6172 .54434 Mdot
.61721 .54436 Mdot
.61722 .54437 Mdot
.61723 .54438 Mdot
.61724 .54439 Mdot
.61725 .5444 Mdot
.61726 .54441 Mdot
.61727 .54443 Mdot
.61728 .54444 Mdot
.61729 .54445 Mdot
.6173 .54446 Mdot
.6173 .54447 Mdot
.61731 .54448 Mdot
.61732 .5445 Mdot
.61733 .54451 Mdot
.61734 .54452 Mdot
.61735 .54453 Mdot
.61736 .54454 Mdot
.61737 .54456 Mdot
.61738 .54457 Mdot
.61739 .54458 Mdot
.6174 .54459 Mdot
.61741 .5446 Mdot
.61742 .54461 Mdot
.61743 .54463 Mdot
.61744 .54464 Mdot
.61745 .54465 Mdot
.61746 .54466 Mdot
.61747 .54467 Mdot
.61748 .54468 Mdot
.61749 .5447 Mdot
.6175 .54471 Mdot
.6175 .54472 Mdot
.61751 .54473 Mdot
.61752 .54474 Mdot
.61753 .54475 Mdot
.61754 .54477 Mdot
.61755 .54478 Mdot
.61756 .54479 Mdot
.61757 .5448 Mdot
.61758 .54481 Mdot
.61759 .54482 Mdot
.6176 .54484 Mdot
.61761 .54485 Mdot
.61762 .54486 Mdot
.61763 .54487 Mdot
.61764 .54488 Mdot
.61765 .54489 Mdot
.61766 .54491 Mdot
.61767 .54492 Mdot
.61768 .54493 Mdot
.61769 .54494 Mdot
.6177 .54495 Mdot
.6177 .54496 Mdot
.61771 .54498 Mdot
.61772 .54499 Mdot
.61773 .545 Mdot
.61774 .54501 Mdot
.61775 .54502 Mdot
.61776 .54503 Mdot
.61777 .54505 Mdot
.61778 .54506 Mdot
.61779 .54507 Mdot
.6178 .54508 Mdot
.61781 .54509 Mdot
.61782 .5451 Mdot
.61783 .54512 Mdot
.61784 .54513 Mdot
.61785 .54514 Mdot
.61786 .54515 Mdot
.61787 .54516 Mdot
.61788 .54517 Mdot
.61789 .54519 Mdot
.6179 .5452 Mdot
.6179 .54521 Mdot
.61791 .54522 Mdot
.61792 .54523 Mdot
.61793 .54524 Mdot
.61794 .54526 Mdot
.61795 .54527 Mdot
.61796 .54528 Mdot
.61797 .54529 Mdot
.61798 .5453 Mdot
.61799 .54531 Mdot
.618 .54533 Mdot
.61801 .54534 Mdot
.61802 .54535 Mdot
.61803 .54536 Mdot
.61804 .54537 Mdot
.61805 .54538 Mdot
.61806 .5454 Mdot
.61807 .54541 Mdot
.61808 .54542 Mdot
.61809 .54543 Mdot
.6181 .54544 Mdot
.6181 .54545 Mdot
.61811 .54547 Mdot
.61812 .54548 Mdot
.61813 .54549 Mdot
.61814 .5455 Mdot
.61815 .54551 Mdot
.61816 .54552 Mdot
.61817 .54554 Mdot
.61818 .54555 Mdot
.61819 .54556 Mdot
.6182 .54557 Mdot
.61821 .54558 Mdot
.61822 .54559 Mdot
.61823 .54561 Mdot
.61824 .54562 Mdot
.61825 .54563 Mdot
.61826 .54564 Mdot
.61827 .54565 Mdot
.61828 .54566 Mdot
.61829 .54568 Mdot
.6183 .54569 Mdot
.6183 .5457 Mdot
.61831 .54571 Mdot
.61832 .54572 Mdot
.61833 .54573 Mdot
.61834 .54575 Mdot
.61835 .54576 Mdot
.61836 .54577 Mdot
.61837 .54578 Mdot
.61838 .54579 Mdot
.61839 .5458 Mdot
.6184 .54581 Mdot
.61841 .54583 Mdot
.61842 .54584 Mdot
.61843 .54585 Mdot
.61844 .54586 Mdot
.61845 .54587 Mdot
.61846 .54588 Mdot
.61847 .5459 Mdot
.61848 .54591 Mdot
.61849 .54592 Mdot
.6185 .54593 Mdot
.6185 .54594 Mdot
.61851 .54595 Mdot
.61852 .54597 Mdot
.61853 .54598 Mdot
.61854 .54599 Mdot
.61855 .546 Mdot
.61856 .54601 Mdot
.61857 .54602 Mdot
.61858 .54603 Mdot
.61859 .54605 Mdot
.6186 .54606 Mdot
.61861 .54607 Mdot
.61862 .54608 Mdot
.61863 .54609 Mdot
.61864 .5461 Mdot
.61865 .54612 Mdot
.61866 .54613 Mdot
.61867 .54614 Mdot
.61868 .54615 Mdot
.61869 .54616 Mdot
.6187 .54617 Mdot
.6187 .54619 Mdot
.61871 .5462 Mdot
.61872 .54621 Mdot
.61873 .54622 Mdot
.61874 .54623 Mdot
.61875 .54624 Mdot
.61876 .54625 Mdot
.61877 .54627 Mdot
.61878 .54628 Mdot
.61879 .54629 Mdot
.6188 .5463 Mdot
.61881 .54631 Mdot
.61882 .54632 Mdot
.61883 .54634 Mdot
.61884 .54635 Mdot
.61885 .54636 Mdot
.61886 .54637 Mdot
.61887 .54638 Mdot
.61888 .54639 Mdot
.61889 .5464 Mdot
.6189 .54642 Mdot
.6189 .54643 Mdot
.61891 .54644 Mdot
.61892 .54645 Mdot
.61893 .54646 Mdot
.61894 .54647 Mdot
.61895 .54649 Mdot
.61896 .5465 Mdot
.61897 .54651 Mdot
.61898 .54652 Mdot
.61899 .54653 Mdot
.619 .54654 Mdot
.61901 .54655 Mdot
.61902 .54657 Mdot
.61903 .54658 Mdot
.61904 .54659 Mdot
.61905 .5466 Mdot
.61906 .54661 Mdot
.61907 .54662 Mdot
.61908 .54664 Mdot
.61909 .54665 Mdot
.6191 .54666 Mdot
.6191 .54667 Mdot
.61911 .54668 Mdot
.61912 .54669 Mdot
.61913 .5467 Mdot
.61914 .54672 Mdot
.61915 .54673 Mdot
.61916 .54674 Mdot
.61917 .54675 Mdot
.61918 .54676 Mdot
.61919 .54677 Mdot
.6192 .54678 Mdot
.61921 .5468 Mdot
.61922 .54681 Mdot
.61923 .54682 Mdot
.61924 .54683 Mdot
.61925 .54684 Mdot
.61926 .54685 Mdot
.61927 .54687 Mdot
.61928 .54688 Mdot
.61929 .54689 Mdot
.6193 .5469 Mdot
.6193 .54691 Mdot
.61931 .54692 Mdot
.61932 .54693 Mdot
.61933 .54695 Mdot
.61934 .54696 Mdot
.61935 .54697 Mdot
.61936 .54698 Mdot
.61937 .54699 Mdot
.61938 .547 Mdot
.61939 .54701 Mdot
.6194 .54703 Mdot
.61941 .54704 Mdot
.61942 .54705 Mdot
.61943 .54706 Mdot
.61944 .54707 Mdot
.61945 .54708 Mdot
.61946 .5471 Mdot
.61947 .54711 Mdot
.61948 .54712 Mdot
.61949 .54713 Mdot
.6195 .54714 Mdot
.6195 .54715 Mdot
.61951 .54716 Mdot
.61952 .54718 Mdot
.61953 .54719 Mdot
.61954 .5472 Mdot
.61955 .54721 Mdot
.61956 .54722 Mdot
.61957 .54723 Mdot
.61958 .54724 Mdot
.61959 .54726 Mdot
.6196 .54727 Mdot
.61961 .54728 Mdot
.61962 .54729 Mdot
.61963 .5473 Mdot
.61964 .54731 Mdot
.61965 .54732 Mdot
.61966 .54734 Mdot
.61967 .54735 Mdot
.61968 .54736 Mdot
.61969 .54737 Mdot
.6197 .54738 Mdot
.6197 .54739 Mdot
.61971 .5474 Mdot
.61972 .54742 Mdot
.61973 .54743 Mdot
.61974 .54744 Mdot
.61975 .54745 Mdot
.61976 .54746 Mdot
.61977 .54747 Mdot
.61978 .54748 Mdot
.61979 .5475 Mdot
.6198 .54751 Mdot
.61981 .54752 Mdot
.61982 .54753 Mdot
.61983 .54754 Mdot
.61984 .54755 Mdot
.61985 .54756 Mdot
.61986 .54758 Mdot
.61987 .54759 Mdot
.61988 .5476 Mdot
.61989 .54761 Mdot
.6199 .54762 Mdot
.6199 .54763 Mdot
.61991 .54764 Mdot
.61992 .54766 Mdot
.61993 .54767 Mdot
.61994 .54768 Mdot
.61995 .54769 Mdot
.61996 .5477 Mdot
.61997 .54771 Mdot
.61998 .54772 Mdot
.61999 .54774 Mdot
.62 .54775 Mdot
.62001 .54776 Mdot
.62002 .54777 Mdot
.62003 .54778 Mdot
.62004 .54779 Mdot
.62005 .5478 Mdot
.62006 .54782 Mdot
.62007 .54783 Mdot
.62008 .54784 Mdot
.62009 .54785 Mdot
.6201 .54786 Mdot
.6201 .54787 Mdot
.62011 .54788 Mdot
.62012 .54789 Mdot
.62013 .54791 Mdot
.62014 .54792 Mdot
.62015 .54793 Mdot
.62016 .54794 Mdot
.62017 .54795 Mdot
.62018 .54796 Mdot
.62019 .54797 Mdot
.6202 .54799 Mdot
.62021 .548 Mdot
.62022 .54801 Mdot
.62023 .54802 Mdot
.62024 .54803 Mdot
.62025 .54804 Mdot
.62026 .54805 Mdot
.62027 .54807 Mdot
.62028 .54808 Mdot
.62029 .54809 Mdot
.6203 .5481 Mdot
.6203 .54811 Mdot
.62031 .54812 Mdot
.62032 .54813 Mdot
.62033 .54814 Mdot
.62034 .54816 Mdot
.62035 .54817 Mdot
.62036 .54818 Mdot
.62037 .54819 Mdot
.62038 .5482 Mdot
.62039 .54821 Mdot
.6204 .54822 Mdot
.62041 .54824 Mdot
.62042 .54825 Mdot
.62043 .54826 Mdot
.62044 .54827 Mdot
.62045 .54828 Mdot
.62046 .54829 Mdot
.62047 .5483 Mdot
.62048 .54832 Mdot
.62049 .54833 Mdot
.6205 .54834 Mdot
.6205 .54835 Mdot
.62051 .54836 Mdot
.62052 .54837 Mdot
.62053 .54838 Mdot
.62054 .54839 Mdot
.62055 .54841 Mdot
.62056 .54842 Mdot
.62057 .54843 Mdot
.62058 .54844 Mdot
.62059 .54845 Mdot
.6206 .54846 Mdot
.62061 .54847 Mdot
.62062 .54849 Mdot
.62063 .5485 Mdot
.62064 .54851 Mdot
.62065 .54852 Mdot
.62066 .54853 Mdot
.62067 .54854 Mdot
.62068 .54855 Mdot
.62069 .54856 Mdot
.6207 .54858 Mdot
.6207 .54859 Mdot
.62071 .5486 Mdot
.62072 .54861 Mdot
.62073 .54862 Mdot
.62074 .54863 Mdot
.62075 .54864 Mdot
.62076 .54865 Mdot
.62077 .54867 Mdot
.62078 .54868 Mdot
.62079 .54869 Mdot
.6208 .5487 Mdot
.62081 .54871 Mdot
.62082 .54872 Mdot
.62083 .54873 Mdot
.62084 .54875 Mdot
.62085 .54876 Mdot
.62086 .54877 Mdot
.62087 .54878 Mdot
.62088 .54879 Mdot
.62089 .5488 Mdot
.6209 .54881 Mdot
.6209 .54882 Mdot
.62091 .54884 Mdot
.62092 .54885 Mdot
.62093 .54886 Mdot
.62094 .54887 Mdot
.62095 .54888 Mdot
.62096 .54889 Mdot
.62097 .5489 Mdot
.62098 .54891 Mdot
.62099 .54893 Mdot
.621 .54894 Mdot
.62101 .54895 Mdot
.62102 .54896 Mdot
.62103 .54897 Mdot
.62104 .54898 Mdot
.62105 .54899 Mdot
.62106 .549 Mdot
.62107 .54902 Mdot
.62108 .54903 Mdot
.62109 .54904 Mdot
.6211 .54905 Mdot
.6211 .54906 Mdot
.62111 .54907 Mdot
.62112 .54908 Mdot
.62113 .54909 Mdot
.62114 .54911 Mdot
.62115 .54912 Mdot
.62116 .54913 Mdot
.62117 .54914 Mdot
.62118 .54915 Mdot
.62119 .54916 Mdot
.6212 .54917 Mdot
.62121 .54918 Mdot
.62122 .5492 Mdot
.62123 .54921 Mdot
.62124 .54922 Mdot
.62125 .54923 Mdot
.62126 .54924 Mdot
.62127 .54925 Mdot
.62128 .54926 Mdot
.62129 .54927 Mdot
.6213 .54929 Mdot
.6213 .5493 Mdot
.62131 .54931 Mdot
.62132 .54932 Mdot
.62133 .54933 Mdot
.62134 .54934 Mdot
.62135 .54935 Mdot
.62136 .54936 Mdot
.62137 .54938 Mdot
.62138 .54939 Mdot
.62139 .5494 Mdot
.6214 .54941 Mdot
.62141 .54942 Mdot
.62142 .54943 Mdot
.62143 .54944 Mdot
.62144 .54945 Mdot
.62145 .54947 Mdot
.62146 .54948 Mdot
.62147 .54949 Mdot
.62148 .5495 Mdot
.62149 .54951 Mdot
.6215 .54952 Mdot
.6215 .54953 Mdot
.62151 .54954 Mdot
.62152 .54956 Mdot
.62153 .54957 Mdot
.62154 .54958 Mdot
.62155 .54959 Mdot
.62156 .5496 Mdot
.62157 .54961 Mdot
.62158 .54962 Mdot
.62159 .54963 Mdot
.6216 .54964 Mdot
.62161 .54966 Mdot
.62162 .54967 Mdot
.62163 .54968 Mdot
.62164 .54969 Mdot
.62165 .5497 Mdot
.62166 .54971 Mdot
.62167 .54972 Mdot
.62168 .54973 Mdot
.62169 .54975 Mdot
.6217 .54976 Mdot
.6217 .54977 Mdot
.62171 .54978 Mdot
.62172 .54979 Mdot
.62173 .5498 Mdot
.62174 .54981 Mdot
.62175 .54982 Mdot
.62176 .54984 Mdot
.62177 .54985 Mdot
.62178 .54986 Mdot
.62179 .54987 Mdot
.6218 .54988 Mdot
.62181 .54989 Mdot
.62182 .5499 Mdot
.62183 .54991 Mdot
.62184 .54992 Mdot
.62185 .54994 Mdot
.62186 .54995 Mdot
.62187 .54996 Mdot
.62188 .54997 Mdot
.62189 .54998 Mdot
.6219 .54999 Mdot
.6219 .55 Mdot
.62191 .55001 Mdot
.62192 .55003 Mdot
.62193 .55004 Mdot
.62194 .55005 Mdot
.62195 .55006 Mdot
.62196 .55007 Mdot
.62197 .55008 Mdot
.62198 .55009 Mdot
.62199 .5501 Mdot
.622 .55011 Mdot
.62201 .55013 Mdot
.62202 .55014 Mdot
.62203 .55015 Mdot
.62204 .55016 Mdot
.62205 .55017 Mdot
.62206 .55018 Mdot
.62207 .55019 Mdot
.62208 .5502 Mdot
.62209 .55021 Mdot
.6221 .55023 Mdot
.6221 .55024 Mdot
.62211 .55025 Mdot
.62212 .55026 Mdot
.62213 .55027 Mdot
.62214 .55028 Mdot
.62215 .55029 Mdot
.62216 .5503 Mdot
.62217 .55031 Mdot
.62218 .55033 Mdot
.62219 .55034 Mdot
.6222 .55035 Mdot
.62221 .55036 Mdot
.62222 .55037 Mdot
.62223 .55038 Mdot
.62224 .55039 Mdot
.62225 .5504 Mdot
.62226 .55041 Mdot
.62227 .55043 Mdot
.62228 .55044 Mdot
.62229 .55045 Mdot
.6223 .55046 Mdot
.6223 .55047 Mdot
.62231 .55048 Mdot
.62232 .55049 Mdot
.62233 .5505 Mdot
.62234 .55051 Mdot
.62235 .55053 Mdot
.62236 .55054 Mdot
.62237 .55055 Mdot
.62238 .55056 Mdot
.62239 .55057 Mdot
.6224 .55058 Mdot
.62241 .55059 Mdot
.62242 .5506 Mdot
.62243 .55061 Mdot
.62244 .55063 Mdot
.62245 .55064 Mdot
.62246 .55065 Mdot
.62247 .55066 Mdot
.62248 .55067 Mdot
.62249 .55068 Mdot
.6225 .55069 Mdot
.6225 .5507 Mdot
.62251 .55071 Mdot
.62252 .55073 Mdot
.62253 .55074 Mdot
.62254 .55075 Mdot
.62255 .55076 Mdot
.62256 .55077 Mdot
.62257 .55078 Mdot
.62258 .55079 Mdot
.62259 .5508 Mdot
.6226 .55081 Mdot
.62261 .55083 Mdot
.62262 .55084 Mdot
.62263 .55085 Mdot
.62264 .55086 Mdot
.62265 .55087 Mdot
.62266 .55088 Mdot
.62267 .55089 Mdot
.62268 .5509 Mdot
.62269 .55091 Mdot
.6227 .55092 Mdot
.6227 .55094 Mdot
.62271 .55095 Mdot
.62272 .55096 Mdot
.62273 .55097 Mdot
.62274 .55098 Mdot
.62275 .55099 Mdot
.62276 .551 Mdot
.62277 .55101 Mdot
.62278 .55102 Mdot
.62279 .55104 Mdot
.6228 .55105 Mdot
.62281 .55106 Mdot
.62282 .55107 Mdot
.62283 .55108 Mdot
.62284 .55109 Mdot
.62285 .5511 Mdot
.62286 .55111 Mdot
.62287 .55112 Mdot
.62288 .55113 Mdot
.62289 .55115 Mdot
.6229 .55116 Mdot
.6229 .55117 Mdot
.62291 .55118 Mdot
.62292 .55119 Mdot
.62293 .5512 Mdot
.62294 .55121 Mdot
.62295 .55122 Mdot
.62296 .55123 Mdot
.62297 .55125 Mdot
.62298 .55126 Mdot
.62299 .55127 Mdot
.623 .55128 Mdot
.62301 .55129 Mdot
.62302 .5513 Mdot
.62303 .55131 Mdot
.62304 .55132 Mdot
.62305 .55133 Mdot
.62306 .55134 Mdot
.62307 .55136 Mdot
.62308 .55137 Mdot
.62309 .55138 Mdot
.6231 .55139 Mdot
.6231 .5514 Mdot
.62311 .55141 Mdot
.62312 .55142 Mdot
.62313 .55143 Mdot
.62314 .55144 Mdot
.62315 .55145 Mdot
.62316 .55147 Mdot
.62317 .55148 Mdot
.62318 .55149 Mdot
.62319 .5515 Mdot
.6232 .55151 Mdot
.62321 .55152 Mdot
.62322 .55153 Mdot
.62323 .55154 Mdot
.62324 .55155 Mdot
.62325 .55156 Mdot
.62326 .55158 Mdot
.62327 .55159 Mdot
.62328 .5516 Mdot
.62329 .55161 Mdot
.6233 .55162 Mdot
.6233 .55163 Mdot
.62331 .55164 Mdot
.62332 .55165 Mdot
.62333 .55166 Mdot
.62334 .55167 Mdot
.62335 .55169 Mdot
.62336 .5517 Mdot
.62337 .55171 Mdot
.62338 .55172 Mdot
.62339 .55173 Mdot
.6234 .55174 Mdot
.62341 .55175 Mdot
.62342 .55176 Mdot
.62343 .55177 Mdot
.62344 .55178 Mdot
.62345 .5518 Mdot
.62346 .55181 Mdot
.62347 .55182 Mdot
.62348 .55183 Mdot
.62349 .55184 Mdot
.6235 .55185 Mdot
.6235 .55186 Mdot
.62351 .55187 Mdot
.62352 .55188 Mdot
.62353 .55189 Mdot
.62354 .5519 Mdot
.62355 .55192 Mdot
.62356 .55193 Mdot
.62357 .55194 Mdot
.62358 .55195 Mdot
.62359 .55196 Mdot
.6236 .55197 Mdot
.62361 .55198 Mdot
.62362 .55199 Mdot
.62363 .552 Mdot
.62364 .55201 Mdot
.62365 .55203 Mdot
.62366 .55204 Mdot
.62367 .55205 Mdot
.62368 .55206 Mdot
.62369 .55207 Mdot
.6237 .55208 Mdot
.6237 .55209 Mdot
.62371 .5521 Mdot
.62372 .55211 Mdot
.62373 .55212 Mdot
.62374 .55213 Mdot
.62375 .55215 Mdot
.62376 .55216 Mdot
.62377 .55217 Mdot
.62378 .55218 Mdot
.62379 .55219 Mdot
.6238 .5522 Mdot
.62381 .55221 Mdot
.62382 .55222 Mdot
.62383 .55223 Mdot
.62384 .55224 Mdot
.62385 .55225 Mdot
.62386 .55227 Mdot
.62387 .55228 Mdot
.62388 .55229 Mdot
.62389 .5523 Mdot
.6239 .55231 Mdot
.6239 .55232 Mdot
.62391 .55233 Mdot
.62392 .55234 Mdot
.62393 .55235 Mdot
.62394 .55236 Mdot
.62395 .55237 Mdot
.62396 .55239 Mdot
.62397 .5524 Mdot
.62398 .55241 Mdot
.62399 .55242 Mdot
.624 .55243 Mdot
.62401 .55244 Mdot
.62402 .55245 Mdot
.62403 .55246 Mdot
.62404 .55247 Mdot
.62405 .55248 Mdot
.62406 .55249 Mdot
.62407 .55251 Mdot
.62408 .55252 Mdot
.62409 .55253 Mdot
.6241 .55254 Mdot
.6241 .55255 Mdot
.62411 .55256 Mdot
.62412 .55257 Mdot
.62413 .55258 Mdot
.62414 .55259 Mdot
.62415 .5526 Mdot
.62416 .55261 Mdot
.62417 .55263 Mdot
.62418 .55264 Mdot
.62419 .55265 Mdot
.6242 .55266 Mdot
.62421 .55267 Mdot
.62422 .55268 Mdot
.62423 .55269 Mdot
.62424 .5527 Mdot
.62425 .55271 Mdot
.62426 .55272 Mdot
.62427 .55273 Mdot
.62428 .55274 Mdot
.62429 .55276 Mdot
.6243 .55277 Mdot
.6243 .55278 Mdot
.62431 .55279 Mdot
.62432 .5528 Mdot
.62433 .55281 Mdot
.62434 .55282 Mdot
.62435 .55283 Mdot
.62436 .55284 Mdot
.62437 .55285 Mdot
.62438 .55286 Mdot
.62439 .55288 Mdot
.6244 .55289 Mdot
.62441 .5529 Mdot
.62442 .55291 Mdot
.62443 .55292 Mdot
.62444 .55293 Mdot
.62445 .55294 Mdot
.62446 .55295 Mdot
.62447 .55296 Mdot
.62448 .55297 Mdot
.62449 .55298 Mdot
.6245 .55299 Mdot
.6245 .55301 Mdot
.62451 .55302 Mdot
.62452 .55303 Mdot
.62453 .55304 Mdot
.62454 .55305 Mdot
.62455 .55306 Mdot
.62456 .55307 Mdot
.62457 .55308 Mdot
.62458 .55309 Mdot
.62459 .5531 Mdot
.6246 .55311 Mdot
.62461 .55312 Mdot
.62462 .55314 Mdot
.62463 .55315 Mdot
.62464 .55316 Mdot
.62465 .55317 Mdot
.62466 .55318 Mdot
.62467 .55319 Mdot
.62468 .5532 Mdot
.62469 .55321 Mdot
.6247 .55322 Mdot
.6247 .55323 Mdot
.62471 .55324 Mdot
.62472 .55325 Mdot
.62473 .55326 Mdot
.62474 .55328 Mdot
.62475 .55329 Mdot
.62476 .5533 Mdot
.62477 .55331 Mdot
.62478 .55332 Mdot
.62479 .55333 Mdot
.6248 .55334 Mdot
.62481 .55335 Mdot
.62482 .55336 Mdot
.62483 .55337 Mdot
.62484 .55338 Mdot
.62485 .55339 Mdot
.62486 .55341 Mdot
.62487 .55342 Mdot
.62488 .55343 Mdot
.62489 .55344 Mdot
.6249 .55345 Mdot
.6249 .55346 Mdot
.62491 .55347 Mdot
.62492 .55348 Mdot
.62493 .55349 Mdot
.62494 .5535 Mdot
.62495 .55351 Mdot
.62496 .55352 Mdot
.62497 .55353 Mdot
.62498 .55355 Mdot
.62499 .55356 Mdot
.625 .55357 Mdot
.62501 .55358 Mdot
.62502 .55359 Mdot
.62503 .5536 Mdot
.62504 .55361 Mdot
.62505 .55362 Mdot
.62506 .55363 Mdot
.62507 .55364 Mdot
.62508 .55365 Mdot
.62509 .55366 Mdot
.6251 .55367 Mdot
.6251 .55369 Mdot
.62511 .5537 Mdot
.62512 .55371 Mdot
.62513 .55372 Mdot
.62514 .55373 Mdot
.62515 .55374 Mdot
.62516 .55375 Mdot
.62517 .55376 Mdot
.62518 .55377 Mdot
.62519 .55378 Mdot
.6252 .55379 Mdot
.62521 .5538 Mdot
.62522 .55381 Mdot
.62523 .55383 Mdot
.62524 .55384 Mdot
.62525 .55385 Mdot
.62526 .55386 Mdot
.62527 .55387 Mdot
.62528 .55388 Mdot
.62529 .55389 Mdot
.6253 .5539 Mdot
.6253 .55391 Mdot
.62531 .55392 Mdot
.62532 .55393 Mdot
.62533 .55394 Mdot
.62534 .55395 Mdot
.62535 .55396 Mdot
.62536 .55398 Mdot
.62537 .55399 Mdot
.62538 .554 Mdot
.62539 .55401 Mdot
.6254 .55402 Mdot
.62541 .55403 Mdot
.62542 .55404 Mdot
.62543 .55405 Mdot
.62544 .55406 Mdot
.62545 .55407 Mdot
.62546 .55408 Mdot
.62547 .55409 Mdot
.62548 .5541 Mdot
.62549 .55412 Mdot
.6255 .55413 Mdot
.6255 .55414 Mdot
.62551 .55415 Mdot
.62552 .55416 Mdot
.62553 .55417 Mdot
.62554 .55418 Mdot
.62555 .55419 Mdot
.62556 .5542 Mdot
.62557 .55421 Mdot
.62558 .55422 Mdot
.62559 .55423 Mdot
.6256 .55424 Mdot
.62561 .55425 Mdot
.62562 .55426 Mdot
.62563 .55428 Mdot
.62564 .55429 Mdot
.62565 .5543 Mdot
.62566 .55431 Mdot
.62567 .55432 Mdot
.62568 .55433 Mdot
.62569 .55434 Mdot
.6257 .55435 Mdot
.6257 .55436 Mdot
.62571 .55437 Mdot
.62572 .55438 Mdot
.62573 .55439 Mdot
.62574 .5544 Mdot
.62575 .55441 Mdot
.62576 .55443 Mdot
.62577 .55444 Mdot
.62578 .55445 Mdot
.62579 .55446 Mdot
.6258 .55447 Mdot
.62581 .55448 Mdot
.62582 .55449 Mdot
.62583 .5545 Mdot
.62584 .55451 Mdot
.62585 .55452 Mdot
.62586 .55453 Mdot
.62587 .55454 Mdot
.62588 .55455 Mdot
.62589 .55456 Mdot
.6259 .55457 Mdot
.6259 .55459 Mdot
.62591 .5546 Mdot
.62592 .55461 Mdot
.62593 .55462 Mdot
.62594 .55463 Mdot
.62595 .55464 Mdot
.62596 .55465 Mdot
.62597 .55466 Mdot
.62598 .55467 Mdot
.62599 .55468 Mdot
.626 .55469 Mdot
.62601 .5547 Mdot
.62602 .55471 Mdot
.62603 .55472 Mdot
.62604 .55473 Mdot
.62605 .55475 Mdot
.62606 .55476 Mdot
.62607 .55477 Mdot
.62608 .55478 Mdot
.62609 .55479 Mdot
.6261 .5548 Mdot
.6261 .55481 Mdot
.62611 .55482 Mdot
.62612 .55483 Mdot
.62613 .55484 Mdot
.62614 .55485 Mdot
.62615 .55486 Mdot
.62616 .55487 Mdot
.62617 .55488 Mdot
.62618 .55489 Mdot
.62619 .5549 Mdot
.6262 .55492 Mdot
.62621 .55493 Mdot
.62622 .55494 Mdot
.62623 .55495 Mdot
.62624 .55496 Mdot
.62625 .55497 Mdot
.62626 .55498 Mdot
.62627 .55499 Mdot
.62628 .555 Mdot
.62629 .55501 Mdot
.6263 .55502 Mdot
.6263 .55503 Mdot
.62631 .55504 Mdot
.62632 .55505 Mdot
.62633 .55506 Mdot
.62634 .55507 Mdot
.62635 .55509 Mdot
.62636 .5551 Mdot
.62637 .55511 Mdot
.62638 .55512 Mdot
.62639 .55513 Mdot
.6264 .55514 Mdot
.62641 .55515 Mdot
.62642 .55516 Mdot
.62643 .55517 Mdot
.62644 .55518 Mdot
.62645 .55519 Mdot
.62646 .5552 Mdot
.62647 .55521 Mdot
.62648 .55522 Mdot
.62649 .55523 Mdot
.6265 .55524 Mdot
.6265 .55525 Mdot
.62651 .55527 Mdot
.62652 .55528 Mdot
.62653 .55529 Mdot
.62654 .5553 Mdot
.62655 .55531 Mdot
.62656 .55532 Mdot
.62657 .55533 Mdot
.62658 .55534 Mdot
.62659 .55535 Mdot
.6266 .55536 Mdot
.62661 .55537 Mdot
.62662 .55538 Mdot
.62663 .55539 Mdot
.62664 .5554 Mdot
.62665 .55541 Mdot
.62666 .55542 Mdot
.62667 .55543 Mdot
.62668 .55544 Mdot
.62669 .55546 Mdot
.6267 .55547 Mdot
.6267 .55548 Mdot
.62671 .55549 Mdot
.62672 .5555 Mdot
.62673 .55551 Mdot
.62674 .55552 Mdot
.62675 .55553 Mdot
.62676 .55554 Mdot
.62677 .55555 Mdot
.62678 .55556 Mdot
.62679 .55557 Mdot
.6268 .55558 Mdot
.62681 .55559 Mdot
.62682 .5556 Mdot
.62683 .55561 Mdot
.62684 .55562 Mdot
.62685 .55563 Mdot
.62686 .55565 Mdot
.62687 .55566 Mdot
.62688 .55567 Mdot
.62689 .55568 Mdot
.6269 .55569 Mdot
.6269 .5557 Mdot
.62691 .55571 Mdot
.62692 .55572 Mdot
.62693 .55573 Mdot
.62694 .55574 Mdot
.62695 .55575 Mdot
.62696 .55576 Mdot
.62697 .55577 Mdot
.62698 .55578 Mdot
.62699 .55579 Mdot
.627 .5558 Mdot
.62701 .55581 Mdot
.62702 .55582 Mdot
.62703 .55583 Mdot
.62704 .55585 Mdot
.62705 .55586 Mdot
.62706 .55587 Mdot
.62707 .55588 Mdot
.62708 .55589 Mdot
.62709 .5559 Mdot
.6271 .55591 Mdot
.6271 .55592 Mdot
.62711 .55593 Mdot
.62712 .55594 Mdot
.62713 .55595 Mdot
.62714 .55596 Mdot
.62715 .55597 Mdot
.62716 .55598 Mdot
.62717 .55599 Mdot
.62718 .556 Mdot
.62719 .55601 Mdot
.6272 .55602 Mdot
.62721 .55603 Mdot
.62722 .55605 Mdot
.62723 .55606 Mdot
.62724 .55607 Mdot
.62725 .55608 Mdot
.62726 .55609 Mdot
.62727 .5561 Mdot
.62728 .55611 Mdot
.62729 .55612 Mdot
.6273 .55613 Mdot
.6273 .55614 Mdot
.62731 .55615 Mdot
.62732 .55616 Mdot
.62733 .55617 Mdot
.62734 .55618 Mdot
.62735 .55619 Mdot
.62736 .5562 Mdot
.62737 .55621 Mdot
.62738 .55622 Mdot
.62739 .55623 Mdot
.6274 .55624 Mdot
.62741 .55625 Mdot
.62742 .55627 Mdot
.62743 .55628 Mdot
.62744 .55629 Mdot
.62745 .5563 Mdot
.62746 .55631 Mdot
.62747 .55632 Mdot
.62748 .55633 Mdot
.62749 .55634 Mdot
.6275 .55635 Mdot
.6275 .55636 Mdot
.62751 .55637 Mdot
.62752 .55638 Mdot
.62753 .55639 Mdot
.62754 .5564 Mdot
.62755 .55641 Mdot
.62756 .55642 Mdot
.62757 .55643 Mdot
.62758 .55644 Mdot
.62759 .55645 Mdot
.6276 .55646 Mdot
.62761 .55647 Mdot
.62762 .55648 Mdot
.62763 .5565 Mdot
.62764 .55651 Mdot
.62765 .55652 Mdot
.62766 .55653 Mdot
.62767 .55654 Mdot
.62768 .55655 Mdot
.62769 .55656 Mdot
.6277 .55657 Mdot
.6277 .55658 Mdot
.62771 .55659 Mdot
.62772 .5566 Mdot
.62773 .55661 Mdot
.62774 .55662 Mdot
.62775 .55663 Mdot
.62776 .55664 Mdot
.62777 .55665 Mdot
.62778 .55666 Mdot
.62779 .55667 Mdot
.6278 .55668 Mdot
.62781 .55669 Mdot
.62782 .5567 Mdot
.62783 .55671 Mdot
.62784 .55672 Mdot
.62785 .55674 Mdot
.62786 .55675 Mdot
.62787 .55676 Mdot
.62788 .55677 Mdot
.62789 .55678 Mdot
.6279 .55679 Mdot
.6279 .5568 Mdot
.62791 .55681 Mdot
.62792 .55682 Mdot
.62793 .55683 Mdot
.62794 .55684 Mdot
.62795 .55685 Mdot
.62796 .55686 Mdot
.62797 .55687 Mdot
.62798 .55688 Mdot
.62799 .55689 Mdot
.628 .5569 Mdot
.62801 .55691 Mdot
.62802 .55692 Mdot
.62803 .55693 Mdot
.62804 .55694 Mdot
.62805 .55695 Mdot
.62806 .55696 Mdot
.62807 .55697 Mdot
.62808 .55698 Mdot
.62809 .557 Mdot
.6281 .55701 Mdot
.6281 .55702 Mdot
.62811 .55703 Mdot
.62812 .55704 Mdot
.62813 .55705 Mdot
.62814 .55706 Mdot
.62815 .55707 Mdot
.62816 .55708 Mdot
.62817 .55709 Mdot
.62818 .5571 Mdot
.62819 .55711 Mdot
.6282 .55712 Mdot
.62821 .55713 Mdot
.62822 .55714 Mdot
.62823 .55715 Mdot
.62824 .55716 Mdot
.62825 .55717 Mdot
.62826 .55718 Mdot
.62827 .55719 Mdot
.62828 .5572 Mdot
.62829 .55721 Mdot
.6283 .55722 Mdot
.6283 .55723 Mdot
.62831 .55724 Mdot
.62832 .55725 Mdot
.62833 .55727 Mdot
.62834 .55728 Mdot
.62835 .55729 Mdot
.62836 .5573 Mdot
.62837 .55731 Mdot
.62838 .55732 Mdot
.62839 .55733 Mdot
.6284 .55734 Mdot
.62841 .55735 Mdot
.62842 .55736 Mdot
.62843 .55737 Mdot
.62844 .55738 Mdot
.62845 .55739 Mdot
.62846 .5574 Mdot
.62847 .55741 Mdot
.62848 .55742 Mdot
.62849 .55743 Mdot
.6285 .55744 Mdot
.6285 .55745 Mdot
.62851 .55746 Mdot
.62852 .55747 Mdot
.62853 .55748 Mdot
.62854 .55749 Mdot
.62855 .5575 Mdot
.62856 .55751 Mdot
.62857 .55752 Mdot
.62858 .55753 Mdot
.62859 .55754 Mdot
.6286 .55755 Mdot
.62861 .55756 Mdot
.62862 .55758 Mdot
.62863 .55759 Mdot
.62864 .5576 Mdot
.62865 .55761 Mdot
.62866 .55762 Mdot
.62867 .55763 Mdot
.62868 .55764 Mdot
.62869 .55765 Mdot
.6287 .55766 Mdot
.6287 .55767 Mdot
.62871 .55768 Mdot
.62872 .55769 Mdot
.62873 .5577 Mdot
.62874 .55771 Mdot
.62875 .55772 Mdot
.62876 .55773 Mdot
.62877 .55774 Mdot
.62878 .55775 Mdot
.62879 .55776 Mdot
.6288 .55777 Mdot
.62881 .55778 Mdot
.62882 .55779 Mdot
.62883 .5578 Mdot
.62884 .55781 Mdot
.62885 .55782 Mdot
.62886 .55783 Mdot
.62887 .55784 Mdot
.62888 .55785 Mdot
.62889 .55786 Mdot
.6289 .55787 Mdot
.6289 .55788 Mdot
.62891 .55789 Mdot
.62892 .5579 Mdot
.62893 .55792 Mdot
.62894 .55793 Mdot
.62895 .55794 Mdot
.62896 .55795 Mdot
.62897 .55796 Mdot
.62898 .55797 Mdot
.62899 .55798 Mdot
.629 .55799 Mdot
.62901 .558 Mdot
.62902 .55801 Mdot
.62903 .55802 Mdot
.62904 .55803 Mdot
.62905 .55804 Mdot
.62906 .55805 Mdot
.62907 .55806 Mdot
.62908 .55807 Mdot
.62909 .55808 Mdot
.6291 .55809 Mdot
.6291 .5581 Mdot
.62911 .55811 Mdot
.62912 .55812 Mdot
.62913 .55813 Mdot
.62914 .55814 Mdot
.62915 .55815 Mdot
.62916 .55816 Mdot
.62917 .55817 Mdot
.62918 .55818 Mdot
.62919 .55819 Mdot
.6292 .5582 Mdot
.62921 .55821 Mdot
.62922 .55822 Mdot
.62923 .55823 Mdot
.62924 .55824 Mdot
.62925 .55825 Mdot
.62926 .55826 Mdot
.62927 .55827 Mdot
.62928 .55828 Mdot
.62929 .55829 Mdot
.6293 .55831 Mdot
.6293 .55832 Mdot
.62931 .55833 Mdot
.62932 .55834 Mdot
.62933 .55835 Mdot
.62934 .55836 Mdot
.62935 .55837 Mdot
.62936 .55838 Mdot
.62937 .55839 Mdot
.62938 .5584 Mdot
.62939 .55841 Mdot
.6294 .55842 Mdot
.62941 .55843 Mdot
.62942 .55844 Mdot
.62943 .55845 Mdot
.62944 .55846 Mdot
.62945 .55847 Mdot
.62946 .55848 Mdot
.62947 .55849 Mdot
.62948 .5585 Mdot
.62949 .55851 Mdot
.6295 .55852 Mdot
.6295 .55853 Mdot
.62951 .55854 Mdot
.62952 .55855 Mdot
.62953 .55856 Mdot
.62954 .55857 Mdot
.62955 .55858 Mdot
.62956 .55859 Mdot
.62957 .5586 Mdot
.62958 .55861 Mdot
.62959 .55862 Mdot
.6296 .55863 Mdot
.62961 .55864 Mdot
.62962 .55865 Mdot
.62963 .55866 Mdot
.62964 .55867 Mdot
.62965 .55868 Mdot
.62966 .55869 Mdot
.62967 .5587 Mdot
.62968 .55871 Mdot
.62969 .55872 Mdot
.6297 .55873 Mdot
.6297 .55874 Mdot
.62971 .55875 Mdot
.62972 .55876 Mdot
.62973 .55877 Mdot
.62974 .55878 Mdot
.62975 .5588 Mdot
.62976 .55881 Mdot
.62977 .55882 Mdot
.62978 .55883 Mdot
.62979 .55884 Mdot
.6298 .55885 Mdot
.62981 .55886 Mdot
.62982 .55887 Mdot
.62983 .55888 Mdot
.62984 .55889 Mdot
.62985 .5589 Mdot
.62986 .55891 Mdot
.62987 .55892 Mdot
.62988 .55893 Mdot
.62989 .55894 Mdot
.6299 .55895 Mdot
.6299 .55896 Mdot
.62991 .55897 Mdot
.62992 .55898 Mdot
.62993 .55899 Mdot
.62994 .559 Mdot
.62995 .55901 Mdot
.62996 .55902 Mdot
.62997 .55903 Mdot
.62998 .55904 Mdot
.62999 .55905 Mdot
.63 .55906 Mdot
.63001 .55907 Mdot
.63002 .55908 Mdot
.63003 .55909 Mdot
.63004 .5591 Mdot
.63005 .55911 Mdot
.63006 .55912 Mdot
.63007 .55913 Mdot
.63008 .55914 Mdot
.63009 .55915 Mdot
.6301 .55916 Mdot
.6301 .55917 Mdot
.63011 .55918 Mdot
.63012 .55919 Mdot
.63013 .5592 Mdot
.63014 .55921 Mdot
.63015 .55922 Mdot
.63016 .55923 Mdot
.63017 .55924 Mdot
.63018 .55925 Mdot
.63019 .55926 Mdot
.6302 .55927 Mdot
.63021 .55928 Mdot
.63022 .55929 Mdot
.63023 .5593 Mdot
.63024 .55931 Mdot
.63025 .55932 Mdot
.63026 .55933 Mdot
.63027 .55934 Mdot
.63028 .55935 Mdot
.63029 .55936 Mdot
.6303 .55937 Mdot
.6303 .55938 Mdot
.63031 .55939 Mdot
.63032 .5594 Mdot
.63033 .55941 Mdot
.63034 .55942 Mdot
.63035 .55943 Mdot
.63036 .55944 Mdot
.63037 .55945 Mdot
.63038 .55946 Mdot
.63039 .55947 Mdot
.6304 .55948 Mdot
.63041 .55949 Mdot
.63042 .5595 Mdot
.63043 .55951 Mdot
.63044 .55952 Mdot
.63045 .55954 Mdot
.63046 .55955 Mdot
.63047 .55956 Mdot
.63048 .55957 Mdot
.63049 .55958 Mdot
.6305 .55959 Mdot
.6305 .5596 Mdot
.63051 .55961 Mdot
.63052 .55962 Mdot
.63053 .55963 Mdot
.63054 .55964 Mdot
.63055 .55965 Mdot
.63056 .55966 Mdot
.63057 .55967 Mdot
.63058 .55968 Mdot
.63059 .55969 Mdot
.6306 .5597 Mdot
.63061 .55971 Mdot
.63062 .55972 Mdot
.63063 .55973 Mdot
.63064 .55974 Mdot
.63065 .55975 Mdot
.63066 .55976 Mdot
.63067 .55977 Mdot
.63068 .55978 Mdot
.63069 .55979 Mdot
.6307 .5598 Mdot
.6307 .55981 Mdot
.63071 .55982 Mdot
.63072 .55983 Mdot
.63073 .55984 Mdot
.63074 .55985 Mdot
.63075 .55986 Mdot
.63076 .55987 Mdot
.63077 .55988 Mdot
.63078 .55989 Mdot
.63079 .5599 Mdot
.6308 .55991 Mdot
.63081 .55992 Mdot
.63082 .55993 Mdot
.63083 .55994 Mdot
.63084 .55995 Mdot
.63085 .55996 Mdot
.63086 .55997 Mdot
.63087 .55998 Mdot
.63088 .55999 Mdot
.63089 .56 Mdot
.6309 .56001 Mdot
.6309 .56002 Mdot
.63091 .56003 Mdot
.63092 .56004 Mdot
.63093 .56005 Mdot
.63094 .56006 Mdot
.63095 .56007 Mdot
.63096 .56008 Mdot
.63097 .56009 Mdot
.63098 .5601 Mdot
.63099 .56011 Mdot
.631 .56012 Mdot
.63101 .56013 Mdot
.63102 .56014 Mdot
.63103 .56015 Mdot
.63104 .56016 Mdot
.63105 .56017 Mdot
.63106 .56018 Mdot
.63107 .56019 Mdot
.63108 .5602 Mdot
.63109 .56021 Mdot
.6311 .56022 Mdot
.6311 .56023 Mdot
.63111 .56024 Mdot
.63112 .56025 Mdot
.63113 .56026 Mdot
.63114 .56027 Mdot
.63115 .56028 Mdot
.63116 .56029 Mdot
.63117 .5603 Mdot
.63118 .56031 Mdot
.63119 .56032 Mdot
.6312 .56033 Mdot
.63121 .56034 Mdot
.63122 .56035 Mdot
.63123 .56036 Mdot
.63124 .56037 Mdot
.63125 .56038 Mdot
.63126 .56039 Mdot
.63127 .5604 Mdot
.63128 .56041 Mdot
.63129 .56042 Mdot
.6313 .56043 Mdot
.6313 .56044 Mdot
.63131 .56045 Mdot
.63132 .56046 Mdot
.63133 .56047 Mdot
.63134 .56048 Mdot
.63135 .56049 Mdot
.63136 .5605 Mdot
.63137 .56051 Mdot
.63138 .56052 Mdot
.63139 .56053 Mdot
.6314 .56054 Mdot
.63141 .56055 Mdot
.63142 .56056 Mdot
.63143 .56057 Mdot
.63144 .56058 Mdot
.63145 .56059 Mdot
.63146 .5606 Mdot
.63147 .56061 Mdot
.63148 .56062 Mdot
.63149 .56063 Mdot
.6315 .56064 Mdot
.6315 .56065 Mdot
.63151 .56066 Mdot
.63152 .56067 Mdot
.63153 .56068 Mdot
.63154 .56069 Mdot
.63155 .5607 Mdot
.63156 .56071 Mdot
.63157 .56072 Mdot
.63158 .56073 Mdot
.63159 .56074 Mdot
.6316 .56075 Mdot
.63161 .56076 Mdot
.63162 .56077 Mdot
.63163 .56078 Mdot
.63164 .56079 Mdot
.63165 .5608 Mdot
.63166 .56081 Mdot
.63167 .56082 Mdot
.63168 .56083 Mdot
.63169 .56084 Mdot
.6317 .56085 Mdot
.6317 .56086 Mdot
.63171 .56087 Mdot
.63172 .56088 Mdot
.63173 .56089 Mdot
.63174 .5609 Mdot
.63175 .56091 Mdot
.63176 .56092 Mdot
.63177 .56093 Mdot
.63178 .56094 Mdot
.63179 .56095 Mdot
.6318 .56096 Mdot
.63181 .56097 Mdot
.63182 .56098 Mdot
.63183 .56099 Mdot
.63184 .561 Mdot
.63185 .56101 Mdot
.63186 .56102 Mdot
.63187 .56103 Mdot
.63188 .56104 Mdot
.63189 .56105 Mdot
.6319 .56106 Mdot
.6319 .56107 Mdot
.63191 .56108 Mdot
.63192 .56109 Mdot
.63193 .5611 Mdot
.63194 .56111 Mdot
.63195 .56111 Mdot
.63196 .56112 Mdot
.63197 .56113 Mdot
.63198 .56114 Mdot
.63199 .56115 Mdot
.632 .56116 Mdot
.63201 .56117 Mdot
.63202 .56118 Mdot
.63203 .56119 Mdot
.63204 .5612 Mdot
.63205 .56121 Mdot
.63206 .56122 Mdot
.63207 .56123 Mdot
.63208 .56124 Mdot
.63209 .56125 Mdot
.6321 .56126 Mdot
.6321 .56127 Mdot
.63211 .56128 Mdot
.63212 .56129 Mdot
.63213 .5613 Mdot
.63214 .56131 Mdot
.63215 .56132 Mdot
.63216 .56133 Mdot
.63217 .56134 Mdot
.63218 .56135 Mdot
.63219 .56136 Mdot
.6322 .56137 Mdot
.63221 .56138 Mdot
.63222 .56139 Mdot
.63223 .5614 Mdot
.63224 .56141 Mdot
.63225 .56142 Mdot
.63226 .56143 Mdot
.63227 .56144 Mdot
.63228 .56145 Mdot
.63229 .56146 Mdot
.6323 .56147 Mdot
.6323 .56148 Mdot
.63231 .56149 Mdot
.63232 .5615 Mdot
.63233 .56151 Mdot
.63234 .56152 Mdot
.63235 .56153 Mdot
.63236 .56154 Mdot
.63237 .56155 Mdot
.63238 .56156 Mdot
.63239 .56157 Mdot
.6324 .56158 Mdot
.63241 .56159 Mdot
.63242 .5616 Mdot
.63243 .56161 Mdot
.63244 .56162 Mdot
.63245 .56163 Mdot
.63246 .56164 Mdot
.63247 .56165 Mdot
.63248 .56166 Mdot
.63249 .56167 Mdot
.6325 .56168 Mdot
.6325 .56169 Mdot
.63251 .5617 Mdot
.63252 .56171 Mdot
.63253 .56172 Mdot
.63254 .56173 Mdot
.63255 .56174 Mdot
.63256 .56175 Mdot
.63257 .56176 Mdot
.63258 .56177 Mdot
.63259 .56178 Mdot
.6326 .56179 Mdot
.63261 .5618 Mdot
.63262 .56181 Mdot
.63263 .56182 Mdot
.63264 .56183 Mdot
.63265 .56183 Mdot
.63266 .56184 Mdot
.63267 .56185 Mdot
.63268 .56186 Mdot
.63269 .56187 Mdot
.6327 .56188 Mdot
.6327 .56189 Mdot
.63271 .5619 Mdot
.63272 .56191 Mdot
.63273 .56192 Mdot
.63274 .56193 Mdot
.63275 .56194 Mdot
.63276 .56195 Mdot
.63277 .56196 Mdot
.63278 .56197 Mdot
.63279 .56198 Mdot
.6328 .56199 Mdot
.63281 .562 Mdot
.63282 .56201 Mdot
.63283 .56202 Mdot
.63284 .56203 Mdot
.63285 .56204 Mdot
.63286 .56205 Mdot
.63287 .56206 Mdot
.63288 .56207 Mdot
.63289 .56208 Mdot
.6329 .56209 Mdot
.6329 .5621 Mdot
.63291 .56211 Mdot
.63292 .56212 Mdot
.63293 .56213 Mdot
.63294 .56214 Mdot
.63295 .56215 Mdot
.63296 .56216 Mdot
.63297 .56217 Mdot
.63298 .56218 Mdot
.63299 .56219 Mdot
.633 .5622 Mdot
.63301 .56221 Mdot
.63302 .56222 Mdot
.63303 .56223 Mdot
.63304 .56224 Mdot
.63305 .56225 Mdot
.63306 .56226 Mdot
.63307 .56227 Mdot
.63308 .56228 Mdot
.63309 .56229 Mdot
.6331 .5623 Mdot
.6331 .5623 Mdot
.63311 .56231 Mdot
.63312 .56232 Mdot
.63313 .56233 Mdot
.63314 .56234 Mdot
.63315 .56235 Mdot
.63316 .56236 Mdot
.63317 .56237 Mdot
.63318 .56238 Mdot
.63319 .56239 Mdot
.6332 .5624 Mdot
.63321 .56241 Mdot
.63322 .56242 Mdot
.63323 .56243 Mdot
.63324 .56244 Mdot
.63325 .56245 Mdot
.63326 .56246 Mdot
.63327 .56247 Mdot
.63328 .56248 Mdot
.63329 .56249 Mdot
.6333 .5625 Mdot
.6333 .56251 Mdot
.63331 .56252 Mdot
.63332 .56253 Mdot
.63333 .56254 Mdot
.63334 .56255 Mdot
.63335 .56256 Mdot
.63336 .56257 Mdot
.63337 .56258 Mdot
.63338 .56259 Mdot
.63339 .5626 Mdot
.6334 .56261 Mdot
.63341 .56262 Mdot
.63342 .56263 Mdot
.63343 .56264 Mdot
.63344 .56265 Mdot
.63345 .56266 Mdot
.63346 .56267 Mdot
.63347 .56267 Mdot
.63348 .56268 Mdot
.63349 .56269 Mdot
.6335 .5627 Mdot
.6335 .56271 Mdot
.63351 .56272 Mdot
.63352 .56273 Mdot
.63353 .56274 Mdot
.63354 .56275 Mdot
.63355 .56276 Mdot
.63356 .56277 Mdot
.63357 .56278 Mdot
.63358 .56279 Mdot
.63359 .5628 Mdot
.6336 .56281 Mdot
.63361 .56282 Mdot
.63362 .56283 Mdot
.63363 .56284 Mdot
.63364 .56285 Mdot
.63365 .56286 Mdot
.63366 .56287 Mdot
.63367 .56288 Mdot
.63368 .56289 Mdot
.63369 .5629 Mdot
.6337 .56291 Mdot
.6337 .56292 Mdot
.63371 .56293 Mdot
.63372 .56294 Mdot
.63373 .56295 Mdot
.63374 .56296 Mdot
.63375 .56297 Mdot
.63376 .56298 Mdot
.63377 .56299 Mdot
.63378 .56299 Mdot
.63379 .563 Mdot
.6338 .56301 Mdot
.63381 .56302 Mdot
.63382 .56303 Mdot
.63383 .56304 Mdot
.63384 .56305 Mdot
.63385 .56306 Mdot
.63386 .56307 Mdot
.63387 .56308 Mdot
.63388 .56309 Mdot
.63389 .5631 Mdot
.6339 .56311 Mdot
.6339 .56312 Mdot
.63391 .56313 Mdot
.63392 .56314 Mdot
.63393 .56315 Mdot
.63394 .56316 Mdot
.63395 .56317 Mdot
.63396 .56318 Mdot
.63397 .56319 Mdot
.63398 .5632 Mdot
.63399 .56321 Mdot
.634 .56322 Mdot
.63401 .56323 Mdot
.63402 .56324 Mdot
.63403 .56325 Mdot
.63404 .56326 Mdot
.63405 .56327 Mdot
.63406 .56328 Mdot
.63407 .56328 Mdot
.63408 .56329 Mdot
.63409 .5633 Mdot
.6341 .56331 Mdot
.6341 .56332 Mdot
.63411 .56333 Mdot
.63412 .56334 Mdot
.63413 .56335 Mdot
.63414 .56336 Mdot
.63415 .56337 Mdot
.63416 .56338 Mdot
.63417 .56339 Mdot
.63418 .5634 Mdot
.63419 .56341 Mdot
.6342 .56342 Mdot
.63421 .56343 Mdot
.63422 .56344 Mdot
.63423 .56345 Mdot
.63424 .56346 Mdot
.63425 .56347 Mdot
.63426 .56348 Mdot
.63427 .56349 Mdot
.63428 .5635 Mdot
.63429 .56351 Mdot
.6343 .56352 Mdot
.6343 .56353 Mdot
.63431 .56353 Mdot
.63432 .56354 Mdot
.63433 .56355 Mdot
.63434 .56356 Mdot
.63435 .56357 Mdot
.63436 .56358 Mdot
.63437 .56359 Mdot
.63438 .5636 Mdot
.63439 .56361 Mdot
.6344 .56362 Mdot
.63441 .56363 Mdot
.63442 .56364 Mdot
.63443 .56365 Mdot
.63444 .56366 Mdot
.63445 .56367 Mdot
.63446 .56368 Mdot
.63447 .56369 Mdot
.63448 .5637 Mdot
.63449 .56371 Mdot
.6345 .56372 Mdot
.6345 .56373 Mdot
.63451 .56374 Mdot
.63452 .56375 Mdot
.63453 .56376 Mdot
.63454 .56377 Mdot
.63455 .56377 Mdot
.63456 .56378 Mdot
.63457 .56379 Mdot
.63458 .5638 Mdot
.63459 .56381 Mdot
.6346 .56382 Mdot
.63461 .56383 Mdot
.63462 .56384 Mdot
.63463 .56385 Mdot
.63464 .56386 Mdot
.63465 .56387 Mdot
.63466 .56388 Mdot
.63467 .56389 Mdot
.63468 .5639 Mdot
.63469 .56391 Mdot
.6347 .56392 Mdot
.6347 .56393 Mdot
.63471 .56394 Mdot
.63472 .56395 Mdot
.63473 .56396 Mdot
.63474 .56397 Mdot
.63475 .56398 Mdot
.63476 .56399 Mdot
.63477 .56399 Mdot
.63478 .564 Mdot
.63479 .56401 Mdot
.6348 .56402 Mdot
.63481 .56403 Mdot
.63482 .56404 Mdot
.63483 .56405 Mdot
.63484 .56406 Mdot
.63485 .56407 Mdot
.63486 .56408 Mdot
.63487 .56409 Mdot
.63488 .5641 Mdot
.63489 .56411 Mdot
.6349 .56412 Mdot
.6349 .56413 Mdot
.63491 .56414 Mdot
.63492 .56415 Mdot
.63493 .56416 Mdot
.63494 .56417 Mdot
.63495 .56418 Mdot
.63496 .56419 Mdot
.63497 .5642 Mdot
.63498 .5642 Mdot
.63499 .56421 Mdot
.635 .56422 Mdot
.63501 .56423 Mdot
.63502 .56424 Mdot
.63503 .56425 Mdot
.63504 .56426 Mdot
.63505 .56427 Mdot
.63506 .56428 Mdot
.63507 .56429 Mdot
.63508 .5643 Mdot
.63509 .56431 Mdot
.6351 .56432 Mdot
.6351 .56433 Mdot
.63511 .56434 Mdot
.63512 .56435 Mdot
.63513 .56436 Mdot
.63514 .56437 Mdot
.63515 .56438 Mdot
.63516 .56439 Mdot
.63517 .5644 Mdot
.63518 .5644 Mdot
.63519 .56441 Mdot
.6352 .56442 Mdot
.63521 .56443 Mdot
.63522 .56444 Mdot
.63523 .56445 Mdot
.63524 .56446 Mdot
.63525 .56447 Mdot
.63526 .56448 Mdot
.63527 .56449 Mdot
.63528 .5645 Mdot
.63529 .56451 Mdot
.6353 .56452 Mdot
.6353 .56453 Mdot
.63531 .56454 Mdot
.63532 .56455 Mdot
.63533 .56456 Mdot
.63534 .56457 Mdot
.63535 .56458 Mdot
.63536 .56458 Mdot
.63537 .56459 Mdot
.63538 .5646 Mdot
.63539 .56461 Mdot
.6354 .56462 Mdot
.63541 .56463 Mdot
.63542 .56464 Mdot
.63543 .56465 Mdot
.63544 .56466 Mdot
.63545 .56467 Mdot
.63546 .56468 Mdot
.63547 .56469 Mdot
.63548 .5647 Mdot
.63549 .56471 Mdot
.6355 .56472 Mdot
.6355 .56473 Mdot
.63551 .56474 Mdot
.63552 .56475 Mdot
.63553 .56476 Mdot
.63554 .56476 Mdot
.63555 .56477 Mdot
.63556 .56478 Mdot
.63557 .56479 Mdot
.63558 .5648 Mdot
.63559 .56481 Mdot
.6356 .56482 Mdot
.63561 .56483 Mdot
.63562 .56484 Mdot
.63563 .56485 Mdot
.63564 .56486 Mdot
.63565 .56487 Mdot
.63566 .56488 Mdot
.63567 .56489 Mdot
.63568 .5649 Mdot
.63569 .56491 Mdot
.6357 .56492 Mdot
.6357 .56493 Mdot
.63571 .56493 Mdot
.63572 .56494 Mdot
.63573 .56495 Mdot
.63574 .56496 Mdot
.63575 .56497 Mdot
.63576 .56498 Mdot
.63577 .56499 Mdot
.63578 .565 Mdot
.63579 .56501 Mdot
.6358 .56502 Mdot
.63581 .56503 Mdot
.63582 .56504 Mdot
.63583 .56505 Mdot
.63584 .56506 Mdot
.63585 .56507 Mdot
.63586 .56508 Mdot
.63587 .56509 Mdot
.63588 .5651 Mdot
.63589 .5651 Mdot
.6359 .56511 Mdot
.6359 .56512 Mdot
.63591 .56513 Mdot
.63592 .56514 Mdot
.63593 .56515 Mdot
.63594 .56516 Mdot
.63595 .56517 Mdot
.63596 .56518 Mdot
.63597 .56519 Mdot
.63598 .5652 Mdot
.63599 .56521 Mdot
.636 .56522 Mdot
.63601 .56523 Mdot
.63602 .56524 Mdot
.63603 .56525 Mdot
.63604 .56526 Mdot
.63605 .56526 Mdot
.63606 .56527 Mdot
.63607 .56528 Mdot
.63608 .56529 Mdot
.63609 .5653 Mdot
.6361 .56531 Mdot
.6361 .56532 Mdot
.63611 .56533 Mdot
.63612 .56534 Mdot
.63613 .56535 Mdot
.63614 .56536 Mdot
.63615 .56537 Mdot
.63616 .56538 Mdot
.63617 .56539 Mdot
.63618 .5654 Mdot
.63619 .56541 Mdot
.6362 .56541 Mdot
.63621 .56542 Mdot
.63622 .56543 Mdot
.63623 .56544 Mdot
.63624 .56545 Mdot
.63625 .56546 Mdot
.63626 .56547 Mdot
.63627 .56548 Mdot
.63628 .56549 Mdot
.63629 .5655 Mdot
.6363 .56551 Mdot
.6363 .56552 Mdot
.63631 .56553 Mdot
.63632 .56554 Mdot
.63633 .56555 Mdot
.63634 .56556 Mdot
.63635 .56556 Mdot
.63636 .56557 Mdot
.63637 .56558 Mdot
.63638 .56559 Mdot
.63639 .5656 Mdot
.6364 .56561 Mdot
.63641 .56562 Mdot
.63642 .56563 Mdot
.63643 .56564 Mdot
.63644 .56565 Mdot
.63645 .56566 Mdot
.63646 .56567 Mdot
.63647 .56568 Mdot
.63648 .56569 Mdot
.63649 .5657 Mdot
.6365 .5657 Mdot
.6365 .56571 Mdot
.63651 .56572 Mdot
.63652 .56573 Mdot
.63653 .56574 Mdot
.63654 .56575 Mdot
.63655 .56576 Mdot
.63656 .56577 Mdot
.63657 .56578 Mdot
.63658 .56579 Mdot
.63659 .5658 Mdot
.6366 .56581 Mdot
.63661 .56582 Mdot
.63662 .56583 Mdot
.63663 .56584 Mdot
.63664 .56584 Mdot
.63665 .56585 Mdot
.63666 .56586 Mdot
.63667 .56587 Mdot
.63668 .56588 Mdot
.63669 .56589 Mdot
.6367 .5659 Mdot
.6367 .56591 Mdot
.63671 .56592 Mdot
.63672 .56593 Mdot
.63673 .56594 Mdot
.63674 .56595 Mdot
.63675 .56596 Mdot
.63676 .56597 Mdot
.63677 .56598 Mdot
.63678 .56598 Mdot
.63679 .56599 Mdot
.6368 .566 Mdot
.63681 .56601 Mdot
.63682 .56602 Mdot
.63683 .56603 Mdot
.63684 .56604 Mdot
.63685 .56605 Mdot
.63686 .56606 Mdot
.63687 .56607 Mdot
.63688 .56608 Mdot
.63689 .56609 Mdot
.6369 .5661 Mdot
.6369 .56611 Mdot
.63691 .56611 Mdot
.63692 .56612 Mdot
.63693 .56613 Mdot
.63694 .56614 Mdot
.63695 .56615 Mdot
.63696 .56616 Mdot
.63697 .56617 Mdot
.63698 .56618 Mdot
.63699 .56619 Mdot
.637 .5662 Mdot
.63701 .56621 Mdot
.63702 .56622 Mdot
.63703 .56623 Mdot
.63704 .56624 Mdot
.63705 .56624 Mdot
.63706 .56625 Mdot
.63707 .56626 Mdot
.63708 .56627 Mdot
.63709 .56628 Mdot
.6371 .56629 Mdot
.6371 .5663 Mdot
.63711 .56631 Mdot
.63712 .56632 Mdot
.63713 .56633 Mdot
.63714 .56634 Mdot
.63715 .56635 Mdot
.63716 .56636 Mdot
.63717 .56636 Mdot
.63718 .56637 Mdot
.63719 .56638 Mdot
.6372 .56639 Mdot
.63721 .5664 Mdot
.63722 .56641 Mdot
.63723 .56642 Mdot
.63724 .56643 Mdot
.63725 .56644 Mdot
.63726 .56645 Mdot
.63727 .56646 Mdot
.63728 .56647 Mdot
.63729 .56648 Mdot
.6373 .56649 Mdot
.6373 .56649 Mdot
.63731 .5665 Mdot
.63732 .56651 Mdot
.63733 .56652 Mdot
.63734 .56653 Mdot
.63735 .56654 Mdot
.63736 .56655 Mdot
.63737 .56656 Mdot
.63738 .56657 Mdot
.63739 .56658 Mdot
.6374 .56659 Mdot
.63741 .5666 Mdot
.63742 .56661 Mdot
.63743 .56661 Mdot
.63744 .56662 Mdot
.63745 .56663 Mdot
.63746 .56664 Mdot
.63747 .56665 Mdot
.63748 .56666 Mdot
.63749 .56667 Mdot
.6375 .56668 Mdot
.6375 .56669 Mdot
.63751 .5667 Mdot
.63752 .56671 Mdot
.63753 .56672 Mdot
.63754 .56672 Mdot
.63755 .56673 Mdot
.63756 .56674 Mdot
.63757 .56675 Mdot
.63758 .56676 Mdot
.63759 .56677 Mdot
.6376 .56678 Mdot
.63761 .56679 Mdot
.63762 .5668 Mdot
.63763 .56681 Mdot
.63764 .56682 Mdot
.63765 .56683 Mdot
.63766 .56684 Mdot
.63767 .56684 Mdot
.63768 .56685 Mdot
.63769 .56686 Mdot
.6377 .56687 Mdot
.6377 .56688 Mdot
.63771 .56689 Mdot
.63772 .5669 Mdot
.63773 .56691 Mdot
.63774 .56692 Mdot
.63775 .56693 Mdot
.63776 .56694 Mdot
.63777 .56695 Mdot
.63778 .56695 Mdot
.63779 .56696 Mdot
.6378 .56697 Mdot
.63781 .56698 Mdot
.63782 .56699 Mdot
.63783 .567 Mdot
.63784 .56701 Mdot
.63785 .56702 Mdot
.63786 .56703 Mdot
.63787 .56704 Mdot
.63788 .56705 Mdot
.63789 .56706 Mdot
.6379 .56706 Mdot
.6379 .56707 Mdot
.63791 .56708 Mdot
.63792 .56709 Mdot
.63793 .5671 Mdot
.63794 .56711 Mdot
.63795 .56712 Mdot
.63796 .56713 Mdot
.63797 .56714 Mdot
.63798 .56715 Mdot
.63799 .56716 Mdot
.638 .56717 Mdot
.63801 .56717 Mdot
.63802 .56718 Mdot
.63803 .56719 Mdot
.63804 .5672 Mdot
.63805 .56721 Mdot
.63806 .56722 Mdot
.63807 .56723 Mdot
.63808 .56724 Mdot
.63809 .56725 Mdot
.6381 .56726 Mdot
.6381 .56727 Mdot
.63811 .56728 Mdot
.63812 .56728 Mdot
.63813 .56729 Mdot
.63814 .5673 Mdot
.63815 .56731 Mdot
.63816 .56732 Mdot
.63817 .56733 Mdot
.63818 .56734 Mdot
.63819 .56735 Mdot
.6382 .56736 Mdot
.63821 .56737 Mdot
.63822 .56738 Mdot
.63823 .56738 Mdot
.63824 .56739 Mdot
.63825 .5674 Mdot
.63826 .56741 Mdot
.63827 .56742 Mdot
.63828 .56743 Mdot
.63829 .56744 Mdot
.6383 .56745 Mdot
.6383 .56746 Mdot
.63831 .56747 Mdot
.63832 .56748 Mdot
.63833 .56749 Mdot
.63834 .56749 Mdot
.63835 .5675 Mdot
.63836 .56751 Mdot
.63837 .56752 Mdot
.63838 .56753 Mdot
.63839 .56754 Mdot
.6384 .56755 Mdot
.63841 .56756 Mdot
.63842 .56757 Mdot
.63843 .56758 Mdot
.63844 .56759 Mdot
.63845 .56759 Mdot
.63846 .5676 Mdot
.63847 .56761 Mdot
.63848 .56762 Mdot
.63849 .56763 Mdot
.6385 .56764 Mdot
.6385 .56765 Mdot
.63851 .56766 Mdot
.63852 .56767 Mdot
.63853 .56768 Mdot
.63854 .56769 Mdot
.63855 .56769 Mdot
.63856 .5677 Mdot
.63857 .56771 Mdot
.63858 .56772 Mdot
.63859 .56773 Mdot
.6386 .56774 Mdot
.63861 .56775 Mdot
.63862 .56776 Mdot
.63863 .56777 Mdot
.63864 .56778 Mdot
.63865 .56779 Mdot
.63866 .56779 Mdot
.63867 .5678 Mdot
.63868 .56781 Mdot
.63869 .56782 Mdot
.6387 .56783 Mdot
.6387 .56784 Mdot
.63871 .56785 Mdot
.63872 .56786 Mdot
.63873 .56787 Mdot
.63874 .56788 Mdot
.63875 .56788 Mdot
.63876 .56789 Mdot
.63877 .5679 Mdot
.63878 .56791 Mdot
.63879 .56792 Mdot
.6388 .56793 Mdot
.63881 .56794 Mdot
.63882 .56795 Mdot
.63883 .56796 Mdot
.63884 .56797 Mdot
.63885 .56798 Mdot
.63886 .56798 Mdot
.63887 .56799 Mdot
.63888 .568 Mdot
.63889 .56801 Mdot
.6389 .56802 Mdot
.6389 .56803 Mdot
.63891 .56804 Mdot
.63892 .56805 Mdot
.63893 .56806 Mdot
.63894 .56807 Mdot
.63895 .56807 Mdot
.63896 .56808 Mdot
.63897 .56809 Mdot
.63898 .5681 Mdot
.63899 .56811 Mdot
.639 .56812 Mdot
.63901 .56813 Mdot
.63902 .56814 Mdot
.63903 .56815 Mdot
.63904 .56816 Mdot
.63905 .56817 Mdot
.63906 .56817 Mdot
.63907 .56818 Mdot
.63908 .56819 Mdot
.63909 .5682 Mdot
.6391 .56821 Mdot
.6391 .56822 Mdot
.63911 .56823 Mdot
.63912 .56824 Mdot
.63913 .56825 Mdot
.63914 .56826 Mdot
.63915 .56826 Mdot
.63916 .56827 Mdot
.63917 .56828 Mdot
.63918 .56829 Mdot
.63919 .5683 Mdot
.6392 .56831 Mdot
.63921 .56832 Mdot
.63922 .56833 Mdot
.63923 .56834 Mdot
.63924 .56835 Mdot
.63925 .56835 Mdot
.63926 .56836 Mdot
.63927 .56837 Mdot
.63928 .56838 Mdot
.63929 .56839 Mdot
.6393 .5684 Mdot
.6393 .56841 Mdot
.63931 .56842 Mdot
.63932 .56843 Mdot
.63933 .56844 Mdot
.63934 .56844 Mdot
.63935 .56845 Mdot
.63936 .56846 Mdot
.63937 .56847 Mdot
.63938 .56848 Mdot
.63939 .56849 Mdot
.6394 .5685 Mdot
.63941 .56851 Mdot
.63942 .56852 Mdot
.63943 .56853 Mdot
.63944 .56853 Mdot
.63945 .56854 Mdot
.63946 .56855 Mdot
.63947 .56856 Mdot
.63948 .56857 Mdot
.63949 .56858 Mdot
.6395 .56859 Mdot
.6395 .5686 Mdot
.63951 .56861 Mdot
.63952 .56861 Mdot
.63953 .56862 Mdot
.63954 .56863 Mdot
.63955 .56864 Mdot
.63956 .56865 Mdot
.63957 .56866 Mdot
.63958 .56867 Mdot
.63959 .56868 Mdot
.6396 .56869 Mdot
.63961 .5687 Mdot
.63962 .5687 Mdot
.63963 .56871 Mdot
.63964 .56872 Mdot
.63965 .56873 Mdot
.63966 .56874 Mdot
.63967 .56875 Mdot
.63968 .56876 Mdot
.63969 .56877 Mdot
.6397 .56878 Mdot
.6397 .56878 Mdot
.63971 .56879 Mdot
.63972 .5688 Mdot
.63973 .56881 Mdot
.63974 .56882 Mdot
.63975 .56883 Mdot
.63976 .56884 Mdot
.63977 .56885 Mdot
.63978 .56886 Mdot
.63979 .56887 Mdot
.6398 .56887 Mdot
.63981 .56888 Mdot
.63982 .56889 Mdot
.63983 .5689 Mdot
.63984 .56891 Mdot
.63985 .56892 Mdot
.63986 .56893 Mdot
.63987 .56894 Mdot
.63988 .56895 Mdot
.63989 .56895 Mdot
.6399 .56896 Mdot
.6399 .56897 Mdot
.63991 .56898 Mdot
.63992 .56899 Mdot
.63993 .569 Mdot
.63994 .56901 Mdot
.63995 .56902 Mdot
.63996 .56903 Mdot
.63997 .56903 Mdot
.63998 .56904 Mdot
.63999 .56905 Mdot
.64 .56906 Mdot
.64001 .56907 Mdot
.64002 .56908 Mdot
.64003 .56909 Mdot
.64004 .5691 Mdot
.64005 .56911 Mdot
.64006 .56911 Mdot
.64007 .56912 Mdot
.64008 .56913 Mdot
.64009 .56914 Mdot
.6401 .56915 Mdot
.6401 .56916 Mdot
.64011 .56917 Mdot
.64012 .56918 Mdot
.64013 .56919 Mdot
.64014 .56919 Mdot
.64015 .5692 Mdot
.64016 .56921 Mdot
.64017 .56922 Mdot
.64018 .56923 Mdot
.64019 .56924 Mdot
.6402 .56925 Mdot
.64021 .56926 Mdot
.64022 .56927 Mdot
.64023 .56927 Mdot
.64024 .56928 Mdot
.64025 .56929 Mdot
.64026 .5693 Mdot
.64027 .56931 Mdot
.64028 .56932 Mdot
.64029 .56933 Mdot
.6403 .56934 Mdot
.6403 .56935 Mdot
.64031 .56935 Mdot
.64032 .56936 Mdot
.64033 .56937 Mdot
.64034 .56938 Mdot
.64035 .56939 Mdot
.64036 .5694 Mdot
.64037 .56941 Mdot
.64038 .56942 Mdot
.64039 .56943 Mdot
.6404 .56943 Mdot
.64041 .56944 Mdot
.64042 .56945 Mdot
.64043 .56946 Mdot
.64044 .56947 Mdot
.64045 .56948 Mdot
.64046 .56949 Mdot
.64047 .5695 Mdot
.64048 .56951 Mdot
.64049 .56951 Mdot
.6405 .56952 Mdot
.6405 .56953 Mdot
.64051 .56954 Mdot
.64052 .56955 Mdot
.64053 .56956 Mdot
.64054 .56957 Mdot
.64055 .56958 Mdot
.64056 .56958 Mdot
.64057 .56959 Mdot
.64058 .5696 Mdot
.64059 .56961 Mdot
.6406 .56962 Mdot
.64061 .56963 Mdot
.64062 .56964 Mdot
.64063 .56965 Mdot
.64064 .56966 Mdot
.64065 .56966 Mdot
.64066 .56967 Mdot
.64067 .56968 Mdot
.64068 .56969 Mdot
.64069 .5697 Mdot
.6407 .56971 Mdot
.6407 .56972 Mdot
.64071 .56973 Mdot
.64072 .56973 Mdot
.64073 .56974 Mdot
.64074 .56975 Mdot
.64075 .56976 Mdot
.64076 .56977 Mdot
.64077 .56978 Mdot
.64078 .56979 Mdot
.64079 .5698 Mdot
.6408 .56981 Mdot
.64081 .56981 Mdot
.64082 .56982 Mdot
.64083 .56983 Mdot
.64084 .56984 Mdot
.64085 .56985 Mdot
.64086 .56986 Mdot
.64087 .56987 Mdot
.64088 .56988 Mdot
.64089 .56988 Mdot
.6409 .56989 Mdot
.6409 .5699 Mdot
.64091 .56991 Mdot
.64092 .56992 Mdot
.64093 .56993 Mdot
.64094 .56994 Mdot
.64095 .56995 Mdot
.64096 .56995 Mdot
.64097 .56996 Mdot
.64098 .56997 Mdot
.64099 .56998 Mdot
.641 .56999 Mdot
.64101 .57 Mdot
.64102 .57001 Mdot
.64103 .57002 Mdot
.64104 .57002 Mdot
.64105 .57003 Mdot
.64106 .57004 Mdot
.64107 .57005 Mdot
.64108 .57006 Mdot
.64109 .57007 Mdot
.6411 .57008 Mdot
.6411 .57009 Mdot
.64111 .57009 Mdot
.64112 .5701 Mdot
.64113 .57011 Mdot
.64114 .57012 Mdot
.64115 .57013 Mdot
.64116 .57014 Mdot
.64117 .57015 Mdot
.64118 .57016 Mdot
.64119 .57017 Mdot
.6412 .57017 Mdot
.64121 .57018 Mdot
.64122 .57019 Mdot
.64123 .5702 Mdot
.64124 .57021 Mdot
.64125 .57022 Mdot
.64126 .57023 Mdot
.64127 .57024 Mdot
.64128 .57024 Mdot
.64129 .57025 Mdot
.6413 .57026 Mdot
.6413 .57027 Mdot
.64131 .57028 Mdot
.64132 .57029 Mdot
.64133 .5703 Mdot
.64134 .5703 Mdot
.64135 .57031 Mdot
.64136 .57032 Mdot
.64137 .57033 Mdot
.64138 .57034 Mdot
.64139 .57035 Mdot
.6414 .57036 Mdot
.64141 .57037 Mdot
.64142 .57037 Mdot
.64143 .57038 Mdot
.64144 .57039 Mdot
.64145 .5704 Mdot
.64146 .57041 Mdot
.64147 .57042 Mdot
.64148 .57043 Mdot
.64149 .57044 Mdot
.6415 .57044 Mdot
.6415 .57045 Mdot
.64151 .57046 Mdot
.64152 .57047 Mdot
.64153 .57048 Mdot
.64154 .57049 Mdot
.64155 .5705 Mdot
.64156 .57051 Mdot
.64157 .57051 Mdot
.64158 .57052 Mdot
.64159 .57053 Mdot
.6416 .57054 Mdot
.64161 .57055 Mdot
.64162 .57056 Mdot
.64163 .57057 Mdot
.64164 .57058 Mdot
.64165 .57058 Mdot
.64166 .57059 Mdot
.64167 .5706 Mdot
.64168 .57061 Mdot
.64169 .57062 Mdot
.6417 .57063 Mdot
.6417 .57064 Mdot
.64171 .57064 Mdot
.64172 .57065 Mdot
.64173 .57066 Mdot
.64174 .57067 Mdot
.64175 .57068 Mdot
.64176 .57069 Mdot
.64177 .5707 Mdot
.64178 .57071 Mdot
.64179 .57071 Mdot
.6418 .57072 Mdot
.64181 .57073 Mdot
.64182 .57074 Mdot
.64183 .57075 Mdot
.64184 .57076 Mdot
.64185 .57077 Mdot
.64186 .57078 Mdot
.64187 .57078 Mdot
.64188 .57079 Mdot
.64189 .5708 Mdot
.6419 .57081 Mdot
.6419 .57082 Mdot
.64191 .57083 Mdot
.64192 .57084 Mdot
.64193 .57084 Mdot
.64194 .57085 Mdot
.64195 .57086 Mdot
.64196 .57087 Mdot
.64197 .57088 Mdot
.64198 .57089 Mdot
.64199 .5709 Mdot
.642 .57091 Mdot
.64201 .57091 Mdot
.64202 .57092 Mdot
.64203 .57093 Mdot
.64204 .57094 Mdot
.64205 .57095 Mdot
.64206 .57096 Mdot
.64207 .57097 Mdot
.64208 .57097 Mdot
.64209 .57098 Mdot
.6421 .57099 Mdot
.6421 .571 Mdot
.64211 .57101 Mdot
.64212 .57102 Mdot
.64213 .57103 Mdot
.64214 .57103 Mdot
.64215 .57104 Mdot
.64216 .57105 Mdot
.64217 .57106 Mdot
.64218 .57107 Mdot
.64219 .57108 Mdot
.6422 .57109 Mdot
.64221 .5711 Mdot
.64222 .5711 Mdot
.64223 .57111 Mdot
.64224 .57112 Mdot
.64225 .57113 Mdot
.64226 .57114 Mdot
.64227 .57115 Mdot
.64228 .57116 Mdot
.64229 .57116 Mdot
.6423 .57117 Mdot
.6423 .57118 Mdot
.64231 .57119 Mdot
.64232 .5712 Mdot
.64233 .57121 Mdot
.64234 .57122 Mdot
.64235 .57122 Mdot
.64236 .57123 Mdot
.64237 .57124 Mdot
.64238 .57125 Mdot
.64239 .57126 Mdot
.6424 .57127 Mdot
.64241 .57128 Mdot
.64242 .57128 Mdot
.64243 .57129 Mdot
.64244 .5713 Mdot
.64245 .57131 Mdot
.64246 .57132 Mdot
.64247 .57133 Mdot
.64248 .57134 Mdot
.64249 .57134 Mdot
.6425 .57135 Mdot
.6425 .57136 Mdot
.64251 .57137 Mdot
.64252 .57138 Mdot
.64253 .57139 Mdot
.64254 .5714 Mdot
.64255 .57141 Mdot
.64256 .57141 Mdot
.64257 .57142 Mdot
.64258 .57143 Mdot
.64259 .57144 Mdot
.6426 .57145 Mdot
.64261 .57146 Mdot
.64262 .57147 Mdot
.64263 .57147 Mdot
.64264 .57148 Mdot
.64265 .57149 Mdot
.64266 .5715 Mdot
.64267 .57151 Mdot
.64268 .57152 Mdot
.64269 .57153 Mdot
.6427 .57153 Mdot
.6427 .57154 Mdot
.64271 .57155 Mdot
.64272 .57156 Mdot
.64273 .57157 Mdot
.64274 .57158 Mdot
.64275 .57159 Mdot
.64276 .57159 Mdot
.64277 .5716 Mdot
.64278 .57161 Mdot
.64279 .57162 Mdot
.6428 .57163 Mdot
.64281 .57164 Mdot
.64282 .57164 Mdot
.64283 .57165 Mdot
.64284 .57166 Mdot
.64285 .57167 Mdot
.64286 .57168 Mdot
.64287 .57169 Mdot
.64288 .5717 Mdot
.64289 .5717 Mdot
.6429 .57171 Mdot
.6429 .57172 Mdot
.64291 .57173 Mdot
.64292 .57174 Mdot
.64293 .57175 Mdot
.64294 .57176 Mdot
.64295 .57176 Mdot
.64296 .57177 Mdot
.64297 .57178 Mdot
.64298 .57179 Mdot
.64299 .5718 Mdot
.643 .57181 Mdot
.64301 .57182 Mdot
.64302 .57182 Mdot
.64303 .57183 Mdot
.64304 .57184 Mdot
.64305 .57185 Mdot
.64306 .57186 Mdot
.64307 .57187 Mdot
.64308 .57188 Mdot
.64309 .57188 Mdot
.6431 .57189 Mdot
.6431 .5719 Mdot
.64311 .57191 Mdot
.64312 .57192 Mdot
.64313 .57193 Mdot
.64314 .57194 Mdot
.64315 .57194 Mdot
.64316 .57195 Mdot
.64317 .57196 Mdot
.64318 .57197 Mdot
.64319 .57198 Mdot
.6432 .57199 Mdot
.64321 .57199 Mdot
.64322 .572 Mdot
.64323 .57201 Mdot
.64324 .57202 Mdot
.64325 .57203 Mdot
.64326 .57204 Mdot
.64327 .57205 Mdot
.64328 .57205 Mdot
.64329 .57206 Mdot
.6433 .57207 Mdot
.6433 .57208 Mdot
.64331 .57209 Mdot
.64332 .5721 Mdot
.64333 .57211 Mdot
.64334 .57211 Mdot
.64335 .57212 Mdot
.64336 .57213 Mdot
.64337 .57214 Mdot
.64338 .57215 Mdot
.64339 .57216 Mdot
.6434 .57216 Mdot
.64341 .57217 Mdot
.64342 .57218 Mdot
.64343 .57219 Mdot
.64344 .5722 Mdot
.64345 .57221 Mdot
.64346 .57222 Mdot
.64347 .57222 Mdot
.64348 .57223 Mdot
.64349 .57224 Mdot
.6435 .57225 Mdot
.6435 .57226 Mdot
.64351 .57227 Mdot
.64352 .57227 Mdot
.64353 .57228 Mdot
.64354 .57229 Mdot
.64355 .5723 Mdot
.64356 .57231 Mdot
.64357 .57232 Mdot
.64358 .57233 Mdot
.64359 .57233 Mdot
.6436 .57234 Mdot
.64361 .57235 Mdot
.64362 .57236 Mdot
.64363 .57237 Mdot
.64364 .57238 Mdot
.64365 .57238 Mdot
.64366 .57239 Mdot
.64367 .5724 Mdot
.64368 .57241 Mdot
.64369 .57242 Mdot
.6437 .57243 Mdot
.6437 .57244 Mdot
.64371 .57244 Mdot
.64372 .57245 Mdot
.64373 .57246 Mdot
.64374 .57247 Mdot
.64375 .57248 Mdot
.64376 .57249 Mdot
.64377 .57249 Mdot
.64378 .5725 Mdot
.64379 .57251 Mdot
.6438 .57252 Mdot
.64381 .57253 Mdot
.64382 .57254 Mdot
.64383 .57254 Mdot
.64384 .57255 Mdot
.64385 .57256 Mdot
.64386 .57257 Mdot
.64387 .57258 Mdot
.64388 .57259 Mdot
.64389 .5726 Mdot
.6439 .5726 Mdot
.6439 .57261 Mdot
.64391 .57262 Mdot
.64392 .57263 Mdot
.64393 .57264 Mdot
.64394 .57265 Mdot
.64395 .57265 Mdot
.64396 .57266 Mdot
.64397 .57267 Mdot
.64398 .57268 Mdot
.64399 .57269 Mdot
.644 .5727 Mdot
.64401 .5727 Mdot
.64402 .57271 Mdot
.64403 .57272 Mdot
.64404 .57273 Mdot
.64405 .57274 Mdot
.64406 .57275 Mdot
.64407 .57276 Mdot
.64408 .57276 Mdot
.64409 .57277 Mdot
.6441 .57278 Mdot
.6441 .57279 Mdot
.64411 .5728 Mdot
.64412 .57281 Mdot
.64413 .57281 Mdot
.64414 .57282 Mdot
.64415 .57283 Mdot
.64416 .57284 Mdot
.64417 .57285 Mdot
.64418 .57286 Mdot
.64419 .57286 Mdot
.6442 .57287 Mdot
.64421 .57288 Mdot
.64422 .57289 Mdot
.64423 .5729 Mdot
.64424 .57291 Mdot
.64425 .57291 Mdot
.64426 .57292 Mdot
.64427 .57293 Mdot
.64428 .57294 Mdot
.64429 .57295 Mdot
.6443 .57296 Mdot
.6443 .57296 Mdot
.64431 .57297 Mdot
.64432 .57298 Mdot
.64433 .57299 Mdot
.64434 .573 Mdot
.64435 .57301 Mdot
.64436 .57302 Mdot
.64437 .57302 Mdot
.64438 .57303 Mdot
.64439 .57304 Mdot
.6444 .57305 Mdot
.64441 .57306 Mdot
.64442 .57307 Mdot
.64443 .57307 Mdot
.64444 .57308 Mdot
.64445 .57309 Mdot
.64446 .5731 Mdot
.64447 .57311 Mdot
.64448 .57312 Mdot
.64449 .57312 Mdot
.6445 .57313 Mdot
.6445 .57314 Mdot
.64451 .57315 Mdot
.64452 .57316 Mdot
.64453 .57317 Mdot
.64454 .57317 Mdot
.64455 .57318 Mdot
.64456 .57319 Mdot
.64457 .5732 Mdot
.64458 .57321 Mdot
.64459 .57322 Mdot
.6446 .57322 Mdot
.64461 .57323 Mdot
.64462 .57324 Mdot
.64463 .57325 Mdot
.64464 .57326 Mdot
.64465 .57327 Mdot
.64466 .57327 Mdot
.64467 .57328 Mdot
.64468 .57329 Mdot
.64469 .5733 Mdot
.6447 .57331 Mdot
.6447 .57332 Mdot
.64471 .57332 Mdot
.64472 .57333 Mdot
.64473 .57334 Mdot
.64474 .57335 Mdot
.64475 .57336 Mdot
.64476 .57337 Mdot
.64477 .57337 Mdot
.64478 .57338 Mdot
.64479 .57339 Mdot
.6448 .5734 Mdot
.64481 .57341 Mdot
.64482 .57342 Mdot
.64483 .57342 Mdot
.64484 .57343 Mdot
.64485 .57344 Mdot
.64486 .57345 Mdot
.64487 .57346 Mdot
.64488 .57346 Mdot
.64489 .57347 Mdot
.6449 .57348 Mdot
.6449 .57349 Mdot
.64491 .5735 Mdot
.64492 .57351 Mdot
.64493 .57351 Mdot
.64494 .57352 Mdot
.64495 .57353 Mdot
.64496 .57354 Mdot
.64497 .57355 Mdot
.64498 .57356 Mdot
.64499 .57356 Mdot
.645 .57357 Mdot
.64501 .57358 Mdot
.64502 .57359 Mdot
.64503 .5736 Mdot
.64504 .57361 Mdot
.64505 .57361 Mdot
.64506 .57362 Mdot
.64507 .57363 Mdot
.64508 .57364 Mdot
.64509 .57365 Mdot
.6451 .57366 Mdot
.6451 .57366 Mdot
.64511 .57367 Mdot
.64512 .57368 Mdot
.64513 .57369 Mdot
.64514 .5737 Mdot
.64515 .57371 Mdot
.64516 .57371 Mdot
.64517 .57372 Mdot
.64518 .57373 Mdot
.64519 .57374 Mdot
.6452 .57375 Mdot
.64521 .57375 Mdot
.64522 .57376 Mdot
.64523 .57377 Mdot
.64524 .57378 Mdot
.64525 .57379 Mdot
.64526 .5738 Mdot
.64527 .5738 Mdot
.64528 .57381 Mdot
.64529 .57382 Mdot
.6453 .57383 Mdot
.6453 .57384 Mdot
.64531 .57385 Mdot
.64532 .57385 Mdot
.64533 .57386 Mdot
.64534 .57387 Mdot
.64535 .57388 Mdot
.64536 .57389 Mdot
.64537 .57389 Mdot
.64538 .5739 Mdot
.64539 .57391 Mdot
.6454 .57392 Mdot
.64541 .57393 Mdot
.64542 .57394 Mdot
.64543 .57394 Mdot
.64544 .57395 Mdot
.64545 .57396 Mdot
.64546 .57397 Mdot
.64547 .57398 Mdot
.64548 .57399 Mdot
.64549 .57399 Mdot
.6455 .574 Mdot
.6455 .57401 Mdot
.64551 .57402 Mdot
.64552 .57403 Mdot
.64553 .57403 Mdot
.64554 .57404 Mdot
.64555 .57405 Mdot
.64556 .57406 Mdot
.64557 .57407 Mdot
.64558 .57408 Mdot
.64559 .57408 Mdot
.6456 .57409 Mdot
.64561 .5741 Mdot
.64562 .57411 Mdot
.64563 .57412 Mdot
.64564 .57413 Mdot
.64565 .57413 Mdot
.64566 .57414 Mdot
.64567 .57415 Mdot
.64568 .57416 Mdot
.64569 .57417 Mdot
.6457 .57417 Mdot
.6457 .57418 Mdot
.64571 .57419 Mdot
.64572 .5742 Mdot
.64573 .57421 Mdot
.64574 .57422 Mdot
.64575 .57422 Mdot
.64576 .57423 Mdot
.64577 .57424 Mdot
.64578 .57425 Mdot
.64579 .57426 Mdot
.6458 .57426 Mdot
.64581 .57427 Mdot
.64582 .57428 Mdot
.64583 .57429 Mdot
.64584 .5743 Mdot
.64585 .57431 Mdot
.64586 .57431 Mdot
.64587 .57432 Mdot
.64588 .57433 Mdot
.64589 .57434 Mdot
.6459 .57435 Mdot
.6459 .57435 Mdot
.64591 .57436 Mdot
.64592 .57437 Mdot
.64593 .57438 Mdot
.64594 .57439 Mdot
.64595 .5744 Mdot
.64596 .5744 Mdot
.64597 .57441 Mdot
.64598 .57442 Mdot
.64599 .57443 Mdot
.646 .57444 Mdot
.64601 .57444 Mdot
.64602 .57445 Mdot
.64603 .57446 Mdot
.64604 .57447 Mdot
.64605 .57448 Mdot
.64606 .57448 Mdot
.64607 .57449 Mdot
.64608 .5745 Mdot
.64609 .57451 Mdot
.6461 .57452 Mdot
.6461 .57453 Mdot
.64611 .57453 Mdot
.64612 .57454 Mdot
.64613 .57455 Mdot
.64614 .57456 Mdot
.64615 .57457 Mdot
.64616 .57457 Mdot
.64617 .57458 Mdot
.64618 .57459 Mdot
.64619 .5746 Mdot
.6462 .57461 Mdot
.64621 .57462 Mdot
.64622 .57462 Mdot
.64623 .57463 Mdot
.64624 .57464 Mdot
.64625 .57465 Mdot
.64626 .57466 Mdot
.64627 .57466 Mdot
.64628 .57467 Mdot
.64629 .57468 Mdot
.6463 .57469 Mdot
.6463 .5747 Mdot
.64631 .5747 Mdot
.64632 .57471 Mdot
.64633 .57472 Mdot
.64634 .57473 Mdot
.64635 .57474 Mdot
.64636 .57475 Mdot
.64637 .57475 Mdot
.64638 .57476 Mdot
.64639 .57477 Mdot
.6464 .57478 Mdot
.64641 .57479 Mdot
.64642 .57479 Mdot
.64643 .5748 Mdot
.64644 .57481 Mdot
.64645 .57482 Mdot
.64646 .57483 Mdot
.64647 .57483 Mdot
.64648 .57484 Mdot
.64649 .57485 Mdot
.6465 .57486 Mdot
.6465 .57487 Mdot
.64651 .57487 Mdot
.64652 .57488 Mdot
.64653 .57489 Mdot
.64654 .5749 Mdot
.64655 .57491 Mdot
.64656 .57492 Mdot
.64657 .57492 Mdot
.64658 .57493 Mdot
.64659 .57494 Mdot
.6466 .57495 Mdot
.64661 .57496 Mdot
.64662 .57496 Mdot
.64663 .57497 Mdot
.64664 .57498 Mdot
.64665 .57499 Mdot
.64666 .575 Mdot
.64667 .575 Mdot
.64668 .57501 Mdot
.64669 .57502 Mdot
.6467 .57503 Mdot
.6467 .57504 Mdot
.64671 .57504 Mdot
.64672 .57505 Mdot
.64673 .57506 Mdot
.64674 .57507 Mdot
.64675 .57508 Mdot
.64676 .57508 Mdot
.64677 .57509 Mdot
.64678 .5751 Mdot
.64679 .57511 Mdot
.6468 .57512 Mdot
.64681 .57513 Mdot
.64682 .57513 Mdot
.64683 .57514 Mdot
.64684 .57515 Mdot
.64685 .57516 Mdot
.64686 .57517 Mdot
.64687 .57517 Mdot
.64688 .57518 Mdot
.64689 .57519 Mdot
.6469 .5752 Mdot
.6469 .57521 Mdot
.64691 .57521 Mdot
.64692 .57522 Mdot
.64693 .57523 Mdot
.64694 .57524 Mdot
.64695 .57525 Mdot
.64696 .57525 Mdot
.64697 .57526 Mdot
.64698 .57527 Mdot
.64699 .57528 Mdot
.647 .57529 Mdot
.64701 .57529 Mdot
.64702 .5753 Mdot
.64703 .57531 Mdot
.64704 .57532 Mdot
.64705 .57533 Mdot
.64706 .57533 Mdot
.64707 .57534 Mdot
.64708 .57535 Mdot
.64709 .57536 Mdot
.6471 .57537 Mdot
.6471 .57537 Mdot
.64711 .57538 Mdot
.64712 .57539 Mdot
.64713 .5754 Mdot
.64714 .57541 Mdot
.64715 .57541 Mdot
.64716 .57542 Mdot
.64717 .57543 Mdot
.64718 .57544 Mdot
.64719 .57545 Mdot
.6472 .57545 Mdot
.64721 .57546 Mdot
.64722 .57547 Mdot
.64723 .57548 Mdot
.64724 .57549 Mdot
.64725 .57549 Mdot
.64726 .5755 Mdot
.64727 .57551 Mdot
.64728 .57552 Mdot
.64729 .57553 Mdot
.6473 .57553 Mdot
.6473 .57554 Mdot
.64731 .57555 Mdot
.64732 .57556 Mdot
.64733 .57557 Mdot
.64734 .57557 Mdot
.64735 .57558 Mdot
.64736 .57559 Mdot
.64737 .5756 Mdot
.64738 .57561 Mdot
.64739 .57561 Mdot
.6474 .57562 Mdot
.64741 .57563 Mdot
.64742 .57564 Mdot
.64743 .57565 Mdot
.64744 .57565 Mdot
.64745 .57566 Mdot
.64746 .57567 Mdot
.64747 .57568 Mdot
.64748 .57569 Mdot
.64749 .57569 Mdot
.6475 .5757 Mdot
.6475 .57571 Mdot
.64751 .57572 Mdot
.64752 .57573 Mdot
.64753 .57573 Mdot
.64754 .57574 Mdot
.64755 .57575 Mdot
.64756 .57576 Mdot
.64757 .57577 Mdot
.64758 .57577 Mdot
.64759 .57578 Mdot
.6476 .57579 Mdot
.64761 .5758 Mdot
.64762 .57581 Mdot
.64763 .57581 Mdot
.64764 .57582 Mdot
.64765 .57583 Mdot
.64766 .57584 Mdot
.64767 .57585 Mdot
.64768 .57585 Mdot
.64769 .57586 Mdot
.6477 .57587 Mdot
.6477 .57588 Mdot
.64771 .57589 Mdot
.64772 .57589 Mdot
.64773 .5759 Mdot
.64774 .57591 Mdot
.64775 .57592 Mdot
.64776 .57593 Mdot
.64777 .57593 Mdot
.64778 .57594 Mdot
.64779 .57595 Mdot
.6478 .57596 Mdot
.64781 .57596 Mdot
.64782 .57597 Mdot
.64783 .57598 Mdot
.64784 .57599 Mdot
.64785 .576 Mdot
.64786 .576 Mdot
.64787 .57601 Mdot
.64788 .57602 Mdot
.64789 .57603 Mdot
.6479 .57604 Mdot
.6479 .57604 Mdot
.64791 .57605 Mdot
.64792 .57606 Mdot
.64793 .57607 Mdot
.64794 .57608 Mdot
.64795 .57608 Mdot
.64796 .57609 Mdot
.64797 .5761 Mdot
.64798 .57611 Mdot
.64799 .57612 Mdot
.648 .57612 Mdot
.64801 .57613 Mdot
.64802 .57614 Mdot
.64803 .57615 Mdot
.64804 .57616 Mdot
.64805 .57616 Mdot
.64806 .57617 Mdot
.64807 .57618 Mdot
.64808 .57619 Mdot
.64809 .57619 Mdot
.6481 .5762 Mdot
.6481 .57621 Mdot
.64811 .57622 Mdot
.64812 .57623 Mdot
.64813 .57623 Mdot
.64814 .57624 Mdot
.64815 .57625 Mdot
.64816 .57626 Mdot
.64817 .57627 Mdot
.64818 .57627 Mdot
.64819 .57628 Mdot
.6482 .57629 Mdot
.64821 .5763 Mdot
.64822 .57631 Mdot
.64823 .57631 Mdot
.64824 .57632 Mdot
.64825 .57633 Mdot
.64826 .57634 Mdot
.64827 .57634 Mdot
.64828 .57635 Mdot
.64829 .57636 Mdot
.6483 .57637 Mdot
.6483 .57638 Mdot
.64831 .57638 Mdot
.64832 .57639 Mdot
.64833 .5764 Mdot
.64834 .57641 Mdot
.64835 .57642 Mdot
.64836 .57642 Mdot
.64837 .57643 Mdot
.64838 .57644 Mdot
.64839 .57645 Mdot
.6484 .57645 Mdot
.64841 .57646 Mdot
.64842 .57647 Mdot
.64843 .57648 Mdot
.64844 .57649 Mdot
.64845 .57649 Mdot
.64846 .5765 Mdot
.64847 .57651 Mdot
.64848 .57652 Mdot
.64849 .57653 Mdot
.6485 .57653 Mdot
.6485 .57654 Mdot
.64851 .57655 Mdot
.64852 .57656 Mdot
.64853 .57656 Mdot
.64854 .57657 Mdot
.64855 .57658 Mdot
.64856 .57659 Mdot
.64857 .5766 Mdot
.64858 .5766 Mdot
.64859 .57661 Mdot
.6486 .57662 Mdot
.64861 .57663 Mdot
.64862 .57664 Mdot
.64863 .57664 Mdot
.64864 .57665 Mdot
.64865 .57666 Mdot
.64866 .57667 Mdot
.64867 .57667 Mdot
.64868 .57668 Mdot
.64869 .57669 Mdot
.6487 .5767 Mdot
.6487 .57671 Mdot
.64871 .57671 Mdot
.64872 .57672 Mdot
.64873 .57673 Mdot
.64874 .57674 Mdot
.64875 .57674 Mdot
.64876 .57675 Mdot
.64877 .57676 Mdot
.64878 .57677 Mdot
.64879 .57678 Mdot
.6488 .57678 Mdot
.64881 .57679 Mdot
.64882 .5768 Mdot
.64883 .57681 Mdot
.64884 .57682 Mdot
.64885 .57682 Mdot
.64886 .57683 Mdot
.64887 .57684 Mdot
.64888 .57685 Mdot
.64889 .57685 Mdot
.6489 .57686 Mdot
.6489 .57687 Mdot
.64891 .57688 Mdot
.64892 .57689 Mdot
.64893 .57689 Mdot
.64894 .5769 Mdot
.64895 .57691 Mdot
.64896 .57692 Mdot
.64897 .57692 Mdot
.64898 .57693 Mdot
.64899 .57694 Mdot
.649 .57695 Mdot
.64901 .57696 Mdot
.64902 .57696 Mdot
.64903 .57697 Mdot
.64904 .57698 Mdot
.64905 .57699 Mdot
.64906 .57699 Mdot
.64907 .577 Mdot
.64908 .57701 Mdot
.64909 .57702 Mdot
.6491 .57703 Mdot
.6491 .57703 Mdot
.64911 .57704 Mdot
.64912 .57705 Mdot
.64913 .57706 Mdot
.64914 .57706 Mdot
.64915 .57707 Mdot
.64916 .57708 Mdot
.64917 .57709 Mdot
.64918 .5771 Mdot
.64919 .5771 Mdot
.6492 .57711 Mdot
.64921 .57712 Mdot
.64922 .57713 Mdot
.64923 .57713 Mdot
.64924 .57714 Mdot
.64925 .57715 Mdot
.64926 .57716 Mdot
.64927 .57717 Mdot
.64928 .57717 Mdot
.64929 .57718 Mdot
.6493 .57719 Mdot
.6493 .5772 Mdot
.64931 .5772 Mdot
.64932 .57721 Mdot
.64933 .57722 Mdot
.64934 .57723 Mdot
.64935 .57724 Mdot
.64936 .57724 Mdot
.64937 .57725 Mdot
.64938 .57726 Mdot
.64939 .57727 Mdot
.6494 .57727 Mdot
.64941 .57728 Mdot
.64942 .57729 Mdot
.64943 .5773 Mdot
.64944 .5773 Mdot
.64945 .57731 Mdot
.64946 .57732 Mdot
.64947 .57733 Mdot
.64948 .57734 Mdot
.64949 .57734 Mdot
.6495 .57735 Mdot
.6495 .57736 Mdot
.64951 .57737 Mdot
.64952 .57737 Mdot
.64953 .57738 Mdot
.64954 .57739 Mdot
.64955 .5774 Mdot
.64956 .57741 Mdot
.64957 .57741 Mdot
.64958 .57742 Mdot
.64959 .57743 Mdot
.6496 .57744 Mdot
.64961 .57744 Mdot
.64962 .57745 Mdot
.64963 .57746 Mdot
.64964 .57747 Mdot
.64965 .57747 Mdot
.64966 .57748 Mdot
.64967 .57749 Mdot
.64968 .5775 Mdot
.64969 .57751 Mdot
.6497 .57751 Mdot
.6497 .57752 Mdot
.64971 .57753 Mdot
.64972 .57754 Mdot
.64973 .57754 Mdot
.64974 .57755 Mdot
.64975 .57756 Mdot
.64976 .57757 Mdot
.64977 .57757 Mdot
.64978 .57758 Mdot
.64979 .57759 Mdot
.6498 .5776 Mdot
.64981 .57761 Mdot
.64982 .57761 Mdot
.64983 .57762 Mdot
.64984 .57763 Mdot
.64985 .57764 Mdot
.64986 .57764 Mdot
.64987 .57765 Mdot
.64988 .57766 Mdot
.64989 .57767 Mdot
.6499 .57767 Mdot
.6499 .57768 Mdot
.64991 .57769 Mdot
.64992 .5777 Mdot
.64993 .57771 Mdot
.64994 .57771 Mdot
.64995 .57772 Mdot
.64996 .57773 Mdot
.64997 .57774 Mdot
.64998 .57774 Mdot
.64999 .57775 Mdot
.65 .57776 Mdot
.65001 .57777 Mdot
.65002 .57777 Mdot
.65003 .57778 Mdot
.65004 .57779 Mdot
.65005 .5778 Mdot
.65006 .5778 Mdot
.65007 .57781 Mdot
.65008 .57782 Mdot
.65009 .57783 Mdot
.6501 .57784 Mdot
.6501 .57784 Mdot
.65011 .57785 Mdot
.65012 .57786 Mdot
.65013 .57787 Mdot
.65014 .57787 Mdot
.65015 .57788 Mdot
.65016 .57789 Mdot
.65017 .5779 Mdot
.65018 .5779 Mdot
.65019 .57791 Mdot
.6502 .57792 Mdot
.65021 .57793 Mdot
.65022 .57793 Mdot
.65023 .57794 Mdot
.65024 .57795 Mdot
.65025 .57796 Mdot
.65026 .57797 Mdot
.65027 .57797 Mdot
.65028 .57798 Mdot
.65029 .57799 Mdot
.6503 .578 Mdot
.6503 .578 Mdot
.65031 .57801 Mdot
.65032 .57802 Mdot
.65033 .57803 Mdot
.65034 .57803 Mdot
.65035 .57804 Mdot
.65036 .57805 Mdot
.65037 .57806 Mdot
.65038 .57806 Mdot
.65039 .57807 Mdot
.6504 .57808 Mdot
.65041 .57809 Mdot
.65042 .5781 Mdot
.65043 .5781 Mdot
.65044 .57811 Mdot
.65045 .57812 Mdot
.65046 .57813 Mdot
.65047 .57813 Mdot
.65048 .57814 Mdot
.65049 .57815 Mdot
.6505 .57816 Mdot
.6505 .57816 Mdot
.65051 .57817 Mdot
.65052 .57818 Mdot
.65053 .57819 Mdot
.65054 .57819 Mdot
.65055 .5782 Mdot
.65056 .57821 Mdot
.65057 .57822 Mdot
.65058 .57822 Mdot
.65059 .57823 Mdot
.6506 .57824 Mdot
.65061 .57825 Mdot
.65062 .57825 Mdot
.65063 .57826 Mdot
.65064 .57827 Mdot
.65065 .57828 Mdot
.65066 .57828 Mdot
.65067 .57829 Mdot
.65068 .5783 Mdot
.65069 .57831 Mdot
.6507 .57832 Mdot
.6507 .57832 Mdot
.65071 .57833 Mdot
.65072 .57834 Mdot
.65073 .57835 Mdot
.65074 .57835 Mdot
.65075 .57836 Mdot
.65076 .57837 Mdot
.65077 .57838 Mdot
.65078 .57838 Mdot
.65079 .57839 Mdot
.6508 .5784 Mdot
.65081 .57841 Mdot
.65082 .57841 Mdot
.65083 .57842 Mdot
.65084 .57843 Mdot
.65085 .57844 Mdot
.65086 .57844 Mdot
.65087 .57845 Mdot
.65088 .57846 Mdot
.65089 .57847 Mdot
.6509 .57847 Mdot
.6509 .57848 Mdot
.65091 .57849 Mdot
.65092 .5785 Mdot
.65093 .5785 Mdot
.65094 .57851 Mdot
.65095 .57852 Mdot
.65096 .57853 Mdot
.65097 .57853 Mdot
.65098 .57854 Mdot
.65099 .57855 Mdot
.651 .57856 Mdot
.65101 .57856 Mdot
.65102 .57857 Mdot
.65103 .57858 Mdot
.65104 .57859 Mdot
.65105 .57859 Mdot
.65106 .5786 Mdot
.65107 .57861 Mdot
.65108 .57862 Mdot
.65109 .57863 Mdot
.6511 .57863 Mdot
.6511 .57864 Mdot
.65111 .57865 Mdot
.65112 .57866 Mdot
.65113 .57866 Mdot
.65114 .57867 Mdot
.65115 .57868 Mdot
.65116 .57869 Mdot
.65117 .57869 Mdot
.65118 .5787 Mdot
.65119 .57871 Mdot
.6512 .57872 Mdot
.65121 .57872 Mdot
.65122 .57873 Mdot
.65123 .57874 Mdot
.65124 .57875 Mdot
.65125 .57875 Mdot
.65126 .57876 Mdot
.65127 .57877 Mdot
.65128 .57878 Mdot
.65129 .57878 Mdot
.6513 .57879 Mdot
.6513 .5788 Mdot
.65131 .57881 Mdot
.65132 .57881 Mdot
.65133 .57882 Mdot
.65134 .57883 Mdot
.65135 .57884 Mdot
.65136 .57884 Mdot
.65137 .57885 Mdot
.65138 .57886 Mdot
.65139 .57887 Mdot
.6514 .57887 Mdot
.65141 .57888 Mdot
.65142 .57889 Mdot
.65143 .5789 Mdot
.65144 .5789 Mdot
.65145 .57891 Mdot
.65146 .57892 Mdot
.65147 .57893 Mdot
.65148 .57893 Mdot
.65149 .57894 Mdot
.6515 .57895 Mdot
.6515 .57896 Mdot
.65151 .57896 Mdot
.65152 .57897 Mdot
.65153 .57898 Mdot
.65154 .57899 Mdot
.65155 .57899 Mdot
.65156 .579 Mdot
.65157 .57901 Mdot
.65158 .57902 Mdot
.65159 .57902 Mdot
.6516 .57903 Mdot
.65161 .57904 Mdot
.65162 .57904 Mdot
.65163 .57905 Mdot
.65164 .57906 Mdot
.65165 .57907 Mdot
.65166 .57907 Mdot
.65167 .57908 Mdot
.65168 .57909 Mdot
.65169 .5791 Mdot
.6517 .5791 Mdot
.6517 .57911 Mdot
.65171 .57912 Mdot
.65172 .57913 Mdot
.65173 .57913 Mdot
.65174 .57914 Mdot
.65175 .57915 Mdot
.65176 .57916 Mdot
.65177 .57916 Mdot
.65178 .57917 Mdot
.65179 .57918 Mdot
.6518 .57919 Mdot
.65181 .57919 Mdot
.65182 .5792 Mdot
.65183 .57921 Mdot
.65184 .57922 Mdot
.65185 .57922 Mdot
.65186 .57923 Mdot
.65187 .57924 Mdot
.65188 .57925 Mdot
.65189 .57925 Mdot
.6519 .57926 Mdot
.6519 .57927 Mdot
.65191 .57928 Mdot
.65192 .57928 Mdot
.65193 .57929 Mdot
.65194 .5793 Mdot
.65195 .57931 Mdot
.65196 .57931 Mdot
.65197 .57932 Mdot
.65198 .57933 Mdot
.65199 .57934 Mdot
.652 .57934 Mdot
.65201 .57935 Mdot
.65202 .57936 Mdot
.65203 .57936 Mdot
.65204 .57937 Mdot
.65205 .57938 Mdot
.65206 .57939 Mdot
.65207 .57939 Mdot
.65208 .5794 Mdot
.65209 .57941 Mdot
.6521 .57942 Mdot
.6521 .57942 Mdot
.65211 .57943 Mdot
.65212 .57944 Mdot
.65213 .57945 Mdot
.65214 .57945 Mdot
.65215 .57946 Mdot
.65216 .57947 Mdot
.65217 .57948 Mdot
.65218 .57948 Mdot
.65219 .57949 Mdot
.6522 .5795 Mdot
.65221 .57951 Mdot
.65222 .57951 Mdot
.65223 .57952 Mdot
.65224 .57953 Mdot
.65225 .57954 Mdot
.65226 .57954 Mdot
.65227 .57955 Mdot
.65228 .57956 Mdot
.65229 .57956 Mdot
.6523 .57957 Mdot
.6523 .57958 Mdot
.65231 .57959 Mdot
.65232 .57959 Mdot
.65233 .5796 Mdot
.65234 .57961 Mdot
.65235 .57962 Mdot
.65236 .57962 Mdot
.65237 .57963 Mdot
.65238 .57964 Mdot
.65239 .57965 Mdot
.6524 .57965 Mdot
.65241 .57966 Mdot
.65242 .57967 Mdot
.65243 .57968 Mdot
.65244 .57968 Mdot
.65245 .57969 Mdot
.65246 .5797 Mdot
.65247 .5797 Mdot
.65248 .57971 Mdot
.65249 .57972 Mdot
.6525 .57973 Mdot
.6525 .57973 Mdot
.65251 .57974 Mdot
.65252 .57975 Mdot
.65253 .57976 Mdot
.65254 .57976 Mdot
.65255 .57977 Mdot
.65256 .57978 Mdot
.65257 .57979 Mdot
.65258 .57979 Mdot
.65259 .5798 Mdot
.6526 .57981 Mdot
.65261 .57981 Mdot
.65262 .57982 Mdot
.65263 .57983 Mdot
.65264 .57984 Mdot
.65265 .57984 Mdot
.65266 .57985 Mdot
.65267 .57986 Mdot
.65268 .57987 Mdot
.65269 .57987 Mdot
.6527 .57988 Mdot
.6527 .57989 Mdot
.65271 .5799 Mdot
.65272 .5799 Mdot
.65273 .57991 Mdot
.65274 .57992 Mdot
.65275 .57992 Mdot
.65276 .57993 Mdot
.65277 .57994 Mdot
.65278 .57995 Mdot
.65279 .57995 Mdot
.6528 .57996 Mdot
.65281 .57997 Mdot
.65282 .57998 Mdot
.65283 .57998 Mdot
.65284 .57999 Mdot
.65285 .58 Mdot
.65286 .58001 Mdot
.65287 .58001 Mdot
.65288 .58002 Mdot
.65289 .58003 Mdot
.6529 .58003 Mdot
.6529 .58004 Mdot
.65291 .58005 Mdot
.65292 .58006 Mdot
.65293 .58006 Mdot
.65294 .58007 Mdot
.65295 .58008 Mdot
.65296 .58009 Mdot
.65297 .58009 Mdot
.65298 .5801 Mdot
.65299 .58011 Mdot
.653 .58012 Mdot
.65301 .58012 Mdot
.65302 .58013 Mdot
.65303 .58014 Mdot
.65304 .58014 Mdot
.65305 .58015 Mdot
.65306 .58016 Mdot
.65307 .58017 Mdot
.65308 .58017 Mdot
.65309 .58018 Mdot
.6531 .58019 Mdot
.6531 .5802 Mdot
.65311 .5802 Mdot
.65312 .58021 Mdot
.65313 .58022 Mdot
.65314 .58022 Mdot
.65315 .58023 Mdot
.65316 .58024 Mdot
.65317 .58025 Mdot
.65318 .58025 Mdot
.65319 .58026 Mdot
.6532 .58027 Mdot
.65321 .58028 Mdot
.65322 .58028 Mdot
.65323 .58029 Mdot
.65324 .5803 Mdot
.65325 .5803 Mdot
.65326 .58031 Mdot
.65327 .58032 Mdot
.65328 .58033 Mdot
.65329 .58033 Mdot
.6533 .58034 Mdot
.6533 .58035 Mdot
.65331 .58036 Mdot
.65332 .58036 Mdot
.65333 .58037 Mdot
.65334 .58038 Mdot
.65335 .58038 Mdot
.65336 .58039 Mdot
.65337 .5804 Mdot
.65338 .58041 Mdot
.65339 .58041 Mdot
.6534 .58042 Mdot
.65341 .58043 Mdot
.65342 .58043 Mdot
.65343 .58044 Mdot
.65344 .58045 Mdot
.65345 .58046 Mdot
.65346 .58046 Mdot
.65347 .58047 Mdot
.65348 .58048 Mdot
.65349 .58049 Mdot
.6535 .58049 Mdot
.6535 .5805 Mdot
.65351 .58051 Mdot
.65352 .58051 Mdot
.65353 .58052 Mdot
.65354 .58053 Mdot
.65355 .58054 Mdot
.65356 .58054 Mdot
.65357 .58055 Mdot
.65358 .58056 Mdot
.65359 .58057 Mdot
.6536 .58057 Mdot
.65361 .58058 Mdot
.65362 .58059 Mdot
.65363 .58059 Mdot
.65364 .5806 Mdot
.65365 .58061 Mdot
.65366 .58062 Mdot
.65367 .58062 Mdot
.65368 .58063 Mdot
.65369 .58064 Mdot
.6537 .58064 Mdot
.6537 .58065 Mdot
.65371 .58066 Mdot
.65372 .58067 Mdot
.65373 .58067 Mdot
.65374 .58068 Mdot
.65375 .58069 Mdot
.65376 .58069 Mdot
.65377 .5807 Mdot
.65378 .58071 Mdot
.65379 .58072 Mdot
.6538 .58072 Mdot
.65381 .58073 Mdot
.65382 .58074 Mdot
.65383 .58075 Mdot
.65384 .58075 Mdot
.65385 .58076 Mdot
.65386 .58077 Mdot
.65387 .58077 Mdot
.65388 .58078 Mdot
.65389 .58079 Mdot
.6539 .5808 Mdot
.6539 .5808 Mdot
.65391 .58081 Mdot
.65392 .58082 Mdot
.65393 .58082 Mdot
.65394 .58083 Mdot
.65395 .58084 Mdot
.65396 .58085 Mdot
.65397 .58085 Mdot
.65398 .58086 Mdot
.65399 .58087 Mdot
.654 .58087 Mdot
.65401 .58088 Mdot
.65402 .58089 Mdot
.65403 .5809 Mdot
.65404 .5809 Mdot
.65405 .58091 Mdot
.65406 .58092 Mdot
.65407 .58092 Mdot
.65408 .58093 Mdot
.65409 .58094 Mdot
.6541 .58095 Mdot
.6541 .58095 Mdot
.65411 .58096 Mdot
.65412 .58097 Mdot
.65413 .58097 Mdot
.65414 .58098 Mdot
.65415 .58099 Mdot
.65416 .581 Mdot
.65417 .581 Mdot
.65418 .58101 Mdot
.65419 .58102 Mdot
.6542 .58102 Mdot
.65421 .58103 Mdot
.65422 .58104 Mdot
.65423 .58105 Mdot
.65424 .58105 Mdot
.65425 .58106 Mdot
.65426 .58107 Mdot
.65427 .58107 Mdot
.65428 .58108 Mdot
.65429 .58109 Mdot
.6543 .5811 Mdot
.6543 .5811 Mdot
.65431 .58111 Mdot
.65432 .58112 Mdot
.65433 .58112 Mdot
.65434 .58113 Mdot
.65435 .58114 Mdot
.65436 .58115 Mdot
.65437 .58115 Mdot
.65438 .58116 Mdot
.65439 .58117 Mdot
.6544 .58117 Mdot
.65441 .58118 Mdot
.65442 .58119 Mdot
.65443 .5812 Mdot
.65444 .5812 Mdot
.65445 .58121 Mdot
.65446 .58122 Mdot
.65447 .58122 Mdot
.65448 .58123 Mdot
.65449 .58124 Mdot
.6545 .58125 Mdot
.6545 .58125 Mdot
.65451 .58126 Mdot
.65452 .58127 Mdot
.65453 .58127 Mdot
.65454 .58128 Mdot
.65455 .58129 Mdot
.65456 .5813 Mdot
.65457 .5813 Mdot
.65458 .58131 Mdot
.65459 .58132 Mdot
.6546 .58132 Mdot
.65461 .58133 Mdot
.65462 .58134 Mdot
.65463 .58135 Mdot
.65464 .58135 Mdot
.65465 .58136 Mdot
.65466 .58137 Mdot
.65467 .58137 Mdot
.65468 .58138 Mdot
.65469 .58139 Mdot
.6547 .58139 Mdot
.6547 .5814 Mdot
.65471 .58141 Mdot
.65472 .58142 Mdot
.65473 .58142 Mdot
.65474 .58143 Mdot
.65475 .58144 Mdot
.65476 .58144 Mdot
.65477 .58145 Mdot
.65478 .58146 Mdot
.65479 .58147 Mdot
.6548 .58147 Mdot
.65481 .58148 Mdot
.65482 .58149 Mdot
.65483 .58149 Mdot
.65484 .5815 Mdot
.65485 .58151 Mdot
.65486 .58152 Mdot
.65487 .58152 Mdot
.65488 .58153 Mdot
.65489 .58154 Mdot
.6549 .58154 Mdot
.6549 .58155 Mdot
.65491 .58156 Mdot
.65492 .58156 Mdot
.65493 .58157 Mdot
.65494 .58158 Mdot
.65495 .58159 Mdot
.65496 .58159 Mdot
.65497 .5816 Mdot
.65498 .58161 Mdot
.65499 .58161 Mdot
.655 .58162 Mdot
.65501 .58163 Mdot
.65502 .58164 Mdot
.65503 .58164 Mdot
.65504 .58165 Mdot
.65505 .58166 Mdot
.65506 .58166 Mdot
.65507 .58167 Mdot
.65508 .58168 Mdot
.65509 .58168 Mdot
.6551 .58169 Mdot
.6551 .5817 Mdot
.65511 .58171 Mdot
.65512 .58171 Mdot
.65513 .58172 Mdot
.65514 .58173 Mdot
.65515 .58173 Mdot
.65516 .58174 Mdot
.65517 .58175 Mdot
.65518 .58175 Mdot
.65519 .58176 Mdot
.6552 .58177 Mdot
.65521 .58178 Mdot
.65522 .58178 Mdot
.65523 .58179 Mdot
.65524 .5818 Mdot
.65525 .5818 Mdot
.65526 .58181 Mdot
.65527 .58182 Mdot
.65528 .58183 Mdot
.65529 .58183 Mdot
.6553 .58184 Mdot
.6553 .58185 Mdot
.65531 .58185 Mdot
.65532 .58186 Mdot
.65533 .58187 Mdot
.65534 .58187 Mdot
.65535 .58188 Mdot
.65536 .58189 Mdot
.65537 .5819 Mdot
.65538 .5819 Mdot
.65539 .58191 Mdot
.6554 .58192 Mdot
.65541 .58192 Mdot
.65542 .58193 Mdot
.65543 .58194 Mdot
.65544 .58194 Mdot
.65545 .58195 Mdot
.65546 .58196 Mdot
.65547 .58197 Mdot
.65548 .58197 Mdot
.65549 .58198 Mdot
.6555 .58199 Mdot
.6555 .58199 Mdot
.65551 .582 Mdot
.65552 .58201 Mdot
.65553 .58201 Mdot
.65554 .58202 Mdot
.65555 .58203 Mdot
.65556 .58203 Mdot
.65557 .58204 Mdot
.65558 .58205 Mdot
.65559 .58206 Mdot
.6556 .58206 Mdot
.65561 .58207 Mdot
.65562 .58208 Mdot
.65563 .58208 Mdot
.65564 .58209 Mdot
.65565 .5821 Mdot
.65566 .5821 Mdot
.65567 .58211 Mdot
.65568 .58212 Mdot
.65569 .58213 Mdot
.6557 .58213 Mdot
.6557 .58214 Mdot
.65571 .58215 Mdot
.65572 .58215 Mdot
.65573 .58216 Mdot
.65574 .58217 Mdot
.65575 .58217 Mdot
.65576 .58218 Mdot
.65577 .58219 Mdot
.65578 .5822 Mdot
.65579 .5822 Mdot
.6558 .58221 Mdot
.65581 .58222 Mdot
.65582 .58222 Mdot
.65583 .58223 Mdot
.65584 .58224 Mdot
.65585 .58224 Mdot
.65586 .58225 Mdot
.65587 .58226 Mdot
.65588 .58226 Mdot
.65589 .58227 Mdot
.6559 .58228 Mdot
.6559 .58229 Mdot
.65591 .58229 Mdot
.65592 .5823 Mdot
.65593 .58231 Mdot
.65594 .58231 Mdot
.65595 .58232 Mdot
.65596 .58233 Mdot
.65597 .58233 Mdot
.65598 .58234 Mdot
.65599 .58235 Mdot
.656 .58235 Mdot
.65601 .58236 Mdot
.65602 .58237 Mdot
.65603 .58238 Mdot
.65604 .58238 Mdot
.65605 .58239 Mdot
.65606 .5824 Mdot
.65607 .5824 Mdot
.65608 .58241 Mdot
.65609 .58242 Mdot
.6561 .58242 Mdot
.6561 .58243 Mdot
.65611 .58244 Mdot
.65612 .58244 Mdot
.65613 .58245 Mdot
.65614 .58246 Mdot
.65615 .58247 Mdot
.65616 .58247 Mdot
.65617 .58248 Mdot
.65618 .58249 Mdot
.65619 .58249 Mdot
.6562 .5825 Mdot
.65621 .58251 Mdot
.65622 .58251 Mdot
.65623 .58252 Mdot
.65624 .58253 Mdot
.65625 .58253 Mdot
.65626 .58254 Mdot
.65627 .58255 Mdot
.65628 .58256 Mdot
.65629 .58256 Mdot
.6563 .58257 Mdot
.6563 .58258 Mdot
.65631 .58258 Mdot
.65632 .58259 Mdot
.65633 .5826 Mdot
.65634 .5826 Mdot
.65635 .58261 Mdot
.65636 .58262 Mdot
.65637 .58262 Mdot
.65638 .58263 Mdot
.65639 .58264 Mdot
.6564 .58264 Mdot
.65641 .58265 Mdot
.65642 .58266 Mdot
.65643 .58267 Mdot
.65644 .58267 Mdot
.65645 .58268 Mdot
.65646 .58269 Mdot
.65647 .58269 Mdot
.65648 .5827 Mdot
.65649 .58271 Mdot
.6565 .58271 Mdot
.6565 .58272 Mdot
.65651 .58273 Mdot
.65652 .58273 Mdot
.65653 .58274 Mdot
.65654 .58275 Mdot
.65655 .58275 Mdot
.65656 .58276 Mdot
.65657 .58277 Mdot
.65658 .58278 Mdot
.65659 .58278 Mdot
.6566 .58279 Mdot
.65661 .5828 Mdot
.65662 .5828 Mdot
.65663 .58281 Mdot
.65664 .58282 Mdot
.65665 .58282 Mdot
.65666 .58283 Mdot
.65667 .58284 Mdot
.65668 .58284 Mdot
.65669 .58285 Mdot
.6567 .58286 Mdot
.6567 .58286 Mdot
.65671 .58287 Mdot
.65672 .58288 Mdot
.65673 .58288 Mdot
.65674 .58289 Mdot
.65675 .5829 Mdot
.65676 .58291 Mdot
.65677 .58291 Mdot
.65678 .58292 Mdot
.65679 .58293 Mdot
.6568 .58293 Mdot
.65681 .58294 Mdot
.65682 .58295 Mdot
.65683 .58295 Mdot
.65684 .58296 Mdot
.65685 .58297 Mdot
.65686 .58297 Mdot
.65687 .58298 Mdot
.65688 .58299 Mdot
.65689 .58299 Mdot
.6569 .583 Mdot
.6569 .58301 Mdot
.65691 .58301 Mdot
.65692 .58302 Mdot
.65693 .58303 Mdot
.65694 .58303 Mdot
.65695 .58304 Mdot
.65696 .58305 Mdot
.65697 .58306 Mdot
.65698 .58306 Mdot
.65699 .58307 Mdot
.657 .58308 Mdot
.65701 .58308 Mdot
.65702 .58309 Mdot
.65703 .5831 Mdot
.65704 .5831 Mdot
.65705 .58311 Mdot
.65706 .58312 Mdot
.65707 .58312 Mdot
.65708 .58313 Mdot
.65709 .58314 Mdot
.6571 .58314 Mdot
.6571 .58315 Mdot
.65711 .58316 Mdot
.65712 .58316 Mdot
.65713 .58317 Mdot
.65714 .58318 Mdot
.65715 .58318 Mdot
.65716 .58319 Mdot
.65717 .5832 Mdot
.65718 .5832 Mdot
.65719 .58321 Mdot
.6572 .58322 Mdot
.65721 .58322 Mdot
.65722 .58323 Mdot
.65723 .58324 Mdot
.65724 .58325 Mdot
.65725 .58325 Mdot
.65726 .58326 Mdot
.65727 .58327 Mdot
.65728 .58327 Mdot
.65729 .58328 Mdot
.6573 .58329 Mdot
.6573 .58329 Mdot
.65731 .5833 Mdot
.65732 .58331 Mdot
.65733 .58331 Mdot
.65734 .58332 Mdot
.65735 .58333 Mdot
.65736 .58333 Mdot
.65737 .58334 Mdot
.65738 .58335 Mdot
.65739 .58335 Mdot
.6574 .58336 Mdot
.65741 .58337 Mdot
.65742 .58337 Mdot
.65743 .58338 Mdot
.65744 .58339 Mdot
.65745 .58339 Mdot
.65746 .5834 Mdot
.65747 .58341 Mdot
.65748 .58341 Mdot
.65749 .58342 Mdot
.6575 .58343 Mdot
.6575 .58343 Mdot
.65751 .58344 Mdot
.65752 .58345 Mdot
.65753 .58345 Mdot
.65754 .58346 Mdot
.65755 .58347 Mdot
.65756 .58347 Mdot
.65757 .58348 Mdot
.65758 .58349 Mdot
.65759 .5835 Mdot
.6576 .5835 Mdot
.65761 .58351 Mdot
.65762 .58352 Mdot
.65763 .58352 Mdot
.65764 .58353 Mdot
.65765 .58354 Mdot
.65766 .58354 Mdot
.65767 .58355 Mdot
.65768 .58356 Mdot
.65769 .58356 Mdot
.6577 .58357 Mdot
.6577 .58358 Mdot
.65771 .58358 Mdot
.65772 .58359 Mdot
.65773 .5836 Mdot
.65774 .5836 Mdot
.65775 .58361 Mdot
.65776 .58362 Mdot
.65777 .58362 Mdot
.65778 .58363 Mdot
.65779 .58364 Mdot
.6578 .58364 Mdot
.65781 .58365 Mdot
.65782 .58366 Mdot
.65783 .58366 Mdot
.65784 .58367 Mdot
.65785 .58368 Mdot
.65786 .58368 Mdot
.65787 .58369 Mdot
.65788 .5837 Mdot
.65789 .5837 Mdot
.6579 .58371 Mdot
.6579 .58372 Mdot
.65791 .58372 Mdot
.65792 .58373 Mdot
.65793 .58374 Mdot
.65794 .58374 Mdot
.65795 .58375 Mdot
.65796 .58376 Mdot
.65797 .58376 Mdot
.65798 .58377 Mdot
.65799 .58378 Mdot
.658 .58378 Mdot
.65801 .58379 Mdot
.65802 .5838 Mdot
.65803 .5838 Mdot
.65804 .58381 Mdot
.65805 .58382 Mdot
.65806 .58382 Mdot
.65807 .58383 Mdot
.65808 .58384 Mdot
.65809 .58384 Mdot
.6581 .58385 Mdot
.6581 .58386 Mdot
.65811 .58386 Mdot
.65812 .58387 Mdot
.65813 .58388 Mdot
.65814 .58388 Mdot
.65815 .58389 Mdot
.65816 .5839 Mdot
.65817 .5839 Mdot
.65818 .58391 Mdot
.65819 .58392 Mdot
.6582 .58392 Mdot
.65821 .58393 Mdot
.65822 .58394 Mdot
.65823 .58394 Mdot
.65824 .58395 Mdot
.65825 .58396 Mdot
.65826 .58396 Mdot
.65827 .58397 Mdot
.65828 .58398 Mdot
.65829 .58398 Mdot
.6583 .58399 Mdot
.6583 .584 Mdot
.65831 .584 Mdot
.65832 .58401 Mdot
.65833 .58402 Mdot
.65834 .58402 Mdot
.65835 .58403 Mdot
.65836 .58404 Mdot
.65837 .58404 Mdot
.65838 .58405 Mdot
.65839 .58406 Mdot
.6584 .58406 Mdot
.65841 .58407 Mdot
.65842 .58408 Mdot
.65843 .58408 Mdot
.65844 .58409 Mdot
.65845 .5841 Mdot
.65846 .5841 Mdot
.65847 .58411 Mdot
.65848 .58412 Mdot
.65849 .58412 Mdot
.6585 .58413 Mdot
.6585 .58414 Mdot
.65851 .58414 Mdot
.65852 .58415 Mdot
.65853 .58416 Mdot
.65854 .58416 Mdot
.65855 .58417 Mdot
.65856 .58418 Mdot
.65857 .58418 Mdot
.65858 .58419 Mdot
.65859 .5842 Mdot
.6586 .5842 Mdot
.65861 .58421 Mdot
.65862 .58422 Mdot
.65863 .58422 Mdot
.65864 .58423 Mdot
.65865 .58423 Mdot
.65866 .58424 Mdot
.65867 .58425 Mdot
.65868 .58425 Mdot
.65869 .58426 Mdot
.6587 .58427 Mdot
.6587 .58427 Mdot
.65871 .58428 Mdot
.65872 .58429 Mdot
.65873 .58429 Mdot
.65874 .5843 Mdot
.65875 .58431 Mdot
.65876 .58431 Mdot
.65877 .58432 Mdot
.65878 .58433 Mdot
.65879 .58433 Mdot
.6588 .58434 Mdot
.65881 .58435 Mdot
.65882 .58435 Mdot
.65883 .58436 Mdot
.65884 .58437 Mdot
.65885 .58437 Mdot
.65886 .58438 Mdot
.65887 .58439 Mdot
.65888 .58439 Mdot
.65889 .5844 Mdot
.6589 .58441 Mdot
.6589 .58441 Mdot
.65891 .58442 Mdot
.65892 .58443 Mdot
.65893 .58443 Mdot
.65894 .58444 Mdot
.65895 .58445 Mdot
.65896 .58445 Mdot
.65897 .58446 Mdot
.65898 .58447 Mdot
.65899 .58447 Mdot
.659 .58448 Mdot
.65901 .58448 Mdot
.65902 .58449 Mdot
.65903 .5845 Mdot
.65904 .5845 Mdot
.65905 .58451 Mdot
.65906 .58452 Mdot
.65907 .58452 Mdot
.65908 .58453 Mdot
.65909 .58454 Mdot
.6591 .58454 Mdot
.6591 .58455 Mdot
.65911 .58456 Mdot
.65912 .58456 Mdot
.65913 .58457 Mdot
.65914 .58458 Mdot
.65915 .58458 Mdot
.65916 .58459 Mdot
.65917 .5846 Mdot
.65918 .5846 Mdot
.65919 .58461 Mdot
.6592 .58462 Mdot
.65921 .58462 Mdot
.65922 .58463 Mdot
.65923 .58464 Mdot
.65924 .58464 Mdot
.65925 .58465 Mdot
.65926 .58466 Mdot
.65927 .58466 Mdot
.65928 .58467 Mdot
.65929 .58467 Mdot
.6593 .58468 Mdot
.6593 .58469 Mdot
.65931 .58469 Mdot
.65932 .5847 Mdot
.65933 .58471 Mdot
.65934 .58471 Mdot
.65935 .58472 Mdot
.65936 .58473 Mdot
.65937 .58473 Mdot
.65938 .58474 Mdot
.65939 .58475 Mdot
.6594 .58475 Mdot
.65941 .58476 Mdot
.65942 .58477 Mdot
.65943 .58477 Mdot
.65944 .58478 Mdot
.65945 .58479 Mdot
.65946 .58479 Mdot
.65947 .5848 Mdot
.65948 .5848 Mdot
.65949 .58481 Mdot
.6595 .58482 Mdot
.6595 .58482 Mdot
.65951 .58483 Mdot
.65952 .58484 Mdot
.65953 .58484 Mdot
.65954 .58485 Mdot
.65955 .58486 Mdot
.65956 .58486 Mdot
.65957 .58487 Mdot
.65958 .58488 Mdot
.65959 .58488 Mdot
.6596 .58489 Mdot
.65961 .5849 Mdot
.65962 .5849 Mdot
.65963 .58491 Mdot
.65964 .58492 Mdot
.65965 .58492 Mdot
.65966 .58493 Mdot
.65967 .58493 Mdot
.65968 .58494 Mdot
.65969 .58495 Mdot
.6597 .58495 Mdot
.6597 .58496 Mdot
.65971 .58497 Mdot
.65972 .58497 Mdot
.65973 .58498 Mdot
.65974 .58499 Mdot
.65975 .58499 Mdot
.65976 .585 Mdot
.65977 .58501 Mdot
.65978 .58501 Mdot
.65979 .58502 Mdot
.6598 .58503 Mdot
.65981 .58503 Mdot
.65982 .58504 Mdot
.65983 .58504 Mdot
.65984 .58505 Mdot
.65985 .58506 Mdot
.65986 .58506 Mdot
.65987 .58507 Mdot
.65988 .58508 Mdot
.65989 .58508 Mdot
.6599 .58509 Mdot
.6599 .5851 Mdot
.65991 .5851 Mdot
.65992 .58511 Mdot
.65993 .58512 Mdot
.65994 .58512 Mdot
.65995 .58513 Mdot
.65996 .58513 Mdot
.65997 .58514 Mdot
.65998 .58515 Mdot
.65999 .58515 Mdot
.66 .58516 Mdot
.66001 .58517 Mdot
.66002 .58517 Mdot
.66003 .58518 Mdot
.66004 .58519 Mdot
.66005 .58519 Mdot
.66006 .5852 Mdot
.66007 .58521 Mdot
.66008 .58521 Mdot
.66009 .58522 Mdot
.6601 .58522 Mdot
.6601 .58523 Mdot
.66011 .58524 Mdot
.66012 .58524 Mdot
.66013 .58525 Mdot
.66014 .58526 Mdot
.66015 .58526 Mdot
.66016 .58527 Mdot
.66017 .58528 Mdot
.66018 .58528 Mdot
.66019 .58529 Mdot
.6602 .5853 Mdot
.66021 .5853 Mdot
.66022 .58531 Mdot
.66023 .58531 Mdot
.66024 .58532 Mdot
.66025 .58533 Mdot
.66026 .58533 Mdot
.66027 .58534 Mdot
.66028 .58535 Mdot
.66029 .58535 Mdot
.6603 .58536 Mdot
.6603 .58537 Mdot
.66031 .58537 Mdot
.66032 .58538 Mdot
.66033 .58539 Mdot
.66034 .58539 Mdot
.66035 .5854 Mdot
.66036 .5854 Mdot
.66037 .58541 Mdot
.66038 .58542 Mdot
.66039 .58542 Mdot
.6604 .58543 Mdot
.66041 .58544 Mdot
.66042 .58544 Mdot
.66043 .58545 Mdot
.66044 .58546 Mdot
.66045 .58546 Mdot
.66046 .58547 Mdot
.66047 .58547 Mdot
.66048 .58548 Mdot
.66049 .58549 Mdot
.6605 .58549 Mdot
.6605 .5855 Mdot
.66051 .58551 Mdot
.66052 .58551 Mdot
.66053 .58552 Mdot
.66054 .58553 Mdot
.66055 .58553 Mdot
.66056 .58554 Mdot
.66057 .58554 Mdot
.66058 .58555 Mdot
.66059 .58556 Mdot
.6606 .58556 Mdot
.66061 .58557 Mdot
.66062 .58558 Mdot
.66063 .58558 Mdot
.66064 .58559 Mdot
.66065 .5856 Mdot
.66066 .5856 Mdot
.66067 .58561 Mdot
.66068 .58561 Mdot
.66069 .58562 Mdot
.6607 .58563 Mdot
.6607 .58563 Mdot
.66071 .58564 Mdot
.66072 .58565 Mdot
.66073 .58565 Mdot
.66074 .58566 Mdot
.66075 .58567 Mdot
.66076 .58567 Mdot
.66077 .58568 Mdot
.66078 .58568 Mdot
.66079 .58569 Mdot
.6608 .5857 Mdot
.66081 .5857 Mdot
.66082 .58571 Mdot
.66083 .58572 Mdot
.66084 .58572 Mdot
.66085 .58573 Mdot
.66086 .58574 Mdot
.66087 .58574 Mdot
.66088 .58575 Mdot
.66089 .58575 Mdot
.6609 .58576 Mdot
.6609 .58577 Mdot
.66091 .58577 Mdot
.66092 .58578 Mdot
.66093 .58579 Mdot
.66094 .58579 Mdot
.66095 .5858 Mdot
.66096 .5858 Mdot
.66097 .58581 Mdot
.66098 .58582 Mdot
.66099 .58582 Mdot
.661 .58583 Mdot
.66101 .58584 Mdot
.66102 .58584 Mdot
.66103 .58585 Mdot
.66104 .58586 Mdot
.66105 .58586 Mdot
.66106 .58587 Mdot
.66107 .58587 Mdot
.66108 .58588 Mdot
.66109 .58589 Mdot
.6611 .58589 Mdot
.6611 .5859 Mdot
.66111 .58591 Mdot
.66112 .58591 Mdot
.66113 .58592 Mdot
.66114 .58592 Mdot
.66115 .58593 Mdot
.66116 .58594 Mdot
.66117 .58594 Mdot
.66118 .58595 Mdot
.66119 .58596 Mdot
.6612 .58596 Mdot
.66121 .58597 Mdot
.66122 .58597 Mdot
.66123 .58598 Mdot
.66124 .58599 Mdot
.66125 .58599 Mdot
.66126 .586 Mdot
.66127 .58601 Mdot
.66128 .58601 Mdot
.66129 .58602 Mdot
.6613 .58602 Mdot
.6613 .58603 Mdot
.66131 .58604 Mdot
.66132 .58604 Mdot
.66133 .58605 Mdot
.66134 .58606 Mdot
.66135 .58606 Mdot
.66136 .58607 Mdot
.66137 .58608 Mdot
.66138 .58608 Mdot
.66139 .58609 Mdot
.6614 .58609 Mdot
.66141 .5861 Mdot
.66142 .58611 Mdot
.66143 .58611 Mdot
.66144 .58612 Mdot
.66145 .58613 Mdot
.66146 .58613 Mdot
.66147 .58614 Mdot
.66148 .58614 Mdot
.66149 .58615 Mdot
.6615 .58616 Mdot
.6615 .58616 Mdot
.66151 .58617 Mdot
.66152 .58618 Mdot
.66153 .58618 Mdot
.66154 .58619 Mdot
.66155 .58619 Mdot
.66156 .5862 Mdot
.66157 .58621 Mdot
.66158 .58621 Mdot
.66159 .58622 Mdot
.6616 .58623 Mdot
.66161 .58623 Mdot
.66162 .58624 Mdot
.66163 .58624 Mdot
.66164 .58625 Mdot
.66165 .58626 Mdot
.66166 .58626 Mdot
.66167 .58627 Mdot
.66168 .58628 Mdot
.66169 .58628 Mdot
.6617 .58629 Mdot
.6617 .58629 Mdot
.66171 .5863 Mdot
.66172 .58631 Mdot
.66173 .58631 Mdot
.66174 .58632 Mdot
.66175 .58632 Mdot
.66176 .58633 Mdot
.66177 .58634 Mdot
.66178 .58634 Mdot
.66179 .58635 Mdot
.6618 .58636 Mdot
.66181 .58636 Mdot
.66182 .58637 Mdot
.66183 .58637 Mdot
.66184 .58638 Mdot
.66185 .58639 Mdot
.66186 .58639 Mdot
.66187 .5864 Mdot
.66188 .58641 Mdot
.66189 .58641 Mdot
.6619 .58642 Mdot
.6619 .58642 Mdot
.66191 .58643 Mdot
.66192 .58644 Mdot
.66193 .58644 Mdot
.66194 .58645 Mdot
.66195 .58646 Mdot
.66196 .58646 Mdot
.66197 .58647 Mdot
.66198 .58647 Mdot
.66199 .58648 Mdot
.662 .58649 Mdot
.66201 .58649 Mdot
.66202 .5865 Mdot
.66203 .5865 Mdot
.66204 .58651 Mdot
.66205 .58652 Mdot
.66206 .58652 Mdot
.66207 .58653 Mdot
.66208 .58654 Mdot
.66209 .58654 Mdot
.6621 .58655 Mdot
.6621 .58655 Mdot
.66211 .58656 Mdot
.66212 .58657 Mdot
.66213 .58657 Mdot
.66214 .58658 Mdot
.66215 .58659 Mdot
.66216 .58659 Mdot
.66217 .5866 Mdot
.66218 .5866 Mdot
.66219 .58661 Mdot
.6622 .58662 Mdot
.66221 .58662 Mdot
.66222 .58663 Mdot
.66223 .58663 Mdot
.66224 .58664 Mdot
.66225 .58665 Mdot
.66226 .58665 Mdot
.66227 .58666 Mdot
.66228 .58667 Mdot
.66229 .58667 Mdot
.6623 .58668 Mdot
.6623 .58668 Mdot
.66231 .58669 Mdot
.66232 .5867 Mdot
.66233 .5867 Mdot
.66234 .58671 Mdot
.66235 .58671 Mdot
.66236 .58672 Mdot
.66237 .58673 Mdot
.66238 .58673 Mdot
.66239 .58674 Mdot
.6624 .58675 Mdot
.66241 .58675 Mdot
.66242 .58676 Mdot
.66243 .58676 Mdot
.66244 .58677 Mdot
.66245 .58678 Mdot
.66246 .58678 Mdot
.66247 .58679 Mdot
.66248 .58679 Mdot
.66249 .5868 Mdot
.6625 .58681 Mdot
.6625 .58681 Mdot
.66251 .58682 Mdot
.66252 .58683 Mdot
.66253 .58683 Mdot
.66254 .58684 Mdot
.66255 .58684 Mdot
.66256 .58685 Mdot
.66257 .58686 Mdot
.66258 .58686 Mdot
.66259 .58687 Mdot
.6626 .58687 Mdot
.66261 .58688 Mdot
.66262 .58689 Mdot
.66263 .58689 Mdot
.66264 .5869 Mdot
.66265 .5869 Mdot
.66266 .58691 Mdot
.66267 .58692 Mdot
.66268 .58692 Mdot
.66269 .58693 Mdot
.6627 .58694 Mdot
.6627 .58694 Mdot
.66271 .58695 Mdot
.66272 .58695 Mdot
.66273 .58696 Mdot
.66274 .58697 Mdot
.66275 .58697 Mdot
.66276 .58698 Mdot
.66277 .58698 Mdot
.66278 .58699 Mdot
.66279 .587 Mdot
.6628 .587 Mdot
.66281 .58701 Mdot
.66282 .58701 Mdot
.66283 .58702 Mdot
.66284 .58703 Mdot
.66285 .58703 Mdot
.66286 .58704 Mdot
.66287 .58704 Mdot
.66288 .58705 Mdot
.66289 .58706 Mdot
.6629 .58706 Mdot
.6629 .58707 Mdot
.66291 .58708 Mdot
.66292 .58708 Mdot
.66293 .58709 Mdot
.66294 .58709 Mdot
.66295 .5871 Mdot
.66296 .58711 Mdot
.66297 .58711 Mdot
.66298 .58712 Mdot
.66299 .58712 Mdot
.663 .58713 Mdot
.66301 .58714 Mdot
.66302 .58714 Mdot
.66303 .58715 Mdot
.66304 .58715 Mdot
.66305 .58716 Mdot
.66306 .58717 Mdot
.66307 .58717 Mdot
.66308 .58718 Mdot
.66309 .58718 Mdot
.6631 .58719 Mdot
.6631 .5872 Mdot
.66311 .5872 Mdot
.66312 .58721 Mdot
.66313 .58721 Mdot
.66314 .58722 Mdot
.66315 .58723 Mdot
.66316 .58723 Mdot
.66317 .58724 Mdot
.66318 .58725 Mdot
.66319 .58725 Mdot
.6632 .58726 Mdot
.66321 .58726 Mdot
.66322 .58727 Mdot
.66323 .58728 Mdot
.66324 .58728 Mdot
.66325 .58729 Mdot
.66326 .58729 Mdot
.66327 .5873 Mdot
.66328 .58731 Mdot
.66329 .58731 Mdot
.6633 .58732 Mdot
.6633 .58732 Mdot
.66331 .58733 Mdot
.66332 .58734 Mdot
.66333 .58734 Mdot
.66334 .58735 Mdot
.66335 .58735 Mdot
.66336 .58736 Mdot
.66337 .58737 Mdot
.66338 .58737 Mdot
.66339 .58738 Mdot
.6634 .58738 Mdot
.66341 .58739 Mdot
.66342 .5874 Mdot
.66343 .5874 Mdot
.66344 .58741 Mdot
.66345 .58741 Mdot
.66346 .58742 Mdot
.66347 .58743 Mdot
.66348 .58743 Mdot
.66349 .58744 Mdot
.6635 .58744 Mdot
.6635 .58745 Mdot
.66351 .58746 Mdot
.66352 .58746 Mdot
.66353 .58747 Mdot
.66354 .58747 Mdot
.66355 .58748 Mdot
.66356 .58749 Mdot
.66357 .58749 Mdot
.66358 .5875 Mdot
.66359 .5875 Mdot
.6636 .58751 Mdot
.66361 .58752 Mdot
.66362 .58752 Mdot
.66363 .58753 Mdot
.66364 .58753 Mdot
.66365 .58754 Mdot
.66366 .58755 Mdot
.66367 .58755 Mdot
.66368 .58756 Mdot
.66369 .58756 Mdot
.6637 .58757 Mdot
.6637 .58758 Mdot
.66371 .58758 Mdot
.66372 .58759 Mdot
.66373 .58759 Mdot
.66374 .5876 Mdot
.66375 .58761 Mdot
.66376 .58761 Mdot
.66377 .58762 Mdot
.66378 .58762 Mdot
.66379 .58763 Mdot
.6638 .58764 Mdot
.66381 .58764 Mdot
.66382 .58765 Mdot
.66383 .58765 Mdot
.66384 .58766 Mdot
.66385 .58767 Mdot
.66386 .58767 Mdot
.66387 .58768 Mdot
.66388 .58768 Mdot
.66389 .58769 Mdot
.6639 .5877 Mdot
.6639 .5877 Mdot
.66391 .58771 Mdot
.66392 .58771 Mdot
.66393 .58772 Mdot
.66394 .58773 Mdot
.66395 .58773 Mdot
.66396 .58774 Mdot
.66397 .58774 Mdot
.66398 .58775 Mdot
.66399 .58775 Mdot
.664 .58776 Mdot
.66401 .58777 Mdot
.66402 .58777 Mdot
.66403 .58778 Mdot
.66404 .58778 Mdot
.66405 .58779 Mdot
.66406 .5878 Mdot
.66407 .5878 Mdot
.66408 .58781 Mdot
.66409 .58781 Mdot
.6641 .58782 Mdot
.6641 .58783 Mdot
.66411 .58783 Mdot
.66412 .58784 Mdot
.66413 .58784 Mdot
.66414 .58785 Mdot
.66415 .58786 Mdot
.66416 .58786 Mdot
.66417 .58787 Mdot
.66418 .58787 Mdot
.66419 .58788 Mdot
.6642 .58789 Mdot
.66421 .58789 Mdot
.66422 .5879 Mdot
.66423 .5879 Mdot
.66424 .58791 Mdot
.66425 .58791 Mdot
.66426 .58792 Mdot
.66427 .58793 Mdot
.66428 .58793 Mdot
.66429 .58794 Mdot
.6643 .58794 Mdot
.6643 .58795 Mdot
.66431 .58796 Mdot
.66432 .58796 Mdot
.66433 .58797 Mdot
.66434 .58797 Mdot
.66435 .58798 Mdot
.66436 .58799 Mdot
.66437 .58799 Mdot
.66438 .588 Mdot
.66439 .588 Mdot
.6644 .58801 Mdot
.66441 .58802 Mdot
.66442 .58802 Mdot
.66443 .58803 Mdot
.66444 .58803 Mdot
.66445 .58804 Mdot
.66446 .58804 Mdot
.66447 .58805 Mdot
.66448 .58806 Mdot
.66449 .58806 Mdot
.6645 .58807 Mdot
.6645 .58807 Mdot
.66451 .58808 Mdot
.66452 .58809 Mdot
.66453 .58809 Mdot
.66454 .5881 Mdot
.66455 .5881 Mdot
.66456 .58811 Mdot
.66457 .58812 Mdot
.66458 .58812 Mdot
.66459 .58813 Mdot
.6646 .58813 Mdot
.66461 .58814 Mdot
.66462 .58814 Mdot
.66463 .58815 Mdot
.66464 .58816 Mdot
.66465 .58816 Mdot
.66466 .58817 Mdot
.66467 .58817 Mdot
.66468 .58818 Mdot
.66469 .58819 Mdot
.6647 .58819 Mdot
.6647 .5882 Mdot
.66471 .5882 Mdot
.66472 .58821 Mdot
.66473 .58822 Mdot
.66474 .58822 Mdot
.66475 .58823 Mdot
.66476 .58823 Mdot
.66477 .58824 Mdot
.66478 .58824 Mdot
.66479 .58825 Mdot
.6648 .58826 Mdot
.66481 .58826 Mdot
.66482 .58827 Mdot
.66483 .58827 Mdot
.66484 .58828 Mdot
.66485 .58829 Mdot
.66486 .58829 Mdot
.66487 .5883 Mdot
.66488 .5883 Mdot
.66489 .58831 Mdot
.6649 .58831 Mdot
.6649 .58832 Mdot
.66491 .58833 Mdot
.66492 .58833 Mdot
.66493 .58834 Mdot
.66494 .58834 Mdot
.66495 .58835 Mdot
.66496 .58836 Mdot
.66497 .58836 Mdot
.66498 .58837 Mdot
.66499 .58837 Mdot
.665 .58838 Mdot
.66501 .58838 Mdot
.66502 .58839 Mdot
.66503 .5884 Mdot
.66504 .5884 Mdot
.66505 .58841 Mdot
.66506 .58841 Mdot
.66507 .58842 Mdot
.66508 .58843 Mdot
.66509 .58843 Mdot
.6651 .58844 Mdot
.6651 .58844 Mdot
.66511 .58845 Mdot
.66512 .58845 Mdot
.66513 .58846 Mdot
.66514 .58847 Mdot
.66515 .58847 Mdot
.66516 .58848 Mdot
.66517 .58848 Mdot
.66518 .58849 Mdot
.66519 .5885 Mdot
.6652 .5885 Mdot
.66521 .58851 Mdot
.66522 .58851 Mdot
.66523 .58852 Mdot
.66524 .58852 Mdot
.66525 .58853 Mdot
.66526 .58854 Mdot
.66527 .58854 Mdot
.66528 .58855 Mdot
.66529 .58855 Mdot
.6653 .58856 Mdot
.6653 .58856 Mdot
.66531 .58857 Mdot
.66532 .58858 Mdot
.66533 .58858 Mdot
.66534 .58859 Mdot
.66535 .58859 Mdot
.66536 .5886 Mdot
.66537 .58861 Mdot
.66538 .58861 Mdot
.66539 .58862 Mdot
.6654 .58862 Mdot
.66541 .58863 Mdot
.66542 .58863 Mdot
.66543 .58864 Mdot
.66544 .58865 Mdot
.66545 .58865 Mdot
.66546 .58866 Mdot
.66547 .58866 Mdot
.66548 .58867 Mdot
.66549 .58867 Mdot
.6655 .58868 Mdot
.6655 .58869 Mdot
.66551 .58869 Mdot
.66552 .5887 Mdot
.66553 .5887 Mdot
.66554 .58871 Mdot
.66555 .58871 Mdot
.66556 .58872 Mdot
.66557 .58873 Mdot
.66558 .58873 Mdot
.66559 .58874 Mdot
.6656 .58874 Mdot
.66561 .58875 Mdot
.66562 .58875 Mdot
.66563 .58876 Mdot
.66564 .58877 Mdot
.66565 .58877 Mdot
.66566 .58878 Mdot
.66567 .58878 Mdot
.66568 .58879 Mdot
.66569 .5888 Mdot
.6657 .5888 Mdot
.6657 .58881 Mdot
.66571 .58881 Mdot
.66572 .58882 Mdot
.66573 .58882 Mdot
.66574 .58883 Mdot
.66575 .58884 Mdot
.66576 .58884 Mdot
.66577 .58885 Mdot
.66578 .58885 Mdot
.66579 .58886 Mdot
.6658 .58886 Mdot
.66581 .58887 Mdot
.66582 .58888 Mdot
.66583 .58888 Mdot
.66584 .58889 Mdot
.66585 .58889 Mdot
.66586 .5889 Mdot
.66587 .5889 Mdot
.66588 .58891 Mdot
.66589 .58892 Mdot
.6659 .58892 Mdot
.6659 .58893 Mdot
.66591 .58893 Mdot
.66592 .58894 Mdot
.66593 .58894 Mdot
.66594 .58895 Mdot
.66595 .58896 Mdot
.66596 .58896 Mdot
.66597 .58897 Mdot
.66598 .58897 Mdot
.66599 .58898 Mdot
.666 .58898 Mdot
.66601 .58899 Mdot
.66602 .589 Mdot
.66603 .589 Mdot
.66604 .58901 Mdot
.66605 .58901 Mdot
.66606 .58902 Mdot
.66607 .58902 Mdot
.66608 .58903 Mdot
.66609 .58904 Mdot
.6661 .58904 Mdot
.6661 .58905 Mdot
.66611 .58905 Mdot
.66612 .58906 Mdot
.66613 .58906 Mdot
.66614 .58907 Mdot
.66615 .58908 Mdot
.66616 .58908 Mdot
.66617 .58909 Mdot
.66618 .58909 Mdot
.66619 .5891 Mdot
.6662 .5891 Mdot
.66621 .58911 Mdot
.66622 .58911 Mdot
.66623 .58912 Mdot
.66624 .58913 Mdot
.66625 .58913 Mdot
.66626 .58914 Mdot
.66627 .58914 Mdot
.66628 .58915 Mdot
.66629 .58915 Mdot
.6663 .58916 Mdot
.6663 .58917 Mdot
.66631 .58917 Mdot
.66632 .58918 Mdot
.66633 .58918 Mdot
.66634 .58919 Mdot
.66635 .58919 Mdot
.66636 .5892 Mdot
.66637 .58921 Mdot
.66638 .58921 Mdot
.66639 .58922 Mdot
.6664 .58922 Mdot
.66641 .58923 Mdot
.66642 .58923 Mdot
.66643 .58924 Mdot
.66644 .58925 Mdot
.66645 .58925 Mdot
.66646 .58926 Mdot
.66647 .58926 Mdot
.66648 .58927 Mdot
.66649 .58927 Mdot
.6665 .58928 Mdot
.6665 .58928 Mdot
.66651 .58929 Mdot
.66652 .5893 Mdot
.66653 .5893 Mdot
.66654 .58931 Mdot
.66655 .58931 Mdot
.66656 .58932 Mdot
.66657 .58932 Mdot
.66658 .58933 Mdot
.66659 .58934 Mdot
.6666 .58934 Mdot
.66661 .58935 Mdot
.66662 .58935 Mdot
.66663 .58936 Mdot
.66664 .58936 Mdot
.66665 .58937 Mdot
.66666 .58937 Mdot
.66667 .58938 Mdot
.66668 .58939 Mdot
.66669 .58939 Mdot
.6667 .5894 Mdot
.6667 .5894 Mdot
.66671 .58941 Mdot
.66672 .58941 Mdot
.66673 .58942 Mdot
.66674 .58943 Mdot
.66675 .58943 Mdot
.66676 .58944 Mdot
.66677 .58944 Mdot
.66678 .58945 Mdot
.66679 .58945 Mdot
.6668 .58946 Mdot
.66681 .58946 Mdot
.66682 .58947 Mdot
.66683 .58948 Mdot
.66684 .58948 Mdot
.66685 .58949 Mdot
.66686 .58949 Mdot
.66687 .5895 Mdot
.66688 .5895 Mdot
.66689 .58951 Mdot
.6669 .58951 Mdot
.6669 .58952 Mdot
.66691 .58953 Mdot
.66692 .58953 Mdot
.66693 .58954 Mdot
.66694 .58954 Mdot
.66695 .58955 Mdot
.66696 .58955 Mdot
.66697 .58956 Mdot
.66698 .58957 Mdot
.66699 .58957 Mdot
.667 .58958 Mdot
.66701 .58958 Mdot
.66702 .58959 Mdot
.66703 .58959 Mdot
.66704 .5896 Mdot
.66705 .5896 Mdot
.66706 .58961 Mdot
.66707 .58962 Mdot
.66708 .58962 Mdot
.66709 .58963 Mdot
.6671 .58963 Mdot
.6671 .58964 Mdot
.66711 .58964 Mdot
.66712 .58965 Mdot
.66713 .58965 Mdot
.66714 .58966 Mdot
.66715 .58967 Mdot
.66716 .58967 Mdot
.66717 .58968 Mdot
.66718 .58968 Mdot
.66719 .58969 Mdot
.6672 .58969 Mdot
.66721 .5897 Mdot
.66722 .5897 Mdot
.66723 .58971 Mdot
.66724 .58972 Mdot
.66725 .58972 Mdot
.66726 .58973 Mdot
.66727 .58973 Mdot
.66728 .58974 Mdot
.66729 .58974 Mdot
.6673 .58975 Mdot
.6673 .58975 Mdot
.66731 .58976 Mdot
.66732 .58977 Mdot
.66733 .58977 Mdot
.66734 .58978 Mdot
.66735 .58978 Mdot
.66736 .58979 Mdot
.66737 .58979 Mdot
.66738 .5898 Mdot
.66739 .5898 Mdot
.6674 .58981 Mdot
.66741 .58982 Mdot
.66742 .58982 Mdot
.66743 .58983 Mdot
.66744 .58983 Mdot
.66745 .58984 Mdot
.66746 .58984 Mdot
.66747 .58985 Mdot
.66748 .58985 Mdot
.66749 .58986 Mdot
.6675 .58987 Mdot
.6675 .58987 Mdot
.66751 .58988 Mdot
.66752 .58988 Mdot
.66753 .58989 Mdot
.66754 .58989 Mdot
.66755 .5899 Mdot
.66756 .5899 Mdot
.66757 .58991 Mdot
.66758 .58991 Mdot
.66759 .58992 Mdot
.6676 .58993 Mdot
.66761 .58993 Mdot
.66762 .58994 Mdot
.66763 .58994 Mdot
.66764 .58995 Mdot
.66765 .58995 Mdot
.66766 .58996 Mdot
.66767 .58996 Mdot
.66768 .58997 Mdot
.66769 .58998 Mdot
.6677 .58998 Mdot
.6677 .58999 Mdot
.66771 .58999 Mdot
.66772 .59 Mdot
.66773 .59 Mdot
.66774 .59001 Mdot
.66775 .59001 Mdot
.66776 .59002 Mdot
.66777 .59002 Mdot
.66778 .59003 Mdot
.66779 .59004 Mdot
.6678 .59004 Mdot
.66781 .59005 Mdot
.66782 .59005 Mdot
.66783 .59006 Mdot
.66784 .59006 Mdot
.66785 .59007 Mdot
.66786 .59007 Mdot
.66787 .59008 Mdot
.66788 .59009 Mdot
.66789 .59009 Mdot
.6679 .5901 Mdot
.6679 .5901 Mdot
.66791 .59011 Mdot
.66792 .59011 Mdot
.66793 .59012 Mdot
.66794 .59012 Mdot
.66795 .59013 Mdot
.66796 .59013 Mdot
.66797 .59014 Mdot
.66798 .59015 Mdot
.66799 .59015 Mdot
.668 .59016 Mdot
.66801 .59016 Mdot
.66802 .59017 Mdot
.66803 .59017 Mdot
.66804 .59018 Mdot
.66805 .59018 Mdot
.66806 .59019 Mdot
.66807 .59019 Mdot
.66808 .5902 Mdot
.66809 .59021 Mdot
.6681 .59021 Mdot
.6681 .59022 Mdot
.66811 .59022 Mdot
.66812 .59023 Mdot
.66813 .59023 Mdot
.66814 .59024 Mdot
.66815 .59024 Mdot
.66816 .59025 Mdot
.66817 .59025 Mdot
.66818 .59026 Mdot
.66819 .59027 Mdot
.6682 .59027 Mdot
.66821 .59028 Mdot
.66822 .59028 Mdot
.66823 .59029 Mdot
.66824 .59029 Mdot
.66825 .5903 Mdot
.66826 .5903 Mdot
.66827 .59031 Mdot
.66828 .59031 Mdot
.66829 .59032 Mdot
.6683 .59032 Mdot
.6683 .59033 Mdot
.66831 .59034 Mdot
.66832 .59034 Mdot
.66833 .59035 Mdot
.66834 .59035 Mdot
.66835 .59036 Mdot
.66836 .59036 Mdot
.66837 .59037 Mdot
.66838 .59037 Mdot
.66839 .59038 Mdot
.6684 .59038 Mdot
.66841 .59039 Mdot
.66842 .5904 Mdot
.66843 .5904 Mdot
.66844 .59041 Mdot
.66845 .59041 Mdot
.66846 .59042 Mdot
.66847 .59042 Mdot
.66848 .59043 Mdot
.66849 .59043 Mdot
.6685 .59044 Mdot
.6685 .59044 Mdot
.66851 .59045 Mdot
.66852 .59045 Mdot
.66853 .59046 Mdot
.66854 .59047 Mdot
.66855 .59047 Mdot
.66856 .59048 Mdot
.66857 .59048 Mdot
.66858 .59049 Mdot
.66859 .59049 Mdot
.6686 .5905 Mdot
.66861 .5905 Mdot
.66862 .59051 Mdot
.66863 .59051 Mdot
.66864 .59052 Mdot
.66865 .59052 Mdot
.66866 .59053 Mdot
.66867 .59054 Mdot
.66868 .59054 Mdot
.66869 .59055 Mdot
.6687 .59055 Mdot
.6687 .59056 Mdot
.66871 .59056 Mdot
.66872 .59057 Mdot
.66873 .59057 Mdot
.66874 .59058 Mdot
.66875 .59058 Mdot
.66876 .59059 Mdot
.66877 .59059 Mdot
.66878 .5906 Mdot
.66879 .59061 Mdot
.6688 .59061 Mdot
.66881 .59062 Mdot
.66882 .59062 Mdot
.66883 .59063 Mdot
.66884 .59063 Mdot
.66885 .59064 Mdot
.66886 .59064 Mdot
.66887 .59065 Mdot
.66888 .59065 Mdot
.66889 .59066 Mdot
.6689 .59066 Mdot
.6689 .59067 Mdot
.66891 .59067 Mdot
.66892 .59068 Mdot
.66893 .59069 Mdot
.66894 .59069 Mdot
.66895 .5907 Mdot
.66896 .5907 Mdot
.66897 .59071 Mdot
.66898 .59071 Mdot
.66899 .59072 Mdot
.669 .59072 Mdot
.66901 .59073 Mdot
.66902 .59073 Mdot
.66903 .59074 Mdot
.66904 .59074 Mdot
.66905 .59075 Mdot
.66906 .59076 Mdot
.66907 .59076 Mdot
.66908 .59077 Mdot
.66909 .59077 Mdot
.6691 .59078 Mdot
.6691 .59078 Mdot
.66911 .59079 Mdot
.66912 .59079 Mdot
.66913 .5908 Mdot
.66914 .5908 Mdot
.66915 .59081 Mdot
.66916 .59081 Mdot
.66917 .59082 Mdot
.66918 .59082 Mdot
.66919 .59083 Mdot
.6692 .59083 Mdot
.66921 .59084 Mdot
.66922 .59085 Mdot
.66923 .59085 Mdot
.66924 .59086 Mdot
.66925 .59086 Mdot
.66926 .59087 Mdot
.66927 .59087 Mdot
.66928 .59088 Mdot
.66929 .59088 Mdot
.6693 .59089 Mdot
.6693 .59089 Mdot
.66931 .5909 Mdot
.66932 .5909 Mdot
.66933 .59091 Mdot
.66934 .59091 Mdot
.66935 .59092 Mdot
.66936 .59093 Mdot
.66937 .59093 Mdot
.66938 .59094 Mdot
.66939 .59094 Mdot
.6694 .59095 Mdot
.66941 .59095 Mdot
.66942 .59096 Mdot
.66943 .59096 Mdot
.66944 .59097 Mdot
.66945 .59097 Mdot
.66946 .59098 Mdot
.66947 .59098 Mdot
.66948 .59099 Mdot
.66949 .59099 Mdot
.6695 .591 Mdot
.6695 .591 Mdot
.66951 .59101 Mdot
.66952 .59101 Mdot
.66953 .59102 Mdot
.66954 .59103 Mdot
.66955 .59103 Mdot
.66956 .59104 Mdot
.66957 .59104 Mdot
.66958 .59105 Mdot
.66959 .59105 Mdot
.6696 .59106 Mdot
.66961 .59106 Mdot
.66962 .59107 Mdot
.66963 .59107 Mdot
.66964 .59108 Mdot
.66965 .59108 Mdot
.66966 .59109 Mdot
.66967 .59109 Mdot
.66968 .5911 Mdot
.66969 .5911 Mdot
.6697 .59111 Mdot
.6697 .59111 Mdot
.66971 .59112 Mdot
.66972 .59113 Mdot
.66973 .59113 Mdot
.66974 .59114 Mdot
.66975 .59114 Mdot
.66976 .59115 Mdot
.66977 .59115 Mdot
.66978 .59116 Mdot
.66979 .59116 Mdot
.6698 .59117 Mdot
.66981 .59117 Mdot
.66982 .59118 Mdot
.66983 .59118 Mdot
.66984 .59119 Mdot
.66985 .59119 Mdot
.66986 .5912 Mdot
.66987 .5912 Mdot
.66988 .59121 Mdot
.66989 .59121 Mdot
.6699 .59122 Mdot
.6699 .59123 Mdot
.66991 .59123 Mdot
.66992 .59124 Mdot
.66993 .59124 Mdot
.66994 .59125 Mdot
.66995 .59125 Mdot
.66996 .59126 Mdot
.66997 .59126 Mdot
.66998 .59127 Mdot
.66999 .59127 Mdot
.67 .59128 Mdot
.67001 .59128 Mdot
.67002 .59129 Mdot
.67003 .59129 Mdot
.67004 .5913 Mdot
.67005 .5913 Mdot
.67006 .59131 Mdot
.67007 .59131 Mdot
.67008 .59132 Mdot
.67009 .59132 Mdot
.6701 .59133 Mdot
.6701 .59133 Mdot
.67011 .59134 Mdot
.67012 .59135 Mdot
.67013 .59135 Mdot
.67014 .59136 Mdot
.67015 .59136 Mdot
.67016 .59137 Mdot
.67017 .59137 Mdot
.67018 .59138 Mdot
.67019 .59138 Mdot
.6702 .59139 Mdot
.67021 .59139 Mdot
.67022 .5914 Mdot
.67023 .5914 Mdot
.67024 .59141 Mdot
.67025 .59141 Mdot
.67026 .59142 Mdot
.67027 .59142 Mdot
.67028 .59143 Mdot
.67029 .59143 Mdot
.6703 .59144 Mdot
.6703 .59144 Mdot
.67031 .59145 Mdot
.67032 .59145 Mdot
.67033 .59146 Mdot
.67034 .59146 Mdot
.67035 .59147 Mdot
.67036 .59147 Mdot
.67037 .59148 Mdot
.67038 .59149 Mdot
.67039 .59149 Mdot
.6704 .5915 Mdot
.67041 .5915 Mdot
.67042 .59151 Mdot
.67043 .59151 Mdot
.67044 .59152 Mdot
.67045 .59152 Mdot
.67046 .59153 Mdot
.67047 .59153 Mdot
.67048 .59154 Mdot
.67049 .59154 Mdot
.6705 .59155 Mdot
.6705 .59155 Mdot
.67051 .59156 Mdot
.67052 .59156 Mdot
.67053 .59157 Mdot
.67054 .59157 Mdot
.67055 .59158 Mdot
.67056 .59158 Mdot
.67057 .59159 Mdot
.67058 .59159 Mdot
.67059 .5916 Mdot
.6706 .5916 Mdot
.67061 .59161 Mdot
.67062 .59161 Mdot
.67063 .59162 Mdot
.67064 .59162 Mdot
.67065 .59163 Mdot
.67066 .59163 Mdot
.67067 .59164 Mdot
.67068 .59164 Mdot
.67069 .59165 Mdot
.6707 .59166 Mdot
.6707 .59166 Mdot
.67071 .59167 Mdot
.67072 .59167 Mdot
.67073 .59168 Mdot
.67074 .59168 Mdot
.67075 .59169 Mdot
.67076 .59169 Mdot
.67077 .5917 Mdot
.67078 .5917 Mdot
.67079 .59171 Mdot
.6708 .59171 Mdot
.67081 .59172 Mdot
.67082 .59172 Mdot
.67083 .59173 Mdot
.67084 .59173 Mdot
.67085 .59174 Mdot
.67086 .59174 Mdot
.67087 .59175 Mdot
.67088 .59175 Mdot
.67089 .59176 Mdot
.6709 .59176 Mdot
.6709 .59177 Mdot
.67091 .59177 Mdot
.67092 .59178 Mdot
.67093 .59178 Mdot
.67094 .59179 Mdot
.67095 .59179 Mdot
.67096 .5918 Mdot
.67097 .5918 Mdot
.67098 .59181 Mdot
.67099 .59181 Mdot
.671 .59182 Mdot
.67101 .59182 Mdot
.67102 .59183 Mdot
.67103 .59183 Mdot
.67104 .59184 Mdot
.67105 .59184 Mdot
.67106 .59185 Mdot
.67107 .59185 Mdot
.67108 .59186 Mdot
.67109 .59186 Mdot
.6711 .59187 Mdot
.6711 .59187 Mdot
.67111 .59188 Mdot
.67112 .59188 Mdot
.67113 .59189 Mdot
.67114 .5919 Mdot
.67115 .5919 Mdot
.67116 .59191 Mdot
.67117 .59191 Mdot
.67118 .59192 Mdot
.67119 .59192 Mdot
.6712 .59193 Mdot
.67121 .59193 Mdot
.67122 .59194 Mdot
.67123 .59194 Mdot
.67124 .59195 Mdot
.67125 .59195 Mdot
.67126 .59196 Mdot
.67127 .59196 Mdot
.67128 .59197 Mdot
.67129 .59197 Mdot
.6713 .59198 Mdot
.6713 .59198 Mdot
.67131 .59199 Mdot
.67132 .59199 Mdot
.67133 .592 Mdot
.67134 .592 Mdot
.67135 .59201 Mdot
.67136 .59201 Mdot
.67137 .59202 Mdot
.67138 .59202 Mdot
.67139 .59203 Mdot
.6714 .59203 Mdot
.67141 .59204 Mdot
.67142 .59204 Mdot
.67143 .59205 Mdot
.67144 .59205 Mdot
.67145 .59206 Mdot
.67146 .59206 Mdot
.67147 .59207 Mdot
.67148 .59207 Mdot
.67149 .59208 Mdot
.6715 .59208 Mdot
.6715 .59209 Mdot
.67151 .59209 Mdot
.67152 .5921 Mdot
.67153 .5921 Mdot
.67154 .59211 Mdot
.67155 .59211 Mdot
.67156 .59212 Mdot
.67157 .59212 Mdot
.67158 .59213 Mdot
.67159 .59213 Mdot
.6716 .59214 Mdot
.67161 .59214 Mdot
.67162 .59215 Mdot
.67163 .59215 Mdot
.67164 .59216 Mdot
.67165 .59216 Mdot
.67166 .59217 Mdot
.67167 .59217 Mdot
.67168 .59218 Mdot
.67169 .59218 Mdot
.6717 .59219 Mdot
.6717 .59219 Mdot
.67171 .5922 Mdot
.67172 .5922 Mdot
.67173 .59221 Mdot
.67174 .59221 Mdot
.67175 .59222 Mdot
.67176 .59222 Mdot
.67177 .59223 Mdot
.67178 .59223 Mdot
.67179 .59224 Mdot
.6718 .59224 Mdot
.67181 .59225 Mdot
.67182 .59225 Mdot
.67183 .59226 Mdot
.67184 .59226 Mdot
.67185 .59227 Mdot
.67186 .59227 Mdot
.67187 .59228 Mdot
.67188 .59228 Mdot
.67189 .59229 Mdot
.6719 .59229 Mdot
.6719 .5923 Mdot
.67191 .5923 Mdot
.67192 .59231 Mdot
.67193 .59231 Mdot
.67194 .59232 Mdot
.67195 .59232 Mdot
.67196 .59233 Mdot
.67197 .59233 Mdot
.67198 .59234 Mdot
.67199 .59234 Mdot
.672 .59235 Mdot
.67201 .59235 Mdot
.67202 .59236 Mdot
.67203 .59236 Mdot
.67204 .59237 Mdot
.67205 .59237 Mdot
.67206 .59238 Mdot
.67207 .59238 Mdot
.67208 .59239 Mdot
.67209 .59239 Mdot
.6721 .5924 Mdot
.6721 .5924 Mdot
.67211 .59241 Mdot
.67212 .59241 Mdot
.67213 .59242 Mdot
.67214 .59242 Mdot
.67215 .59243 Mdot
.67216 .59243 Mdot
.67217 .59244 Mdot
.67218 .59244 Mdot
.67219 .59245 Mdot
.6722 .59245 Mdot
.67221 .59246 Mdot
.67222 .59246 Mdot
.67223 .59247 Mdot
.67224 .59247 Mdot
.67225 .59248 Mdot
.67226 .59248 Mdot
.67227 .59249 Mdot
.67228 .59249 Mdot
.67229 .5925 Mdot
.6723 .5925 Mdot
.6723 .59251 Mdot
.67231 .59251 Mdot
.67232 .59252 Mdot
.67233 .59252 Mdot
.67234 .59253 Mdot
.67235 .59253 Mdot
.67236 .59254 Mdot
.67237 .59254 Mdot
.67238 .59255 Mdot
.67239 .59255 Mdot
.6724 .59256 Mdot
.67241 .59256 Mdot
.67242 .59257 Mdot
.67243 .59257 Mdot
.67244 .59258 Mdot
.67245 .59258 Mdot
.67246 .59259 Mdot
.67247 .59259 Mdot
.67248 .59259 Mdot
.67249 .5926 Mdot
.6725 .5926 Mdot
.6725 .59261 Mdot
.67251 .59261 Mdot
.67252 .59262 Mdot
.67253 .59262 Mdot
.67254 .59263 Mdot
.67255 .59263 Mdot
.67256 .59264 Mdot
.67257 .59264 Mdot
.67258 .59265 Mdot
.67259 .59265 Mdot
.6726 .59266 Mdot
.67261 .59266 Mdot
.67262 .59267 Mdot
.67263 .59267 Mdot
.67264 .59268 Mdot
.67265 .59268 Mdot
.67266 .59269 Mdot
.67267 .59269 Mdot
.67268 .5927 Mdot
.67269 .5927 Mdot
.6727 .59271 Mdot
.6727 .59271 Mdot
.67271 .59272 Mdot
.67272 .59272 Mdot
.67273 .59273 Mdot
.67274 .59273 Mdot
.67275 .59274 Mdot
.67276 .59274 Mdot
.67277 .59275 Mdot
.67278 .59275 Mdot
.67279 .59276 Mdot
.6728 .59276 Mdot
.67281 .59277 Mdot
.67282 .59277 Mdot
.67283 .59278 Mdot
.67284 .59278 Mdot
.67285 .59279 Mdot
.67286 .59279 Mdot
.67287 .5928 Mdot
.67288 .5928 Mdot
.67289 .59281 Mdot
.6729 .59281 Mdot
.6729 .59282 Mdot
.67291 .59282 Mdot
.67292 .59282 Mdot
.67293 .59283 Mdot
.67294 .59283 Mdot
.67295 .59284 Mdot
.67296 .59284 Mdot
.67297 .59285 Mdot
.67298 .59285 Mdot
.67299 .59286 Mdot
.673 .59286 Mdot
.67301 .59287 Mdot
.67302 .59287 Mdot
.67303 .59288 Mdot
.67304 .59288 Mdot
.67305 .59289 Mdot
.67306 .59289 Mdot
.67307 .5929 Mdot
.67308 .5929 Mdot
.67309 .59291 Mdot
.6731 .59291 Mdot
.6731 .59292 Mdot
.67311 .59292 Mdot
.67312 .59293 Mdot
.67313 .59293 Mdot
.67314 .59294 Mdot
.67315 .59294 Mdot
.67316 .59295 Mdot
.67317 .59295 Mdot
.67318 .59296 Mdot
.67319 .59296 Mdot
.6732 .59297 Mdot
.67321 .59297 Mdot
.67322 .59298 Mdot
.67323 .59298 Mdot
.67324 .59298 Mdot
.67325 .59299 Mdot
.67326 .59299 Mdot
.67327 .593 Mdot
.67328 .593 Mdot
.67329 .59301 Mdot
.6733 .59301 Mdot
.6733 .59302 Mdot
.67331 .59302 Mdot
.67332 .59303 Mdot
.67333 .59303 Mdot
.67334 .59304 Mdot
.67335 .59304 Mdot
.67336 .59305 Mdot
.67337 .59305 Mdot
.67338 .59306 Mdot
.67339 .59306 Mdot
.6734 .59307 Mdot
.67341 .59307 Mdot
.67342 .59308 Mdot
.67343 .59308 Mdot
.67344 .59309 Mdot
.67345 .59309 Mdot
.67346 .5931 Mdot
.67347 .5931 Mdot
.67348 .59311 Mdot
.67349 .59311 Mdot
.6735 .59311 Mdot
.6735 .59312 Mdot
.67351 .59312 Mdot
.67352 .59313 Mdot
.67353 .59313 Mdot
.67354 .59314 Mdot
.67355 .59314 Mdot
.67356 .59315 Mdot
.67357 .59315 Mdot
.67358 .59316 Mdot
.67359 .59316 Mdot
.6736 .59317 Mdot
.67361 .59317 Mdot
.67362 .59318 Mdot
.67363 .59318 Mdot
.67364 .59319 Mdot
.67365 .59319 Mdot
.67366 .5932 Mdot
.67367 .5932 Mdot
.67368 .59321 Mdot
.67369 .59321 Mdot
.6737 .59322 Mdot
.6737 .59322 Mdot
.67371 .59322 Mdot
.67372 .59323 Mdot
.67373 .59323 Mdot
.67374 .59324 Mdot
.67375 .59324 Mdot
.67376 .59325 Mdot
.67377 .59325 Mdot
.67378 .59326 Mdot
.67379 .59326 Mdot
.6738 .59327 Mdot
.67381 .59327 Mdot
.67382 .59328 Mdot
.67383 .59328 Mdot
.67384 .59329 Mdot
.67385 .59329 Mdot
.67386 .5933 Mdot
.67387 .5933 Mdot
.67388 .59331 Mdot
.67389 .59331 Mdot
.6739 .59331 Mdot
.6739 .59332 Mdot
.67391 .59332 Mdot
.67392 .59333 Mdot
.67393 .59333 Mdot
.67394 .59334 Mdot
.67395 .59334 Mdot
.67396 .59335 Mdot
.67397 .59335 Mdot
.67398 .59336 Mdot
.67399 .59336 Mdot
.674 .59337 Mdot
.67401 .59337 Mdot
.67402 .59338 Mdot
.67403 .59338 Mdot
.67404 .59339 Mdot
.67405 .59339 Mdot
.67406 .5934 Mdot
.67407 .5934 Mdot
.67408 .5934 Mdot
.67409 .59341 Mdot
.6741 .59341 Mdot
.6741 .59342 Mdot
.67411 .59342 Mdot
.67412 .59343 Mdot
.67413 .59343 Mdot
.67414 .59344 Mdot
.67415 .59344 Mdot
.67416 .59345 Mdot
.67417 .59345 Mdot
.67418 .59346 Mdot
.67419 .59346 Mdot
.6742 .59347 Mdot
.67421 .59347 Mdot
.67422 .59348 Mdot
.67423 .59348 Mdot
.67424 .59349 Mdot
.67425 .59349 Mdot
.67426 .59349 Mdot
.67427 .5935 Mdot
.67428 .5935 Mdot
.67429 .59351 Mdot
.6743 .59351 Mdot
.6743 .59352 Mdot
.67431 .59352 Mdot
.67432 .59353 Mdot
.67433 .59353 Mdot
.67434 .59354 Mdot
.67435 .59354 Mdot
.67436 .59355 Mdot
.67437 .59355 Mdot
.67438 .59356 Mdot
.67439 .59356 Mdot
.6744 .59356 Mdot
.67441 .59357 Mdot
.67442 .59357 Mdot
.67443 .59358 Mdot
.67444 .59358 Mdot
.67445 .59359 Mdot
.67446 .59359 Mdot
.67447 .5936 Mdot
.67448 .5936 Mdot
.67449 .59361 Mdot
.6745 .59361 Mdot
.6745 .59362 Mdot
.67451 .59362 Mdot
.67452 .59363 Mdot
.67453 .59363 Mdot
.67454 .59364 Mdot
.67455 .59364 Mdot
.67456 .59364 Mdot
.67457 .59365 Mdot
.67458 .59365 Mdot
.67459 .59366 Mdot
.6746 .59366 Mdot
.67461 .59367 Mdot
.67462 .59367 Mdot
.67463 .59368 Mdot
.67464 .59368 Mdot
.67465 .59369 Mdot
.67466 .59369 Mdot
.67467 .5937 Mdot
.67468 .5937 Mdot
.67469 .59371 Mdot
.6747 .59371 Mdot
.6747 .59371 Mdot
.67471 .59372 Mdot
.67472 .59372 Mdot
.67473 .59373 Mdot
.67474 .59373 Mdot
.67475 .59374 Mdot
.67476 .59374 Mdot
.67477 .59375 Mdot
.67478 .59375 Mdot
.67479 .59376 Mdot
.6748 .59376 Mdot
.67481 .59377 Mdot
.67482 .59377 Mdot
.67483 .59377 Mdot
.67484 .59378 Mdot
.67485 .59378 Mdot
.67486 .59379 Mdot
.67487 .59379 Mdot
.67488 .5938 Mdot
.67489 .5938 Mdot
.6749 .59381 Mdot
.6749 .59381 Mdot
.67491 .59382 Mdot
.67492 .59382 Mdot
.67493 .59383 Mdot
.67494 .59383 Mdot
.67495 .59383 Mdot
.67496 .59384 Mdot
.67497 .59384 Mdot
.67498 .59385 Mdot
.67499 .59385 Mdot
.675 .59386 Mdot
.67501 .59386 Mdot
.67502 .59387 Mdot
.67503 .59387 Mdot
.67504 .59388 Mdot
.67505 .59388 Mdot
.67506 .59389 Mdot
.67507 .59389 Mdot
.67508 .59389 Mdot
.67509 .5939 Mdot
.6751 .5939 Mdot
.6751 .59391 Mdot
.67511 .59391 Mdot
.67512 .59392 Mdot
.67513 .59392 Mdot
.67514 .59393 Mdot
.67515 .59393 Mdot
.67516 .59394 Mdot
.67517 .59394 Mdot
.67518 .59395 Mdot
.67519 .59395 Mdot
.6752 .59395 Mdot
.67521 .59396 Mdot
.67522 .59396 Mdot
.67523 .59397 Mdot
.67524 .59397 Mdot
.67525 .59398 Mdot
.67526 .59398 Mdot
.67527 .59399 Mdot
.67528 .59399 Mdot
.67529 .594 Mdot
.6753 .594 Mdot
.6753 .594 Mdot
.67531 .59401 Mdot
.67532 .59401 Mdot
.67533 .59402 Mdot
.67534 .59402 Mdot
.67535 .59403 Mdot
.67536 .59403 Mdot
.67537 .59404 Mdot
.67538 .59404 Mdot
.67539 .59405 Mdot
.6754 .59405 Mdot
.67541 .59406 Mdot
.67542 .59406 Mdot
.67543 .59406 Mdot
.67544 .59407 Mdot
.67545 .59407 Mdot
.67546 .59408 Mdot
.67547 .59408 Mdot
.67548 .59409 Mdot
.67549 .59409 Mdot
.6755 .5941 Mdot
.6755 .5941 Mdot
.67551 .59411 Mdot
.67552 .59411 Mdot
.67553 .59411 Mdot
.67554 .59412 Mdot
.67555 .59412 Mdot
.67556 .59413 Mdot
.67557 .59413 Mdot
.67558 .59414 Mdot
.67559 .59414 Mdot
.6756 .59415 Mdot
.67561 .59415 Mdot
.67562 .59416 Mdot
.67563 .59416 Mdot
.67564 .59416 Mdot
.67565 .59417 Mdot
.67566 .59417 Mdot
.67567 .59418 Mdot
.67568 .59418 Mdot
.67569 .59419 Mdot
.6757 .59419 Mdot
.6757 .5942 Mdot
.67571 .5942 Mdot
.67572 .59421 Mdot
.67573 .59421 Mdot
.67574 .59421 Mdot
.67575 .59422 Mdot
.67576 .59422 Mdot
.67577 .59423 Mdot
.67578 .59423 Mdot
.67579 .59424 Mdot
.6758 .59424 Mdot
.67581 .59425 Mdot
.67582 .59425 Mdot
.67583 .59425 Mdot
.67584 .59426 Mdot
.67585 .59426 Mdot
.67586 .59427 Mdot
.67587 .59427 Mdot
.67588 .59428 Mdot
.67589 .59428 Mdot
.6759 .59429 Mdot
.6759 .59429 Mdot
.67591 .5943 Mdot
.67592 .5943 Mdot
.67593 .5943 Mdot
.67594 .59431 Mdot
.67595 .59431 Mdot
.67596 .59432 Mdot
.67597 .59432 Mdot
.67598 .59433 Mdot
.67599 .59433 Mdot
.676 .59434 Mdot
.67601 .59434 Mdot
.67602 .59435 Mdot
.67603 .59435 Mdot
.67604 .59435 Mdot
.67605 .59436 Mdot
.67606 .59436 Mdot
.67607 .59437 Mdot
.67608 .59437 Mdot
.67609 .59438 Mdot
.6761 .59438 Mdot
.6761 .59439 Mdot
.67611 .59439 Mdot
.67612 .59439 Mdot
.67613 .5944 Mdot
.67614 .5944 Mdot
.67615 .59441 Mdot
.67616 .59441 Mdot
.67617 .59442 Mdot
.67618 .59442 Mdot
.67619 .59443 Mdot
.6762 .59443 Mdot
.67621 .59443 Mdot
.67622 .59444 Mdot
.67623 .59444 Mdot
.67624 .59445 Mdot
.67625 .59445 Mdot
.67626 .59446 Mdot
.67627 .59446 Mdot
.67628 .59447 Mdot
.67629 .59447 Mdot
.6763 .59447 Mdot
.6763 .59448 Mdot
.67631 .59448 Mdot
.67632 .59449 Mdot
.67633 .59449 Mdot
.67634 .5945 Mdot
.67635 .5945 Mdot
.67636 .59451 Mdot
.67637 .59451 Mdot
.67638 .59451 Mdot
.67639 .59452 Mdot
.6764 .59452 Mdot
.67641 .59453 Mdot
.67642 .59453 Mdot
.67643 .59454 Mdot
.67644 .59454 Mdot
.67645 .59455 Mdot
.67646 .59455 Mdot
.67647 .59455 Mdot
.67648 .59456 Mdot
.67649 .59456 Mdot
.6765 .59457 Mdot
.6765 .59457 Mdot
.67651 .59458 Mdot
.67652 .59458 Mdot
.67653 .59459 Mdot
.67654 .59459 Mdot
.67655 .59459 Mdot
.67656 .5946 Mdot
.67657 .5946 Mdot
.67658 .59461 Mdot
.67659 .59461 Mdot
.6766 .59462 Mdot
.67661 .59462 Mdot
.67662 .59463 Mdot
.67663 .59463 Mdot
.67664 .59463 Mdot
.67665 .59464 Mdot
.67666 .59464 Mdot
.67667 .59465 Mdot
.67668 .59465 Mdot
.67669 .59466 Mdot
.6767 .59466 Mdot
.6767 .59467 Mdot
.67671 .59467 Mdot
.67672 .59467 Mdot
.67673 .59468 Mdot
.67674 .59468 Mdot
.67675 .59469 Mdot
.67676 .59469 Mdot
.67677 .5947 Mdot
.67678 .5947 Mdot
.67679 .59471 Mdot
.6768 .59471 Mdot
.67681 .59471 Mdot
.67682 .59472 Mdot
.67683 .59472 Mdot
.67684 .59473 Mdot
.67685 .59473 Mdot
.67686 .59474 Mdot
.67687 .59474 Mdot
.67688 .59474 Mdot
.67689 .59475 Mdot
.6769 .59475 Mdot
.6769 .59476 Mdot
.67691 .59476 Mdot
.67692 .59477 Mdot
.67693 .59477 Mdot
.67694 .59478 Mdot
.67695 .59478 Mdot
.67696 .59478 Mdot
.67697 .59479 Mdot
.67698 .59479 Mdot
.67699 .5948 Mdot
.677 .5948 Mdot
.67701 .59481 Mdot
.67702 .59481 Mdot
.67703 .59481 Mdot
.67704 .59482 Mdot
.67705 .59482 Mdot
.67706 .59483 Mdot
.67707 .59483 Mdot
.67708 .59484 Mdot
.67709 .59484 Mdot
.6771 .59485 Mdot
.6771 .59485 Mdot
.67711 .59485 Mdot
.67712 .59486 Mdot
.67713 .59486 Mdot
.67714 .59487 Mdot
.67715 .59487 Mdot
.67716 .59488 Mdot
.67717 .59488 Mdot
.67718 .59488 Mdot
.67719 .59489 Mdot
.6772 .59489 Mdot
.67721 .5949 Mdot
.67722 .5949 Mdot
.67723 .59491 Mdot
.67724 .59491 Mdot
.67725 .59491 Mdot
.67726 .59492 Mdot
.67727 .59492 Mdot
.67728 .59493 Mdot
.67729 .59493 Mdot
.6773 .59494 Mdot
.6773 .59494 Mdot
.67731 .59495 Mdot
.67732 .59495 Mdot
.67733 .59495 Mdot
.67734 .59496 Mdot
.67735 .59496 Mdot
.67736 .59497 Mdot
.67737 .59497 Mdot
.67738 .59498 Mdot
.67739 .59498 Mdot
.6774 .59498 Mdot
.67741 .59499 Mdot
.67742 .59499 Mdot
.67743 .595 Mdot
.67744 .595 Mdot
.67745 .59501 Mdot
.67746 .59501 Mdot
.67747 .59501 Mdot
.67748 .59502 Mdot
.67749 .59502 Mdot
.6775 .59503 Mdot
.6775 .59503 Mdot
.67751 .59504 Mdot
.67752 .59504 Mdot
.67753 .59504 Mdot
.67754 .59505 Mdot
.67755 .59505 Mdot
.67756 .59506 Mdot
.67757 .59506 Mdot
.67758 .59507 Mdot
.67759 .59507 Mdot
.6776 .59507 Mdot
.67761 .59508 Mdot
.67762 .59508 Mdot
.67763 .59509 Mdot
.67764 .59509 Mdot
.67765 .5951 Mdot
.67766 .5951 Mdot
.67767 .5951 Mdot
.67768 .59511 Mdot
.67769 .59511 Mdot
.6777 .59512 Mdot
.6777 .59512 Mdot
.67771 .59513 Mdot
.67772 .59513 Mdot
.67773 .59513 Mdot
.67774 .59514 Mdot
.67775 .59514 Mdot
.67776 .59515 Mdot
.67777 .59515 Mdot
.67778 .59516 Mdot
.67779 .59516 Mdot
.6778 .59516 Mdot
.67781 .59517 Mdot
.67782 .59517 Mdot
.67783 .59518 Mdot
.67784 .59518 Mdot
.67785 .59519 Mdot
.67786 .59519 Mdot
.67787 .59519 Mdot
.67788 .5952 Mdot
.67789 .5952 Mdot
.6779 .59521 Mdot
.6779 .59521 Mdot
.67791 .59522 Mdot
.67792 .59522 Mdot
.67793 .59522 Mdot
.67794 .59523 Mdot
.67795 .59523 Mdot
.67796 .59524 Mdot
.67797 .59524 Mdot
.67798 .59525 Mdot
.67799 .59525 Mdot
.678 .59525 Mdot
.67801 .59526 Mdot
.67802 .59526 Mdot
.67803 .59527 Mdot
.67804 .59527 Mdot
.67805 .59528 Mdot
.67806 .59528 Mdot
.67807 .59528 Mdot
.67808 .59529 Mdot
.67809 .59529 Mdot
.6781 .5953 Mdot
.6781 .5953 Mdot
.67811 .59531 Mdot
.67812 .59531 Mdot
.67813 .59531 Mdot
.67814 .59532 Mdot
.67815 .59532 Mdot
.67816 .59533 Mdot
.67817 .59533 Mdot
.67818 .59534 Mdot
.67819 .59534 Mdot
.6782 .59534 Mdot
.67821 .59535 Mdot
.67822 .59535 Mdot
.67823 .59536 Mdot
.67824 .59536 Mdot
.67825 .59536 Mdot
.67826 .59537 Mdot
.67827 .59537 Mdot
.67828 .59538 Mdot
.67829 .59538 Mdot
.6783 .59539 Mdot
.6783 .59539 Mdot
.67831 .59539 Mdot
.67832 .5954 Mdot
.67833 .5954 Mdot
.67834 .59541 Mdot
.67835 .59541 Mdot
.67836 .59542 Mdot
.67837 .59542 Mdot
.67838 .59542 Mdot
.67839 .59543 Mdot
.6784 .59543 Mdot
.67841 .59544 Mdot
.67842 .59544 Mdot
.67843 .59544 Mdot
.67844 .59545 Mdot
.67845 .59545 Mdot
.67846 .59546 Mdot
.67847 .59546 Mdot
.67848 .59547 Mdot
.67849 .59547 Mdot
.6785 .59547 Mdot
.6785 .59548 Mdot
.67851 .59548 Mdot
.67852 .59549 Mdot
.67853 .59549 Mdot
.67854 .5955 Mdot
.67855 .5955 Mdot
.67856 .5955 Mdot
.67857 .59551 Mdot
.67858 .59551 Mdot
.67859 .59552 Mdot
.6786 .59552 Mdot
.67861 .59552 Mdot
.67862 .59553 Mdot
.67863 .59553 Mdot
.67864 .59554 Mdot
.67865 .59554 Mdot
.67866 .59555 Mdot
.67867 .59555 Mdot
.67868 .59555 Mdot
.67869 .59556 Mdot
.6787 .59556 Mdot
.6787 .59557 Mdot
.67871 .59557 Mdot
.67872 .59557 Mdot
.67873 .59558 Mdot
.67874 .59558 Mdot
.67875 .59559 Mdot
.67876 .59559 Mdot
.67877 .5956 Mdot
.67878 .5956 Mdot
.67879 .5956 Mdot
.6788 .59561 Mdot
.67881 .59561 Mdot
.67882 .59562 Mdot
.67883 .59562 Mdot
.67884 .59562 Mdot
.67885 .59563 Mdot
.67886 .59563 Mdot
.67887 .59564 Mdot
.67888 .59564 Mdot
.67889 .59565 Mdot
.6789 .59565 Mdot
.6789 .59565 Mdot
.67891 .59566 Mdot
.67892 .59566 Mdot
.67893 .59567 Mdot
.67894 .59567 Mdot
.67895 .59567 Mdot
.67896 .59568 Mdot
.67897 .59568 Mdot
.67898 .59569 Mdot
.67899 .59569 Mdot
.679 .59569 Mdot
.67901 .5957 Mdot
.67902 .5957 Mdot
.67903 .59571 Mdot
.67904 .59571 Mdot
.67905 .59572 Mdot
.67906 .59572 Mdot
.67907 .59572 Mdot
.67908 .59573 Mdot
.67909 .59573 Mdot
.6791 .59574 Mdot
.6791 .59574 Mdot
.67911 .59574 Mdot
.67912 .59575 Mdot
.67913 .59575 Mdot
.67914 .59576 Mdot
.67915 .59576 Mdot
.67916 .59576 Mdot
.67917 .59577 Mdot
.67918 .59577 Mdot
.67919 .59578 Mdot
.6792 .59578 Mdot
.67921 .59579 Mdot
.67922 .59579 Mdot
.67923 .59579 Mdot
.67924 .5958 Mdot
.67925 .5958 Mdot
.67926 .59581 Mdot
.67927 .59581 Mdot
.67928 .59581 Mdot
.67929 .59582 Mdot
.6793 .59582 Mdot
.6793 .59583 Mdot
.67931 .59583 Mdot
.67932 .59583 Mdot
.67933 .59584 Mdot
.67934 .59584 Mdot
.67935 .59585 Mdot
.67936 .59585 Mdot
.67937 .59586 Mdot
.67938 .59586 Mdot
.67939 .59586 Mdot
.6794 .59587 Mdot
.67941 .59587 Mdot
.67942 .59588 Mdot
.67943 .59588 Mdot
.67944 .59588 Mdot
.67945 .59589 Mdot
.67946 .59589 Mdot
.67947 .5959 Mdot
.67948 .5959 Mdot
.67949 .5959 Mdot
.6795 .59591 Mdot
.6795 .59591 Mdot
.67951 .59592 Mdot
.67952 .59592 Mdot
.67953 .59592 Mdot
.67954 .59593 Mdot
.67955 .59593 Mdot
.67956 .59594 Mdot
.67957 .59594 Mdot
.67958 .59594 Mdot
.67959 .59595 Mdot
.6796 .59595 Mdot
.67961 .59596 Mdot
.67962 .59596 Mdot
.67963 .59597 Mdot
.67964 .59597 Mdot
.67965 .59597 Mdot
.67966 .59598 Mdot
.67967 .59598 Mdot
.67968 .59599 Mdot
.67969 .59599 Mdot
.6797 .59599 Mdot
.6797 .596 Mdot
.67971 .596 Mdot
.67972 .59601 Mdot
.67973 .59601 Mdot
.67974 .59601 Mdot
.67975 .59602 Mdot
.67976 .59602 Mdot
.67977 .59603 Mdot
.67978 .59603 Mdot
.67979 .59603 Mdot
.6798 .59604 Mdot
.67981 .59604 Mdot
.67982 .59605 Mdot
.67983 .59605 Mdot
.67984 .59605 Mdot
.67985 .59606 Mdot
.67986 .59606 Mdot
.67987 .59607 Mdot
.67988 .59607 Mdot
.67989 .59607 Mdot
.6799 .59608 Mdot
.6799 .59608 Mdot
.67991 .59609 Mdot
.67992 .59609 Mdot
.67993 .59609 Mdot
.67994 .5961 Mdot
.67995 .5961 Mdot
.67996 .59611 Mdot
.67997 .59611 Mdot
.67998 .59611 Mdot
.67999 .59612 Mdot
.68 .59612 Mdot
.68001 .59613 Mdot
.68002 .59613 Mdot
.68003 .59613 Mdot
.68004 .59614 Mdot
.68005 .59614 Mdot
.68006 .59615 Mdot
.68007 .59615 Mdot
.68008 .59615 Mdot
.68009 .59616 Mdot
.6801 .59616 Mdot
.6801 .59617 Mdot
.68011 .59617 Mdot
.68012 .59617 Mdot
.68013 .59618 Mdot
.68014 .59618 Mdot
.68015 .59619 Mdot
.68016 .59619 Mdot
.68017 .59619 Mdot
.68018 .5962 Mdot
.68019 .5962 Mdot
.6802 .59621 Mdot
.68021 .59621 Mdot
.68022 .59621 Mdot
.68023 .59622 Mdot
.68024 .59622 Mdot
.68025 .59623 Mdot
.68026 .59623 Mdot
.68027 .59623 Mdot
.68028 .59624 Mdot
.68029 .59624 Mdot
.6803 .59625 Mdot
.6803 .59625 Mdot
.68031 .59625 Mdot
.68032 .59626 Mdot
.68033 .59626 Mdot
.68034 .59627 Mdot
.68035 .59627 Mdot
.68036 .59627 Mdot
.68037 .59628 Mdot
.68038 .59628 Mdot
.68039 .59629 Mdot
.6804 .59629 Mdot
.68041 .59629 Mdot
.68042 .5963 Mdot
.68043 .5963 Mdot
.68044 .59631 Mdot
.68045 .59631 Mdot
.68046 .59631 Mdot
.68047 .59632 Mdot
.68048 .59632 Mdot
.68049 .59633 Mdot
.6805 .59633 Mdot
.6805 .59633 Mdot
.68051 .59634 Mdot
.68052 .59634 Mdot
.68053 .59635 Mdot
.68054 .59635 Mdot
.68055 .59635 Mdot
.68056 .59636 Mdot
.68057 .59636 Mdot
.68058 .59637 Mdot
.68059 .59637 Mdot
.6806 .59637 Mdot
.68061 .59638 Mdot
.68062 .59638 Mdot
.68063 .59638 Mdot
.68064 .59639 Mdot
.68065 .59639 Mdot
.68066 .5964 Mdot
.68067 .5964 Mdot
.68068 .5964 Mdot
.68069 .59641 Mdot
.6807 .59641 Mdot
.6807 .59642 Mdot
.68071 .59642 Mdot
.68072 .59642 Mdot
.68073 .59643 Mdot
.68074 .59643 Mdot
.68075 .59644 Mdot
.68076 .59644 Mdot
.68077 .59644 Mdot
.68078 .59645 Mdot
.68079 .59645 Mdot
.6808 .59646 Mdot
.68081 .59646 Mdot
.68082 .59646 Mdot
.68083 .59647 Mdot
.68084 .59647 Mdot
.68085 .59648 Mdot
.68086 .59648 Mdot
.68087 .59648 Mdot
.68088 .59649 Mdot
.68089 .59649 Mdot
.6809 .59649 Mdot
.6809 .5965 Mdot
.68091 .5965 Mdot
.68092 .59651 Mdot
.68093 .59651 Mdot
.68094 .59651 Mdot
.68095 .59652 Mdot
.68096 .59652 Mdot
.68097 .59653 Mdot
.68098 .59653 Mdot
.68099 .59653 Mdot
.681 .59654 Mdot
.68101 .59654 Mdot
.68102 .59655 Mdot
.68103 .59655 Mdot
.68104 .59655 Mdot
.68105 .59656 Mdot
.68106 .59656 Mdot
.68107 .59656 Mdot
.68108 .59657 Mdot
.68109 .59657 Mdot
.6811 .59658 Mdot
.6811 .59658 Mdot
.68111 .59658 Mdot
.68112 .59659 Mdot
.68113 .59659 Mdot
.68114 .5966 Mdot
.68115 .5966 Mdot
.68116 .5966 Mdot
.68117 .59661 Mdot
.68118 .59661 Mdot
.68119 .59662 Mdot
.6812 .59662 Mdot
.68121 .59662 Mdot
.68122 .59663 Mdot
.68123 .59663 Mdot
.68124 .59663 Mdot
.68125 .59664 Mdot
.68126 .59664 Mdot
.68127 .59665 Mdot
.68128 .59665 Mdot
.68129 .59665 Mdot
.6813 .59666 Mdot
.6813 .59666 Mdot
.68131 .59667 Mdot
.68132 .59667 Mdot
.68133 .59667 Mdot
.68134 .59668 Mdot
.68135 .59668 Mdot
.68136 .59668 Mdot
.68137 .59669 Mdot
.68138 .59669 Mdot
.68139 .5967 Mdot
.6814 .5967 Mdot
.68141 .5967 Mdot
.68142 .59671 Mdot
.68143 .59671 Mdot
.68144 .59672 Mdot
.68145 .59672 Mdot
.68146 .59672 Mdot
.68147 .59673 Mdot
.68148 .59673 Mdot
.68149 .59673 Mdot
.6815 .59674 Mdot
.6815 .59674 Mdot
.68151 .59675 Mdot
.68152 .59675 Mdot
.68153 .59675 Mdot
.68154 .59676 Mdot
.68155 .59676 Mdot
.68156 .59677 Mdot
.68157 .59677 Mdot
.68158 .59677 Mdot
.68159 .59678 Mdot
.6816 .59678 Mdot
.68161 .59678 Mdot
.68162 .59679 Mdot
.68163 .59679 Mdot
.68164 .5968 Mdot
.68165 .5968 Mdot
.68166 .5968 Mdot
.68167 .59681 Mdot
.68168 .59681 Mdot
.68169 .59682 Mdot
.6817 .59682 Mdot
.6817 .59682 Mdot
.68171 .59683 Mdot
.68172 .59683 Mdot
.68173 .59683 Mdot
.68174 .59684 Mdot
.68175 .59684 Mdot
.68176 .59685 Mdot
.68177 .59685 Mdot
.68178 .59685 Mdot
.68179 .59686 Mdot
.6818 .59686 Mdot
.68181 .59686 Mdot
.68182 .59687 Mdot
.68183 .59687 Mdot
.68184 .59688 Mdot
.68185 .59688 Mdot
.68186 .59688 Mdot
.68187 .59689 Mdot
.68188 .59689 Mdot
.68189 .59689 Mdot
.6819 .5969 Mdot
.6819 .5969 Mdot
.68191 .59691 Mdot
.68192 .59691 Mdot
.68193 .59691 Mdot
.68194 .59692 Mdot
.68195 .59692 Mdot
.68196 .59693 Mdot
.68197 .59693 Mdot
.68198 .59693 Mdot
.68199 .59694 Mdot
.682 .59694 Mdot
.68201 .59694 Mdot
.68202 .59695 Mdot
.68203 .59695 Mdot
.68204 .59696 Mdot
.68205 .59696 Mdot
.68206 .59696 Mdot
.68207 .59697 Mdot
.68208 .59697 Mdot
.68209 .59697 Mdot
.6821 .59698 Mdot
.6821 .59698 Mdot
.68211 .59699 Mdot
.68212 .59699 Mdot
.68213 .59699 Mdot
.68214 .597 Mdot
.68215 .597 Mdot
.68216 .597 Mdot
.68217 .59701 Mdot
.68218 .59701 Mdot
.68219 .59702 Mdot
.6822 .59702 Mdot
.68221 .59702 Mdot
.68222 .59703 Mdot
.68223 .59703 Mdot
.68224 .59703 Mdot
.68225 .59704 Mdot
.68226 .59704 Mdot
.68227 .59705 Mdot
.68228 .59705 Mdot
.68229 .59705 Mdot
.6823 .59706 Mdot
.6823 .59706 Mdot
.68231 .59706 Mdot
.68232 .59707 Mdot
.68233 .59707 Mdot
.68234 .59708 Mdot
.68235 .59708 Mdot
.68236 .59708 Mdot
.68237 .59709 Mdot
.68238 .59709 Mdot
.68239 .59709 Mdot
.6824 .5971 Mdot
.68241 .5971 Mdot
.68242 .59711 Mdot
.68243 .59711 Mdot
.68244 .59711 Mdot
.68245 .59712 Mdot
.68246 .59712 Mdot
.68247 .59712 Mdot
.68248 .59713 Mdot
.68249 .59713 Mdot
.6825 .59714 Mdot
.6825 .59714 Mdot
.68251 .59714 Mdot
.68252 .59715 Mdot
.68253 .59715 Mdot
.68254 .59715 Mdot
.68255 .59716 Mdot
.68256 .59716 Mdot
.68257 .59716 Mdot
.68258 .59717 Mdot
.68259 .59717 Mdot
.6826 .59718 Mdot
.68261 .59718 Mdot
.68262 .59718 Mdot
.68263 .59719 Mdot
.68264 .59719 Mdot
.68265 .59719 Mdot
.68266 .5972 Mdot
.68267 .5972 Mdot
.68268 .59721 Mdot
.68269 .59721 Mdot
.6827 .59721 Mdot
.6827 .59722 Mdot
.68271 .59722 Mdot
.68272 .59722 Mdot
.68273 .59723 Mdot
.68274 .59723 Mdot
.68275 .59724 Mdot
.68276 .59724 Mdot
.68277 .59724 Mdot
.68278 .59725 Mdot
.68279 .59725 Mdot
.6828 .59725 Mdot
.68281 .59726 Mdot
.68282 .59726 Mdot
.68283 .59726 Mdot
.68284 .59727 Mdot
.68285 .59727 Mdot
.68286 .59728 Mdot
.68287 .59728 Mdot
.68288 .59728 Mdot
.68289 .59729 Mdot
.6829 .59729 Mdot
.6829 .59729 Mdot
.68291 .5973 Mdot
.68292 .5973 Mdot
.68293 .5973 Mdot
.68294 .59731 Mdot
.68295 .59731 Mdot
.68296 .59732 Mdot
.68297 .59732 Mdot
.68298 .59732 Mdot
.68299 .59733 Mdot
.683 .59733 Mdot
.68301 .59733 Mdot
.68302 .59734 Mdot
.68303 .59734 Mdot
.68304 .59735 Mdot
.68305 .59735 Mdot
.68306 .59735 Mdot
.68307 .59736 Mdot
.68308 .59736 Mdot
.68309 .59736 Mdot
.6831 .59737 Mdot
.6831 .59737 Mdot
.68311 .59737 Mdot
.68312 .59738 Mdot
.68313 .59738 Mdot
.68314 .59739 Mdot
.68315 .59739 Mdot
.68316 .59739 Mdot
.68317 .5974 Mdot
.68318 .5974 Mdot
.68319 .5974 Mdot
.6832 .59741 Mdot
.68321 .59741 Mdot
.68322 .59741 Mdot
.68323 .59742 Mdot
.68324 .59742 Mdot
.68325 .59743 Mdot
.68326 .59743 Mdot
.68327 .59743 Mdot
.68328 .59744 Mdot
.68329 .59744 Mdot
.6833 .59744 Mdot
.6833 .59745 Mdot
.68331 .59745 Mdot
.68332 .59745 Mdot
.68333 .59746 Mdot
.68334 .59746 Mdot
.68335 .59746 Mdot
.68336 .59747 Mdot
.68337 .59747 Mdot
.68338 .59748 Mdot
.68339 .59748 Mdot
.6834 .59748 Mdot
.68341 .59749 Mdot
.68342 .59749 Mdot
.68343 .59749 Mdot
.68344 .5975 Mdot
.68345 .5975 Mdot
.68346 .5975 Mdot
.68347 .59751 Mdot
.68348 .59751 Mdot
.68349 .59752 Mdot
.6835 .59752 Mdot
.6835 .59752 Mdot
.68351 .59753 Mdot
.68352 .59753 Mdot
.68353 .59753 Mdot
.68354 .59754 Mdot
.68355 .59754 Mdot
.68356 .59754 Mdot
.68357 .59755 Mdot
.68358 .59755 Mdot
.68359 .59755 Mdot
.6836 .59756 Mdot
.68361 .59756 Mdot
.68362 .59757 Mdot
.68363 .59757 Mdot
.68364 .59757 Mdot
.68365 .59758 Mdot
.68366 .59758 Mdot
.68367 .59758 Mdot
.68368 .59759 Mdot
.68369 .59759 Mdot
.6837 .59759 Mdot
.6837 .5976 Mdot
.68371 .5976 Mdot
.68372 .59761 Mdot
.68373 .59761 Mdot
.68374 .59761 Mdot
.68375 .59762 Mdot
.68376 .59762 Mdot
.68377 .59762 Mdot
.68378 .59763 Mdot
.68379 .59763 Mdot
.6838 .59763 Mdot
.68381 .59764 Mdot
.68382 .59764 Mdot
.68383 .59764 Mdot
.68384 .59765 Mdot
.68385 .59765 Mdot
.68386 .59765 Mdot
.68387 .59766 Mdot
.68388 .59766 Mdot
.68389 .59767 Mdot
.6839 .59767 Mdot
.6839 .59767 Mdot
.68391 .59768 Mdot
.68392 .59768 Mdot
.68393 .59768 Mdot
.68394 .59769 Mdot
.68395 .59769 Mdot
.68396 .59769 Mdot
.68397 .5977 Mdot
.68398 .5977 Mdot
.68399 .5977 Mdot
.684 .59771 Mdot
.68401 .59771 Mdot
.68402 .59772 Mdot
.68403 .59772 Mdot
.68404 .59772 Mdot
.68405 .59773 Mdot
.68406 .59773 Mdot
.68407 .59773 Mdot
.68408 .59774 Mdot
.68409 .59774 Mdot
.6841 .59774 Mdot
.6841 .59775 Mdot
.68411 .59775 Mdot
.68412 .59775 Mdot
.68413 .59776 Mdot
.68414 .59776 Mdot
.68415 .59776 Mdot
.68416 .59777 Mdot
.68417 .59777 Mdot
.68418 .59778 Mdot
.68419 .59778 Mdot
.6842 .59778 Mdot
.68421 .59779 Mdot
.68422 .59779 Mdot
.68423 .59779 Mdot
.68424 .5978 Mdot
.68425 .5978 Mdot
.68426 .5978 Mdot
.68427 .59781 Mdot
.68428 .59781 Mdot
.68429 .59781 Mdot
.6843 .59782 Mdot
.6843 .59782 Mdot
.68431 .59782 Mdot
.68432 .59783 Mdot
.68433 .59783 Mdot
.68434 .59783 Mdot
.68435 .59784 Mdot
.68436 .59784 Mdot
.68437 .59785 Mdot
.68438 .59785 Mdot
.68439 .59785 Mdot
.6844 .59786 Mdot
.68441 .59786 Mdot
.68442 .59786 Mdot
.68443 .59787 Mdot
.68444 .59787 Mdot
.68445 .59787 Mdot
.68446 .59788 Mdot
.68447 .59788 Mdot
.68448 .59788 Mdot
.68449 .59789 Mdot
.6845 .59789 Mdot
.6845 .59789 Mdot
.68451 .5979 Mdot
.68452 .5979 Mdot
.68453 .5979 Mdot
.68454 .59791 Mdot
.68455 .59791 Mdot
.68456 .59791 Mdot
.68457 .59792 Mdot
.68458 .59792 Mdot
.68459 .59793 Mdot
.6846 .59793 Mdot
.68461 .59793 Mdot
.68462 .59794 Mdot
.68463 .59794 Mdot
.68464 .59794 Mdot
.68465 .59795 Mdot
.68466 .59795 Mdot
.68467 .59795 Mdot
.68468 .59796 Mdot
.68469 .59796 Mdot
.6847 .59796 Mdot
.6847 .59797 Mdot
.68471 .59797 Mdot
.68472 .59797 Mdot
.68473 .59798 Mdot
.68474 .59798 Mdot
.68475 .59798 Mdot
.68476 .59799 Mdot
.68477 .59799 Mdot
.68478 .59799 Mdot
.68479 .598 Mdot
.6848 .598 Mdot
.68481 .598 Mdot
.68482 .59801 Mdot
.68483 .59801 Mdot
.68484 .59801 Mdot
.68485 .59802 Mdot
.68486 .59802 Mdot
.68487 .59803 Mdot
.68488 .59803 Mdot
.68489 .59803 Mdot
.6849 .59804 Mdot
.6849 .59804 Mdot
.68491 .59804 Mdot
.68492 .59805 Mdot
.68493 .59805 Mdot
.68494 .59805 Mdot
.68495 .59806 Mdot
.68496 .59806 Mdot
.68497 .59806 Mdot
.68498 .59807 Mdot
.68499 .59807 Mdot
.685 .59807 Mdot
.68501 .59808 Mdot
.68502 .59808 Mdot
.68503 .59808 Mdot
.68504 .59809 Mdot
.68505 .59809 Mdot
.68506 .59809 Mdot
.68507 .5981 Mdot
.68508 .5981 Mdot
.68509 .5981 Mdot
.6851 .59811 Mdot
.6851 .59811 Mdot
.68511 .59811 Mdot
.68512 .59812 Mdot
.68513 .59812 Mdot
.68514 .59812 Mdot
.68515 .59813 Mdot
.68516 .59813 Mdot
.68517 .59813 Mdot
.68518 .59814 Mdot
.68519 .59814 Mdot
.6852 .59814 Mdot
.68521 .59815 Mdot
.68522 .59815 Mdot
.68523 .59815 Mdot
.68524 .59816 Mdot
.68525 .59816 Mdot
.68526 .59817 Mdot
.68527 .59817 Mdot
.68528 .59817 Mdot
.68529 .59818 Mdot
.6853 .59818 Mdot
.6853 .59818 Mdot
.68531 .59819 Mdot
.68532 .59819 Mdot
.68533 .59819 Mdot
.68534 .5982 Mdot
.68535 .5982 Mdot
.68536 .5982 Mdot
.68537 .59821 Mdot
.68538 .59821 Mdot
.68539 .59821 Mdot
.6854 .59822 Mdot
.68541 .59822 Mdot
.68542 .59822 Mdot
.68543 .59823 Mdot
.68544 .59823 Mdot
.68545 .59823 Mdot
.68546 .59824 Mdot
.68547 .59824 Mdot
.68548 .59824 Mdot
.68549 .59825 Mdot
.6855 .59825 Mdot
.6855 .59825 Mdot
.68551 .59826 Mdot
.68552 .59826 Mdot
.68553 .59826 Mdot
.68554 .59827 Mdot
.68555 .59827 Mdot
.68556 .59827 Mdot
.68557 .59828 Mdot
.68558 .59828 Mdot
.68559 .59828 Mdot
.6856 .59829 Mdot
.68561 .59829 Mdot
.68562 .59829 Mdot
.68563 .5983 Mdot
.68564 .5983 Mdot
.68565 .5983 Mdot
.68566 .59831 Mdot
.68567 .59831 Mdot
.68568 .59831 Mdot
.68569 .59832 Mdot
.6857 .59832 Mdot
.6857 .59832 Mdot
.68571 .59833 Mdot
.68572 .59833 Mdot
.68573 .59833 Mdot
.68574 .59834 Mdot
.68575 .59834 Mdot
.68576 .59834 Mdot
.68577 .59835 Mdot
.68578 .59835 Mdot
.68579 .59835 Mdot
.6858 .59836 Mdot
.68581 .59836 Mdot
.68582 .59836 Mdot
.68583 .59837 Mdot
.68584 .59837 Mdot
.68585 .59837 Mdot
.68586 .59838 Mdot
.68587 .59838 Mdot
.68588 .59838 Mdot
.68589 .59839 Mdot
.6859 .59839 Mdot
.6859 .59839 Mdot
.68591 .5984 Mdot
.68592 .5984 Mdot
.68593 .5984 Mdot
.68594 .59841 Mdot
.68595 .59841 Mdot
.68596 .59841 Mdot
.68597 .59842 Mdot
.68598 .59842 Mdot
.68599 .59842 Mdot
.686 .59843 Mdot
.68601 .59843 Mdot
.68602 .59843 Mdot
.68603 .59844 Mdot
.68604 .59844 Mdot
.68605 .59844 Mdot
.68606 .59845 Mdot
.68607 .59845 Mdot
.68608 .59845 Mdot
.68609 .59846 Mdot
.6861 .59846 Mdot
.6861 .59846 Mdot
.68611 .59847 Mdot
.68612 .59847 Mdot
.68613 .59847 Mdot
.68614 .59848 Mdot
.68615 .59848 Mdot
.68616 .59848 Mdot
.68617 .59849 Mdot
.68618 .59849 Mdot
.68619 .59849 Mdot
.6862 .59849 Mdot
.68621 .5985 Mdot
.68622 .5985 Mdot
.68623 .5985 Mdot
.68624 .59851 Mdot
.68625 .59851 Mdot
.68626 .59851 Mdot
.68627 .59852 Mdot
.68628 .59852 Mdot
.68629 .59852 Mdot
.6863 .59853 Mdot
.6863 .59853 Mdot
.68631 .59853 Mdot
.68632 .59854 Mdot
.68633 .59854 Mdot
.68634 .59854 Mdot
.68635 .59855 Mdot
.68636 .59855 Mdot
.68637 .59855 Mdot
.68638 .59856 Mdot
.68639 .59856 Mdot
.6864 .59856 Mdot
.68641 .59857 Mdot
.68642 .59857 Mdot
.68643 .59857 Mdot
.68644 .59858 Mdot
.68645 .59858 Mdot
.68646 .59858 Mdot
.68647 .59859 Mdot
.68648 .59859 Mdot
.68649 .59859 Mdot
.6865 .5986 Mdot
.6865 .5986 Mdot
.68651 .5986 Mdot
.68652 .59861 Mdot
.68653 .59861 Mdot
.68654 .59861 Mdot
.68655 .59862 Mdot
.68656 .59862 Mdot
.68657 .59862 Mdot
.68658 .59863 Mdot
.68659 .59863 Mdot
.6866 .59863 Mdot
.68661 .59863 Mdot
.68662 .59864 Mdot
.68663 .59864 Mdot
.68664 .59864 Mdot
.68665 .59865 Mdot
.68666 .59865 Mdot
.68667 .59865 Mdot
.68668 .59866 Mdot
.68669 .59866 Mdot
.6867 .59866 Mdot
.6867 .59867 Mdot
.68671 .59867 Mdot
.68672 .59867 Mdot
.68673 .59868 Mdot
.68674 .59868 Mdot
.68675 .59868 Mdot
.68676 .59869 Mdot
.68677 .59869 Mdot
.68678 .59869 Mdot
.68679 .5987 Mdot
.6868 .5987 Mdot
.68681 .5987 Mdot
.68682 .59871 Mdot
.68683 .59871 Mdot
.68684 .59871 Mdot
.68685 .59872 Mdot
.68686 .59872 Mdot
.68687 .59872 Mdot
.68688 .59872 Mdot
.68689 .59873 Mdot
.6869 .59873 Mdot
.6869 .59873 Mdot
.68691 .59874 Mdot
.68692 .59874 Mdot
.68693 .59874 Mdot
.68694 .59875 Mdot
.68695 .59875 Mdot
.68696 .59875 Mdot
.68697 .59876 Mdot
.68698 .59876 Mdot
.68699 .59876 Mdot
.687 .59877 Mdot
.68701 .59877 Mdot
.68702 .59877 Mdot
.68703 .59878 Mdot
.68704 .59878 Mdot
.68705 .59878 Mdot
.68706 .59879 Mdot
.68707 .59879 Mdot
.68708 .59879 Mdot
.68709 .59879 Mdot
.6871 .5988 Mdot
.6871 .5988 Mdot
.68711 .5988 Mdot
.68712 .59881 Mdot
.68713 .59881 Mdot
.68714 .59881 Mdot
.68715 .59882 Mdot
.68716 .59882 Mdot
.68717 .59882 Mdot
.68718 .59883 Mdot
.68719 .59883 Mdot
.6872 .59883 Mdot
.68721 .59884 Mdot
.68722 .59884 Mdot
.68723 .59884 Mdot
.68724 .59885 Mdot
.68725 .59885 Mdot
.68726 .59885 Mdot
.68727 .59885 Mdot
.68728 .59886 Mdot
.68729 .59886 Mdot
.6873 .59886 Mdot
.6873 .59887 Mdot
.68731 .59887 Mdot
.68732 .59887 Mdot
.68733 .59888 Mdot
.68734 .59888 Mdot
.68735 .59888 Mdot
.68736 .59889 Mdot
.68737 .59889 Mdot
.68738 .59889 Mdot
.68739 .5989 Mdot
.6874 .5989 Mdot
.68741 .5989 Mdot
.68742 .5989 Mdot
.68743 .59891 Mdot
.68744 .59891 Mdot
.68745 .59891 Mdot
.68746 .59892 Mdot
.68747 .59892 Mdot
.68748 .59892 Mdot
.68749 .59893 Mdot
.6875 .59893 Mdot
.6875 .59893 Mdot
.68751 .59894 Mdot
.68752 .59894 Mdot
.68753 .59894 Mdot
.68754 .59895 Mdot
.68755 .59895 Mdot
.68756 .59895 Mdot
.68757 .59895 Mdot
.68758 .59896 Mdot
.68759 .59896 Mdot
.6876 .59896 Mdot
.68761 .59897 Mdot
.68762 .59897 Mdot
.68763 .59897 Mdot
.68764 .59898 Mdot
.68765 .59898 Mdot
.68766 .59898 Mdot
.68767 .59899 Mdot
.68768 .59899 Mdot
.68769 .59899 Mdot
.6877 .599 Mdot
.6877 .599 Mdot
.68771 .599 Mdot
.68772 .599 Mdot
.68773 .59901 Mdot
.68774 .59901 Mdot
.68775 .59901 Mdot
.68776 .59902 Mdot
.68777 .59902 Mdot
.68778 .59902 Mdot
.68779 .59903 Mdot
.6878 .59903 Mdot
.68781 .59903 Mdot
.68782 .59904 Mdot
.68783 .59904 Mdot
.68784 .59904 Mdot
.68785 .59904 Mdot
.68786 .59905 Mdot
.68787 .59905 Mdot
.68788 .59905 Mdot
.68789 .59906 Mdot
.6879 .59906 Mdot
.6879 .59906 Mdot
.68791 .59907 Mdot
.68792 .59907 Mdot
.68793 .59907 Mdot
.68794 .59908 Mdot
.68795 .59908 Mdot
.68796 .59908 Mdot
.68797 .59908 Mdot
.68798 .59909 Mdot
.68799 .59909 Mdot
.688 .59909 Mdot
.68801 .5991 Mdot
.68802 .5991 Mdot
.68803 .5991 Mdot
.68804 .59911 Mdot
.68805 .59911 Mdot
.68806 .59911 Mdot
.68807 .59912 Mdot
.68808 .59912 Mdot
.68809 .59912 Mdot
.6881 .59912 Mdot
.6881 .59913 Mdot
.68811 .59913 Mdot
.68812 .59913 Mdot
.68813 .59914 Mdot
.68814 .59914 Mdot
.68815 .59914 Mdot
.68816 .59915 Mdot
.68817 .59915 Mdot
.68818 .59915 Mdot
.68819 .59915 Mdot
.6882 .59916 Mdot
.68821 .59916 Mdot
.68822 .59916 Mdot
.68823 .59917 Mdot
.68824 .59917 Mdot
.68825 .59917 Mdot
.68826 .59918 Mdot
.68827 .59918 Mdot
.68828 .59918 Mdot
.68829 .59919 Mdot
.6883 .59919 Mdot
.6883 .59919 Mdot
.68831 .59919 Mdot
.68832 .5992 Mdot
.68833 .5992 Mdot
.68834 .5992 Mdot
.68835 .59921 Mdot
.68836 .59921 Mdot
.68837 .59921 Mdot
.68838 .59922 Mdot
.68839 .59922 Mdot
.6884 .59922 Mdot
.68841 .59922 Mdot
.68842 .59923 Mdot
.68843 .59923 Mdot
.68844 .59923 Mdot
.68845 .59924 Mdot
.68846 .59924 Mdot
.68847 .59924 Mdot
.68848 .59925 Mdot
.68849 .59925 Mdot
.6885 .59925 Mdot
.6885 .59925 Mdot
.68851 .59926 Mdot
.68852 .59926 Mdot
.68853 .59926 Mdot
.68854 .59927 Mdot
.68855 .59927 Mdot
.68856 .59927 Mdot
.68857 .59928 Mdot
.68858 .59928 Mdot
.68859 .59928 Mdot
.6886 .59928 Mdot
.68861 .59929 Mdot
.68862 .59929 Mdot
.68863 .59929 Mdot
.68864 .5993 Mdot
.68865 .5993 Mdot
.68866 .5993 Mdot
.68867 .59931 Mdot
.68868 .59931 Mdot
.68869 .59931 Mdot
.6887 .59931 Mdot
.6887 .59932 Mdot
.68871 .59932 Mdot
.68872 .59932 Mdot
.68873 .59933 Mdot
.68874 .59933 Mdot
.68875 .59933 Mdot
.68876 .59934 Mdot
.68877 .59934 Mdot
.68878 .59934 Mdot
.68879 .59934 Mdot
.6888 .59935 Mdot
.68881 .59935 Mdot
.68882 .59935 Mdot
.68883 .59936 Mdot
.68884 .59936 Mdot
.68885 .59936 Mdot
.68886 .59936 Mdot
.68887 .59937 Mdot
.68888 .59937 Mdot
.68889 .59937 Mdot
.6889 .59938 Mdot
.6889 .59938 Mdot
.68891 .59938 Mdot
.68892 .59939 Mdot
.68893 .59939 Mdot
.68894 .59939 Mdot
.68895 .59939 Mdot
.68896 .5994 Mdot
.68897 .5994 Mdot
.68898 .5994 Mdot
.68899 .59941 Mdot
.689 .59941 Mdot
.68901 .59941 Mdot
.68902 .59942 Mdot
.68903 .59942 Mdot
.68904 .59942 Mdot
.68905 .59942 Mdot
.68906 .59943 Mdot
.68907 .59943 Mdot
.68908 .59943 Mdot
.68909 .59944 Mdot
.6891 .59944 Mdot
.6891 .59944 Mdot
.68911 .59944 Mdot
.68912 .59945 Mdot
.68913 .59945 Mdot
.68914 .59945 Mdot
.68915 .59946 Mdot
.68916 .59946 Mdot
.68917 .59946 Mdot
.68918 .59946 Mdot
.68919 .59947 Mdot
.6892 .59947 Mdot
.68921 .59947 Mdot
.68922 .59948 Mdot
.68923 .59948 Mdot
.68924 .59948 Mdot
.68925 .59949 Mdot
.68926 .59949 Mdot
.68927 .59949 Mdot
.68928 .59949 Mdot
.68929 .5995 Mdot
.6893 .5995 Mdot
.6893 .5995 Mdot
.68931 .59951 Mdot
.68932 .59951 Mdot
.68933 .59951 Mdot
.68934 .59951 Mdot
.68935 .59952 Mdot
.68936 .59952 Mdot
.68937 .59952 Mdot
.68938 .59953 Mdot
.68939 .59953 Mdot
.6894 .59953 Mdot
.68941 .59953 Mdot
.68942 .59954 Mdot
.68943 .59954 Mdot
.68944 .59954 Mdot
.68945 .59955 Mdot
.68946 .59955 Mdot
.68947 .59955 Mdot
.68948 .59956 Mdot
.68949 .59956 Mdot
.6895 .59956 Mdot
.6895 .59956 Mdot
.68951 .59957 Mdot
.68952 .59957 Mdot
.68953 .59957 Mdot
.68954 .59958 Mdot
.68955 .59958 Mdot
.68956 .59958 Mdot
.68957 .59958 Mdot
.68958 .59959 Mdot
.68959 .59959 Mdot
.6896 .59959 Mdot
.68961 .5996 Mdot
.68962 .5996 Mdot
.68963 .5996 Mdot
.68964 .5996 Mdot
.68965 .59961 Mdot
.68966 .59961 Mdot
.68967 .59961 Mdot
.68968 .59962 Mdot
.68969 .59962 Mdot
.6897 .59962 Mdot
.6897 .59962 Mdot
.68971 .59963 Mdot
.68972 .59963 Mdot
.68973 .59963 Mdot
.68974 .59964 Mdot
.68975 .59964 Mdot
.68976 .59964 Mdot
.68977 .59964 Mdot
.68978 .59965 Mdot
.68979 .59965 Mdot
.6898 .59965 Mdot
.68981 .59966 Mdot
.68982 .59966 Mdot
.68983 .59966 Mdot
.68984 .59966 Mdot
.68985 .59967 Mdot
.68986 .59967 Mdot
.68987 .59967 Mdot
.68988 .59968 Mdot
.68989 .59968 Mdot
.6899 .59968 Mdot
.6899 .59968 Mdot
.68991 .59969 Mdot
.68992 .59969 Mdot
.68993 .59969 Mdot
.68994 .5997 Mdot
.68995 .5997 Mdot
.68996 .5997 Mdot
.68997 .5997 Mdot
.68998 .59971 Mdot
.68999 .59971 Mdot
.69 .59971 Mdot
.69001 .59971 Mdot
.69002 .59972 Mdot
.69003 .59972 Mdot
.69004 .59972 Mdot
.69005 .59973 Mdot
.69006 .59973 Mdot
.69007 .59973 Mdot
.69008 .59973 Mdot
.69009 .59974 Mdot
.6901 .59974 Mdot
.6901 .59974 Mdot
.69011 .59975 Mdot
.69012 .59975 Mdot
.69013 .59975 Mdot
.69014 .59975 Mdot
.69015 .59976 Mdot
.69016 .59976 Mdot
.69017 .59976 Mdot
.69018 .59977 Mdot
.69019 .59977 Mdot
.6902 .59977 Mdot
.69021 .59977 Mdot
.69022 .59978 Mdot
.69023 .59978 Mdot
.69024 .59978 Mdot
.69025 .59979 Mdot
.69026 .59979 Mdot
.69027 .59979 Mdot
.69028 .59979 Mdot
.69029 .5998 Mdot
.6903 .5998 Mdot
.6903 .5998 Mdot
.69031 .5998 Mdot
.69032 .59981 Mdot
.69033 .59981 Mdot
.69034 .59981 Mdot
.69035 .59982 Mdot
.69036 .59982 Mdot
.69037 .59982 Mdot
.69038 .59982 Mdot
.69039 .59983 Mdot
.6904 .59983 Mdot
.69041 .59983 Mdot
.69042 .59984 Mdot
.69043 .59984 Mdot
.69044 .59984 Mdot
.69045 .59984 Mdot
.69046 .59985 Mdot
.69047 .59985 Mdot
.69048 .59985 Mdot
.69049 .59985 Mdot
.6905 .59986 Mdot
.6905 .59986 Mdot
.69051 .59986 Mdot
.69052 .59987 Mdot
.69053 .59987 Mdot
.69054 .59987 Mdot
.69055 .59987 Mdot
.69056 .59988 Mdot
.69057 .59988 Mdot
.69058 .59988 Mdot
.69059 .59989 Mdot
.6906 .59989 Mdot
.69061 .59989 Mdot
.69062 .59989 Mdot
.69063 .5999 Mdot
.69064 .5999 Mdot
.69065 .5999 Mdot
.69066 .5999 Mdot
.69067 .59991 Mdot
.69068 .59991 Mdot
.69069 .59991 Mdot
.6907 .59992 Mdot
.6907 .59992 Mdot
.69071 .59992 Mdot
.69072 .59992 Mdot
.69073 .59993 Mdot
.69074 .59993 Mdot
.69075 .59993 Mdot
.69076 .59993 Mdot
.69077 .59994 Mdot
.69078 .59994 Mdot
.69079 .59994 Mdot
.6908 .59995 Mdot
.69081 .59995 Mdot
.69082 .59995 Mdot
.69083 .59995 Mdot
.69084 .59996 Mdot
.69085 .59996 Mdot
.69086 .59996 Mdot
.69087 .59996 Mdot
.69088 .59997 Mdot
.69089 .59997 Mdot
.6909 .59997 Mdot
.6909 .59998 Mdot
.69091 .59998 Mdot
.69092 .59998 Mdot
.69093 .59998 Mdot
.69094 .59999 Mdot
.69095 .59999 Mdot
.69096 .59999 Mdot
.69097 .59999 Mdot
.69098 .6 Mdot
.69099 .6 Mdot
.691 .6 Mdot
.69101 .60001 Mdot
.69102 .60001 Mdot
.69103 .60001 Mdot
.69104 .60001 Mdot
.69105 .60002 Mdot
.69106 .60002 Mdot
.69107 .60002 Mdot
.69108 .60002 Mdot
.69109 .60003 Mdot
.6911 .60003 Mdot
.6911 .60003 Mdot
.69111 .60004 Mdot
.69112 .60004 Mdot
.69113 .60004 Mdot
.69114 .60004 Mdot
.69115 .60005 Mdot
.69116 .60005 Mdot
.69117 .60005 Mdot
.69118 .60005 Mdot
.69119 .60006 Mdot
.6912 .60006 Mdot
.69121 .60006 Mdot
.69122 .60006 Mdot
.69123 .60007 Mdot
.69124 .60007 Mdot
.69125 .60007 Mdot
.69126 .60008 Mdot
.69127 .60008 Mdot
.69128 .60008 Mdot
.69129 .60008 Mdot
.6913 .60009 Mdot
.6913 .60009 Mdot
.69131 .60009 Mdot
.69132 .60009 Mdot
.69133 .6001 Mdot
.69134 .6001 Mdot
.69135 .6001 Mdot
.69136 .6001 Mdot
.69137 .60011 Mdot
.69138 .60011 Mdot
.69139 .60011 Mdot
.6914 .60012 Mdot
.69141 .60012 Mdot
.69142 .60012 Mdot
.69143 .60012 Mdot
.69144 .60013 Mdot
.69145 .60013 Mdot
.69146 .60013 Mdot
.69147 .60013 Mdot
.69148 .60014 Mdot
.69149 .60014 Mdot
.6915 .60014 Mdot
.6915 .60014 Mdot
.69151 .60015 Mdot
.69152 .60015 Mdot
.69153 .60015 Mdot
.69154 .60016 Mdot
.69155 .60016 Mdot
.69156 .60016 Mdot
.69157 .60016 Mdot
.69158 .60017 Mdot
.69159 .60017 Mdot
.6916 .60017 Mdot
.69161 .60017 Mdot
.69162 .60018 Mdot
.69163 .60018 Mdot
.69164 .60018 Mdot
.69165 .60018 Mdot
.69166 .60019 Mdot
.69167 .60019 Mdot
.69168 .60019 Mdot
.69169 .60019 Mdot
.6917 .6002 Mdot
.6917 .6002 Mdot
.69171 .6002 Mdot
.69172 .60021 Mdot
.69173 .60021 Mdot
.69174 .60021 Mdot
.69175 .60021 Mdot
.69176 .60022 Mdot
.69177 .60022 Mdot
.69178 .60022 Mdot
.69179 .60022 Mdot
.6918 .60023 Mdot
.69181 .60023 Mdot
.69182 .60023 Mdot
.69183 .60023 Mdot
.69184 .60024 Mdot
.69185 .60024 Mdot
.69186 .60024 Mdot
.69187 .60024 Mdot
.69188 .60025 Mdot
.69189 .60025 Mdot
.6919 .60025 Mdot
.6919 .60025 Mdot
.69191 .60026 Mdot
.69192 .60026 Mdot
.69193 .60026 Mdot
.69194 .60027 Mdot
.69195 .60027 Mdot
.69196 .60027 Mdot
.69197 .60027 Mdot
.69198 .60028 Mdot
.69199 .60028 Mdot
.692 .60028 Mdot
.69201 .60028 Mdot
.69202 .60029 Mdot
.69203 .60029 Mdot
.69204 .60029 Mdot
.69205 .60029 Mdot
.69206 .6003 Mdot
.69207 .6003 Mdot
.69208 .6003 Mdot
.69209 .6003 Mdot
.6921 .60031 Mdot
.6921 .60031 Mdot
.69211 .60031 Mdot
.69212 .60031 Mdot
.69213 .60032 Mdot
.69214 .60032 Mdot
.69215 .60032 Mdot
.69216 .60032 Mdot
.69217 .60033 Mdot
.69218 .60033 Mdot
.69219 .60033 Mdot
.6922 .60034 Mdot
.69221 .60034 Mdot
.69222 .60034 Mdot
.69223 .60034 Mdot
.69224 .60035 Mdot
.69225 .60035 Mdot
.69226 .60035 Mdot
.69227 .60035 Mdot
.69228 .60036 Mdot
.69229 .60036 Mdot
.6923 .60036 Mdot
.6923 .60036 Mdot
.69231 .60037 Mdot
.69232 .60037 Mdot
.69233 .60037 Mdot
.69234 .60037 Mdot
.69235 .60038 Mdot
.69236 .60038 Mdot
.69237 .60038 Mdot
.69238 .60038 Mdot
.69239 .60039 Mdot
.6924 .60039 Mdot
.69241 .60039 Mdot
.69242 .60039 Mdot
.69243 .6004 Mdot
.69244 .6004 Mdot
.69245 .6004 Mdot
.69246 .6004 Mdot
.69247 .60041 Mdot
.69248 .60041 Mdot
.69249 .60041 Mdot
.6925 .60041 Mdot
.6925 .60042 Mdot
.69251 .60042 Mdot
.69252 .60042 Mdot
.69253 .60042 Mdot
.69254 .60043 Mdot
.69255 .60043 Mdot
.69256 .60043 Mdot
.69257 .60043 Mdot
.69258 .60044 Mdot
.69259 .60044 Mdot
.6926 .60044 Mdot
.69261 .60044 Mdot
.69262 .60045 Mdot
.69263 .60045 Mdot
.69264 .60045 Mdot
.69265 .60045 Mdot
.69266 .60046 Mdot
.69267 .60046 Mdot
.69268 .60046 Mdot
.69269 .60046 Mdot
.6927 .60047 Mdot
.6927 .60047 Mdot
.69271 .60047 Mdot
.69272 .60047 Mdot
.69273 .60048 Mdot
.69274 .60048 Mdot
.69275 .60048 Mdot
.69276 .60048 Mdot
.69277 .60049 Mdot
.69278 .60049 Mdot
.69279 .60049 Mdot
.6928 .60049 Mdot
.69281 .6005 Mdot
.69282 .6005 Mdot
.69283 .6005 Mdot
.69284 .6005 Mdot
.69285 .60051 Mdot
.69286 .60051 Mdot
.69287 .60051 Mdot
.69288 .60051 Mdot
.69289 .60052 Mdot
.6929 .60052 Mdot
.6929 .60052 Mdot
.69291 .60052 Mdot
.69292 .60053 Mdot
.69293 .60053 Mdot
.69294 .60053 Mdot
.69295 .60053 Mdot
.69296 .60054 Mdot
.69297 .60054 Mdot
.69298 .60054 Mdot
.69299 .60054 Mdot
.693 .60055 Mdot
.69301 .60055 Mdot
.69302 .60055 Mdot
.69303 .60055 Mdot
.69304 .60056 Mdot
.69305 .60056 Mdot
.69306 .60056 Mdot
.69307 .60056 Mdot
.69308 .60057 Mdot
.69309 .60057 Mdot
.6931 .60057 Mdot
.6931 .60057 Mdot
.69311 .60058 Mdot
.69312 .60058 Mdot
.69313 .60058 Mdot
.69314 .60058 Mdot
.69315 .60059 Mdot
.69316 .60059 Mdot
.69317 .60059 Mdot
.69318 .60059 Mdot
.69319 .6006 Mdot
.6932 .6006 Mdot
.69321 .6006 Mdot
.69322 .6006 Mdot
.69323 .60061 Mdot
.69324 .60061 Mdot
.69325 .60061 Mdot
.69326 .60061 Mdot
.69327 .60062 Mdot
.69328 .60062 Mdot
.69329 .60062 Mdot
.6933 .60062 Mdot
.6933 .60063 Mdot
.69331 .60063 Mdot
.69332 .60063 Mdot
.69333 .60063 Mdot
.69334 .60064 Mdot
.69335 .60064 Mdot
.69336 .60064 Mdot
.69337 .60064 Mdot
.69338 .60064 Mdot
.69339 .60065 Mdot
.6934 .60065 Mdot
.69341 .60065 Mdot
.69342 .60065 Mdot
.69343 .60066 Mdot
.69344 .60066 Mdot
.69345 .60066 Mdot
.69346 .60066 Mdot
.69347 .60067 Mdot
.69348 .60067 Mdot
.69349 .60067 Mdot
.6935 .60067 Mdot
.6935 .60068 Mdot
.69351 .60068 Mdot
.69352 .60068 Mdot
.69353 .60068 Mdot
.69354 .60069 Mdot
.69355 .60069 Mdot
.69356 .60069 Mdot
.69357 .60069 Mdot
.69358 .6007 Mdot
.69359 .6007 Mdot
.6936 .6007 Mdot
.69361 .6007 Mdot
.69362 .60071 Mdot
.69363 .60071 Mdot
.69364 .60071 Mdot
.69365 .60071 Mdot
.69366 .60071 Mdot
.69367 .60072 Mdot
.69368 .60072 Mdot
.69369 .60072 Mdot
.6937 .60072 Mdot
.6937 .60073 Mdot
.69371 .60073 Mdot
.69372 .60073 Mdot
.69373 .60073 Mdot
.69374 .60074 Mdot
.69375 .60074 Mdot
.69376 .60074 Mdot
.69377 .60074 Mdot
.69378 .60075 Mdot
.69379 .60075 Mdot
.6938 .60075 Mdot
.69381 .60075 Mdot
.69382 .60076 Mdot
.69383 .60076 Mdot
.69384 .60076 Mdot
.69385 .60076 Mdot
.69386 .60076 Mdot
.69387 .60077 Mdot
.69388 .60077 Mdot
.69389 .60077 Mdot
.6939 .60077 Mdot
.6939 .60078 Mdot
.69391 .60078 Mdot
.69392 .60078 Mdot
.69393 .60078 Mdot
.69394 .60079 Mdot
.69395 .60079 Mdot
.69396 .60079 Mdot
.69397 .60079 Mdot
.69398 .6008 Mdot
.69399 .6008 Mdot
.694 .6008 Mdot
.69401 .6008 Mdot
.69402 .60081 Mdot
.69403 .60081 Mdot
.69404 .60081 Mdot
.69405 .60081 Mdot
.69406 .60081 Mdot
.69407 .60082 Mdot
.69408 .60082 Mdot
.69409 .60082 Mdot
.6941 .60082 Mdot
.6941 .60083 Mdot
.69411 .60083 Mdot
.69412 .60083 Mdot
.69413 .60083 Mdot
.69414 .60084 Mdot
.69415 .60084 Mdot
.69416 .60084 Mdot
.69417 .60084 Mdot
.69418 .60084 Mdot
.69419 .60085 Mdot
.6942 .60085 Mdot
.69421 .60085 Mdot
.69422 .60085 Mdot
.69423 .60086 Mdot
.69424 .60086 Mdot
.69425 .60086 Mdot
.69426 .60086 Mdot
.69427 .60087 Mdot
.69428 .60087 Mdot
.69429 .60087 Mdot
.6943 .60087 Mdot
.6943 .60088 Mdot
.69431 .60088 Mdot
.69432 .60088 Mdot
.69433 .60088 Mdot
.69434 .60088 Mdot
.69435 .60089 Mdot
.69436 .60089 Mdot
.69437 .60089 Mdot
.69438 .60089 Mdot
.69439 .6009 Mdot
.6944 .6009 Mdot
.69441 .6009 Mdot
.69442 .6009 Mdot
.69443 .60091 Mdot
.69444 .60091 Mdot
.69445 .60091 Mdot
.69446 .60091 Mdot
.69447 .60091 Mdot
.69448 .60092 Mdot
.69449 .60092 Mdot
.6945 .60092 Mdot
.6945 .60092 Mdot
.69451 .60093 Mdot
.69452 .60093 Mdot
.69453 .60093 Mdot
.69454 .60093 Mdot
.69455 .60094 Mdot
.69456 .60094 Mdot
.69457 .60094 Mdot
.69458 .60094 Mdot
.69459 .60094 Mdot
.6946 .60095 Mdot
.69461 .60095 Mdot
.69462 .60095 Mdot
.69463 .60095 Mdot
.69464 .60096 Mdot
.69465 .60096 Mdot
.69466 .60096 Mdot
.69467 .60096 Mdot
.69468 .60096 Mdot
.69469 .60097 Mdot
.6947 .60097 Mdot
.6947 .60097 Mdot
.69471 .60097 Mdot
.69472 .60098 Mdot
.69473 .60098 Mdot
.69474 .60098 Mdot
.69475 .60098 Mdot
.69476 .60099 Mdot
.69477 .60099 Mdot
.69478 .60099 Mdot
.69479 .60099 Mdot
.6948 .60099 Mdot
.69481 .601 Mdot
.69482 .601 Mdot
.69483 .601 Mdot
.69484 .601 Mdot
.69485 .60101 Mdot
.69486 .60101 Mdot
.69487 .60101 Mdot
.69488 .60101 Mdot
.69489 .60101 Mdot
.6949 .60102 Mdot
.6949 .60102 Mdot
.69491 .60102 Mdot
.69492 .60102 Mdot
.69493 .60103 Mdot
.69494 .60103 Mdot
.69495 .60103 Mdot
.69496 .60103 Mdot
.69497 .60103 Mdot
.69498 .60104 Mdot
.69499 .60104 Mdot
.695 .60104 Mdot
.69501 .60104 Mdot
.69502 .60105 Mdot
.69503 .60105 Mdot
.69504 .60105 Mdot
.69505 .60105 Mdot
.69506 .60106 Mdot
.69507 .60106 Mdot
.69508 .60106 Mdot
.69509 .60106 Mdot
.6951 .60106 Mdot
.6951 .60107 Mdot
.69511 .60107 Mdot
.69512 .60107 Mdot
.69513 .60107 Mdot
.69514 .60108 Mdot
.69515 .60108 Mdot
.69516 .60108 Mdot
.69517 .60108 Mdot
.69518 .60108 Mdot
.69519 .60109 Mdot
.6952 .60109 Mdot
.69521 .60109 Mdot
.69522 .60109 Mdot
.69523 .6011 Mdot
.69524 .6011 Mdot
.69525 .6011 Mdot
.69526 .6011 Mdot
.69527 .6011 Mdot
.69528 .60111 Mdot
.69529 .60111 Mdot
.6953 .60111 Mdot
.6953 .60111 Mdot
.69531 .60111 Mdot
.69532 .60112 Mdot
.69533 .60112 Mdot
.69534 .60112 Mdot
.69535 .60112 Mdot
.69536 .60113 Mdot
.69537 .60113 Mdot
.69538 .60113 Mdot
.69539 .60113 Mdot
.6954 .60113 Mdot
.69541 .60114 Mdot
.69542 .60114 Mdot
.69543 .60114 Mdot
.69544 .60114 Mdot
.69545 .60115 Mdot
.69546 .60115 Mdot
.69547 .60115 Mdot
.69548 .60115 Mdot
.69549 .60115 Mdot
.6955 .60116 Mdot
.6955 .60116 Mdot
.69551 .60116 Mdot
.69552 .60116 Mdot
.69553 .60117 Mdot
.69554 .60117 Mdot
.69555 .60117 Mdot
.69556 .60117 Mdot
.69557 .60117 Mdot
.69558 .60118 Mdot
.69559 .60118 Mdot
.6956 .60118 Mdot
.69561 .60118 Mdot
.69562 .60118 Mdot
.69563 .60119 Mdot
.69564 .60119 Mdot
.69565 .60119 Mdot
.69566 .60119 Mdot
.69567 .6012 Mdot
.69568 .6012 Mdot
.69569 .6012 Mdot
.6957 .6012 Mdot
.6957 .6012 Mdot
.69571 .60121 Mdot
.69572 .60121 Mdot
.69573 .60121 Mdot
.69574 .60121 Mdot
.69575 .60122 Mdot
.69576 .60122 Mdot
.69577 .60122 Mdot
.69578 .60122 Mdot
.69579 .60122 Mdot
.6958 .60123 Mdot
.69581 .60123 Mdot
.69582 .60123 Mdot
.69583 .60123 Mdot
.69584 .60123 Mdot
.69585 .60124 Mdot
.69586 .60124 Mdot
.69587 .60124 Mdot
.69588 .60124 Mdot
.69589 .60125 Mdot
.6959 .60125 Mdot
.6959 .60125 Mdot
.69591 .60125 Mdot
.69592 .60125 Mdot
.69593 .60126 Mdot
.69594 .60126 Mdot
.69595 .60126 Mdot
.69596 .60126 Mdot
.69597 .60126 Mdot
.69598 .60127 Mdot
.69599 .60127 Mdot
.696 .60127 Mdot
.69601 .60127 Mdot
.69602 .60127 Mdot
.69603 .60128 Mdot
.69604 .60128 Mdot
.69605 .60128 Mdot
.69606 .60128 Mdot
.69607 .60129 Mdot
.69608 .60129 Mdot
.69609 .60129 Mdot
.6961 .60129 Mdot
.6961 .60129 Mdot
.69611 .6013 Mdot
.69612 .6013 Mdot
.69613 .6013 Mdot
.69614 .6013 Mdot
.69615 .6013 Mdot
.69616 .60131 Mdot
.69617 .60131 Mdot
.69618 .60131 Mdot
.69619 .60131 Mdot
.6962 .60131 Mdot
.69621 .60132 Mdot
.69622 .60132 Mdot
.69623 .60132 Mdot
.69624 .60132 Mdot
.69625 .60133 Mdot
.69626 .60133 Mdot
.69627 .60133 Mdot
.69628 .60133 Mdot
.69629 .60133 Mdot
.6963 .60134 Mdot
.6963 .60134 Mdot
.69631 .60134 Mdot
.69632 .60134 Mdot
.69633 .60134 Mdot
.69634 .60135 Mdot
.69635 .60135 Mdot
.69636 .60135 Mdot
.69637 .60135 Mdot
.69638 .60135 Mdot
.69639 .60136 Mdot
.6964 .60136 Mdot
.69641 .60136 Mdot
.69642 .60136 Mdot
.69643 .60137 Mdot
.69644 .60137 Mdot
.69645 .60137 Mdot
.69646 .60137 Mdot
.69647 .60137 Mdot
.69648 .60138 Mdot
.69649 .60138 Mdot
.6965 .60138 Mdot
.6965 .60138 Mdot
.69651 .60138 Mdot
.69652 .60139 Mdot
.69653 .60139 Mdot
.69654 .60139 Mdot
.69655 .60139 Mdot
.69656 .60139 Mdot
.69657 .6014 Mdot
.69658 .6014 Mdot
.69659 .6014 Mdot
.6966 .6014 Mdot
.69661 .6014 Mdot
.69662 .60141 Mdot
.69663 .60141 Mdot
.69664 .60141 Mdot
.69665 .60141 Mdot
.69666 .60141 Mdot
.69667 .60142 Mdot
.69668 .60142 Mdot
.69669 .60142 Mdot
.6967 .60142 Mdot
.6967 .60142 Mdot
.69671 .60143 Mdot
.69672 .60143 Mdot
.69673 .60143 Mdot
.69674 .60143 Mdot
.69675 .60143 Mdot
.69676 .60144 Mdot
.69677 .60144 Mdot
.69678 .60144 Mdot
.69679 .60144 Mdot
.6968 .60145 Mdot
.69681 .60145 Mdot
.69682 .60145 Mdot
.69683 .60145 Mdot
.69684 .60145 Mdot
.69685 .60146 Mdot
.69686 .60146 Mdot
.69687 .60146 Mdot
.69688 .60146 Mdot
.69689 .60146 Mdot
.6969 .60147 Mdot
.6969 .60147 Mdot
.69691 .60147 Mdot
.69692 .60147 Mdot
.69693 .60147 Mdot
.69694 .60148 Mdot
.69695 .60148 Mdot
.69696 .60148 Mdot
.69697 .60148 Mdot
.69698 .60148 Mdot
.69699 .60149 Mdot
.697 .60149 Mdot
.69701 .60149 Mdot
.69702 .60149 Mdot
.69703 .60149 Mdot
.69704 .6015 Mdot
.69705 .6015 Mdot
.69706 .6015 Mdot
.69707 .6015 Mdot
.69708 .6015 Mdot
.69709 .60151 Mdot
.6971 .60151 Mdot
.6971 .60151 Mdot
.69711 .60151 Mdot
.69712 .60151 Mdot
.69713 .60152 Mdot
.69714 .60152 Mdot
.69715 .60152 Mdot
.69716 .60152 Mdot
.69717 .60152 Mdot
.69718 .60153 Mdot
.69719 .60153 Mdot
.6972 .60153 Mdot
.69721 .60153 Mdot
.69722 .60153 Mdot
.69723 .60154 Mdot
.69724 .60154 Mdot
.69725 .60154 Mdot
.69726 .60154 Mdot
.69727 .60154 Mdot
.69728 .60155 Mdot
.69729 .60155 Mdot
.6973 .60155 Mdot
.6973 .60155 Mdot
.69731 .60155 Mdot
.69732 .60155 Mdot
.69733 .60156 Mdot
.69734 .60156 Mdot
.69735 .60156 Mdot
.69736 .60156 Mdot
.69737 .60156 Mdot
.69738 .60157 Mdot
.69739 .60157 Mdot
.6974 .60157 Mdot
.69741 .60157 Mdot
.69742 .60157 Mdot
.69743 .60158 Mdot
.69744 .60158 Mdot
.69745 .60158 Mdot
.69746 .60158 Mdot
.69747 .60158 Mdot
.69748 .60159 Mdot
.69749 .60159 Mdot
.6975 .60159 Mdot
.6975 .60159 Mdot
.69751 .60159 Mdot
.69752 .6016 Mdot
.69753 .6016 Mdot
.69754 .6016 Mdot
.69755 .6016 Mdot
.69756 .6016 Mdot
.69757 .60161 Mdot
.69758 .60161 Mdot
.69759 .60161 Mdot
.6976 .60161 Mdot
.69761 .60161 Mdot
.69762 .60162 Mdot
.69763 .60162 Mdot
.69764 .60162 Mdot
.69765 .60162 Mdot
.69766 .60162 Mdot
.69767 .60163 Mdot
.69768 .60163 Mdot
.69769 .60163 Mdot
.6977 .60163 Mdot
.6977 .60163 Mdot
.69771 .60163 Mdot
.69772 .60164 Mdot
.69773 .60164 Mdot
.69774 .60164 Mdot
.69775 .60164 Mdot
.69776 .60164 Mdot
.69777 .60165 Mdot
.69778 .60165 Mdot
.69779 .60165 Mdot
.6978 .60165 Mdot
.69781 .60165 Mdot
.69782 .60166 Mdot
.69783 .60166 Mdot
.69784 .60166 Mdot
.69785 .60166 Mdot
.69786 .60166 Mdot
.69787 .60167 Mdot
.69788 .60167 Mdot
.69789 .60167 Mdot
.6979 .60167 Mdot
.6979 .60167 Mdot
.69791 .60167 Mdot
.69792 .60168 Mdot
.69793 .60168 Mdot
.69794 .60168 Mdot
.69795 .60168 Mdot
.69796 .60168 Mdot
.69797 .60169 Mdot
.69798 .60169 Mdot
.69799 .60169 Mdot
.698 .60169 Mdot
.69801 .60169 Mdot
.69802 .6017 Mdot
.69803 .6017 Mdot
.69804 .6017 Mdot
.69805 .6017 Mdot
.69806 .6017 Mdot
.69807 .60171 Mdot
.69808 .60171 Mdot
.69809 .60171 Mdot
.6981 .60171 Mdot
.6981 .60171 Mdot
.69811 .60171 Mdot
.69812 .60172 Mdot
.69813 .60172 Mdot
.69814 .60172 Mdot
.69815 .60172 Mdot
.69816 .60172 Mdot
.69817 .60173 Mdot
.69818 .60173 Mdot
.69819 .60173 Mdot
.6982 .60173 Mdot
.69821 .60173 Mdot
.69822 .60174 Mdot
.69823 .60174 Mdot
.69824 .60174 Mdot
.69825 .60174 Mdot
.69826 .60174 Mdot
.69827 .60174 Mdot
.69828 .60175 Mdot
.69829 .60175 Mdot
.6983 .60175 Mdot
.6983 .60175 Mdot
.69831 .60175 Mdot
.69832 .60176 Mdot
.69833 .60176 Mdot
.69834 .60176 Mdot
.69835 .60176 Mdot
.69836 .60176 Mdot
.69837 .60176 Mdot
.69838 .60177 Mdot
.69839 .60177 Mdot
.6984 .60177 Mdot
.69841 .60177 Mdot
.69842 .60177 Mdot
.69843 .60178 Mdot
.69844 .60178 Mdot
.69845 .60178 Mdot
.69846 .60178 Mdot
.69847 .60178 Mdot
.69848 .60178 Mdot
.69849 .60179 Mdot
.6985 .60179 Mdot
.6985 .60179 Mdot
.69851 .60179 Mdot
.69852 .60179 Mdot
.69853 .6018 Mdot
.69854 .6018 Mdot
.69855 .6018 Mdot
.69856 .6018 Mdot
.69857 .6018 Mdot
.69858 .60181 Mdot
.69859 .60181 Mdot
.6986 .60181 Mdot
.69861 .60181 Mdot
.69862 .60181 Mdot
.69863 .60181 Mdot
.69864 .60182 Mdot
.69865 .60182 Mdot
.69866 .60182 Mdot
.69867 .60182 Mdot
.69868 .60182 Mdot
.69869 .60183 Mdot
.6987 .60183 Mdot
.6987 .60183 Mdot
.69871 .60183 Mdot
.69872 .60183 Mdot
.69873 .60183 Mdot
.69874 .60184 Mdot
.69875 .60184 Mdot
.69876 .60184 Mdot
.69877 .60184 Mdot
.69878 .60184 Mdot
.69879 .60184 Mdot
.6988 .60185 Mdot
.69881 .60185 Mdot
.69882 .60185 Mdot
.69883 .60185 Mdot
.69884 .60185 Mdot
.69885 .60186 Mdot
.69886 .60186 Mdot
.69887 .60186 Mdot
.69888 .60186 Mdot
.69889 .60186 Mdot
.6989 .60186 Mdot
.6989 .60187 Mdot
.69891 .60187 Mdot
.69892 .60187 Mdot
.69893 .60187 Mdot
.69894 .60187 Mdot
.69895 .60188 Mdot
.69896 .60188 Mdot
.69897 .60188 Mdot
.69898 .60188 Mdot
.69899 .60188 Mdot
.699 .60188 Mdot
.69901 .60189 Mdot
.69902 .60189 Mdot
.69903 .60189 Mdot
.69904 .60189 Mdot
.69905 .60189 Mdot
.69906 .60189 Mdot
.69907 .6019 Mdot
.69908 .6019 Mdot
.69909 .6019 Mdot
.6991 .6019 Mdot
.6991 .6019 Mdot
.69911 .60191 Mdot
.69912 .60191 Mdot
.69913 .60191 Mdot
.69914 .60191 Mdot
.69915 .60191 Mdot
.69916 .60191 Mdot
.69917 .60192 Mdot
.69918 .60192 Mdot
.69919 .60192 Mdot
.6992 .60192 Mdot
.69921 .60192 Mdot
.69922 .60192 Mdot
.69923 .60193 Mdot
.69924 .60193 Mdot
.69925 .60193 Mdot
.69926 .60193 Mdot
.69927 .60193 Mdot
.69928 .60194 Mdot
.69929 .60194 Mdot
.6993 .60194 Mdot
.6993 .60194 Mdot
.69931 .60194 Mdot
.69932 .60194 Mdot
.69933 .60195 Mdot
.69934 .60195 Mdot
.69935 .60195 Mdot
.69936 .60195 Mdot
.69937 .60195 Mdot
.69938 .60195 Mdot
.69939 .60196 Mdot
.6994 .60196 Mdot
.69941 .60196 Mdot
.69942 .60196 Mdot
.69943 .60196 Mdot
.69944 .60196 Mdot
.69945 .60197 Mdot
.69946 .60197 Mdot
.69947 .60197 Mdot
.69948 .60197 Mdot
.69949 .60197 Mdot
.6995 .60197 Mdot
.6995 .60198 Mdot
.69951 .60198 Mdot
.69952 .60198 Mdot
.69953 .60198 Mdot
.69954 .60198 Mdot
.69955 .60199 Mdot
.69956 .60199 Mdot
.69957 .60199 Mdot
.69958 .60199 Mdot
.69959 .60199 Mdot
.6996 .60199 Mdot
.69961 .602 Mdot
.69962 .602 Mdot
.69963 .602 Mdot
.69964 .602 Mdot
.69965 .602 Mdot
.69966 .602 Mdot
.69967 .60201 Mdot
.69968 .60201 Mdot
.69969 .60201 Mdot
.6997 .60201 Mdot
.6997 .60201 Mdot
.69971 .60201 Mdot
.69972 .60202 Mdot
.69973 .60202 Mdot
.69974 .60202 Mdot
.69975 .60202 Mdot
.69976 .60202 Mdot
.69977 .60202 Mdot
.69978 .60203 Mdot
.69979 .60203 Mdot
.6998 .60203 Mdot
.69981 .60203 Mdot
.69982 .60203 Mdot
.69983 .60203 Mdot
.69984 .60204 Mdot
.69985 .60204 Mdot
.69986 .60204 Mdot
.69987 .60204 Mdot
.69988 .60204 Mdot
.69989 .60204 Mdot
.6999 .60205 Mdot
.6999 .60205 Mdot
.69991 .60205 Mdot
.69992 .60205 Mdot
.69993 .60205 Mdot
.69994 .60205 Mdot
.69995 .60206 Mdot
.69996 .60206 Mdot
.69997 .60206 Mdot
.69998 .60206 Mdot
.69999 .60206 Mdot
.7 .60206 Mdot
.70001 .60207 Mdot
.70002 .60207 Mdot
.70003 .60207 Mdot
.70004 .60207 Mdot
.70005 .60207 Mdot
.70006 .60207 Mdot
.70007 .60208 Mdot
.70008 .60208 Mdot
.70009 .60208 Mdot
.7001 .60208 Mdot
.7001 .60208 Mdot
.70011 .60208 Mdot
.70012 .60209 Mdot
.70013 .60209 Mdot
.70014 .60209 Mdot
.70015 .60209 Mdot
.70016 .60209 Mdot
.70017 .60209 Mdot
.70018 .6021 Mdot
.70019 .6021 Mdot
.7002 .6021 Mdot
.70021 .6021 Mdot
.70022 .6021 Mdot
.70023 .6021 Mdot
.70024 .60211 Mdot
.70025 .60211 Mdot
.70026 .60211 Mdot
.70027 .60211 Mdot
.70028 .60211 Mdot
.70029 .60211 Mdot
.7003 .60212 Mdot
.7003 .60212 Mdot
.70031 .60212 Mdot
.70032 .60212 Mdot
.70033 .60212 Mdot
.70034 .60212 Mdot
.70035 .60212 Mdot
.70036 .60213 Mdot
.70037 .60213 Mdot
.70038 .60213 Mdot
.70039 .60213 Mdot
.7004 .60213 Mdot
.70041 .60213 Mdot
.70042 .60214 Mdot
.70043 .60214 Mdot
.70044 .60214 Mdot
.70045 .60214 Mdot
.70046 .60214 Mdot
.70047 .60214 Mdot
.70048 .60215 Mdot
.70049 .60215 Mdot
.7005 .60215 Mdot
.7005 .60215 Mdot
.70051 .60215 Mdot
.70052 .60215 Mdot
.70053 .60216 Mdot
.70054 .60216 Mdot
.70055 .60216 Mdot
.70056 .60216 Mdot
.70057 .60216 Mdot
.70058 .60216 Mdot
.70059 .60216 Mdot
.7006 .60217 Mdot
.70061 .60217 Mdot
.70062 .60217 Mdot
.70063 .60217 Mdot
.70064 .60217 Mdot
.70065 .60217 Mdot
.70066 .60218 Mdot
.70067 .60218 Mdot
.70068 .60218 Mdot
.70069 .60218 Mdot
.7007 .60218 Mdot
.7007 .60218 Mdot
.70071 .60219 Mdot
.70072 .60219 Mdot
.70073 .60219 Mdot
.70074 .60219 Mdot
.70075 .60219 Mdot
.70076 .60219 Mdot
.70077 .60219 Mdot
.70078 .6022 Mdot
.70079 .6022 Mdot
.7008 .6022 Mdot
.70081 .6022 Mdot
.70082 .6022 Mdot
.70083 .6022 Mdot
.70084 .60221 Mdot
.70085 .60221 Mdot
.70086 .60221 Mdot
.70087 .60221 Mdot
.70088 .60221 Mdot
.70089 .60221 Mdot
.7009 .60222 Mdot
.7009 .60222 Mdot
.70091 .60222 Mdot
.70092 .60222 Mdot
.70093 .60222 Mdot
.70094 .60222 Mdot
.70095 .60222 Mdot
.70096 .60223 Mdot
.70097 .60223 Mdot
.70098 .60223 Mdot
.70099 .60223 Mdot
.701 .60223 Mdot
.70101 .60223 Mdot
.70102 .60224 Mdot
.70103 .60224 Mdot
.70104 .60224 Mdot
.70105 .60224 Mdot
.70106 .60224 Mdot
.70107 .60224 Mdot
.70108 .60224 Mdot
.70109 .60225 Mdot
.7011 .60225 Mdot
.7011 .60225 Mdot
.70111 .60225 Mdot
.70112 .60225 Mdot
.70113 .60225 Mdot
.70114 .60226 Mdot
.70115 .60226 Mdot
.70116 .60226 Mdot
.70117 .60226 Mdot
.70118 .60226 Mdot
.70119 .60226 Mdot
.7012 .60226 Mdot
.70121 .60227 Mdot
.70122 .60227 Mdot
.70123 .60227 Mdot
.70124 .60227 Mdot
.70125 .60227 Mdot
.70126 .60227 Mdot
.70127 .60227 Mdot
.70128 .60228 Mdot
.70129 .60228 Mdot
.7013 .60228 Mdot
.7013 .60228 Mdot
.70131 .60228 Mdot
.70132 .60228 Mdot
.70133 .60229 Mdot
.70134 .60229 Mdot
.70135 .60229 Mdot
.70136 .60229 Mdot
.70137 .60229 Mdot
.70138 .60229 Mdot
.70139 .60229 Mdot
.7014 .6023 Mdot
.70141 .6023 Mdot
.70142 .6023 Mdot
.70143 .6023 Mdot
.70144 .6023 Mdot
.70145 .6023 Mdot
.70146 .6023 Mdot
.70147 .60231 Mdot
.70148 .60231 Mdot
.70149 .60231 Mdot
.7015 .60231 Mdot
.7015 .60231 Mdot
.70151 .60231 Mdot
.70152 .60232 Mdot
.70153 .60232 Mdot
.70154 .60232 Mdot
.70155 .60232 Mdot
.70156 .60232 Mdot
.70157 .60232 Mdot
.70158 .60232 Mdot
.70159 .60233 Mdot
.7016 .60233 Mdot
.70161 .60233 Mdot
.70162 .60233 Mdot
.70163 .60233 Mdot
.70164 .60233 Mdot
.70165 .60233 Mdot
.70166 .60234 Mdot
.70167 .60234 Mdot
.70168 .60234 Mdot
.70169 .60234 Mdot
.7017 .60234 Mdot
.7017 .60234 Mdot
.70171 .60234 Mdot
.70172 .60235 Mdot
.70173 .60235 Mdot
.70174 .60235 Mdot
.70175 .60235 Mdot
.70176 .60235 Mdot
.70177 .60235 Mdot
.70178 .60235 Mdot
.70179 .60236 Mdot
.7018 .60236 Mdot
.70181 .60236 Mdot
.70182 .60236 Mdot
.70183 .60236 Mdot
.70184 .60236 Mdot
.70185 .60236 Mdot
.70186 .60237 Mdot
.70187 .60237 Mdot
.70188 .60237 Mdot
.70189 .60237 Mdot
.7019 .60237 Mdot
.7019 .60237 Mdot
.70191 .60238 Mdot
.70192 .60238 Mdot
.70193 .60238 Mdot
.70194 .60238 Mdot
.70195 .60238 Mdot
.70196 .60238 Mdot
.70197 .60238 Mdot
.70198 .60239 Mdot
.70199 .60239 Mdot
.702 .60239 Mdot
.70201 .60239 Mdot
.70202 .60239 Mdot
.70203 .60239 Mdot
.70204 .60239 Mdot
.70205 .6024 Mdot
.70206 .6024 Mdot
.70207 .6024 Mdot
.70208 .6024 Mdot
.70209 .6024 Mdot
.7021 .6024 Mdot
.7021 .6024 Mdot
.70211 .6024 Mdot
.70212 .60241 Mdot
.70213 .60241 Mdot
.70214 .60241 Mdot
.70215 .60241 Mdot
.70216 .60241 Mdot
.70217 .60241 Mdot
.70218 .60241 Mdot
.70219 .60242 Mdot
.7022 .60242 Mdot
.70221 .60242 Mdot
.70222 .60242 Mdot
.70223 .60242 Mdot
.70224 .60242 Mdot
.70225 .60242 Mdot
.70226 .60243 Mdot
.70227 .60243 Mdot
.70228 .60243 Mdot
.70229 .60243 Mdot
.7023 .60243 Mdot
.7023 .60243 Mdot
.70231 .60243 Mdot
.70232 .60244 Mdot
.70233 .60244 Mdot
.70234 .60244 Mdot
.70235 .60244 Mdot
.70236 .60244 Mdot
.70237 .60244 Mdot
.70238 .60244 Mdot
.70239 .60245 Mdot
.7024 .60245 Mdot
.70241 .60245 Mdot
.70242 .60245 Mdot
.70243 .60245 Mdot
.70244 .60245 Mdot
.70245 .60245 Mdot
.70246 .60246 Mdot
.70247 .60246 Mdot
.70248 .60246 Mdot
.70249 .60246 Mdot
.7025 .60246 Mdot
.7025 .60246 Mdot
.70251 .60246 Mdot
.70252 .60246 Mdot
.70253 .60247 Mdot
.70254 .60247 Mdot
.70255 .60247 Mdot
.70256 .60247 Mdot
.70257 .60247 Mdot
.70258 .60247 Mdot
.70259 .60247 Mdot
.7026 .60248 Mdot
.70261 .60248 Mdot
.70262 .60248 Mdot
.70263 .60248 Mdot
.70264 .60248 Mdot
.70265 .60248 Mdot
.70266 .60248 Mdot
.70267 .60249 Mdot
.70268 .60249 Mdot
.70269 .60249 Mdot
.7027 .60249 Mdot
.7027 .60249 Mdot
.70271 .60249 Mdot
.70272 .60249 Mdot
.70273 .60249 Mdot
.70274 .6025 Mdot
.70275 .6025 Mdot
.70276 .6025 Mdot
.70277 .6025 Mdot
.70278 .6025 Mdot
.70279 .6025 Mdot
.7028 .6025 Mdot
.70281 .60251 Mdot
.70282 .60251 Mdot
.70283 .60251 Mdot
.70284 .60251 Mdot
.70285 .60251 Mdot
.70286 .60251 Mdot
.70287 .60251 Mdot
.70288 .60251 Mdot
.70289 .60252 Mdot
.7029 .60252 Mdot
.7029 .60252 Mdot
.70291 .60252 Mdot
.70292 .60252 Mdot
.70293 .60252 Mdot
.70294 .60252 Mdot
.70295 .60252 Mdot
.70296 .60253 Mdot
.70297 .60253 Mdot
.70298 .60253 Mdot
.70299 .60253 Mdot
.703 .60253 Mdot
.70301 .60253 Mdot
.70302 .60253 Mdot
.70303 .60254 Mdot
.70304 .60254 Mdot
.70305 .60254 Mdot
.70306 .60254 Mdot
.70307 .60254 Mdot
.70308 .60254 Mdot
.70309 .60254 Mdot
.7031 .60254 Mdot
.7031 .60255 Mdot
.70311 .60255 Mdot
.70312 .60255 Mdot
.70313 .60255 Mdot
.70314 .60255 Mdot
.70315 .60255 Mdot
.70316 .60255 Mdot
.70317 .60255 Mdot
.70318 .60256 Mdot
.70319 .60256 Mdot
.7032 .60256 Mdot
.70321 .60256 Mdot
.70322 .60256 Mdot
.70323 .60256 Mdot
.70324 .60256 Mdot
.70325 .60257 Mdot
.70326 .60257 Mdot
.70327 .60257 Mdot
.70328 .60257 Mdot
.70329 .60257 Mdot
.7033 .60257 Mdot
.7033 .60257 Mdot
.70331 .60257 Mdot
.70332 .60258 Mdot
.70333 .60258 Mdot
.70334 .60258 Mdot
.70335 .60258 Mdot
.70336 .60258 Mdot
.70337 .60258 Mdot
.70338 .60258 Mdot
.70339 .60258 Mdot
.7034 .60259 Mdot
.70341 .60259 Mdot
.70342 .60259 Mdot
.70343 .60259 Mdot
.70344 .60259 Mdot
.70345 .60259 Mdot
.70346 .60259 Mdot
.70347 .60259 Mdot
.70348 .6026 Mdot
.70349 .6026 Mdot
.7035 .6026 Mdot
.7035 .6026 Mdot
.70351 .6026 Mdot
.70352 .6026 Mdot
.70353 .6026 Mdot
.70354 .6026 Mdot
.70355 .60261 Mdot
.70356 .60261 Mdot
.70357 .60261 Mdot
.70358 .60261 Mdot
.70359 .60261 Mdot
.7036 .60261 Mdot
.70361 .60261 Mdot
.70362 .60261 Mdot
.70363 .60262 Mdot
.70364 .60262 Mdot
.70365 .60262 Mdot
.70366 .60262 Mdot
.70367 .60262 Mdot
.70368 .60262 Mdot
.70369 .60262 Mdot
.7037 .60262 Mdot
.7037 .60263 Mdot
.70371 .60263 Mdot
.70372 .60263 Mdot
.70373 .60263 Mdot
.70374 .60263 Mdot
.70375 .60263 Mdot
.70376 .60263 Mdot
.70377 .60263 Mdot
.70378 .60264 Mdot
.70379 .60264 Mdot
.7038 .60264 Mdot
.70381 .60264 Mdot
.70382 .60264 Mdot
.70383 .60264 Mdot
.70384 .60264 Mdot
.70385 .60264 Mdot
.70386 .60265 Mdot
.70387 .60265 Mdot
.70388 .60265 Mdot
.70389 .60265 Mdot
.7039 .60265 Mdot
.7039 .60265 Mdot
.70391 .60265 Mdot
.70392 .60265 Mdot
.70393 .60265 Mdot
.70394 .60266 Mdot
.70395 .60266 Mdot
.70396 .60266 Mdot
.70397 .60266 Mdot
.70398 .60266 Mdot
.70399 .60266 Mdot
.704 .60266 Mdot
.70401 .60266 Mdot
.70402 .60267 Mdot
.70403 .60267 Mdot
.70404 .60267 Mdot
.70405 .60267 Mdot
.70406 .60267 Mdot
.70407 .60267 Mdot
.70408 .60267 Mdot
.70409 .60267 Mdot
.7041 .60267 Mdot
.7041 .60268 Mdot
.70411 .60268 Mdot
.70412 .60268 Mdot
.70413 .60268 Mdot
.70414 .60268 Mdot
.70415 .60268 Mdot
.70416 .60268 Mdot
.70417 .60268 Mdot
.70418 .60269 Mdot
.70419 .60269 Mdot
.7042 .60269 Mdot
.70421 .60269 Mdot
.70422 .60269 Mdot
.70423 .60269 Mdot
.70424 .60269 Mdot
.70425 .60269 Mdot
.70426 .60269 Mdot
.70427 .6027 Mdot
.70428 .6027 Mdot
.70429 .6027 Mdot
.7043 .6027 Mdot
.7043 .6027 Mdot
.70431 .6027 Mdot
.70432 .6027 Mdot
.70433 .6027 Mdot
.70434 .60271 Mdot
.70435 .60271 Mdot
.70436 .60271 Mdot
.70437 .60271 Mdot
.70438 .60271 Mdot
.70439 .60271 Mdot
.7044 .60271 Mdot
.70441 .60271 Mdot
.70442 .60271 Mdot
.70443 .60272 Mdot
.70444 .60272 Mdot
.70445 .60272 Mdot
.70446 .60272 Mdot
.70447 .60272 Mdot
.70448 .60272 Mdot
.70449 .60272 Mdot
.7045 .60272 Mdot
.7045 .60272 Mdot
.70451 .60273 Mdot
.70452 .60273 Mdot
.70453 .60273 Mdot
.70454 .60273 Mdot
.70455 .60273 Mdot
.70456 .60273 Mdot
.70457 .60273 Mdot
.70458 .60273 Mdot
.70459 .60274 Mdot
.7046 .60274 Mdot
.70461 .60274 Mdot
.70462 .60274 Mdot
.70463 .60274 Mdot
.70464 .60274 Mdot
.70465 .60274 Mdot
.70466 .60274 Mdot
.70467 .60274 Mdot
.70468 .60275 Mdot
.70469 .60275 Mdot
.7047 .60275 Mdot
.7047 .60275 Mdot
.70471 .60275 Mdot
.70472 .60275 Mdot
.70473 .60275 Mdot
.70474 .60275 Mdot
.70475 .60275 Mdot
.70476 .60276 Mdot
.70477 .60276 Mdot
.70478 .60276 Mdot
.70479 .60276 Mdot
.7048 .60276 Mdot
.70481 .60276 Mdot
.70482 .60276 Mdot
.70483 .60276 Mdot
.70484 .60276 Mdot
.70485 .60277 Mdot
.70486 .60277 Mdot
.70487 .60277 Mdot
.70488 .60277 Mdot
.70489 .60277 Mdot
.7049 .60277 Mdot
.7049 .60277 Mdot
.70491 .60277 Mdot
.70492 .60277 Mdot
.70493 .60277 Mdot
.70494 .60278 Mdot
.70495 .60278 Mdot
.70496 .60278 Mdot
.70497 .60278 Mdot
.70498 .60278 Mdot
.70499 .60278 Mdot
.705 .60278 Mdot
.70501 .60278 Mdot
.70502 .60278 Mdot
.70503 .60279 Mdot
.70504 .60279 Mdot
.70505 .60279 Mdot
.70506 .60279 Mdot
.70507 .60279 Mdot
.70508 .60279 Mdot
.70509 .60279 Mdot
.7051 .60279 Mdot
.7051 .60279 Mdot
.70511 .6028 Mdot
.70512 .6028 Mdot
.70513 .6028 Mdot
.70514 .6028 Mdot
.70515 .6028 Mdot
.70516 .6028 Mdot
.70517 .6028 Mdot
.70518 .6028 Mdot
.70519 .6028 Mdot
.7052 .6028 Mdot
.70521 .60281 Mdot
.70522 .60281 Mdot
.70523 .60281 Mdot
.70524 .60281 Mdot
.70525 .60281 Mdot
.70526 .60281 Mdot
.70527 .60281 Mdot
.70528 .60281 Mdot
.70529 .60281 Mdot
.7053 .60282 Mdot
.7053 .60282 Mdot
.70531 .60282 Mdot
.70532 .60282 Mdot
.70533 .60282 Mdot
.70534 .60282 Mdot
.70535 .60282 Mdot
.70536 .60282 Mdot
.70537 .60282 Mdot
.70538 .60282 Mdot
.70539 .60283 Mdot
.7054 .60283 Mdot
.70541 .60283 Mdot
.70542 .60283 Mdot
.70543 .60283 Mdot
.70544 .60283 Mdot
.70545 .60283 Mdot
.70546 .60283 Mdot
.70547 .60283 Mdot
.70548 .60284 Mdot
.70549 .60284 Mdot
.7055 .60284 Mdot
.7055 .60284 Mdot
.70551 .60284 Mdot
.70552 .60284 Mdot
.70553 .60284 Mdot
.70554 .60284 Mdot
.70555 .60284 Mdot
.70556 .60284 Mdot
.70557 .60285 Mdot
.70558 .60285 Mdot
.70559 .60285 Mdot
.7056 .60285 Mdot
.70561 .60285 Mdot
.70562 .60285 Mdot
.70563 .60285 Mdot
.70564 .60285 Mdot
.70565 .60285 Mdot
.70566 .60285 Mdot
.70567 .60286 Mdot
.70568 .60286 Mdot
.70569 .60286 Mdot
.7057 .60286 Mdot
.7057 .60286 Mdot
.70571 .60286 Mdot
.70572 .60286 Mdot
.70573 .60286 Mdot
.70574 .60286 Mdot
.70575 .60286 Mdot
.70576 .60287 Mdot
.70577 .60287 Mdot
.70578 .60287 Mdot
.70579 .60287 Mdot
.7058 .60287 Mdot
.70581 .60287 Mdot
.70582 .60287 Mdot
.70583 .60287 Mdot
.70584 .60287 Mdot
.70585 .60287 Mdot
.70586 .60288 Mdot
.70587 .60288 Mdot
.70588 .60288 Mdot
.70589 .60288 Mdot
.7059 .60288 Mdot
.7059 .60288 Mdot
.70591 .60288 Mdot
.70592 .60288 Mdot
.70593 .60288 Mdot
.70594 .60288 Mdot
.70595 .60289 Mdot
.70596 .60289 Mdot
.70597 .60289 Mdot
.70598 .60289 Mdot
.70599 .60289 Mdot
.706 .60289 Mdot
.70601 .60289 Mdot
.70602 .60289 Mdot
.70603 .60289 Mdot
.70604 .60289 Mdot
.70605 .60289 Mdot
.70606 .6029 Mdot
.70607 .6029 Mdot
.70608 .6029 Mdot
.70609 .6029 Mdot
.7061 .6029 Mdot
.7061 .6029 Mdot
.70611 .6029 Mdot
.70612 .6029 Mdot
.70613 .6029 Mdot
.70614 .6029 Mdot
.70615 .60291 Mdot
.70616 .60291 Mdot
.70617 .60291 Mdot
.70618 .60291 Mdot
.70619 .60291 Mdot
.7062 .60291 Mdot
.70621 .60291 Mdot
.70622 .60291 Mdot
.70623 .60291 Mdot
.70624 .60291 Mdot
.70625 .60291 Mdot
.70626 .60292 Mdot
.70627 .60292 Mdot
.70628 .60292 Mdot
.70629 .60292 Mdot
.7063 .60292 Mdot
.7063 .60292 Mdot
.70631 .60292 Mdot
.70632 .60292 Mdot
.70633 .60292 Mdot
.70634 .60292 Mdot
.70635 .60292 Mdot
.70636 .60293 Mdot
.70637 .60293 Mdot
.70638 .60293 Mdot
.70639 .60293 Mdot
.7064 .60293 Mdot
.70641 .60293 Mdot
.70642 .60293 Mdot
.70643 .60293 Mdot
.70644 .60293 Mdot
.70645 .60293 Mdot
.70646 .60293 Mdot
.70647 .60294 Mdot
.70648 .60294 Mdot
.70649 .60294 Mdot
.7065 .60294 Mdot
.7065 .60294 Mdot
.70651 .60294 Mdot
.70652 .60294 Mdot
.70653 .60294 Mdot
.70654 .60294 Mdot
.70655 .60294 Mdot
.70656 .60294 Mdot
.70657 .60295 Mdot
.70658 .60295 Mdot
.70659 .60295 Mdot
.7066 .60295 Mdot
.70661 .60295 Mdot
.70662 .60295 Mdot
.70663 .60295 Mdot
.70664 .60295 Mdot
.70665 .60295 Mdot
.70666 .60295 Mdot
.70667 .60295 Mdot
.70668 .60296 Mdot
.70669 .60296 Mdot
.7067 .60296 Mdot
.7067 .60296 Mdot
.70671 .60296 Mdot
.70672 .60296 Mdot
.70673 .60296 Mdot
.70674 .60296 Mdot
.70675 .60296 Mdot
.70676 .60296 Mdot
.70677 .60296 Mdot
.70678 .60297 Mdot
.70679 .60297 Mdot
.7068 .60297 Mdot
.70681 .60297 Mdot
.70682 .60297 Mdot
.70683 .60297 Mdot
.70684 .60297 Mdot
.70685 .60297 Mdot
.70686 .60297 Mdot
.70687 .60297 Mdot
.70688 .60297 Mdot
.70689 .60297 Mdot
.7069 .60298 Mdot
.7069 .60298 Mdot
.70691 .60298 Mdot
.70692 .60298 Mdot
.70693 .60298 Mdot
.70694 .60298 Mdot
.70695 .60298 Mdot
.70696 .60298 Mdot
.70697 .60298 Mdot
.70698 .60298 Mdot
.70699 .60298 Mdot
.707 .60299 Mdot
.70701 .60299 Mdot
.70702 .60299 Mdot
.70703 .60299 Mdot
.70704 .60299 Mdot
.70705 .60299 Mdot
.70706 .60299 Mdot
.70707 .60299 Mdot
.70708 .60299 Mdot
.70709 .60299 Mdot
.7071 .60299 Mdot
.7071 .60299 Mdot
.70711 .603 Mdot
.70712 .603 Mdot
.70713 .603 Mdot
.70714 .603 Mdot
.70715 .603 Mdot
.70716 .603 Mdot
.70717 .603 Mdot
.70718 .603 Mdot
.70719 .603 Mdot
.7072 .603 Mdot
.70721 .603 Mdot
.70722 .603 Mdot
.70723 .60301 Mdot
.70724 .60301 Mdot
.70725 .60301 Mdot
.70726 .60301 Mdot
.70727 .60301 Mdot
.70728 .60301 Mdot
.70729 .60301 Mdot
.7073 .60301 Mdot
.7073 .60301 Mdot
.70731 .60301 Mdot
.70732 .60301 Mdot
.70733 .60301 Mdot
.70734 .60302 Mdot
.70735 .60302 Mdot
.70736 .60302 Mdot
.70737 .60302 Mdot
.70738 .60302 Mdot
.70739 .60302 Mdot
.7074 .60302 Mdot
.70741 .60302 Mdot
.70742 .60302 Mdot
.70743 .60302 Mdot
.70744 .60302 Mdot
.70745 .60302 Mdot
.70746 .60302 Mdot
.70747 .60303 Mdot
.70748 .60303 Mdot
.70749 .60303 Mdot
.7075 .60303 Mdot
.7075 .60303 Mdot
.70751 .60303 Mdot
.70752 .60303 Mdot
.70753 .60303 Mdot
.70754 .60303 Mdot
.70755 .60303 Mdot
.70756 .60303 Mdot
.70757 .60303 Mdot
.70758 .60304 Mdot
.70759 .60304 Mdot
.7076 .60304 Mdot
.70761 .60304 Mdot
.70762 .60304 Mdot
.70763 .60304 Mdot
.70764 .60304 Mdot
.70765 .60304 Mdot
.70766 .60304 Mdot
.70767 .60304 Mdot
.70768 .60304 Mdot
.70769 .60304 Mdot
.7077 .60304 Mdot
.7077 .60305 Mdot
.70771 .60305 Mdot
.70772 .60305 Mdot
.70773 .60305 Mdot
.70774 .60305 Mdot
.70775 .60305 Mdot
.70776 .60305 Mdot
.70777 .60305 Mdot
.70778 .60305 Mdot
.70779 .60305 Mdot
.7078 .60305 Mdot
.70781 .60305 Mdot
.70782 .60305 Mdot
.70783 .60306 Mdot
.70784 .60306 Mdot
.70785 .60306 Mdot
.70786 .60306 Mdot
.70787 .60306 Mdot
.70788 .60306 Mdot
.70789 .60306 Mdot
.7079 .60306 Mdot
.7079 .60306 Mdot
.70791 .60306 Mdot
.70792 .60306 Mdot
.70793 .60306 Mdot
.70794 .60306 Mdot
.70795 .60306 Mdot
.70796 .60307 Mdot
.70797 .60307 Mdot
.70798 .60307 Mdot
.70799 .60307 Mdot
.708 .60307 Mdot
.70801 .60307 Mdot
.70802 .60307 Mdot
.70803 .60307 Mdot
.70804 .60307 Mdot
.70805 .60307 Mdot
.70806 .60307 Mdot
.70807 .60307 Mdot
.70808 .60307 Mdot
.70809 .60308 Mdot
.7081 .60308 Mdot
.7081 .60308 Mdot
.70811 .60308 Mdot
.70812 .60308 Mdot
.70813 .60308 Mdot
.70814 .60308 Mdot
.70815 .60308 Mdot
.70816 .60308 Mdot
.70817 .60308 Mdot
.70818 .60308 Mdot
.70819 .60308 Mdot
.7082 .60308 Mdot
.70821 .60308 Mdot
.70822 .60309 Mdot
.70823 .60309 Mdot
.70824 .60309 Mdot
.70825 .60309 Mdot
.70826 .60309 Mdot
.70827 .60309 Mdot
.70828 .60309 Mdot
.70829 .60309 Mdot
.7083 .60309 Mdot
.7083 .60309 Mdot
.70831 .60309 Mdot
.70832 .60309 Mdot
.70833 .60309 Mdot
.70834 .60309 Mdot
.70835 .6031 Mdot
.70836 .6031 Mdot
.70837 .6031 Mdot
.70838 .6031 Mdot
.70839 .6031 Mdot
.7084 .6031 Mdot
.70841 .6031 Mdot
.70842 .6031 Mdot
.70843 .6031 Mdot
.70844 .6031 Mdot
.70845 .6031 Mdot
.70846 .6031 Mdot
.70847 .6031 Mdot
.70848 .6031 Mdot
.70849 .6031 Mdot
.7085 .60311 Mdot
.7085 .60311 Mdot
.70851 .60311 Mdot
.70852 .60311 Mdot
.70853 .60311 Mdot
.70854 .60311 Mdot
.70855 .60311 Mdot
.70856 .60311 Mdot
.70857 .60311 Mdot
.70858 .60311 Mdot
.70859 .60311 Mdot
.7086 .60311 Mdot
.70861 .60311 Mdot
.70862 .60311 Mdot
.70863 .60311 Mdot
.70864 .60312 Mdot
.70865 .60312 Mdot
.70866 .60312 Mdot
.70867 .60312 Mdot
.70868 .60312 Mdot
.70869 .60312 Mdot
.7087 .60312 Mdot
.7087 .60312 Mdot
.70871 .60312 Mdot
.70872 .60312 Mdot
.70873 .60312 Mdot
.70874 .60312 Mdot
.70875 .60312 Mdot
.70876 .60312 Mdot
.70877 .60312 Mdot
.70878 .60313 Mdot
.70879 .60313 Mdot
.7088 .60313 Mdot
.70881 .60313 Mdot
.70882 .60313 Mdot
.70883 .60313 Mdot
.70884 .60313 Mdot
.70885 .60313 Mdot
.70886 .60313 Mdot
.70887 .60313 Mdot
.70888 .60313 Mdot
.70889 .60313 Mdot
.7089 .60313 Mdot
.7089 .60313 Mdot
.70891 .60313 Mdot
.70892 .60313 Mdot
.70893 .60314 Mdot
.70894 .60314 Mdot
.70895 .60314 Mdot
.70896 .60314 Mdot
.70897 .60314 Mdot
.70898 .60314 Mdot
.70899 .60314 Mdot
.709 .60314 Mdot
.70901 .60314 Mdot
.70902 .60314 Mdot
.70903 .60314 Mdot
.70904 .60314 Mdot
.70905 .60314 Mdot
.70906 .60314 Mdot
.70907 .60314 Mdot
.70908 .60314 Mdot
.70909 .60315 Mdot
.7091 .60315 Mdot
.7091 .60315 Mdot
.70911 .60315 Mdot
.70912 .60315 Mdot
.70913 .60315 Mdot
.70914 .60315 Mdot
.70915 .60315 Mdot
.70916 .60315 Mdot
.70917 .60315 Mdot
.70918 .60315 Mdot
.70919 .60315 Mdot
.7092 .60315 Mdot
.70921 .60315 Mdot
.70922 .60315 Mdot
.70923 .60315 Mdot
.70924 .60316 Mdot
.70925 .60316 Mdot
.70926 .60316 Mdot
.70927 .60316 Mdot
.70928 .60316 Mdot
.70929 .60316 Mdot
.7093 .60316 Mdot
.7093 .60316 Mdot
.70931 .60316 Mdot
.70932 .60316 Mdot
.70933 .60316 Mdot
.70934 .60316 Mdot
.70935 .60316 Mdot
.70936 .60316 Mdot
.70937 .60316 Mdot
.70938 .60316 Mdot
.70939 .60316 Mdot
.7094 .60317 Mdot
.70941 .60317 Mdot
.70942 .60317 Mdot
.70943 .60317 Mdot
.70944 .60317 Mdot
.70945 .60317 Mdot
.70946 .60317 Mdot
.70947 .60317 Mdot
.70948 .60317 Mdot
.70949 .60317 Mdot
.7095 .60317 Mdot
.7095 .60317 Mdot
.70951 .60317 Mdot
.70952 .60317 Mdot
.70953 .60317 Mdot
.70954 .60317 Mdot
.70955 .60317 Mdot
.70956 .60317 Mdot
.70957 .60318 Mdot
.70958 .60318 Mdot
.70959 .60318 Mdot
.7096 .60318 Mdot
.70961 .60318 Mdot
.70962 .60318 Mdot
.70963 .60318 Mdot
.70964 .60318 Mdot
.70965 .60318 Mdot
.70966 .60318 Mdot
.70967 .60318 Mdot
.70968 .60318 Mdot
.70969 .60318 Mdot
.7097 .60318 Mdot
.7097 .60318 Mdot
.70971 .60318 Mdot
.70972 .60318 Mdot
.70973 .60318 Mdot
.70974 .60319 Mdot
.70975 .60319 Mdot
.70976 .60319 Mdot
.70977 .60319 Mdot
.70978 .60319 Mdot
.70979 .60319 Mdot
.7098 .60319 Mdot
.70981 .60319 Mdot
.70982 .60319 Mdot
.70983 .60319 Mdot
.70984 .60319 Mdot
.70985 .60319 Mdot
.70986 .60319 Mdot
.70987 .60319 Mdot
.70988 .60319 Mdot
.70989 .60319 Mdot
.7099 .60319 Mdot
.7099 .60319 Mdot
.70991 .60319 Mdot
.70992 .6032 Mdot
.70993 .6032 Mdot
.70994 .6032 Mdot
.70995 .6032 Mdot
.70996 .6032 Mdot
.70997 .6032 Mdot
.70998 .6032 Mdot
.70999 .6032 Mdot
.71 .6032 Mdot
.71001 .6032 Mdot
.71002 .6032 Mdot
.71003 .6032 Mdot
.71004 .6032 Mdot
.71005 .6032 Mdot
.71006 .6032 Mdot
.71007 .6032 Mdot
.71008 .6032 Mdot
.71009 .6032 Mdot
.7101 .6032 Mdot
.7101 .6032 Mdot
.71011 .60321 Mdot
.71012 .60321 Mdot
.71013 .60321 Mdot
.71014 .60321 Mdot
.71015 .60321 Mdot
.71016 .60321 Mdot
.71017 .60321 Mdot
.71018 .60321 Mdot
.71019 .60321 Mdot
.7102 .60321 Mdot
.71021 .60321 Mdot
.71022 .60321 Mdot
.71023 .60321 Mdot
.71024 .60321 Mdot
.71025 .60321 Mdot
.71026 .60321 Mdot
.71027 .60321 Mdot
.71028 .60321 Mdot
.71029 .60321 Mdot
.7103 .60321 Mdot
.7103 .60321 Mdot
.71031 .60322 Mdot
.71032 .60322 Mdot
.71033 .60322 Mdot
.71034 .60322 Mdot
.71035 .60322 Mdot
.71036 .60322 Mdot
.71037 .60322 Mdot
.71038 .60322 Mdot
.71039 .60322 Mdot
.7104 .60322 Mdot
.71041 .60322 Mdot
.71042 .60322 Mdot
.71043 .60322 Mdot
.71044 .60322 Mdot
.71045 .60322 Mdot
.71046 .60322 Mdot
.71047 .60322 Mdot
.71048 .60322 Mdot
.71049 .60322 Mdot
.7105 .60322 Mdot
.7105 .60322 Mdot
.71051 .60323 Mdot
.71052 .60323 Mdot
.71053 .60323 Mdot
.71054 .60323 Mdot
.71055 .60323 Mdot
.71056 .60323 Mdot
.71057 .60323 Mdot
.71058 .60323 Mdot
.71059 .60323 Mdot
.7106 .60323 Mdot
.71061 .60323 Mdot
.71062 .60323 Mdot
.71063 .60323 Mdot
.71064 .60323 Mdot
.71065 .60323 Mdot
.71066 .60323 Mdot
.71067 .60323 Mdot
.71068 .60323 Mdot
.71069 .60323 Mdot
.7107 .60323 Mdot
.7107 .60323 Mdot
.71071 .60323 Mdot
.71072 .60323 Mdot
.71073 .60324 Mdot
.71074 .60324 Mdot
.71075 .60324 Mdot
.71076 .60324 Mdot
.71077 .60324 Mdot
.71078 .60324 Mdot
.71079 .60324 Mdot
.7108 .60324 Mdot
.71081 .60324 Mdot
.71082 .60324 Mdot
.71083 .60324 Mdot
.71084 .60324 Mdot
.71085 .60324 Mdot
.71086 .60324 Mdot
.71087 .60324 Mdot
.71088 .60324 Mdot
.71089 .60324 Mdot
.7109 .60324 Mdot
.7109 .60324 Mdot
.71091 .60324 Mdot
.71092 .60324 Mdot
.71093 .60324 Mdot
.71094 .60324 Mdot
.71095 .60324 Mdot
.71096 .60325 Mdot
.71097 .60325 Mdot
.71098 .60325 Mdot
.71099 .60325 Mdot
.711 .60325 Mdot
.71101 .60325 Mdot
.71102 .60325 Mdot
.71103 .60325 Mdot
.71104 .60325 Mdot
.71105 .60325 Mdot
.71106 .60325 Mdot
.71107 .60325 Mdot
.71108 .60325 Mdot
.71109 .60325 Mdot
.7111 .60325 Mdot
.7111 .60325 Mdot
.71111 .60325 Mdot
.71112 .60325 Mdot
.71113 .60325 Mdot
.71114 .60325 Mdot
.71115 .60325 Mdot
.71116 .60325 Mdot
.71117 .60325 Mdot
.71118 .60325 Mdot
.71119 .60325 Mdot
.7112 .60325 Mdot
.71121 .60326 Mdot
.71122 .60326 Mdot
.71123 .60326 Mdot
.71124 .60326 Mdot
.71125 .60326 Mdot
.71126 .60326 Mdot
.71127 .60326 Mdot
.71128 .60326 Mdot
.71129 .60326 Mdot
.7113 .60326 Mdot
.7113 .60326 Mdot
.71131 .60326 Mdot
.71132 .60326 Mdot
.71133 .60326 Mdot
.71134 .60326 Mdot
.71135 .60326 Mdot
.71136 .60326 Mdot
.71137 .60326 Mdot
.71138 .60326 Mdot
.71139 .60326 Mdot
.7114 .60326 Mdot
.71141 .60326 Mdot
.71142 .60326 Mdot
.71143 .60326 Mdot
.71144 .60326 Mdot
.71145 .60326 Mdot
.71146 .60326 Mdot
.71147 .60326 Mdot
.71148 .60327 Mdot
.71149 .60327 Mdot
.7115 .60327 Mdot
.7115 .60327 Mdot
.71151 .60327 Mdot
.71152 .60327 Mdot
.71153 .60327 Mdot
.71154 .60327 Mdot
.71155 .60327 Mdot
.71156 .60327 Mdot
.71157 .60327 Mdot
.71158 .60327 Mdot
.71159 .60327 Mdot
.7116 .60327 Mdot
.71161 .60327 Mdot
.71162 .60327 Mdot
.71163 .60327 Mdot
.71164 .60327 Mdot
.71165 .60327 Mdot
.71166 .60327 Mdot
.71167 .60327 Mdot
.71168 .60327 Mdot
.71169 .60327 Mdot
.7117 .60327 Mdot
.7117 .60327 Mdot
.71171 .60327 Mdot
.71172 .60327 Mdot
.71173 .60327 Mdot
.71174 .60327 Mdot
.71175 .60327 Mdot
.71176 .60327 Mdot
.71177 .60328 Mdot
.71178 .60328 Mdot
.71179 .60328 Mdot
.7118 .60328 Mdot
.71181 .60328 Mdot
.71182 .60328 Mdot
.71183 .60328 Mdot
.71184 .60328 Mdot
.71185 .60328 Mdot
.71186 .60328 Mdot
.71187 .60328 Mdot
.71188 .60328 Mdot
.71189 .60328 Mdot
.7119 .60328 Mdot
.7119 .60328 Mdot
.71191 .60328 Mdot
.71192 .60328 Mdot
.71193 .60328 Mdot
.71194 .60328 Mdot
.71195 .60328 Mdot
.71196 .60328 Mdot
.71197 .60328 Mdot
.71198 .60328 Mdot
.71199 .60328 Mdot
.712 .60328 Mdot
.71201 .60328 Mdot
.71202 .60328 Mdot
.71203 .60328 Mdot
.71204 .60328 Mdot
.71205 .60328 Mdot
.71206 .60328 Mdot
.71207 .60328 Mdot
.71208 .60328 Mdot
.71209 .60328 Mdot
.7121 .60328 Mdot
.7121 .60329 Mdot
.71211 .60329 Mdot
.71212 .60329 Mdot
.71213 .60329 Mdot
.71214 .60329 Mdot
.71215 .60329 Mdot
.71216 .60329 Mdot
.71217 .60329 Mdot
.71218 .60329 Mdot
.71219 .60329 Mdot
.7122 .60329 Mdot
.71221 .60329 Mdot
.71222 .60329 Mdot
.71223 .60329 Mdot
.71224 .60329 Mdot
.71225 .60329 Mdot
.71226 .60329 Mdot
.71227 .60329 Mdot
.71228 .60329 Mdot
.71229 .60329 Mdot
.7123 .60329 Mdot
.7123 .60329 Mdot
.71231 .60329 Mdot
.71232 .60329 Mdot
.71233 .60329 Mdot
.71234 .60329 Mdot
.71235 .60329 Mdot
.71236 .60329 Mdot
.71237 .60329 Mdot
.71238 .60329 Mdot
.71239 .60329 Mdot
.7124 .60329 Mdot
.71241 .60329 Mdot
.71242 .60329 Mdot
.71243 .60329 Mdot
.71244 .60329 Mdot
.71245 .60329 Mdot
.71246 .60329 Mdot
.71247 .60329 Mdot
.71248 .60329 Mdot
.71249 .6033 Mdot
.7125 .6033 Mdot
.7125 .6033 Mdot
.71251 .6033 Mdot
.71252 .6033 Mdot
.71253 .6033 Mdot
.71254 .6033 Mdot
.71255 .6033 Mdot
.71256 .6033 Mdot
.71257 .6033 Mdot
.71258 .6033 Mdot
.71259 .6033 Mdot
.7126 .6033 Mdot
.71261 .6033 Mdot
.71262 .6033 Mdot
.71263 .6033 Mdot
.71264 .6033 Mdot
.71265 .6033 Mdot
.71266 .6033 Mdot
.71267 .6033 Mdot
.71268 .6033 Mdot
.71269 .6033 Mdot
.7127 .6033 Mdot
.7127 .6033 Mdot
.71271 .6033 Mdot
.71272 .6033 Mdot
.71273 .6033 Mdot
.71274 .6033 Mdot
.71275 .6033 Mdot
.71276 .6033 Mdot
.71277 .6033 Mdot
.71278 .6033 Mdot
.71279 .6033 Mdot
.7128 .6033 Mdot
.71281 .6033 Mdot
.71282 .6033 Mdot
.71283 .6033 Mdot
.71284 .6033 Mdot
.71285 .6033 Mdot
.71286 .6033 Mdot
.71287 .6033 Mdot
.71288 .6033 Mdot
.71289 .6033 Mdot
.7129 .6033 Mdot
.7129 .6033 Mdot
.71291 .6033 Mdot
.71292 .6033 Mdot
.71293 .6033 Mdot
.71294 .6033 Mdot
.71295 .6033 Mdot
.71296 .60331 Mdot
.71297 .60331 Mdot
.71298 .60331 Mdot
.71299 .60331 Mdot
.713 .60331 Mdot
.71301 .60331 Mdot
.71302 .60331 Mdot
.71303 .60331 Mdot
.71304 .60331 Mdot
.71305 .60331 Mdot
.71306 .60331 Mdot
.71307 .60331 Mdot
.71308 .60331 Mdot
.71309 .60331 Mdot
.7131 .60331 Mdot
.7131 .60331 Mdot
.71311 .60331 Mdot
.71312 .60331 Mdot
.71313 .60331 Mdot
.71314 .60331 Mdot
.71315 .60331 Mdot
.71316 .60331 Mdot
.71317 .60331 Mdot
.71318 .60331 Mdot
.71319 .60331 Mdot
.7132 .60331 Mdot
.71321 .60331 Mdot
.71322 .60331 Mdot
.71323 .60331 Mdot
.71324 .60331 Mdot
.71325 .60331 Mdot
.71326 .60331 Mdot
.71327 .60331 Mdot
.71328 .60331 Mdot
.71329 .60331 Mdot
.7133 .60331 Mdot
.7133 .60331 Mdot
.71331 .60331 Mdot
.71332 .60331 Mdot
.71333 .60331 Mdot
.71334 .60331 Mdot
.71335 .60331 Mdot
.71336 .60331 Mdot
.71337 .60331 Mdot
.71338 .60331 Mdot
.71339 .60331 Mdot
.7134 .60331 Mdot
.71341 .60331 Mdot
.71342 .60331 Mdot
.71343 .60331 Mdot
.71344 .60331 Mdot
.71345 .60331 Mdot
.71346 .60331 Mdot
.71347 .60331 Mdot
.71348 .60331 Mdot
.71349 .60331 Mdot
.7135 .60331 Mdot
.7135 .60331 Mdot
.71351 .60331 Mdot
.71352 .60331 Mdot
.71353 .60331 Mdot
.71354 .60331 Mdot
.71355 .60331 Mdot
.71356 .60331 Mdot
.71357 .60331 Mdot
.71358 .60331 Mdot
.71359 .60331 Mdot
.7136 .60331 Mdot
.71361 .60331 Mdot
.71362 .60331 Mdot
.71363 .60331 Mdot
.71364 .60331 Mdot
.71365 .60331 Mdot
.71366 .60331 Mdot
.71367 .60331 Mdot
.71368 .60331 Mdot
.71369 .60332 Mdot
.7137 .60332 Mdot
.7137 .60332 Mdot
.71371 .60332 Mdot
.71372 .60332 Mdot
.71373 .60332 Mdot
.71374 .60332 Mdot
.71375 .60332 Mdot
.71376 .60332 Mdot
.71377 .60332 Mdot
.71378 .60332 Mdot
.71379 .60332 Mdot
.7138 .60332 Mdot
.71381 .60332 Mdot
.71382 .60332 Mdot
.71383 .60332 Mdot
.71384 .60332 Mdot
.71385 .60332 Mdot
.71386 .60332 Mdot
.71387 .60332 Mdot
.71388 .60332 Mdot
.71389 .60332 Mdot
.7139 .60332 Mdot
.7139 .60332 Mdot
.71391 .60332 Mdot
.71392 .60332 Mdot
.71393 .60332 Mdot
.71394 .60332 Mdot
.71395 .60332 Mdot
.71396 .60332 Mdot
.71397 .60332 Mdot
.71398 .60332 Mdot
.71399 .60332 Mdot
.714 .60332 Mdot
.71401 .60332 Mdot
.71402 .60332 Mdot
.71403 .60332 Mdot
.71404 .60332 Mdot
.71405 .60332 Mdot
.71406 .60332 Mdot
.71407 .60332 Mdot
.71408 .60332 Mdot
.71409 .60332 Mdot
.7141 .60332 Mdot
.7141 .60332 Mdot
.71411 .60332 Mdot
.71412 .60332 Mdot
.71413 .60332 Mdot
.71414 .60332 Mdot
.71415 .60332 Mdot
.71416 .60332 Mdot
.71417 .60332 Mdot
.71418 .60332 Mdot
.71419 .60332 Mdot
.7142 .60332 Mdot
.71421 .60332 Mdot
.71422 .60332 Mdot
.71423 .60332 Mdot
.71424 .60332 Mdot
.71425 .60332 Mdot
.71426 .60332 Mdot
.71427 .60332 Mdot
.71428 .60332 Mdot
.71429 .60332 Mdot
.7143 .60332 Mdot
.7143 .60332 Mdot
.71431 .60332 Mdot
.71432 .60332 Mdot
.71433 .60332 Mdot
.71434 .60332 Mdot
.71435 .60332 Mdot
.71436 .60332 Mdot
.71437 .60332 Mdot
.71438 .60332 Mdot
.71439 .60332 Mdot
.7144 .60332 Mdot
.71441 .60332 Mdot
.71442 .60332 Mdot
.71443 .60332 Mdot
.71444 .60332 Mdot
.71445 .60332 Mdot
.71446 .60332 Mdot
.71447 .60332 Mdot
.71448 .60332 Mdot
.71449 .60332 Mdot
.7145 .60332 Mdot
.7145 .60332 Mdot
.71451 .60332 Mdot
.71452 .60332 Mdot
.71453 .60332 Mdot
.71454 .60332 Mdot
.71455 .60332 Mdot
.71456 .60332 Mdot
.71457 .60332 Mdot
.71458 .60332 Mdot
.71459 .60332 Mdot
.7146 .60332 Mdot
.71461 .60332 Mdot
.71462 .60332 Mdot
.71463 .60332 Mdot
.71464 .60332 Mdot
.71465 .60332 Mdot
.71466 .60332 Mdot
.71467 .60332 Mdot
.71468 .60332 Mdot
.71469 .60332 Mdot
.7147 .60332 Mdot
.7147 .60332 Mdot
.71471 .60332 Mdot
.71472 .60332 Mdot
.71473 .60332 Mdot
.71474 .60332 Mdot
.71475 .60332 Mdot
.71476 .60332 Mdot
.71477 .60332 Mdot
.71478 .60332 Mdot
.71479 .60332 Mdot
.7148 .60332 Mdot
.71481 .60332 Mdot
.71482 .60332 Mdot
.71483 .60332 Mdot
.71484 .60332 Mdot
.71485 .60332 Mdot
.71486 .60332 Mdot
.71487 .60332 Mdot
.71488 .60332 Mdot
.71489 .60332 Mdot
.7149 .60332 Mdot
.7149 .60332 Mdot
.71491 .60332 Mdot
.71492 .60332 Mdot
.71493 .60332 Mdot
.71494 .60332 Mdot
.71495 .60332 Mdot
.71496 .60332 Mdot
.71497 .60332 Mdot
.71498 .60332 Mdot
.71499 .60332 Mdot
.715 .60332 Mdot
.71501 .60332 Mdot
.71502 .60332 Mdot
.71503 .60332 Mdot
.71504 .60332 Mdot
.71505 .60332 Mdot
.71506 .60332 Mdot
.71507 .60332 Mdot
.71508 .60332 Mdot
.71509 .60332 Mdot
.7151 .60332 Mdot
.7151 .60332 Mdot
.71511 .60332 Mdot
.71512 .60332 Mdot
.71513 .60332 Mdot
.71514 .60332 Mdot
.71515 .60332 Mdot
.71516 .60332 Mdot
.71517 .60332 Mdot
.71518 .60332 Mdot
.71519 .60332 Mdot
.7152 .60332 Mdot
.71521 .60332 Mdot
.71522 .60332 Mdot
.71523 .60332 Mdot
.71524 .60332 Mdot
.71525 .60332 Mdot
.71526 .60332 Mdot
.71527 .60332 Mdot
.71528 .60332 Mdot
.71529 .60332 Mdot
.7153 .60332 Mdot
.7153 .60331 Mdot
.71531 .60331 Mdot
.71532 .60331 Mdot
.71533 .60331 Mdot
.71534 .60331 Mdot
.71535 .60331 Mdot
.71536 .60331 Mdot
.71537 .60331 Mdot
.71538 .60331 Mdot
.71539 .60331 Mdot
.7154 .60331 Mdot
.71541 .60331 Mdot
.71542 .60331 Mdot
.71543 .60331 Mdot
.71544 .60331 Mdot
.71545 .60331 Mdot
.71546 .60331 Mdot
.71547 .60331 Mdot
.71548 .60331 Mdot
.71549 .60331 Mdot
.7155 .60331 Mdot
.7155 .60331 Mdot
.71551 .60331 Mdot
.71552 .60331 Mdot
.71553 .60331 Mdot
.71554 .60331 Mdot
.71555 .60331 Mdot
.71556 .60331 Mdot
.71557 .60331 Mdot
.71558 .60331 Mdot
.71559 .60331 Mdot
.7156 .60331 Mdot
.71561 .60331 Mdot
.71562 .60331 Mdot
.71563 .60331 Mdot
.71564 .60331 Mdot
.71565 .60331 Mdot
.71566 .60331 Mdot
.71567 .60331 Mdot
.71568 .60331 Mdot
.71569 .60331 Mdot
.7157 .60331 Mdot
.7157 .60331 Mdot
.71571 .60331 Mdot
.71572 .60331 Mdot
.71573 .60331 Mdot
.71574 .60331 Mdot
.71575 .60331 Mdot
.71576 .60331 Mdot
.71577 .60331 Mdot
.71578 .60331 Mdot
.71579 .60331 Mdot
.7158 .60331 Mdot
.71581 .60331 Mdot
.71582 .60331 Mdot
.71583 .60331 Mdot
.71584 .60331 Mdot
.71585 .60331 Mdot
.71586 .60331 Mdot
.71587 .60331 Mdot
.71588 .60331 Mdot
.71589 .60331 Mdot
.7159 .60331 Mdot
.7159 .60331 Mdot
.71591 .60331 Mdot
.71592 .60331 Mdot
.71593 .60331 Mdot
.71594 .60331 Mdot
.71595 .60331 Mdot
.71596 .60331 Mdot
.71597 .60331 Mdot
.71598 .60331 Mdot
.71599 .60331 Mdot
.716 .60331 Mdot
.71601 .60331 Mdot
.71602 .60331 Mdot
.71603 .6033 Mdot
.71604 .6033 Mdot
.71605 .6033 Mdot
.71606 .6033 Mdot
.71607 .6033 Mdot
.71608 .6033 Mdot
.71609 .6033 Mdot
.7161 .6033 Mdot
.7161 .6033 Mdot
.71611 .6033 Mdot
.71612 .6033 Mdot
.71613 .6033 Mdot
.71614 .6033 Mdot
.71615 .6033 Mdot
.71616 .6033 Mdot
.71617 .6033 Mdot
.71618 .6033 Mdot
.71619 .6033 Mdot
.7162 .6033 Mdot
.71621 .6033 Mdot
.71622 .6033 Mdot
.71623 .6033 Mdot
.71624 .6033 Mdot
.71625 .6033 Mdot
.71626 .6033 Mdot
.71627 .6033 Mdot
.71628 .6033 Mdot
.71629 .6033 Mdot
.7163 .6033 Mdot
.7163 .6033 Mdot
.71631 .6033 Mdot
.71632 .6033 Mdot
.71633 .6033 Mdot
.71634 .6033 Mdot
.71635 .6033 Mdot
.71636 .6033 Mdot
.71637 .6033 Mdot
.71638 .6033 Mdot
.71639 .6033 Mdot
.7164 .6033 Mdot
.71641 .6033 Mdot
.71642 .6033 Mdot
.71643 .6033 Mdot
.71644 .6033 Mdot
.71645 .6033 Mdot
.71646 .6033 Mdot
.71647 .6033 Mdot
.71648 .6033 Mdot
.71649 .6033 Mdot
.7165 .6033 Mdot
.7165 .60329 Mdot
.71651 .60329 Mdot
.71652 .60329 Mdot
.71653 .60329 Mdot
.71654 .60329 Mdot
.71655 .60329 Mdot
.71656 .60329 Mdot
.71657 .60329 Mdot
.71658 .60329 Mdot
.71659 .60329 Mdot
.7166 .60329 Mdot
.71661 .60329 Mdot
.71662 .60329 Mdot
.71663 .60329 Mdot
.71664 .60329 Mdot
.71665 .60329 Mdot
.71666 .60329 Mdot
.71667 .60329 Mdot
.71668 .60329 Mdot
.71669 .60329 Mdot
.7167 .60329 Mdot
.7167 .60329 Mdot
.71671 .60329 Mdot
.71672 .60329 Mdot
.71673 .60329 Mdot
.71674 .60329 Mdot
.71675 .60329 Mdot
.71676 .60329 Mdot
.71677 .60329 Mdot
.71678 .60329 Mdot
.71679 .60329 Mdot
.7168 .60329 Mdot
.71681 .60329 Mdot
.71682 .60329 Mdot
.71683 .60329 Mdot
.71684 .60329 Mdot
.71685 .60329 Mdot
.71686 .60329 Mdot
.71687 .60329 Mdot
.71688 .60329 Mdot
.71689 .60328 Mdot
.7169 .60328 Mdot
.7169 .60328 Mdot
.71691 .60328 Mdot
.71692 .60328 Mdot
.71693 .60328 Mdot
.71694 .60328 Mdot
.71695 .60328 Mdot
.71696 .60328 Mdot
.71697 .60328 Mdot
.71698 .60328 Mdot
.71699 .60328 Mdot
.717 .60328 Mdot
.71701 .60328 Mdot
.71702 .60328 Mdot
.71703 .60328 Mdot
.71704 .60328 Mdot
.71705 .60328 Mdot
.71706 .60328 Mdot
.71707 .60328 Mdot
.71708 .60328 Mdot
.71709 .60328 Mdot
.7171 .60328 Mdot
.7171 .60328 Mdot
.71711 .60328 Mdot
.71712 .60328 Mdot
.71713 .60328 Mdot
.71714 .60328 Mdot
.71715 .60328 Mdot
.71716 .60328 Mdot
.71717 .60328 Mdot
.71718 .60328 Mdot
.71719 .60328 Mdot
.7172 .60328 Mdot
.71721 .60328 Mdot
.71722 .60327 Mdot
.71723 .60327 Mdot
.71724 .60327 Mdot
.71725 .60327 Mdot
.71726 .60327 Mdot
.71727 .60327 Mdot
.71728 .60327 Mdot
.71729 .60327 Mdot
.7173 .60327 Mdot
.7173 .60327 Mdot
.71731 .60327 Mdot
.71732 .60327 Mdot
.71733 .60327 Mdot
.71734 .60327 Mdot
.71735 .60327 Mdot
.71736 .60327 Mdot
.71737 .60327 Mdot
.71738 .60327 Mdot
.71739 .60327 Mdot
.7174 .60327 Mdot
.71741 .60327 Mdot
.71742 .60327 Mdot
.71743 .60327 Mdot
.71744 .60327 Mdot
.71745 .60327 Mdot
.71746 .60327 Mdot
.71747 .60327 Mdot
.71748 .60327 Mdot
.71749 .60327 Mdot
.7175 .60327 Mdot
.7175 .60327 Mdot
.71751 .60326 Mdot
.71752 .60326 Mdot
.71753 .60326 Mdot
.71754 .60326 Mdot
.71755 .60326 Mdot
.71756 .60326 Mdot
.71757 .60326 Mdot
.71758 .60326 Mdot
.71759 .60326 Mdot
.7176 .60326 Mdot
.71761 .60326 Mdot
.71762 .60326 Mdot
.71763 .60326 Mdot
.71764 .60326 Mdot
.71765 .60326 Mdot
.71766 .60326 Mdot
.71767 .60326 Mdot
.71768 .60326 Mdot
.71769 .60326 Mdot
.7177 .60326 Mdot
.7177 .60326 Mdot
.71771 .60326 Mdot
.71772 .60326 Mdot
.71773 .60326 Mdot
.71774 .60326 Mdot
.71775 .60326 Mdot
.71776 .60326 Mdot
.71777 .60326 Mdot
.71778 .60325 Mdot
.71779 .60325 Mdot
.7178 .60325 Mdot
.71781 .60325 Mdot
.71782 .60325 Mdot
.71783 .60325 Mdot
.71784 .60325 Mdot
.71785 .60325 Mdot
.71786 .60325 Mdot
.71787 .60325 Mdot
.71788 .60325 Mdot
.71789 .60325 Mdot
.7179 .60325 Mdot
.7179 .60325 Mdot
.71791 .60325 Mdot
.71792 .60325 Mdot
.71793 .60325 Mdot
.71794 .60325 Mdot
.71795 .60325 Mdot
.71796 .60325 Mdot
.71797 .60325 Mdot
.71798 .60325 Mdot
.71799 .60325 Mdot
.718 .60325 Mdot
.71801 .60325 Mdot
.71802 .60325 Mdot
.71803 .60324 Mdot
.71804 .60324 Mdot
.71805 .60324 Mdot
.71806 .60324 Mdot
.71807 .60324 Mdot
.71808 .60324 Mdot
.71809 .60324 Mdot
.7181 .60324 Mdot
.7181 .60324 Mdot
.71811 .60324 Mdot
.71812 .60324 Mdot
.71813 .60324 Mdot
.71814 .60324 Mdot
.71815 .60324 Mdot
.71816 .60324 Mdot
.71817 .60324 Mdot
.71818 .60324 Mdot
.71819 .60324 Mdot
.7182 .60324 Mdot
.71821 .60324 Mdot
.71822 .60324 Mdot
.71823 .60324 Mdot
.71824 .60324 Mdot
.71825 .60324 Mdot
.71826 .60324 Mdot
.71827 .60323 Mdot
.71828 .60323 Mdot
.71829 .60323 Mdot
.7183 .60323 Mdot
.7183 .60323 Mdot
.71831 .60323 Mdot
.71832 .60323 Mdot
.71833 .60323 Mdot
.71834 .60323 Mdot
.71835 .60323 Mdot
.71836 .60323 Mdot
.71837 .60323 Mdot
.71838 .60323 Mdot
.71839 .60323 Mdot
.7184 .60323 Mdot
.71841 .60323 Mdot
.71842 .60323 Mdot
.71843 .60323 Mdot
.71844 .60323 Mdot
.71845 .60323 Mdot
.71846 .60323 Mdot
.71847 .60323 Mdot
.71848 .60323 Mdot
.71849 .60322 Mdot
.7185 .60322 Mdot
.7185 .60322 Mdot
.71851 .60322 Mdot
.71852 .60322 Mdot
.71853 .60322 Mdot
.71854 .60322 Mdot
.71855 .60322 Mdot
.71856 .60322 Mdot
.71857 .60322 Mdot
.71858 .60322 Mdot
.71859 .60322 Mdot
.7186 .60322 Mdot
.71861 .60322 Mdot
.71862 .60322 Mdot
.71863 .60322 Mdot
.71864 .60322 Mdot
.71865 .60322 Mdot
.71866 .60322 Mdot
.71867 .60322 Mdot
.71868 .60322 Mdot
.71869 .60321 Mdot
.7187 .60321 Mdot
.7187 .60321 Mdot
.71871 .60321 Mdot
.71872 .60321 Mdot
.71873 .60321 Mdot
.71874 .60321 Mdot
.71875 .60321 Mdot
.71876 .60321 Mdot
.71877 .60321 Mdot
.71878 .60321 Mdot
.71879 .60321 Mdot
.7188 .60321 Mdot
.71881 .60321 Mdot
.71882 .60321 Mdot
.71883 .60321 Mdot
.71884 .60321 Mdot
.71885 .60321 Mdot
.71886 .60321 Mdot
.71887 .60321 Mdot
.71888 .60321 Mdot
.71889 .6032 Mdot
.7189 .6032 Mdot
.7189 .6032 Mdot
.71891 .6032 Mdot
.71892 .6032 Mdot
.71893 .6032 Mdot
.71894 .6032 Mdot
.71895 .6032 Mdot
.71896 .6032 Mdot
.71897 .6032 Mdot
.71898 .6032 Mdot
.71899 .6032 Mdot
.719 .6032 Mdot
.71901 .6032 Mdot
.71902 .6032 Mdot
.71903 .6032 Mdot
.71904 .6032 Mdot
.71905 .6032 Mdot
.71906 .6032 Mdot
.71907 .6032 Mdot
.71908 .60319 Mdot
.71909 .60319 Mdot
.7191 .60319 Mdot
.7191 .60319 Mdot
.71911 .60319 Mdot
.71912 .60319 Mdot
.71913 .60319 Mdot
.71914 .60319 Mdot
.71915 .60319 Mdot
.71916 .60319 Mdot
.71917 .60319 Mdot
.71918 .60319 Mdot
.71919 .60319 Mdot
.7192 .60319 Mdot
.71921 .60319 Mdot
.71922 .60319 Mdot
.71923 .60319 Mdot
.71924 .60319 Mdot
.71925 .60319 Mdot
.71926 .60318 Mdot
.71927 .60318 Mdot
.71928 .60318 Mdot
.71929 .60318 Mdot
.7193 .60318 Mdot
.7193 .60318 Mdot
.71931 .60318 Mdot
.71932 .60318 Mdot
.71933 .60318 Mdot
.71934 .60318 Mdot
.71935 .60318 Mdot
.71936 .60318 Mdot
.71937 .60318 Mdot
.71938 .60318 Mdot
.71939 .60318 Mdot
.7194 .60318 Mdot
.71941 .60318 Mdot
.71942 .60318 Mdot
.71943 .60318 Mdot
.71944 .60317 Mdot
.71945 .60317 Mdot
.71946 .60317 Mdot
.71947 .60317 Mdot
.71948 .60317 Mdot
.71949 .60317 Mdot
.7195 .60317 Mdot
.7195 .60317 Mdot
.71951 .60317 Mdot
.71952 .60317 Mdot
.71953 .60317 Mdot
.71954 .60317 Mdot
.71955 .60317 Mdot
.71956 .60317 Mdot
.71957 .60317 Mdot
.71958 .60317 Mdot
.71959 .60317 Mdot
.7196 .60316 Mdot
.71961 .60316 Mdot
.71962 .60316 Mdot
.71963 .60316 Mdot
.71964 .60316 Mdot
.71965 .60316 Mdot
.71966 .60316 Mdot
.71967 .60316 Mdot
.71968 .60316 Mdot
.71969 .60316 Mdot
.7197 .60316 Mdot
.7197 .60316 Mdot
.71971 .60316 Mdot
.71972 .60316 Mdot
.71973 .60316 Mdot
.71974 .60316 Mdot
.71975 .60316 Mdot
.71976 .60315 Mdot
.71977 .60315 Mdot
.71978 .60315 Mdot
.71979 .60315 Mdot
.7198 .60315 Mdot
.71981 .60315 Mdot
.71982 .60315 Mdot
.71983 .60315 Mdot
.71984 .60315 Mdot
.71985 .60315 Mdot
.71986 .60315 Mdot
.71987 .60315 Mdot
.71988 .60315 Mdot
.71989 .60315 Mdot
.7199 .60315 Mdot
.7199 .60315 Mdot
.71991 .60315 Mdot
.71992 .60314 Mdot
.71993 .60314 Mdot
.71994 .60314 Mdot
.71995 .60314 Mdot
.71996 .60314 Mdot
.71997 .60314 Mdot
.71998 .60314 Mdot
.71999 .60314 Mdot
.72 .60314 Mdot
.72001 .60314 Mdot
.72002 .60314 Mdot
.72003 .60314 Mdot
.72004 .60314 Mdot
.72005 .60314 Mdot
.72006 .60314 Mdot
.72007 .60314 Mdot
.72008 .60313 Mdot
.72009 .60313 Mdot
.7201 .60313 Mdot
.7201 .60313 Mdot
.72011 .60313 Mdot
.72012 .60313 Mdot
.72013 .60313 Mdot
.72014 .60313 Mdot
.72015 .60313 Mdot
.72016 .60313 Mdot
.72017 .60313 Mdot
.72018 .60313 Mdot
.72019 .60313 Mdot
.7202 .60313 Mdot
.72021 .60313 Mdot
.72022 .60313 Mdot
.72023 .60312 Mdot
.72024 .60312 Mdot
.72025 .60312 Mdot
.72026 .60312 Mdot
.72027 .60312 Mdot
.72028 .60312 Mdot
.72029 .60312 Mdot
.7203 .60312 Mdot
.7203 .60312 Mdot
.72031 .60312 Mdot
.72032 .60312 Mdot
.72033 .60312 Mdot
.72034 .60312 Mdot
.72035 .60312 Mdot
.72036 .60312 Mdot
.72037 .60311 Mdot
.72038 .60311 Mdot
.72039 .60311 Mdot
.7204 .60311 Mdot
.72041 .60311 Mdot
.72042 .60311 Mdot
.72043 .60311 Mdot
.72044 .60311 Mdot
.72045 .60311 Mdot
.72046 .60311 Mdot
.72047 .60311 Mdot
.72048 .60311 Mdot
.72049 .60311 Mdot
.7205 .60311 Mdot
.7205 .60311 Mdot
.72051 .6031 Mdot
.72052 .6031 Mdot
.72053 .6031 Mdot
.72054 .6031 Mdot
.72055 .6031 Mdot
.72056 .6031 Mdot
.72057 .6031 Mdot
.72058 .6031 Mdot
.72059 .6031 Mdot
.7206 .6031 Mdot
.72061 .6031 Mdot
.72062 .6031 Mdot
.72063 .6031 Mdot
.72064 .6031 Mdot
.72065 .6031 Mdot
.72066 .60309 Mdot
.72067 .60309 Mdot
.72068 .60309 Mdot
.72069 .60309 Mdot
.7207 .60309 Mdot
.7207 .60309 Mdot
.72071 .60309 Mdot
.72072 .60309 Mdot
.72073 .60309 Mdot
.72074 .60309 Mdot
.72075 .60309 Mdot
.72076 .60309 Mdot
.72077 .60309 Mdot
.72078 .60309 Mdot
.72079 .60308 Mdot
.7208 .60308 Mdot
.72081 .60308 Mdot
.72082 .60308 Mdot
.72083 .60308 Mdot
.72084 .60308 Mdot
.72085 .60308 Mdot
.72086 .60308 Mdot
.72087 .60308 Mdot
.72088 .60308 Mdot
.72089 .60308 Mdot
.7209 .60308 Mdot
.7209 .60308 Mdot
.72091 .60308 Mdot
.72092 .60307 Mdot
.72093 .60307 Mdot
.72094 .60307 Mdot
.72095 .60307 Mdot
.72096 .60307 Mdot
.72097 .60307 Mdot
.72098 .60307 Mdot
.72099 .60307 Mdot
.721 .60307 Mdot
.72101 .60307 Mdot
.72102 .60307 Mdot
.72103 .60307 Mdot
.72104 .60307 Mdot
.72105 .60307 Mdot
.72106 .60306 Mdot
.72107 .60306 Mdot
.72108 .60306 Mdot
.72109 .60306 Mdot
.7211 .60306 Mdot
.7211 .60306 Mdot
.72111 .60306 Mdot
.72112 .60306 Mdot
.72113 .60306 Mdot
.72114 .60306 Mdot
.72115 .60306 Mdot
.72116 .60306 Mdot
.72117 .60306 Mdot
.72118 .60306 Mdot
.72119 .60305 Mdot
.7212 .60305 Mdot
.72121 .60305 Mdot
.72122 .60305 Mdot
.72123 .60305 Mdot
.72124 .60305 Mdot
.72125 .60305 Mdot
.72126 .60305 Mdot
.72127 .60305 Mdot
.72128 .60305 Mdot
.72129 .60305 Mdot
.7213 .60305 Mdot
.7213 .60305 Mdot
.72131 .60304 Mdot
.72132 .60304 Mdot
.72133 .60304 Mdot
.72134 .60304 Mdot
.72135 .60304 Mdot
.72136 .60304 Mdot
.72137 .60304 Mdot
.72138 .60304 Mdot
.72139 .60304 Mdot
.7214 .60304 Mdot
.72141 .60304 Mdot
.72142 .60304 Mdot
.72143 .60304 Mdot
.72144 .60303 Mdot
.72145 .60303 Mdot
.72146 .60303 Mdot
.72147 .60303 Mdot
.72148 .60303 Mdot
.72149 .60303 Mdot
.7215 .60303 Mdot
.7215 .60303 Mdot
.72151 .60303 Mdot
.72152 .60303 Mdot
.72153 .60303 Mdot
.72154 .60303 Mdot
.72155 .60303 Mdot
.72156 .60302 Mdot
.72157 .60302 Mdot
.72158 .60302 Mdot
.72159 .60302 Mdot
.7216 .60302 Mdot
.72161 .60302 Mdot
.72162 .60302 Mdot
.72163 .60302 Mdot
.72164 .60302 Mdot
.72165 .60302 Mdot
.72166 .60302 Mdot
.72167 .60302 Mdot
.72168 .60301 Mdot
.72169 .60301 Mdot
.7217 .60301 Mdot
.7217 .60301 Mdot
.72171 .60301 Mdot
.72172 .60301 Mdot
.72173 .60301 Mdot
.72174 .60301 Mdot
.72175 .60301 Mdot
.72176 .60301 Mdot
.72177 .60301 Mdot
.72178 .60301 Mdot
.72179 .60301 Mdot
.7218 .603 Mdot
.72181 .603 Mdot
.72182 .603 Mdot
.72183 .603 Mdot
.72184 .603 Mdot
.72185 .603 Mdot
.72186 .603 Mdot
.72187 .603 Mdot
.72188 .603 Mdot
.72189 .603 Mdot
.7219 .603 Mdot
.7219 .603 Mdot
.72191 .60299 Mdot
.72192 .60299 Mdot
.72193 .60299 Mdot
.72194 .60299 Mdot
.72195 .60299 Mdot
.72196 .60299 Mdot
.72197 .60299 Mdot
.72198 .60299 Mdot
.72199 .60299 Mdot
.722 .60299 Mdot
.72201 .60299 Mdot
.72202 .60299 Mdot
.72203 .60298 Mdot
.72204 .60298 Mdot
.72205 .60298 Mdot
.72206 .60298 Mdot
.72207 .60298 Mdot
.72208 .60298 Mdot
.72209 .60298 Mdot
.7221 .60298 Mdot
.7221 .60298 Mdot
.72211 .60298 Mdot
.72212 .60298 Mdot
.72213 .60297 Mdot
.72214 .60297 Mdot
.72215 .60297 Mdot
.72216 .60297 Mdot
.72217 .60297 Mdot
.72218 .60297 Mdot
.72219 .60297 Mdot
.7222 .60297 Mdot
.72221 .60297 Mdot
.72222 .60297 Mdot
.72223 .60297 Mdot
.72224 .60297 Mdot
.72225 .60296 Mdot
.72226 .60296 Mdot
.72227 .60296 Mdot
.72228 .60296 Mdot
.72229 .60296 Mdot
.7223 .60296 Mdot
.7223 .60296 Mdot
.72231 .60296 Mdot
.72232 .60296 Mdot
.72233 .60296 Mdot
.72234 .60296 Mdot
.72235 .60296 Mdot
.72236 .60295 Mdot
.72237 .60295 Mdot
.72238 .60295 Mdot
.72239 .60295 Mdot
.7224 .60295 Mdot
.72241 .60295 Mdot
.72242 .60295 Mdot
.72243 .60295 Mdot
.72244 .60295 Mdot
.72245 .60295 Mdot
.72246 .60295 Mdot
.72247 .60294 Mdot
.72248 .60294 Mdot
.72249 .60294 Mdot
.7225 .60294 Mdot
.7225 .60294 Mdot
.72251 .60294 Mdot
.72252 .60294 Mdot
.72253 .60294 Mdot
.72254 .60294 Mdot
.72255 .60294 Mdot
.72256 .60294 Mdot
.72257 .60293 Mdot
.72258 .60293 Mdot
.72259 .60293 Mdot
.7226 .60293 Mdot
.72261 .60293 Mdot
.72262 .60293 Mdot
.72263 .60293 Mdot
.72264 .60293 Mdot
.72265 .60293 Mdot
.72266 .60293 Mdot
.72267 .60293 Mdot
.72268 .60292 Mdot
.72269 .60292 Mdot
.7227 .60292 Mdot
.7227 .60292 Mdot
.72271 .60292 Mdot
.72272 .60292 Mdot
.72273 .60292 Mdot
.72274 .60292 Mdot
.72275 .60292 Mdot
.72276 .60292 Mdot
.72277 .60292 Mdot
.72278 .60291 Mdot
.72279 .60291 Mdot
.7228 .60291 Mdot
.72281 .60291 Mdot
.72282 .60291 Mdot
.72283 .60291 Mdot
.72284 .60291 Mdot
.72285 .60291 Mdot
.72286 .60291 Mdot
.72287 .60291 Mdot
.72288 .60291 Mdot
.72289 .6029 Mdot
.7229 .6029 Mdot
.7229 .6029 Mdot
.72291 .6029 Mdot
.72292 .6029 Mdot
.72293 .6029 Mdot
.72294 .6029 Mdot
.72295 .6029 Mdot
.72296 .6029 Mdot
.72297 .6029 Mdot
.72298 .60289 Mdot
.72299 .60289 Mdot
.723 .60289 Mdot
.72301 .60289 Mdot
.72302 .60289 Mdot
.72303 .60289 Mdot
.72304 .60289 Mdot
.72305 .60289 Mdot
.72306 .60289 Mdot
.72307 .60289 Mdot
.72308 .60289 Mdot
.72309 .60288 Mdot
.7231 .60288 Mdot
.7231 .60288 Mdot
.72311 .60288 Mdot
.72312 .60288 Mdot
.72313 .60288 Mdot
.72314 .60288 Mdot
.72315 .60288 Mdot
.72316 .60288 Mdot
.72317 .60288 Mdot
.72318 .60287 Mdot
.72319 .60287 Mdot
.7232 .60287 Mdot
.72321 .60287 Mdot
.72322 .60287 Mdot
.72323 .60287 Mdot
.72324 .60287 Mdot
.72325 .60287 Mdot
.72326 .60287 Mdot
.72327 .60287 Mdot
.72328 .60286 Mdot
.72329 .60286 Mdot
.7233 .60286 Mdot
.7233 .60286 Mdot
.72331 .60286 Mdot
.72332 .60286 Mdot
.72333 .60286 Mdot
.72334 .60286 Mdot
.72335 .60286 Mdot
.72336 .60286 Mdot
.72337 .60285 Mdot
.72338 .60285 Mdot
.72339 .60285 Mdot
.7234 .60285 Mdot
.72341 .60285 Mdot
.72342 .60285 Mdot
.72343 .60285 Mdot
.72344 .60285 Mdot
.72345 .60285 Mdot
.72346 .60285 Mdot
.72347 .60284 Mdot
.72348 .60284 Mdot
.72349 .60284 Mdot
.7235 .60284 Mdot
.7235 .60284 Mdot
.72351 .60284 Mdot
.72352 .60284 Mdot
.72353 .60284 Mdot
.72354 .60284 Mdot
.72355 .60284 Mdot
.72356 .60283 Mdot
.72357 .60283 Mdot
.72358 .60283 Mdot
.72359 .60283 Mdot
.7236 .60283 Mdot
.72361 .60283 Mdot
.72362 .60283 Mdot
.72363 .60283 Mdot
.72364 .60283 Mdot
.72365 .60283 Mdot
.72366 .60282 Mdot
.72367 .60282 Mdot
.72368 .60282 Mdot
.72369 .60282 Mdot
.7237 .60282 Mdot
.7237 .60282 Mdot
.72371 .60282 Mdot
.72372 .60282 Mdot
.72373 .60282 Mdot
.72374 .60282 Mdot
.72375 .60281 Mdot
.72376 .60281 Mdot
.72377 .60281 Mdot
.72378 .60281 Mdot
.72379 .60281 Mdot
.7238 .60281 Mdot
.72381 .60281 Mdot
.72382 .60281 Mdot
.72383 .60281 Mdot
.72384 .60281 Mdot
.72385 .6028 Mdot
.72386 .6028 Mdot
.72387 .6028 Mdot
.72388 .6028 Mdot
.72389 .6028 Mdot
.7239 .6028 Mdot
.7239 .6028 Mdot
.72391 .6028 Mdot
.72392 .6028 Mdot
.72393 .60279 Mdot
.72394 .60279 Mdot
.72395 .60279 Mdot
.72396 .60279 Mdot
.72397 .60279 Mdot
.72398 .60279 Mdot
.72399 .60279 Mdot
.724 .60279 Mdot
.72401 .60279 Mdot
.72402 .60279 Mdot
.72403 .60278 Mdot
.72404 .60278 Mdot
.72405 .60278 Mdot
.72406 .60278 Mdot
.72407 .60278 Mdot
.72408 .60278 Mdot
.72409 .60278 Mdot
.7241 .60278 Mdot
.7241 .60278 Mdot
.72411 .60277 Mdot
.72412 .60277 Mdot
.72413 .60277 Mdot
.72414 .60277 Mdot
.72415 .60277 Mdot
.72416 .60277 Mdot
.72417 .60277 Mdot
.72418 .60277 Mdot
.72419 .60277 Mdot
.7242 .60276 Mdot
.72421 .60276 Mdot
.72422 .60276 Mdot
.72423 .60276 Mdot
.72424 .60276 Mdot
.72425 .60276 Mdot
.72426 .60276 Mdot
.72427 .60276 Mdot
.72428 .60276 Mdot
.72429 .60275 Mdot
.7243 .60275 Mdot
.7243 .60275 Mdot
.72431 .60275 Mdot
.72432 .60275 Mdot
.72433 .60275 Mdot
.72434 .60275 Mdot
.72435 .60275 Mdot
.72436 .60275 Mdot
.72437 .60275 Mdot
.72438 .60274 Mdot
.72439 .60274 Mdot
.7244 .60274 Mdot
.72441 .60274 Mdot
.72442 .60274 Mdot
.72443 .60274 Mdot
.72444 .60274 Mdot
.72445 .60274 Mdot
.72446 .60274 Mdot
.72447 .60273 Mdot
.72448 .60273 Mdot
.72449 .60273 Mdot
.7245 .60273 Mdot
.7245 .60273 Mdot
.72451 .60273 Mdot
.72452 .60273 Mdot
.72453 .60273 Mdot
.72454 .60273 Mdot
.72455 .60272 Mdot
.72456 .60272 Mdot
.72457 .60272 Mdot
.72458 .60272 Mdot
.72459 .60272 Mdot
.7246 .60272 Mdot
.72461 .60272 Mdot
.72462 .60272 Mdot
.72463 .60271 Mdot
.72464 .60271 Mdot
.72465 .60271 Mdot
.72466 .60271 Mdot
.72467 .60271 Mdot
.72468 .60271 Mdot
.72469 .60271 Mdot
.7247 .60271 Mdot
.7247 .60271 Mdot
.72471 .6027 Mdot
.72472 .6027 Mdot
.72473 .6027 Mdot
.72474 .6027 Mdot
.72475 .6027 Mdot
.72476 .6027 Mdot
.72477 .6027 Mdot
.72478 .6027 Mdot
.72479 .6027 Mdot
.7248 .60269 Mdot
.72481 .60269 Mdot
.72482 .60269 Mdot
.72483 .60269 Mdot
.72484 .60269 Mdot
.72485 .60269 Mdot
.72486 .60269 Mdot
.72487 .60269 Mdot
.72488 .60269 Mdot
.72489 .60268 Mdot
.7249 .60268 Mdot
.7249 .60268 Mdot
.72491 .60268 Mdot
.72492 .60268 Mdot
.72493 .60268 Mdot
.72494 .60268 Mdot
.72495 .60268 Mdot
.72496 .60267 Mdot
.72497 .60267 Mdot
.72498 .60267 Mdot
.72499 .60267 Mdot
.725 .60267 Mdot
.72501 .60267 Mdot
.72502 .60267 Mdot
.72503 .60267 Mdot
.72504 .60267 Mdot
.72505 .60266 Mdot
.72506 .60266 Mdot
.72507 .60266 Mdot
.72508 .60266 Mdot
.72509 .60266 Mdot
.7251 .60266 Mdot
.7251 .60266 Mdot
.72511 .60266 Mdot
.72512 .60265 Mdot
.72513 .60265 Mdot
.72514 .60265 Mdot
.72515 .60265 Mdot
.72516 .60265 Mdot
.72517 .60265 Mdot
.72518 .60265 Mdot
.72519 .60265 Mdot
.7252 .60265 Mdot
.72521 .60264 Mdot
.72522 .60264 Mdot
.72523 .60264 Mdot
.72524 .60264 Mdot
.72525 .60264 Mdot
.72526 .60264 Mdot
.72527 .60264 Mdot
.72528 .60264 Mdot
.72529 .60263 Mdot
.7253 .60263 Mdot
.7253 .60263 Mdot
.72531 .60263 Mdot
.72532 .60263 Mdot
.72533 .60263 Mdot
.72534 .60263 Mdot
.72535 .60263 Mdot
.72536 .60262 Mdot
.72537 .60262 Mdot
.72538 .60262 Mdot
.72539 .60262 Mdot
.7254 .60262 Mdot
.72541 .60262 Mdot
.72542 .60262 Mdot
.72543 .60262 Mdot
.72544 .60261 Mdot
.72545 .60261 Mdot
.72546 .60261 Mdot
.72547 .60261 Mdot
.72548 .60261 Mdot
.72549 .60261 Mdot
.7255 .60261 Mdot
.7255 .60261 Mdot
.72551 .60261 Mdot
.72552 .6026 Mdot
.72553 .6026 Mdot
.72554 .6026 Mdot
.72555 .6026 Mdot
.72556 .6026 Mdot
.72557 .6026 Mdot
.72558 .6026 Mdot
.72559 .6026 Mdot
.7256 .60259 Mdot
.72561 .60259 Mdot
.72562 .60259 Mdot
.72563 .60259 Mdot
.72564 .60259 Mdot
.72565 .60259 Mdot
.72566 .60259 Mdot
.72567 .60259 Mdot
.72568 .60258 Mdot
.72569 .60258 Mdot
.7257 .60258 Mdot
.7257 .60258 Mdot
.72571 .60258 Mdot
.72572 .60258 Mdot
.72573 .60258 Mdot
.72574 .60258 Mdot
.72575 .60257 Mdot
.72576 .60257 Mdot
.72577 .60257 Mdot
.72578 .60257 Mdot
.72579 .60257 Mdot
.7258 .60257 Mdot
.72581 .60257 Mdot
.72582 .60257 Mdot
.72583 .60256 Mdot
.72584 .60256 Mdot
.72585 .60256 Mdot
.72586 .60256 Mdot
.72587 .60256 Mdot
.72588 .60256 Mdot
.72589 .60256 Mdot
.7259 .60256 Mdot
.7259 .60255 Mdot
.72591 .60255 Mdot
.72592 .60255 Mdot
.72593 .60255 Mdot
.72594 .60255 Mdot
.72595 .60255 Mdot
.72596 .60255 Mdot
.72597 .60255 Mdot
.72598 .60254 Mdot
.72599 .60254 Mdot
.726 .60254 Mdot
.72601 .60254 Mdot
.72602 .60254 Mdot
.72603 .60254 Mdot
.72604 .60254 Mdot
.72605 .60253 Mdot
.72606 .60253 Mdot
.72607 .60253 Mdot
.72608 .60253 Mdot
.72609 .60253 Mdot
.7261 .60253 Mdot
.7261 .60253 Mdot
.72611 .60253 Mdot
.72612 .60252 Mdot
.72613 .60252 Mdot
.72614 .60252 Mdot
.72615 .60252 Mdot
.72616 .60252 Mdot
.72617 .60252 Mdot
.72618 .60252 Mdot
.72619 .60252 Mdot
.7262 .60251 Mdot
.72621 .60251 Mdot
.72622 .60251 Mdot
.72623 .60251 Mdot
.72624 .60251 Mdot
.72625 .60251 Mdot
.72626 .60251 Mdot
.72627 .6025 Mdot
.72628 .6025 Mdot
.72629 .6025 Mdot
.7263 .6025 Mdot
.7263 .6025 Mdot
.72631 .6025 Mdot
.72632 .6025 Mdot
.72633 .6025 Mdot
.72634 .60249 Mdot
.72635 .60249 Mdot
.72636 .60249 Mdot
.72637 .60249 Mdot
.72638 .60249 Mdot
.72639 .60249 Mdot
.7264 .60249 Mdot
.72641 .60249 Mdot
.72642 .60248 Mdot
.72643 .60248 Mdot
.72644 .60248 Mdot
.72645 .60248 Mdot
.72646 .60248 Mdot
.72647 .60248 Mdot
.72648 .60248 Mdot
.72649 .60247 Mdot
.7265 .60247 Mdot
.7265 .60247 Mdot
.72651 .60247 Mdot
.72652 .60247 Mdot
.72653 .60247 Mdot
.72654 .60247 Mdot
.72655 .60247 Mdot
.72656 .60246 Mdot
.72657 .60246 Mdot
.72658 .60246 Mdot
.72659 .60246 Mdot
.7266 .60246 Mdot
.72661 .60246 Mdot
.72662 .60246 Mdot
.72663 .60245 Mdot
.72664 .60245 Mdot
.72665 .60245 Mdot
.72666 .60245 Mdot
.72667 .60245 Mdot
.72668 .60245 Mdot
.72669 .60245 Mdot
.7267 .60244 Mdot
.7267 .60244 Mdot
.72671 .60244 Mdot
.72672 .60244 Mdot
.72673 .60244 Mdot
.72674 .60244 Mdot
.72675 .60244 Mdot
.72676 .60244 Mdot
.72677 .60243 Mdot
.72678 .60243 Mdot
.72679 .60243 Mdot
.7268 .60243 Mdot
.72681 .60243 Mdot
.72682 .60243 Mdot
.72683 .60243 Mdot
.72684 .60242 Mdot
.72685 .60242 Mdot
.72686 .60242 Mdot
.72687 .60242 Mdot
.72688 .60242 Mdot
.72689 .60242 Mdot
.7269 .60242 Mdot
.7269 .60241 Mdot
.72691 .60241 Mdot
.72692 .60241 Mdot
.72693 .60241 Mdot
.72694 .60241 Mdot
.72695 .60241 Mdot
.72696 .60241 Mdot
.72697 .60241 Mdot
.72698 .6024 Mdot
.72699 .6024 Mdot
.727 .6024 Mdot
.72701 .6024 Mdot
.72702 .6024 Mdot
.72703 .6024 Mdot
.72704 .6024 Mdot
.72705 .60239 Mdot
.72706 .60239 Mdot
.72707 .60239 Mdot
.72708 .60239 Mdot
.72709 .60239 Mdot
.7271 .60239 Mdot
.7271 .60239 Mdot
.72711 .60238 Mdot
.72712 .60238 Mdot
.72713 .60238 Mdot
.72714 .60238 Mdot
.72715 .60238 Mdot
.72716 .60238 Mdot
.72717 .60238 Mdot
.72718 .60237 Mdot
.72719 .60237 Mdot
.7272 .60237 Mdot
.72721 .60237 Mdot
.72722 .60237 Mdot
.72723 .60237 Mdot
.72724 .60237 Mdot
.72725 .60236 Mdot
.72726 .60236 Mdot
.72727 .60236 Mdot
.72728 .60236 Mdot
.72729 .60236 Mdot
.7273 .60236 Mdot
.7273 .60236 Mdot
.72731 .60235 Mdot
.72732 .60235 Mdot
.72733 .60235 Mdot
.72734 .60235 Mdot
.72735 .60235 Mdot
.72736 .60235 Mdot
.72737 .60235 Mdot
.72738 .60234 Mdot
.72739 .60234 Mdot
.7274 .60234 Mdot
.72741 .60234 Mdot
.72742 .60234 Mdot
.72743 .60234 Mdot
.72744 .60234 Mdot
.72745 .60233 Mdot
.72746 .60233 Mdot
.72747 .60233 Mdot
.72748 .60233 Mdot
.72749 .60233 Mdot
.7275 .60233 Mdot
.7275 .60233 Mdot
.72751 .60232 Mdot
.72752 .60232 Mdot
.72753 .60232 Mdot
.72754 .60232 Mdot
.72755 .60232 Mdot
.72756 .60232 Mdot
.72757 .60232 Mdot
.72758 .60231 Mdot
.72759 .60231 Mdot
.7276 .60231 Mdot
.72761 .60231 Mdot
.72762 .60231 Mdot
.72763 .60231 Mdot
.72764 .60231 Mdot
.72765 .6023 Mdot
.72766 .6023 Mdot
.72767 .6023 Mdot
.72768 .6023 Mdot
.72769 .6023 Mdot
.7277 .6023 Mdot
.7277 .6023 Mdot
.72771 .60229 Mdot
.72772 .60229 Mdot
.72773 .60229 Mdot
.72774 .60229 Mdot
.72775 .60229 Mdot
.72776 .60229 Mdot
.72777 .60228 Mdot
.72778 .60228 Mdot
.72779 .60228 Mdot
.7278 .60228 Mdot
.72781 .60228 Mdot
.72782 .60228 Mdot
.72783 .60228 Mdot
.72784 .60227 Mdot
.72785 .60227 Mdot
.72786 .60227 Mdot
.72787 .60227 Mdot
.72788 .60227 Mdot
.72789 .60227 Mdot
.7279 .60227 Mdot
.7279 .60226 Mdot
.72791 .60226 Mdot
.72792 .60226 Mdot
.72793 .60226 Mdot
.72794 .60226 Mdot
.72795 .60226 Mdot
.72796 .60226 Mdot
.72797 .60225 Mdot
.72798 .60225 Mdot
.72799 .60225 Mdot
.728 .60225 Mdot
.72801 .60225 Mdot
.72802 .60225 Mdot
.72803 .60224 Mdot
.72804 .60224 Mdot
.72805 .60224 Mdot
.72806 .60224 Mdot
.72807 .60224 Mdot
.72808 .60224 Mdot
.72809 .60224 Mdot
.7281 .60223 Mdot
.7281 .60223 Mdot
.72811 .60223 Mdot
.72812 .60223 Mdot
.72813 .60223 Mdot
.72814 .60223 Mdot
.72815 .60222 Mdot
.72816 .60222 Mdot
.72817 .60222 Mdot
.72818 .60222 Mdot
.72819 .60222 Mdot
.7282 .60222 Mdot
.72821 .60222 Mdot
.72822 .60221 Mdot
.72823 .60221 Mdot
.72824 .60221 Mdot
.72825 .60221 Mdot
.72826 .60221 Mdot
.72827 .60221 Mdot
.72828 .60221 Mdot
.72829 .6022 Mdot
.7283 .6022 Mdot
.7283 .6022 Mdot
.72831 .6022 Mdot
.72832 .6022 Mdot
.72833 .6022 Mdot
.72834 .60219 Mdot
.72835 .60219 Mdot
.72836 .60219 Mdot
.72837 .60219 Mdot
.72838 .60219 Mdot
.72839 .60219 Mdot
.7284 .60219 Mdot
.72841 .60218 Mdot
.72842 .60218 Mdot
.72843 .60218 Mdot
.72844 .60218 Mdot
.72845 .60218 Mdot
.72846 .60218 Mdot
.72847 .60217 Mdot
.72848 .60217 Mdot
.72849 .60217 Mdot
.7285 .60217 Mdot
.7285 .60217 Mdot
.72851 .60217 Mdot
.72852 .60216 Mdot
.72853 .60216 Mdot
.72854 .60216 Mdot
.72855 .60216 Mdot
.72856 .60216 Mdot
.72857 .60216 Mdot
.72858 .60216 Mdot
.72859 .60215 Mdot
.7286 .60215 Mdot
.72861 .60215 Mdot
.72862 .60215 Mdot
.72863 .60215 Mdot
.72864 .60215 Mdot
.72865 .60214 Mdot
.72866 .60214 Mdot
.72867 .60214 Mdot
.72868 .60214 Mdot
.72869 .60214 Mdot
.7287 .60214 Mdot
.7287 .60214 Mdot
.72871 .60213 Mdot
.72872 .60213 Mdot
.72873 .60213 Mdot
.72874 .60213 Mdot
.72875 .60213 Mdot
.72876 .60213 Mdot
.72877 .60212 Mdot
.72878 .60212 Mdot
.72879 .60212 Mdot
.7288 .60212 Mdot
.72881 .60212 Mdot
.72882 .60212 Mdot
.72883 .60211 Mdot
.72884 .60211 Mdot
.72885 .60211 Mdot
.72886 .60211 Mdot
.72887 .60211 Mdot
.72888 .60211 Mdot
.72889 .60211 Mdot
.7289 .6021 Mdot
.7289 .6021 Mdot
.72891 .6021 Mdot
.72892 .6021 Mdot
.72893 .6021 Mdot
.72894 .6021 Mdot
.72895 .60209 Mdot
.72896 .60209 Mdot
.72897 .60209 Mdot
.72898 .60209 Mdot
.72899 .60209 Mdot
.729 .60209 Mdot
.72901 .60208 Mdot
.72902 .60208 Mdot
.72903 .60208 Mdot
.72904 .60208 Mdot
.72905 .60208 Mdot
.72906 .60208 Mdot
.72907 .60207 Mdot
.72908 .60207 Mdot
.72909 .60207 Mdot
.7291 .60207 Mdot
.7291 .60207 Mdot
.72911 .60207 Mdot
.72912 .60206 Mdot
.72913 .60206 Mdot
.72914 .60206 Mdot
.72915 .60206 Mdot
.72916 .60206 Mdot
.72917 .60206 Mdot
.72918 .60205 Mdot
.72919 .60205 Mdot
.7292 .60205 Mdot
.72921 .60205 Mdot
.72922 .60205 Mdot
.72923 .60205 Mdot
.72924 .60205 Mdot
.72925 .60204 Mdot
.72926 .60204 Mdot
.72927 .60204 Mdot
.72928 .60204 Mdot
.72929 .60204 Mdot
.7293 .60204 Mdot
.7293 .60203 Mdot
.72931 .60203 Mdot
.72932 .60203 Mdot
.72933 .60203 Mdot
.72934 .60203 Mdot
.72935 .60203 Mdot
.72936 .60202 Mdot
.72937 .60202 Mdot
.72938 .60202 Mdot
.72939 .60202 Mdot
.7294 .60202 Mdot
.72941 .60202 Mdot
.72942 .60201 Mdot
.72943 .60201 Mdot
.72944 .60201 Mdot
.72945 .60201 Mdot
.72946 .60201 Mdot
.72947 .60201 Mdot
.72948 .602 Mdot
.72949 .602 Mdot
.7295 .602 Mdot
.7295 .602 Mdot
.72951 .602 Mdot
.72952 .602 Mdot
.72953 .60199 Mdot
.72954 .60199 Mdot
.72955 .60199 Mdot
.72956 .60199 Mdot
.72957 .60199 Mdot
.72958 .60199 Mdot
.72959 .60198 Mdot
.7296 .60198 Mdot
.72961 .60198 Mdot
.72962 .60198 Mdot
.72963 .60198 Mdot
.72964 .60198 Mdot
.72965 .60197 Mdot
.72966 .60197 Mdot
.72967 .60197 Mdot
.72968 .60197 Mdot
.72969 .60197 Mdot
.7297 .60197 Mdot
.7297 .60196 Mdot
.72971 .60196 Mdot
.72972 .60196 Mdot
.72973 .60196 Mdot
.72974 .60196 Mdot
.72975 .60196 Mdot
.72976 .60195 Mdot
.72977 .60195 Mdot
.72978 .60195 Mdot
.72979 .60195 Mdot
.7298 .60195 Mdot
.72981 .60195 Mdot
.72982 .60194 Mdot
.72983 .60194 Mdot
.72984 .60194 Mdot
.72985 .60194 Mdot
.72986 .60194 Mdot
.72987 .60193 Mdot
.72988 .60193 Mdot
.72989 .60193 Mdot
.7299 .60193 Mdot
.7299 .60193 Mdot
.72991 .60193 Mdot
.72992 .60192 Mdot
.72993 .60192 Mdot
.72994 .60192 Mdot
.72995 .60192 Mdot
.72996 .60192 Mdot
.72997 .60192 Mdot
.72998 .60191 Mdot
.72999 .60191 Mdot
.73 .60191 Mdot
.73001 .60191 Mdot
.73002 .60191 Mdot
.73003 .60191 Mdot
.73004 .6019 Mdot
.73005 .6019 Mdot
.73006 .6019 Mdot
.73007 .6019 Mdot
.73008 .6019 Mdot
.73009 .6019 Mdot
.7301 .60189 Mdot
.7301 .60189 Mdot
.73011 .60189 Mdot
.73012 .60189 Mdot
.73013 .60189 Mdot
.73014 .60189 Mdot
.73015 .60188 Mdot
.73016 .60188 Mdot
.73017 .60188 Mdot
.73018 .60188 Mdot
.73019 .60188 Mdot
.7302 .60187 Mdot
.73021 .60187 Mdot
.73022 .60187 Mdot
.73023 .60187 Mdot
.73024 .60187 Mdot
.73025 .60187 Mdot
.73026 .60186 Mdot
.73027 .60186 Mdot
.73028 .60186 Mdot
.73029 .60186 Mdot
.7303 .60186 Mdot
.7303 .60186 Mdot
.73031 .60185 Mdot
.73032 .60185 Mdot
.73033 .60185 Mdot
.73034 .60185 Mdot
.73035 .60185 Mdot
.73036 .60184 Mdot
.73037 .60184 Mdot
.73038 .60184 Mdot
.73039 .60184 Mdot
.7304 .60184 Mdot
.73041 .60184 Mdot
.73042 .60183 Mdot
.73043 .60183 Mdot
.73044 .60183 Mdot
.73045 .60183 Mdot
.73046 .60183 Mdot
.73047 .60183 Mdot
.73048 .60182 Mdot
.73049 .60182 Mdot
.7305 .60182 Mdot
.7305 .60182 Mdot
.73051 .60182 Mdot
.73052 .60181 Mdot
.73053 .60181 Mdot
.73054 .60181 Mdot
.73055 .60181 Mdot
.73056 .60181 Mdot
.73057 .60181 Mdot
.73058 .6018 Mdot
.73059 .6018 Mdot
.7306 .6018 Mdot
.73061 .6018 Mdot
.73062 .6018 Mdot
.73063 .6018 Mdot
.73064 .60179 Mdot
.73065 .60179 Mdot
.73066 .60179 Mdot
.73067 .60179 Mdot
.73068 .60179 Mdot
.73069 .60178 Mdot
.7307 .60178 Mdot
.7307 .60178 Mdot
.73071 .60178 Mdot
.73072 .60178 Mdot
.73073 .60178 Mdot
.73074 .60177 Mdot
.73075 .60177 Mdot
.73076 .60177 Mdot
.73077 .60177 Mdot
.73078 .60177 Mdot
.73079 .60176 Mdot
.7308 .60176 Mdot
.73081 .60176 Mdot
.73082 .60176 Mdot
.73083 .60176 Mdot
.73084 .60176 Mdot
.73085 .60175 Mdot
.73086 .60175 Mdot
.73087 .60175 Mdot
.73088 .60175 Mdot
.73089 .60175 Mdot
.7309 .60174 Mdot
.7309 .60174 Mdot
.73091 .60174 Mdot
.73092 .60174 Mdot
.73093 .60174 Mdot
.73094 .60174 Mdot
.73095 .60173 Mdot
.73096 .60173 Mdot
.73097 .60173 Mdot
.73098 .60173 Mdot
.73099 .60173 Mdot
.731 .60172 Mdot
.73101 .60172 Mdot
.73102 .60172 Mdot
.73103 .60172 Mdot
.73104 .60172 Mdot
.73105 .60172 Mdot
.73106 .60171 Mdot
.73107 .60171 Mdot
.73108 .60171 Mdot
.73109 .60171 Mdot
.7311 .60171 Mdot
.7311 .6017 Mdot
.73111 .6017 Mdot
.73112 .6017 Mdot
.73113 .6017 Mdot
.73114 .6017 Mdot
.73115 .6017 Mdot
.73116 .60169 Mdot
.73117 .60169 Mdot
.73118 .60169 Mdot
.73119 .60169 Mdot
.7312 .60169 Mdot
.73121 .60168 Mdot
.73122 .60168 Mdot
.73123 .60168 Mdot
.73124 .60168 Mdot
.73125 .60168 Mdot
.73126 .60168 Mdot
.73127 .60167 Mdot
.73128 .60167 Mdot
.73129 .60167 Mdot
.7313 .60167 Mdot
.7313 .60167 Mdot
.73131 .60166 Mdot
.73132 .60166 Mdot
.73133 .60166 Mdot
.73134 .60166 Mdot
.73135 .60166 Mdot
.73136 .60165 Mdot
.73137 .60165 Mdot
.73138 .60165 Mdot
.73139 .60165 Mdot
.7314 .60165 Mdot
.73141 .60165 Mdot
.73142 .60164 Mdot
.73143 .60164 Mdot
.73144 .60164 Mdot
.73145 .60164 Mdot
.73146 .60164 Mdot
.73147 .60163 Mdot
.73148 .60163 Mdot
.73149 .60163 Mdot
.7315 .60163 Mdot
.7315 .60163 Mdot
.73151 .60162 Mdot
.73152 .60162 Mdot
.73153 .60162 Mdot
.73154 .60162 Mdot
.73155 .60162 Mdot
.73156 .60162 Mdot
.73157 .60161 Mdot
.73158 .60161 Mdot
.73159 .60161 Mdot
.7316 .60161 Mdot
.73161 .60161 Mdot
.73162 .6016 Mdot
.73163 .6016 Mdot
.73164 .6016 Mdot
.73165 .6016 Mdot
.73166 .6016 Mdot
.73167 .60159 Mdot
.73168 .60159 Mdot
.73169 .60159 Mdot
.7317 .60159 Mdot
.7317 .60159 Mdot
.73171 .60158 Mdot
.73172 .60158 Mdot
.73173 .60158 Mdot
.73174 .60158 Mdot
.73175 .60158 Mdot
.73176 .60158 Mdot
.73177 .60157 Mdot
.73178 .60157 Mdot
.73179 .60157 Mdot
.7318 .60157 Mdot
.73181 .60157 Mdot
.73182 .60156 Mdot
.73183 .60156 Mdot
.73184 .60156 Mdot
.73185 .60156 Mdot
.73186 .60156 Mdot
.73187 .60155 Mdot
.73188 .60155 Mdot
.73189 .60155 Mdot
.7319 .60155 Mdot
.7319 .60155 Mdot
.73191 .60154 Mdot
.73192 .60154 Mdot
.73193 .60154 Mdot
.73194 .60154 Mdot
.73195 .60154 Mdot
.73196 .60153 Mdot
.73197 .60153 Mdot
.73198 .60153 Mdot
.73199 .60153 Mdot
.732 .60153 Mdot
.73201 .60153 Mdot
.73202 .60152 Mdot
.73203 .60152 Mdot
.73204 .60152 Mdot
.73205 .60152 Mdot
.73206 .60152 Mdot
.73207 .60151 Mdot
.73208 .60151 Mdot
.73209 .60151 Mdot
.7321 .60151 Mdot
.7321 .60151 Mdot
.73211 .6015 Mdot
.73212 .6015 Mdot
.73213 .6015 Mdot
.73214 .6015 Mdot
.73215 .6015 Mdot
.73216 .60149 Mdot
.73217 .60149 Mdot
.73218 .60149 Mdot
.73219 .60149 Mdot
.7322 .60149 Mdot
.73221 .60148 Mdot
.73222 .60148 Mdot
.73223 .60148 Mdot
.73224 .60148 Mdot
.73225 .60148 Mdot
.73226 .60147 Mdot
.73227 .60147 Mdot
.73228 .60147 Mdot
.73229 .60147 Mdot
.7323 .60147 Mdot
.7323 .60146 Mdot
.73231 .60146 Mdot
.73232 .60146 Mdot
.73233 .60146 Mdot
.73234 .60146 Mdot
.73235 .60145 Mdot
.73236 .60145 Mdot
.73237 .60145 Mdot
.73238 .60145 Mdot
.73239 .60145 Mdot
.7324 .60145 Mdot
.73241 .60144 Mdot
.73242 .60144 Mdot
.73243 .60144 Mdot
.73244 .60144 Mdot
.73245 .60144 Mdot
.73246 .60143 Mdot
.73247 .60143 Mdot
.73248 .60143 Mdot
.73249 .60143 Mdot
.7325 .60143 Mdot
.7325 .60142 Mdot
.73251 .60142 Mdot
.73252 .60142 Mdot
.73253 .60142 Mdot
.73254 .60142 Mdot
.73255 .60141 Mdot
.73256 .60141 Mdot
.73257 .60141 Mdot
.73258 .60141 Mdot
.73259 .60141 Mdot
.7326 .6014 Mdot
.73261 .6014 Mdot
.73262 .6014 Mdot
.73263 .6014 Mdot
.73264 .6014 Mdot
.73265 .60139 Mdot
.73266 .60139 Mdot
.73267 .60139 Mdot
.73268 .60139 Mdot
.73269 .60139 Mdot
.7327 .60138 Mdot
.7327 .60138 Mdot
.73271 .60138 Mdot
.73272 .60138 Mdot
.73273 .60138 Mdot
.73274 .60137 Mdot
.73275 .60137 Mdot
.73276 .60137 Mdot
.73277 .60137 Mdot
.73278 .60137 Mdot
.73279 .60136 Mdot
.7328 .60136 Mdot
.73281 .60136 Mdot
.73282 .60136 Mdot
.73283 .60135 Mdot
.73284 .60135 Mdot
.73285 .60135 Mdot
.73286 .60135 Mdot
.73287 .60135 Mdot
.73288 .60134 Mdot
.73289 .60134 Mdot
.7329 .60134 Mdot
.7329 .60134 Mdot
.73291 .60134 Mdot
.73292 .60133 Mdot
.73293 .60133 Mdot
.73294 .60133 Mdot
.73295 .60133 Mdot
.73296 .60133 Mdot
.73297 .60132 Mdot
.73298 .60132 Mdot
.73299 .60132 Mdot
.733 .60132 Mdot
.73301 .60132 Mdot
.73302 .60131 Mdot
.73303 .60131 Mdot
.73304 .60131 Mdot
.73305 .60131 Mdot
.73306 .60131 Mdot
.73307 .6013 Mdot
.73308 .6013 Mdot
.73309 .6013 Mdot
.7331 .6013 Mdot
.7331 .6013 Mdot
.73311 .60129 Mdot
.73312 .60129 Mdot
.73313 .60129 Mdot
.73314 .60129 Mdot
.73315 .60129 Mdot
.73316 .60128 Mdot
.73317 .60128 Mdot
.73318 .60128 Mdot
.73319 .60128 Mdot
.7332 .60128 Mdot
.73321 .60127 Mdot
.73322 .60127 Mdot
.73323 .60127 Mdot
.73324 .60127 Mdot
.73325 .60126 Mdot
.73326 .60126 Mdot
.73327 .60126 Mdot
.73328 .60126 Mdot
.73329 .60126 Mdot
.7333 .60125 Mdot
.7333 .60125 Mdot
.73331 .60125 Mdot
.73332 .60125 Mdot
.73333 .60125 Mdot
.73334 .60124 Mdot
.73335 .60124 Mdot
.73336 .60124 Mdot
.73337 .60124 Mdot
.73338 .60124 Mdot
.73339 .60123 Mdot
.7334 .60123 Mdot
.73341 .60123 Mdot
.73342 .60123 Mdot
.73343 .60123 Mdot
.73344 .60122 Mdot
.73345 .60122 Mdot
.73346 .60122 Mdot
.73347 .60122 Mdot
.73348 .60121 Mdot
.73349 .60121 Mdot
.7335 .60121 Mdot
.7335 .60121 Mdot
.73351 .60121 Mdot
.73352 .6012 Mdot
.73353 .6012 Mdot
.73354 .6012 Mdot
.73355 .6012 Mdot
.73356 .6012 Mdot
.73357 .60119 Mdot
.73358 .60119 Mdot
.73359 .60119 Mdot
.7336 .60119 Mdot
.73361 .60119 Mdot
.73362 .60118 Mdot
.73363 .60118 Mdot
.73364 .60118 Mdot
.73365 .60118 Mdot
.73366 .60117 Mdot
.73367 .60117 Mdot
.73368 .60117 Mdot
.73369 .60117 Mdot
.7337 .60117 Mdot
.7337 .60116 Mdot
.73371 .60116 Mdot
.73372 .60116 Mdot
.73373 .60116 Mdot
.73374 .60116 Mdot
.73375 .60115 Mdot
.73376 .60115 Mdot
.73377 .60115 Mdot
.73378 .60115 Mdot
.73379 .60115 Mdot
.7338 .60114 Mdot
.73381 .60114 Mdot
.73382 .60114 Mdot
.73383 .60114 Mdot
.73384 .60113 Mdot
.73385 .60113 Mdot
.73386 .60113 Mdot
.73387 .60113 Mdot
.73388 .60113 Mdot
.73389 .60112 Mdot
.7339 .60112 Mdot
.7339 .60112 Mdot
.73391 .60112 Mdot
.73392 .60112 Mdot
.73393 .60111 Mdot
.73394 .60111 Mdot
.73395 .60111 Mdot
.73396 .60111 Mdot
.73397 .6011 Mdot
.73398 .6011 Mdot
.73399 .6011 Mdot
.734 .6011 Mdot
.73401 .6011 Mdot
.73402 .60109 Mdot
.73403 .60109 Mdot
.73404 .60109 Mdot
.73405 .60109 Mdot
.73406 .60109 Mdot
.73407 .60108 Mdot
.73408 .60108 Mdot
.73409 .60108 Mdot
.7341 .60108 Mdot
.7341 .60107 Mdot
.73411 .60107 Mdot
.73412 .60107 Mdot
.73413 .60107 Mdot
.73414 .60107 Mdot
.73415 .60106 Mdot
.73416 .60106 Mdot
.73417 .60106 Mdot
.73418 .60106 Mdot
.73419 .60105 Mdot
.7342 .60105 Mdot
.73421 .60105 Mdot
.73422 .60105 Mdot
.73423 .60105 Mdot
.73424 .60104 Mdot
.73425 .60104 Mdot
.73426 .60104 Mdot
.73427 .60104 Mdot
.73428 .60104 Mdot
.73429 .60103 Mdot
.7343 .60103 Mdot
.7343 .60103 Mdot
.73431 .60103 Mdot
.73432 .60102 Mdot
.73433 .60102 Mdot
.73434 .60102 Mdot
.73435 .60102 Mdot
.73436 .60102 Mdot
.73437 .60101 Mdot
.73438 .60101 Mdot
.73439 .60101 Mdot
.7344 .60101 Mdot
.73441 .601 Mdot
.73442 .601 Mdot
.73443 .601 Mdot
.73444 .601 Mdot
.73445 .601 Mdot
.73446 .60099 Mdot
.73447 .60099 Mdot
.73448 .60099 Mdot
.73449 .60099 Mdot
.7345 .60098 Mdot
.7345 .60098 Mdot
.73451 .60098 Mdot
.73452 .60098 Mdot
.73453 .60098 Mdot
.73454 .60097 Mdot
.73455 .60097 Mdot
.73456 .60097 Mdot
.73457 .60097 Mdot
.73458 .60096 Mdot
.73459 .60096 Mdot
.7346 .60096 Mdot
.73461 .60096 Mdot
.73462 .60096 Mdot
.73463 .60095 Mdot
.73464 .60095 Mdot
.73465 .60095 Mdot
.73466 .60095 Mdot
.73467 .60094 Mdot
.73468 .60094 Mdot
.73469 .60094 Mdot
.7347 .60094 Mdot
.7347 .60094 Mdot
.73471 .60093 Mdot
.73472 .60093 Mdot
.73473 .60093 Mdot
.73474 .60093 Mdot
.73475 .60092 Mdot
.73476 .60092 Mdot
.73477 .60092 Mdot
.73478 .60092 Mdot
.73479 .60092 Mdot
.7348 .60091 Mdot
.73481 .60091 Mdot
.73482 .60091 Mdot
.73483 .60091 Mdot
.73484 .6009 Mdot
.73485 .6009 Mdot
.73486 .6009 Mdot
.73487 .6009 Mdot
.73488 .6009 Mdot
.73489 .60089 Mdot
.7349 .60089 Mdot
.7349 .60089 Mdot
.73491 .60089 Mdot
.73492 .60088 Mdot
.73493 .60088 Mdot
.73494 .60088 Mdot
.73495 .60088 Mdot
.73496 .60088 Mdot
.73497 .60087 Mdot
.73498 .60087 Mdot
.73499 .60087 Mdot
.735 .60087 Mdot
.73501 .60086 Mdot
.73502 .60086 Mdot
.73503 .60086 Mdot
.73504 .60086 Mdot
.73505 .60086 Mdot
.73506 .60085 Mdot
.73507 .60085 Mdot
.73508 .60085 Mdot
.73509 .60085 Mdot
.7351 .60084 Mdot
.7351 .60084 Mdot
.73511 .60084 Mdot
.73512 .60084 Mdot
.73513 .60083 Mdot
.73514 .60083 Mdot
.73515 .60083 Mdot
.73516 .60083 Mdot
.73517 .60083 Mdot
.73518 .60082 Mdot
.73519 .60082 Mdot
.7352 .60082 Mdot
.73521 .60082 Mdot
.73522 .60081 Mdot
.73523 .60081 Mdot
.73524 .60081 Mdot
.73525 .60081 Mdot
.73526 .60081 Mdot
.73527 .6008 Mdot
.73528 .6008 Mdot
.73529 .6008 Mdot
.7353 .6008 Mdot
.7353 .60079 Mdot
.73531 .60079 Mdot
.73532 .60079 Mdot
.73533 .60079 Mdot
.73534 .60078 Mdot
.73535 .60078 Mdot
.73536 .60078 Mdot
.73537 .60078 Mdot
.73538 .60078 Mdot
.73539 .60077 Mdot
.7354 .60077 Mdot
.73541 .60077 Mdot
.73542 .60077 Mdot
.73543 .60076 Mdot
.73544 .60076 Mdot
.73545 .60076 Mdot
.73546 .60076 Mdot
.73547 .60075 Mdot
.73548 .60075 Mdot
.73549 .60075 Mdot
.7355 .60075 Mdot
.7355 .60075 Mdot
.73551 .60074 Mdot
.73552 .60074 Mdot
.73553 .60074 Mdot
.73554 .60074 Mdot
.73555 .60073 Mdot
.73556 .60073 Mdot
.73557 .60073 Mdot
.73558 .60073 Mdot
.73559 .60072 Mdot
.7356 .60072 Mdot
.73561 .60072 Mdot
.73562 .60072 Mdot
.73563 .60072 Mdot
.73564 .60071 Mdot
.73565 .60071 Mdot
.73566 .60071 Mdot
.73567 .60071 Mdot
.73568 .6007 Mdot
.73569 .6007 Mdot
.7357 .6007 Mdot
.7357 .6007 Mdot
.73571 .60069 Mdot
.73572 .60069 Mdot
.73573 .60069 Mdot
.73574 .60069 Mdot
.73575 .60068 Mdot
.73576 .60068 Mdot
.73577 .60068 Mdot
.73578 .60068 Mdot
.73579 .60068 Mdot
.7358 .60067 Mdot
.73581 .60067 Mdot
.73582 .60067 Mdot
.73583 .60067 Mdot
.73584 .60066 Mdot
.73585 .60066 Mdot
.73586 .60066 Mdot
.73587 .60066 Mdot
.73588 .60065 Mdot
.73589 .60065 Mdot
.7359 .60065 Mdot
.7359 .60065 Mdot
.73591 .60064 Mdot
.73592 .60064 Mdot
.73593 .60064 Mdot
.73594 .60064 Mdot
.73595 .60064 Mdot
.73596 .60063 Mdot
.73597 .60063 Mdot
.73598 .60063 Mdot
.73599 .60063 Mdot
.736 .60062 Mdot
.73601 .60062 Mdot
.73602 .60062 Mdot
.73603 .60062 Mdot
.73604 .60061 Mdot
.73605 .60061 Mdot
.73606 .60061 Mdot
.73607 .60061 Mdot
.73608 .6006 Mdot
.73609 .6006 Mdot
.7361 .6006 Mdot
.7361 .6006 Mdot
.73611 .6006 Mdot
.73612 .60059 Mdot
.73613 .60059 Mdot
.73614 .60059 Mdot
.73615 .60059 Mdot
.73616 .60058 Mdot
.73617 .60058 Mdot
.73618 .60058 Mdot
.73619 .60058 Mdot
.7362 .60057 Mdot
.73621 .60057 Mdot
.73622 .60057 Mdot
.73623 .60057 Mdot
.73624 .60056 Mdot
.73625 .60056 Mdot
.73626 .60056 Mdot
.73627 .60056 Mdot
.73628 .60055 Mdot
.73629 .60055 Mdot
.7363 .60055 Mdot
.7363 .60055 Mdot
.73631 .60054 Mdot
.73632 .60054 Mdot
.73633 .60054 Mdot
.73634 .60054 Mdot
.73635 .60054 Mdot
.73636 .60053 Mdot
.73637 .60053 Mdot
.73638 .60053 Mdot
.73639 .60053 Mdot
.7364 .60052 Mdot
.73641 .60052 Mdot
.73642 .60052 Mdot
.73643 .60052 Mdot
.73644 .60051 Mdot
.73645 .60051 Mdot
.73646 .60051 Mdot
.73647 .60051 Mdot
.73648 .6005 Mdot
.73649 .6005 Mdot
.7365 .6005 Mdot
.7365 .6005 Mdot
.73651 .60049 Mdot
.73652 .60049 Mdot
.73653 .60049 Mdot
.73654 .60049 Mdot
.73655 .60048 Mdot
.73656 .60048 Mdot
.73657 .60048 Mdot
.73658 .60048 Mdot
.73659 .60047 Mdot
.7366 .60047 Mdot
.73661 .60047 Mdot
.73662 .60047 Mdot
.73663 .60047 Mdot
.73664 .60046 Mdot
.73665 .60046 Mdot
.73666 .60046 Mdot
.73667 .60046 Mdot
.73668 .60045 Mdot
.73669 .60045 Mdot
.7367 .60045 Mdot
.7367 .60045 Mdot
.73671 .60044 Mdot
.73672 .60044 Mdot
.73673 .60044 Mdot
.73674 .60044 Mdot
.73675 .60043 Mdot
.73676 .60043 Mdot
.73677 .60043 Mdot
.73678 .60043 Mdot
.73679 .60042 Mdot
.7368 .60042 Mdot
.73681 .60042 Mdot
.73682 .60042 Mdot
.73683 .60041 Mdot
.73684 .60041 Mdot
.73685 .60041 Mdot
.73686 .60041 Mdot
.73687 .6004 Mdot
.73688 .6004 Mdot
.73689 .6004 Mdot
.7369 .6004 Mdot
.7369 .60039 Mdot
.73691 .60039 Mdot
.73692 .60039 Mdot
.73693 .60039 Mdot
.73694 .60038 Mdot
.73695 .60038 Mdot
.73696 .60038 Mdot
.73697 .60038 Mdot
.73698 .60037 Mdot
.73699 .60037 Mdot
.737 .60037 Mdot
.73701 .60037 Mdot
.73702 .60036 Mdot
.73703 .60036 Mdot
.73704 .60036 Mdot
.73705 .60036 Mdot
.73706 .60035 Mdot
.73707 .60035 Mdot
.73708 .60035 Mdot
.73709 .60035 Mdot
.7371 .60034 Mdot
.7371 .60034 Mdot
.73711 .60034 Mdot
.73712 .60034 Mdot
.73713 .60033 Mdot
.73714 .60033 Mdot
.73715 .60033 Mdot
.73716 .60033 Mdot
.73717 .60032 Mdot
.73718 .60032 Mdot
.73719 .60032 Mdot
.7372 .60032 Mdot
.73721 .60031 Mdot
.73722 .60031 Mdot
.73723 .60031 Mdot
.73724 .60031 Mdot
.73725 .6003 Mdot
.73726 .6003 Mdot
.73727 .6003 Mdot
.73728 .6003 Mdot
.73729 .60029 Mdot
.7373 .60029 Mdot
.7373 .60029 Mdot
.73731 .60029 Mdot
.73732 .60028 Mdot
.73733 .60028 Mdot
.73734 .60028 Mdot
.73735 .60028 Mdot
.73736 .60027 Mdot
.73737 .60027 Mdot
.73738 .60027 Mdot
.73739 .60027 Mdot
.7374 .60026 Mdot
.73741 .60026 Mdot
.73742 .60026 Mdot
.73743 .60026 Mdot
.73744 .60025 Mdot
.73745 .60025 Mdot
.73746 .60025 Mdot
.73747 .60025 Mdot
.73748 .60024 Mdot
.73749 .60024 Mdot
.7375 .60024 Mdot
.7375 .60024 Mdot
.73751 .60023 Mdot
.73752 .60023 Mdot
.73753 .60023 Mdot
.73754 .60023 Mdot
.73755 .60022 Mdot
.73756 .60022 Mdot
.73757 .60022 Mdot
.73758 .60022 Mdot
.73759 .60021 Mdot
.7376 .60021 Mdot
.73761 .60021 Mdot
.73762 .60021 Mdot
.73763 .6002 Mdot
.73764 .6002 Mdot
.73765 .6002 Mdot
.73766 .6002 Mdot
.73767 .60019 Mdot
.73768 .60019 Mdot
.73769 .60019 Mdot
.7377 .60019 Mdot
.7377 .60018 Mdot
.73771 .60018 Mdot
.73772 .60018 Mdot
.73773 .60018 Mdot
.73774 .60017 Mdot
.73775 .60017 Mdot
.73776 .60017 Mdot
.73777 .60017 Mdot
.73778 .60016 Mdot
.73779 .60016 Mdot
.7378 .60016 Mdot
.73781 .60016 Mdot
.73782 .60015 Mdot
.73783 .60015 Mdot
.73784 .60015 Mdot
.73785 .60015 Mdot
.73786 .60014 Mdot
.73787 .60014 Mdot
.73788 .60014 Mdot
.73789 .60013 Mdot
.7379 .60013 Mdot
.7379 .60013 Mdot
.73791 .60013 Mdot
.73792 .60012 Mdot
.73793 .60012 Mdot
.73794 .60012 Mdot
.73795 .60012 Mdot
.73796 .60011 Mdot
.73797 .60011 Mdot
.73798 .60011 Mdot
.73799 .60011 Mdot
.738 .6001 Mdot
.73801 .6001 Mdot
.73802 .6001 Mdot
.73803 .6001 Mdot
.73804 .60009 Mdot
.73805 .60009 Mdot
.73806 .60009 Mdot
.73807 .60009 Mdot
.73808 .60008 Mdot
.73809 .60008 Mdot
.7381 .60008 Mdot
.7381 .60008 Mdot
.73811 .60007 Mdot
.73812 .60007 Mdot
.73813 .60007 Mdot
.73814 .60007 Mdot
.73815 .60006 Mdot
.73816 .60006 Mdot
.73817 .60006 Mdot
.73818 .60005 Mdot
.73819 .60005 Mdot
.7382 .60005 Mdot
.73821 .60005 Mdot
.73822 .60004 Mdot
.73823 .60004 Mdot
.73824 .60004 Mdot
.73825 .60004 Mdot
.73826 .60003 Mdot
.73827 .60003 Mdot
.73828 .60003 Mdot
.73829 .60003 Mdot
.7383 .60002 Mdot
.7383 .60002 Mdot
.73831 .60002 Mdot
.73832 .60002 Mdot
.73833 .60001 Mdot
.73834 .60001 Mdot
.73835 .60001 Mdot
.73836 .60001 Mdot
.73837 .6 Mdot
.73838 .6 Mdot
.73839 .6 Mdot
.7384 .59999 Mdot
.73841 .59999 Mdot
.73842 .59999 Mdot
.73843 .59999 Mdot
.73844 .59998 Mdot
.73845 .59998 Mdot
.73846 .59998 Mdot
.73847 .59998 Mdot
.73848 .59997 Mdot
.73849 .59997 Mdot
.7385 .59997 Mdot
.7385 .59997 Mdot
.73851 .59996 Mdot
.73852 .59996 Mdot
.73853 .59996 Mdot
.73854 .59996 Mdot
.73855 .59995 Mdot
.73856 .59995 Mdot
.73857 .59995 Mdot
.73858 .59994 Mdot
.73859 .59994 Mdot
.7386 .59994 Mdot
.73861 .59994 Mdot
.73862 .59993 Mdot
.73863 .59993 Mdot
.73864 .59993 Mdot
.73865 .59993 Mdot
.73866 .59992 Mdot
.73867 .59992 Mdot
.73868 .59992 Mdot
.73869 .59992 Mdot
.7387 .59991 Mdot
.7387 .59991 Mdot
.73871 .59991 Mdot
.73872 .5999 Mdot
.73873 .5999 Mdot
.73874 .5999 Mdot
.73875 .5999 Mdot
.73876 .59989 Mdot
.73877 .59989 Mdot
.73878 .59989 Mdot
.73879 .59989 Mdot
.7388 .59988 Mdot
.73881 .59988 Mdot
.73882 .59988 Mdot
.73883 .59988 Mdot
.73884 .59987 Mdot
.73885 .59987 Mdot
.73886 .59987 Mdot
.73887 .59986 Mdot
.73888 .59986 Mdot
.73889 .59986 Mdot
.7389 .59986 Mdot
.7389 .59985 Mdot
.73891 .59985 Mdot
.73892 .59985 Mdot
.73893 .59985 Mdot
.73894 .59984 Mdot
.73895 .59984 Mdot
.73896 .59984 Mdot
.73897 .59984 Mdot
.73898 .59983 Mdot
.73899 .59983 Mdot
.739 .59983 Mdot
.73901 .59982 Mdot
.73902 .59982 Mdot
.73903 .59982 Mdot
.73904 .59982 Mdot
.73905 .59981 Mdot
.73906 .59981 Mdot
.73907 .59981 Mdot
.73908 .59981 Mdot
.73909 .5998 Mdot
.7391 .5998 Mdot
.7391 .5998 Mdot
.73911 .5998 Mdot
.73912 .59979 Mdot
.73913 .59979 Mdot
.73914 .59979 Mdot
.73915 .59978 Mdot
.73916 .59978 Mdot
.73917 .59978 Mdot
.73918 .59978 Mdot
.73919 .59977 Mdot
.7392 .59977 Mdot
.73921 .59977 Mdot
.73922 .59977 Mdot
.73923 .59976 Mdot
.73924 .59976 Mdot
.73925 .59976 Mdot
.73926 .59975 Mdot
.73927 .59975 Mdot
.73928 .59975 Mdot
.73929 .59975 Mdot
.7393 .59974 Mdot
.7393 .59974 Mdot
.73931 .59974 Mdot
.73932 .59974 Mdot
.73933 .59973 Mdot
.73934 .59973 Mdot
.73935 .59973 Mdot
.73936 .59972 Mdot
.73937 .59972 Mdot
.73938 .59972 Mdot
.73939 .59972 Mdot
.7394 .59971 Mdot
.73941 .59971 Mdot
.73942 .59971 Mdot
.73943 .59971 Mdot
.73944 .5997 Mdot
.73945 .5997 Mdot
.73946 .5997 Mdot
.73947 .59969 Mdot
.73948 .59969 Mdot
.73949 .59969 Mdot
.7395 .59969 Mdot
.7395 .59968 Mdot
.73951 .59968 Mdot
.73952 .59968 Mdot
.73953 .59968 Mdot
.73954 .59967 Mdot
.73955 .59967 Mdot
.73956 .59967 Mdot
.73957 .59966 Mdot
.73958 .59966 Mdot
.73959 .59966 Mdot
.7396 .59966 Mdot
.73961 .59965 Mdot
.73962 .59965 Mdot
.73963 .59965 Mdot
.73964 .59965 Mdot
.73965 .59964 Mdot
.73966 .59964 Mdot
.73967 .59964 Mdot
.73968 .59963 Mdot
.73969 .59963 Mdot
.7397 .59963 Mdot
.7397 .59963 Mdot
.73971 .59962 Mdot
.73972 .59962 Mdot
.73973 .59962 Mdot
.73974 .59961 Mdot
.73975 .59961 Mdot
.73976 .59961 Mdot
.73977 .59961 Mdot
.73978 .5996 Mdot
.73979 .5996 Mdot
.7398 .5996 Mdot
.73981 .5996 Mdot
.73982 .59959 Mdot
.73983 .59959 Mdot
.73984 .59959 Mdot
.73985 .59958 Mdot
.73986 .59958 Mdot
.73987 .59958 Mdot
.73988 .59958 Mdot
.73989 .59957 Mdot
.7399 .59957 Mdot
.7399 .59957 Mdot
.73991 .59956 Mdot
.73992 .59956 Mdot
.73993 .59956 Mdot
.73994 .59956 Mdot
.73995 .59955 Mdot
.73996 .59955 Mdot
.73997 .59955 Mdot
.73998 .59955 Mdot
.73999 .59954 Mdot
.74 .59954 Mdot
.74001 .59954 Mdot
.74002 .59953 Mdot
.74003 .59953 Mdot
.74004 .59953 Mdot
.74005 .59953 Mdot
.74006 .59952 Mdot
.74007 .59952 Mdot
.74008 .59952 Mdot
.74009 .59951 Mdot
.7401 .59951 Mdot
.7401 .59951 Mdot
.74011 .59951 Mdot
.74012 .5995 Mdot
.74013 .5995 Mdot
.74014 .5995 Mdot
.74015 .59949 Mdot
.74016 .59949 Mdot
.74017 .59949 Mdot
.74018 .59949 Mdot
.74019 .59948 Mdot
.7402 .59948 Mdot
.74021 .59948 Mdot
.74022 .59948 Mdot
.74023 .59947 Mdot
.74024 .59947 Mdot
.74025 .59947 Mdot
.74026 .59946 Mdot
.74027 .59946 Mdot
.74028 .59946 Mdot
.74029 .59946 Mdot
.7403 .59945 Mdot
.7403 .59945 Mdot
.74031 .59945 Mdot
.74032 .59944 Mdot
.74033 .59944 Mdot
.74034 .59944 Mdot
.74035 .59944 Mdot
.74036 .59943 Mdot
.74037 .59943 Mdot
.74038 .59943 Mdot
.74039 .59942 Mdot
.7404 .59942 Mdot
.74041 .59942 Mdot
.74042 .59942 Mdot
.74043 .59941 Mdot
.74044 .59941 Mdot
.74045 .59941 Mdot
.74046 .5994 Mdot
.74047 .5994 Mdot
.74048 .5994 Mdot
.74049 .5994 Mdot
.7405 .59939 Mdot
.7405 .59939 Mdot
.74051 .59939 Mdot
.74052 .59938 Mdot
.74053 .59938 Mdot
.74054 .59938 Mdot
.74055 .59938 Mdot
.74056 .59937 Mdot
.74057 .59937 Mdot
.74058 .59937 Mdot
.74059 .59936 Mdot
.7406 .59936 Mdot
.74061 .59936 Mdot
.74062 .59936 Mdot
.74063 .59935 Mdot
.74064 .59935 Mdot
.74065 .59935 Mdot
.74066 .59934 Mdot
.74067 .59934 Mdot
.74068 .59934 Mdot
.74069 .59934 Mdot
.7407 .59933 Mdot
.7407 .59933 Mdot
.74071 .59933 Mdot
.74072 .59932 Mdot
.74073 .59932 Mdot
.74074 .59932 Mdot
.74075 .59932 Mdot
.74076 .59931 Mdot
.74077 .59931 Mdot
.74078 .59931 Mdot
.74079 .5993 Mdot
.7408 .5993 Mdot
.74081 .5993 Mdot
.74082 .5993 Mdot
.74083 .59929 Mdot
.74084 .59929 Mdot
.74085 .59929 Mdot
.74086 .59928 Mdot
.74087 .59928 Mdot
.74088 .59928 Mdot
.74089 .59928 Mdot
.7409 .59927 Mdot
.7409 .59927 Mdot
.74091 .59927 Mdot
.74092 .59926 Mdot
.74093 .59926 Mdot
.74094 .59926 Mdot
.74095 .59926 Mdot
.74096 .59925 Mdot
.74097 .59925 Mdot
.74098 .59925 Mdot
.74099 .59924 Mdot
.741 .59924 Mdot
.74101 .59924 Mdot
.74102 .59924 Mdot
.74103 .59923 Mdot
.74104 .59923 Mdot
.74105 .59923 Mdot
.74106 .59922 Mdot
.74107 .59922 Mdot
.74108 .59922 Mdot
.74109 .59921 Mdot
.7411 .59921 Mdot
.7411 .59921 Mdot
.74111 .59921 Mdot
.74112 .5992 Mdot
.74113 .5992 Mdot
.74114 .5992 Mdot
.74115 .59919 Mdot
.74116 .59919 Mdot
.74117 .59919 Mdot
.74118 .59919 Mdot
.74119 .59918 Mdot
.7412 .59918 Mdot
.74121 .59918 Mdot
.74122 .59917 Mdot
.74123 .59917 Mdot
.74124 .59917 Mdot
.74125 .59917 Mdot
.74126 .59916 Mdot
.74127 .59916 Mdot
.74128 .59916 Mdot
.74129 .59915 Mdot
.7413 .59915 Mdot
.7413 .59915 Mdot
.74131 .59914 Mdot
.74132 .59914 Mdot
.74133 .59914 Mdot
.74134 .59914 Mdot
.74135 .59913 Mdot
.74136 .59913 Mdot
.74137 .59913 Mdot
.74138 .59912 Mdot
.74139 .59912 Mdot
.7414 .59912 Mdot
.74141 .59912 Mdot
.74142 .59911 Mdot
.74143 .59911 Mdot
.74144 .59911 Mdot
.74145 .5991 Mdot
.74146 .5991 Mdot
.74147 .5991 Mdot
.74148 .59909 Mdot
.74149 .59909 Mdot
.7415 .59909 Mdot
.7415 .59909 Mdot
.74151 .59908 Mdot
.74152 .59908 Mdot
.74153 .59908 Mdot
.74154 .59907 Mdot
.74155 .59907 Mdot
.74156 .59907 Mdot
.74157 .59907 Mdot
.74158 .59906 Mdot
.74159 .59906 Mdot
.7416 .59906 Mdot
.74161 .59905 Mdot
.74162 .59905 Mdot
.74163 .59905 Mdot
.74164 .59904 Mdot
.74165 .59904 Mdot
.74166 .59904 Mdot
.74167 .59904 Mdot
.74168 .59903 Mdot
.74169 .59903 Mdot
.7417 .59903 Mdot
.7417 .59902 Mdot
.74171 .59902 Mdot
.74172 .59902 Mdot
.74173 .59901 Mdot
.74174 .59901 Mdot
.74175 .59901 Mdot
.74176 .59901 Mdot
.74177 .599 Mdot
.74178 .599 Mdot
.74179 .599 Mdot
.7418 .59899 Mdot
.74181 .59899 Mdot
.74182 .59899 Mdot
.74183 .59898 Mdot
.74184 .59898 Mdot
.74185 .59898 Mdot
.74186 .59898 Mdot
.74187 .59897 Mdot
.74188 .59897 Mdot
.74189 .59897 Mdot
.7419 .59896 Mdot
.7419 .59896 Mdot
.74191 .59896 Mdot
.74192 .59895 Mdot
.74193 .59895 Mdot
.74194 .59895 Mdot
.74195 .59895 Mdot
.74196 .59894 Mdot
.74197 .59894 Mdot
.74198 .59894 Mdot
.74199 .59893 Mdot
.742 .59893 Mdot
.74201 .59893 Mdot
.74202 .59892 Mdot
.74203 .59892 Mdot
.74204 .59892 Mdot
.74205 .59892 Mdot
.74206 .59891 Mdot
.74207 .59891 Mdot
.74208 .59891 Mdot
.74209 .5989 Mdot
.7421 .5989 Mdot
.7421 .5989 Mdot
.74211 .59889 Mdot
.74212 .59889 Mdot
.74213 .59889 Mdot
.74214 .59889 Mdot
.74215 .59888 Mdot
.74216 .59888 Mdot
.74217 .59888 Mdot
.74218 .59887 Mdot
.74219 .59887 Mdot
.7422 .59887 Mdot
.74221 .59886 Mdot
.74222 .59886 Mdot
.74223 .59886 Mdot
.74224 .59886 Mdot
.74225 .59885 Mdot
.74226 .59885 Mdot
.74227 .59885 Mdot
.74228 .59884 Mdot
.74229 .59884 Mdot
.7423 .59884 Mdot
.7423 .59883 Mdot
.74231 .59883 Mdot
.74232 .59883 Mdot
.74233 .59883 Mdot
.74234 .59882 Mdot
.74235 .59882 Mdot
.74236 .59882 Mdot
.74237 .59881 Mdot
.74238 .59881 Mdot
.74239 .59881 Mdot
.7424 .5988 Mdot
.74241 .5988 Mdot
.74242 .5988 Mdot
.74243 .59879 Mdot
.74244 .59879 Mdot
.74245 .59879 Mdot
.74246 .59879 Mdot
.74247 .59878 Mdot
.74248 .59878 Mdot
.74249 .59878 Mdot
.7425 .59877 Mdot
.7425 .59877 Mdot
.74251 .59877 Mdot
.74252 .59876 Mdot
.74253 .59876 Mdot
.74254 .59876 Mdot
.74255 .59875 Mdot
.74256 .59875 Mdot
.74257 .59875 Mdot
.74258 .59875 Mdot
.74259 .59874 Mdot
.7426 .59874 Mdot
.74261 .59874 Mdot
.74262 .59873 Mdot
.74263 .59873 Mdot
.74264 .59873 Mdot
.74265 .59872 Mdot
.74266 .59872 Mdot
.74267 .59872 Mdot
.74268 .59871 Mdot
.74269 .59871 Mdot
.7427 .59871 Mdot
.7427 .59871 Mdot
.74271 .5987 Mdot
.74272 .5987 Mdot
.74273 .5987 Mdot
.74274 .59869 Mdot
.74275 .59869 Mdot
.74276 .59869 Mdot
.74277 .59868 Mdot
.74278 .59868 Mdot
.74279 .59868 Mdot
.7428 .59867 Mdot
.74281 .59867 Mdot
.74282 .59867 Mdot
.74283 .59867 Mdot
.74284 .59866 Mdot
.74285 .59866 Mdot
.74286 .59866 Mdot
.74287 .59865 Mdot
.74288 .59865 Mdot
.74289 .59865 Mdot
.7429 .59864 Mdot
.7429 .59864 Mdot
.74291 .59864 Mdot
.74292 .59863 Mdot
.74293 .59863 Mdot
.74294 .59863 Mdot
.74295 .59863 Mdot
.74296 .59862 Mdot
.74297 .59862 Mdot
.74298 .59862 Mdot
.74299 .59861 Mdot
.743 .59861 Mdot
.74301 .59861 Mdot
.74302 .5986 Mdot
.74303 .5986 Mdot
.74304 .5986 Mdot
.74305 .59859 Mdot
.74306 .59859 Mdot
.74307 .59859 Mdot
.74308 .59858 Mdot
.74309 .59858 Mdot
.7431 .59858 Mdot
.7431 .59858 Mdot
.74311 .59857 Mdot
.74312 .59857 Mdot
.74313 .59857 Mdot
.74314 .59856 Mdot
.74315 .59856 Mdot
.74316 .59856 Mdot
.74317 .59855 Mdot
.74318 .59855 Mdot
.74319 .59855 Mdot
.7432 .59854 Mdot
.74321 .59854 Mdot
.74322 .59854 Mdot
.74323 .59853 Mdot
.74324 .59853 Mdot
.74325 .59853 Mdot
.74326 .59853 Mdot
.74327 .59852 Mdot
.74328 .59852 Mdot
.74329 .59852 Mdot
.7433 .59851 Mdot
.7433 .59851 Mdot
.74331 .59851 Mdot
.74332 .5985 Mdot
.74333 .5985 Mdot
.74334 .5985 Mdot
.74335 .59849 Mdot
.74336 .59849 Mdot
.74337 .59849 Mdot
.74338 .59848 Mdot
.74339 .59848 Mdot
.7434 .59848 Mdot
.74341 .59848 Mdot
.74342 .59847 Mdot
.74343 .59847 Mdot
.74344 .59847 Mdot
.74345 .59846 Mdot
.74346 .59846 Mdot
.74347 .59846 Mdot
.74348 .59845 Mdot
.74349 .59845 Mdot
.7435 .59845 Mdot
.7435 .59844 Mdot
.74351 .59844 Mdot
.74352 .59844 Mdot
.74353 .59843 Mdot
.74354 .59843 Mdot
.74355 .59843 Mdot
.74356 .59842 Mdot
.74357 .59842 Mdot
.74358 .59842 Mdot
.74359 .59842 Mdot
.7436 .59841 Mdot
.74361 .59841 Mdot
.74362 .59841 Mdot
.74363 .5984 Mdot
.74364 .5984 Mdot
.74365 .5984 Mdot
.74366 .59839 Mdot
.74367 .59839 Mdot
.74368 .59839 Mdot
.74369 .59838 Mdot
.7437 .59838 Mdot
.7437 .59838 Mdot
.74371 .59837 Mdot
.74372 .59837 Mdot
.74373 .59837 Mdot
.74374 .59836 Mdot
.74375 .59836 Mdot
.74376 .59836 Mdot
.74377 .59835 Mdot
.74378 .59835 Mdot
.74379 .59835 Mdot
.7438 .59835 Mdot
.74381 .59834 Mdot
.74382 .59834 Mdot
.74383 .59834 Mdot
.74384 .59833 Mdot
.74385 .59833 Mdot
.74386 .59833 Mdot
.74387 .59832 Mdot
.74388 .59832 Mdot
.74389 .59832 Mdot
.7439 .59831 Mdot
.7439 .59831 Mdot
.74391 .59831 Mdot
.74392 .5983 Mdot
.74393 .5983 Mdot
.74394 .5983 Mdot
.74395 .59829 Mdot
.74396 .59829 Mdot
.74397 .59829 Mdot
.74398 .59828 Mdot
.74399 .59828 Mdot
.744 .59828 Mdot
.74401 .59827 Mdot
.74402 .59827 Mdot
.74403 .59827 Mdot
.74404 .59826 Mdot
.74405 .59826 Mdot
.74406 .59826 Mdot
.74407 .59826 Mdot
.74408 .59825 Mdot
.74409 .59825 Mdot
.7441 .59825 Mdot
.7441 .59824 Mdot
.74411 .59824 Mdot
.74412 .59824 Mdot
.74413 .59823 Mdot
.74414 .59823 Mdot
.74415 .59823 Mdot
.74416 .59822 Mdot
.74417 .59822 Mdot
.74418 .59822 Mdot
.74419 .59821 Mdot
.7442 .59821 Mdot
.74421 .59821 Mdot
.74422 .5982 Mdot
.74423 .5982 Mdot
.74424 .5982 Mdot
.74425 .59819 Mdot
.74426 .59819 Mdot
.74427 .59819 Mdot
.74428 .59818 Mdot
.74429 .59818 Mdot
.7443 .59818 Mdot
.7443 .59817 Mdot
.74431 .59817 Mdot
.74432 .59817 Mdot
.74433 .59816 Mdot
.74434 .59816 Mdot
.74435 .59816 Mdot
.74436 .59815 Mdot
.74437 .59815 Mdot
.74438 .59815 Mdot
.74439 .59815 Mdot
.7444 .59814 Mdot
.74441 .59814 Mdot
.74442 .59814 Mdot
.74443 .59813 Mdot
.74444 .59813 Mdot
.74445 .59813 Mdot
.74446 .59812 Mdot
.74447 .59812 Mdot
.74448 .59812 Mdot
.74449 .59811 Mdot
.7445 .59811 Mdot
.7445 .59811 Mdot
.74451 .5981 Mdot
.74452 .5981 Mdot
.74453 .5981 Mdot
.74454 .59809 Mdot
.74455 .59809 Mdot
.74456 .59809 Mdot
.74457 .59808 Mdot
.74458 .59808 Mdot
.74459 .59808 Mdot
.7446 .59807 Mdot
.74461 .59807 Mdot
.74462 .59807 Mdot
.74463 .59806 Mdot
.74464 .59806 Mdot
.74465 .59806 Mdot
.74466 .59805 Mdot
.74467 .59805 Mdot
.74468 .59805 Mdot
.74469 .59804 Mdot
.7447 .59804 Mdot
.7447 .59804 Mdot
.74471 .59803 Mdot
.74472 .59803 Mdot
.74473 .59803 Mdot
.74474 .59802 Mdot
.74475 .59802 Mdot
.74476 .59802 Mdot
.74477 .59801 Mdot
.74478 .59801 Mdot
.74479 .59801 Mdot
.7448 .598 Mdot
.74481 .598 Mdot
.74482 .598 Mdot
.74483 .59799 Mdot
.74484 .59799 Mdot
.74485 .59799 Mdot
.74486 .59798 Mdot
.74487 .59798 Mdot
.74488 .59798 Mdot
.74489 .59797 Mdot
.7449 .59797 Mdot
.7449 .59797 Mdot
.74491 .59796 Mdot
.74492 .59796 Mdot
.74493 .59796 Mdot
.74494 .59795 Mdot
.74495 .59795 Mdot
.74496 .59795 Mdot
.74497 .59794 Mdot
.74498 .59794 Mdot
.74499 .59794 Mdot
.745 .59793 Mdot
.74501 .59793 Mdot
.74502 .59793 Mdot
.74503 .59792 Mdot
.74504 .59792 Mdot
.74505 .59792 Mdot
.74506 .59791 Mdot
.74507 .59791 Mdot
.74508 .59791 Mdot
.74509 .5979 Mdot
.7451 .5979 Mdot
.7451 .5979 Mdot
.74511 .59789 Mdot
.74512 .59789 Mdot
.74513 .59789 Mdot
.74514 .59788 Mdot
.74515 .59788 Mdot
.74516 .59788 Mdot
.74517 .59787 Mdot
.74518 .59787 Mdot
.74519 .59787 Mdot
.7452 .59786 Mdot
.74521 .59786 Mdot
.74522 .59786 Mdot
.74523 .59785 Mdot
.74524 .59785 Mdot
.74525 .59785 Mdot
.74526 .59784 Mdot
.74527 .59784 Mdot
.74528 .59784 Mdot
.74529 .59783 Mdot
.7453 .59783 Mdot
.7453 .59783 Mdot
.74531 .59782 Mdot
.74532 .59782 Mdot
.74533 .59782 Mdot
.74534 .59781 Mdot
.74535 .59781 Mdot
.74536 .59781 Mdot
.74537 .5978 Mdot
.74538 .5978 Mdot
.74539 .5978 Mdot
.7454 .59779 Mdot
.74541 .59779 Mdot
.74542 .59779 Mdot
.74543 .59778 Mdot
.74544 .59778 Mdot
.74545 .59778 Mdot
.74546 .59777 Mdot
.74547 .59777 Mdot
.74548 .59777 Mdot
.74549 .59776 Mdot
.7455 .59776 Mdot
.7455 .59776 Mdot
.74551 .59775 Mdot
.74552 .59775 Mdot
.74553 .59775 Mdot
.74554 .59774 Mdot
.74555 .59774 Mdot
.74556 .59774 Mdot
.74557 .59773 Mdot
.74558 .59773 Mdot
.74559 .59773 Mdot
.7456 .59772 Mdot
.74561 .59772 Mdot
.74562 .59772 Mdot
.74563 .59771 Mdot
.74564 .59771 Mdot
.74565 .59771 Mdot
.74566 .5977 Mdot
.74567 .5977 Mdot
.74568 .5977 Mdot
.74569 .59769 Mdot
.7457 .59769 Mdot
.7457 .59769 Mdot
.74571 .59768 Mdot
.74572 .59768 Mdot
.74573 .59768 Mdot
.74574 .59767 Mdot
.74575 .59767 Mdot
.74576 .59767 Mdot
.74577 .59766 Mdot
.74578 .59766 Mdot
.74579 .59766 Mdot
.7458 .59765 Mdot
.74581 .59765 Mdot
.74582 .59765 Mdot
.74583 .59764 Mdot
.74584 .59764 Mdot
.74585 .59764 Mdot
.74586 .59763 Mdot
.74587 .59763 Mdot
.74588 .59763 Mdot
.74589 .59762 Mdot
.7459 .59762 Mdot
.7459 .59761 Mdot
.74591 .59761 Mdot
.74592 .59761 Mdot
.74593 .5976 Mdot
.74594 .5976 Mdot
.74595 .5976 Mdot
.74596 .59759 Mdot
.74597 .59759 Mdot
.74598 .59759 Mdot
.74599 .59758 Mdot
.746 .59758 Mdot
.74601 .59758 Mdot
.74602 .59757 Mdot
.74603 .59757 Mdot
.74604 .59757 Mdot
.74605 .59756 Mdot
.74606 .59756 Mdot
.74607 .59756 Mdot
.74608 .59755 Mdot
.74609 .59755 Mdot
.7461 .59755 Mdot
.7461 .59754 Mdot
.74611 .59754 Mdot
.74612 .59754 Mdot
.74613 .59753 Mdot
.74614 .59753 Mdot
.74615 .59753 Mdot
.74616 .59752 Mdot
.74617 .59752 Mdot
.74618 .59752 Mdot
.74619 .59751 Mdot
.7462 .59751 Mdot
.74621 .5975 Mdot
.74622 .5975 Mdot
.74623 .5975 Mdot
.74624 .59749 Mdot
.74625 .59749 Mdot
.74626 .59749 Mdot
.74627 .59748 Mdot
.74628 .59748 Mdot
.74629 .59748 Mdot
.7463 .59747 Mdot
.7463 .59747 Mdot
.74631 .59747 Mdot
.74632 .59746 Mdot
.74633 .59746 Mdot
.74634 .59746 Mdot
.74635 .59745 Mdot
.74636 .59745 Mdot
.74637 .59745 Mdot
.74638 .59744 Mdot
.74639 .59744 Mdot
.7464 .59744 Mdot
.74641 .59743 Mdot
.74642 .59743 Mdot
.74643 .59743 Mdot
.74644 .59742 Mdot
.74645 .59742 Mdot
.74646 .59742 Mdot
.74647 .59741 Mdot
.74648 .59741 Mdot
.74649 .5974 Mdot
.7465 .5974 Mdot
.7465 .5974 Mdot
.74651 .59739 Mdot
.74652 .59739 Mdot
.74653 .59739 Mdot
.74654 .59738 Mdot
.74655 .59738 Mdot
.74656 .59738 Mdot
.74657 .59737 Mdot
.74658 .59737 Mdot
.74659 .59737 Mdot
.7466 .59736 Mdot
.74661 .59736 Mdot
.74662 .59736 Mdot
.74663 .59735 Mdot
.74664 .59735 Mdot
.74665 .59735 Mdot
.74666 .59734 Mdot
.74667 .59734 Mdot
.74668 .59733 Mdot
.74669 .59733 Mdot
.7467 .59733 Mdot
.7467 .59732 Mdot
.74671 .59732 Mdot
.74672 .59732 Mdot
.74673 .59731 Mdot
.74674 .59731 Mdot
.74675 .59731 Mdot
.74676 .5973 Mdot
.74677 .5973 Mdot
.74678 .5973 Mdot
.74679 .59729 Mdot
.7468 .59729 Mdot
.74681 .59729 Mdot
.74682 .59728 Mdot
.74683 .59728 Mdot
.74684 .59728 Mdot
.74685 .59727 Mdot
.74686 .59727 Mdot
.74687 .59726 Mdot
.74688 .59726 Mdot
.74689 .59726 Mdot
.7469 .59725 Mdot
.7469 .59725 Mdot
.74691 .59725 Mdot
.74692 .59724 Mdot
.74693 .59724 Mdot
.74694 .59724 Mdot
.74695 .59723 Mdot
.74696 .59723 Mdot
.74697 .59723 Mdot
.74698 .59722 Mdot
.74699 .59722 Mdot
.747 .59722 Mdot
.74701 .59721 Mdot
.74702 .59721 Mdot
.74703 .5972 Mdot
.74704 .5972 Mdot
.74705 .5972 Mdot
.74706 .59719 Mdot
.74707 .59719 Mdot
.74708 .59719 Mdot
.74709 .59718 Mdot
.7471 .59718 Mdot
.7471 .59718 Mdot
.74711 .59717 Mdot
.74712 .59717 Mdot
.74713 .59717 Mdot
.74714 .59716 Mdot
.74715 .59716 Mdot
.74716 .59716 Mdot
.74717 .59715 Mdot
.74718 .59715 Mdot
.74719 .59714 Mdot
.7472 .59714 Mdot
.74721 .59714 Mdot
.74722 .59713 Mdot
.74723 .59713 Mdot
.74724 .59713 Mdot
.74725 .59712 Mdot
.74726 .59712 Mdot
.74727 .59712 Mdot
.74728 .59711 Mdot
.74729 .59711 Mdot
.7473 .59711 Mdot
.7473 .5971 Mdot
.74731 .5971 Mdot
.74732 .5971 Mdot
.74733 .59709 Mdot
.74734 .59709 Mdot
.74735 .59708 Mdot
.74736 .59708 Mdot
.74737 .59708 Mdot
.74738 .59707 Mdot
.74739 .59707 Mdot
.7474 .59707 Mdot
.74741 .59706 Mdot
.74742 .59706 Mdot
.74743 .59706 Mdot
.74744 .59705 Mdot
.74745 .59705 Mdot
.74746 .59705 Mdot
.74747 .59704 Mdot
.74748 .59704 Mdot
.74749 .59703 Mdot
.7475 .59703 Mdot
.7475 .59703 Mdot
.74751 .59702 Mdot
.74752 .59702 Mdot
.74753 .59702 Mdot
.74754 .59701 Mdot
.74755 .59701 Mdot
.74756 .59701 Mdot
.74757 .597 Mdot
.74758 .597 Mdot
.74759 .59699 Mdot
.7476 .59699 Mdot
.74761 .59699 Mdot
.74762 .59698 Mdot
.74763 .59698 Mdot
.74764 .59698 Mdot
.74765 .59697 Mdot
.74766 .59697 Mdot
.74767 .59697 Mdot
.74768 .59696 Mdot
.74769 .59696 Mdot
.7477 .59696 Mdot
.7477 .59695 Mdot
.74771 .59695 Mdot
.74772 .59694 Mdot
.74773 .59694 Mdot
.74774 .59694 Mdot
.74775 .59693 Mdot
.74776 .59693 Mdot
.74777 .59693 Mdot
.74778 .59692 Mdot
.74779 .59692 Mdot
.7478 .59692 Mdot
.74781 .59691 Mdot
.74782 .59691 Mdot
.74783 .5969 Mdot
.74784 .5969 Mdot
.74785 .5969 Mdot
.74786 .59689 Mdot
.74787 .59689 Mdot
.74788 .59689 Mdot
.74789 .59688 Mdot
.7479 .59688 Mdot
.7479 .59688 Mdot
.74791 .59687 Mdot
.74792 .59687 Mdot
.74793 .59687 Mdot
.74794 .59686 Mdot
.74795 .59686 Mdot
.74796 .59685 Mdot
.74797 .59685 Mdot
.74798 .59685 Mdot
.74799 .59684 Mdot
.748 .59684 Mdot
.74801 .59684 Mdot
.74802 .59683 Mdot
.74803 .59683 Mdot
.74804 .59683 Mdot
.74805 .59682 Mdot
.74806 .59682 Mdot
.74807 .59681 Mdot
.74808 .59681 Mdot
.74809 .59681 Mdot
.7481 .5968 Mdot
.7481 .5968 Mdot
.74811 .5968 Mdot
.74812 .59679 Mdot
.74813 .59679 Mdot
.74814 .59679 Mdot
.74815 .59678 Mdot
.74816 .59678 Mdot
.74817 .59677 Mdot
.74818 .59677 Mdot
.74819 .59677 Mdot
.7482 .59676 Mdot
.74821 .59676 Mdot
.74822 .59676 Mdot
.74823 .59675 Mdot
.74824 .59675 Mdot
.74825 .59674 Mdot
.74826 .59674 Mdot
.74827 .59674 Mdot
.74828 .59673 Mdot
.74829 .59673 Mdot
.7483 .59673 Mdot
.7483 .59672 Mdot
.74831 .59672 Mdot
.74832 .59672 Mdot
.74833 .59671 Mdot
.74834 .59671 Mdot
.74835 .5967 Mdot
.74836 .5967 Mdot
.74837 .5967 Mdot
.74838 .59669 Mdot
.74839 .59669 Mdot
.7484 .59669 Mdot
.74841 .59668 Mdot
.74842 .59668 Mdot
.74843 .59668 Mdot
.74844 .59667 Mdot
.74845 .59667 Mdot
.74846 .59666 Mdot
.74847 .59666 Mdot
.74848 .59666 Mdot
.74849 .59665 Mdot
.7485 .59665 Mdot
.7485 .59665 Mdot
.74851 .59664 Mdot
.74852 .59664 Mdot
.74853 .59663 Mdot
.74854 .59663 Mdot
.74855 .59663 Mdot
.74856 .59662 Mdot
.74857 .59662 Mdot
.74858 .59662 Mdot
.74859 .59661 Mdot
.7486 .59661 Mdot
.74861 .59661 Mdot
.74862 .5966 Mdot
.74863 .5966 Mdot
.74864 .59659 Mdot
.74865 .59659 Mdot
.74866 .59659 Mdot
.74867 .59658 Mdot
.74868 .59658 Mdot
.74869 .59658 Mdot
.7487 .59657 Mdot
.7487 .59657 Mdot
.74871 .59656 Mdot
.74872 .59656 Mdot
.74873 .59656 Mdot
.74874 .59655 Mdot
.74875 .59655 Mdot
.74876 .59655 Mdot
.74877 .59654 Mdot
.74878 .59654 Mdot
.74879 .59653 Mdot
.7488 .59653 Mdot
.74881 .59653 Mdot
.74882 .59652 Mdot
.74883 .59652 Mdot
.74884 .59652 Mdot
.74885 .59651 Mdot
.74886 .59651 Mdot
.74887 .5965 Mdot
.74888 .5965 Mdot
.74889 .5965 Mdot
.7489 .59649 Mdot
.7489 .59649 Mdot
.74891 .59649 Mdot
.74892 .59648 Mdot
.74893 .59648 Mdot
.74894 .59648 Mdot
.74895 .59647 Mdot
.74896 .59647 Mdot
.74897 .59646 Mdot
.74898 .59646 Mdot
.74899 .59646 Mdot
.749 .59645 Mdot
.74901 .59645 Mdot
.74902 .59645 Mdot
.74903 .59644 Mdot
.74904 .59644 Mdot
.74905 .59643 Mdot
.74906 .59643 Mdot
.74907 .59643 Mdot
.74908 .59642 Mdot
.74909 .59642 Mdot
.7491 .59642 Mdot
.7491 .59641 Mdot
.74911 .59641 Mdot
.74912 .5964 Mdot
.74913 .5964 Mdot
.74914 .5964 Mdot
.74915 .59639 Mdot
.74916 .59639 Mdot
.74917 .59639 Mdot
.74918 .59638 Mdot
.74919 .59638 Mdot
.7492 .59637 Mdot
.74921 .59637 Mdot
.74922 .59637 Mdot
.74923 .59636 Mdot
.74924 .59636 Mdot
.74925 .59636 Mdot
.74926 .59635 Mdot
.74927 .59635 Mdot
.74928 .59634 Mdot
.74929 .59634 Mdot
.7493 .59634 Mdot
.7493 .59633 Mdot
.74931 .59633 Mdot
.74932 .59633 Mdot
.74933 .59632 Mdot
.74934 .59632 Mdot
.74935 .59631 Mdot
.74936 .59631 Mdot
.74937 .59631 Mdot
.74938 .5963 Mdot
.74939 .5963 Mdot
.7494 .59629 Mdot
.74941 .59629 Mdot
.74942 .59629 Mdot
.74943 .59628 Mdot
.74944 .59628 Mdot
.74945 .59628 Mdot
.74946 .59627 Mdot
.74947 .59627 Mdot
.74948 .59626 Mdot
.74949 .59626 Mdot
.7495 .59626 Mdot
.7495 .59625 Mdot
.74951 .59625 Mdot
.74952 .59625 Mdot
.74953 .59624 Mdot
.74954 .59624 Mdot
.74955 .59623 Mdot
.74956 .59623 Mdot
.74957 .59623 Mdot
.74958 .59622 Mdot
.74959 .59622 Mdot
.7496 .59622 Mdot
.74961 .59621 Mdot
.74962 .59621 Mdot
.74963 .5962 Mdot
.74964 .5962 Mdot
.74965 .5962 Mdot
.74966 .59619 Mdot
.74967 .59619 Mdot
.74968 .59619 Mdot
.74969 .59618 Mdot
.7497 .59618 Mdot
.7497 .59617 Mdot
.74971 .59617 Mdot
.74972 .59617 Mdot
.74973 .59616 Mdot
.74974 .59616 Mdot
.74975 .59615 Mdot
.74976 .59615 Mdot
.74977 .59615 Mdot
.74978 .59614 Mdot
.74979 .59614 Mdot
.7498 .59614 Mdot
.74981 .59613 Mdot
.74982 .59613 Mdot
.74983 .59612 Mdot
.74984 .59612 Mdot
.74985 .59612 Mdot
.74986 .59611 Mdot
.74987 .59611 Mdot
.74988 .5961 Mdot
.74989 .5961 Mdot
.7499 .5961 Mdot
.7499 .59609 Mdot
.74991 .59609 Mdot
.74992 .59609 Mdot
.74993 .59608 Mdot
.74994 .59608 Mdot
.74995 .59607 Mdot
.74996 .59607 Mdot
.74997 .59607 Mdot
.74998 .59606 Mdot
.74999 .59606 Mdot
.75 .59606 Mdot
.75001 .59605 Mdot
.75002 .59605 Mdot
.75003 .59604 Mdot
.75004 .59604 Mdot
.75005 .59604 Mdot
.75006 .59603 Mdot
.75007 .59603 Mdot
.75008 .59602 Mdot
.75009 .59602 Mdot
.7501 .59602 Mdot
.7501 .59601 Mdot
.75011 .59601 Mdot
.75012 .59601 Mdot
.75013 .596 Mdot
.75014 .596 Mdot
.75015 .59599 Mdot
.75016 .59599 Mdot
.75017 .59599 Mdot
.75018 .59598 Mdot
.75019 .59598 Mdot
.7502 .59597 Mdot
.75021 .59597 Mdot
.75022 .59597 Mdot
.75023 .59596 Mdot
.75024 .59596 Mdot
.75025 .59595 Mdot
.75026 .59595 Mdot
.75027 .59595 Mdot
.75028 .59594 Mdot
.75029 .59594 Mdot
.7503 .59594 Mdot
.7503 .59593 Mdot
.75031 .59593 Mdot
.75032 .59592 Mdot
.75033 .59592 Mdot
.75034 .59592 Mdot
.75035 .59591 Mdot
.75036 .59591 Mdot
.75037 .5959 Mdot
.75038 .5959 Mdot
.75039 .5959 Mdot
.7504 .59589 Mdot
.75041 .59589 Mdot
.75042 .59589 Mdot
.75043 .59588 Mdot
.75044 .59588 Mdot
.75045 .59587 Mdot
.75046 .59587 Mdot
.75047 .59587 Mdot
.75048 .59586 Mdot
.75049 .59586 Mdot
.7505 .59585 Mdot
.7505 .59585 Mdot
.75051 .59585 Mdot
.75052 .59584 Mdot
.75053 .59584 Mdot
.75054 .59583 Mdot
.75055 .59583 Mdot
.75056 .59583 Mdot
.75057 .59582 Mdot
.75058 .59582 Mdot
.75059 .59582 Mdot
.7506 .59581 Mdot
.75061 .59581 Mdot
.75062 .5958 Mdot
.75063 .5958 Mdot
.75064 .5958 Mdot
.75065 .59579 Mdot
.75066 .59579 Mdot
.75067 .59578 Mdot
.75068 .59578 Mdot
.75069 .59578 Mdot
.7507 .59577 Mdot
.7507 .59577 Mdot
.75071 .59576 Mdot
.75072 .59576 Mdot
.75073 .59576 Mdot
.75074 .59575 Mdot
.75075 .59575 Mdot
.75076 .59574 Mdot
.75077 .59574 Mdot
.75078 .59574 Mdot
.75079 .59573 Mdot
.7508 .59573 Mdot
.75081 .59573 Mdot
.75082 .59572 Mdot
.75083 .59572 Mdot
.75084 .59571 Mdot
.75085 .59571 Mdot
.75086 .59571 Mdot
.75087 .5957 Mdot
.75088 .5957 Mdot
.75089 .59569 Mdot
.7509 .59569 Mdot
.7509 .59569 Mdot
.75091 .59568 Mdot
.75092 .59568 Mdot
.75093 .59567 Mdot
.75094 .59567 Mdot
.75095 .59567 Mdot
.75096 .59566 Mdot
.75097 .59566 Mdot
.75098 .59565 Mdot
.75099 .59565 Mdot
.751 .59565 Mdot
.75101 .59564 Mdot
.75102 .59564 Mdot
.75103 .59563 Mdot
.75104 .59563 Mdot
.75105 .59563 Mdot
.75106 .59562 Mdot
.75107 .59562 Mdot
.75108 .59561 Mdot
.75109 .59561 Mdot
.7511 .59561 Mdot
.7511 .5956 Mdot
.75111 .5956 Mdot
.75112 .5956 Mdot
.75113 .59559 Mdot
.75114 .59559 Mdot
.75115 .59558 Mdot
.75116 .59558 Mdot
.75117 .59558 Mdot
.75118 .59557 Mdot
.75119 .59557 Mdot
.7512 .59556 Mdot
.75121 .59556 Mdot
.75122 .59556 Mdot
.75123 .59555 Mdot
.75124 .59555 Mdot
.75125 .59554 Mdot
.75126 .59554 Mdot
.75127 .59554 Mdot
.75128 .59553 Mdot
.75129 .59553 Mdot
.7513 .59552 Mdot
.7513 .59552 Mdot
.75131 .59552 Mdot
.75132 .59551 Mdot
.75133 .59551 Mdot
.75134 .5955 Mdot
.75135 .5955 Mdot
.75136 .5955 Mdot
.75137 .59549 Mdot
.75138 .59549 Mdot
.75139 .59548 Mdot
.7514 .59548 Mdot
.75141 .59548 Mdot
.75142 .59547 Mdot
.75143 .59547 Mdot
.75144 .59546 Mdot
.75145 .59546 Mdot
.75146 .59546 Mdot
.75147 .59545 Mdot
.75148 .59545 Mdot
.75149 .59544 Mdot
.7515 .59544 Mdot
.7515 .59544 Mdot
.75151 .59543 Mdot
.75152 .59543 Mdot
.75153 .59542 Mdot
.75154 .59542 Mdot
.75155 .59542 Mdot
.75156 .59541 Mdot
.75157 .59541 Mdot
.75158 .5954 Mdot
.75159 .5954 Mdot
.7516 .5954 Mdot
.75161 .59539 Mdot
.75162 .59539 Mdot
.75163 .59538 Mdot
.75164 .59538 Mdot
.75165 .59538 Mdot
.75166 .59537 Mdot
.75167 .59537 Mdot
.75168 .59536 Mdot
.75169 .59536 Mdot
.7517 .59536 Mdot
.7517 .59535 Mdot
.75171 .59535 Mdot
.75172 .59534 Mdot
.75173 .59534 Mdot
.75174 .59534 Mdot
.75175 .59533 Mdot
.75176 .59533 Mdot
.75177 .59532 Mdot
.75178 .59532 Mdot
.75179 .59532 Mdot
.7518 .59531 Mdot
.75181 .59531 Mdot
.75182 .5953 Mdot
.75183 .5953 Mdot
.75184 .5953 Mdot
.75185 .59529 Mdot
.75186 .59529 Mdot
.75187 .59528 Mdot
.75188 .59528 Mdot
.75189 .59528 Mdot
.7519 .59527 Mdot
.7519 .59527 Mdot
.75191 .59526 Mdot
.75192 .59526 Mdot
.75193 .59526 Mdot
.75194 .59525 Mdot
.75195 .59525 Mdot
.75196 .59524 Mdot
.75197 .59524 Mdot
.75198 .59524 Mdot
.75199 .59523 Mdot
.752 .59523 Mdot
.75201 .59522 Mdot
.75202 .59522 Mdot
.75203 .59522 Mdot
.75204 .59521 Mdot
.75205 .59521 Mdot
.75206 .5952 Mdot
.75207 .5952 Mdot
.75208 .59519 Mdot
.75209 .59519 Mdot
.7521 .59519 Mdot
.7521 .59518 Mdot
.75211 .59518 Mdot
.75212 .59517 Mdot
.75213 .59517 Mdot
.75214 .59517 Mdot
.75215 .59516 Mdot
.75216 .59516 Mdot
.75217 .59515 Mdot
.75218 .59515 Mdot
.75219 .59515 Mdot
.7522 .59514 Mdot
.75221 .59514 Mdot
.75222 .59513 Mdot
.75223 .59513 Mdot
.75224 .59513 Mdot
.75225 .59512 Mdot
.75226 .59512 Mdot
.75227 .59511 Mdot
.75228 .59511 Mdot
.75229 .59511 Mdot
.7523 .5951 Mdot
.7523 .5951 Mdot
.75231 .59509 Mdot
.75232 .59509 Mdot
.75233 .59509 Mdot
.75234 .59508 Mdot
.75235 .59508 Mdot
.75236 .59507 Mdot
.75237 .59507 Mdot
.75238 .59506 Mdot
.75239 .59506 Mdot
.7524 .59506 Mdot
.75241 .59505 Mdot
.75242 .59505 Mdot
.75243 .59504 Mdot
.75244 .59504 Mdot
.75245 .59504 Mdot
.75246 .59503 Mdot
.75247 .59503 Mdot
.75248 .59502 Mdot
.75249 .59502 Mdot
.7525 .59502 Mdot
.7525 .59501 Mdot
.75251 .59501 Mdot
.75252 .595 Mdot
.75253 .595 Mdot
.75254 .595 Mdot
.75255 .59499 Mdot
.75256 .59499 Mdot
.75257 .59498 Mdot
.75258 .59498 Mdot
.75259 .59497 Mdot
.7526 .59497 Mdot
.75261 .59497 Mdot
.75262 .59496 Mdot
.75263 .59496 Mdot
.75264 .59495 Mdot
.75265 .59495 Mdot
.75266 .59495 Mdot
.75267 .59494 Mdot
.75268 .59494 Mdot
.75269 .59493 Mdot
.7527 .59493 Mdot
.7527 .59493 Mdot
.75271 .59492 Mdot
.75272 .59492 Mdot
.75273 .59491 Mdot
.75274 .59491 Mdot
.75275 .5949 Mdot
.75276 .5949 Mdot
.75277 .5949 Mdot
.75278 .59489 Mdot
.75279 .59489 Mdot
.7528 .59488 Mdot
.75281 .59488 Mdot
.75282 .59488 Mdot
.75283 .59487 Mdot
.75284 .59487 Mdot
.75285 .59486 Mdot
.75286 .59486 Mdot
.75287 .59486 Mdot
.75288 .59485 Mdot
.75289 .59485 Mdot
.7529 .59484 Mdot
.7529 .59484 Mdot
.75291 .59483 Mdot
.75292 .59483 Mdot
.75293 .59483 Mdot
.75294 .59482 Mdot
.75295 .59482 Mdot
.75296 .59481 Mdot
.75297 .59481 Mdot
.75298 .59481 Mdot
.75299 .5948 Mdot
.753 .5948 Mdot
.75301 .59479 Mdot
.75302 .59479 Mdot
.75303 .59478 Mdot
.75304 .59478 Mdot
.75305 .59478 Mdot
.75306 .59477 Mdot
.75307 .59477 Mdot
.75308 .59476 Mdot
.75309 .59476 Mdot
.7531 .59476 Mdot
.7531 .59475 Mdot
.75311 .59475 Mdot
.75312 .59474 Mdot
.75313 .59474 Mdot
.75314 .59473 Mdot
.75315 .59473 Mdot
.75316 .59473 Mdot
.75317 .59472 Mdot
.75318 .59472 Mdot
.75319 .59471 Mdot
.7532 .59471 Mdot
.75321 .59471 Mdot
.75322 .5947 Mdot
.75323 .5947 Mdot
.75324 .59469 Mdot
.75325 .59469 Mdot
.75326 .59468 Mdot
.75327 .59468 Mdot
.75328 .59468 Mdot
.75329 .59467 Mdot
.7533 .59467 Mdot
.7533 .59466 Mdot
.75331 .59466 Mdot
.75332 .59466 Mdot
.75333 .59465 Mdot
.75334 .59465 Mdot
.75335 .59464 Mdot
.75336 .59464 Mdot
.75337 .59463 Mdot
.75338 .59463 Mdot
.75339 .59463 Mdot
.7534 .59462 Mdot
.75341 .59462 Mdot
.75342 .59461 Mdot
.75343 .59461 Mdot
.75344 .59461 Mdot
.75345 .5946 Mdot
.75346 .5946 Mdot
.75347 .59459 Mdot
.75348 .59459 Mdot
.75349 .59458 Mdot
.7535 .59458 Mdot
.7535 .59458 Mdot
.75351 .59457 Mdot
.75352 .59457 Mdot
.75353 .59456 Mdot
.75354 .59456 Mdot
.75355 .59456 Mdot
.75356 .59455 Mdot
.75357 .59455 Mdot
.75358 .59454 Mdot
.75359 .59454 Mdot
.7536 .59453 Mdot
.75361 .59453 Mdot
.75362 .59453 Mdot
.75363 .59452 Mdot
.75364 .59452 Mdot
.75365 .59451 Mdot
.75366 .59451 Mdot
.75367 .5945 Mdot
.75368 .5945 Mdot
.75369 .5945 Mdot
.7537 .59449 Mdot
.7537 .59449 Mdot
.75371 .59448 Mdot
.75372 .59448 Mdot
.75373 .59448 Mdot
.75374 .59447 Mdot
.75375 .59447 Mdot
.75376 .59446 Mdot
.75377 .59446 Mdot
.75378 .59445 Mdot
.75379 .59445 Mdot
.7538 .59445 Mdot
.75381 .59444 Mdot
.75382 .59444 Mdot
.75383 .59443 Mdot
.75384 .59443 Mdot
.75385 .59442 Mdot
.75386 .59442 Mdot
.75387 .59442 Mdot
.75388 .59441 Mdot
.75389 .59441 Mdot
.7539 .5944 Mdot
.7539 .5944 Mdot
.75391 .59439 Mdot
.75392 .59439 Mdot
.75393 .59439 Mdot
.75394 .59438 Mdot
.75395 .59438 Mdot
.75396 .59437 Mdot
.75397 .59437 Mdot
.75398 .59436 Mdot
.75399 .59436 Mdot
.754 .59436 Mdot
.75401 .59435 Mdot
.75402 .59435 Mdot
.75403 .59434 Mdot
.75404 .59434 Mdot
.75405 .59434 Mdot
.75406 .59433 Mdot
.75407 .59433 Mdot
.75408 .59432 Mdot
.75409 .59432 Mdot
.7541 .59431 Mdot
.7541 .59431 Mdot
.75411 .59431 Mdot
.75412 .5943 Mdot
.75413 .5943 Mdot
.75414 .59429 Mdot
.75415 .59429 Mdot
.75416 .59428 Mdot
.75417 .59428 Mdot
.75418 .59428 Mdot
.75419 .59427 Mdot
.7542 .59427 Mdot
.75421 .59426 Mdot
.75422 .59426 Mdot
.75423 .59425 Mdot
.75424 .59425 Mdot
.75425 .59425 Mdot
.75426 .59424 Mdot
.75427 .59424 Mdot
.75428 .59423 Mdot
.75429 .59423 Mdot
.7543 .59422 Mdot
.7543 .59422 Mdot
.75431 .59422 Mdot
.75432 .59421 Mdot
.75433 .59421 Mdot
.75434 .5942 Mdot
.75435 .5942 Mdot
.75436 .59419 Mdot
.75437 .59419 Mdot
.75438 .59419 Mdot
.75439 .59418 Mdot
.7544 .59418 Mdot
.75441 .59417 Mdot
.75442 .59417 Mdot
.75443 .59416 Mdot
.75444 .59416 Mdot
.75445 .59416 Mdot
.75446 .59415 Mdot
.75447 .59415 Mdot
.75448 .59414 Mdot
.75449 .59414 Mdot
.7545 .59413 Mdot
.7545 .59413 Mdot
.75451 .59413 Mdot
.75452 .59412 Mdot
.75453 .59412 Mdot
.75454 .59411 Mdot
.75455 .59411 Mdot
.75456 .5941 Mdot
.75457 .5941 Mdot
.75458 .5941 Mdot
.75459 .59409 Mdot
.7546 .59409 Mdot
.75461 .59408 Mdot
.75462 .59408 Mdot
.75463 .59407 Mdot
.75464 .59407 Mdot
.75465 .59407 Mdot
.75466 .59406 Mdot
.75467 .59406 Mdot
.75468 .59405 Mdot
.75469 .59405 Mdot
.7547 .59404 Mdot
.7547 .59404 Mdot
.75471 .59404 Mdot
.75472 .59403 Mdot
.75473 .59403 Mdot
.75474 .59402 Mdot
.75475 .59402 Mdot
.75476 .59401 Mdot
.75477 .59401 Mdot
.75478 .594 Mdot
.75479 .594 Mdot
.7548 .594 Mdot
.75481 .59399 Mdot
.75482 .59399 Mdot
.75483 .59398 Mdot
.75484 .59398 Mdot
.75485 .59397 Mdot
.75486 .59397 Mdot
.75487 .59397 Mdot
.75488 .59396 Mdot
.75489 .59396 Mdot
.7549 .59395 Mdot
.7549 .59395 Mdot
.75491 .59394 Mdot
.75492 .59394 Mdot
.75493 .59394 Mdot
.75494 .59393 Mdot
.75495 .59393 Mdot
.75496 .59392 Mdot
.75497 .59392 Mdot
.75498 .59391 Mdot
.75499 .59391 Mdot
.755 .5939 Mdot
.75501 .5939 Mdot
.75502 .5939 Mdot
.75503 .59389 Mdot
.75504 .59389 Mdot
.75505 .59388 Mdot
.75506 .59388 Mdot
.75507 .59387 Mdot
.75508 .59387 Mdot
.75509 .59387 Mdot
.7551 .59386 Mdot
.7551 .59386 Mdot
.75511 .59385 Mdot
.75512 .59385 Mdot
.75513 .59384 Mdot
.75514 .59384 Mdot
.75515 .59384 Mdot
.75516 .59383 Mdot
.75517 .59383 Mdot
.75518 .59382 Mdot
.75519 .59382 Mdot
.7552 .59381 Mdot
.75521 .59381 Mdot
.75522 .5938 Mdot
.75523 .5938 Mdot
.75524 .5938 Mdot
.75525 .59379 Mdot
.75526 .59379 Mdot
.75527 .59378 Mdot
.75528 .59378 Mdot
.75529 .59377 Mdot
.7553 .59377 Mdot
.7553 .59377 Mdot
.75531 .59376 Mdot
.75532 .59376 Mdot
.75533 .59375 Mdot
.75534 .59375 Mdot
.75535 .59374 Mdot
.75536 .59374 Mdot
.75537 .59373 Mdot
.75538 .59373 Mdot
.75539 .59373 Mdot
.7554 .59372 Mdot
.75541 .59372 Mdot
.75542 .59371 Mdot
.75543 .59371 Mdot
.75544 .5937 Mdot
.75545 .5937 Mdot
.75546 .59369 Mdot
.75547 .59369 Mdot
.75548 .59369 Mdot
.75549 .59368 Mdot
.7555 .59368 Mdot
.7555 .59367 Mdot
.75551 .59367 Mdot
.75552 .59366 Mdot
.75553 .59366 Mdot
.75554 .59366 Mdot
.75555 .59365 Mdot
.75556 .59365 Mdot
.75557 .59364 Mdot
.75558 .59364 Mdot
.75559 .59363 Mdot
.7556 .59363 Mdot
.75561 .59362 Mdot
.75562 .59362 Mdot
.75563 .59362 Mdot
.75564 .59361 Mdot
.75565 .59361 Mdot
.75566 .5936 Mdot
.75567 .5936 Mdot
.75568 .59359 Mdot
.75569 .59359 Mdot
.7557 .59358 Mdot
.7557 .59358 Mdot
.75571 .59358 Mdot
.75572 .59357 Mdot
.75573 .59357 Mdot
.75574 .59356 Mdot
.75575 .59356 Mdot
.75576 .59355 Mdot
.75577 .59355 Mdot
.75578 .59354 Mdot
.75579 .59354 Mdot
.7558 .59354 Mdot
.75581 .59353 Mdot
.75582 .59353 Mdot
.75583 .59352 Mdot
.75584 .59352 Mdot
.75585 .59351 Mdot
.75586 .59351 Mdot
.75587 .59351 Mdot
.75588 .5935 Mdot
.75589 .5935 Mdot
.7559 .59349 Mdot
.7559 .59349 Mdot
.75591 .59348 Mdot
.75592 .59348 Mdot
.75593 .59347 Mdot
.75594 .59347 Mdot
.75595 .59347 Mdot
.75596 .59346 Mdot
.75597 .59346 Mdot
.75598 .59345 Mdot
.75599 .59345 Mdot
.756 .59344 Mdot
.75601 .59344 Mdot
.75602 .59343 Mdot
.75603 .59343 Mdot
.75604 .59342 Mdot
.75605 .59342 Mdot
.75606 .59342 Mdot
.75607 .59341 Mdot
.75608 .59341 Mdot
.75609 .5934 Mdot
.7561 .5934 Mdot
.7561 .59339 Mdot
.75611 .59339 Mdot
.75612 .59338 Mdot
.75613 .59338 Mdot
.75614 .59338 Mdot
.75615 .59337 Mdot
.75616 .59337 Mdot
.75617 .59336 Mdot
.75618 .59336 Mdot
.75619 .59335 Mdot
.7562 .59335 Mdot
.75621 .59334 Mdot
.75622 .59334 Mdot
.75623 .59334 Mdot
.75624 .59333 Mdot
.75625 .59333 Mdot
.75626 .59332 Mdot
.75627 .59332 Mdot
.75628 .59331 Mdot
.75629 .59331 Mdot
.7563 .5933 Mdot
.7563 .5933 Mdot
.75631 .5933 Mdot
.75632 .59329 Mdot
.75633 .59329 Mdot
.75634 .59328 Mdot
.75635 .59328 Mdot
.75636 .59327 Mdot
.75637 .59327 Mdot
.75638 .59326 Mdot
.75639 .59326 Mdot
.7564 .59325 Mdot
.75641 .59325 Mdot
.75642 .59325 Mdot
.75643 .59324 Mdot
.75644 .59324 Mdot
.75645 .59323 Mdot
.75646 .59323 Mdot
.75647 .59322 Mdot
.75648 .59322 Mdot
.75649 .59321 Mdot
.7565 .59321 Mdot
.7565 .59321 Mdot
.75651 .5932 Mdot
.75652 .5932 Mdot
.75653 .59319 Mdot
.75654 .59319 Mdot
.75655 .59318 Mdot
.75656 .59318 Mdot
.75657 .59317 Mdot
.75658 .59317 Mdot
.75659 .59316 Mdot
.7566 .59316 Mdot
.75661 .59316 Mdot
.75662 .59315 Mdot
.75663 .59315 Mdot
.75664 .59314 Mdot
.75665 .59314 Mdot
.75666 .59313 Mdot
.75667 .59313 Mdot
.75668 .59312 Mdot
.75669 .59312 Mdot
.7567 .59312 Mdot
.7567 .59311 Mdot
.75671 .59311 Mdot
.75672 .5931 Mdot
.75673 .5931 Mdot
.75674 .59309 Mdot
.75675 .59309 Mdot
.75676 .59308 Mdot
.75677 .59308 Mdot
.75678 .59307 Mdot
.75679 .59307 Mdot
.7568 .59307 Mdot
.75681 .59306 Mdot
.75682 .59306 Mdot
.75683 .59305 Mdot
.75684 .59305 Mdot
.75685 .59304 Mdot
.75686 .59304 Mdot
.75687 .59303 Mdot
.75688 .59303 Mdot
.75689 .59302 Mdot
.7569 .59302 Mdot
.7569 .59302 Mdot
.75691 .59301 Mdot
.75692 .59301 Mdot
.75693 .593 Mdot
.75694 .593 Mdot
.75695 .59299 Mdot
.75696 .59299 Mdot
.75697 .59298 Mdot
.75698 .59298 Mdot
.75699 .59297 Mdot
.757 .59297 Mdot
.75701 .59297 Mdot
.75702 .59296 Mdot
.75703 .59296 Mdot
.75704 .59295 Mdot
.75705 .59295 Mdot
.75706 .59294 Mdot
.75707 .59294 Mdot
.75708 .59293 Mdot
.75709 .59293 Mdot
.7571 .59292 Mdot
.7571 .59292 Mdot
.75711 .59292 Mdot
.75712 .59291 Mdot
.75713 .59291 Mdot
.75714 .5929 Mdot
.75715 .5929 Mdot
.75716 .59289 Mdot
.75717 .59289 Mdot
.75718 .59288 Mdot
.75719 .59288 Mdot
.7572 .59287 Mdot
.75721 .59287 Mdot
.75722 .59287 Mdot
.75723 .59286 Mdot
.75724 .59286 Mdot
.75725 .59285 Mdot
.75726 .59285 Mdot
.75727 .59284 Mdot
.75728 .59284 Mdot
.75729 .59283 Mdot
.7573 .59283 Mdot
.7573 .59282 Mdot
.75731 .59282 Mdot
.75732 .59281 Mdot
.75733 .59281 Mdot
.75734 .59281 Mdot
.75735 .5928 Mdot
.75736 .5928 Mdot
.75737 .59279 Mdot
.75738 .59279 Mdot
.75739 .59278 Mdot
.7574 .59278 Mdot
.75741 .59277 Mdot
.75742 .59277 Mdot
.75743 .59276 Mdot
.75744 .59276 Mdot
.75745 .59275 Mdot
.75746 .59275 Mdot
.75747 .59275 Mdot
.75748 .59274 Mdot
.75749 .59274 Mdot
.7575 .59273 Mdot
.7575 .59273 Mdot
.75751 .59272 Mdot
.75752 .59272 Mdot
.75753 .59271 Mdot
.75754 .59271 Mdot
.75755 .5927 Mdot
.75756 .5927 Mdot
.75757 .5927 Mdot
.75758 .59269 Mdot
.75759 .59269 Mdot
.7576 .59268 Mdot
.75761 .59268 Mdot
.75762 .59267 Mdot
.75763 .59267 Mdot
.75764 .59266 Mdot
.75765 .59266 Mdot
.75766 .59265 Mdot
.75767 .59265 Mdot
.75768 .59264 Mdot
.75769 .59264 Mdot
.7577 .59264 Mdot
.7577 .59263 Mdot
.75771 .59263 Mdot
.75772 .59262 Mdot
.75773 .59262 Mdot
.75774 .59261 Mdot
.75775 .59261 Mdot
.75776 .5926 Mdot
.75777 .5926 Mdot
.75778 .59259 Mdot
.75779 .59259 Mdot
.7578 .59258 Mdot
.75781 .59258 Mdot
.75782 .59257 Mdot
.75783 .59257 Mdot
.75784 .59257 Mdot
.75785 .59256 Mdot
.75786 .59256 Mdot
.75787 .59255 Mdot
.75788 .59255 Mdot
.75789 .59254 Mdot
.7579 .59254 Mdot
.7579 .59253 Mdot
.75791 .59253 Mdot
.75792 .59252 Mdot
.75793 .59252 Mdot
.75794 .59251 Mdot
.75795 .59251 Mdot
.75796 .59251 Mdot
.75797 .5925 Mdot
.75798 .5925 Mdot
.75799 .59249 Mdot
.758 .59249 Mdot
.75801 .59248 Mdot
.75802 .59248 Mdot
.75803 .59247 Mdot
.75804 .59247 Mdot
.75805 .59246 Mdot
.75806 .59246 Mdot
.75807 .59245 Mdot
.75808 .59245 Mdot
.75809 .59244 Mdot
.7581 .59244 Mdot
.7581 .59244 Mdot
.75811 .59243 Mdot
.75812 .59243 Mdot
.75813 .59242 Mdot
.75814 .59242 Mdot
.75815 .59241 Mdot
.75816 .59241 Mdot
.75817 .5924 Mdot
.75818 .5924 Mdot
.75819 .59239 Mdot
.7582 .59239 Mdot
.75821 .59238 Mdot
.75822 .59238 Mdot
.75823 .59237 Mdot
.75824 .59237 Mdot
.75825 .59237 Mdot
.75826 .59236 Mdot
.75827 .59236 Mdot
.75828 .59235 Mdot
.75829 .59235 Mdot
.7583 .59234 Mdot
.7583 .59234 Mdot
.75831 .59233 Mdot
.75832 .59233 Mdot
.75833 .59232 Mdot
.75834 .59232 Mdot
.75835 .59231 Mdot
.75836 .59231 Mdot
.75837 .5923 Mdot
.75838 .5923 Mdot
.75839 .5923 Mdot
.7584 .59229 Mdot
.75841 .59229 Mdot
.75842 .59228 Mdot
.75843 .59228 Mdot
.75844 .59227 Mdot
.75845 .59227 Mdot
.75846 .59226 Mdot
.75847 .59226 Mdot
.75848 .59225 Mdot
.75849 .59225 Mdot
.7585 .59224 Mdot
.7585 .59224 Mdot
.75851 .59223 Mdot
.75852 .59223 Mdot
.75853 .59222 Mdot
.75854 .59222 Mdot
.75855 .59222 Mdot
.75856 .59221 Mdot
.75857 .59221 Mdot
.75858 .5922 Mdot
.75859 .5922 Mdot
.7586 .59219 Mdot
.75861 .59219 Mdot
.75862 .59218 Mdot
.75863 .59218 Mdot
.75864 .59217 Mdot
.75865 .59217 Mdot
.75866 .59216 Mdot
.75867 .59216 Mdot
.75868 .59215 Mdot
.75869 .59215 Mdot
.7587 .59214 Mdot
.7587 .59214 Mdot
.75871 .59213 Mdot
.75872 .59213 Mdot
.75873 .59213 Mdot
.75874 .59212 Mdot
.75875 .59212 Mdot
.75876 .59211 Mdot
.75877 .59211 Mdot
.75878 .5921 Mdot
.75879 .5921 Mdot
.7588 .59209 Mdot
.75881 .59209 Mdot
.75882 .59208 Mdot
.75883 .59208 Mdot
.75884 .59207 Mdot
.75885 .59207 Mdot
.75886 .59206 Mdot
.75887 .59206 Mdot
.75888 .59205 Mdot
.75889 .59205 Mdot
.7589 .59204 Mdot
.7589 .59204 Mdot
.75891 .59204 Mdot
.75892 .59203 Mdot
.75893 .59203 Mdot
.75894 .59202 Mdot
.75895 .59202 Mdot
.75896 .59201 Mdot
.75897 .59201 Mdot
.75898 .592 Mdot
.75899 .592 Mdot
.759 .59199 Mdot
.75901 .59199 Mdot
.75902 .59198 Mdot
.75903 .59198 Mdot
.75904 .59197 Mdot
.75905 .59197 Mdot
.75906 .59196 Mdot
.75907 .59196 Mdot
.75908 .59195 Mdot
.75909 .59195 Mdot
.7591 .59195 Mdot
.7591 .59194 Mdot
.75911 .59194 Mdot
.75912 .59193 Mdot
.75913 .59193 Mdot
.75914 .59192 Mdot
.75915 .59192 Mdot
.75916 .59191 Mdot
.75917 .59191 Mdot
.75918 .5919 Mdot
.75919 .5919 Mdot
.7592 .59189 Mdot
.75921 .59189 Mdot
.75922 .59188 Mdot
.75923 .59188 Mdot
.75924 .59187 Mdot
.75925 .59187 Mdot
.75926 .59186 Mdot
.75927 .59186 Mdot
.75928 .59185 Mdot
.75929 .59185 Mdot
.7593 .59184 Mdot
.7593 .59184 Mdot
.75931 .59184 Mdot
.75932 .59183 Mdot
.75933 .59183 Mdot
.75934 .59182 Mdot
.75935 .59182 Mdot
.75936 .59181 Mdot
.75937 .59181 Mdot
.75938 .5918 Mdot
.75939 .5918 Mdot
.7594 .59179 Mdot
.75941 .59179 Mdot
.75942 .59178 Mdot
.75943 .59178 Mdot
.75944 .59177 Mdot
.75945 .59177 Mdot
.75946 .59176 Mdot
.75947 .59176 Mdot
.75948 .59175 Mdot
.75949 .59175 Mdot
.7595 .59174 Mdot
.7595 .59174 Mdot
.75951 .59173 Mdot
.75952 .59173 Mdot
.75953 .59173 Mdot
.75954 .59172 Mdot
.75955 .59172 Mdot
.75956 .59171 Mdot
.75957 .59171 Mdot
.75958 .5917 Mdot
.75959 .5917 Mdot
.7596 .59169 Mdot
.75961 .59169 Mdot
.75962 .59168 Mdot
.75963 .59168 Mdot
.75964 .59167 Mdot
.75965 .59167 Mdot
.75966 .59166 Mdot
.75967 .59166 Mdot
.75968 .59165 Mdot
.75969 .59165 Mdot
.7597 .59164 Mdot
.7597 .59164 Mdot
.75971 .59163 Mdot
.75972 .59163 Mdot
.75973 .59162 Mdot
.75974 .59162 Mdot
.75975 .59161 Mdot
.75976 .59161 Mdot
.75977 .5916 Mdot
.75978 .5916 Mdot
.75979 .59159 Mdot
.7598 .59159 Mdot
.75981 .59159 Mdot
.75982 .59158 Mdot
.75983 .59158 Mdot
.75984 .59157 Mdot
.75985 .59157 Mdot
.75986 .59156 Mdot
.75987 .59156 Mdot
.75988 .59155 Mdot
.75989 .59155 Mdot
.7599 .59154 Mdot
.7599 .59154 Mdot
.75991 .59153 Mdot
.75992 .59153 Mdot
.75993 .59152 Mdot
.75994 .59152 Mdot
.75995 .59151 Mdot
.75996 .59151 Mdot
.75997 .5915 Mdot
.75998 .5915 Mdot
.75999 .59149 Mdot
.76 .59149 Mdot
.76001 .59148 Mdot
.76002 .59148 Mdot
.76003 .59147 Mdot
.76004 .59147 Mdot
.76005 .59146 Mdot
.76006 .59146 Mdot
.76007 .59145 Mdot
.76008 .59145 Mdot
.76009 .59144 Mdot
.7601 .59144 Mdot
.7601 .59143 Mdot
.76011 .59143 Mdot
.76012 .59143 Mdot
.76013 .59142 Mdot
.76014 .59142 Mdot
.76015 .59141 Mdot
.76016 .59141 Mdot
.76017 .5914 Mdot
.76018 .5914 Mdot
.76019 .59139 Mdot
.7602 .59139 Mdot
.76021 .59138 Mdot
.76022 .59138 Mdot
.76023 .59137 Mdot
.76024 .59137 Mdot
.76025 .59136 Mdot
.76026 .59136 Mdot
.76027 .59135 Mdot
.76028 .59135 Mdot
.76029 .59134 Mdot
.7603 .59134 Mdot
.7603 .59133 Mdot
.76031 .59133 Mdot
.76032 .59132 Mdot
.76033 .59132 Mdot
.76034 .59131 Mdot
.76035 .59131 Mdot
.76036 .5913 Mdot
.76037 .5913 Mdot
.76038 .59129 Mdot
.76039 .59129 Mdot
.7604 .59128 Mdot
.76041 .59128 Mdot
.76042 .59127 Mdot
.76043 .59127 Mdot
.76044 .59126 Mdot
.76045 .59126 Mdot
.76046 .59125 Mdot
.76047 .59125 Mdot
.76048 .59124 Mdot
.76049 .59124 Mdot
.7605 .59123 Mdot
.7605 .59123 Mdot
.76051 .59122 Mdot
.76052 .59122 Mdot
.76053 .59121 Mdot
.76054 .59121 Mdot
.76055 .59121 Mdot
.76056 .5912 Mdot
.76057 .5912 Mdot
.76058 .59119 Mdot
.76059 .59119 Mdot
.7606 .59118 Mdot
.76061 .59118 Mdot
.76062 .59117 Mdot
.76063 .59117 Mdot
.76064 .59116 Mdot
.76065 .59116 Mdot
.76066 .59115 Mdot
.76067 .59115 Mdot
.76068 .59114 Mdot
.76069 .59114 Mdot
.7607 .59113 Mdot
.7607 .59113 Mdot
.76071 .59112 Mdot
.76072 .59112 Mdot
.76073 .59111 Mdot
.76074 .59111 Mdot
.76075 .5911 Mdot
.76076 .5911 Mdot
.76077 .59109 Mdot
.76078 .59109 Mdot
.76079 .59108 Mdot
.7608 .59108 Mdot
.76081 .59107 Mdot
.76082 .59107 Mdot
.76083 .59106 Mdot
.76084 .59106 Mdot
.76085 .59105 Mdot
.76086 .59105 Mdot
.76087 .59104 Mdot
.76088 .59104 Mdot
.76089 .59103 Mdot
.7609 .59103 Mdot
.7609 .59102 Mdot
.76091 .59102 Mdot
.76092 .59101 Mdot
.76093 .59101 Mdot
.76094 .591 Mdot
.76095 .591 Mdot
.76096 .59099 Mdot
.76097 .59099 Mdot
.76098 .59098 Mdot
.76099 .59098 Mdot
.761 .59097 Mdot
.76101 .59097 Mdot
.76102 .59096 Mdot
.76103 .59096 Mdot
.76104 .59095 Mdot
.76105 .59095 Mdot
.76106 .59094 Mdot
.76107 .59094 Mdot
.76108 .59093 Mdot
.76109 .59093 Mdot
.7611 .59092 Mdot
.7611 .59092 Mdot
.76111 .59091 Mdot
.76112 .59091 Mdot
.76113 .5909 Mdot
.76114 .5909 Mdot
.76115 .59089 Mdot
.76116 .59089 Mdot
.76117 .59088 Mdot
.76118 .59088 Mdot
.76119 .59087 Mdot
.7612 .59087 Mdot
.76121 .59086 Mdot
.76122 .59086 Mdot
.76123 .59085 Mdot
.76124 .59085 Mdot
.76125 .59084 Mdot
.76126 .59084 Mdot
.76127 .59083 Mdot
.76128 .59083 Mdot
.76129 .59082 Mdot
.7613 .59082 Mdot
.7613 .59081 Mdot
.76131 .59081 Mdot
.76132 .5908 Mdot
.76133 .5908 Mdot
.76134 .59079 Mdot
.76135 .59079 Mdot
.76136 .59078 Mdot
.76137 .59078 Mdot
.76138 .59077 Mdot
.76139 .59077 Mdot
.7614 .59076 Mdot
.76141 .59076 Mdot
.76142 .59075 Mdot
.76143 .59075 Mdot
.76144 .59074 Mdot
.76145 .59074 Mdot
.76146 .59073 Mdot
.76147 .59073 Mdot
.76148 .59072 Mdot
.76149 .59072 Mdot
.7615 .59071 Mdot
.7615 .59071 Mdot
.76151 .5907 Mdot
.76152 .5907 Mdot
.76153 .59069 Mdot
.76154 .59069 Mdot
.76155 .59068 Mdot
.76156 .59068 Mdot
.76157 .59067 Mdot
.76158 .59067 Mdot
.76159 .59066 Mdot
.7616 .59066 Mdot
.76161 .59065 Mdot
.76162 .59065 Mdot
.76163 .59064 Mdot
.76164 .59064 Mdot
.76165 .59063 Mdot
.76166 .59063 Mdot
.76167 .59062 Mdot
.76168 .59062 Mdot
.76169 .59061 Mdot
.7617 .59061 Mdot
.7617 .5906 Mdot
.76171 .5906 Mdot
.76172 .59059 Mdot
.76173 .59059 Mdot
.76174 .59058 Mdot
.76175 .59058 Mdot
.76176 .59057 Mdot
.76177 .59057 Mdot
.76178 .59056 Mdot
.76179 .59056 Mdot
.7618 .59055 Mdot
.76181 .59055 Mdot
.76182 .59054 Mdot
.76183 .59054 Mdot
.76184 .59053 Mdot
.76185 .59053 Mdot
.76186 .59052 Mdot
.76187 .59052 Mdot
.76188 .59051 Mdot
.76189 .59051 Mdot
.7619 .5905 Mdot
.7619 .5905 Mdot
.76191 .59049 Mdot
.76192 .59049 Mdot
.76193 .59048 Mdot
.76194 .59048 Mdot
.76195 .59047 Mdot
.76196 .59047 Mdot
.76197 .59046 Mdot
.76198 .59046 Mdot
.76199 .59045 Mdot
.762 .59045 Mdot
.76201 .59044 Mdot
.76202 .59044 Mdot
.76203 .59043 Mdot
.76204 .59043 Mdot
.76205 .59042 Mdot
.76206 .59042 Mdot
.76207 .59041 Mdot
.76208 .59041 Mdot
.76209 .5904 Mdot
.7621 .5904 Mdot
.7621 .59039 Mdot
.76211 .59039 Mdot
.76212 .59038 Mdot
.76213 .59038 Mdot
.76214 .59037 Mdot
.76215 .59037 Mdot
.76216 .59036 Mdot
.76217 .59036 Mdot
.76218 .59035 Mdot
.76219 .59035 Mdot
.7622 .59034 Mdot
.76221 .59034 Mdot
.76222 .59033 Mdot
.76223 .59033 Mdot
.76224 .59032 Mdot
.76225 .59032 Mdot
.76226 .59031 Mdot
.76227 .59031 Mdot
.76228 .5903 Mdot
.76229 .5903 Mdot
.7623 .59029 Mdot
.7623 .59029 Mdot
.76231 .59028 Mdot
.76232 .59028 Mdot
.76233 .59027 Mdot
.76234 .59027 Mdot
.76235 .59026 Mdot
.76236 .59026 Mdot
.76237 .59025 Mdot
.76238 .59025 Mdot
.76239 .59024 Mdot
.7624 .59023 Mdot
.76241 .59023 Mdot
.76242 .59022 Mdot
.76243 .59022 Mdot
.76244 .59021 Mdot
.76245 .59021 Mdot
.76246 .5902 Mdot
.76247 .5902 Mdot
.76248 .59019 Mdot
.76249 .59019 Mdot
.7625 .59018 Mdot
.7625 .59018 Mdot
.76251 .59017 Mdot
.76252 .59017 Mdot
.76253 .59016 Mdot
.76254 .59016 Mdot
.76255 .59015 Mdot
.76256 .59015 Mdot
.76257 .59014 Mdot
.76258 .59014 Mdot
.76259 .59013 Mdot
.7626 .59013 Mdot
.76261 .59012 Mdot
.76262 .59012 Mdot
.76263 .59011 Mdot
.76264 .59011 Mdot
.76265 .5901 Mdot
.76266 .5901 Mdot
.76267 .59009 Mdot
.76268 .59009 Mdot
.76269 .59008 Mdot
.7627 .59008 Mdot
.7627 .59007 Mdot
.76271 .59007 Mdot
.76272 .59006 Mdot
.76273 .59006 Mdot
.76274 .59005 Mdot
.76275 .59005 Mdot
.76276 .59004 Mdot
.76277 .59004 Mdot
.76278 .59003 Mdot
.76279 .59003 Mdot
.7628 .59002 Mdot
.76281 .59002 Mdot
.76282 .59001 Mdot
.76283 .59 Mdot
.76284 .59 Mdot
.76285 .58999 Mdot
.76286 .58999 Mdot
.76287 .58998 Mdot
.76288 .58998 Mdot
.76289 .58997 Mdot
.7629 .58997 Mdot
.7629 .58996 Mdot
.76291 .58996 Mdot
.76292 .58995 Mdot
.76293 .58995 Mdot
.76294 .58994 Mdot
.76295 .58994 Mdot
.76296 .58993 Mdot
.76297 .58993 Mdot
.76298 .58992 Mdot
.76299 .58992 Mdot
.763 .58991 Mdot
.76301 .58991 Mdot
.76302 .5899 Mdot
.76303 .5899 Mdot
.76304 .58989 Mdot
.76305 .58989 Mdot
.76306 .58988 Mdot
.76307 .58988 Mdot
.76308 .58987 Mdot
.76309 .58987 Mdot
.7631 .58986 Mdot
.7631 .58986 Mdot
.76311 .58985 Mdot
.76312 .58985 Mdot
.76313 .58984 Mdot
.76314 .58983 Mdot
.76315 .58983 Mdot
.76316 .58982 Mdot
.76317 .58982 Mdot
.76318 .58981 Mdot
.76319 .58981 Mdot
.7632 .5898 Mdot
.76321 .5898 Mdot
.76322 .58979 Mdot
.76323 .58979 Mdot
.76324 .58978 Mdot
.76325 .58978 Mdot
.76326 .58977 Mdot
.76327 .58977 Mdot
.76328 .58976 Mdot
.76329 .58976 Mdot
.7633 .58975 Mdot
.7633 .58975 Mdot
.76331 .58974 Mdot
.76332 .58974 Mdot
.76333 .58973 Mdot
.76334 .58973 Mdot
.76335 .58972 Mdot
.76336 .58972 Mdot
.76337 .58971 Mdot
.76338 .58971 Mdot
.76339 .5897 Mdot
.7634 .58969 Mdot
.76341 .58969 Mdot
.76342 .58968 Mdot
.76343 .58968 Mdot
.76344 .58967 Mdot
.76345 .58967 Mdot
.76346 .58966 Mdot
.76347 .58966 Mdot
.76348 .58965 Mdot
.76349 .58965 Mdot
.7635 .58964 Mdot
.7635 .58964 Mdot
.76351 .58963 Mdot
.76352 .58963 Mdot
.76353 .58962 Mdot
.76354 .58962 Mdot
.76355 .58961 Mdot
.76356 .58961 Mdot
.76357 .5896 Mdot
.76358 .5896 Mdot
.76359 .58959 Mdot
.7636 .58959 Mdot
.76361 .58958 Mdot
.76362 .58958 Mdot
.76363 .58957 Mdot
.76364 .58956 Mdot
.76365 .58956 Mdot
.76366 .58955 Mdot
.76367 .58955 Mdot
.76368 .58954 Mdot
.76369 .58954 Mdot
.7637 .58953 Mdot
.7637 .58953 Mdot
.76371 .58952 Mdot
.76372 .58952 Mdot
.76373 .58951 Mdot
.76374 .58951 Mdot
.76375 .5895 Mdot
.76376 .5895 Mdot
.76377 .58949 Mdot
.76378 .58949 Mdot
.76379 .58948 Mdot
.7638 .58948 Mdot
.76381 .58947 Mdot
.76382 .58947 Mdot
.76383 .58946 Mdot
.76384 .58946 Mdot
.76385 .58945 Mdot
.76386 .58944 Mdot
.76387 .58944 Mdot
.76388 .58943 Mdot
.76389 .58943 Mdot
.7639 .58942 Mdot
.7639 .58942 Mdot
.76391 .58941 Mdot
.76392 .58941 Mdot
.76393 .5894 Mdot
.76394 .5894 Mdot
.76395 .58939 Mdot
.76396 .58939 Mdot
.76397 .58938 Mdot
.76398 .58938 Mdot
.76399 .58937 Mdot
.764 .58937 Mdot
.76401 .58936 Mdot
.76402 .58936 Mdot
.76403 .58935 Mdot
.76404 .58934 Mdot
.76405 .58934 Mdot
.76406 .58933 Mdot
.76407 .58933 Mdot
.76408 .58932 Mdot
.76409 .58932 Mdot
.7641 .58931 Mdot
.7641 .58931 Mdot
.76411 .5893 Mdot
.76412 .5893 Mdot
.76413 .58929 Mdot
.76414 .58929 Mdot
.76415 .58928 Mdot
.76416 .58928 Mdot
.76417 .58927 Mdot
.76418 .58927 Mdot
.76419 .58926 Mdot
.7642 .58926 Mdot
.76421 .58925 Mdot
.76422 .58924 Mdot
.76423 .58924 Mdot
.76424 .58923 Mdot
.76425 .58923 Mdot
.76426 .58922 Mdot
.76427 .58922 Mdot
.76428 .58921 Mdot
.76429 .58921 Mdot
.7643 .5892 Mdot
.7643 .5892 Mdot
.76431 .58919 Mdot
.76432 .58919 Mdot
.76433 .58918 Mdot
.76434 .58918 Mdot
.76435 .58917 Mdot
.76436 .58917 Mdot
.76437 .58916 Mdot
.76438 .58916 Mdot
.76439 .58915 Mdot
.7644 .58914 Mdot
.76441 .58914 Mdot
.76442 .58913 Mdot
.76443 .58913 Mdot
.76444 .58912 Mdot
.76445 .58912 Mdot
.76446 .58911 Mdot
.76447 .58911 Mdot
.76448 .5891 Mdot
.76449 .5891 Mdot
.7645 .58909 Mdot
.7645 .58909 Mdot
.76451 .58908 Mdot
.76452 .58908 Mdot
.76453 .58907 Mdot
.76454 .58907 Mdot
.76455 .58906 Mdot
.76456 .58905 Mdot
.76457 .58905 Mdot
.76458 .58904 Mdot
.76459 .58904 Mdot
.7646 .58903 Mdot
.76461 .58903 Mdot
.76462 .58902 Mdot
.76463 .58902 Mdot
.76464 .58901 Mdot
.76465 .58901 Mdot
.76466 .589 Mdot
.76467 .589 Mdot
.76468 .58899 Mdot
.76469 .58899 Mdot
.7647 .58898 Mdot
.7647 .58897 Mdot
.76471 .58897 Mdot
.76472 .58896 Mdot
.76473 .58896 Mdot
.76474 .58895 Mdot
.76475 .58895 Mdot
.76476 .58894 Mdot
.76477 .58894 Mdot
.76478 .58893 Mdot
.76479 .58893 Mdot
.7648 .58892 Mdot
.76481 .58892 Mdot
.76482 .58891 Mdot
.76483 .58891 Mdot
.76484 .5889 Mdot
.76485 .58889 Mdot
.76486 .58889 Mdot
.76487 .58888 Mdot
.76488 .58888 Mdot
.76489 .58887 Mdot
.7649 .58887 Mdot
.7649 .58886 Mdot
.76491 .58886 Mdot
.76492 .58885 Mdot
.76493 .58885 Mdot
.76494 .58884 Mdot
.76495 .58884 Mdot
.76496 .58883 Mdot
.76497 .58883 Mdot
.76498 .58882 Mdot
.76499 .58881 Mdot
.765 .58881 Mdot
.76501 .5888 Mdot
.76502 .5888 Mdot
.76503 .58879 Mdot
.76504 .58879 Mdot
.76505 .58878 Mdot
.76506 .58878 Mdot
.76507 .58877 Mdot
.76508 .58877 Mdot
.76509 .58876 Mdot
.7651 .58876 Mdot
.7651 .58875 Mdot
.76511 .58875 Mdot
.76512 .58874 Mdot
.76513 .58873 Mdot
.76514 .58873 Mdot
.76515 .58872 Mdot
.76516 .58872 Mdot
.76517 .58871 Mdot
.76518 .58871 Mdot
.76519 .5887 Mdot
.7652 .5887 Mdot
.76521 .58869 Mdot
.76522 .58869 Mdot
.76523 .58868 Mdot
.76524 .58868 Mdot
.76525 .58867 Mdot
.76526 .58866 Mdot
.76527 .58866 Mdot
.76528 .58865 Mdot
.76529 .58865 Mdot
.7653 .58864 Mdot
.7653 .58864 Mdot
.76531 .58863 Mdot
.76532 .58863 Mdot
.76533 .58862 Mdot
.76534 .58862 Mdot
.76535 .58861 Mdot
.76536 .58861 Mdot
.76537 .5886 Mdot
.76538 .58859 Mdot
.76539 .58859 Mdot
.7654 .58858 Mdot
.76541 .58858 Mdot
.76542 .58857 Mdot
.76543 .58857 Mdot
.76544 .58856 Mdot
.76545 .58856 Mdot
.76546 .58855 Mdot
.76547 .58855 Mdot
.76548 .58854 Mdot
.76549 .58854 Mdot
.7655 .58853 Mdot
.7655 .58852 Mdot
.76551 .58852 Mdot
.76552 .58851 Mdot
.76553 .58851 Mdot
.76554 .5885 Mdot
.76555 .5885 Mdot
.76556 .58849 Mdot
.76557 .58849 Mdot
.76558 .58848 Mdot
.76559 .58848 Mdot
.7656 .58847 Mdot
.76561 .58847 Mdot
.76562 .58846 Mdot
.76563 .58845 Mdot
.76564 .58845 Mdot
.76565 .58844 Mdot
.76566 .58844 Mdot
.76567 .58843 Mdot
.76568 .58843 Mdot
.76569 .58842 Mdot
.7657 .58842 Mdot
.7657 .58841 Mdot
.76571 .58841 Mdot
.76572 .5884 Mdot
.76573 .58839 Mdot
.76574 .58839 Mdot
.76575 .58838 Mdot
.76576 .58838 Mdot
.76577 .58837 Mdot
.76578 .58837 Mdot
.76579 .58836 Mdot
.7658 .58836 Mdot
.76581 .58835 Mdot
.76582 .58835 Mdot
.76583 .58834 Mdot
.76584 .58833 Mdot
.76585 .58833 Mdot
.76586 .58832 Mdot
.76587 .58832 Mdot
.76588 .58831 Mdot
.76589 .58831 Mdot
.7659 .5883 Mdot
.7659 .5883 Mdot
.76591 .58829 Mdot
.76592 .58829 Mdot
.76593 .58828 Mdot
.76594 .58828 Mdot
.76595 .58827 Mdot
.76596 .58826 Mdot
.76597 .58826 Mdot
.76598 .58825 Mdot
.76599 .58825 Mdot
.766 .58824 Mdot
.76601 .58824 Mdot
.76602 .58823 Mdot
.76603 .58823 Mdot
.76604 .58822 Mdot
.76605 .58822 Mdot
.76606 .58821 Mdot
.76607 .5882 Mdot
.76608 .5882 Mdot
.76609 .58819 Mdot
.7661 .58819 Mdot
.7661 .58818 Mdot
.76611 .58818 Mdot
.76612 .58817 Mdot
.76613 .58817 Mdot
.76614 .58816 Mdot
.76615 .58816 Mdot
.76616 .58815 Mdot
.76617 .58814 Mdot
.76618 .58814 Mdot
.76619 .58813 Mdot
.7662 .58813 Mdot
.76621 .58812 Mdot
.76622 .58812 Mdot
.76623 .58811 Mdot
.76624 .58811 Mdot
.76625 .5881 Mdot
.76626 .5881 Mdot
.76627 .58809 Mdot
.76628 .58808 Mdot
.76629 .58808 Mdot
.7663 .58807 Mdot
.7663 .58807 Mdot
.76631 .58806 Mdot
.76632 .58806 Mdot
.76633 .58805 Mdot
.76634 .58805 Mdot
.76635 .58804 Mdot
.76636 .58803 Mdot
.76637 .58803 Mdot
.76638 .58802 Mdot
.76639 .58802 Mdot
.7664 .58801 Mdot
.76641 .58801 Mdot
.76642 .588 Mdot
.76643 .588 Mdot
.76644 .58799 Mdot
.76645 .58799 Mdot
.76646 .58798 Mdot
.76647 .58797 Mdot
.76648 .58797 Mdot
.76649 .58796 Mdot
.7665 .58796 Mdot
.7665 .58795 Mdot
.76651 .58795 Mdot
.76652 .58794 Mdot
.76653 .58794 Mdot
.76654 .58793 Mdot
.76655 .58792 Mdot
.76656 .58792 Mdot
.76657 .58791 Mdot
.76658 .58791 Mdot
.76659 .5879 Mdot
.7666 .5879 Mdot
.76661 .58789 Mdot
.76662 .58789 Mdot
.76663 .58788 Mdot
.76664 .58788 Mdot
.76665 .58787 Mdot
.76666 .58786 Mdot
.76667 .58786 Mdot
.76668 .58785 Mdot
.76669 .58785 Mdot
.7667 .58784 Mdot
.7667 .58784 Mdot
.76671 .58783 Mdot
.76672 .58783 Mdot
.76673 .58782 Mdot
.76674 .58781 Mdot
.76675 .58781 Mdot
.76676 .5878 Mdot
.76677 .5878 Mdot
.76678 .58779 Mdot
.76679 .58779 Mdot
.7668 .58778 Mdot
.76681 .58778 Mdot
.76682 .58777 Mdot
.76683 .58777 Mdot
.76684 .58776 Mdot
.76685 .58775 Mdot
.76686 .58775 Mdot
.76687 .58774 Mdot
.76688 .58774 Mdot
.76689 .58773 Mdot
.7669 .58773 Mdot
.7669 .58772 Mdot
.76691 .58772 Mdot
.76692 .58771 Mdot
.76693 .5877 Mdot
.76694 .5877 Mdot
.76695 .58769 Mdot
.76696 .58769 Mdot
.76697 .58768 Mdot
.76698 .58768 Mdot
.76699 .58767 Mdot
.767 .58767 Mdot
.76701 .58766 Mdot
.76702 .58765 Mdot
.76703 .58765 Mdot
.76704 .58764 Mdot
.76705 .58764 Mdot
.76706 .58763 Mdot
.76707 .58763 Mdot
.76708 .58762 Mdot
.76709 .58762 Mdot
.7671 .58761 Mdot
.7671 .5876 Mdot
.76711 .5876 Mdot
.76712 .58759 Mdot
.76713 .58759 Mdot
.76714 .58758 Mdot
.76715 .58758 Mdot
.76716 .58757 Mdot
.76717 .58757 Mdot
.76718 .58756 Mdot
.76719 .58755 Mdot
.7672 .58755 Mdot
.76721 .58754 Mdot
.76722 .58754 Mdot
.76723 .58753 Mdot
.76724 .58753 Mdot
.76725 .58752 Mdot
.76726 .58752 Mdot
.76727 .58751 Mdot
.76728 .5875 Mdot
.76729 .5875 Mdot
.7673 .58749 Mdot
.7673 .58749 Mdot
.76731 .58748 Mdot
.76732 .58748 Mdot
.76733 .58747 Mdot
.76734 .58747 Mdot
.76735 .58746 Mdot
.76736 .58745 Mdot
.76737 .58745 Mdot
.76738 .58744 Mdot
.76739 .58744 Mdot
.7674 .58743 Mdot
.76741 .58743 Mdot
.76742 .58742 Mdot
.76743 .58741 Mdot
.76744 .58741 Mdot
.76745 .5874 Mdot
.76746 .5874 Mdot
.76747 .58739 Mdot
.76748 .58739 Mdot
.76749 .58738 Mdot
.7675 .58738 Mdot
.7675 .58737 Mdot
.76751 .58736 Mdot
.76752 .58736 Mdot
.76753 .58735 Mdot
.76754 .58735 Mdot
.76755 .58734 Mdot
.76756 .58734 Mdot
.76757 .58733 Mdot
.76758 .58733 Mdot
.76759 .58732 Mdot
.7676 .58731 Mdot
.76761 .58731 Mdot
.76762 .5873 Mdot
.76763 .5873 Mdot
.76764 .58729 Mdot
.76765 .58729 Mdot
.76766 .58728 Mdot
.76767 .58727 Mdot
.76768 .58727 Mdot
.76769 .58726 Mdot
.7677 .58726 Mdot
.7677 .58725 Mdot
.76771 .58725 Mdot
.76772 .58724 Mdot
.76773 .58724 Mdot
.76774 .58723 Mdot
.76775 .58722 Mdot
.76776 .58722 Mdot
.76777 .58721 Mdot
.76778 .58721 Mdot
.76779 .5872 Mdot
.7678 .5872 Mdot
.76781 .58719 Mdot
.76782 .58718 Mdot
.76783 .58718 Mdot
.76784 .58717 Mdot
.76785 .58717 Mdot
.76786 .58716 Mdot
.76787 .58716 Mdot
.76788 .58715 Mdot
.76789 .58715 Mdot
.7679 .58714 Mdot
.7679 .58713 Mdot
.76791 .58713 Mdot
.76792 .58712 Mdot
.76793 .58712 Mdot
.76794 .58711 Mdot
.76795 .58711 Mdot
.76796 .5871 Mdot
.76797 .58709 Mdot
.76798 .58709 Mdot
.76799 .58708 Mdot
.768 .58708 Mdot
.76801 .58707 Mdot
.76802 .58707 Mdot
.76803 .58706 Mdot
.76804 .58706 Mdot
.76805 .58705 Mdot
.76806 .58704 Mdot
.76807 .58704 Mdot
.76808 .58703 Mdot
.76809 .58703 Mdot
.7681 .58702 Mdot
.7681 .58702 Mdot
.76811 .58701 Mdot
.76812 .587 Mdot
.76813 .587 Mdot
.76814 .58699 Mdot
.76815 .58699 Mdot
.76816 .58698 Mdot
.76817 .58698 Mdot
.76818 .58697 Mdot
.76819 .58696 Mdot
.7682 .58696 Mdot
.76821 .58695 Mdot
.76822 .58695 Mdot
.76823 .58694 Mdot
.76824 .58694 Mdot
.76825 .58693 Mdot
.76826 .58693 Mdot
.76827 .58692 Mdot
.76828 .58691 Mdot
.76829 .58691 Mdot
.7683 .5869 Mdot
.7683 .5869 Mdot
.76831 .58689 Mdot
.76832 .58689 Mdot
.76833 .58688 Mdot
.76834 .58687 Mdot
.76835 .58687 Mdot
.76836 .58686 Mdot
.76837 .58686 Mdot
.76838 .58685 Mdot
.76839 .58685 Mdot
.7684 .58684 Mdot
.76841 .58683 Mdot
.76842 .58683 Mdot
.76843 .58682 Mdot
.76844 .58682 Mdot
.76845 .58681 Mdot
.76846 .58681 Mdot
.76847 .5868 Mdot
.76848 .58679 Mdot
.76849 .58679 Mdot
.7685 .58678 Mdot
.7685 .58678 Mdot
.76851 .58677 Mdot
.76852 .58677 Mdot
.76853 .58676 Mdot
.76854 .58675 Mdot
.76855 .58675 Mdot
.76856 .58674 Mdot
.76857 .58674 Mdot
.76858 .58673 Mdot
.76859 .58673 Mdot
.7686 .58672 Mdot
.76861 .58671 Mdot
.76862 .58671 Mdot
.76863 .5867 Mdot
.76864 .5867 Mdot
.76865 .58669 Mdot
.76866 .58669 Mdot
.76867 .58668 Mdot
.76868 .58667 Mdot
.76869 .58667 Mdot
.7687 .58666 Mdot
.7687 .58666 Mdot
.76871 .58665 Mdot
.76872 .58665 Mdot
.76873 .58664 Mdot
.76874 .58663 Mdot
.76875 .58663 Mdot
.76876 .58662 Mdot
.76877 .58662 Mdot
.76878 .58661 Mdot
.76879 .58661 Mdot
.7688 .5866 Mdot
.76881 .58659 Mdot
.76882 .58659 Mdot
.76883 .58658 Mdot
.76884 .58658 Mdot
.76885 .58657 Mdot
.76886 .58657 Mdot
.76887 .58656 Mdot
.76888 .58655 Mdot
.76889 .58655 Mdot
.7689 .58654 Mdot
.7689 .58654 Mdot
.76891 .58653 Mdot
.76892 .58653 Mdot
.76893 .58652 Mdot
.76894 .58651 Mdot
.76895 .58651 Mdot
.76896 .5865 Mdot
.76897 .5865 Mdot
.76898 .58649 Mdot
.76899 .58649 Mdot
.769 .58648 Mdot
.76901 .58647 Mdot
.76902 .58647 Mdot
.76903 .58646 Mdot
.76904 .58646 Mdot
.76905 .58645 Mdot
.76906 .58645 Mdot
.76907 .58644 Mdot
.76908 .58643 Mdot
.76909 .58643 Mdot
.7691 .58642 Mdot
.7691 .58642 Mdot
.76911 .58641 Mdot
.76912 .58641 Mdot
.76913 .5864 Mdot
.76914 .58639 Mdot
.76915 .58639 Mdot
.76916 .58638 Mdot
.76917 .58638 Mdot
.76918 .58637 Mdot
.76919 .58637 Mdot
.7692 .58636 Mdot
.76921 .58635 Mdot
.76922 .58635 Mdot
.76923 .58634 Mdot
.76924 .58634 Mdot
.76925 .58633 Mdot
.76926 .58632 Mdot
.76927 .58632 Mdot
.76928 .58631 Mdot
.76929 .58631 Mdot
.7693 .5863 Mdot
.7693 .5863 Mdot
.76931 .58629 Mdot
.76932 .58628 Mdot
.76933 .58628 Mdot
.76934 .58627 Mdot
.76935 .58627 Mdot
.76936 .58626 Mdot
.76937 .58626 Mdot
.76938 .58625 Mdot
.76939 .58624 Mdot
.7694 .58624 Mdot
.76941 .58623 Mdot
.76942 .58623 Mdot
.76943 .58622 Mdot
.76944 .58622 Mdot
.76945 .58621 Mdot
.76946 .5862 Mdot
.76947 .5862 Mdot
.76948 .58619 Mdot
.76949 .58619 Mdot
.7695 .58618 Mdot
.7695 .58617 Mdot
.76951 .58617 Mdot
.76952 .58616 Mdot
.76953 .58616 Mdot
.76954 .58615 Mdot
.76955 .58615 Mdot
.76956 .58614 Mdot
.76957 .58613 Mdot
.76958 .58613 Mdot
.76959 .58612 Mdot
.7696 .58612 Mdot
.76961 .58611 Mdot
.76962 .58611 Mdot
.76963 .5861 Mdot
.76964 .58609 Mdot
.76965 .58609 Mdot
.76966 .58608 Mdot
.76967 .58608 Mdot
.76968 .58607 Mdot
.76969 .58606 Mdot
.7697 .58606 Mdot
.7697 .58605 Mdot
.76971 .58605 Mdot
.76972 .58604 Mdot
.76973 .58604 Mdot
.76974 .58603 Mdot
.76975 .58602 Mdot
.76976 .58602 Mdot
.76977 .58601 Mdot
.76978 .58601 Mdot
.76979 .586 Mdot
.7698 .58599 Mdot
.76981 .58599 Mdot
.76982 .58598 Mdot
.76983 .58598 Mdot
.76984 .58597 Mdot
.76985 .58597 Mdot
.76986 .58596 Mdot
.76987 .58595 Mdot
.76988 .58595 Mdot
.76989 .58594 Mdot
.7699 .58594 Mdot
.7699 .58593 Mdot
.76991 .58593 Mdot
.76992 .58592 Mdot
.76993 .58591 Mdot
.76994 .58591 Mdot
.76995 .5859 Mdot
.76996 .5859 Mdot
.76997 .58589 Mdot
.76998 .58588 Mdot
.76999 .58588 Mdot
.77 .58587 Mdot
.77001 .58587 Mdot
.77002 .58586 Mdot
.77003 .58586 Mdot
.77004 .58585 Mdot
.77005 .58584 Mdot
.77006 .58584 Mdot
.77007 .58583 Mdot
.77008 .58583 Mdot
.77009 .58582 Mdot
.7701 .58581 Mdot
.7701 .58581 Mdot
.77011 .5858 Mdot
.77012 .5858 Mdot
.77013 .58579 Mdot
.77014 .58578 Mdot
.77015 .58578 Mdot
.77016 .58577 Mdot
.77017 .58577 Mdot
.77018 .58576 Mdot
.77019 .58576 Mdot
.7702 .58575 Mdot
.77021 .58574 Mdot
.77022 .58574 Mdot
.77023 .58573 Mdot
.77024 .58573 Mdot
.77025 .58572 Mdot
.77026 .58571 Mdot
.77027 .58571 Mdot
.77028 .5857 Mdot
.77029 .5857 Mdot
.7703 .58569 Mdot
.7703 .58569 Mdot
.77031 .58568 Mdot
.77032 .58567 Mdot
.77033 .58567 Mdot
.77034 .58566 Mdot
.77035 .58566 Mdot
.77036 .58565 Mdot
.77037 .58564 Mdot
.77038 .58564 Mdot
.77039 .58563 Mdot
.7704 .58563 Mdot
.77041 .58562 Mdot
.77042 .58561 Mdot
.77043 .58561 Mdot
.77044 .5856 Mdot
.77045 .5856 Mdot
.77046 .58559 Mdot
.77047 .58559 Mdot
.77048 .58558 Mdot
.77049 .58557 Mdot
.7705 .58557 Mdot
.7705 .58556 Mdot
.77051 .58556 Mdot
.77052 .58555 Mdot
.77053 .58554 Mdot
.77054 .58554 Mdot
.77055 .58553 Mdot
.77056 .58553 Mdot
.77057 .58552 Mdot
.77058 .58551 Mdot
.77059 .58551 Mdot
.7706 .5855 Mdot
.77061 .5855 Mdot
.77062 .58549 Mdot
.77063 .58549 Mdot
.77064 .58548 Mdot
.77065 .58547 Mdot
.77066 .58547 Mdot
.77067 .58546 Mdot
.77068 .58546 Mdot
.77069 .58545 Mdot
.7707 .58544 Mdot
.7707 .58544 Mdot
.77071 .58543 Mdot
.77072 .58543 Mdot
.77073 .58542 Mdot
.77074 .58541 Mdot
.77075 .58541 Mdot
.77076 .5854 Mdot
.77077 .5854 Mdot
.77078 .58539 Mdot
.77079 .58538 Mdot
.7708 .58538 Mdot
.77081 .58537 Mdot
.77082 .58537 Mdot
.77083 .58536 Mdot
.77084 .58536 Mdot
.77085 .58535 Mdot
.77086 .58534 Mdot
.77087 .58534 Mdot
.77088 .58533 Mdot
.77089 .58533 Mdot
.7709 .58532 Mdot
.7709 .58531 Mdot
.77091 .58531 Mdot
.77092 .5853 Mdot
.77093 .5853 Mdot
.77094 .58529 Mdot
.77095 .58528 Mdot
.77096 .58528 Mdot
.77097 .58527 Mdot
.77098 .58527 Mdot
.77099 .58526 Mdot
.771 .58525 Mdot
.77101 .58525 Mdot
.77102 .58524 Mdot
.77103 .58524 Mdot
.77104 .58523 Mdot
.77105 .58522 Mdot
.77106 .58522 Mdot
.77107 .58521 Mdot
.77108 .58521 Mdot
.77109 .5852 Mdot
.7711 .5852 Mdot
.7711 .58519 Mdot
.77111 .58518 Mdot
.77112 .58518 Mdot
.77113 .58517 Mdot
.77114 .58517 Mdot
.77115 .58516 Mdot
.77116 .58515 Mdot
.77117 .58515 Mdot
.77118 .58514 Mdot
.77119 .58514 Mdot
.7712 .58513 Mdot
.77121 .58512 Mdot
.77122 .58512 Mdot
.77123 .58511 Mdot
.77124 .58511 Mdot
.77125 .5851 Mdot
.77126 .58509 Mdot
.77127 .58509 Mdot
.77128 .58508 Mdot
.77129 .58508 Mdot
.7713 .58507 Mdot
.7713 .58506 Mdot
.77131 .58506 Mdot
.77132 .58505 Mdot
.77133 .58505 Mdot
.77134 .58504 Mdot
.77135 .58503 Mdot
.77136 .58503 Mdot
.77137 .58502 Mdot
.77138 .58502 Mdot
.77139 .58501 Mdot
.7714 .585 Mdot
.77141 .585 Mdot
.77142 .58499 Mdot
.77143 .58499 Mdot
.77144 .58498 Mdot
.77145 .58497 Mdot
.77146 .58497 Mdot
.77147 .58496 Mdot
.77148 .58496 Mdot
.77149 .58495 Mdot
.7715 .58494 Mdot
.7715 .58494 Mdot
.77151 .58493 Mdot
.77152 .58493 Mdot
.77153 .58492 Mdot
.77154 .58491 Mdot
.77155 .58491 Mdot
.77156 .5849 Mdot
.77157 .5849 Mdot
.77158 .58489 Mdot
.77159 .58488 Mdot
.7716 .58488 Mdot
.77161 .58487 Mdot
.77162 .58487 Mdot
.77163 .58486 Mdot
.77164 .58485 Mdot
.77165 .58485 Mdot
.77166 .58484 Mdot
.77167 .58484 Mdot
.77168 .58483 Mdot
.77169 .58483 Mdot
.7717 .58482 Mdot
.7717 .58481 Mdot
.77171 .58481 Mdot
.77172 .5848 Mdot
.77173 .58479 Mdot
.77174 .58479 Mdot
.77175 .58478 Mdot
.77176 .58478 Mdot
.77177 .58477 Mdot
.77178 .58476 Mdot
.77179 .58476 Mdot
.7718 .58475 Mdot
.77181 .58475 Mdot
.77182 .58474 Mdot
.77183 .58473 Mdot
.77184 .58473 Mdot
.77185 .58472 Mdot
.77186 .58472 Mdot
.77187 .58471 Mdot
.77188 .5847 Mdot
.77189 .5847 Mdot
.7719 .58469 Mdot
.7719 .58469 Mdot
.77191 .58468 Mdot
.77192 .58467 Mdot
.77193 .58467 Mdot
.77194 .58466 Mdot
.77195 .58466 Mdot
.77196 .58465 Mdot
.77197 .58464 Mdot
.77198 .58464 Mdot
.77199 .58463 Mdot
.772 .58463 Mdot
.77201 .58462 Mdot
.77202 .58461 Mdot
.77203 .58461 Mdot
.77204 .5846 Mdot
.77205 .5846 Mdot
.77206 .58459 Mdot
.77207 .58458 Mdot
.77208 .58458 Mdot
.77209 .58457 Mdot
.7721 .58457 Mdot
.7721 .58456 Mdot
.77211 .58455 Mdot
.77212 .58455 Mdot
.77213 .58454 Mdot
.77214 .58454 Mdot
.77215 .58453 Mdot
.77216 .58452 Mdot
.77217 .58452 Mdot
.77218 .58451 Mdot
.77219 .58451 Mdot
.7722 .5845 Mdot
.77221 .58449 Mdot
.77222 .58449 Mdot
.77223 .58448 Mdot
.77224 .58448 Mdot
.77225 .58447 Mdot
.77226 .58446 Mdot
.77227 .58446 Mdot
.77228 .58445 Mdot
.77229 .58445 Mdot
.7723 .58444 Mdot
.7723 .58443 Mdot
.77231 .58443 Mdot
.77232 .58442 Mdot
.77233 .58441 Mdot
.77234 .58441 Mdot
.77235 .5844 Mdot
.77236 .5844 Mdot
.77237 .58439 Mdot
.77238 .58438 Mdot
.77239 .58438 Mdot
.7724 .58437 Mdot
.77241 .58437 Mdot
.77242 .58436 Mdot
.77243 .58435 Mdot
.77244 .58435 Mdot
.77245 .58434 Mdot
.77246 .58434 Mdot
.77247 .58433 Mdot
.77248 .58432 Mdot
.77249 .58432 Mdot
.7725 .58431 Mdot
.7725 .58431 Mdot
.77251 .5843 Mdot
.77252 .58429 Mdot
.77253 .58429 Mdot
.77254 .58428 Mdot
.77255 .58428 Mdot
.77256 .58427 Mdot
.77257 .58426 Mdot
.77258 .58426 Mdot
.77259 .58425 Mdot
.7726 .58424 Mdot
.77261 .58424 Mdot
.77262 .58423 Mdot
.77263 .58423 Mdot
.77264 .58422 Mdot
.77265 .58421 Mdot
.77266 .58421 Mdot
.77267 .5842 Mdot
.77268 .5842 Mdot
.77269 .58419 Mdot
.7727 .58418 Mdot
.7727 .58418 Mdot
.77271 .58417 Mdot
.77272 .58417 Mdot
.77273 .58416 Mdot
.77274 .58415 Mdot
.77275 .58415 Mdot
.77276 .58414 Mdot
.77277 .58414 Mdot
.77278 .58413 Mdot
.77279 .58412 Mdot
.7728 .58412 Mdot
.77281 .58411 Mdot
.77282 .5841 Mdot
.77283 .5841 Mdot
.77284 .58409 Mdot
.77285 .58409 Mdot
.77286 .58408 Mdot
.77287 .58407 Mdot
.77288 .58407 Mdot
.77289 .58406 Mdot
.7729 .58406 Mdot
.7729 .58405 Mdot
.77291 .58404 Mdot
.77292 .58404 Mdot
.77293 .58403 Mdot
.77294 .58403 Mdot
.77295 .58402 Mdot
.77296 .58401 Mdot
.77297 .58401 Mdot
.77298 .584 Mdot
.77299 .58399 Mdot
.773 .58399 Mdot
.77301 .58398 Mdot
.77302 .58398 Mdot
.77303 .58397 Mdot
.77304 .58396 Mdot
.77305 .58396 Mdot
.77306 .58395 Mdot
.77307 .58395 Mdot
.77308 .58394 Mdot
.77309 .58393 Mdot
.7731 .58393 Mdot
.7731 .58392 Mdot
.77311 .58391 Mdot
.77312 .58391 Mdot
.77313 .5839 Mdot
.77314 .5839 Mdot
.77315 .58389 Mdot
.77316 .58388 Mdot
.77317 .58388 Mdot
.77318 .58387 Mdot
.77319 .58387 Mdot
.7732 .58386 Mdot
.77321 .58385 Mdot
.77322 .58385 Mdot
.77323 .58384 Mdot
.77324 .58384 Mdot
.77325 .58383 Mdot
.77326 .58382 Mdot
.77327 .58382 Mdot
.77328 .58381 Mdot
.77329 .5838 Mdot
.7733 .5838 Mdot
.7733 .58379 Mdot
.77331 .58379 Mdot
.77332 .58378 Mdot
.77333 .58377 Mdot
.77334 .58377 Mdot
.77335 .58376 Mdot
.77336 .58376 Mdot
.77337 .58375 Mdot
.77338 .58374 Mdot
.77339 .58374 Mdot
.7734 .58373 Mdot
.77341 .58372 Mdot
.77342 .58372 Mdot
.77343 .58371 Mdot
.77344 .58371 Mdot
.77345 .5837 Mdot
.77346 .58369 Mdot
.77347 .58369 Mdot
.77348 .58368 Mdot
.77349 .58367 Mdot
.7735 .58367 Mdot
.7735 .58366 Mdot
.77351 .58366 Mdot
.77352 .58365 Mdot
.77353 .58364 Mdot
.77354 .58364 Mdot
.77355 .58363 Mdot
.77356 .58363 Mdot
.77357 .58362 Mdot
.77358 .58361 Mdot
.77359 .58361 Mdot
.7736 .5836 Mdot
.77361 .58359 Mdot
.77362 .58359 Mdot
.77363 .58358 Mdot
.77364 .58358 Mdot
.77365 .58357 Mdot
.77366 .58356 Mdot
.77367 .58356 Mdot
.77368 .58355 Mdot
.77369 .58355 Mdot
.7737 .58354 Mdot
.7737 .58353 Mdot
.77371 .58353 Mdot
.77372 .58352 Mdot
.77373 .58351 Mdot
.77374 .58351 Mdot
.77375 .5835 Mdot
.77376 .5835 Mdot
.77377 .58349 Mdot
.77378 .58348 Mdot
.77379 .58348 Mdot
.7738 .58347 Mdot
.77381 .58346 Mdot
.77382 .58346 Mdot
.77383 .58345 Mdot
.77384 .58345 Mdot
.77385 .58344 Mdot
.77386 .58343 Mdot
.77387 .58343 Mdot
.77388 .58342 Mdot
.77389 .58341 Mdot
.7739 .58341 Mdot
.7739 .5834 Mdot
.77391 .5834 Mdot
.77392 .58339 Mdot
.77393 .58338 Mdot
.77394 .58338 Mdot
.77395 .58337 Mdot
.77396 .58337 Mdot
.77397 .58336 Mdot
.77398 .58335 Mdot
.77399 .58335 Mdot
.774 .58334 Mdot
.77401 .58333 Mdot
.77402 .58333 Mdot
.77403 .58332 Mdot
.77404 .58332 Mdot
.77405 .58331 Mdot
.77406 .5833 Mdot
.77407 .5833 Mdot
.77408 .58329 Mdot
.77409 .58328 Mdot
.7741 .58328 Mdot
.7741 .58327 Mdot
.77411 .58327 Mdot
.77412 .58326 Mdot
.77413 .58325 Mdot
.77414 .58325 Mdot
.77415 .58324 Mdot
.77416 .58323 Mdot
.77417 .58323 Mdot
.77418 .58322 Mdot
.77419 .58322 Mdot
.7742 .58321 Mdot
.77421 .5832 Mdot
.77422 .5832 Mdot
.77423 .58319 Mdot
.77424 .58318 Mdot
.77425 .58318 Mdot
.77426 .58317 Mdot
.77427 .58317 Mdot
.77428 .58316 Mdot
.77429 .58315 Mdot
.7743 .58315 Mdot
.7743 .58314 Mdot
.77431 .58313 Mdot
.77432 .58313 Mdot
.77433 .58312 Mdot
.77434 .58312 Mdot
.77435 .58311 Mdot
.77436 .5831 Mdot
.77437 .5831 Mdot
.77438 .58309 Mdot
.77439 .58308 Mdot
.7744 .58308 Mdot
.77441 .58307 Mdot
.77442 .58307 Mdot
.77443 .58306 Mdot
.77444 .58305 Mdot
.77445 .58305 Mdot
.77446 .58304 Mdot
.77447 .58303 Mdot
.77448 .58303 Mdot
.77449 .58302 Mdot
.7745 .58302 Mdot
.7745 .58301 Mdot
.77451 .583 Mdot
.77452 .583 Mdot
.77453 .58299 Mdot
.77454 .58298 Mdot
.77455 .58298 Mdot
.77456 .58297 Mdot
.77457 .58297 Mdot
.77458 .58296 Mdot
.77459 .58295 Mdot
.7746 .58295 Mdot
.77461 .58294 Mdot
.77462 .58293 Mdot
.77463 .58293 Mdot
.77464 .58292 Mdot
.77465 .58292 Mdot
.77466 .58291 Mdot
.77467 .5829 Mdot
.77468 .5829 Mdot
.77469 .58289 Mdot
.7747 .58288 Mdot
.7747 .58288 Mdot
.77471 .58287 Mdot
.77472 .58286 Mdot
.77473 .58286 Mdot
.77474 .58285 Mdot
.77475 .58285 Mdot
.77476 .58284 Mdot
.77477 .58283 Mdot
.77478 .58283 Mdot
.77479 .58282 Mdot
.7748 .58281 Mdot
.77481 .58281 Mdot
.77482 .5828 Mdot
.77483 .5828 Mdot
.77484 .58279 Mdot
.77485 .58278 Mdot
.77486 .58278 Mdot
.77487 .58277 Mdot
.77488 .58276 Mdot
.77489 .58276 Mdot
.7749 .58275 Mdot
.7749 .58275 Mdot
.77491 .58274 Mdot
.77492 .58273 Mdot
.77493 .58273 Mdot
.77494 .58272 Mdot
.77495 .58271 Mdot
.77496 .58271 Mdot
.77497 .5827 Mdot
.77498 .58269 Mdot
.77499 .58269 Mdot
.775 .58268 Mdot
.77501 .58268 Mdot
.77502 .58267 Mdot
.77503 .58266 Mdot
.77504 .58266 Mdot
.77505 .58265 Mdot
.77506 .58264 Mdot
.77507 .58264 Mdot
.77508 .58263 Mdot
.77509 .58263 Mdot
.7751 .58262 Mdot
.7751 .58261 Mdot
.77511 .58261 Mdot
.77512 .5826 Mdot
.77513 .58259 Mdot
.77514 .58259 Mdot
.77515 .58258 Mdot
.77516 .58257 Mdot
.77517 .58257 Mdot
.77518 .58256 Mdot
.77519 .58256 Mdot
.7752 .58255 Mdot
.77521 .58254 Mdot
.77522 .58254 Mdot
.77523 .58253 Mdot
.77524 .58252 Mdot
.77525 .58252 Mdot
.77526 .58251 Mdot
.77527 .5825 Mdot
.77528 .5825 Mdot
.77529 .58249 Mdot
.7753 .58249 Mdot
.7753 .58248 Mdot
.77531 .58247 Mdot
.77532 .58247 Mdot
.77533 .58246 Mdot
.77534 .58245 Mdot
.77535 .58245 Mdot
.77536 .58244 Mdot
.77537 .58244 Mdot
.77538 .58243 Mdot
.77539 .58242 Mdot
.7754 .58242 Mdot
.77541 .58241 Mdot
.77542 .5824 Mdot
.77543 .5824 Mdot
.77544 .58239 Mdot
.77545 .58238 Mdot
.77546 .58238 Mdot
.77547 .58237 Mdot
.77548 .58237 Mdot
.77549 .58236 Mdot
.7755 .58235 Mdot
.7755 .58235 Mdot
.77551 .58234 Mdot
.77552 .58233 Mdot
.77553 .58233 Mdot
.77554 .58232 Mdot
.77555 .58231 Mdot
.77556 .58231 Mdot
.77557 .5823 Mdot
.77558 .5823 Mdot
.77559 .58229 Mdot
.7756 .58228 Mdot
.77561 .58228 Mdot
.77562 .58227 Mdot
.77563 .58226 Mdot
.77564 .58226 Mdot
.77565 .58225 Mdot
.77566 .58224 Mdot
.77567 .58224 Mdot
.77568 .58223 Mdot
.77569 .58223 Mdot
.7757 .58222 Mdot
.7757 .58221 Mdot
.77571 .58221 Mdot
.77572 .5822 Mdot
.77573 .58219 Mdot
.77574 .58219 Mdot
.77575 .58218 Mdot
.77576 .58217 Mdot
.77577 .58217 Mdot
.77578 .58216 Mdot
.77579 .58215 Mdot
.7758 .58215 Mdot
.77581 .58214 Mdot
.77582 .58214 Mdot
.77583 .58213 Mdot
.77584 .58212 Mdot
.77585 .58212 Mdot
.77586 .58211 Mdot
.77587 .5821 Mdot
.77588 .5821 Mdot
.77589 .58209 Mdot
.7759 .58208 Mdot
.7759 .58208 Mdot
.77591 .58207 Mdot
.77592 .58207 Mdot
.77593 .58206 Mdot
.77594 .58205 Mdot
.77595 .58205 Mdot
.77596 .58204 Mdot
.77597 .58203 Mdot
.77598 .58203 Mdot
.77599 .58202 Mdot
.776 .58201 Mdot
.77601 .58201 Mdot
.77602 .582 Mdot
.77603 .58199 Mdot
.77604 .58199 Mdot
.77605 .58198 Mdot
.77606 .58198 Mdot
.77607 .58197 Mdot
.77608 .58196 Mdot
.77609 .58196 Mdot
.7761 .58195 Mdot
.7761 .58194 Mdot
.77611 .58194 Mdot
.77612 .58193 Mdot
.77613 .58192 Mdot
.77614 .58192 Mdot
.77615 .58191 Mdot
.77616 .5819 Mdot
.77617 .5819 Mdot
.77618 .58189 Mdot
.77619 .58189 Mdot
.7762 .58188 Mdot
.77621 .58187 Mdot
.77622 .58187 Mdot
.77623 .58186 Mdot
.77624 .58185 Mdot
.77625 .58185 Mdot
.77626 .58184 Mdot
.77627 .58183 Mdot
.77628 .58183 Mdot
.77629 .58182 Mdot
.7763 .58181 Mdot
.7763 .58181 Mdot
.77631 .5818 Mdot
.77632 .5818 Mdot
.77633 .58179 Mdot
.77634 .58178 Mdot
.77635 .58178 Mdot
.77636 .58177 Mdot
.77637 .58176 Mdot
.77638 .58176 Mdot
.77639 .58175 Mdot
.7764 .58174 Mdot
.77641 .58174 Mdot
.77642 .58173 Mdot
.77643 .58172 Mdot
.77644 .58172 Mdot
.77645 .58171 Mdot
.77646 .58171 Mdot
.77647 .5817 Mdot
.77648 .58169 Mdot
.77649 .58169 Mdot
.7765 .58168 Mdot
.7765 .58167 Mdot
.77651 .58167 Mdot
.77652 .58166 Mdot
.77653 .58165 Mdot
.77654 .58165 Mdot
.77655 .58164 Mdot
.77656 .58163 Mdot
.77657 .58163 Mdot
.77658 .58162 Mdot
.77659 .58161 Mdot
.7766 .58161 Mdot
.77661 .5816 Mdot
.77662 .5816 Mdot
.77663 .58159 Mdot
.77664 .58158 Mdot
.77665 .58158 Mdot
.77666 .58157 Mdot
.77667 .58156 Mdot
.77668 .58156 Mdot
.77669 .58155 Mdot
.7767 .58154 Mdot
.7767 .58154 Mdot
.77671 .58153 Mdot
.77672 .58152 Mdot
.77673 .58152 Mdot
.77674 .58151 Mdot
.77675 .5815 Mdot
.77676 .5815 Mdot
.77677 .58149 Mdot
.77678 .58149 Mdot
.77679 .58148 Mdot
.7768 .58147 Mdot
.77681 .58147 Mdot
.77682 .58146 Mdot
.77683 .58145 Mdot
.77684 .58145 Mdot
.77685 .58144 Mdot
.77686 .58143 Mdot
.77687 .58143 Mdot
.77688 .58142 Mdot
.77689 .58141 Mdot
.7769 .58141 Mdot
.7769 .5814 Mdot
.77691 .58139 Mdot
.77692 .58139 Mdot
.77693 .58138 Mdot
.77694 .58138 Mdot
.77695 .58137 Mdot
.77696 .58136 Mdot
.77697 .58136 Mdot
.77698 .58135 Mdot
.77699 .58134 Mdot
.777 .58134 Mdot
.77701 .58133 Mdot
.77702 .58132 Mdot
.77703 .58132 Mdot
.77704 .58131 Mdot
.77705 .5813 Mdot
.77706 .5813 Mdot
.77707 .58129 Mdot
.77708 .58128 Mdot
.77709 .58128 Mdot
.7771 .58127 Mdot
.7771 .58126 Mdot
.77711 .58126 Mdot
.77712 .58125 Mdot
.77713 .58124 Mdot
.77714 .58124 Mdot
.77715 .58123 Mdot
.77716 .58123 Mdot
.77717 .58122 Mdot
.77718 .58121 Mdot
.77719 .58121 Mdot
.7772 .5812 Mdot
.77721 .58119 Mdot
.77722 .58119 Mdot
.77723 .58118 Mdot
.77724 .58117 Mdot
.77725 .58117 Mdot
.77726 .58116 Mdot
.77727 .58115 Mdot
.77728 .58115 Mdot
.77729 .58114 Mdot
.7773 .58113 Mdot
.7773 .58113 Mdot
.77731 .58112 Mdot
.77732 .58111 Mdot
.77733 .58111 Mdot
.77734 .5811 Mdot
.77735 .58109 Mdot
.77736 .58109 Mdot
.77737 .58108 Mdot
.77738 .58108 Mdot
.77739 .58107 Mdot
.7774 .58106 Mdot
.77741 .58106 Mdot
.77742 .58105 Mdot
.77743 .58104 Mdot
.77744 .58104 Mdot
.77745 .58103 Mdot
.77746 .58102 Mdot
.77747 .58102 Mdot
.77748 .58101 Mdot
.77749 .581 Mdot
.7775 .581 Mdot
.7775 .58099 Mdot
.77751 .58098 Mdot
.77752 .58098 Mdot
.77753 .58097 Mdot
.77754 .58096 Mdot
.77755 .58096 Mdot
.77756 .58095 Mdot
.77757 .58094 Mdot
.77758 .58094 Mdot
.77759 .58093 Mdot
.7776 .58092 Mdot
.77761 .58092 Mdot
.77762 .58091 Mdot
.77763 .5809 Mdot
.77764 .5809 Mdot
.77765 .58089 Mdot
.77766 .58089 Mdot
.77767 .58088 Mdot
.77768 .58087 Mdot
.77769 .58087 Mdot
.7777 .58086 Mdot
.7777 .58085 Mdot
.77771 .58085 Mdot
.77772 .58084 Mdot
.77773 .58083 Mdot
.77774 .58083 Mdot
.77775 .58082 Mdot
.77776 .58081 Mdot
.77777 .58081 Mdot
.77778 .5808 Mdot
.77779 .58079 Mdot
.7778 .58079 Mdot
.77781 .58078 Mdot
.77782 .58077 Mdot
.77783 .58077 Mdot
.77784 .58076 Mdot
.77785 .58075 Mdot
.77786 .58075 Mdot
.77787 .58074 Mdot
.77788 .58073 Mdot
.77789 .58073 Mdot
.7779 .58072 Mdot
.7779 .58071 Mdot
.77791 .58071 Mdot
.77792 .5807 Mdot
.77793 .58069 Mdot
.77794 .58069 Mdot
.77795 .58068 Mdot
.77796 .58067 Mdot
.77797 .58067 Mdot
.77798 .58066 Mdot
.77799 .58065 Mdot
.778 .58065 Mdot
.77801 .58064 Mdot
.77802 .58063 Mdot
.77803 .58063 Mdot
.77804 .58062 Mdot
.77805 .58062 Mdot
.77806 .58061 Mdot
.77807 .5806 Mdot
.77808 .5806 Mdot
.77809 .58059 Mdot
.7781 .58058 Mdot
.7781 .58058 Mdot
.77811 .58057 Mdot
.77812 .58056 Mdot
.77813 .58056 Mdot
.77814 .58055 Mdot
.77815 .58054 Mdot
.77816 .58054 Mdot
.77817 .58053 Mdot
.77818 .58052 Mdot
.77819 .58052 Mdot
.7782 .58051 Mdot
.77821 .5805 Mdot
.77822 .5805 Mdot
.77823 .58049 Mdot
.77824 .58048 Mdot
.77825 .58048 Mdot
.77826 .58047 Mdot
.77827 .58046 Mdot
.77828 .58046 Mdot
.77829 .58045 Mdot
.7783 .58044 Mdot
.7783 .58044 Mdot
.77831 .58043 Mdot
.77832 .58042 Mdot
.77833 .58042 Mdot
.77834 .58041 Mdot
.77835 .5804 Mdot
.77836 .5804 Mdot
.77837 .58039 Mdot
.77838 .58038 Mdot
.77839 .58038 Mdot
.7784 .58037 Mdot
.77841 .58036 Mdot
.77842 .58036 Mdot
.77843 .58035 Mdot
.77844 .58034 Mdot
.77845 .58034 Mdot
.77846 .58033 Mdot
.77847 .58032 Mdot
.77848 .58032 Mdot
.77849 .58031 Mdot
.7785 .5803 Mdot
.7785 .5803 Mdot
.77851 .58029 Mdot
.77852 .58028 Mdot
.77853 .58028 Mdot
.77854 .58027 Mdot
.77855 .58026 Mdot
.77856 .58026 Mdot
.77857 .58025 Mdot
.77858 .58024 Mdot
.77859 .58024 Mdot
.7786 .58023 Mdot
.77861 .58022 Mdot
.77862 .58022 Mdot
.77863 .58021 Mdot
.77864 .5802 Mdot
.77865 .5802 Mdot
.77866 .58019 Mdot
.77867 .58018 Mdot
.77868 .58018 Mdot
.77869 .58017 Mdot
.7787 .58016 Mdot
.7787 .58016 Mdot
.77871 .58015 Mdot
.77872 .58014 Mdot
.77873 .58014 Mdot
.77874 .58013 Mdot
.77875 .58012 Mdot
.77876 .58012 Mdot
.77877 .58011 Mdot
.77878 .5801 Mdot
.77879 .5801 Mdot
.7788 .58009 Mdot
.77881 .58008 Mdot
.77882 .58008 Mdot
.77883 .58007 Mdot
.77884 .58006 Mdot
.77885 .58006 Mdot
.77886 .58005 Mdot
.77887 .58004 Mdot
.77888 .58004 Mdot
.77889 .58003 Mdot
.7789 .58002 Mdot
.7789 .58002 Mdot
.77891 .58001 Mdot
.77892 .58 Mdot
.77893 .58 Mdot
.77894 .57999 Mdot
.77895 .57998 Mdot
.77896 .57998 Mdot
.77897 .57997 Mdot
.77898 .57996 Mdot
.77899 .57996 Mdot
.779 .57995 Mdot
.77901 .57994 Mdot
.77902 .57994 Mdot
.77903 .57993 Mdot
.77904 .57992 Mdot
.77905 .57992 Mdot
.77906 .57991 Mdot
.77907 .5799 Mdot
.77908 .5799 Mdot
.77909 .57989 Mdot
.7791 .57988 Mdot
.7791 .57988 Mdot
.77911 .57987 Mdot
.77912 .57986 Mdot
.77913 .57986 Mdot
.77914 .57985 Mdot
.77915 .57984 Mdot
.77916 .57984 Mdot
.77917 .57983 Mdot
.77918 .57982 Mdot
.77919 .57982 Mdot
.7792 .57981 Mdot
.77921 .5798 Mdot
.77922 .5798 Mdot
.77923 .57979 Mdot
.77924 .57978 Mdot
.77925 .57978 Mdot
.77926 .57977 Mdot
.77927 .57976 Mdot
.77928 .57976 Mdot
.77929 .57975 Mdot
.7793 .57974 Mdot
.7793 .57974 Mdot
.77931 .57973 Mdot
.77932 .57972 Mdot
.77933 .57972 Mdot
.77934 .57971 Mdot
.77935 .5797 Mdot
.77936 .5797 Mdot
.77937 .57969 Mdot
.77938 .57968 Mdot
.77939 .57968 Mdot
.7794 .57967 Mdot
.77941 .57966 Mdot
.77942 .57966 Mdot
.77943 .57965 Mdot
.77944 .57964 Mdot
.77945 .57963 Mdot
.77946 .57963 Mdot
.77947 .57962 Mdot
.77948 .57961 Mdot
.77949 .57961 Mdot
.7795 .5796 Mdot
.7795 .57959 Mdot
.77951 .57959 Mdot
.77952 .57958 Mdot
.77953 .57957 Mdot
.77954 .57957 Mdot
.77955 .57956 Mdot
.77956 .57955 Mdot
.77957 .57955 Mdot
.77958 .57954 Mdot
.77959 .57953 Mdot
.7796 .57953 Mdot
.77961 .57952 Mdot
.77962 .57951 Mdot
.77963 .57951 Mdot
.77964 .5795 Mdot
.77965 .57949 Mdot
.77966 .57949 Mdot
.77967 .57948 Mdot
.77968 .57947 Mdot
.77969 .57947 Mdot
.7797 .57946 Mdot
.7797 .57945 Mdot
.77971 .57945 Mdot
.77972 .57944 Mdot
.77973 .57943 Mdot
.77974 .57943 Mdot
.77975 .57942 Mdot
.77976 .57941 Mdot
.77977 .57941 Mdot
.77978 .5794 Mdot
.77979 .57939 Mdot
.7798 .57939 Mdot
.77981 .57938 Mdot
.77982 .57937 Mdot
.77983 .57936 Mdot
.77984 .57936 Mdot
.77985 .57935 Mdot
.77986 .57934 Mdot
.77987 .57934 Mdot
.77988 .57933 Mdot
.77989 .57932 Mdot
.7799 .57932 Mdot
.7799 .57931 Mdot
.77991 .5793 Mdot
.77992 .5793 Mdot
.77993 .57929 Mdot
.77994 .57928 Mdot
.77995 .57928 Mdot
.77996 .57927 Mdot
.77997 .57926 Mdot
.77998 .57926 Mdot
.77999 .57925 Mdot
.78 .57924 Mdot
.78001 .57924 Mdot
.78002 .57923 Mdot
.78003 .57922 Mdot
.78004 .57922 Mdot
.78005 .57921 Mdot
.78006 .5792 Mdot
.78007 .5792 Mdot
.78008 .57919 Mdot
.78009 .57918 Mdot
.7801 .57917 Mdot
.7801 .57917 Mdot
.78011 .57916 Mdot
.78012 .57915 Mdot
.78013 .57915 Mdot
.78014 .57914 Mdot
.78015 .57913 Mdot
.78016 .57913 Mdot
.78017 .57912 Mdot
.78018 .57911 Mdot
.78019 .57911 Mdot
.7802 .5791 Mdot
.78021 .57909 Mdot
.78022 .57909 Mdot
.78023 .57908 Mdot
.78024 .57907 Mdot
.78025 .57907 Mdot
.78026 .57906 Mdot
.78027 .57905 Mdot
.78028 .57905 Mdot
.78029 .57904 Mdot
.7803 .57903 Mdot
.7803 .57903 Mdot
.78031 .57902 Mdot
.78032 .57901 Mdot
.78033 .579 Mdot
.78034 .579 Mdot
.78035 .57899 Mdot
.78036 .57898 Mdot
.78037 .57898 Mdot
.78038 .57897 Mdot
.78039 .57896 Mdot
.7804 .57896 Mdot
.78041 .57895 Mdot
.78042 .57894 Mdot
.78043 .57894 Mdot
.78044 .57893 Mdot
.78045 .57892 Mdot
.78046 .57892 Mdot
.78047 .57891 Mdot
.78048 .5789 Mdot
.78049 .5789 Mdot
.7805 .57889 Mdot
.7805 .57888 Mdot
.78051 .57888 Mdot
.78052 .57887 Mdot
.78053 .57886 Mdot
.78054 .57885 Mdot
.78055 .57885 Mdot
.78056 .57884 Mdot
.78057 .57883 Mdot
.78058 .57883 Mdot
.78059 .57882 Mdot
.7806 .57881 Mdot
.78061 .57881 Mdot
.78062 .5788 Mdot
.78063 .57879 Mdot
.78064 .57879 Mdot
.78065 .57878 Mdot
.78066 .57877 Mdot
.78067 .57877 Mdot
.78068 .57876 Mdot
.78069 .57875 Mdot
.7807 .57875 Mdot
.7807 .57874 Mdot
.78071 .57873 Mdot
.78072 .57872 Mdot
.78073 .57872 Mdot
.78074 .57871 Mdot
.78075 .5787 Mdot
.78076 .5787 Mdot
.78077 .57869 Mdot
.78078 .57868 Mdot
.78079 .57868 Mdot
.7808 .57867 Mdot
.78081 .57866 Mdot
.78082 .57866 Mdot
.78083 .57865 Mdot
.78084 .57864 Mdot
.78085 .57864 Mdot
.78086 .57863 Mdot
.78087 .57862 Mdot
.78088 .57861 Mdot
.78089 .57861 Mdot
.7809 .5786 Mdot
.7809 .57859 Mdot
.78091 .57859 Mdot
.78092 .57858 Mdot
.78093 .57857 Mdot
.78094 .57857 Mdot
.78095 .57856 Mdot
.78096 .57855 Mdot
.78097 .57855 Mdot
.78098 .57854 Mdot
.78099 .57853 Mdot
.781 .57853 Mdot
.78101 .57852 Mdot
.78102 .57851 Mdot
.78103 .5785 Mdot
.78104 .5785 Mdot
.78105 .57849 Mdot
.78106 .57848 Mdot
.78107 .57848 Mdot
.78108 .57847 Mdot
.78109 .57846 Mdot
.7811 .57846 Mdot
.7811 .57845 Mdot
.78111 .57844 Mdot
.78112 .57844 Mdot
.78113 .57843 Mdot
.78114 .57842 Mdot
.78115 .57842 Mdot
.78116 .57841 Mdot
.78117 .5784 Mdot
.78118 .57839 Mdot
.78119 .57839 Mdot
.7812 .57838 Mdot
.78121 .57837 Mdot
.78122 .57837 Mdot
.78123 .57836 Mdot
.78124 .57835 Mdot
.78125 .57835 Mdot
.78126 .57834 Mdot
.78127 .57833 Mdot
.78128 .57833 Mdot
.78129 .57832 Mdot
.7813 .57831 Mdot
.7813 .5783 Mdot
.78131 .5783 Mdot
.78132 .57829 Mdot
.78133 .57828 Mdot
.78134 .57828 Mdot
.78135 .57827 Mdot
.78136 .57826 Mdot
.78137 .57826 Mdot
.78138 .57825 Mdot
.78139 .57824 Mdot
.7814 .57824 Mdot
.78141 .57823 Mdot
.78142 .57822 Mdot
.78143 .57822 Mdot
.78144 .57821 Mdot
.78145 .5782 Mdot
.78146 .57819 Mdot
.78147 .57819 Mdot
.78148 .57818 Mdot
.78149 .57817 Mdot
.7815 .57817 Mdot
.7815 .57816 Mdot
.78151 .57815 Mdot
.78152 .57815 Mdot
.78153 .57814 Mdot
.78154 .57813 Mdot
.78155 .57813 Mdot
.78156 .57812 Mdot
.78157 .57811 Mdot
.78158 .5781 Mdot
.78159 .5781 Mdot
.7816 .57809 Mdot
.78161 .57808 Mdot
.78162 .57808 Mdot
.78163 .57807 Mdot
.78164 .57806 Mdot
.78165 .57806 Mdot
.78166 .57805 Mdot
.78167 .57804 Mdot
.78168 .57803 Mdot
.78169 .57803 Mdot
.7817 .57802 Mdot
.7817 .57801 Mdot
.78171 .57801 Mdot
.78172 .578 Mdot
.78173 .57799 Mdot
.78174 .57799 Mdot
.78175 .57798 Mdot
.78176 .57797 Mdot
.78177 .57797 Mdot
.78178 .57796 Mdot
.78179 .57795 Mdot
.7818 .57794 Mdot
.78181 .57794 Mdot
.78182 .57793 Mdot
.78183 .57792 Mdot
.78184 .57792 Mdot
.78185 .57791 Mdot
.78186 .5779 Mdot
.78187 .5779 Mdot
.78188 .57789 Mdot
.78189 .57788 Mdot
.7819 .57787 Mdot
.7819 .57787 Mdot
.78191 .57786 Mdot
.78192 .57785 Mdot
.78193 .57785 Mdot
.78194 .57784 Mdot
.78195 .57783 Mdot
.78196 .57783 Mdot
.78197 .57782 Mdot
.78198 .57781 Mdot
.78199 .57781 Mdot
.782 .5778 Mdot
.78201 .57779 Mdot
.78202 .57778 Mdot
.78203 .57778 Mdot
.78204 .57777 Mdot
.78205 .57776 Mdot
.78206 .57776 Mdot
.78207 .57775 Mdot
.78208 .57774 Mdot
.78209 .57774 Mdot
.7821 .57773 Mdot
.7821 .57772 Mdot
.78211 .57771 Mdot
.78212 .57771 Mdot
.78213 .5777 Mdot
.78214 .57769 Mdot
.78215 .57769 Mdot
.78216 .57768 Mdot
.78217 .57767 Mdot
.78218 .57767 Mdot
.78219 .57766 Mdot
.7822 .57765 Mdot
.78221 .57764 Mdot
.78222 .57764 Mdot
.78223 .57763 Mdot
.78224 .57762 Mdot
.78225 .57762 Mdot
.78226 .57761 Mdot
.78227 .5776 Mdot
.78228 .5776 Mdot
.78229 .57759 Mdot
.7823 .57758 Mdot
.7823 .57757 Mdot
.78231 .57757 Mdot
.78232 .57756 Mdot
.78233 .57755 Mdot
.78234 .57755 Mdot
.78235 .57754 Mdot
.78236 .57753 Mdot
.78237 .57753 Mdot
.78238 .57752 Mdot
.78239 .57751 Mdot
.7824 .5775 Mdot
.78241 .5775 Mdot
.78242 .57749 Mdot
.78243 .57748 Mdot
.78244 .57748 Mdot
.78245 .57747 Mdot
.78246 .57746 Mdot
.78247 .57746 Mdot
.78248 .57745 Mdot
.78249 .57744 Mdot
.7825 .57743 Mdot
.7825 .57743 Mdot
.78251 .57742 Mdot
.78252 .57741 Mdot
.78253 .57741 Mdot
.78254 .5774 Mdot
.78255 .57739 Mdot
.78256 .57739 Mdot
.78257 .57738 Mdot
.78258 .57737 Mdot
.78259 .57736 Mdot
.7826 .57736 Mdot
.78261 .57735 Mdot
.78262 .57734 Mdot
.78263 .57734 Mdot
.78264 .57733 Mdot
.78265 .57732 Mdot
.78266 .57732 Mdot
.78267 .57731 Mdot
.78268 .5773 Mdot
.78269 .57729 Mdot
.7827 .57729 Mdot
.7827 .57728 Mdot
.78271 .57727 Mdot
.78272 .57727 Mdot
.78273 .57726 Mdot
.78274 .57725 Mdot
.78275 .57724 Mdot
.78276 .57724 Mdot
.78277 .57723 Mdot
.78278 .57722 Mdot
.78279 .57722 Mdot
.7828 .57721 Mdot
.78281 .5772 Mdot
.78282 .5772 Mdot
.78283 .57719 Mdot
.78284 .57718 Mdot
.78285 .57717 Mdot
.78286 .57717 Mdot
.78287 .57716 Mdot
.78288 .57715 Mdot
.78289 .57715 Mdot
.7829 .57714 Mdot
.7829 .57713 Mdot
.78291 .57713 Mdot
.78292 .57712 Mdot
.78293 .57711 Mdot
.78294 .5771 Mdot
.78295 .5771 Mdot
.78296 .57709 Mdot
.78297 .57708 Mdot
.78298 .57708 Mdot
.78299 .57707 Mdot
.783 .57706 Mdot
.78301 .57705 Mdot
.78302 .57705 Mdot
.78303 .57704 Mdot
.78304 .57703 Mdot
.78305 .57703 Mdot
.78306 .57702 Mdot
.78307 .57701 Mdot
.78308 .57701 Mdot
.78309 .577 Mdot
.7831 .57699 Mdot
.7831 .57698 Mdot
.78311 .57698 Mdot
.78312 .57697 Mdot
.78313 .57696 Mdot
.78314 .57696 Mdot
.78315 .57695 Mdot
.78316 .57694 Mdot
.78317 .57693 Mdot
.78318 .57693 Mdot
.78319 .57692 Mdot
.7832 .57691 Mdot
.78321 .57691 Mdot
.78322 .5769 Mdot
.78323 .57689 Mdot
.78324 .57688 Mdot
.78325 .57688 Mdot
.78326 .57687 Mdot
.78327 .57686 Mdot
.78328 .57686 Mdot
.78329 .57685 Mdot
.7833 .57684 Mdot
.7833 .57684 Mdot
.78331 .57683 Mdot
.78332 .57682 Mdot
.78333 .57681 Mdot
.78334 .57681 Mdot
.78335 .5768 Mdot
.78336 .57679 Mdot
.78337 .57679 Mdot
.78338 .57678 Mdot
.78339 .57677 Mdot
.7834 .57676 Mdot
.78341 .57676 Mdot
.78342 .57675 Mdot
.78343 .57674 Mdot
.78344 .57674 Mdot
.78345 .57673 Mdot
.78346 .57672 Mdot
.78347 .57671 Mdot
.78348 .57671 Mdot
.78349 .5767 Mdot
.7835 .57669 Mdot
.7835 .57669 Mdot
.78351 .57668 Mdot
.78352 .57667 Mdot
.78353 .57666 Mdot
.78354 .57666 Mdot
.78355 .57665 Mdot
.78356 .57664 Mdot
.78357 .57664 Mdot
.78358 .57663 Mdot
.78359 .57662 Mdot
.7836 .57661 Mdot
.78361 .57661 Mdot
.78362 .5766 Mdot
.78363 .57659 Mdot
.78364 .57659 Mdot
.78365 .57658 Mdot
.78366 .57657 Mdot
.78367 .57657 Mdot
.78368 .57656 Mdot
.78369 .57655 Mdot
.7837 .57654 Mdot
.7837 .57654 Mdot
.78371 .57653 Mdot
.78372 .57652 Mdot
.78373 .57652 Mdot
.78374 .57651 Mdot
.78375 .5765 Mdot
.78376 .57649 Mdot
.78377 .57649 Mdot
.78378 .57648 Mdot
.78379 .57647 Mdot
.7838 .57647 Mdot
.78381 .57646 Mdot
.78382 .57645 Mdot
.78383 .57644 Mdot
.78384 .57644 Mdot
.78385 .57643 Mdot
.78386 .57642 Mdot
.78387 .57642 Mdot
.78388 .57641 Mdot
.78389 .5764 Mdot
.7839 .57639 Mdot
.7839 .57639 Mdot
.78391 .57638 Mdot
.78392 .57637 Mdot
.78393 .57637 Mdot
.78394 .57636 Mdot
.78395 .57635 Mdot
.78396 .57634 Mdot
.78397 .57634 Mdot
.78398 .57633 Mdot
.78399 .57632 Mdot
.784 .57632 Mdot
.78401 .57631 Mdot
.78402 .5763 Mdot
.78403 .57629 Mdot
.78404 .57629 Mdot
.78405 .57628 Mdot
.78406 .57627 Mdot
.78407 .57627 Mdot
.78408 .57626 Mdot
.78409 .57625 Mdot
.7841 .57624 Mdot
.7841 .57624 Mdot
.78411 .57623 Mdot
.78412 .57622 Mdot
.78413 .57621 Mdot
.78414 .57621 Mdot
.78415 .5762 Mdot
.78416 .57619 Mdot
.78417 .57619 Mdot
.78418 .57618 Mdot
.78419 .57617 Mdot
.7842 .57616 Mdot
.78421 .57616 Mdot
.78422 .57615 Mdot
.78423 .57614 Mdot
.78424 .57614 Mdot
.78425 .57613 Mdot
.78426 .57612 Mdot
.78427 .57611 Mdot
.78428 .57611 Mdot
.78429 .5761 Mdot
.7843 .57609 Mdot
.7843 .57609 Mdot
.78431 .57608 Mdot
.78432 .57607 Mdot
.78433 .57606 Mdot
.78434 .57606 Mdot
.78435 .57605 Mdot
.78436 .57604 Mdot
.78437 .57604 Mdot
.78438 .57603 Mdot
.78439 .57602 Mdot
.7844 .57601 Mdot
.78441 .57601 Mdot
.78442 .576 Mdot
.78443 .57599 Mdot
.78444 .57599 Mdot
.78445 .57598 Mdot
.78446 .57597 Mdot
.78447 .57596 Mdot
.78448 .57596 Mdot
.78449 .57595 Mdot
.7845 .57594 Mdot
.7845 .57593 Mdot
.78451 .57593 Mdot
.78452 .57592 Mdot
.78453 .57591 Mdot
.78454 .57591 Mdot
.78455 .5759 Mdot
.78456 .57589 Mdot
.78457 .57588 Mdot
.78458 .57588 Mdot
.78459 .57587 Mdot
.7846 .57586 Mdot
.78461 .57586 Mdot
.78462 .57585 Mdot
.78463 .57584 Mdot
.78464 .57583 Mdot
.78465 .57583 Mdot
.78466 .57582 Mdot
.78467 .57581 Mdot
.78468 .5758 Mdot
.78469 .5758 Mdot
.7847 .57579 Mdot
.7847 .57578 Mdot
.78471 .57578 Mdot
.78472 .57577 Mdot
.78473 .57576 Mdot
.78474 .57575 Mdot
.78475 .57575 Mdot
.78476 .57574 Mdot
.78477 .57573 Mdot
.78478 .57573 Mdot
.78479 .57572 Mdot
.7848 .57571 Mdot
.78481 .5757 Mdot
.78482 .5757 Mdot
.78483 .57569 Mdot
.78484 .57568 Mdot
.78485 .57567 Mdot
.78486 .57567 Mdot
.78487 .57566 Mdot
.78488 .57565 Mdot
.78489 .57565 Mdot
.7849 .57564 Mdot
.7849 .57563 Mdot
.78491 .57562 Mdot
.78492 .57562 Mdot
.78493 .57561 Mdot
.78494 .5756 Mdot
.78495 .5756 Mdot
.78496 .57559 Mdot
.78497 .57558 Mdot
.78498 .57557 Mdot
.78499 .57557 Mdot
.785 .57556 Mdot
.78501 .57555 Mdot
.78502 .57554 Mdot
.78503 .57554 Mdot
.78504 .57553 Mdot
.78505 .57552 Mdot
.78506 .57552 Mdot
.78507 .57551 Mdot
.78508 .5755 Mdot
.78509 .57549 Mdot
.7851 .57549 Mdot
.7851 .57548 Mdot
.78511 .57547 Mdot
.78512 .57546 Mdot
.78513 .57546 Mdot
.78514 .57545 Mdot
.78515 .57544 Mdot
.78516 .57544 Mdot
.78517 .57543 Mdot
.78518 .57542 Mdot
.78519 .57541 Mdot
.7852 .57541 Mdot
.78521 .5754 Mdot
.78522 .57539 Mdot
.78523 .57538 Mdot
.78524 .57538 Mdot
.78525 .57537 Mdot
.78526 .57536 Mdot
.78527 .57536 Mdot
.78528 .57535 Mdot
.78529 .57534 Mdot
.7853 .57533 Mdot
.7853 .57533 Mdot
.78531 .57532 Mdot
.78532 .57531 Mdot
.78533 .5753 Mdot
.78534 .5753 Mdot
.78535 .57529 Mdot
.78536 .57528 Mdot
.78537 .57528 Mdot
.78538 .57527 Mdot
.78539 .57526 Mdot
.7854 .57525 Mdot
.78541 .57525 Mdot
.78542 .57524 Mdot
.78543 .57523 Mdot
.78544 .57522 Mdot
.78545 .57522 Mdot
.78546 .57521 Mdot
.78547 .5752 Mdot
.78548 .5752 Mdot
.78549 .57519 Mdot
.7855 .57518 Mdot
.7855 .57517 Mdot
.78551 .57517 Mdot
.78552 .57516 Mdot
.78553 .57515 Mdot
.78554 .57514 Mdot
.78555 .57514 Mdot
.78556 .57513 Mdot
.78557 .57512 Mdot
.78558 .57512 Mdot
.78559 .57511 Mdot
.7856 .5751 Mdot
.78561 .57509 Mdot
.78562 .57509 Mdot
.78563 .57508 Mdot
.78564 .57507 Mdot
.78565 .57506 Mdot
.78566 .57506 Mdot
.78567 .57505 Mdot
.78568 .57504 Mdot
.78569 .57504 Mdot
.7857 .57503 Mdot
.7857 .57502 Mdot
.78571 .57501 Mdot
.78572 .57501 Mdot
.78573 .575 Mdot
.78574 .57499 Mdot
.78575 .57498 Mdot
.78576 .57498 Mdot
.78577 .57497 Mdot
.78578 .57496 Mdot
.78579 .57495 Mdot
.7858 .57495 Mdot
.78581 .57494 Mdot
.78582 .57493 Mdot
.78583 .57493 Mdot
.78584 .57492 Mdot
.78585 .57491 Mdot
.78586 .5749 Mdot
.78587 .5749 Mdot
.78588 .57489 Mdot
.78589 .57488 Mdot
.7859 .57487 Mdot
.7859 .57487 Mdot
.78591 .57486 Mdot
.78592 .57485 Mdot
.78593 .57484 Mdot
.78594 .57484 Mdot
.78595 .57483 Mdot
.78596 .57482 Mdot
.78597 .57482 Mdot
.78598 .57481 Mdot
.78599 .5748 Mdot
.786 .57479 Mdot
.78601 .57479 Mdot
.78602 .57478 Mdot
.78603 .57477 Mdot
.78604 .57476 Mdot
.78605 .57476 Mdot
.78606 .57475 Mdot
.78607 .57474 Mdot
.78608 .57473 Mdot
.78609 .57473 Mdot
.7861 .57472 Mdot
.7861 .57471 Mdot
.78611 .57471 Mdot
.78612 .5747 Mdot
.78613 .57469 Mdot
.78614 .57468 Mdot
.78615 .57468 Mdot
.78616 .57467 Mdot
.78617 .57466 Mdot
.78618 .57465 Mdot
.78619 .57465 Mdot
.7862 .57464 Mdot
.78621 .57463 Mdot
.78622 .57462 Mdot
.78623 .57462 Mdot
.78624 .57461 Mdot
.78625 .5746 Mdot
.78626 .5746 Mdot
.78627 .57459 Mdot
.78628 .57458 Mdot
.78629 .57457 Mdot
.7863 .57457 Mdot
.7863 .57456 Mdot
.78631 .57455 Mdot
.78632 .57454 Mdot
.78633 .57454 Mdot
.78634 .57453 Mdot
.78635 .57452 Mdot
.78636 .57451 Mdot
.78637 .57451 Mdot
.78638 .5745 Mdot
.78639 .57449 Mdot
.7864 .57448 Mdot
.78641 .57448 Mdot
.78642 .57447 Mdot
.78643 .57446 Mdot
.78644 .57446 Mdot
.78645 .57445 Mdot
.78646 .57444 Mdot
.78647 .57443 Mdot
.78648 .57443 Mdot
.78649 .57442 Mdot
.7865 .57441 Mdot
.7865 .5744 Mdot
.78651 .5744 Mdot
.78652 .57439 Mdot
.78653 .57438 Mdot
.78654 .57437 Mdot
.78655 .57437 Mdot
.78656 .57436 Mdot
.78657 .57435 Mdot
.78658 .57434 Mdot
.78659 .57434 Mdot
.7866 .57433 Mdot
.78661 .57432 Mdot
.78662 .57431 Mdot
.78663 .57431 Mdot
.78664 .5743 Mdot
.78665 .57429 Mdot
.78666 .57429 Mdot
.78667 .57428 Mdot
.78668 .57427 Mdot
.78669 .57426 Mdot
.7867 .57426 Mdot
.7867 .57425 Mdot
.78671 .57424 Mdot
.78672 .57423 Mdot
.78673 .57423 Mdot
.78674 .57422 Mdot
.78675 .57421 Mdot
.78676 .5742 Mdot
.78677 .5742 Mdot
.78678 .57419 Mdot
.78679 .57418 Mdot
.7868 .57417 Mdot
.78681 .57417 Mdot
.78682 .57416 Mdot
.78683 .57415 Mdot
.78684 .57414 Mdot
.78685 .57414 Mdot
.78686 .57413 Mdot
.78687 .57412 Mdot
.78688 .57411 Mdot
.78689 .57411 Mdot
.7869 .5741 Mdot
.7869 .57409 Mdot
.78691 .57409 Mdot
.78692 .57408 Mdot
.78693 .57407 Mdot
.78694 .57406 Mdot
.78695 .57406 Mdot
.78696 .57405 Mdot
.78697 .57404 Mdot
.78698 .57403 Mdot
.78699 .57403 Mdot
.787 .57402 Mdot
.78701 .57401 Mdot
.78702 .574 Mdot
.78703 .574 Mdot
.78704 .57399 Mdot
.78705 .57398 Mdot
.78706 .57397 Mdot
.78707 .57397 Mdot
.78708 .57396 Mdot
.78709 .57395 Mdot
.7871 .57394 Mdot
.7871 .57394 Mdot
.78711 .57393 Mdot
.78712 .57392 Mdot
.78713 .57391 Mdot
.78714 .57391 Mdot
.78715 .5739 Mdot
.78716 .57389 Mdot
.78717 .57388 Mdot
.78718 .57388 Mdot
.78719 .57387 Mdot
.7872 .57386 Mdot
.78721 .57385 Mdot
.78722 .57385 Mdot
.78723 .57384 Mdot
.78724 .57383 Mdot
.78725 .57382 Mdot
.78726 .57382 Mdot
.78727 .57381 Mdot
.78728 .5738 Mdot
.78729 .5738 Mdot
.7873 .57379 Mdot
.7873 .57378 Mdot
.78731 .57377 Mdot
.78732 .57377 Mdot
.78733 .57376 Mdot
.78734 .57375 Mdot
.78735 .57374 Mdot
.78736 .57374 Mdot
.78737 .57373 Mdot
.78738 .57372 Mdot
.78739 .57371 Mdot
.7874 .57371 Mdot
.78741 .5737 Mdot
.78742 .57369 Mdot
.78743 .57368 Mdot
.78744 .57368 Mdot
.78745 .57367 Mdot
.78746 .57366 Mdot
.78747 .57365 Mdot
.78748 .57365 Mdot
.78749 .57364 Mdot
.7875 .57363 Mdot
.7875 .57362 Mdot
.78751 .57362 Mdot
.78752 .57361 Mdot
.78753 .5736 Mdot
.78754 .57359 Mdot
.78755 .57359 Mdot
.78756 .57358 Mdot
.78757 .57357 Mdot
.78758 .57356 Mdot
.78759 .57356 Mdot
.7876 .57355 Mdot
.78761 .57354 Mdot
.78762 .57353 Mdot
.78763 .57353 Mdot
.78764 .57352 Mdot
.78765 .57351 Mdot
.78766 .5735 Mdot
.78767 .5735 Mdot
.78768 .57349 Mdot
.78769 .57348 Mdot
.7877 .57347 Mdot
.7877 .57347 Mdot
.78771 .57346 Mdot
.78772 .57345 Mdot
.78773 .57344 Mdot
.78774 .57344 Mdot
.78775 .57343 Mdot
.78776 .57342 Mdot
.78777 .57341 Mdot
.78778 .57341 Mdot
.78779 .5734 Mdot
.7878 .57339 Mdot
.78781 .57338 Mdot
.78782 .57338 Mdot
.78783 .57337 Mdot
.78784 .57336 Mdot
.78785 .57335 Mdot
.78786 .57335 Mdot
.78787 .57334 Mdot
.78788 .57333 Mdot
.78789 .57332 Mdot
.7879 .57332 Mdot
.7879 .57331 Mdot
.78791 .5733 Mdot
.78792 .57329 Mdot
.78793 .57329 Mdot
.78794 .57328 Mdot
.78795 .57327 Mdot
.78796 .57326 Mdot
.78797 .57326 Mdot
.78798 .57325 Mdot
.78799 .57324 Mdot
.788 .57323 Mdot
.78801 .57323 Mdot
.78802 .57322 Mdot
.78803 .57321 Mdot
.78804 .5732 Mdot
.78805 .5732 Mdot
.78806 .57319 Mdot
.78807 .57318 Mdot
.78808 .57317 Mdot
.78809 .57317 Mdot
.7881 .57316 Mdot
.7881 .57315 Mdot
.78811 .57314 Mdot
.78812 .57314 Mdot
.78813 .57313 Mdot
.78814 .57312 Mdot
.78815 .57311 Mdot
.78816 .57311 Mdot
.78817 .5731 Mdot
.78818 .57309 Mdot
.78819 .57308 Mdot
.7882 .57308 Mdot
.78821 .57307 Mdot
.78822 .57306 Mdot
.78823 .57305 Mdot
.78824 .57305 Mdot
.78825 .57304 Mdot
.78826 .57303 Mdot
.78827 .57302 Mdot
.78828 .57302 Mdot
.78829 .57301 Mdot
.7883 .573 Mdot
.7883 .57299 Mdot
.78831 .57299 Mdot
.78832 .57298 Mdot
.78833 .57297 Mdot
.78834 .57296 Mdot
.78835 .57295 Mdot
.78836 .57295 Mdot
.78837 .57294 Mdot
.78838 .57293 Mdot
.78839 .57292 Mdot
.7884 .57292 Mdot
.78841 .57291 Mdot
.78842 .5729 Mdot
.78843 .57289 Mdot
.78844 .57289 Mdot
.78845 .57288 Mdot
.78846 .57287 Mdot
.78847 .57286 Mdot
.78848 .57286 Mdot
.78849 .57285 Mdot
.7885 .57284 Mdot
.7885 .57283 Mdot
.78851 .57283 Mdot
.78852 .57282 Mdot
.78853 .57281 Mdot
.78854 .5728 Mdot
.78855 .5728 Mdot
.78856 .57279 Mdot
.78857 .57278 Mdot
.78858 .57277 Mdot
.78859 .57277 Mdot
.7886 .57276 Mdot
.78861 .57275 Mdot
.78862 .57274 Mdot
.78863 .57274 Mdot
.78864 .57273 Mdot
.78865 .57272 Mdot
.78866 .57271 Mdot
.78867 .57271 Mdot
.78868 .5727 Mdot
.78869 .57269 Mdot
.7887 .57268 Mdot
.7887 .57267 Mdot
.78871 .57267 Mdot
.78872 .57266 Mdot
.78873 .57265 Mdot
.78874 .57264 Mdot
.78875 .57264 Mdot
.78876 .57263 Mdot
.78877 .57262 Mdot
.78878 .57261 Mdot
.78879 .57261 Mdot
.7888 .5726 Mdot
.78881 .57259 Mdot
.78882 .57258 Mdot
.78883 .57258 Mdot
.78884 .57257 Mdot
.78885 .57256 Mdot
.78886 .57255 Mdot
.78887 .57255 Mdot
.78888 .57254 Mdot
.78889 .57253 Mdot
.7889 .57252 Mdot
.7889 .57252 Mdot
.78891 .57251 Mdot
.78892 .5725 Mdot
.78893 .57249 Mdot
.78894 .57249 Mdot
.78895 .57248 Mdot
.78896 .57247 Mdot
.78897 .57246 Mdot
.78898 .57245 Mdot
.78899 .57245 Mdot
.789 .57244 Mdot
.78901 .57243 Mdot
.78902 .57242 Mdot
.78903 .57242 Mdot
.78904 .57241 Mdot
.78905 .5724 Mdot
.78906 .57239 Mdot
.78907 .57239 Mdot
.78908 .57238 Mdot
.78909 .57237 Mdot
.7891 .57236 Mdot
.7891 .57236 Mdot
.78911 .57235 Mdot
.78912 .57234 Mdot
.78913 .57233 Mdot
.78914 .57233 Mdot
.78915 .57232 Mdot
.78916 .57231 Mdot
.78917 .5723 Mdot
.78918 .57229 Mdot
.78919 .57229 Mdot
.7892 .57228 Mdot
.78921 .57227 Mdot
.78922 .57226 Mdot
.78923 .57226 Mdot
.78924 .57225 Mdot
.78925 .57224 Mdot
.78926 .57223 Mdot
.78927 .57223 Mdot
.78928 .57222 Mdot
.78929 .57221 Mdot
.7893 .5722 Mdot
.7893 .5722 Mdot
.78931 .57219 Mdot
.78932 .57218 Mdot
.78933 .57217 Mdot
.78934 .57217 Mdot
.78935 .57216 Mdot
.78936 .57215 Mdot
.78937 .57214 Mdot
.78938 .57213 Mdot
.78939 .57213 Mdot
.7894 .57212 Mdot
.78941 .57211 Mdot
.78942 .5721 Mdot
.78943 .5721 Mdot
.78944 .57209 Mdot
.78945 .57208 Mdot
.78946 .57207 Mdot
.78947 .57207 Mdot
.78948 .57206 Mdot
.78949 .57205 Mdot
.7895 .57204 Mdot
.7895 .57204 Mdot
.78951 .57203 Mdot
.78952 .57202 Mdot
.78953 .57201 Mdot
.78954 .572 Mdot
.78955 .572 Mdot
.78956 .57199 Mdot
.78957 .57198 Mdot
.78958 .57197 Mdot
.78959 .57197 Mdot
.7896 .57196 Mdot
.78961 .57195 Mdot
.78962 .57194 Mdot
.78963 .57194 Mdot
.78964 .57193 Mdot
.78965 .57192 Mdot
.78966 .57191 Mdot
.78967 .5719 Mdot
.78968 .5719 Mdot
.78969 .57189 Mdot
.7897 .57188 Mdot
.7897 .57187 Mdot
.78971 .57187 Mdot
.78972 .57186 Mdot
.78973 .57185 Mdot
.78974 .57184 Mdot
.78975 .57184 Mdot
.78976 .57183 Mdot
.78977 .57182 Mdot
.78978 .57181 Mdot
.78979 .57181 Mdot
.7898 .5718 Mdot
.78981 .57179 Mdot
.78982 .57178 Mdot
.78983 .57177 Mdot
.78984 .57177 Mdot
.78985 .57176 Mdot
.78986 .57175 Mdot
.78987 .57174 Mdot
.78988 .57174 Mdot
.78989 .57173 Mdot
.7899 .57172 Mdot
.7899 .57171 Mdot
.78991 .57171 Mdot
.78992 .5717 Mdot
.78993 .57169 Mdot
.78994 .57168 Mdot
.78995 .57167 Mdot
.78996 .57167 Mdot
.78997 .57166 Mdot
.78998 .57165 Mdot
.78999 .57164 Mdot
.79 .57164 Mdot
.79001 .57163 Mdot
.79002 .57162 Mdot
.79003 .57161 Mdot
.79004 .57161 Mdot
.79005 .5716 Mdot
.79006 .57159 Mdot
.79007 .57158 Mdot
.79008 .57157 Mdot
.79009 .57157 Mdot
.7901 .57156 Mdot
.7901 .57155 Mdot
.79011 .57154 Mdot
.79012 .57154 Mdot
.79013 .57153 Mdot
.79014 .57152 Mdot
.79015 .57151 Mdot
.79016 .5715 Mdot
.79017 .5715 Mdot
.79018 .57149 Mdot
.79019 .57148 Mdot
.7902 .57147 Mdot
.79021 .57147 Mdot
.79022 .57146 Mdot
.79023 .57145 Mdot
.79024 .57144 Mdot
.79025 .57144 Mdot
.79026 .57143 Mdot
.79027 .57142 Mdot
.79028 .57141 Mdot
.79029 .5714 Mdot
.7903 .5714 Mdot
.7903 .57139 Mdot
.79031 .57138 Mdot
.79032 .57137 Mdot
.79033 .57137 Mdot
.79034 .57136 Mdot
.79035 .57135 Mdot
.79036 .57134 Mdot
.79037 .57134 Mdot
.79038 .57133 Mdot
.79039 .57132 Mdot
.7904 .57131 Mdot
.79041 .5713 Mdot
.79042 .5713 Mdot
.79043 .57129 Mdot
.79044 .57128 Mdot
.79045 .57127 Mdot
.79046 .57127 Mdot
.79047 .57126 Mdot
.79048 .57125 Mdot
.79049 .57124 Mdot
.7905 .57123 Mdot
.7905 .57123 Mdot
.79051 .57122 Mdot
.79052 .57121 Mdot
.79053 .5712 Mdot
.79054 .5712 Mdot
.79055 .57119 Mdot
.79056 .57118 Mdot
.79057 .57117 Mdot
.79058 .57116 Mdot
.79059 .57116 Mdot
.7906 .57115 Mdot
.79061 .57114 Mdot
.79062 .57113 Mdot
.79063 .57113 Mdot
.79064 .57112 Mdot
.79065 .57111 Mdot
.79066 .5711 Mdot
.79067 .57109 Mdot
.79068 .57109 Mdot
.79069 .57108 Mdot
.7907 .57107 Mdot
.7907 .57106 Mdot
.79071 .57106 Mdot
.79072 .57105 Mdot
.79073 .57104 Mdot
.79074 .57103 Mdot
.79075 .57103 Mdot
.79076 .57102 Mdot
.79077 .57101 Mdot
.79078 .571 Mdot
.79079 .57099 Mdot
.7908 .57099 Mdot
.79081 .57098 Mdot
.79082 .57097 Mdot
.79083 .57096 Mdot
.79084 .57096 Mdot
.79085 .57095 Mdot
.79086 .57094 Mdot
.79087 .57093 Mdot
.79088 .57092 Mdot
.79089 .57092 Mdot
.7909 .57091 Mdot
.7909 .5709 Mdot
.79091 .57089 Mdot
.79092 .57089 Mdot
.79093 .57088 Mdot
.79094 .57087 Mdot
.79095 .57086 Mdot
.79096 .57085 Mdot
.79097 .57085 Mdot
.79098 .57084 Mdot
.79099 .57083 Mdot
.791 .57082 Mdot
.79101 .57082 Mdot
.79102 .57081 Mdot
.79103 .5708 Mdot
.79104 .57079 Mdot
.79105 .57078 Mdot
.79106 .57078 Mdot
.79107 .57077 Mdot
.79108 .57076 Mdot
.79109 .57075 Mdot
.7911 .57075 Mdot
.7911 .57074 Mdot
.79111 .57073 Mdot
.79112 .57072 Mdot
.79113 .57071 Mdot
.79114 .57071 Mdot
.79115 .5707 Mdot
.79116 .57069 Mdot
.79117 .57068 Mdot
.79118 .57067 Mdot
.79119 .57067 Mdot
.7912 .57066 Mdot
.79121 .57065 Mdot
.79122 .57064 Mdot
.79123 .57064 Mdot
.79124 .57063 Mdot
.79125 .57062 Mdot
.79126 .57061 Mdot
.79127 .5706 Mdot
.79128 .5706 Mdot
.79129 .57059 Mdot
.7913 .57058 Mdot
.7913 .57057 Mdot
.79131 .57057 Mdot
.79132 .57056 Mdot
.79133 .57055 Mdot
.79134 .57054 Mdot
.79135 .57053 Mdot
.79136 .57053 Mdot
.79137 .57052 Mdot
.79138 .57051 Mdot
.79139 .5705 Mdot
.7914 .5705 Mdot
.79141 .57049 Mdot
.79142 .57048 Mdot
.79143 .57047 Mdot
.79144 .57046 Mdot
.79145 .57046 Mdot
.79146 .57045 Mdot
.79147 .57044 Mdot
.79148 .57043 Mdot
.79149 .57042 Mdot
.7915 .57042 Mdot
.7915 .57041 Mdot
.79151 .5704 Mdot
.79152 .57039 Mdot
.79153 .57039 Mdot
.79154 .57038 Mdot
.79155 .57037 Mdot
.79156 .57036 Mdot
.79157 .57035 Mdot
.79158 .57035 Mdot
.79159 .57034 Mdot
.7916 .57033 Mdot
.79161 .57032 Mdot
.79162 .57032 Mdot
.79163 .57031 Mdot
.79164 .5703 Mdot
.79165 .57029 Mdot
.79166 .57028 Mdot
.79167 .57028 Mdot
.79168 .57027 Mdot
.79169 .57026 Mdot
.7917 .57025 Mdot
.7917 .57024 Mdot
.79171 .57024 Mdot
.79172 .57023 Mdot
.79173 .57022 Mdot
.79174 .57021 Mdot
.79175 .57021 Mdot
.79176 .5702 Mdot
.79177 .57019 Mdot
.79178 .57018 Mdot
.79179 .57017 Mdot
.7918 .57017 Mdot
.79181 .57016 Mdot
.79182 .57015 Mdot
.79183 .57014 Mdot
.79184 .57013 Mdot
.79185 .57013 Mdot
.79186 .57012 Mdot
.79187 .57011 Mdot
.79188 .5701 Mdot
.79189 .5701 Mdot
.7919 .57009 Mdot
.7919 .57008 Mdot
.79191 .57007 Mdot
.79192 .57006 Mdot
.79193 .57006 Mdot
.79194 .57005 Mdot
.79195 .57004 Mdot
.79196 .57003 Mdot
.79197 .57002 Mdot
.79198 .57002 Mdot
.79199 .57001 Mdot
.792 .57 Mdot
.79201 .56999 Mdot
.79202 .56998 Mdot
.79203 .56998 Mdot
.79204 .56997 Mdot
.79205 .56996 Mdot
.79206 .56995 Mdot
.79207 .56995 Mdot
.79208 .56994 Mdot
.79209 .56993 Mdot
.7921 .56992 Mdot
.7921 .56991 Mdot
.79211 .56991 Mdot
.79212 .5699 Mdot
.79213 .56989 Mdot
.79214 .56988 Mdot
.79215 .56987 Mdot
.79216 .56987 Mdot
.79217 .56986 Mdot
.79218 .56985 Mdot
.79219 .56984 Mdot
.7922 .56984 Mdot
.79221 .56983 Mdot
.79222 .56982 Mdot
.79223 .56981 Mdot
.79224 .5698 Mdot
.79225 .5698 Mdot
.79226 .56979 Mdot
.79227 .56978 Mdot
.79228 .56977 Mdot
.79229 .56976 Mdot
.7923 .56976 Mdot
.7923 .56975 Mdot
.79231 .56974 Mdot
.79232 .56973 Mdot
.79233 .56972 Mdot
.79234 .56972 Mdot
.79235 .56971 Mdot
.79236 .5697 Mdot
.79237 .56969 Mdot
.79238 .56968 Mdot
.79239 .56968 Mdot
.7924 .56967 Mdot
.79241 .56966 Mdot
.79242 .56965 Mdot
.79243 .56965 Mdot
.79244 .56964 Mdot
.79245 .56963 Mdot
.79246 .56962 Mdot
.79247 .56961 Mdot
.79248 .56961 Mdot
.79249 .5696 Mdot
.7925 .56959 Mdot
.7925 .56958 Mdot
.79251 .56957 Mdot
.79252 .56957 Mdot
.79253 .56956 Mdot
.79254 .56955 Mdot
.79255 .56954 Mdot
.79256 .56953 Mdot
.79257 .56953 Mdot
.79258 .56952 Mdot
.79259 .56951 Mdot
.7926 .5695 Mdot
.79261 .56949 Mdot
.79262 .56949 Mdot
.79263 .56948 Mdot
.79264 .56947 Mdot
.79265 .56946 Mdot
.79266 .56946 Mdot
.79267 .56945 Mdot
.79268 .56944 Mdot
.79269 .56943 Mdot
.7927 .56942 Mdot
.7927 .56942 Mdot
.79271 .56941 Mdot
.79272 .5694 Mdot
.79273 .56939 Mdot
.79274 .56938 Mdot
.79275 .56938 Mdot
.79276 .56937 Mdot
.79277 .56936 Mdot
.79278 .56935 Mdot
.79279 .56934 Mdot
.7928 .56934 Mdot
.79281 .56933 Mdot
.79282 .56932 Mdot
.79283 .56931 Mdot
.79284 .5693 Mdot
.79285 .5693 Mdot
.79286 .56929 Mdot
.79287 .56928 Mdot
.79288 .56927 Mdot
.79289 .56926 Mdot
.7929 .56926 Mdot
.7929 .56925 Mdot
.79291 .56924 Mdot
.79292 .56923 Mdot
.79293 .56922 Mdot
.79294 .56922 Mdot
.79295 .56921 Mdot
.79296 .5692 Mdot
.79297 .56919 Mdot
.79298 .56918 Mdot
.79299 .56918 Mdot
.793 .56917 Mdot
.79301 .56916 Mdot
.79302 .56915 Mdot
.79303 .56915 Mdot
.79304 .56914 Mdot
.79305 .56913 Mdot
.79306 .56912 Mdot
.79307 .56911 Mdot
.79308 .56911 Mdot
.79309 .5691 Mdot
.7931 .56909 Mdot
.7931 .56908 Mdot
.79311 .56907 Mdot
.79312 .56907 Mdot
.79313 .56906 Mdot
.79314 .56905 Mdot
.79315 .56904 Mdot
.79316 .56903 Mdot
.79317 .56903 Mdot
.79318 .56902 Mdot
.79319 .56901 Mdot
.7932 .569 Mdot
.79321 .56899 Mdot
.79322 .56899 Mdot
.79323 .56898 Mdot
.79324 .56897 Mdot
.79325 .56896 Mdot
.79326 .56895 Mdot
.79327 .56895 Mdot
.79328 .56894 Mdot
.79329 .56893 Mdot
.7933 .56892 Mdot
.7933 .56891 Mdot
.79331 .56891 Mdot
.79332 .5689 Mdot
.79333 .56889 Mdot
.79334 .56888 Mdot
.79335 .56887 Mdot
.79336 .56887 Mdot
.79337 .56886 Mdot
.79338 .56885 Mdot
.79339 .56884 Mdot
.7934 .56883 Mdot
.79341 .56883 Mdot
.79342 .56882 Mdot
.79343 .56881 Mdot
.79344 .5688 Mdot
.79345 .56879 Mdot
.79346 .56879 Mdot
.79347 .56878 Mdot
.79348 .56877 Mdot
.79349 .56876 Mdot
.7935 .56875 Mdot
.7935 .56875 Mdot
.79351 .56874 Mdot
.79352 .56873 Mdot
.79353 .56872 Mdot
.79354 .56871 Mdot
.79355 .56871 Mdot
.79356 .5687 Mdot
.79357 .56869 Mdot
.79358 .56868 Mdot
.79359 .56867 Mdot
.7936 .56867 Mdot
.79361 .56866 Mdot
.79362 .56865 Mdot
.79363 .56864 Mdot
.79364 .56863 Mdot
.79365 .56863 Mdot
.79366 .56862 Mdot
.79367 .56861 Mdot
.79368 .5686 Mdot
.79369 .56859 Mdot
.7937 .56859 Mdot
.7937 .56858 Mdot
.79371 .56857 Mdot
.79372 .56856 Mdot
.79373 .56855 Mdot
.79374 .56855 Mdot
.79375 .56854 Mdot
.79376 .56853 Mdot
.79377 .56852 Mdot
.79378 .56851 Mdot
.79379 .56851 Mdot
.7938 .5685 Mdot
.79381 .56849 Mdot
.79382 .56848 Mdot
.79383 .56847 Mdot
.79384 .56846 Mdot
.79385 .56846 Mdot
.79386 .56845 Mdot
.79387 .56844 Mdot
.79388 .56843 Mdot
.79389 .56842 Mdot
.7939 .56842 Mdot
.7939 .56841 Mdot
.79391 .5684 Mdot
.79392 .56839 Mdot
.79393 .56838 Mdot
.79394 .56838 Mdot
.79395 .56837 Mdot
.79396 .56836 Mdot
.79397 .56835 Mdot
.79398 .56834 Mdot
.79399 .56834 Mdot
.794 .56833 Mdot
.79401 .56832 Mdot
.79402 .56831 Mdot
.79403 .5683 Mdot
.79404 .5683 Mdot
.79405 .56829 Mdot
.79406 .56828 Mdot
.79407 .56827 Mdot
.79408 .56826 Mdot
.79409 .56826 Mdot
.7941 .56825 Mdot
.7941 .56824 Mdot
.79411 .56823 Mdot
.79412 .56822 Mdot
.79413 .56822 Mdot
.79414 .56821 Mdot
.79415 .5682 Mdot
.79416 .56819 Mdot
.79417 .56818 Mdot
.79418 .56818 Mdot
.79419 .56817 Mdot
.7942 .56816 Mdot
.79421 .56815 Mdot
.79422 .56814 Mdot
.79423 .56813 Mdot
.79424 .56813 Mdot
.79425 .56812 Mdot
.79426 .56811 Mdot
.79427 .5681 Mdot
.79428 .56809 Mdot
.79429 .56809 Mdot
.7943 .56808 Mdot
.7943 .56807 Mdot
.79431 .56806 Mdot
.79432 .56805 Mdot
.79433 .56805 Mdot
.79434 .56804 Mdot
.79435 .56803 Mdot
.79436 .56802 Mdot
.79437 .56801 Mdot
.79438 .56801 Mdot
.79439 .568 Mdot
.7944 .56799 Mdot
.79441 .56798 Mdot
.79442 .56797 Mdot
.79443 .56796 Mdot
.79444 .56796 Mdot
.79445 .56795 Mdot
.79446 .56794 Mdot
.79447 .56793 Mdot
.79448 .56792 Mdot
.79449 .56792 Mdot
.7945 .56791 Mdot
.7945 .5679 Mdot
.79451 .56789 Mdot
.79452 .56788 Mdot
.79453 .56788 Mdot
.79454 .56787 Mdot
.79455 .56786 Mdot
.79456 .56785 Mdot
.79457 .56784 Mdot
.79458 .56784 Mdot
.79459 .56783 Mdot
.7946 .56782 Mdot
.79461 .56781 Mdot
.79462 .5678 Mdot
.79463 .56779 Mdot
.79464 .56779 Mdot
.79465 .56778 Mdot
.79466 .56777 Mdot
.79467 .56776 Mdot
.79468 .56775 Mdot
.79469 .56775 Mdot
.7947 .56774 Mdot
.7947 .56773 Mdot
.79471 .56772 Mdot
.79472 .56771 Mdot
.79473 .56771 Mdot
.79474 .5677 Mdot
.79475 .56769 Mdot
.79476 .56768 Mdot
.79477 .56767 Mdot
.79478 .56767 Mdot
.79479 .56766 Mdot
.7948 .56765 Mdot
.79481 .56764 Mdot
.79482 .56763 Mdot
.79483 .56762 Mdot
.79484 .56762 Mdot
.79485 .56761 Mdot
.79486 .5676 Mdot
.79487 .56759 Mdot
.79488 .56758 Mdot
.79489 .56758 Mdot
.7949 .56757 Mdot
.7949 .56756 Mdot
.79491 .56755 Mdot
.79492 .56754 Mdot
.79493 .56754 Mdot
.79494 .56753 Mdot
.79495 .56752 Mdot
.79496 .56751 Mdot
.79497 .5675 Mdot
.79498 .56749 Mdot
.79499 .56749 Mdot
.795 .56748 Mdot
.79501 .56747 Mdot
.79502 .56746 Mdot
.79503 .56745 Mdot
.79504 .56745 Mdot
.79505 .56744 Mdot
.79506 .56743 Mdot
.79507 .56742 Mdot
.79508 .56741 Mdot
.79509 .5674 Mdot
.7951 .5674 Mdot
.7951 .56739 Mdot
.79511 .56738 Mdot
.79512 .56737 Mdot
.79513 .56736 Mdot
.79514 .56736 Mdot
.79515 .56735 Mdot
.79516 .56734 Mdot
.79517 .56733 Mdot
.79518 .56732 Mdot
.79519 .56732 Mdot
.7952 .56731 Mdot
.79521 .5673 Mdot
.79522 .56729 Mdot
.79523 .56728 Mdot
.79524 .56727 Mdot
.79525 .56727 Mdot
.79526 .56726 Mdot
.79527 .56725 Mdot
.79528 .56724 Mdot
.79529 .56723 Mdot
.7953 .56723 Mdot
.7953 .56722 Mdot
.79531 .56721 Mdot
.79532 .5672 Mdot
.79533 .56719 Mdot
.79534 .56718 Mdot
.79535 .56718 Mdot
.79536 .56717 Mdot
.79537 .56716 Mdot
.79538 .56715 Mdot
.79539 .56714 Mdot
.7954 .56714 Mdot
.79541 .56713 Mdot
.79542 .56712 Mdot
.79543 .56711 Mdot
.79544 .5671 Mdot
.79545 .56709 Mdot
.79546 .56709 Mdot
.79547 .56708 Mdot
.79548 .56707 Mdot
.79549 .56706 Mdot
.7955 .56705 Mdot
.7955 .56705 Mdot
.79551 .56704 Mdot
.79552 .56703 Mdot
.79553 .56702 Mdot
.79554 .56701 Mdot
.79555 .567 Mdot
.79556 .567 Mdot
.79557 .56699 Mdot
.79558 .56698 Mdot
.79559 .56697 Mdot
.7956 .56696 Mdot
.79561 .56696 Mdot
.79562 .56695 Mdot
.79563 .56694 Mdot
.79564 .56693 Mdot
.79565 .56692 Mdot
.79566 .56691 Mdot
.79567 .56691 Mdot
.79568 .5669 Mdot
.79569 .56689 Mdot
.7957 .56688 Mdot
.7957 .56687 Mdot
.79571 .56687 Mdot
.79572 .56686 Mdot
.79573 .56685 Mdot
.79574 .56684 Mdot
.79575 .56683 Mdot
.79576 .56682 Mdot
.79577 .56682 Mdot
.79578 .56681 Mdot
.79579 .5668 Mdot
.7958 .56679 Mdot
.79581 .56678 Mdot
.79582 .56677 Mdot
.79583 .56677 Mdot
.79584 .56676 Mdot
.79585 .56675 Mdot
.79586 .56674 Mdot
.79587 .56673 Mdot
.79588 .56673 Mdot
.79589 .56672 Mdot
.7959 .56671 Mdot
.7959 .5667 Mdot
.79591 .56669 Mdot
.79592 .56668 Mdot
.79593 .56668 Mdot
.79594 .56667 Mdot
.79595 .56666 Mdot
.79596 .56665 Mdot
.79597 .56664 Mdot
.79598 .56664 Mdot
.79599 .56663 Mdot
.796 .56662 Mdot
.79601 .56661 Mdot
.79602 .5666 Mdot
.79603 .56659 Mdot
.79604 .56659 Mdot
.79605 .56658 Mdot
.79606 .56657 Mdot
.79607 .56656 Mdot
.79608 .56655 Mdot
.79609 .56654 Mdot
.7961 .56654 Mdot
.7961 .56653 Mdot
.79611 .56652 Mdot
.79612 .56651 Mdot
.79613 .5665 Mdot
.79614 .5665 Mdot
.79615 .56649 Mdot
.79616 .56648 Mdot
.79617 .56647 Mdot
.79618 .56646 Mdot
.79619 .56645 Mdot
.7962 .56645 Mdot
.79621 .56644 Mdot
.79622 .56643 Mdot
.79623 .56642 Mdot
.79624 .56641 Mdot
.79625 .5664 Mdot
.79626 .5664 Mdot
.79627 .56639 Mdot
.79628 .56638 Mdot
.79629 .56637 Mdot
.7963 .56636 Mdot
.7963 .56636 Mdot
.79631 .56635 Mdot
.79632 .56634 Mdot
.79633 .56633 Mdot
.79634 .56632 Mdot
.79635 .56631 Mdot
.79636 .56631 Mdot
.79637 .5663 Mdot
.79638 .56629 Mdot
.79639 .56628 Mdot
.7964 .56627 Mdot
.79641 .56626 Mdot
.79642 .56626 Mdot
.79643 .56625 Mdot
.79644 .56624 Mdot
.79645 .56623 Mdot
.79646 .56622 Mdot
.79647 .56621 Mdot
.79648 .56621 Mdot
.79649 .5662 Mdot
.7965 .56619 Mdot
.7965 .56618 Mdot
.79651 .56617 Mdot
.79652 .56617 Mdot
.79653 .56616 Mdot
.79654 .56615 Mdot
.79655 .56614 Mdot
.79656 .56613 Mdot
.79657 .56612 Mdot
.79658 .56612 Mdot
.79659 .56611 Mdot
.7966 .5661 Mdot
.79661 .56609 Mdot
.79662 .56608 Mdot
.79663 .56607 Mdot
.79664 .56607 Mdot
.79665 .56606 Mdot
.79666 .56605 Mdot
.79667 .56604 Mdot
.79668 .56603 Mdot
.79669 .56602 Mdot
.7967 .56602 Mdot
.7967 .56601 Mdot
.79671 .566 Mdot
.79672 .56599 Mdot
.79673 .56598 Mdot
.79674 .56597 Mdot
.79675 .56597 Mdot
.79676 .56596 Mdot
.79677 .56595 Mdot
.79678 .56594 Mdot
.79679 .56593 Mdot
.7968 .56592 Mdot
.79681 .56592 Mdot
.79682 .56591 Mdot
.79683 .5659 Mdot
.79684 .56589 Mdot
.79685 .56588 Mdot
.79686 .56588 Mdot
.79687 .56587 Mdot
.79688 .56586 Mdot
.79689 .56585 Mdot
.7969 .56584 Mdot
.7969 .56583 Mdot
.79691 .56583 Mdot
.79692 .56582 Mdot
.79693 .56581 Mdot
.79694 .5658 Mdot
.79695 .56579 Mdot
.79696 .56578 Mdot
.79697 .56578 Mdot
.79698 .56577 Mdot
.79699 .56576 Mdot
.797 .56575 Mdot
.79701 .56574 Mdot
.79702 .56573 Mdot
.79703 .56573 Mdot
.79704 .56572 Mdot
.79705 .56571 Mdot
.79706 .5657 Mdot
.79707 .56569 Mdot
.79708 .56568 Mdot
.79709 .56568 Mdot
.7971 .56567 Mdot
.7971 .56566 Mdot
.79711 .56565 Mdot
.79712 .56564 Mdot
.79713 .56563 Mdot
.79714 .56563 Mdot
.79715 .56562 Mdot
.79716 .56561 Mdot
.79717 .5656 Mdot
.79718 .56559 Mdot
.79719 .56558 Mdot
.7972 .56558 Mdot
.79721 .56557 Mdot
.79722 .56556 Mdot
.79723 .56555 Mdot
.79724 .56554 Mdot
.79725 .56553 Mdot
.79726 .56553 Mdot
.79727 .56552 Mdot
.79728 .56551 Mdot
.79729 .5655 Mdot
.7973 .56549 Mdot
.7973 .56548 Mdot
.79731 .56548 Mdot
.79732 .56547 Mdot
.79733 .56546 Mdot
.79734 .56545 Mdot
.79735 .56544 Mdot
.79736 .56543 Mdot
.79737 .56543 Mdot
.79738 .56542 Mdot
.79739 .56541 Mdot
.7974 .5654 Mdot
.79741 .56539 Mdot
.79742 .56538 Mdot
.79743 .56538 Mdot
.79744 .56537 Mdot
.79745 .56536 Mdot
.79746 .56535 Mdot
.79747 .56534 Mdot
.79748 .56533 Mdot
.79749 .56533 Mdot
.7975 .56532 Mdot
.7975 .56531 Mdot
.79751 .5653 Mdot
.79752 .56529 Mdot
.79753 .56528 Mdot
.79754 .56528 Mdot
.79755 .56527 Mdot
.79756 .56526 Mdot
.79757 .56525 Mdot
.79758 .56524 Mdot
.79759 .56523 Mdot
.7976 .56522 Mdot
.79761 .56522 Mdot
.79762 .56521 Mdot
.79763 .5652 Mdot
.79764 .56519 Mdot
.79765 .56518 Mdot
.79766 .56517 Mdot
.79767 .56517 Mdot
.79768 .56516 Mdot
.79769 .56515 Mdot
.7977 .56514 Mdot
.7977 .56513 Mdot
.79771 .56512 Mdot
.79772 .56512 Mdot
.79773 .56511 Mdot
.79774 .5651 Mdot
.79775 .56509 Mdot
.79776 .56508 Mdot
.79777 .56507 Mdot
.79778 .56507 Mdot
.79779 .56506 Mdot
.7978 .56505 Mdot
.79781 .56504 Mdot
.79782 .56503 Mdot
.79783 .56502 Mdot
.79784 .56502 Mdot
.79785 .56501 Mdot
.79786 .565 Mdot
.79787 .56499 Mdot
.79788 .56498 Mdot
.79789 .56497 Mdot
.7979 .56497 Mdot
.7979 .56496 Mdot
.79791 .56495 Mdot
.79792 .56494 Mdot
.79793 .56493 Mdot
.79794 .56492 Mdot
.79795 .56491 Mdot
.79796 .56491 Mdot
.79797 .5649 Mdot
.79798 .56489 Mdot
.79799 .56488 Mdot
.798 .56487 Mdot
.79801 .56486 Mdot
.79802 .56486 Mdot
.79803 .56485 Mdot
.79804 .56484 Mdot
.79805 .56483 Mdot
.79806 .56482 Mdot
.79807 .56481 Mdot
.79808 .56481 Mdot
.79809 .5648 Mdot
.7981 .56479 Mdot
.7981 .56478 Mdot
.79811 .56477 Mdot
.79812 .56476 Mdot
.79813 .56476 Mdot
.79814 .56475 Mdot
.79815 .56474 Mdot
.79816 .56473 Mdot
.79817 .56472 Mdot
.79818 .56471 Mdot
.79819 .5647 Mdot
.7982 .5647 Mdot
.79821 .56469 Mdot
.79822 .56468 Mdot
.79823 .56467 Mdot
.79824 .56466 Mdot
.79825 .56465 Mdot
.79826 .56465 Mdot
.79827 .56464 Mdot
.79828 .56463 Mdot
.79829 .56462 Mdot
.7983 .56461 Mdot
.7983 .5646 Mdot
.79831 .5646 Mdot
.79832 .56459 Mdot
.79833 .56458 Mdot
.79834 .56457 Mdot
.79835 .56456 Mdot
.79836 .56455 Mdot
.79837 .56454 Mdot
.79838 .56454 Mdot
.79839 .56453 Mdot
.7984 .56452 Mdot
.79841 .56451 Mdot
.79842 .5645 Mdot
.79843 .56449 Mdot
.79844 .56449 Mdot
.79845 .56448 Mdot
.79846 .56447 Mdot
.79847 .56446 Mdot
.79848 .56445 Mdot
.79849 .56444 Mdot
.7985 .56443 Mdot
.7985 .56443 Mdot
.79851 .56442 Mdot
.79852 .56441 Mdot
.79853 .5644 Mdot
.79854 .56439 Mdot
.79855 .56438 Mdot
.79856 .56438 Mdot
.79857 .56437 Mdot
.79858 .56436 Mdot
.79859 .56435 Mdot
.7986 .56434 Mdot
.79861 .56433 Mdot
.79862 .56433 Mdot
.79863 .56432 Mdot
.79864 .56431 Mdot
.79865 .5643 Mdot
.79866 .56429 Mdot
.79867 .56428 Mdot
.79868 .56427 Mdot
.79869 .56427 Mdot
.7987 .56426 Mdot
.7987 .56425 Mdot
.79871 .56424 Mdot
.79872 .56423 Mdot
.79873 .56422 Mdot
.79874 .56422 Mdot
.79875 .56421 Mdot
.79876 .5642 Mdot
.79877 .56419 Mdot
.79878 .56418 Mdot
.79879 .56417 Mdot
.7988 .56416 Mdot
.79881 .56416 Mdot
.79882 .56415 Mdot
.79883 .56414 Mdot
.79884 .56413 Mdot
.79885 .56412 Mdot
.79886 .56411 Mdot
.79887 .5641 Mdot
.79888 .5641 Mdot
.79889 .56409 Mdot
.7989 .56408 Mdot
.7989 .56407 Mdot
.79891 .56406 Mdot
.79892 .56405 Mdot
.79893 .56405 Mdot
.79894 .56404 Mdot
.79895 .56403 Mdot
.79896 .56402 Mdot
.79897 .56401 Mdot
.79898 .564 Mdot
.79899 .56399 Mdot
.799 .56399 Mdot
.79901 .56398 Mdot
.79902 .56397 Mdot
.79903 .56396 Mdot
.79904 .56395 Mdot
.79905 .56394 Mdot
.79906 .56394 Mdot
.79907 .56393 Mdot
.79908 .56392 Mdot
.79909 .56391 Mdot
.7991 .5639 Mdot
.7991 .56389 Mdot
.79911 .56388 Mdot
.79912 .56388 Mdot
.79913 .56387 Mdot
.79914 .56386 Mdot
.79915 .56385 Mdot
.79916 .56384 Mdot
.79917 .56383 Mdot
.79918 .56382 Mdot
.79919 .56382 Mdot
.7992 .56381 Mdot
.79921 .5638 Mdot
.79922 .56379 Mdot
.79923 .56378 Mdot
.79924 .56377 Mdot
.79925 .56377 Mdot
.79926 .56376 Mdot
.79927 .56375 Mdot
.79928 .56374 Mdot
.79929 .56373 Mdot
.7993 .56372 Mdot
.7993 .56371 Mdot
.79931 .56371 Mdot
.79932 .5637 Mdot
.79933 .56369 Mdot
.79934 .56368 Mdot
.79935 .56367 Mdot
.79936 .56366 Mdot
.79937 .56365 Mdot
.79938 .56365 Mdot
.79939 .56364 Mdot
.7994 .56363 Mdot
.79941 .56362 Mdot
.79942 .56361 Mdot
.79943 .5636 Mdot
.79944 .56359 Mdot
.79945 .56359 Mdot
.79946 .56358 Mdot
.79947 .56357 Mdot
.79948 .56356 Mdot
.79949 .56355 Mdot
.7995 .56354 Mdot
.7995 .56354 Mdot
.79951 .56353 Mdot
.79952 .56352 Mdot
.79953 .56351 Mdot
.79954 .5635 Mdot
.79955 .56349 Mdot
.79956 .56348 Mdot
.79957 .56348 Mdot
.79958 .56347 Mdot
.79959 .56346 Mdot
.7996 .56345 Mdot
.79961 .56344 Mdot
.79962 .56343 Mdot
.79963 .56342 Mdot
.79964 .56342 Mdot
.79965 .56341 Mdot
.79966 .5634 Mdot
.79967 .56339 Mdot
.79968 .56338 Mdot
.79969 .56337 Mdot
.7997 .56336 Mdot
.7997 .56336 Mdot
.79971 .56335 Mdot
.79972 .56334 Mdot
.79973 .56333 Mdot
.79974 .56332 Mdot
.79975 .56331 Mdot
.79976 .5633 Mdot
.79977 .5633 Mdot
.79978 .56329 Mdot
.79979 .56328 Mdot
.7998 .56327 Mdot
.79981 .56326 Mdot
.79982 .56325 Mdot
.79983 .56324 Mdot
.79984 .56324 Mdot
.79985 .56323 Mdot
.79986 .56322 Mdot
.79987 .56321 Mdot
.79988 .5632 Mdot
.79989 .56319 Mdot
.7999 .56318 Mdot
.7999 .56318 Mdot
.79991 .56317 Mdot
.79992 .56316 Mdot
.79993 .56315 Mdot
.79994 .56314 Mdot
.79995 .56313 Mdot
.79996 .56312 Mdot
.79997 .56312 Mdot
.79998 .56311 Mdot
.79999 .5631 Mdot
.8 .56309 Mdot
.80001 .56308 Mdot
.80002 .56307 Mdot
.80003 .56306 Mdot
.80004 .56306 Mdot
.80005 .56305 Mdot
.80006 .56304 Mdot
.80007 .56303 Mdot
.80008 .56302 Mdot
.80009 .56301 Mdot
.8001 .563 Mdot
.8001 .563 Mdot
.80011 .56299 Mdot
.80012 .56298 Mdot
.80013 .56297 Mdot
.80014 .56296 Mdot
.80015 .56295 Mdot
.80016 .56294 Mdot
.80017 .56294 Mdot
.80018 .56293 Mdot
.80019 .56292 Mdot
.8002 .56291 Mdot
.80021 .5629 Mdot
.80022 .56289 Mdot
.80023 .56288 Mdot
.80024 .56288 Mdot
.80025 .56287 Mdot
.80026 .56286 Mdot
.80027 .56285 Mdot
.80028 .56284 Mdot
.80029 .56283 Mdot
.8003 .56282 Mdot
.8003 .56282 Mdot
.80031 .56281 Mdot
.80032 .5628 Mdot
.80033 .56279 Mdot
.80034 .56278 Mdot
.80035 .56277 Mdot
.80036 .56276 Mdot
.80037 .56276 Mdot
.80038 .56275 Mdot
.80039 .56274 Mdot
.8004 .56273 Mdot
.80041 .56272 Mdot
.80042 .56271 Mdot
.80043 .5627 Mdot
.80044 .5627 Mdot
.80045 .56269 Mdot
.80046 .56268 Mdot
.80047 .56267 Mdot
.80048 .56266 Mdot
.80049 .56265 Mdot
.8005 .56264 Mdot
.8005 .56264 Mdot
.80051 .56263 Mdot
.80052 .56262 Mdot
.80053 .56261 Mdot
.80054 .5626 Mdot
.80055 .56259 Mdot
.80056 .56258 Mdot
.80057 .56257 Mdot
.80058 .56257 Mdot
.80059 .56256 Mdot
.8006 .56255 Mdot
.80061 .56254 Mdot
.80062 .56253 Mdot
.80063 .56252 Mdot
.80064 .56251 Mdot
.80065 .56251 Mdot
.80066 .5625 Mdot
.80067 .56249 Mdot
.80068 .56248 Mdot
.80069 .56247 Mdot
.8007 .56246 Mdot
.8007 .56245 Mdot
.80071 .56245 Mdot
.80072 .56244 Mdot
.80073 .56243 Mdot
.80074 .56242 Mdot
.80075 .56241 Mdot
.80076 .5624 Mdot
.80077 .56239 Mdot
.80078 .56238 Mdot
.80079 .56238 Mdot
.8008 .56237 Mdot
.80081 .56236 Mdot
.80082 .56235 Mdot
.80083 .56234 Mdot
.80084 .56233 Mdot
.80085 .56232 Mdot
.80086 .56232 Mdot
.80087 .56231 Mdot
.80088 .5623 Mdot
.80089 .56229 Mdot
.8009 .56228 Mdot
.8009 .56227 Mdot
.80091 .56226 Mdot
.80092 .56226 Mdot
.80093 .56225 Mdot
.80094 .56224 Mdot
.80095 .56223 Mdot
.80096 .56222 Mdot
.80097 .56221 Mdot
.80098 .5622 Mdot
.80099 .56219 Mdot
.801 .56219 Mdot
.80101 .56218 Mdot
.80102 .56217 Mdot
.80103 .56216 Mdot
.80104 .56215 Mdot
.80105 .56214 Mdot
.80106 .56213 Mdot
.80107 .56213 Mdot
.80108 .56212 Mdot
.80109 .56211 Mdot
.8011 .5621 Mdot
.8011 .56209 Mdot
.80111 .56208 Mdot
.80112 .56207 Mdot
.80113 .56206 Mdot
.80114 .56206 Mdot
.80115 .56205 Mdot
.80116 .56204 Mdot
.80117 .56203 Mdot
.80118 .56202 Mdot
.80119 .56201 Mdot
.8012 .562 Mdot
.80121 .562 Mdot
.80122 .56199 Mdot
.80123 .56198 Mdot
.80124 .56197 Mdot
.80125 .56196 Mdot
.80126 .56195 Mdot
.80127 .56194 Mdot
.80128 .56193 Mdot
.80129 .56193 Mdot
.8013 .56192 Mdot
.8013 .56191 Mdot
.80131 .5619 Mdot
.80132 .56189 Mdot
.80133 .56188 Mdot
.80134 .56187 Mdot
.80135 .56187 Mdot
.80136 .56186 Mdot
.80137 .56185 Mdot
.80138 .56184 Mdot
.80139 .56183 Mdot
.8014 .56182 Mdot
.80141 .56181 Mdot
.80142 .5618 Mdot
.80143 .5618 Mdot
.80144 .56179 Mdot
.80145 .56178 Mdot
.80146 .56177 Mdot
.80147 .56176 Mdot
.80148 .56175 Mdot
.80149 .56174 Mdot
.8015 .56173 Mdot
.8015 .56173 Mdot
.80151 .56172 Mdot
.80152 .56171 Mdot
.80153 .5617 Mdot
.80154 .56169 Mdot
.80155 .56168 Mdot
.80156 .56167 Mdot
.80157 .56167 Mdot
.80158 .56166 Mdot
.80159 .56165 Mdot
.8016 .56164 Mdot
.80161 .56163 Mdot
.80162 .56162 Mdot
.80163 .56161 Mdot
.80164 .5616 Mdot
.80165 .5616 Mdot
.80166 .56159 Mdot
.80167 .56158 Mdot
.80168 .56157 Mdot
.80169 .56156 Mdot
.8017 .56155 Mdot
.8017 .56154 Mdot
.80171 .56153 Mdot
.80172 .56153 Mdot
.80173 .56152 Mdot
.80174 .56151 Mdot
.80175 .5615 Mdot
.80176 .56149 Mdot
.80177 .56148 Mdot
.80178 .56147 Mdot
.80179 .56146 Mdot
.8018 .56146 Mdot
.80181 .56145 Mdot
.80182 .56144 Mdot
.80183 .56143 Mdot
.80184 .56142 Mdot
.80185 .56141 Mdot
.80186 .5614 Mdot
.80187 .56139 Mdot
.80188 .56139 Mdot
.80189 .56138 Mdot
.8019 .56137 Mdot
.8019 .56136 Mdot
.80191 .56135 Mdot
.80192 .56134 Mdot
.80193 .56133 Mdot
.80194 .56132 Mdot
.80195 .56132 Mdot
.80196 .56131 Mdot
.80197 .5613 Mdot
.80198 .56129 Mdot
.80199 .56128 Mdot
.802 .56127 Mdot
.80201 .56126 Mdot
.80202 .56125 Mdot
.80203 .56125 Mdot
.80204 .56124 Mdot
.80205 .56123 Mdot
.80206 .56122 Mdot
.80207 .56121 Mdot
.80208 .5612 Mdot
.80209 .56119 Mdot
.8021 .56119 Mdot
.8021 .56118 Mdot
.80211 .56117 Mdot
.80212 .56116 Mdot
.80213 .56115 Mdot
.80214 .56114 Mdot
.80215 .56113 Mdot
.80216 .56112 Mdot
.80217 .56111 Mdot
.80218 .56111 Mdot
.80219 .5611 Mdot
.8022 .56109 Mdot
.80221 .56108 Mdot
.80222 .56107 Mdot
.80223 .56106 Mdot
.80224 .56105 Mdot
.80225 .56104 Mdot
.80226 .56104 Mdot
.80227 .56103 Mdot
.80228 .56102 Mdot
.80229 .56101 Mdot
.8023 .561 Mdot
.8023 .56099 Mdot
.80231 .56098 Mdot
.80232 .56097 Mdot
.80233 .56097 Mdot
.80234 .56096 Mdot
.80235 .56095 Mdot
.80236 .56094 Mdot
.80237 .56093 Mdot
.80238 .56092 Mdot
.80239 .56091 Mdot
.8024 .5609 Mdot
.80241 .5609 Mdot
.80242 .56089 Mdot
.80243 .56088 Mdot
.80244 .56087 Mdot
.80245 .56086 Mdot
.80246 .56085 Mdot
.80247 .56084 Mdot
.80248 .56083 Mdot
.80249 .56083 Mdot
.8025 .56082 Mdot
.8025 .56081 Mdot
.80251 .5608 Mdot
.80252 .56079 Mdot
.80253 .56078 Mdot
.80254 .56077 Mdot
.80255 .56076 Mdot
.80256 .56076 Mdot
.80257 .56075 Mdot
.80258 .56074 Mdot
.80259 .56073 Mdot
.8026 .56072 Mdot
.80261 .56071 Mdot
.80262 .5607 Mdot
.80263 .56069 Mdot
.80264 .56068 Mdot
.80265 .56068 Mdot
.80266 .56067 Mdot
.80267 .56066 Mdot
.80268 .56065 Mdot
.80269 .56064 Mdot
.8027 .56063 Mdot
.8027 .56062 Mdot
.80271 .56061 Mdot
.80272 .56061 Mdot
.80273 .5606 Mdot
.80274 .56059 Mdot
.80275 .56058 Mdot
.80276 .56057 Mdot
.80277 .56056 Mdot
.80278 .56055 Mdot
.80279 .56054 Mdot
.8028 .56054 Mdot
.80281 .56053 Mdot
.80282 .56052 Mdot
.80283 .56051 Mdot
.80284 .5605 Mdot
.80285 .56049 Mdot
.80286 .56048 Mdot
.80287 .56047 Mdot
.80288 .56046 Mdot
.80289 .56046 Mdot
.8029 .56045 Mdot
.8029 .56044 Mdot
.80291 .56043 Mdot
.80292 .56042 Mdot
.80293 .56041 Mdot
.80294 .5604 Mdot
.80295 .56039 Mdot
.80296 .56039 Mdot
.80297 .56038 Mdot
.80298 .56037 Mdot
.80299 .56036 Mdot
.803 .56035 Mdot
.80301 .56034 Mdot
.80302 .56033 Mdot
.80303 .56032 Mdot
.80304 .56031 Mdot
.80305 .56031 Mdot
.80306 .5603 Mdot
.80307 .56029 Mdot
.80308 .56028 Mdot
.80309 .56027 Mdot
.8031 .56026 Mdot
.8031 .56025 Mdot
.80311 .56024 Mdot
.80312 .56024 Mdot
.80313 .56023 Mdot
.80314 .56022 Mdot
.80315 .56021 Mdot
.80316 .5602 Mdot
.80317 .56019 Mdot
.80318 .56018 Mdot
.80319 .56017 Mdot
.8032 .56016 Mdot
.80321 .56016 Mdot
.80322 .56015 Mdot
.80323 .56014 Mdot
.80324 .56013 Mdot
.80325 .56012 Mdot
.80326 .56011 Mdot
.80327 .5601 Mdot
.80328 .56009 Mdot
.80329 .56008 Mdot
.8033 .56008 Mdot
.8033 .56007 Mdot
.80331 .56006 Mdot
.80332 .56005 Mdot
.80333 .56004 Mdot
.80334 .56003 Mdot
.80335 .56002 Mdot
.80336 .56001 Mdot
.80337 .56001 Mdot
.80338 .56 Mdot
.80339 .55999 Mdot
.8034 .55998 Mdot
.80341 .55997 Mdot
.80342 .55996 Mdot
.80343 .55995 Mdot
.80344 .55994 Mdot
.80345 .55993 Mdot
.80346 .55993 Mdot
.80347 .55992 Mdot
.80348 .55991 Mdot
.80349 .5599 Mdot
.8035 .55989 Mdot
.8035 .55988 Mdot
.80351 .55987 Mdot
.80352 .55986 Mdot
.80353 .55985 Mdot
.80354 .55985 Mdot
.80355 .55984 Mdot
.80356 .55983 Mdot
.80357 .55982 Mdot
.80358 .55981 Mdot
.80359 .5598 Mdot
.8036 .55979 Mdot
.80361 .55978 Mdot
.80362 .55977 Mdot
.80363 .55977 Mdot
.80364 .55976 Mdot
.80365 .55975 Mdot
.80366 .55974 Mdot
.80367 .55973 Mdot
.80368 .55972 Mdot
.80369 .55971 Mdot
.8037 .5597 Mdot
.8037 .55969 Mdot
.80371 .55969 Mdot
.80372 .55968 Mdot
.80373 .55967 Mdot
.80374 .55966 Mdot
.80375 .55965 Mdot
.80376 .55964 Mdot
.80377 .55963 Mdot
.80378 .55962 Mdot
.80379 .55961 Mdot
.8038 .55961 Mdot
.80381 .5596 Mdot
.80382 .55959 Mdot
.80383 .55958 Mdot
.80384 .55957 Mdot
.80385 .55956 Mdot
.80386 .55955 Mdot
.80387 .55954 Mdot
.80388 .55953 Mdot
.80389 .55953 Mdot
.8039 .55952 Mdot
.8039 .55951 Mdot
.80391 .5595 Mdot
.80392 .55949 Mdot
.80393 .55948 Mdot
.80394 .55947 Mdot
.80395 .55946 Mdot
.80396 .55945 Mdot
.80397 .55945 Mdot
.80398 .55944 Mdot
.80399 .55943 Mdot
.804 .55942 Mdot
.80401 .55941 Mdot
.80402 .5594 Mdot
.80403 .55939 Mdot
.80404 .55938 Mdot
.80405 .55937 Mdot
.80406 .55937 Mdot
.80407 .55936 Mdot
.80408 .55935 Mdot
.80409 .55934 Mdot
.8041 .55933 Mdot
.8041 .55932 Mdot
.80411 .55931 Mdot
.80412 .5593 Mdot
.80413 .55929 Mdot
.80414 .55928 Mdot
.80415 .55928 Mdot
.80416 .55927 Mdot
.80417 .55926 Mdot
.80418 .55925 Mdot
.80419 .55924 Mdot
.8042 .55923 Mdot
.80421 .55922 Mdot
.80422 .55921 Mdot
.80423 .5592 Mdot
.80424 .5592 Mdot
.80425 .55919 Mdot
.80426 .55918 Mdot
.80427 .55917 Mdot
.80428 .55916 Mdot
.80429 .55915 Mdot
.8043 .55914 Mdot
.8043 .55913 Mdot
.80431 .55912 Mdot
.80432 .55912 Mdot
.80433 .55911 Mdot
.80434 .5591 Mdot
.80435 .55909 Mdot
.80436 .55908 Mdot
.80437 .55907 Mdot
.80438 .55906 Mdot
.80439 .55905 Mdot
.8044 .55904 Mdot
.80441 .55903 Mdot
.80442 .55903 Mdot
.80443 .55902 Mdot
.80444 .55901 Mdot
.80445 .559 Mdot
.80446 .55899 Mdot
.80447 .55898 Mdot
.80448 .55897 Mdot
.80449 .55896 Mdot
.8045 .55895 Mdot
.8045 .55895 Mdot
.80451 .55894 Mdot
.80452 .55893 Mdot
.80453 .55892 Mdot
.80454 .55891 Mdot
.80455 .5589 Mdot
.80456 .55889 Mdot
.80457 .55888 Mdot
.80458 .55887 Mdot
.80459 .55886 Mdot
.8046 .55886 Mdot
.80461 .55885 Mdot
.80462 .55884 Mdot
.80463 .55883 Mdot
.80464 .55882 Mdot
.80465 .55881 Mdot
.80466 .5588 Mdot
.80467 .55879 Mdot
.80468 .55878 Mdot
.80469 .55878 Mdot
.8047 .55877 Mdot
.8047 .55876 Mdot
.80471 .55875 Mdot
.80472 .55874 Mdot
.80473 .55873 Mdot
.80474 .55872 Mdot
.80475 .55871 Mdot
.80476 .5587 Mdot
.80477 .55869 Mdot
.80478 .55869 Mdot
.80479 .55868 Mdot
.8048 .55867 Mdot
.80481 .55866 Mdot
.80482 .55865 Mdot
.80483 .55864 Mdot
.80484 .55863 Mdot
.80485 .55862 Mdot
.80486 .55861 Mdot
.80487 .5586 Mdot
.80488 .5586 Mdot
.80489 .55859 Mdot
.8049 .55858 Mdot
.8049 .55857 Mdot
.80491 .55856 Mdot
.80492 .55855 Mdot
.80493 .55854 Mdot
.80494 .55853 Mdot
.80495 .55852 Mdot
.80496 .55851 Mdot
.80497 .55851 Mdot
.80498 .5585 Mdot
.80499 .55849 Mdot
.805 .55848 Mdot
.80501 .55847 Mdot
.80502 .55846 Mdot
.80503 .55845 Mdot
.80504 .55844 Mdot
.80505 .55843 Mdot
.80506 .55842 Mdot
.80507 .55842 Mdot
.80508 .55841 Mdot
.80509 .5584 Mdot
.8051 .55839 Mdot
.8051 .55838 Mdot
.80511 .55837 Mdot
.80512 .55836 Mdot
.80513 .55835 Mdot
.80514 .55834 Mdot
.80515 .55833 Mdot
.80516 .55833 Mdot
.80517 .55832 Mdot
.80518 .55831 Mdot
.80519 .5583 Mdot
.8052 .55829 Mdot
.80521 .55828 Mdot
.80522 .55827 Mdot
.80523 .55826 Mdot
.80524 .55825 Mdot
.80525 .55824 Mdot
.80526 .55824 Mdot
.80527 .55823 Mdot
.80528 .55822 Mdot
.80529 .55821 Mdot
.8053 .5582 Mdot
.8053 .55819 Mdot
.80531 .55818 Mdot
.80532 .55817 Mdot
.80533 .55816 Mdot
.80534 .55815 Mdot
.80535 .55815 Mdot
.80536 .55814 Mdot
.80537 .55813 Mdot
.80538 .55812 Mdot
.80539 .55811 Mdot
.8054 .5581 Mdot
.80541 .55809 Mdot
.80542 .55808 Mdot
.80543 .55807 Mdot
.80544 .55806 Mdot
.80545 .55805 Mdot
.80546 .55805 Mdot
.80547 .55804 Mdot
.80548 .55803 Mdot
.80549 .55802 Mdot
.8055 .55801 Mdot
.8055 .558 Mdot
.80551 .55799 Mdot
.80552 .55798 Mdot
.80553 .55797 Mdot
.80554 .55796 Mdot
.80555 .55796 Mdot
.80556 .55795 Mdot
.80557 .55794 Mdot
.80558 .55793 Mdot
.80559 .55792 Mdot
.8056 .55791 Mdot
.80561 .5579 Mdot
.80562 .55789 Mdot
.80563 .55788 Mdot
.80564 .55787 Mdot
.80565 .55787 Mdot
.80566 .55786 Mdot
.80567 .55785 Mdot
.80568 .55784 Mdot
.80569 .55783 Mdot
.8057 .55782 Mdot
.8057 .55781 Mdot
.80571 .5578 Mdot
.80572 .55779 Mdot
.80573 .55778 Mdot
.80574 .55777 Mdot
.80575 .55777 Mdot
.80576 .55776 Mdot
.80577 .55775 Mdot
.80578 .55774 Mdot
.80579 .55773 Mdot
.8058 .55772 Mdot
.80581 .55771 Mdot
.80582 .5577 Mdot
.80583 .55769 Mdot
.80584 .55768 Mdot
.80585 .55767 Mdot
.80586 .55767 Mdot
.80587 .55766 Mdot
.80588 .55765 Mdot
.80589 .55764 Mdot
.8059 .55763 Mdot
.8059 .55762 Mdot
.80591 .55761 Mdot
.80592 .5576 Mdot
.80593 .55759 Mdot
.80594 .55758 Mdot
.80595 .55758 Mdot
.80596 .55757 Mdot
.80597 .55756 Mdot
.80598 .55755 Mdot
.80599 .55754 Mdot
.806 .55753 Mdot
.80601 .55752 Mdot
.80602 .55751 Mdot
.80603 .5575 Mdot
.80604 .55749 Mdot
.80605 .55748 Mdot
.80606 .55748 Mdot
.80607 .55747 Mdot
.80608 .55746 Mdot
.80609 .55745 Mdot
.8061 .55744 Mdot
.8061 .55743 Mdot
.80611 .55742 Mdot
.80612 .55741 Mdot
.80613 .5574 Mdot
.80614 .55739 Mdot
.80615 .55738 Mdot
.80616 .55738 Mdot
.80617 .55737 Mdot
.80618 .55736 Mdot
.80619 .55735 Mdot
.8062 .55734 Mdot
.80621 .55733 Mdot
.80622 .55732 Mdot
.80623 .55731 Mdot
.80624 .5573 Mdot
.80625 .55729 Mdot
.80626 .55728 Mdot
.80627 .55728 Mdot
.80628 .55727 Mdot
.80629 .55726 Mdot
.8063 .55725 Mdot
.8063 .55724 Mdot
.80631 .55723 Mdot
.80632 .55722 Mdot
.80633 .55721 Mdot
.80634 .5572 Mdot
.80635 .55719 Mdot
.80636 .55718 Mdot
.80637 .55718 Mdot
.80638 .55717 Mdot
.80639 .55716 Mdot
.8064 .55715 Mdot
.80641 .55714 Mdot
.80642 .55713 Mdot
.80643 .55712 Mdot
.80644 .55711 Mdot
.80645 .5571 Mdot
.80646 .55709 Mdot
.80647 .55708 Mdot
.80648 .55707 Mdot
.80649 .55707 Mdot
.8065 .55706 Mdot
.8065 .55705 Mdot
.80651 .55704 Mdot
.80652 .55703 Mdot
.80653 .55702 Mdot
.80654 .55701 Mdot
.80655 .557 Mdot
.80656 .55699 Mdot
.80657 .55698 Mdot
.80658 .55697 Mdot
.80659 .55697 Mdot
.8066 .55696 Mdot
.80661 .55695 Mdot
.80662 .55694 Mdot
.80663 .55693 Mdot
.80664 .55692 Mdot
.80665 .55691 Mdot
.80666 .5569 Mdot
.80667 .55689 Mdot
.80668 .55688 Mdot
.80669 .55687 Mdot
.8067 .55686 Mdot
.8067 .55686 Mdot
.80671 .55685 Mdot
.80672 .55684 Mdot
.80673 .55683 Mdot
.80674 .55682 Mdot
.80675 .55681 Mdot
.80676 .5568 Mdot
.80677 .55679 Mdot
.80678 .55678 Mdot
.80679 .55677 Mdot
.8068 .55676 Mdot
.80681 .55676 Mdot
.80682 .55675 Mdot
.80683 .55674 Mdot
.80684 .55673 Mdot
.80685 .55672 Mdot
.80686 .55671 Mdot
.80687 .5567 Mdot
.80688 .55669 Mdot
.80689 .55668 Mdot
.8069 .55667 Mdot
.8069 .55666 Mdot
.80691 .55665 Mdot
.80692 .55665 Mdot
.80693 .55664 Mdot
.80694 .55663 Mdot
.80695 .55662 Mdot
.80696 .55661 Mdot
.80697 .5566 Mdot
.80698 .55659 Mdot
.80699 .55658 Mdot
.807 .55657 Mdot
.80701 .55656 Mdot
.80702 .55655 Mdot
.80703 .55654 Mdot
.80704 .55654 Mdot
.80705 .55653 Mdot
.80706 .55652 Mdot
.80707 .55651 Mdot
.80708 .5565 Mdot
.80709 .55649 Mdot
.8071 .55648 Mdot
.8071 .55647 Mdot
.80711 .55646 Mdot
.80712 .55645 Mdot
.80713 .55644 Mdot
.80714 .55643 Mdot
.80715 .55643 Mdot
.80716 .55642 Mdot
.80717 .55641 Mdot
.80718 .5564 Mdot
.80719 .55639 Mdot
.8072 .55638 Mdot
.80721 .55637 Mdot
.80722 .55636 Mdot
.80723 .55635 Mdot
.80724 .55634 Mdot
.80725 .55633 Mdot
.80726 .55632 Mdot
.80727 .55632 Mdot
.80728 .55631 Mdot
.80729 .5563 Mdot
.8073 .55629 Mdot
.8073 .55628 Mdot
.80731 .55627 Mdot
.80732 .55626 Mdot
.80733 .55625 Mdot
.80734 .55624 Mdot
.80735 .55623 Mdot
.80736 .55622 Mdot
.80737 .55621 Mdot
.80738 .5562 Mdot
.80739 .5562 Mdot
.8074 .55619 Mdot
.80741 .55618 Mdot
.80742 .55617 Mdot
.80743 .55616 Mdot
.80744 .55615 Mdot
.80745 .55614 Mdot
.80746 .55613 Mdot
.80747 .55612 Mdot
.80748 .55611 Mdot
.80749 .5561 Mdot
.8075 .55609 Mdot
.8075 .55609 Mdot
.80751 .55608 Mdot
.80752 .55607 Mdot
.80753 .55606 Mdot
.80754 .55605 Mdot
.80755 .55604 Mdot
.80756 .55603 Mdot
.80757 .55602 Mdot
.80758 .55601 Mdot
.80759 .556 Mdot
.8076 .55599 Mdot
.80761 .55598 Mdot
.80762 .55597 Mdot
.80763 .55597 Mdot
.80764 .55596 Mdot
.80765 .55595 Mdot
.80766 .55594 Mdot
.80767 .55593 Mdot
.80768 .55592 Mdot
.80769 .55591 Mdot
.8077 .5559 Mdot
.8077 .55589 Mdot
.80771 .55588 Mdot
.80772 .55587 Mdot
.80773 .55586 Mdot
.80774 .55586 Mdot
.80775 .55585 Mdot
.80776 .55584 Mdot
.80777 .55583 Mdot
.80778 .55582 Mdot
.80779 .55581 Mdot
.8078 .5558 Mdot
.80781 .55579 Mdot
.80782 .55578 Mdot
.80783 .55577 Mdot
.80784 .55576 Mdot
.80785 .55575 Mdot
.80786 .55574 Mdot
.80787 .55574 Mdot
.80788 .55573 Mdot
.80789 .55572 Mdot
.8079 .55571 Mdot
.8079 .5557 Mdot
.80791 .55569 Mdot
.80792 .55568 Mdot
.80793 .55567 Mdot
.80794 .55566 Mdot
.80795 .55565 Mdot
.80796 .55564 Mdot
.80797 .55563 Mdot
.80798 .55562 Mdot
.80799 .55562 Mdot
.808 .55561 Mdot
.80801 .5556 Mdot
.80802 .55559 Mdot
.80803 .55558 Mdot
.80804 .55557 Mdot
.80805 .55556 Mdot
.80806 .55555 Mdot
.80807 .55554 Mdot
.80808 .55553 Mdot
.80809 .55552 Mdot
.8081 .55551 Mdot
.8081 .5555 Mdot
.80811 .55549 Mdot
.80812 .55549 Mdot
.80813 .55548 Mdot
.80814 .55547 Mdot
.80815 .55546 Mdot
.80816 .55545 Mdot
.80817 .55544 Mdot
.80818 .55543 Mdot
.80819 .55542 Mdot
.8082 .55541 Mdot
.80821 .5554 Mdot
.80822 .55539 Mdot
.80823 .55538 Mdot
.80824 .55537 Mdot
.80825 .55537 Mdot
.80826 .55536 Mdot
.80827 .55535 Mdot
.80828 .55534 Mdot
.80829 .55533 Mdot
.8083 .55532 Mdot
.8083 .55531 Mdot
.80831 .5553 Mdot
.80832 .55529 Mdot
.80833 .55528 Mdot
.80834 .55527 Mdot
.80835 .55526 Mdot
.80836 .55525 Mdot
.80837 .55524 Mdot
.80838 .55524 Mdot
.80839 .55523 Mdot
.8084 .55522 Mdot
.80841 .55521 Mdot
.80842 .5552 Mdot
.80843 .55519 Mdot
.80844 .55518 Mdot
.80845 .55517 Mdot
.80846 .55516 Mdot
.80847 .55515 Mdot
.80848 .55514 Mdot
.80849 .55513 Mdot
.8085 .55512 Mdot
.8085 .55511 Mdot
.80851 .55511 Mdot
.80852 .5551 Mdot
.80853 .55509 Mdot
.80854 .55508 Mdot
.80855 .55507 Mdot
.80856 .55506 Mdot
.80857 .55505 Mdot
.80858 .55504 Mdot
.80859 .55503 Mdot
.8086 .55502 Mdot
.80861 .55501 Mdot
.80862 .555 Mdot
.80863 .55499 Mdot
.80864 .55498 Mdot
.80865 .55498 Mdot
.80866 .55497 Mdot
.80867 .55496 Mdot
.80868 .55495 Mdot
.80869 .55494 Mdot
.8087 .55493 Mdot
.8087 .55492 Mdot
.80871 .55491 Mdot
.80872 .5549 Mdot
.80873 .55489 Mdot
.80874 .55488 Mdot
.80875 .55487 Mdot
.80876 .55486 Mdot
.80877 .55485 Mdot
.80878 .55485 Mdot
.80879 .55484 Mdot
.8088 .55483 Mdot
.80881 .55482 Mdot
.80882 .55481 Mdot
.80883 .5548 Mdot
.80884 .55479 Mdot
.80885 .55478 Mdot
.80886 .55477 Mdot
.80887 .55476 Mdot
.80888 .55475 Mdot
.80889 .55474 Mdot
.8089 .55473 Mdot
.8089 .55472 Mdot
.80891 .55471 Mdot
.80892 .55471 Mdot
.80893 .5547 Mdot
.80894 .55469 Mdot
.80895 .55468 Mdot
.80896 .55467 Mdot
.80897 .55466 Mdot
.80898 .55465 Mdot
.80899 .55464 Mdot
.809 .55463 Mdot
.80901 .55462 Mdot
.80902 .55461 Mdot
.80903 .5546 Mdot
.80904 .55459 Mdot
.80905 .55458 Mdot
.80906 .55457 Mdot
.80907 .55457 Mdot
.80908 .55456 Mdot
.80909 .55455 Mdot
.8091 .55454 Mdot
.8091 .55453 Mdot
.80911 .55452 Mdot
.80912 .55451 Mdot
.80913 .5545 Mdot
.80914 .55449 Mdot
.80915 .55448 Mdot
.80916 .55447 Mdot
.80917 .55446 Mdot
.80918 .55445 Mdot
.80919 .55444 Mdot
.8092 .55443 Mdot
.80921 .55443 Mdot
.80922 .55442 Mdot
.80923 .55441 Mdot
.80924 .5544 Mdot
.80925 .55439 Mdot
.80926 .55438 Mdot
.80927 .55437 Mdot
.80928 .55436 Mdot
.80929 .55435 Mdot
.8093 .55434 Mdot
.8093 .55433 Mdot
.80931 .55432 Mdot
.80932 .55431 Mdot
.80933 .5543 Mdot
.80934 .55429 Mdot
.80935 .55429 Mdot
.80936 .55428 Mdot
.80937 .55427 Mdot
.80938 .55426 Mdot
.80939 .55425 Mdot
.8094 .55424 Mdot
.80941 .55423 Mdot
.80942 .55422 Mdot
.80943 .55421 Mdot
.80944 .5542 Mdot
.80945 .55419 Mdot
.80946 .55418 Mdot
.80947 .55417 Mdot
.80948 .55416 Mdot
.80949 .55415 Mdot
.8095 .55414 Mdot
.8095 .55414 Mdot
.80951 .55413 Mdot
.80952 .55412 Mdot
.80953 .55411 Mdot
.80954 .5541 Mdot
.80955 .55409 Mdot
.80956 .55408 Mdot
.80957 .55407 Mdot
.80958 .55406 Mdot
.80959 .55405 Mdot
.8096 .55404 Mdot
.80961 .55403 Mdot
.80962 .55402 Mdot
.80963 .55401 Mdot
.80964 .554 Mdot
.80965 .55399 Mdot
.80966 .55399 Mdot
.80967 .55398 Mdot
.80968 .55397 Mdot
.80969 .55396 Mdot
.8097 .55395 Mdot
.8097 .55394 Mdot
.80971 .55393 Mdot
.80972 .55392 Mdot
.80973 .55391 Mdot
.80974 .5539 Mdot
.80975 .55389 Mdot
.80976 .55388 Mdot
.80977 .55387 Mdot
.80978 .55386 Mdot
.80979 .55385 Mdot
.8098 .55384 Mdot
.80981 .55384 Mdot
.80982 .55383 Mdot
.80983 .55382 Mdot
.80984 .55381 Mdot
.80985 .5538 Mdot
.80986 .55379 Mdot
.80987 .55378 Mdot
.80988 .55377 Mdot
.80989 .55376 Mdot
.8099 .55375 Mdot
.8099 .55374 Mdot
.80991 .55373 Mdot
.80992 .55372 Mdot
.80993 .55371 Mdot
.80994 .5537 Mdot
.80995 .55369 Mdot
.80996 .55368 Mdot
.80997 .55368 Mdot
.80998 .55367 Mdot
.80999 .55366 Mdot
.81 .55365 Mdot
.81001 .55364 Mdot
.81002 .55363 Mdot
.81003 .55362 Mdot
.81004 .55361 Mdot
.81005 .5536 Mdot
.81006 .55359 Mdot
.81007 .55358 Mdot
.81008 .55357 Mdot
.81009 .55356 Mdot
.8101 .55355 Mdot
.8101 .55354 Mdot
.81011 .55353 Mdot
.81012 .55352 Mdot
.81013 .55352 Mdot
.81014 .55351 Mdot
.81015 .5535 Mdot
.81016 .55349 Mdot
.81017 .55348 Mdot
.81018 .55347 Mdot
.81019 .55346 Mdot
.8102 .55345 Mdot
.81021 .55344 Mdot
.81022 .55343 Mdot
.81023 .55342 Mdot
.81024 .55341 Mdot
.81025 .5534 Mdot
.81026 .55339 Mdot
.81027 .55338 Mdot
.81028 .55337 Mdot
.81029 .55336 Mdot
.8103 .55336 Mdot
.8103 .55335 Mdot
.81031 .55334 Mdot
.81032 .55333 Mdot
.81033 .55332 Mdot
.81034 .55331 Mdot
.81035 .5533 Mdot
.81036 .55329 Mdot
.81037 .55328 Mdot
.81038 .55327 Mdot
.81039 .55326 Mdot
.8104 .55325 Mdot
.81041 .55324 Mdot
.81042 .55323 Mdot
.81043 .55322 Mdot
.81044 .55321 Mdot
.81045 .5532 Mdot
.81046 .55319 Mdot
.81047 .55319 Mdot
.81048 .55318 Mdot
.81049 .55317 Mdot
.8105 .55316 Mdot
.8105 .55315 Mdot
.81051 .55314 Mdot
.81052 .55313 Mdot
.81053 .55312 Mdot
.81054 .55311 Mdot
.81055 .5531 Mdot
.81056 .55309 Mdot
.81057 .55308 Mdot
.81058 .55307 Mdot
.81059 .55306 Mdot
.8106 .55305 Mdot
.81061 .55304 Mdot
.81062 .55303 Mdot
.81063 .55302 Mdot
.81064 .55302 Mdot
.81065 .55301 Mdot
.81066 .553 Mdot
.81067 .55299 Mdot
.81068 .55298 Mdot
.81069 .55297 Mdot
.8107 .55296 Mdot
.8107 .55295 Mdot
.81071 .55294 Mdot
.81072 .55293 Mdot
.81073 .55292 Mdot
.81074 .55291 Mdot
.81075 .5529 Mdot
.81076 .55289 Mdot
.81077 .55288 Mdot
.81078 .55287 Mdot
.81079 .55286 Mdot
.8108 .55285 Mdot
.81081 .55284 Mdot
.81082 .55284 Mdot
.81083 .55283 Mdot
.81084 .55282 Mdot
.81085 .55281 Mdot
.81086 .5528 Mdot
.81087 .55279 Mdot
.81088 .55278 Mdot
.81089 .55277 Mdot
.8109 .55276 Mdot
.8109 .55275 Mdot
.81091 .55274 Mdot
.81092 .55273 Mdot
.81093 .55272 Mdot
.81094 .55271 Mdot
.81095 .5527 Mdot
.81096 .55269 Mdot
.81097 .55268 Mdot
.81098 .55267 Mdot
.81099 .55266 Mdot
.811 .55266 Mdot
.81101 .55265 Mdot
.81102 .55264 Mdot
.81103 .55263 Mdot
.81104 .55262 Mdot
.81105 .55261 Mdot
.81106 .5526 Mdot
.81107 .55259 Mdot
.81108 .55258 Mdot
.81109 .55257 Mdot
.8111 .55256 Mdot
.8111 .55255 Mdot
.81111 .55254 Mdot
.81112 .55253 Mdot
.81113 .55252 Mdot
.81114 .55251 Mdot
.81115 .5525 Mdot
.81116 .55249 Mdot
.81117 .55248 Mdot
.81118 .55247 Mdot
.81119 .55247 Mdot
.8112 .55246 Mdot
.81121 .55245 Mdot
.81122 .55244 Mdot
.81123 .55243 Mdot
.81124 .55242 Mdot
.81125 .55241 Mdot
.81126 .5524 Mdot
.81127 .55239 Mdot
.81128 .55238 Mdot
.81129 .55237 Mdot
.8113 .55236 Mdot
.8113 .55235 Mdot
.81131 .55234 Mdot
.81132 .55233 Mdot
.81133 .55232 Mdot
.81134 .55231 Mdot
.81135 .5523 Mdot
.81136 .55229 Mdot
.81137 .55228 Mdot
.81138 .55227 Mdot
.81139 .55227 Mdot
.8114 .55226 Mdot
.81141 .55225 Mdot
.81142 .55224 Mdot
.81143 .55223 Mdot
.81144 .55222 Mdot
.81145 .55221 Mdot
.81146 .5522 Mdot
.81147 .55219 Mdot
.81148 .55218 Mdot
.81149 .55217 Mdot
.8115 .55216 Mdot
.8115 .55215 Mdot
.81151 .55214 Mdot
.81152 .55213 Mdot
.81153 .55212 Mdot
.81154 .55211 Mdot
.81155 .5521 Mdot
.81156 .55209 Mdot
.81157 .55208 Mdot
.81158 .55207 Mdot
.81159 .55207 Mdot
.8116 .55206 Mdot
.81161 .55205 Mdot
.81162 .55204 Mdot
.81163 .55203 Mdot
.81164 .55202 Mdot
.81165 .55201 Mdot
.81166 .552 Mdot
.81167 .55199 Mdot
.81168 .55198 Mdot
.81169 .55197 Mdot
.8117 .55196 Mdot
.8117 .55195 Mdot
.81171 .55194 Mdot
.81172 .55193 Mdot
.81173 .55192 Mdot
.81174 .55191 Mdot
.81175 .5519 Mdot
.81176 .55189 Mdot
.81177 .55188 Mdot
.81178 .55187 Mdot
.81179 .55186 Mdot
.8118 .55186 Mdot
.81181 .55185 Mdot
.81182 .55184 Mdot
.81183 .55183 Mdot
.81184 .55182 Mdot
.81185 .55181 Mdot
.81186 .5518 Mdot
.81187 .55179 Mdot
.81188 .55178 Mdot
.81189 .55177 Mdot
.8119 .55176 Mdot
.8119 .55175 Mdot
.81191 .55174 Mdot
.81192 .55173 Mdot
.81193 .55172 Mdot
.81194 .55171 Mdot
.81195 .5517 Mdot
.81196 .55169 Mdot
.81197 .55168 Mdot
.81198 .55167 Mdot
.81199 .55166 Mdot
.812 .55165 Mdot
.81201 .55164 Mdot
.81202 .55164 Mdot
.81203 .55163 Mdot
.81204 .55162 Mdot
.81205 .55161 Mdot
.81206 .5516 Mdot
.81207 .55159 Mdot
.81208 .55158 Mdot
.81209 .55157 Mdot
.8121 .55156 Mdot
.8121 .55155 Mdot
.81211 .55154 Mdot
.81212 .55153 Mdot
.81213 .55152 Mdot
.81214 .55151 Mdot
.81215 .5515 Mdot
.81216 .55149 Mdot
.81217 .55148 Mdot
.81218 .55147 Mdot
.81219 .55146 Mdot
.8122 .55145 Mdot
.81221 .55144 Mdot
.81222 .55143 Mdot
.81223 .55142 Mdot
.81224 .55141 Mdot
.81225 .55141 Mdot
.81226 .5514 Mdot
.81227 .55139 Mdot
.81228 .55138 Mdot
.81229 .55137 Mdot
.8123 .55136 Mdot
.8123 .55135 Mdot
.81231 .55134 Mdot
.81232 .55133 Mdot
.81233 .55132 Mdot
.81234 .55131 Mdot
.81235 .5513 Mdot
.81236 .55129 Mdot
.81237 .55128 Mdot
.81238 .55127 Mdot
.81239 .55126 Mdot
.8124 .55125 Mdot
.81241 .55124 Mdot
.81242 .55123 Mdot
.81243 .55122 Mdot
.81244 .55121 Mdot
.81245 .5512 Mdot
.81246 .55119 Mdot
.81247 .55118 Mdot
.81248 .55117 Mdot
.81249 .55117 Mdot
.8125 .55116 Mdot
.8125 .55115 Mdot
.81251 .55114 Mdot
.81252 .55113 Mdot
.81253 .55112 Mdot
.81254 .55111 Mdot
.81255 .5511 Mdot
.81256 .55109 Mdot
.81257 .55108 Mdot
.81258 .55107 Mdot
.81259 .55106 Mdot
.8126 .55105 Mdot
.81261 .55104 Mdot
.81262 .55103 Mdot
.81263 .55102 Mdot
.81264 .55101 Mdot
.81265 .551 Mdot
.81266 .55099 Mdot
.81267 .55098 Mdot
.81268 .55097 Mdot
.81269 .55096 Mdot
.8127 .55095 Mdot
.8127 .55094 Mdot
.81271 .55093 Mdot
.81272 .55092 Mdot
.81273 .55092 Mdot
.81274 .55091 Mdot
.81275 .5509 Mdot
.81276 .55089 Mdot
.81277 .55088 Mdot
.81278 .55087 Mdot
.81279 .55086 Mdot
.8128 .55085 Mdot
.81281 .55084 Mdot
.81282 .55083 Mdot
.81283 .55082 Mdot
.81284 .55081 Mdot
.81285 .5508 Mdot
.81286 .55079 Mdot
.81287 .55078 Mdot
.81288 .55077 Mdot
.81289 .55076 Mdot
.8129 .55075 Mdot
.8129 .55074 Mdot
.81291 .55073 Mdot
.81292 .55072 Mdot
.81293 .55071 Mdot
.81294 .5507 Mdot
.81295 .55069 Mdot
.81296 .55068 Mdot
.81297 .55067 Mdot
.81298 .55066 Mdot
.81299 .55065 Mdot
.813 .55065 Mdot
.81301 .55064 Mdot
.81302 .55063 Mdot
.81303 .55062 Mdot
.81304 .55061 Mdot
.81305 .5506 Mdot
.81306 .55059 Mdot
.81307 .55058 Mdot
.81308 .55057 Mdot
.81309 .55056 Mdot
.8131 .55055 Mdot
.8131 .55054 Mdot
.81311 .55053 Mdot
.81312 .55052 Mdot
.81313 .55051 Mdot
.81314 .5505 Mdot
.81315 .55049 Mdot
.81316 .55048 Mdot
.81317 .55047 Mdot
.81318 .55046 Mdot
.81319 .55045 Mdot
.8132 .55044 Mdot
.81321 .55043 Mdot
.81322 .55042 Mdot
.81323 .55041 Mdot
.81324 .5504 Mdot
.81325 .55039 Mdot
.81326 .55038 Mdot
.81327 .55037 Mdot
.81328 .55037 Mdot
.81329 .55036 Mdot
.8133 .55035 Mdot
.8133 .55034 Mdot
.81331 .55033 Mdot
.81332 .55032 Mdot
.81333 .55031 Mdot
.81334 .5503 Mdot
.81335 .55029 Mdot
.81336 .55028 Mdot
.81337 .55027 Mdot
.81338 .55026 Mdot
.81339 .55025 Mdot
.8134 .55024 Mdot
.81341 .55023 Mdot
.81342 .55022 Mdot
.81343 .55021 Mdot
.81344 .5502 Mdot
.81345 .55019 Mdot
.81346 .55018 Mdot
.81347 .55017 Mdot
.81348 .55016 Mdot
.81349 .55015 Mdot
.8135 .55014 Mdot
.8135 .55013 Mdot
.81351 .55012 Mdot
.81352 .55011 Mdot
.81353 .5501 Mdot
.81354 .55009 Mdot
.81355 .55008 Mdot
.81356 .55007 Mdot
.81357 .55006 Mdot
.81358 .55006 Mdot
.81359 .55005 Mdot
.8136 .55004 Mdot
.81361 .55003 Mdot
.81362 .55002 Mdot
.81363 .55001 Mdot
.81364 .55 Mdot
.81365 .54999 Mdot
.81366 .54998 Mdot
.81367 .54997 Mdot
.81368 .54996 Mdot
.81369 .54995 Mdot
.8137 .54994 Mdot
.8137 .54993 Mdot
.81371 .54992 Mdot
.81372 .54991 Mdot
.81373 .5499 Mdot
.81374 .54989 Mdot
.81375 .54988 Mdot
.81376 .54987 Mdot
.81377 .54986 Mdot
.81378 .54985 Mdot
.81379 .54984 Mdot
.8138 .54983 Mdot
.81381 .54982 Mdot
.81382 .54981 Mdot
.81383 .5498 Mdot
.81384 .54979 Mdot
.81385 .54978 Mdot
.81386 .54977 Mdot
.81387 .54976 Mdot
.81388 .54975 Mdot
.81389 .54974 Mdot
.8139 .54973 Mdot
.8139 .54973 Mdot
.81391 .54972 Mdot
.81392 .54971 Mdot
.81393 .5497 Mdot
.81394 .54969 Mdot
.81395 .54968 Mdot
.81396 .54967 Mdot
.81397 .54966 Mdot
.81398 .54965 Mdot
.81399 .54964 Mdot
.814 .54963 Mdot
.81401 .54962 Mdot
.81402 .54961 Mdot
.81403 .5496 Mdot
.81404 .54959 Mdot
.81405 .54958 Mdot
.81406 .54957 Mdot
.81407 .54956 Mdot
.81408 .54955 Mdot
.81409 .54954 Mdot
.8141 .54953 Mdot
.8141 .54952 Mdot
.81411 .54951 Mdot
.81412 .5495 Mdot
.81413 .54949 Mdot
.81414 .54948 Mdot
.81415 .54947 Mdot
.81416 .54946 Mdot
.81417 .54945 Mdot
.81418 .54944 Mdot
.81419 .54943 Mdot
.8142 .54942 Mdot
.81421 .54941 Mdot
.81422 .5494 Mdot
.81423 .54939 Mdot
.81424 .54938 Mdot
.81425 .54937 Mdot
.81426 .54936 Mdot
.81427 .54935 Mdot
.81428 .54935 Mdot
.81429 .54934 Mdot
.8143 .54933 Mdot
.8143 .54932 Mdot
.81431 .54931 Mdot
.81432 .5493 Mdot
.81433 .54929 Mdot
.81434 .54928 Mdot
.81435 .54927 Mdot
.81436 .54926 Mdot
.81437 .54925 Mdot
.81438 .54924 Mdot
.81439 .54923 Mdot
.8144 .54922 Mdot
.81441 .54921 Mdot
.81442 .5492 Mdot
.81443 .54919 Mdot
.81444 .54918 Mdot
.81445 .54917 Mdot
.81446 .54916 Mdot
.81447 .54915 Mdot
.81448 .54914 Mdot
.81449 .54913 Mdot
.8145 .54912 Mdot
.8145 .54911 Mdot
.81451 .5491 Mdot
.81452 .54909 Mdot
.81453 .54908 Mdot
.81454 .54907 Mdot
.81455 .54906 Mdot
.81456 .54905 Mdot
.81457 .54904 Mdot
.81458 .54903 Mdot
.81459 .54902 Mdot
.8146 .54901 Mdot
.81461 .549 Mdot
.81462 .54899 Mdot
.81463 .54898 Mdot
.81464 .54897 Mdot
.81465 .54896 Mdot
.81466 .54895 Mdot
.81467 .54894 Mdot
.81468 .54893 Mdot
.81469 .54893 Mdot
.8147 .54892 Mdot
.8147 .54891 Mdot
.81471 .5489 Mdot
.81472 .54889 Mdot
.81473 .54888 Mdot
.81474 .54887 Mdot
.81475 .54886 Mdot
.81476 .54885 Mdot
.81477 .54884 Mdot
.81478 .54883 Mdot
.81479 .54882 Mdot
.8148 .54881 Mdot
.81481 .5488 Mdot
.81482 .54879 Mdot
.81483 .54878 Mdot
.81484 .54877 Mdot
.81485 .54876 Mdot
.81486 .54875 Mdot
.81487 .54874 Mdot
.81488 .54873 Mdot
.81489 .54872 Mdot
.8149 .54871 Mdot
.8149 .5487 Mdot
.81491 .54869 Mdot
.81492 .54868 Mdot
.81493 .54867 Mdot
.81494 .54866 Mdot
.81495 .54865 Mdot
.81496 .54864 Mdot
.81497 .54863 Mdot
.81498 .54862 Mdot
.81499 .54861 Mdot
.815 .5486 Mdot
.81501 .54859 Mdot
.81502 .54858 Mdot
.81503 .54857 Mdot
.81504 .54856 Mdot
.81505 .54855 Mdot
.81506 .54854 Mdot
.81507 .54853 Mdot
.81508 .54852 Mdot
.81509 .54851 Mdot
.8151 .5485 Mdot
.8151 .54849 Mdot
.81511 .54848 Mdot
.81512 .54847 Mdot
.81513 .54846 Mdot
.81514 .54845 Mdot
.81515 .54844 Mdot
.81516 .54843 Mdot
.81517 .54843 Mdot
.81518 .54842 Mdot
.81519 .54841 Mdot
.8152 .5484 Mdot
.81521 .54839 Mdot
.81522 .54838 Mdot
.81523 .54837 Mdot
.81524 .54836 Mdot
.81525 .54835 Mdot
.81526 .54834 Mdot
.81527 .54833 Mdot
.81528 .54832 Mdot
.81529 .54831 Mdot
.8153 .5483 Mdot
.8153 .54829 Mdot
.81531 .54828 Mdot
.81532 .54827 Mdot
.81533 .54826 Mdot
.81534 .54825 Mdot
.81535 .54824 Mdot
.81536 .54823 Mdot
.81537 .54822 Mdot
.81538 .54821 Mdot
.81539 .5482 Mdot
.8154 .54819 Mdot
.81541 .54818 Mdot
.81542 .54817 Mdot
.81543 .54816 Mdot
.81544 .54815 Mdot
.81545 .54814 Mdot
.81546 .54813 Mdot
.81547 .54812 Mdot
.81548 .54811 Mdot
.81549 .5481 Mdot
.8155 .54809 Mdot
.8155 .54808 Mdot
.81551 .54807 Mdot
.81552 .54806 Mdot
.81553 .54805 Mdot
.81554 .54804 Mdot
.81555 .54803 Mdot
.81556 .54802 Mdot
.81557 .54801 Mdot
.81558 .548 Mdot
.81559 .54799 Mdot
.8156 .54798 Mdot
.81561 .54797 Mdot
.81562 .54796 Mdot
.81563 .54795 Mdot
.81564 .54794 Mdot
.81565 .54793 Mdot
.81566 .54792 Mdot
.81567 .54791 Mdot
.81568 .5479 Mdot
.81569 .54789 Mdot
.8157 .54788 Mdot
.8157 .54787 Mdot
.81571 .54786 Mdot
.81572 .54785 Mdot
.81573 .54784 Mdot
.81574 .54783 Mdot
.81575 .54782 Mdot
.81576 .54781 Mdot
.81577 .5478 Mdot
.81578 .54779 Mdot
.81579 .54778 Mdot
.8158 .54778 Mdot
.81581 .54777 Mdot
.81582 .54776 Mdot
.81583 .54775 Mdot
.81584 .54774 Mdot
.81585 .54773 Mdot
.81586 .54772 Mdot
.81587 .54771 Mdot
.81588 .5477 Mdot
.81589 .54769 Mdot
.8159 .54768 Mdot
.8159 .54767 Mdot
.81591 .54766 Mdot
.81592 .54765 Mdot
.81593 .54764 Mdot
.81594 .54763 Mdot
.81595 .54762 Mdot
.81596 .54761 Mdot
.81597 .5476 Mdot
.81598 .54759 Mdot
.81599 .54758 Mdot
.816 .54757 Mdot
.81601 .54756 Mdot
.81602 .54755 Mdot
.81603 .54754 Mdot
.81604 .54753 Mdot
.81605 .54752 Mdot
.81606 .54751 Mdot
.81607 .5475 Mdot
.81608 .54749 Mdot
.81609 .54748 Mdot
.8161 .54747 Mdot
.8161 .54746 Mdot
.81611 .54745 Mdot
.81612 .54744 Mdot
.81613 .54743 Mdot
.81614 .54742 Mdot
.81615 .54741 Mdot
.81616 .5474 Mdot
.81617 .54739 Mdot
.81618 .54738 Mdot
.81619 .54737 Mdot
.8162 .54736 Mdot
.81621 .54735 Mdot
.81622 .54734 Mdot
.81623 .54733 Mdot
.81624 .54732 Mdot
.81625 .54731 Mdot
.81626 .5473 Mdot
.81627 .54729 Mdot
.81628 .54728 Mdot
.81629 .54727 Mdot
.8163 .54726 Mdot
.8163 .54725 Mdot
.81631 .54724 Mdot
.81632 .54723 Mdot
.81633 .54722 Mdot
.81634 .54721 Mdot
.81635 .5472 Mdot
.81636 .54719 Mdot
.81637 .54718 Mdot
.81638 .54717 Mdot
.81639 .54716 Mdot
.8164 .54715 Mdot
.81641 .54714 Mdot
.81642 .54713 Mdot
.81643 .54712 Mdot
.81644 .54711 Mdot
.81645 .5471 Mdot
.81646 .54709 Mdot
.81647 .54708 Mdot
.81648 .54707 Mdot
.81649 .54706 Mdot
.8165 .54705 Mdot
.8165 .54704 Mdot
.81651 .54703 Mdot
.81652 .54702 Mdot
.81653 .54701 Mdot
.81654 .547 Mdot
.81655 .54699 Mdot
.81656 .54698 Mdot
.81657 .54697 Mdot
.81658 .54696 Mdot
.81659 .54695 Mdot
.8166 .54694 Mdot
.81661 .54693 Mdot
.81662 .54692 Mdot
.81663 .54691 Mdot
.81664 .5469 Mdot
.81665 .54689 Mdot
.81666 .54688 Mdot
.81667 .54687 Mdot
.81668 .54686 Mdot
.81669 .54685 Mdot
.8167 .54684 Mdot
.8167 .54683 Mdot
.81671 .54682 Mdot
.81672 .54681 Mdot
.81673 .5468 Mdot
.81674 .54679 Mdot
.81675 .54678 Mdot
.81676 .54677 Mdot
.81677 .54676 Mdot
.81678 .54675 Mdot
.81679 .54674 Mdot
.8168 .54673 Mdot
.81681 .54672 Mdot
.81682 .54671 Mdot
.81683 .5467 Mdot
.81684 .54669 Mdot
.81685 .54668 Mdot
.81686 .54667 Mdot
.81687 .54666 Mdot
.81688 .54665 Mdot
.81689 .54664 Mdot
.8169 .54663 Mdot
.8169 .54662 Mdot
.81691 .54661 Mdot
.81692 .5466 Mdot
.81693 .54659 Mdot
.81694 .54658 Mdot
.81695 .54657 Mdot
.81696 .54656 Mdot
.81697 .54655 Mdot
.81698 .54654 Mdot
.81699 .54653 Mdot
.817 .54652 Mdot
.81701 .54651 Mdot
.81702 .5465 Mdot
.81703 .54649 Mdot
.81704 .54649 Mdot
.81705 .54648 Mdot
.81706 .54647 Mdot
.81707 .54646 Mdot
.81708 .54645 Mdot
.81709 .54644 Mdot
.8171 .54643 Mdot
.8171 .54642 Mdot
.81711 .54641 Mdot
.81712 .5464 Mdot
.81713 .54639 Mdot
.81714 .54638 Mdot
.81715 .54637 Mdot
.81716 .54636 Mdot
.81717 .54635 Mdot
.81718 .54634 Mdot
.81719 .54633 Mdot
.8172 .54632 Mdot
.81721 .54631 Mdot
.81722 .5463 Mdot
.81723 .54629 Mdot
.81724 .54628 Mdot
.81725 .54627 Mdot
.81726 .54626 Mdot
.81727 .54625 Mdot
.81728 .54624 Mdot
.81729 .54623 Mdot
.8173 .54622 Mdot
.8173 .54621 Mdot
.81731 .5462 Mdot
.81732 .54619 Mdot
.81733 .54618 Mdot
.81734 .54617 Mdot
.81735 .54616 Mdot
.81736 .54615 Mdot
.81737 .54614 Mdot
.81738 .54613 Mdot
.81739 .54612 Mdot
.8174 .54611 Mdot
.81741 .5461 Mdot
.81742 .54609 Mdot
.81743 .54608 Mdot
.81744 .54607 Mdot
.81745 .54606 Mdot
.81746 .54605 Mdot
.81747 .54604 Mdot
.81748 .54603 Mdot
.81749 .54602 Mdot
.8175 .54601 Mdot
.8175 .546 Mdot
.81751 .54599 Mdot
.81752 .54598 Mdot
.81753 .54597 Mdot
.81754 .54596 Mdot
.81755 .54595 Mdot
.81756 .54594 Mdot
.81757 .54593 Mdot
.81758 .54592 Mdot
.81759 .54591 Mdot
.8176 .5459 Mdot
.81761 .54589 Mdot
.81762 .54588 Mdot
.81763 .54587 Mdot
.81764 .54586 Mdot
.81765 .54585 Mdot
.81766 .54584 Mdot
.81767 .54583 Mdot
.81768 .54582 Mdot
.81769 .54581 Mdot
.8177 .5458 Mdot
.8177 .54579 Mdot
.81771 .54578 Mdot
.81772 .54577 Mdot
.81773 .54576 Mdot
.81774 .54575 Mdot
.81775 .54574 Mdot
.81776 .54572 Mdot
.81777 .54571 Mdot
.81778 .5457 Mdot
.81779 .54569 Mdot
.8178 .54568 Mdot
.81781 .54567 Mdot
.81782 .54566 Mdot
.81783 .54565 Mdot
.81784 .54564 Mdot
.81785 .54563 Mdot
.81786 .54562 Mdot
.81787 .54561 Mdot
.81788 .5456 Mdot
.81789 .54559 Mdot
.8179 .54558 Mdot
.8179 .54557 Mdot
.81791 .54556 Mdot
.81792 .54555 Mdot
.81793 .54554 Mdot
.81794 .54553 Mdot
.81795 .54552 Mdot
.81796 .54551 Mdot
.81797 .5455 Mdot
.81798 .54549 Mdot
.81799 .54548 Mdot
.818 .54547 Mdot
.81801 .54546 Mdot
.81802 .54545 Mdot
.81803 .54544 Mdot
.81804 .54543 Mdot
.81805 .54542 Mdot
.81806 .54541 Mdot
.81807 .5454 Mdot
.81808 .54539 Mdot
.81809 .54538 Mdot
.8181 .54537 Mdot
.8181 .54536 Mdot
.81811 .54535 Mdot
.81812 .54534 Mdot
.81813 .54533 Mdot
.81814 .54532 Mdot
.81815 .54531 Mdot
.81816 .5453 Mdot
.81817 .54529 Mdot
.81818 .54528 Mdot
.81819 .54527 Mdot
.8182 .54526 Mdot
.81821 .54525 Mdot
.81822 .54524 Mdot
.81823 .54523 Mdot
.81824 .54522 Mdot
.81825 .54521 Mdot
.81826 .5452 Mdot
.81827 .54519 Mdot
.81828 .54518 Mdot
.81829 .54517 Mdot
.8183 .54516 Mdot
.8183 .54515 Mdot
.81831 .54514 Mdot
.81832 .54513 Mdot
.81833 .54512 Mdot
.81834 .54511 Mdot
.81835 .5451 Mdot
.81836 .54509 Mdot
.81837 .54508 Mdot
.81838 .54507 Mdot
.81839 .54506 Mdot
.8184 .54505 Mdot
.81841 .54504 Mdot
.81842 .54503 Mdot
.81843 .54502 Mdot
.81844 .54501 Mdot
.81845 .545 Mdot
.81846 .54499 Mdot
.81847 .54498 Mdot
.81848 .54497 Mdot
.81849 .54496 Mdot
.8185 .54495 Mdot
.8185 .54494 Mdot
.81851 .54493 Mdot
.81852 .54492 Mdot
.81853 .54491 Mdot
.81854 .5449 Mdot
.81855 .54489 Mdot
.81856 .54488 Mdot
.81857 .54487 Mdot
.81858 .54486 Mdot
.81859 .54485 Mdot
.8186 .54484 Mdot
.81861 .54483 Mdot
.81862 .54482 Mdot
.81863 .54481 Mdot
.81864 .5448 Mdot
.81865 .54479 Mdot
.81866 .54478 Mdot
.81867 .54477 Mdot
.81868 .54476 Mdot
.81869 .54475 Mdot
.8187 .54474 Mdot
.8187 .54473 Mdot
.81871 .54472 Mdot
.81872 .54471 Mdot
.81873 .5447 Mdot
.81874 .54469 Mdot
.81875 .54468 Mdot
.81876 .54467 Mdot
.81877 .54466 Mdot
.81878 .54465 Mdot
.81879 .54464 Mdot
.8188 .54463 Mdot
.81881 .54462 Mdot
.81882 .54461 Mdot
.81883 .5446 Mdot
.81884 .54459 Mdot
.81885 .54458 Mdot
.81886 .54457 Mdot
.81887 .54456 Mdot
.81888 .54455 Mdot
.81889 .54454 Mdot
.8189 .54453 Mdot
.8189 .54452 Mdot
.81891 .54451 Mdot
.81892 .5445 Mdot
.81893 .54449 Mdot
.81894 .54448 Mdot
.81895 .54447 Mdot
.81896 .54446 Mdot
.81897 .54445 Mdot
.81898 .54444 Mdot
.81899 .54443 Mdot
.819 .54441 Mdot
.81901 .5444 Mdot
.81902 .54439 Mdot
.81903 .54438 Mdot
.81904 .54437 Mdot
.81905 .54436 Mdot
.81906 .54435 Mdot
.81907 .54434 Mdot
.81908 .54433 Mdot
.81909 .54432 Mdot
.8191 .54431 Mdot
.8191 .5443 Mdot
.81911 .54429 Mdot
.81912 .54428 Mdot
.81913 .54427 Mdot
.81914 .54426 Mdot
.81915 .54425 Mdot
.81916 .54424 Mdot
.81917 .54423 Mdot
.81918 .54422 Mdot
.81919 .54421 Mdot
.8192 .5442 Mdot
.81921 .54419 Mdot
.81922 .54418 Mdot
.81923 .54417 Mdot
.81924 .54416 Mdot
.81925 .54415 Mdot
.81926 .54414 Mdot
.81927 .54413 Mdot
.81928 .54412 Mdot
.81929 .54411 Mdot
.8193 .5441 Mdot
.8193 .54409 Mdot
.81931 .54408 Mdot
.81932 .54407 Mdot
.81933 .54406 Mdot
.81934 .54405 Mdot
.81935 .54404 Mdot
.81936 .54403 Mdot
.81937 .54402 Mdot
.81938 .54401 Mdot
.81939 .544 Mdot
.8194 .54399 Mdot
.81941 .54398 Mdot
.81942 .54397 Mdot
.81943 .54396 Mdot
.81944 .54395 Mdot
.81945 .54394 Mdot
.81946 .54393 Mdot
.81947 .54392 Mdot
.81948 .54391 Mdot
.81949 .5439 Mdot
.8195 .54389 Mdot
.8195 .54388 Mdot
.81951 .54387 Mdot
.81952 .54386 Mdot
.81953 .54385 Mdot
.81954 .54384 Mdot
.81955 .54383 Mdot
.81956 .54382 Mdot
.81957 .54381 Mdot
.81958 .5438 Mdot
.81959 .54379 Mdot
.8196 .54378 Mdot
.81961 .54377 Mdot
.81962 .54376 Mdot
.81963 .54375 Mdot
.81964 .54373 Mdot
.81965 .54372 Mdot
.81966 .54371 Mdot
.81967 .5437 Mdot
.81968 .54369 Mdot
.81969 .54368 Mdot
.8197 .54367 Mdot
.8197 .54366 Mdot
.81971 .54365 Mdot
.81972 .54364 Mdot
.81973 .54363 Mdot
.81974 .54362 Mdot
.81975 .54361 Mdot
.81976 .5436 Mdot
.81977 .54359 Mdot
.81978 .54358 Mdot
.81979 .54357 Mdot
.8198 .54356 Mdot
.81981 .54355 Mdot
.81982 .54354 Mdot
.81983 .54353 Mdot
.81984 .54352 Mdot
.81985 .54351 Mdot
.81986 .5435 Mdot
.81987 .54349 Mdot
.81988 .54348 Mdot
.81989 .54347 Mdot
.8199 .54346 Mdot
.8199 .54345 Mdot
.81991 .54344 Mdot
.81992 .54343 Mdot
.81993 .54342 Mdot
.81994 .54341 Mdot
.81995 .5434 Mdot
.81996 .54339 Mdot
.81997 .54338 Mdot
.81998 .54337 Mdot
.81999 .54336 Mdot
.82 .54335 Mdot
.82001 .54334 Mdot
.82002 .54333 Mdot
.82003 .54332 Mdot
.82004 .54331 Mdot
.82005 .5433 Mdot
.82006 .54329 Mdot
.82007 .54328 Mdot
.82008 .54327 Mdot
.82009 .54326 Mdot
.8201 .54325 Mdot
.8201 .54324 Mdot
.82011 .54323 Mdot
.82012 .54322 Mdot
.82013 .5432 Mdot
.82014 .54319 Mdot
.82015 .54318 Mdot
.82016 .54317 Mdot
.82017 .54316 Mdot
.82018 .54315 Mdot
.82019 .54314 Mdot
.8202 .54313 Mdot
.82021 .54312 Mdot
.82022 .54311 Mdot
.82023 .5431 Mdot
.82024 .54309 Mdot
.82025 .54308 Mdot
.82026 .54307 Mdot
.82027 .54306 Mdot
.82028 .54305 Mdot
.82029 .54304 Mdot
.8203 .54303 Mdot
.8203 .54302 Mdot
.82031 .54301 Mdot
.82032 .543 Mdot
.82033 .54299 Mdot
.82034 .54298 Mdot
.82035 .54297 Mdot
.82036 .54296 Mdot
.82037 .54295 Mdot
.82038 .54294 Mdot
.82039 .54293 Mdot
.8204 .54292 Mdot
.82041 .54291 Mdot
.82042 .5429 Mdot
.82043 .54289 Mdot
.82044 .54288 Mdot
.82045 .54287 Mdot
.82046 .54286 Mdot
.82047 .54285 Mdot
.82048 .54284 Mdot
.82049 .54283 Mdot
.8205 .54282 Mdot
.8205 .54281 Mdot
.82051 .5428 Mdot
.82052 .54279 Mdot
.82053 .54278 Mdot
.82054 .54276 Mdot
.82055 .54275 Mdot
.82056 .54274 Mdot
.82057 .54273 Mdot
.82058 .54272 Mdot
.82059 .54271 Mdot
.8206 .5427 Mdot
.82061 .54269 Mdot
.82062 .54268 Mdot
.82063 .54267 Mdot
.82064 .54266 Mdot
.82065 .54265 Mdot
.82066 .54264 Mdot
.82067 .54263 Mdot
.82068 .54262 Mdot
.82069 .54261 Mdot
.8207 .5426 Mdot
.8207 .54259 Mdot
.82071 .54258 Mdot
.82072 .54257 Mdot
.82073 .54256 Mdot
.82074 .54255 Mdot
.82075 .54254 Mdot
.82076 .54253 Mdot
.82077 .54252 Mdot
.82078 .54251 Mdot
.82079 .5425 Mdot
.8208 .54249 Mdot
.82081 .54248 Mdot
.82082 .54247 Mdot
.82083 .54246 Mdot
.82084 .54245 Mdot
.82085 .54244 Mdot
.82086 .54243 Mdot
.82087 .54242 Mdot
.82088 .54241 Mdot
.82089 .5424 Mdot
.8209 .54239 Mdot
.8209 .54238 Mdot
.82091 .54236 Mdot
.82092 .54235 Mdot
.82093 .54234 Mdot
.82094 .54233 Mdot
.82095 .54232 Mdot
.82096 .54231 Mdot
.82097 .5423 Mdot
.82098 .54229 Mdot
.82099 .54228 Mdot
.821 .54227 Mdot
.82101 .54226 Mdot
.82102 .54225 Mdot
.82103 .54224 Mdot
.82104 .54223 Mdot
.82105 .54222 Mdot
.82106 .54221 Mdot
.82107 .5422 Mdot
.82108 .54219 Mdot
.82109 .54218 Mdot
.8211 .54217 Mdot
.8211 .54216 Mdot
.82111 .54215 Mdot
.82112 .54214 Mdot
.82113 .54213 Mdot
.82114 .54212 Mdot
.82115 .54211 Mdot
.82116 .5421 Mdot
.82117 .54209 Mdot
.82118 .54208 Mdot
.82119 .54207 Mdot
.8212 .54206 Mdot
.82121 .54205 Mdot
.82122 .54204 Mdot
.82123 .54203 Mdot
.82124 .54202 Mdot
.82125 .542 Mdot
.82126 .54199 Mdot
.82127 .54198 Mdot
.82128 .54197 Mdot
.82129 .54196 Mdot
.8213 .54195 Mdot
.8213 .54194 Mdot
.82131 .54193 Mdot
.82132 .54192 Mdot
.82133 .54191 Mdot
.82134 .5419 Mdot
.82135 .54189 Mdot
.82136 .54188 Mdot
.82137 .54187 Mdot
.82138 .54186 Mdot
.82139 .54185 Mdot
.8214 .54184 Mdot
.82141 .54183 Mdot
.82142 .54182 Mdot
.82143 .54181 Mdot
.82144 .5418 Mdot
.82145 .54179 Mdot
.82146 .54178 Mdot
.82147 .54177 Mdot
.82148 .54176 Mdot
.82149 .54175 Mdot
.8215 .54174 Mdot
.8215 .54173 Mdot
.82151 .54172 Mdot
.82152 .54171 Mdot
.82153 .5417 Mdot
.82154 .54169 Mdot
.82155 .54167 Mdot
.82156 .54166 Mdot
.82157 .54165 Mdot
.82158 .54164 Mdot
.82159 .54163 Mdot
.8216 .54162 Mdot
.82161 .54161 Mdot
.82162 .5416 Mdot
.82163 .54159 Mdot
.82164 .54158 Mdot
.82165 .54157 Mdot
.82166 .54156 Mdot
.82167 .54155 Mdot
.82168 .54154 Mdot
.82169 .54153 Mdot
.8217 .54152 Mdot
.8217 .54151 Mdot
.82171 .5415 Mdot
.82172 .54149 Mdot
.82173 .54148 Mdot
.82174 .54147 Mdot
.82175 .54146 Mdot
.82176 .54145 Mdot
.82177 .54144 Mdot
.82178 .54143 Mdot
.82179 .54142 Mdot
.8218 .54141 Mdot
.82181 .5414 Mdot
.82182 .54139 Mdot
.82183 .54138 Mdot
.82184 .54136 Mdot
.82185 .54135 Mdot
.82186 .54134 Mdot
.82187 .54133 Mdot
.82188 .54132 Mdot
.82189 .54131 Mdot
.8219 .5413 Mdot
.8219 .54129 Mdot
.82191 .54128 Mdot
.82192 .54127 Mdot
.82193 .54126 Mdot
.82194 .54125 Mdot
.82195 .54124 Mdot
.82196 .54123 Mdot
.82197 .54122 Mdot
.82198 .54121 Mdot
.82199 .5412 Mdot
.822 .54119 Mdot
.82201 .54118 Mdot
.82202 .54117 Mdot
.82203 .54116 Mdot
.82204 .54115 Mdot
.82205 .54114 Mdot
.82206 .54113 Mdot
.82207 .54112 Mdot
.82208 .54111 Mdot
.82209 .5411 Mdot
.8221 .54109 Mdot
.8221 .54107 Mdot
.82211 .54106 Mdot
.82212 .54105 Mdot
.82213 .54104 Mdot
.82214 .54103 Mdot
.82215 .54102 Mdot
.82216 .54101 Mdot
.82217 .541 Mdot
.82218 .54099 Mdot
.82219 .54098 Mdot
.8222 .54097 Mdot
.82221 .54096 Mdot
.82222 .54095 Mdot
.82223 .54094 Mdot
.82224 .54093 Mdot
.82225 .54092 Mdot
.82226 .54091 Mdot
.82227 .5409 Mdot
.82228 .54089 Mdot
.82229 .54088 Mdot
.8223 .54087 Mdot
.8223 .54086 Mdot
.82231 .54085 Mdot
.82232 .54084 Mdot
.82233 .54083 Mdot
.82234 .54082 Mdot
.82235 .54081 Mdot
.82236 .54079 Mdot
.82237 .54078 Mdot
.82238 .54077 Mdot
.82239 .54076 Mdot
.8224 .54075 Mdot
.82241 .54074 Mdot
.82242 .54073 Mdot
.82243 .54072 Mdot
.82244 .54071 Mdot
.82245 .5407 Mdot
.82246 .54069 Mdot
.82247 .54068 Mdot
.82248 .54067 Mdot
.82249 .54066 Mdot
.8225 .54065 Mdot
.8225 .54064 Mdot
.82251 .54063 Mdot
.82252 .54062 Mdot
.82253 .54061 Mdot
.82254 .5406 Mdot
.82255 .54059 Mdot
.82256 .54058 Mdot
.82257 .54057 Mdot
.82258 .54056 Mdot
.82259 .54055 Mdot
.8226 .54053 Mdot
.82261 .54052 Mdot
.82262 .54051 Mdot
.82263 .5405 Mdot
.82264 .54049 Mdot
.82265 .54048 Mdot
.82266 .54047 Mdot
.82267 .54046 Mdot
.82268 .54045 Mdot
.82269 .54044 Mdot
.8227 .54043 Mdot
.8227 .54042 Mdot
.82271 .54041 Mdot
.82272 .5404 Mdot
.82273 .54039 Mdot
.82274 .54038 Mdot
.82275 .54037 Mdot
.82276 .54036 Mdot
.82277 .54035 Mdot
.82278 .54034 Mdot
.82279 .54033 Mdot
.8228 .54032 Mdot
.82281 .54031 Mdot
.82282 .5403 Mdot
.82283 .54029 Mdot
.82284 .54027 Mdot
.82285 .54026 Mdot
.82286 .54025 Mdot
.82287 .54024 Mdot
.82288 .54023 Mdot
.82289 .54022 Mdot
.8229 .54021 Mdot
.8229 .5402 Mdot
.82291 .54019 Mdot
.82292 .54018 Mdot
.82293 .54017 Mdot
.82294 .54016 Mdot
.82295 .54015 Mdot
.82296 .54014 Mdot
.82297 .54013 Mdot
.82298 .54012 Mdot
.82299 .54011 Mdot
.823 .5401 Mdot
.82301 .54009 Mdot
.82302 .54008 Mdot
.82303 .54007 Mdot
.82304 .54006 Mdot
.82305 .54005 Mdot
.82306 .54003 Mdot
.82307 .54002 Mdot
.82308 .54001 Mdot
.82309 .54 Mdot
.8231 .53999 Mdot
.8231 .53998 Mdot
.82311 .53997 Mdot
.82312 .53996 Mdot
.82313 .53995 Mdot
.82314 .53994 Mdot
.82315 .53993 Mdot
.82316 .53992 Mdot
.82317 .53991 Mdot
.82318 .5399 Mdot
.82319 .53989 Mdot
.8232 .53988 Mdot
.82321 .53987 Mdot
.82322 .53986 Mdot
.82323 .53985 Mdot
.82324 .53984 Mdot
.82325 .53983 Mdot
.82326 .53982 Mdot
.82327 .5398 Mdot
.82328 .53979 Mdot
.82329 .53978 Mdot
.8233 .53977 Mdot
.8233 .53976 Mdot
.82331 .53975 Mdot
.82332 .53974 Mdot
.82333 .53973 Mdot
.82334 .53972 Mdot
.82335 .53971 Mdot
.82336 .5397 Mdot
.82337 .53969 Mdot
.82338 .53968 Mdot
.82339 .53967 Mdot
.8234 .53966 Mdot
.82341 .53965 Mdot
.82342 .53964 Mdot
.82343 .53963 Mdot
.82344 .53962 Mdot
.82345 .53961 Mdot
.82346 .5396 Mdot
.82347 .53959 Mdot
.82348 .53957 Mdot
.82349 .53956 Mdot
.8235 .53955 Mdot
.8235 .53954 Mdot
.82351 .53953 Mdot
.82352 .53952 Mdot
.82353 .53951 Mdot
.82354 .5395 Mdot
.82355 .53949 Mdot
.82356 .53948 Mdot
.82357 .53947 Mdot
.82358 .53946 Mdot
.82359 .53945 Mdot
.8236 .53944 Mdot
.82361 .53943 Mdot
.82362 .53942 Mdot
.82363 .53941 Mdot
.82364 .5394 Mdot
.82365 .53939 Mdot
.82366 .53938 Mdot
.82367 .53937 Mdot
.82368 .53935 Mdot
.82369 .53934 Mdot
.8237 .53933 Mdot
.8237 .53932 Mdot
.82371 .53931 Mdot
.82372 .5393 Mdot
.82373 .53929 Mdot
.82374 .53928 Mdot
.82375 .53927 Mdot
.82376 .53926 Mdot
.82377 .53925 Mdot
.82378 .53924 Mdot
.82379 .53923 Mdot
.8238 .53922 Mdot
.82381 .53921 Mdot
.82382 .5392 Mdot
.82383 .53919 Mdot
.82384 .53918 Mdot
.82385 .53917 Mdot
.82386 .53916 Mdot
.82387 .53914 Mdot
.82388 .53913 Mdot
.82389 .53912 Mdot
.8239 .53911 Mdot
.8239 .5391 Mdot
.82391 .53909 Mdot
.82392 .53908 Mdot
.82393 .53907 Mdot
.82394 .53906 Mdot
.82395 .53905 Mdot
.82396 .53904 Mdot
.82397 .53903 Mdot
.82398 .53902 Mdot
.82399 .53901 Mdot
.824 .539 Mdot
.82401 .53899 Mdot
.82402 .53898 Mdot
.82403 .53897 Mdot
.82404 .53896 Mdot
.82405 .53895 Mdot
.82406 .53893 Mdot
.82407 .53892 Mdot
.82408 .53891 Mdot
.82409 .5389 Mdot
.8241 .53889 Mdot
.8241 .53888 Mdot
.82411 .53887 Mdot
.82412 .53886 Mdot
.82413 .53885 Mdot
.82414 .53884 Mdot
.82415 .53883 Mdot
.82416 .53882 Mdot
.82417 .53881 Mdot
.82418 .5388 Mdot
.82419 .53879 Mdot
.8242 .53878 Mdot
.82421 .53877 Mdot
.82422 .53876 Mdot
.82423 .53875 Mdot
.82424 .53873 Mdot
.82425 .53872 Mdot
.82426 .53871 Mdot
.82427 .5387 Mdot
.82428 .53869 Mdot
.82429 .53868 Mdot
.8243 .53867 Mdot
.8243 .53866 Mdot
.82431 .53865 Mdot
.82432 .53864 Mdot
.82433 .53863 Mdot
.82434 .53862 Mdot
.82435 .53861 Mdot
.82436 .5386 Mdot
.82437 .53859 Mdot
.82438 .53858 Mdot
.82439 .53857 Mdot
.8244 .53856 Mdot
.82441 .53855 Mdot
.82442 .53853 Mdot
.82443 .53852 Mdot
.82444 .53851 Mdot
.82445 .5385 Mdot
.82446 .53849 Mdot
.82447 .53848 Mdot
.82448 .53847 Mdot
.82449 .53846 Mdot
.8245 .53845 Mdot
.8245 .53844 Mdot
.82451 .53843 Mdot
.82452 .53842 Mdot
.82453 .53841 Mdot
.82454 .5384 Mdot
.82455 .53839 Mdot
.82456 .53838 Mdot
.82457 .53837 Mdot
.82458 .53836 Mdot
.82459 .53834 Mdot
.8246 .53833 Mdot
.82461 .53832 Mdot
.82462 .53831 Mdot
.82463 .5383 Mdot
.82464 .53829 Mdot
.82465 .53828 Mdot
.82466 .53827 Mdot
.82467 .53826 Mdot
.82468 .53825 Mdot
.82469 .53824 Mdot
.8247 .53823 Mdot
.8247 .53822 Mdot
.82471 .53821 Mdot
.82472 .5382 Mdot
.82473 .53819 Mdot
.82474 .53818 Mdot
.82475 .53817 Mdot
.82476 .53815 Mdot
.82477 .53814 Mdot
.82478 .53813 Mdot
.82479 .53812 Mdot
.8248 .53811 Mdot
.82481 .5381 Mdot
.82482 .53809 Mdot
.82483 .53808 Mdot
.82484 .53807 Mdot
.82485 .53806 Mdot
.82486 .53805 Mdot
.82487 .53804 Mdot
.82488 .53803 Mdot
.82489 .53802 Mdot
.8249 .53801 Mdot
.8249 .538 Mdot
.82491 .53799 Mdot
.82492 .53798 Mdot
.82493 .53796 Mdot
.82494 .53795 Mdot
.82495 .53794 Mdot
.82496 .53793 Mdot
.82497 .53792 Mdot
.82498 .53791 Mdot
.82499 .5379 Mdot
.825 .53789 Mdot
.82501 .53788 Mdot
.82502 .53787 Mdot
.82503 .53786 Mdot
.82504 .53785 Mdot
.82505 .53784 Mdot
.82506 .53783 Mdot
.82507 .53782 Mdot
.82508 .53781 Mdot
.82509 .5378 Mdot
.8251 .53778 Mdot
.8251 .53777 Mdot
.82511 .53776 Mdot
.82512 .53775 Mdot
.82513 .53774 Mdot
.82514 .53773 Mdot
.82515 .53772 Mdot
.82516 .53771 Mdot
.82517 .5377 Mdot
.82518 .53769 Mdot
.82519 .53768 Mdot
.8252 .53767 Mdot
.82521 .53766 Mdot
.82522 .53765 Mdot
.82523 .53764 Mdot
.82524 .53763 Mdot
.82525 .53761 Mdot
.82526 .5376 Mdot
.82527 .53759 Mdot
.82528 .53758 Mdot
.82529 .53757 Mdot
.8253 .53756 Mdot
.8253 .53755 Mdot
.82531 .53754 Mdot
.82532 .53753 Mdot
.82533 .53752 Mdot
.82534 .53751 Mdot
.82535 .5375 Mdot
.82536 .53749 Mdot
.82537 .53748 Mdot
.82538 .53747 Mdot
.82539 .53746 Mdot
.8254 .53745 Mdot
.82541 .53743 Mdot
.82542 .53742 Mdot
.82543 .53741 Mdot
.82544 .5374 Mdot
.82545 .53739 Mdot
.82546 .53738 Mdot
.82547 .53737 Mdot
.82548 .53736 Mdot
.82549 .53735 Mdot
.8255 .53734 Mdot
.8255 .53733 Mdot
.82551 .53732 Mdot
.82552 .53731 Mdot
.82553 .5373 Mdot
.82554 .53729 Mdot
.82555 .53728 Mdot
.82556 .53726 Mdot
.82557 .53725 Mdot
.82558 .53724 Mdot
.82559 .53723 Mdot
.8256 .53722 Mdot
.82561 .53721 Mdot
.82562 .5372 Mdot
.82563 .53719 Mdot
.82564 .53718 Mdot
.82565 .53717 Mdot
.82566 .53716 Mdot
.82567 .53715 Mdot
.82568 .53714 Mdot
.82569 .53713 Mdot
.8257 .53712 Mdot
.8257 .53711 Mdot
.82571 .53709 Mdot
.82572 .53708 Mdot
.82573 .53707 Mdot
.82574 .53706 Mdot
.82575 .53705 Mdot
.82576 .53704 Mdot
.82577 .53703 Mdot
.82578 .53702 Mdot
.82579 .53701 Mdot
.8258 .537 Mdot
.82581 .53699 Mdot
.82582 .53698 Mdot
.82583 .53697 Mdot
.82584 .53696 Mdot
.82585 .53695 Mdot
.82586 .53693 Mdot
.82587 .53692 Mdot
.82588 .53691 Mdot
.82589 .5369 Mdot
.8259 .53689 Mdot
.8259 .53688 Mdot
.82591 .53687 Mdot
.82592 .53686 Mdot
.82593 .53685 Mdot
.82594 .53684 Mdot
.82595 .53683 Mdot
.82596 .53682 Mdot
.82597 .53681 Mdot
.82598 .5368 Mdot
.82599 .53679 Mdot
.826 .53678 Mdot
.82601 .53676 Mdot
.82602 .53675 Mdot
.82603 .53674 Mdot
.82604 .53673 Mdot
.82605 .53672 Mdot
.82606 .53671 Mdot
.82607 .5367 Mdot
.82608 .53669 Mdot
.82609 .53668 Mdot
.8261 .53667 Mdot
.8261 .53666 Mdot
.82611 .53665 Mdot
.82612 .53664 Mdot
.82613 .53663 Mdot
.82614 .53662 Mdot
.82615 .5366 Mdot
.82616 .53659 Mdot
.82617 .53658 Mdot
.82618 .53657 Mdot
.82619 .53656 Mdot
.8262 .53655 Mdot
.82621 .53654 Mdot
.82622 .53653 Mdot
.82623 .53652 Mdot
.82624 .53651 Mdot
.82625 .5365 Mdot
.82626 .53649 Mdot
.82627 .53648 Mdot
.82628 .53647 Mdot
.82629 .53645 Mdot
.8263 .53644 Mdot
.8263 .53643 Mdot
.82631 .53642 Mdot
.82632 .53641 Mdot
.82633 .5364 Mdot
.82634 .53639 Mdot
.82635 .53638 Mdot
.82636 .53637 Mdot
.82637 .53636 Mdot
.82638 .53635 Mdot
.82639 .53634 Mdot
.8264 .53633 Mdot
.82641 .53632 Mdot
.82642 .53631 Mdot
.82643 .53629 Mdot
.82644 .53628 Mdot
.82645 .53627 Mdot
.82646 .53626 Mdot
.82647 .53625 Mdot
.82648 .53624 Mdot
.82649 .53623 Mdot
.8265 .53622 Mdot
.8265 .53621 Mdot
.82651 .5362 Mdot
.82652 .53619 Mdot
.82653 .53618 Mdot
.82654 .53617 Mdot
.82655 .53616 Mdot
.82656 .53614 Mdot
.82657 .53613 Mdot
.82658 .53612 Mdot
.82659 .53611 Mdot
.8266 .5361 Mdot
.82661 .53609 Mdot
.82662 .53608 Mdot
.82663 .53607 Mdot
.82664 .53606 Mdot
.82665 .53605 Mdot
.82666 .53604 Mdot
.82667 .53603 Mdot
.82668 .53602 Mdot
.82669 .53601 Mdot
.8267 .536 Mdot
.8267 .53598 Mdot
.82671 .53597 Mdot
.82672 .53596 Mdot
.82673 .53595 Mdot
.82674 .53594 Mdot
.82675 .53593 Mdot
.82676 .53592 Mdot
.82677 .53591 Mdot
.82678 .5359 Mdot
.82679 .53589 Mdot
.8268 .53588 Mdot
.82681 .53587 Mdot
.82682 .53586 Mdot
.82683 .53584 Mdot
.82684 .53583 Mdot
.82685 .53582 Mdot
.82686 .53581 Mdot
.82687 .5358 Mdot
.82688 .53579 Mdot
.82689 .53578 Mdot
.8269 .53577 Mdot
.8269 .53576 Mdot
.82691 .53575 Mdot
.82692 .53574 Mdot
.82693 .53573 Mdot
.82694 .53572 Mdot
.82695 .53571 Mdot
.82696 .53569 Mdot
.82697 .53568 Mdot
.82698 .53567 Mdot
.82699 .53566 Mdot
.827 .53565 Mdot
.82701 .53564 Mdot
.82702 .53563 Mdot
.82703 .53562 Mdot
.82704 .53561 Mdot
.82705 .5356 Mdot
.82706 .53559 Mdot
.82707 .53558 Mdot
.82708 .53557 Mdot
.82709 .53556 Mdot
.8271 .53554 Mdot
.8271 .53553 Mdot
.82711 .53552 Mdot
.82712 .53551 Mdot
.82713 .5355 Mdot
.82714 .53549 Mdot
.82715 .53548 Mdot
.82716 .53547 Mdot
.82717 .53546 Mdot
.82718 .53545 Mdot
.82719 .53544 Mdot
.8272 .53543 Mdot
.82721 .53542 Mdot
.82722 .5354 Mdot
.82723 .53539 Mdot
.82724 .53538 Mdot
.82725 .53537 Mdot
.82726 .53536 Mdot
.82727 .53535 Mdot
.82728 .53534 Mdot
.82729 .53533 Mdot
.8273 .53532 Mdot
.8273 .53531 Mdot
.82731 .5353 Mdot
.82732 .53529 Mdot
.82733 .53528 Mdot
.82734 .53526 Mdot
.82735 .53525 Mdot
.82736 .53524 Mdot
.82737 .53523 Mdot
.82738 .53522 Mdot
.82739 .53521 Mdot
.8274 .5352 Mdot
.82741 .53519 Mdot
.82742 .53518 Mdot
.82743 .53517 Mdot
.82744 .53516 Mdot
.82745 .53515 Mdot
.82746 .53514 Mdot
.82747 .53513 Mdot
.82748 .53511 Mdot
.82749 .5351 Mdot
.8275 .53509 Mdot
.8275 .53508 Mdot
.82751 .53507 Mdot
.82752 .53506 Mdot
.82753 .53505 Mdot
.82754 .53504 Mdot
.82755 .53503 Mdot
.82756 .53502 Mdot
.82757 .53501 Mdot
.82758 .535 Mdot
.82759 .53498 Mdot
.8276 .53497 Mdot
.82761 .53496 Mdot
.82762 .53495 Mdot
.82763 .53494 Mdot
.82764 .53493 Mdot
.82765 .53492 Mdot
.82766 .53491 Mdot
.82767 .5349 Mdot
.82768 .53489 Mdot
.82769 .53488 Mdot
.8277 .53487 Mdot
.8277 .53486 Mdot
.82771 .53484 Mdot
.82772 .53483 Mdot
.82773 .53482 Mdot
.82774 .53481 Mdot
.82775 .5348 Mdot
.82776 .53479 Mdot
.82777 .53478 Mdot
.82778 .53477 Mdot
.82779 .53476 Mdot
.8278 .53475 Mdot
.82781 .53474 Mdot
.82782 .53473 Mdot
.82783 .53472 Mdot
.82784 .5347 Mdot
.82785 .53469 Mdot
.82786 .53468 Mdot
.82787 .53467 Mdot
.82788 .53466 Mdot
.82789 .53465 Mdot
.8279 .53464 Mdot
.8279 .53463 Mdot
.82791 .53462 Mdot
.82792 .53461 Mdot
.82793 .5346 Mdot
.82794 .53459 Mdot
.82795 .53457 Mdot
.82796 .53456 Mdot
.82797 .53455 Mdot
.82798 .53454 Mdot
.82799 .53453 Mdot
.828 .53452 Mdot
.82801 .53451 Mdot
.82802 .5345 Mdot
.82803 .53449 Mdot
.82804 .53448 Mdot
.82805 .53447 Mdot
.82806 .53446 Mdot
.82807 .53445 Mdot
.82808 .53443 Mdot
.82809 .53442 Mdot
.8281 .53441 Mdot
.8281 .5344 Mdot
.82811 .53439 Mdot
.82812 .53438 Mdot
.82813 .53437 Mdot
.82814 .53436 Mdot
.82815 .53435 Mdot
.82816 .53434 Mdot
.82817 .53433 Mdot
.82818 .53432 Mdot
.82819 .5343 Mdot
.8282 .53429 Mdot
.82821 .53428 Mdot
.82822 .53427 Mdot
.82823 .53426 Mdot
.82824 .53425 Mdot
.82825 .53424 Mdot
.82826 .53423 Mdot
.82827 .53422 Mdot
.82828 .53421 Mdot
.82829 .5342 Mdot
.8283 .53419 Mdot
.8283 .53417 Mdot
.82831 .53416 Mdot
.82832 .53415 Mdot
.82833 .53414 Mdot
.82834 .53413 Mdot
.82835 .53412 Mdot
.82836 .53411 Mdot
.82837 .5341 Mdot
.82838 .53409 Mdot
.82839 .53408 Mdot
.8284 .53407 Mdot
.82841 .53406 Mdot
.82842 .53404 Mdot
.82843 .53403 Mdot
.82844 .53402 Mdot
.82845 .53401 Mdot
.82846 .534 Mdot
.82847 .53399 Mdot
.82848 .53398 Mdot
.82849 .53397 Mdot
.8285 .53396 Mdot
.8285 .53395 Mdot
.82851 .53394 Mdot
.82852 .53393 Mdot
.82853 .53391 Mdot
.82854 .5339 Mdot
.82855 .53389 Mdot
.82856 .53388 Mdot
.82857 .53387 Mdot
.82858 .53386 Mdot
.82859 .53385 Mdot
.8286 .53384 Mdot
.82861 .53383 Mdot
.82862 .53382 Mdot
.82863 .53381 Mdot
.82864 .5338 Mdot
.82865 .53378 Mdot
.82866 .53377 Mdot
.82867 .53376 Mdot
.82868 .53375 Mdot
.82869 .53374 Mdot
.8287 .53373 Mdot
.8287 .53372 Mdot
.82871 .53371 Mdot
.82872 .5337 Mdot
.82873 .53369 Mdot
.82874 .53368 Mdot
.82875 .53366 Mdot
.82876 .53365 Mdot
.82877 .53364 Mdot
.82878 .53363 Mdot
.82879 .53362 Mdot
.8288 .53361 Mdot
.82881 .5336 Mdot
.82882 .53359 Mdot
.82883 .53358 Mdot
.82884 .53357 Mdot
.82885 .53356 Mdot
.82886 .53355 Mdot
.82887 .53353 Mdot
.82888 .53352 Mdot
.82889 .53351 Mdot
.8289 .5335 Mdot
.8289 .53349 Mdot
.82891 .53348 Mdot
.82892 .53347 Mdot
.82893 .53346 Mdot
.82894 .53345 Mdot
.82895 .53344 Mdot
.82896 .53343 Mdot
.82897 .53341 Mdot
.82898 .5334 Mdot
.82899 .53339 Mdot
.829 .53338 Mdot
.82901 .53337 Mdot
.82902 .53336 Mdot
.82903 .53335 Mdot
.82904 .53334 Mdot
.82905 .53333 Mdot
.82906 .53332 Mdot
.82907 .53331 Mdot
.82908 .53329 Mdot
.82909 .53328 Mdot
.8291 .53327 Mdot
.8291 .53326 Mdot
.82911 .53325 Mdot
.82912 .53324 Mdot
.82913 .53323 Mdot
.82914 .53322 Mdot
.82915 .53321 Mdot
.82916 .5332 Mdot
.82917 .53319 Mdot
.82918 .53318 Mdot
.82919 .53316 Mdot
.8292 .53315 Mdot
.82921 .53314 Mdot
.82922 .53313 Mdot
.82923 .53312 Mdot
.82924 .53311 Mdot
.82925 .5331 Mdot
.82926 .53309 Mdot
.82927 .53308 Mdot
.82928 .53307 Mdot
.82929 .53306 Mdot
.8293 .53304 Mdot
.8293 .53303 Mdot
.82931 .53302 Mdot
.82932 .53301 Mdot
.82933 .533 Mdot
.82934 .53299 Mdot
.82935 .53298 Mdot
.82936 .53297 Mdot
.82937 .53296 Mdot
.82938 .53295 Mdot
.82939 .53294 Mdot
.8294 .53292 Mdot
.82941 .53291 Mdot
.82942 .5329 Mdot
.82943 .53289 Mdot
.82944 .53288 Mdot
.82945 .53287 Mdot
.82946 .53286 Mdot
.82947 .53285 Mdot
.82948 .53284 Mdot
.82949 .53283 Mdot
.8295 .53282 Mdot
.8295 .5328 Mdot
.82951 .53279 Mdot
.82952 .53278 Mdot
.82953 .53277 Mdot
.82954 .53276 Mdot
.82955 .53275 Mdot
.82956 .53274 Mdot
.82957 .53273 Mdot
.82958 .53272 Mdot
.82959 .53271 Mdot
.8296 .5327 Mdot
.82961 .53268 Mdot
.82962 .53267 Mdot
.82963 .53266 Mdot
.82964 .53265 Mdot
.82965 .53264 Mdot
.82966 .53263 Mdot
.82967 .53262 Mdot
.82968 .53261 Mdot
.82969 .5326 Mdot
.8297 .53259 Mdot
.8297 .53257 Mdot
.82971 .53256 Mdot
.82972 .53255 Mdot
.82973 .53254 Mdot
.82974 .53253 Mdot
.82975 .53252 Mdot
.82976 .53251 Mdot
.82977 .5325 Mdot
.82978 .53249 Mdot
.82979 .53248 Mdot
.8298 .53247 Mdot
.82981 .53245 Mdot
.82982 .53244 Mdot
.82983 .53243 Mdot
.82984 .53242 Mdot
.82985 .53241 Mdot
.82986 .5324 Mdot
.82987 .53239 Mdot
.82988 .53238 Mdot
.82989 .53237 Mdot
.8299 .53236 Mdot
.8299 .53235 Mdot
.82991 .53233 Mdot
.82992 .53232 Mdot
.82993 .53231 Mdot
.82994 .5323 Mdot
.82995 .53229 Mdot
.82996 .53228 Mdot
.82997 .53227 Mdot
.82998 .53226 Mdot
.82999 .53225 Mdot
.83 .53224 Mdot
.83001 .53222 Mdot
.83002 .53221 Mdot
.83003 .5322 Mdot
.83004 .53219 Mdot
.83005 .53218 Mdot
.83006 .53217 Mdot
.83007 .53216 Mdot
.83008 .53215 Mdot
.83009 .53214 Mdot
.8301 .53213 Mdot
.8301 .53211 Mdot
.83011 .5321 Mdot
.83012 .53209 Mdot
.83013 .53208 Mdot
.83014 .53207 Mdot
.83015 .53206 Mdot
.83016 .53205 Mdot
.83017 .53204 Mdot
.83018 .53203 Mdot
.83019 .53202 Mdot
.8302 .53201 Mdot
.83021 .53199 Mdot
.83022 .53198 Mdot
.83023 .53197 Mdot
.83024 .53196 Mdot
.83025 .53195 Mdot
.83026 .53194 Mdot
.83027 .53193 Mdot
.83028 .53192 Mdot
.83029 .53191 Mdot
.8303 .5319 Mdot
.8303 .53188 Mdot
.83031 .53187 Mdot
.83032 .53186 Mdot
.83033 .53185 Mdot
.83034 .53184 Mdot
.83035 .53183 Mdot
.83036 .53182 Mdot
.83037 .53181 Mdot
.83038 .5318 Mdot
.83039 .53179 Mdot
.8304 .53177 Mdot
.83041 .53176 Mdot
.83042 .53175 Mdot
.83043 .53174 Mdot
.83044 .53173 Mdot
.83045 .53172 Mdot
.83046 .53171 Mdot
.83047 .5317 Mdot
.83048 .53169 Mdot
.83049 .53168 Mdot
.8305 .53166 Mdot
.8305 .53165 Mdot
.83051 .53164 Mdot
.83052 .53163 Mdot
.83053 .53162 Mdot
.83054 .53161 Mdot
.83055 .5316 Mdot
.83056 .53159 Mdot
.83057 .53158 Mdot
.83058 .53157 Mdot
.83059 .53155 Mdot
.8306 .53154 Mdot
.83061 .53153 Mdot
.83062 .53152 Mdot
.83063 .53151 Mdot
.83064 .5315 Mdot
.83065 .53149 Mdot
.83066 .53148 Mdot
.83067 .53147 Mdot
.83068 .53146 Mdot
.83069 .53144 Mdot
.8307 .53143 Mdot
.8307 .53142 Mdot
.83071 .53141 Mdot
.83072 .5314 Mdot
.83073 .53139 Mdot
.83074 .53138 Mdot
.83075 .53137 Mdot
.83076 .53136 Mdot
.83077 .53135 Mdot
.83078 .53133 Mdot
.83079 .53132 Mdot
.8308 .53131 Mdot
.83081 .5313 Mdot
.83082 .53129 Mdot
.83083 .53128 Mdot
.83084 .53127 Mdot
.83085 .53126 Mdot
.83086 .53125 Mdot
.83087 .53124 Mdot
.83088 .53122 Mdot
.83089 .53121 Mdot
.8309 .5312 Mdot
.8309 .53119 Mdot
.83091 .53118 Mdot
.83092 .53117 Mdot
.83093 .53116 Mdot
.83094 .53115 Mdot
.83095 .53114 Mdot
.83096 .53113 Mdot
.83097 .53111 Mdot
.83098 .5311 Mdot
.83099 .53109 Mdot
.831 .53108 Mdot
.83101 .53107 Mdot
.83102 .53106 Mdot
.83103 .53105 Mdot
.83104 .53104 Mdot
.83105 .53103 Mdot
.83106 .53102 Mdot
.83107 .531 Mdot
.83108 .53099 Mdot
.83109 .53098 Mdot
.8311 .53097 Mdot
.8311 .53096 Mdot
.83111 .53095 Mdot
.83112 .53094 Mdot
.83113 .53093 Mdot
.83114 .53092 Mdot
.83115 .5309 Mdot
.83116 .53089 Mdot
.83117 .53088 Mdot
.83118 .53087 Mdot
.83119 .53086 Mdot
.8312 .53085 Mdot
.83121 .53084 Mdot
.83122 .53083 Mdot
.83123 .53082 Mdot
.83124 .53081 Mdot
.83125 .53079 Mdot
.83126 .53078 Mdot
.83127 .53077 Mdot
.83128 .53076 Mdot
.83129 .53075 Mdot
.8313 .53074 Mdot
.8313 .53073 Mdot
.83131 .53072 Mdot
.83132 .53071 Mdot
.83133 .53069 Mdot
.83134 .53068 Mdot
.83135 .53067 Mdot
.83136 .53066 Mdot
.83137 .53065 Mdot
.83138 .53064 Mdot
.83139 .53063 Mdot
.8314 .53062 Mdot
.83141 .53061 Mdot
.83142 .5306 Mdot
.83143 .53058 Mdot
.83144 .53057 Mdot
.83145 .53056 Mdot
.83146 .53055 Mdot
.83147 .53054 Mdot
.83148 .53053 Mdot
.83149 .53052 Mdot
.8315 .53051 Mdot
.8315 .5305 Mdot
.83151 .53048 Mdot
.83152 .53047 Mdot
.83153 .53046 Mdot
.83154 .53045 Mdot
.83155 .53044 Mdot
.83156 .53043 Mdot
.83157 .53042 Mdot
.83158 .53041 Mdot
.83159 .5304 Mdot
.8316 .53039 Mdot
.83161 .53037 Mdot
.83162 .53036 Mdot
.83163 .53035 Mdot
.83164 .53034 Mdot
.83165 .53033 Mdot
.83166 .53032 Mdot
.83167 .53031 Mdot
.83168 .5303 Mdot
.83169 .53029 Mdot
.8317 .53027 Mdot
.8317 .53026 Mdot
.83171 .53025 Mdot
.83172 .53024 Mdot
.83173 .53023 Mdot
.83174 .53022 Mdot
.83175 .53021 Mdot
.83176 .5302 Mdot
.83177 .53019 Mdot
.83178 .53017 Mdot
.83179 .53016 Mdot
.8318 .53015 Mdot
.83181 .53014 Mdot
.83182 .53013 Mdot
.83183 .53012 Mdot
.83184 .53011 Mdot
.83185 .5301 Mdot
.83186 .53009 Mdot
.83187 .53007 Mdot
.83188 .53006 Mdot
.83189 .53005 Mdot
.8319 .53004 Mdot
.8319 .53003 Mdot
.83191 .53002 Mdot
.83192 .53001 Mdot
.83193 .53 Mdot
.83194 .52999 Mdot
.83195 .52998 Mdot
.83196 .52996 Mdot
.83197 .52995 Mdot
.83198 .52994 Mdot
.83199 .52993 Mdot
.832 .52992 Mdot
.83201 .52991 Mdot
.83202 .5299 Mdot
.83203 .52989 Mdot
.83204 .52988 Mdot
.83205 .52986 Mdot
.83206 .52985 Mdot
.83207 .52984 Mdot
.83208 .52983 Mdot
.83209 .52982 Mdot
.8321 .52981 Mdot
.8321 .5298 Mdot
.83211 .52979 Mdot
.83212 .52978 Mdot
.83213 .52976 Mdot
.83214 .52975 Mdot
.83215 .52974 Mdot
.83216 .52973 Mdot
.83217 .52972 Mdot
.83218 .52971 Mdot
.83219 .5297 Mdot
.8322 .52969 Mdot
.83221 .52968 Mdot
.83222 .52966 Mdot
.83223 .52965 Mdot
.83224 .52964 Mdot
.83225 .52963 Mdot
.83226 .52962 Mdot
.83227 .52961 Mdot
.83228 .5296 Mdot
.83229 .52959 Mdot
.8323 .52958 Mdot
.8323 .52956 Mdot
.83231 .52955 Mdot
.83232 .52954 Mdot
.83233 .52953 Mdot
.83234 .52952 Mdot
.83235 .52951 Mdot
.83236 .5295 Mdot
.83237 .52949 Mdot
.83238 .52947 Mdot
.83239 .52946 Mdot
.8324 .52945 Mdot
.83241 .52944 Mdot
.83242 .52943 Mdot
.83243 .52942 Mdot
.83244 .52941 Mdot
.83245 .5294 Mdot
.83246 .52939 Mdot
.83247 .52937 Mdot
.83248 .52936 Mdot
.83249 .52935 Mdot
.8325 .52934 Mdot
.8325 .52933 Mdot
.83251 .52932 Mdot
.83252 .52931 Mdot
.83253 .5293 Mdot
.83254 .52929 Mdot
.83255 .52927 Mdot
.83256 .52926 Mdot
.83257 .52925 Mdot
.83258 .52924 Mdot
.83259 .52923 Mdot
.8326 .52922 Mdot
.83261 .52921 Mdot
.83262 .5292 Mdot
.83263 .52919 Mdot
.83264 .52917 Mdot
.83265 .52916 Mdot
.83266 .52915 Mdot
.83267 .52914 Mdot
.83268 .52913 Mdot
.83269 .52912 Mdot
.8327 .52911 Mdot
.8327 .5291 Mdot
.83271 .52908 Mdot
.83272 .52907 Mdot
.83273 .52906 Mdot
.83274 .52905 Mdot
.83275 .52904 Mdot
.83276 .52903 Mdot
.83277 .52902 Mdot
.83278 .52901 Mdot
.83279 .529 Mdot
.8328 .52898 Mdot
.83281 .52897 Mdot
.83282 .52896 Mdot
.83283 .52895 Mdot
.83284 .52894 Mdot
.83285 .52893 Mdot
.83286 .52892 Mdot
.83287 .52891 Mdot
.83288 .5289 Mdot
.83289 .52888 Mdot
.8329 .52887 Mdot
.8329 .52886 Mdot
.83291 .52885 Mdot
.83292 .52884 Mdot
.83293 .52883 Mdot
.83294 .52882 Mdot
.83295 .52881 Mdot
.83296 .52879 Mdot
.83297 .52878 Mdot
.83298 .52877 Mdot
.83299 .52876 Mdot
.833 .52875 Mdot
.83301 .52874 Mdot
.83302 .52873 Mdot
.83303 .52872 Mdot
.83304 .52871 Mdot
.83305 .52869 Mdot
.83306 .52868 Mdot
.83307 .52867 Mdot
.83308 .52866 Mdot
.83309 .52865 Mdot
.8331 .52864 Mdot
.8331 .52863 Mdot
.83311 .52862 Mdot
.83312 .5286 Mdot
.83313 .52859 Mdot
.83314 .52858 Mdot
.83315 .52857 Mdot
.83316 .52856 Mdot
.83317 .52855 Mdot
.83318 .52854 Mdot
.83319 .52853 Mdot
.8332 .52852 Mdot
.83321 .5285 Mdot
.83322 .52849 Mdot
.83323 .52848 Mdot
.83324 .52847 Mdot
.83325 .52846 Mdot
.83326 .52845 Mdot
.83327 .52844 Mdot
.83328 .52843 Mdot
.83329 .52841 Mdot
.8333 .5284 Mdot
.8333 .52839 Mdot
.83331 .52838 Mdot
.83332 .52837 Mdot
.83333 .52836 Mdot
.83334 .52835 Mdot
.83335 .52834 Mdot
.83336 .52833 Mdot
.83337 .52831 Mdot
.83338 .5283 Mdot
.83339 .52829 Mdot
.8334 .52828 Mdot
.83341 .52827 Mdot
.83342 .52826 Mdot
.83343 .52825 Mdot
.83344 .52824 Mdot
.83345 .52822 Mdot
.83346 .52821 Mdot
.83347 .5282 Mdot
.83348 .52819 Mdot
.83349 .52818 Mdot
.8335 .52817 Mdot
.8335 .52816 Mdot
.83351 .52815 Mdot
.83352 .52813 Mdot
.83353 .52812 Mdot
.83354 .52811 Mdot
.83355 .5281 Mdot
.83356 .52809 Mdot
.83357 .52808 Mdot
.83358 .52807 Mdot
.83359 .52806 Mdot
.8336 .52804 Mdot
.83361 .52803 Mdot
.83362 .52802 Mdot
.83363 .52801 Mdot
.83364 .528 Mdot
.83365 .52799 Mdot
.83366 .52798 Mdot
.83367 .52797 Mdot
.83368 .52796 Mdot
.83369 .52794 Mdot
.8337 .52793 Mdot
.8337 .52792 Mdot
.83371 .52791 Mdot
.83372 .5279 Mdot
.83373 .52789 Mdot
.83374 .52788 Mdot
.83375 .52787 Mdot
.83376 .52785 Mdot
.83377 .52784 Mdot
.83378 .52783 Mdot
.83379 .52782 Mdot
.8338 .52781 Mdot
.83381 .5278 Mdot
.83382 .52779 Mdot
.83383 .52778 Mdot
.83384 .52776 Mdot
.83385 .52775 Mdot
.83386 .52774 Mdot
.83387 .52773 Mdot
.83388 .52772 Mdot
.83389 .52771 Mdot
.8339 .5277 Mdot
.8339 .52769 Mdot
.83391 .52767 Mdot
.83392 .52766 Mdot
.83393 .52765 Mdot
.83394 .52764 Mdot
.83395 .52763 Mdot
.83396 .52762 Mdot
.83397 .52761 Mdot
.83398 .5276 Mdot
.83399 .52758 Mdot
.834 .52757 Mdot
.83401 .52756 Mdot
.83402 .52755 Mdot
.83403 .52754 Mdot
.83404 .52753 Mdot
.83405 .52752 Mdot
.83406 .52751 Mdot
.83407 .52749 Mdot
.83408 .52748 Mdot
.83409 .52747 Mdot
.8341 .52746 Mdot
.8341 .52745 Mdot
.83411 .52744 Mdot
.83412 .52743 Mdot
.83413 .52742 Mdot
.83414 .5274 Mdot
.83415 .52739 Mdot
.83416 .52738 Mdot
.83417 .52737 Mdot
.83418 .52736 Mdot
.83419 .52735 Mdot
.8342 .52734 Mdot
.83421 .52733 Mdot
.83422 .52731 Mdot
.83423 .5273 Mdot
.83424 .52729 Mdot
.83425 .52728 Mdot
.83426 .52727 Mdot
.83427 .52726 Mdot
.83428 .52725 Mdot
.83429 .52724 Mdot
.8343 .52722 Mdot
.8343 .52721 Mdot
.83431 .5272 Mdot
.83432 .52719 Mdot
.83433 .52718 Mdot
.83434 .52717 Mdot
.83435 .52716 Mdot
.83436 .52715 Mdot
.83437 .52713 Mdot
.83438 .52712 Mdot
.83439 .52711 Mdot
.8344 .5271 Mdot
.83441 .52709 Mdot
.83442 .52708 Mdot
.83443 .52707 Mdot
.83444 .52706 Mdot
.83445 .52704 Mdot
.83446 .52703 Mdot
.83447 .52702 Mdot
.83448 .52701 Mdot
.83449 .527 Mdot
.8345 .52699 Mdot
.8345 .52698 Mdot
.83451 .52696 Mdot
.83452 .52695 Mdot
.83453 .52694 Mdot
.83454 .52693 Mdot
.83455 .52692 Mdot
.83456 .52691 Mdot
.83457 .5269 Mdot
.83458 .52689 Mdot
.83459 .52687 Mdot
.8346 .52686 Mdot
.83461 .52685 Mdot
.83462 .52684 Mdot
.83463 .52683 Mdot
.83464 .52682 Mdot
.83465 .52681 Mdot
.83466 .5268 Mdot
.83467 .52678 Mdot
.83468 .52677 Mdot
.83469 .52676 Mdot
.8347 .52675 Mdot
.8347 .52674 Mdot
.83471 .52673 Mdot
.83472 .52672 Mdot
.83473 .52671 Mdot
.83474 .52669 Mdot
.83475 .52668 Mdot
.83476 .52667 Mdot
.83477 .52666 Mdot
.83478 .52665 Mdot
.83479 .52664 Mdot
.8348 .52663 Mdot
.83481 .52661 Mdot
.83482 .5266 Mdot
.83483 .52659 Mdot
.83484 .52658 Mdot
.83485 .52657 Mdot
.83486 .52656 Mdot
.83487 .52655 Mdot
.83488 .52654 Mdot
.83489 .52652 Mdot
.8349 .52651 Mdot
.8349 .5265 Mdot
.83491 .52649 Mdot
.83492 .52648 Mdot
.83493 .52647 Mdot
.83494 .52646 Mdot
.83495 .52645 Mdot
.83496 .52643 Mdot
.83497 .52642 Mdot
.83498 .52641 Mdot
.83499 .5264 Mdot
.835 .52639 Mdot
.83501 .52638 Mdot
.83502 .52637 Mdot
.83503 .52635 Mdot
.83504 .52634 Mdot
.83505 .52633 Mdot
.83506 .52632 Mdot
.83507 .52631 Mdot
.83508 .5263 Mdot
.83509 .52629 Mdot
.8351 .52628 Mdot
.8351 .52626 Mdot
.83511 .52625 Mdot
.83512 .52624 Mdot
.83513 .52623 Mdot
.83514 .52622 Mdot
.83515 .52621 Mdot
.83516 .5262 Mdot
.83517 .52618 Mdot
.83518 .52617 Mdot
.83519 .52616 Mdot
.8352 .52615 Mdot
.83521 .52614 Mdot
.83522 .52613 Mdot
.83523 .52612 Mdot
.83524 .52611 Mdot
.83525 .52609 Mdot
.83526 .52608 Mdot
.83527 .52607 Mdot
.83528 .52606 Mdot
.83529 .52605 Mdot
.8353 .52604 Mdot
.8353 .52603 Mdot
.83531 .52601 Mdot
.83532 .526 Mdot
.83533 .52599 Mdot
.83534 .52598 Mdot
.83535 .52597 Mdot
.83536 .52596 Mdot
.83537 .52595 Mdot
.83538 .52594 Mdot
.83539 .52592 Mdot
.8354 .52591 Mdot
.83541 .5259 Mdot
.83542 .52589 Mdot
.83543 .52588 Mdot
.83544 .52587 Mdot
.83545 .52586 Mdot
.83546 .52584 Mdot
.83547 .52583 Mdot
.83548 .52582 Mdot
.83549 .52581 Mdot
.8355 .5258 Mdot
.8355 .52579 Mdot
.83551 .52578 Mdot
.83552 .52577 Mdot
.83553 .52575 Mdot
.83554 .52574 Mdot
.83555 .52573 Mdot
.83556 .52572 Mdot
.83557 .52571 Mdot
.83558 .5257 Mdot
.83559 .52569 Mdot
.8356 .52567 Mdot
.83561 .52566 Mdot
.83562 .52565 Mdot
.83563 .52564 Mdot
.83564 .52563 Mdot
.83565 .52562 Mdot
.83566 .52561 Mdot
.83567 .52559 Mdot
.83568 .52558 Mdot
.83569 .52557 Mdot
.8357 .52556 Mdot
.8357 .52555 Mdot
.83571 .52554 Mdot
.83572 .52553 Mdot
.83573 .52552 Mdot
.83574 .5255 Mdot
.83575 .52549 Mdot
.83576 .52548 Mdot
.83577 .52547 Mdot
.83578 .52546 Mdot
.83579 .52545 Mdot
.8358 .52544 Mdot
.83581 .52542 Mdot
.83582 .52541 Mdot
.83583 .5254 Mdot
.83584 .52539 Mdot
.83585 .52538 Mdot
.83586 .52537 Mdot
.83587 .52536 Mdot
.83588 .52534 Mdot
.83589 .52533 Mdot
.8359 .52532 Mdot
.8359 .52531 Mdot
.83591 .5253 Mdot
.83592 .52529 Mdot
.83593 .52528 Mdot
.83594 .52527 Mdot
.83595 .52525 Mdot
.83596 .52524 Mdot
.83597 .52523 Mdot
.83598 .52522 Mdot
.83599 .52521 Mdot
.836 .5252 Mdot
.83601 .52519 Mdot
.83602 .52517 Mdot
.83603 .52516 Mdot
.83604 .52515 Mdot
.83605 .52514 Mdot
.83606 .52513 Mdot
.83607 .52512 Mdot
.83608 .52511 Mdot
.83609 .52509 Mdot
.8361 .52508 Mdot
.8361 .52507 Mdot
.83611 .52506 Mdot
.83612 .52505 Mdot
.83613 .52504 Mdot
.83614 .52503 Mdot
.83615 .52501 Mdot
.83616 .525 Mdot
.83617 .52499 Mdot
.83618 .52498 Mdot
.83619 .52497 Mdot
.8362 .52496 Mdot
.83621 .52495 Mdot
.83622 .52493 Mdot
.83623 .52492 Mdot
.83624 .52491 Mdot
.83625 .5249 Mdot
.83626 .52489 Mdot
.83627 .52488 Mdot
.83628 .52487 Mdot
.83629 .52485 Mdot
.8363 .52484 Mdot
.8363 .52483 Mdot
.83631 .52482 Mdot
.83632 .52481 Mdot
.83633 .5248 Mdot
.83634 .52479 Mdot
.83635 .52478 Mdot
.83636 .52476 Mdot
.83637 .52475 Mdot
.83638 .52474 Mdot
.83639 .52473 Mdot
.8364 .52472 Mdot
.83641 .52471 Mdot
.83642 .5247 Mdot
.83643 .52468 Mdot
.83644 .52467 Mdot
.83645 .52466 Mdot
.83646 .52465 Mdot
.83647 .52464 Mdot
.83648 .52463 Mdot
.83649 .52462 Mdot
.8365 .5246 Mdot
.8365 .52459 Mdot
.83651 .52458 Mdot
.83652 .52457 Mdot
.83653 .52456 Mdot
.83654 .52455 Mdot
.83655 .52454 Mdot
.83656 .52452 Mdot
.83657 .52451 Mdot
.83658 .5245 Mdot
.83659 .52449 Mdot
.8366 .52448 Mdot
.83661 .52447 Mdot
.83662 .52446 Mdot
.83663 .52444 Mdot
.83664 .52443 Mdot
.83665 .52442 Mdot
.83666 .52441 Mdot
.83667 .5244 Mdot
.83668 .52439 Mdot
.83669 .52438 Mdot
.8367 .52436 Mdot
.8367 .52435 Mdot
.83671 .52434 Mdot
.83672 .52433 Mdot
.83673 .52432 Mdot
.83674 .52431 Mdot
.83675 .5243 Mdot
.83676 .52428 Mdot
.83677 .52427 Mdot
.83678 .52426 Mdot
.83679 .52425 Mdot
.8368 .52424 Mdot
.83681 .52423 Mdot
.83682 .52422 Mdot
.83683 .5242 Mdot
.83684 .52419 Mdot
.83685 .52418 Mdot
.83686 .52417 Mdot
.83687 .52416 Mdot
.83688 .52415 Mdot
.83689 .52413 Mdot
.8369 .52412 Mdot
.8369 .52411 Mdot
.83691 .5241 Mdot
.83692 .52409 Mdot
.83693 .52408 Mdot
.83694 .52407 Mdot
.83695 .52405 Mdot
.83696 .52404 Mdot
.83697 .52403 Mdot
.83698 .52402 Mdot
.83699 .52401 Mdot
.837 .524 Mdot
.83701 .52399 Mdot
.83702 .52397 Mdot
.83703 .52396 Mdot
.83704 .52395 Mdot
.83705 .52394 Mdot
.83706 .52393 Mdot
.83707 .52392 Mdot
.83708 .52391 Mdot
.83709 .52389 Mdot
.8371 .52388 Mdot
.8371 .52387 Mdot
.83711 .52386 Mdot
.83712 .52385 Mdot
.83713 .52384 Mdot
.83714 .52383 Mdot
.83715 .52381 Mdot
.83716 .5238 Mdot
.83717 .52379 Mdot
.83718 .52378 Mdot
.83719 .52377 Mdot
.8372 .52376 Mdot
.83721 .52375 Mdot
.83722 .52373 Mdot
.83723 .52372 Mdot
.83724 .52371 Mdot
.83725 .5237 Mdot
.83726 .52369 Mdot
.83727 .52368 Mdot
.83728 .52366 Mdot
.83729 .52365 Mdot
.8373 .52364 Mdot
.8373 .52363 Mdot
.83731 .52362 Mdot
.83732 .52361 Mdot
.83733 .5236 Mdot
.83734 .52358 Mdot
.83735 .52357 Mdot
.83736 .52356 Mdot
.83737 .52355 Mdot
.83738 .52354 Mdot
.83739 .52353 Mdot
.8374 .52352 Mdot
.83741 .5235 Mdot
.83742 .52349 Mdot
.83743 .52348 Mdot
.83744 .52347 Mdot
.83745 .52346 Mdot
.83746 .52345 Mdot
.83747 .52344 Mdot
.83748 .52342 Mdot
.83749 .52341 Mdot
.8375 .5234 Mdot
.8375 .52339 Mdot
.83751 .52338 Mdot
.83752 .52337 Mdot
.83753 .52335 Mdot
.83754 .52334 Mdot
.83755 .52333 Mdot
.83756 .52332 Mdot
.83757 .52331 Mdot
.83758 .5233 Mdot
.83759 .52329 Mdot
.8376 .52327 Mdot
.83761 .52326 Mdot
.83762 .52325 Mdot
.83763 .52324 Mdot
.83764 .52323 Mdot
.83765 .52322 Mdot
.83766 .52321 Mdot
.83767 .52319 Mdot
.83768 .52318 Mdot
.83769 .52317 Mdot
.8377 .52316 Mdot
.8377 .52315 Mdot
.83771 .52314 Mdot
.83772 .52312 Mdot
.83773 .52311 Mdot
.83774 .5231 Mdot
.83775 .52309 Mdot
.83776 .52308 Mdot
.83777 .52307 Mdot
.83778 .52306 Mdot
.83779 .52304 Mdot
.8378 .52303 Mdot
.83781 .52302 Mdot
.83782 .52301 Mdot
.83783 .523 Mdot
.83784 .52299 Mdot
.83785 .52298 Mdot
.83786 .52296 Mdot
.83787 .52295 Mdot
.83788 .52294 Mdot
.83789 .52293 Mdot
.8379 .52292 Mdot
.8379 .52291 Mdot
.83791 .52289 Mdot
.83792 .52288 Mdot
.83793 .52287 Mdot
.83794 .52286 Mdot
.83795 .52285 Mdot
.83796 .52284 Mdot
.83797 .52283 Mdot
.83798 .52281 Mdot
.83799 .5228 Mdot
.838 .52279 Mdot
.83801 .52278 Mdot
.83802 .52277 Mdot
.83803 .52276 Mdot
.83804 .52274 Mdot
.83805 .52273 Mdot
.83806 .52272 Mdot
.83807 .52271 Mdot
.83808 .5227 Mdot
.83809 .52269 Mdot
.8381 .52268 Mdot
.8381 .52266 Mdot
.83811 .52265 Mdot
.83812 .52264 Mdot
.83813 .52263 Mdot
.83814 .52262 Mdot
.83815 .52261 Mdot
.83816 .52259 Mdot
.83817 .52258 Mdot
.83818 .52257 Mdot
.83819 .52256 Mdot
.8382 .52255 Mdot
.83821 .52254 Mdot
.83822 .52253 Mdot
.83823 .52251 Mdot
.83824 .5225 Mdot
.83825 .52249 Mdot
.83826 .52248 Mdot
.83827 .52247 Mdot
.83828 .52246 Mdot
.83829 .52244 Mdot
.8383 .52243 Mdot
.8383 .52242 Mdot
.83831 .52241 Mdot
.83832 .5224 Mdot
.83833 .52239 Mdot
.83834 .52238 Mdot
.83835 .52236 Mdot
.83836 .52235 Mdot
.83837 .52234 Mdot
.83838 .52233 Mdot
.83839 .52232 Mdot
.8384 .52231 Mdot
.83841 .52229 Mdot
.83842 .52228 Mdot
.83843 .52227 Mdot
.83844 .52226 Mdot
.83845 .52225 Mdot
.83846 .52224 Mdot
.83847 .52223 Mdot
.83848 .52221 Mdot
.83849 .5222 Mdot
.8385 .52219 Mdot
.8385 .52218 Mdot
.83851 .52217 Mdot
.83852 .52216 Mdot
.83853 .52214 Mdot
.83854 .52213 Mdot
.83855 .52212 Mdot
.83856 .52211 Mdot
.83857 .5221 Mdot
.83858 .52209 Mdot
.83859 .52207 Mdot
.8386 .52206 Mdot
.83861 .52205 Mdot
.83862 .52204 Mdot
.83863 .52203 Mdot
.83864 .52202 Mdot
.83865 .52201 Mdot
.83866 .52199 Mdot
.83867 .52198 Mdot
.83868 .52197 Mdot
.83869 .52196 Mdot
.8387 .52195 Mdot
.8387 .52194 Mdot
.83871 .52192 Mdot
.83872 .52191 Mdot
.83873 .5219 Mdot
.83874 .52189 Mdot
.83875 .52188 Mdot
.83876 .52187 Mdot
.83877 .52186 Mdot
.83878 .52184 Mdot
.83879 .52183 Mdot
.8388 .52182 Mdot
.83881 .52181 Mdot
.83882 .5218 Mdot
.83883 .52179 Mdot
.83884 .52177 Mdot
.83885 .52176 Mdot
.83886 .52175 Mdot
.83887 .52174 Mdot
.83888 .52173 Mdot
.83889 .52172 Mdot
.8389 .5217 Mdot
.8389 .52169 Mdot
.83891 .52168 Mdot
.83892 .52167 Mdot
.83893 .52166 Mdot
.83894 .52165 Mdot
.83895 .52163 Mdot
.83896 .52162 Mdot
.83897 .52161 Mdot
.83898 .5216 Mdot
.83899 .52159 Mdot
.839 .52158 Mdot
.83901 .52157 Mdot
.83902 .52155 Mdot
.83903 .52154 Mdot
.83904 .52153 Mdot
.83905 .52152 Mdot
.83906 .52151 Mdot
.83907 .5215 Mdot
.83908 .52148 Mdot
.83909 .52147 Mdot
.8391 .52146 Mdot
.8391 .52145 Mdot
.83911 .52144 Mdot
.83912 .52143 Mdot
.83913 .52141 Mdot
.83914 .5214 Mdot
.83915 .52139 Mdot
.83916 .52138 Mdot
.83917 .52137 Mdot
.83918 .52136 Mdot
.83919 .52134 Mdot
.8392 .52133 Mdot
.83921 .52132 Mdot
.83922 .52131 Mdot
.83923 .5213 Mdot
.83924 .52129 Mdot
.83925 .52128 Mdot
.83926 .52126 Mdot
.83927 .52125 Mdot
.83928 .52124 Mdot
.83929 .52123 Mdot
.8393 .52122 Mdot
.8393 .52121 Mdot
.83931 .52119 Mdot
.83932 .52118 Mdot
.83933 .52117 Mdot
.83934 .52116 Mdot
.83935 .52115 Mdot
.83936 .52114 Mdot
.83937 .52112 Mdot
.83938 .52111 Mdot
.83939 .5211 Mdot
.8394 .52109 Mdot
.83941 .52108 Mdot
.83942 .52107 Mdot
.83943 .52105 Mdot
.83944 .52104 Mdot
.83945 .52103 Mdot
.83946 .52102 Mdot
.83947 .52101 Mdot
.83948 .521 Mdot
.83949 .52098 Mdot
.8395 .52097 Mdot
.8395 .52096 Mdot
.83951 .52095 Mdot
.83952 .52094 Mdot
.83953 .52093 Mdot
.83954 .52091 Mdot
.83955 .5209 Mdot
.83956 .52089 Mdot
.83957 .52088 Mdot
.83958 .52087 Mdot
.83959 .52086 Mdot
.8396 .52085 Mdot
.83961 .52083 Mdot
.83962 .52082 Mdot
.83963 .52081 Mdot
.83964 .5208 Mdot
.83965 .52079 Mdot
.83966 .52078 Mdot
.83967 .52076 Mdot
.83968 .52075 Mdot
.83969 .52074 Mdot
.8397 .52073 Mdot
.8397 .52072 Mdot
.83971 .52071 Mdot
.83972 .52069 Mdot
.83973 .52068 Mdot
.83974 .52067 Mdot
.83975 .52066 Mdot
.83976 .52065 Mdot
.83977 .52064 Mdot
.83978 .52062 Mdot
.83979 .52061 Mdot
.8398 .5206 Mdot
.83981 .52059 Mdot
.83982 .52058 Mdot
.83983 .52057 Mdot
.83984 .52055 Mdot
.83985 .52054 Mdot
.83986 .52053 Mdot
.83987 .52052 Mdot
.83988 .52051 Mdot
.83989 .5205 Mdot
.8399 .52048 Mdot
.8399 .52047 Mdot
.83991 .52046 Mdot
.83992 .52045 Mdot
.83993 .52044 Mdot
.83994 .52043 Mdot
.83995 .52041 Mdot
.83996 .5204 Mdot
.83997 .52039 Mdot
.83998 .52038 Mdot
.83999 .52037 Mdot
.84 .52036 Mdot
.84001 .52034 Mdot
.84002 .52033 Mdot
.84003 .52032 Mdot
.84004 .52031 Mdot
.84005 .5203 Mdot
.84006 .52029 Mdot
.84007 .52027 Mdot
.84008 .52026 Mdot
.84009 .52025 Mdot
.8401 .52024 Mdot
.8401 .52023 Mdot
.84011 .52022 Mdot
.84012 .5202 Mdot
.84013 .52019 Mdot
.84014 .52018 Mdot
.84015 .52017 Mdot
.84016 .52016 Mdot
.84017 .52015 Mdot
.84018 .52013 Mdot
.84019 .52012 Mdot
.8402 .52011 Mdot
.84021 .5201 Mdot
.84022 .52009 Mdot
.84023 .52008 Mdot
.84024 .52006 Mdot
.84025 .52005 Mdot
.84026 .52004 Mdot
.84027 .52003 Mdot
.84028 .52002 Mdot
.84029 .52001 Mdot
.8403 .51999 Mdot
.8403 .51998 Mdot
.84031 .51997 Mdot
.84032 .51996 Mdot
.84033 .51995 Mdot
.84034 .51994 Mdot
.84035 .51992 Mdot
.84036 .51991 Mdot
.84037 .5199 Mdot
.84038 .51989 Mdot
.84039 .51988 Mdot
.8404 .51987 Mdot
.84041 .51985 Mdot
.84042 .51984 Mdot
.84043 .51983 Mdot
.84044 .51982 Mdot
.84045 .51981 Mdot
.84046 .51979 Mdot
.84047 .51978 Mdot
.84048 .51977 Mdot
.84049 .51976 Mdot
.8405 .51975 Mdot
.8405 .51974 Mdot
.84051 .51972 Mdot
.84052 .51971 Mdot
.84053 .5197 Mdot
.84054 .51969 Mdot
.84055 .51968 Mdot
.84056 .51967 Mdot
.84057 .51965 Mdot
.84058 .51964 Mdot
.84059 .51963 Mdot
.8406 .51962 Mdot
.84061 .51961 Mdot
.84062 .5196 Mdot
.84063 .51958 Mdot
.84064 .51957 Mdot
.84065 .51956 Mdot
.84066 .51955 Mdot
.84067 .51954 Mdot
.84068 .51953 Mdot
.84069 .51951 Mdot
.8407 .5195 Mdot
.8407 .51949 Mdot
.84071 .51948 Mdot
.84072 .51947 Mdot
.84073 .51946 Mdot
.84074 .51944 Mdot
.84075 .51943 Mdot
.84076 .51942 Mdot
.84077 .51941 Mdot
.84078 .5194 Mdot
.84079 .51939 Mdot
.8408 .51937 Mdot
.84081 .51936 Mdot
.84082 .51935 Mdot
.84083 .51934 Mdot
.84084 .51933 Mdot
.84085 .51931 Mdot
.84086 .5193 Mdot
.84087 .51929 Mdot
.84088 .51928 Mdot
.84089 .51927 Mdot
.8409 .51926 Mdot
.8409 .51924 Mdot
.84091 .51923 Mdot
.84092 .51922 Mdot
.84093 .51921 Mdot
.84094 .5192 Mdot
.84095 .51919 Mdot
.84096 .51917 Mdot
.84097 .51916 Mdot
.84098 .51915 Mdot
.84099 .51914 Mdot
.841 .51913 Mdot
.84101 .51912 Mdot
.84102 .5191 Mdot
.84103 .51909 Mdot
.84104 .51908 Mdot
.84105 .51907 Mdot
.84106 .51906 Mdot
.84107 .51905 Mdot
.84108 .51903 Mdot
.84109 .51902 Mdot
.8411 .51901 Mdot
.8411 .519 Mdot
.84111 .51899 Mdot
.84112 .51897 Mdot
.84113 .51896 Mdot
.84114 .51895 Mdot
.84115 .51894 Mdot
.84116 .51893 Mdot
.84117 .51892 Mdot
.84118 .5189 Mdot
.84119 .51889 Mdot
.8412 .51888 Mdot
.84121 .51887 Mdot
.84122 .51886 Mdot
.84123 .51885 Mdot
.84124 .51883 Mdot
.84125 .51882 Mdot
.84126 .51881 Mdot
.84127 .5188 Mdot
.84128 .51879 Mdot
.84129 .51877 Mdot
.8413 .51876 Mdot
.8413 .51875 Mdot
.84131 .51874 Mdot
.84132 .51873 Mdot
.84133 .51872 Mdot
.84134 .5187 Mdot
.84135 .51869 Mdot
.84136 .51868 Mdot
.84137 .51867 Mdot
.84138 .51866 Mdot
.84139 .51865 Mdot
.8414 .51863 Mdot
.84141 .51862 Mdot
.84142 .51861 Mdot
.84143 .5186 Mdot
.84144 .51859 Mdot
.84145 .51858 Mdot
.84146 .51856 Mdot
.84147 .51855 Mdot
.84148 .51854 Mdot
.84149 .51853 Mdot
.8415 .51852 Mdot
.8415 .5185 Mdot
.84151 .51849 Mdot
.84152 .51848 Mdot
.84153 .51847 Mdot
.84154 .51846 Mdot
.84155 .51845 Mdot
.84156 .51843 Mdot
.84157 .51842 Mdot
.84158 .51841 Mdot
.84159 .5184 Mdot
.8416 .51839 Mdot
.84161 .51837 Mdot
.84162 .51836 Mdot
.84163 .51835 Mdot
.84164 .51834 Mdot
.84165 .51833 Mdot
.84166 .51832 Mdot
.84167 .5183 Mdot
.84168 .51829 Mdot
.84169 .51828 Mdot
.8417 .51827 Mdot
.8417 .51826 Mdot
.84171 .51825 Mdot
.84172 .51823 Mdot
.84173 .51822 Mdot
.84174 .51821 Mdot
.84175 .5182 Mdot
.84176 .51819 Mdot
.84177 .51817 Mdot
.84178 .51816 Mdot
.84179 .51815 Mdot
.8418 .51814 Mdot
.84181 .51813 Mdot
.84182 .51812 Mdot
.84183 .5181 Mdot
.84184 .51809 Mdot
.84185 .51808 Mdot
.84186 .51807 Mdot
.84187 .51806 Mdot
.84188 .51804 Mdot
.84189 .51803 Mdot
.8419 .51802 Mdot
.8419 .51801 Mdot
.84191 .518 Mdot
.84192 .51799 Mdot
.84193 .51797 Mdot
.84194 .51796 Mdot
.84195 .51795 Mdot
.84196 .51794 Mdot
.84197 .51793 Mdot
.84198 .51792 Mdot
.84199 .5179 Mdot
.842 .51789 Mdot
.84201 .51788 Mdot
.84202 .51787 Mdot
.84203 .51786 Mdot
.84204 .51784 Mdot
.84205 .51783 Mdot
.84206 .51782 Mdot
.84207 .51781 Mdot
.84208 .5178 Mdot
.84209 .51779 Mdot
.8421 .51777 Mdot
.8421 .51776 Mdot
.84211 .51775 Mdot
.84212 .51774 Mdot
.84213 .51773 Mdot
.84214 .51771 Mdot
.84215 .5177 Mdot
.84216 .51769 Mdot
.84217 .51768 Mdot
.84218 .51767 Mdot
.84219 .51766 Mdot
.8422 .51764 Mdot
.84221 .51763 Mdot
.84222 .51762 Mdot
.84223 .51761 Mdot
.84224 .5176 Mdot
.84225 .51758 Mdot
.84226 .51757 Mdot
.84227 .51756 Mdot
.84228 .51755 Mdot
.84229 .51754 Mdot
.8423 .51753 Mdot
.8423 .51751 Mdot
.84231 .5175 Mdot
.84232 .51749 Mdot
.84233 .51748 Mdot
.84234 .51747 Mdot
.84235 .51745 Mdot
.84236 .51744 Mdot
.84237 .51743 Mdot
.84238 .51742 Mdot
.84239 .51741 Mdot
.8424 .5174 Mdot
.84241 .51738 Mdot
.84242 .51737 Mdot
.84243 .51736 Mdot
.84244 .51735 Mdot
.84245 .51734 Mdot
.84246 .51732 Mdot
.84247 .51731 Mdot
.84248 .5173 Mdot
.84249 .51729 Mdot
.8425 .51728 Mdot
.8425 .51727 Mdot
.84251 .51725 Mdot
.84252 .51724 Mdot
.84253 .51723 Mdot
.84254 .51722 Mdot
.84255 .51721 Mdot
.84256 .51719 Mdot
.84257 .51718 Mdot
.84258 .51717 Mdot
.84259 .51716 Mdot
.8426 .51715 Mdot
.84261 .51713 Mdot
.84262 .51712 Mdot
.84263 .51711 Mdot
.84264 .5171 Mdot
.84265 .51709 Mdot
.84266 .51708 Mdot
.84267 .51706 Mdot
.84268 .51705 Mdot
.84269 .51704 Mdot
.8427 .51703 Mdot
.8427 .51702 Mdot
.84271 .517 Mdot
.84272 .51699 Mdot
.84273 .51698 Mdot
.84274 .51697 Mdot
.84275 .51696 Mdot
.84276 .51695 Mdot
.84277 .51693 Mdot
.84278 .51692 Mdot
.84279 .51691 Mdot
.8428 .5169 Mdot
.84281 .51689 Mdot
.84282 .51687 Mdot
.84283 .51686 Mdot
.84284 .51685 Mdot
.84285 .51684 Mdot
.84286 .51683 Mdot
.84287 .51681 Mdot
.84288 .5168 Mdot
.84289 .51679 Mdot
.8429 .51678 Mdot
.8429 .51677 Mdot
.84291 .51676 Mdot
.84292 .51674 Mdot
.84293 .51673 Mdot
.84294 .51672 Mdot
.84295 .51671 Mdot
.84296 .5167 Mdot
.84297 .51668 Mdot
.84298 .51667 Mdot
.84299 .51666 Mdot
.843 .51665 Mdot
.84301 .51664 Mdot
.84302 .51663 Mdot
.84303 .51661 Mdot
.84304 .5166 Mdot
.84305 .51659 Mdot
.84306 .51658 Mdot
.84307 .51657 Mdot
.84308 .51655 Mdot
.84309 .51654 Mdot
.8431 .51653 Mdot
.8431 .51652 Mdot
.84311 .51651 Mdot
.84312 .51649 Mdot
.84313 .51648 Mdot
.84314 .51647 Mdot
.84315 .51646 Mdot
.84316 .51645 Mdot
.84317 .51644 Mdot
.84318 .51642 Mdot
.84319 .51641 Mdot
.8432 .5164 Mdot
.84321 .51639 Mdot
.84322 .51638 Mdot
.84323 .51636 Mdot
.84324 .51635 Mdot
.84325 .51634 Mdot
.84326 .51633 Mdot
.84327 .51632 Mdot
.84328 .5163 Mdot
.84329 .51629 Mdot
.8433 .51628 Mdot
.8433 .51627 Mdot
.84331 .51626 Mdot
.84332 .51624 Mdot
.84333 .51623 Mdot
.84334 .51622 Mdot
.84335 .51621 Mdot
.84336 .5162 Mdot
.84337 .51619 Mdot
.84338 .51617 Mdot
.84339 .51616 Mdot
.8434 .51615 Mdot
.84341 .51614 Mdot
.84342 .51613 Mdot
.84343 .51611 Mdot
.84344 .5161 Mdot
.84345 .51609 Mdot
.84346 .51608 Mdot
.84347 .51607 Mdot
.84348 .51605 Mdot
.84349 .51604 Mdot
.8435 .51603 Mdot
.8435 .51602 Mdot
.84351 .51601 Mdot
.84352 .516 Mdot
.84353 .51598 Mdot
.84354 .51597 Mdot
.84355 .51596 Mdot
.84356 .51595 Mdot
.84357 .51594 Mdot
.84358 .51592 Mdot
.84359 .51591 Mdot
.8436 .5159 Mdot
.84361 .51589 Mdot
.84362 .51588 Mdot
.84363 .51586 Mdot
.84364 .51585 Mdot
.84365 .51584 Mdot
.84366 .51583 Mdot
.84367 .51582 Mdot
.84368 .5158 Mdot
.84369 .51579 Mdot
.8437 .51578 Mdot
.8437 .51577 Mdot
.84371 .51576 Mdot
.84372 .51574 Mdot
.84373 .51573 Mdot
.84374 .51572 Mdot
.84375 .51571 Mdot
.84376 .5157 Mdot
.84377 .51569 Mdot
.84378 .51567 Mdot
.84379 .51566 Mdot
.8438 .51565 Mdot
.84381 .51564 Mdot
.84382 .51563 Mdot
.84383 .51561 Mdot
.84384 .5156 Mdot
.84385 .51559 Mdot
.84386 .51558 Mdot
.84387 .51557 Mdot
.84388 .51555 Mdot
.84389 .51554 Mdot
.8439 .51553 Mdot
.8439 .51552 Mdot
.84391 .51551 Mdot
.84392 .51549 Mdot
.84393 .51548 Mdot
.84394 .51547 Mdot
.84395 .51546 Mdot
.84396 .51545 Mdot
.84397 .51543 Mdot
.84398 .51542 Mdot
.84399 .51541 Mdot
.844 .5154 Mdot
.84401 .51539 Mdot
.84402 .51538 Mdot
.84403 .51536 Mdot
.84404 .51535 Mdot
.84405 .51534 Mdot
.84406 .51533 Mdot
.84407 .51532 Mdot
.84408 .5153 Mdot
.84409 .51529 Mdot
.8441 .51528 Mdot
.8441 .51527 Mdot
.84411 .51526 Mdot
.84412 .51524 Mdot
.84413 .51523 Mdot
.84414 .51522 Mdot
.84415 .51521 Mdot
.84416 .5152 Mdot
.84417 .51518 Mdot
.84418 .51517 Mdot
.84419 .51516 Mdot
.8442 .51515 Mdot
.84421 .51514 Mdot
.84422 .51512 Mdot
.84423 .51511 Mdot
.84424 .5151 Mdot
.84425 .51509 Mdot
.84426 .51508 Mdot
.84427 .51506 Mdot
.84428 .51505 Mdot
.84429 .51504 Mdot
.8443 .51503 Mdot
.8443 .51502 Mdot
.84431 .515 Mdot
.84432 .51499 Mdot
.84433 .51498 Mdot
.84434 .51497 Mdot
.84435 .51496 Mdot
.84436 .51495 Mdot
.84437 .51493 Mdot
.84438 .51492 Mdot
.84439 .51491 Mdot
.8444 .5149 Mdot
.84441 .51489 Mdot
.84442 .51487 Mdot
.84443 .51486 Mdot
.84444 .51485 Mdot
.84445 .51484 Mdot
.84446 .51483 Mdot
.84447 .51481 Mdot
.84448 .5148 Mdot
.84449 .51479 Mdot
.8445 .51478 Mdot
.8445 .51477 Mdot
.84451 .51475 Mdot
.84452 .51474 Mdot
.84453 .51473 Mdot
.84454 .51472 Mdot
.84455 .51471 Mdot
.84456 .51469 Mdot
.84457 .51468 Mdot
.84458 .51467 Mdot
.84459 .51466 Mdot
.8446 .51465 Mdot
.84461 .51463 Mdot
.84462 .51462 Mdot
.84463 .51461 Mdot
.84464 .5146 Mdot
.84465 .51459 Mdot
.84466 .51457 Mdot
.84467 .51456 Mdot
.84468 .51455 Mdot
.84469 .51454 Mdot
.8447 .51453 Mdot
.8447 .51451 Mdot
.84471 .5145 Mdot
.84472 .51449 Mdot
.84473 .51448 Mdot
.84474 .51447 Mdot
.84475 .51445 Mdot
.84476 .51444 Mdot
.84477 .51443 Mdot
.84478 .51442 Mdot
.84479 .51441 Mdot
.8448 .51439 Mdot
.84481 .51438 Mdot
.84482 .51437 Mdot
.84483 .51436 Mdot
.84484 .51435 Mdot
.84485 .51433 Mdot
.84486 .51432 Mdot
.84487 .51431 Mdot
.84488 .5143 Mdot
.84489 .51429 Mdot
.8449 .51427 Mdot
.8449 .51426 Mdot
.84491 .51425 Mdot
.84492 .51424 Mdot
.84493 .51423 Mdot
.84494 .51421 Mdot
.84495 .5142 Mdot
.84496 .51419 Mdot
.84497 .51418 Mdot
.84498 .51417 Mdot
.84499 .51415 Mdot
.845 .51414 Mdot
.84501 .51413 Mdot
.84502 .51412 Mdot
.84503 .51411 Mdot
.84504 .51409 Mdot
.84505 .51408 Mdot
.84506 .51407 Mdot
.84507 .51406 Mdot
.84508 .51405 Mdot
.84509 .51403 Mdot
.8451 .51402 Mdot
.8451 .51401 Mdot
.84511 .514 Mdot
.84512 .51399 Mdot
.84513 .51397 Mdot
.84514 .51396 Mdot
.84515 .51395 Mdot
.84516 .51394 Mdot
.84517 .51393 Mdot
.84518 .51391 Mdot
.84519 .5139 Mdot
.8452 .51389 Mdot
.84521 .51388 Mdot
.84522 .51387 Mdot
.84523 .51385 Mdot
.84524 .51384 Mdot
.84525 .51383 Mdot
.84526 .51382 Mdot
.84527 .51381 Mdot
.84528 .51379 Mdot
.84529 .51378 Mdot
.8453 .51377 Mdot
.8453 .51376 Mdot
.84531 .51375 Mdot
.84532 .51373 Mdot
.84533 .51372 Mdot
.84534 .51371 Mdot
.84535 .5137 Mdot
.84536 .51369 Mdot
.84537 .51367 Mdot
.84538 .51366 Mdot
.84539 .51365 Mdot
.8454 .51364 Mdot
.84541 .51363 Mdot
.84542 .51361 Mdot
.84543 .5136 Mdot
.84544 .51359 Mdot
.84545 .51358 Mdot
.84546 .51357 Mdot
.84547 .51355 Mdot
.84548 .51354 Mdot
.84549 .51353 Mdot
.8455 .51352 Mdot
.8455 .51351 Mdot
.84551 .51349 Mdot
.84552 .51348 Mdot
.84553 .51347 Mdot
.84554 .51346 Mdot
.84555 .51345 Mdot
.84556 .51343 Mdot
.84557 .51342 Mdot
.84558 .51341 Mdot
.84559 .5134 Mdot
.8456 .51338 Mdot
.84561 .51337 Mdot
.84562 .51336 Mdot
.84563 .51335 Mdot
.84564 .51334 Mdot
.84565 .51332 Mdot
.84566 .51331 Mdot
.84567 .5133 Mdot
.84568 .51329 Mdot
.84569 .51328 Mdot
.8457 .51326 Mdot
.8457 .51325 Mdot
.84571 .51324 Mdot
.84572 .51323 Mdot
.84573 .51322 Mdot
.84574 .5132 Mdot
.84575 .51319 Mdot
.84576 .51318 Mdot
.84577 .51317 Mdot
.84578 .51316 Mdot
.84579 .51314 Mdot
.8458 .51313 Mdot
.84581 .51312 Mdot
.84582 .51311 Mdot
.84583 .5131 Mdot
.84584 .51308 Mdot
.84585 .51307 Mdot
.84586 .51306 Mdot
.84587 .51305 Mdot
.84588 .51304 Mdot
.84589 .51302 Mdot
.8459 .51301 Mdot
.8459 .513 Mdot
.84591 .51299 Mdot
.84592 .51297 Mdot
.84593 .51296 Mdot
.84594 .51295 Mdot
.84595 .51294 Mdot
.84596 .51293 Mdot
.84597 .51291 Mdot
.84598 .5129 Mdot
.84599 .51289 Mdot
.846 .51288 Mdot
.84601 .51287 Mdot
.84602 .51285 Mdot
.84603 .51284 Mdot
.84604 .51283 Mdot
.84605 .51282 Mdot
.84606 .51281 Mdot
.84607 .51279 Mdot
.84608 .51278 Mdot
.84609 .51277 Mdot
.8461 .51276 Mdot
.8461 .51275 Mdot
.84611 .51273 Mdot
.84612 .51272 Mdot
.84613 .51271 Mdot
.84614 .5127 Mdot
.84615 .51269 Mdot
.84616 .51267 Mdot
.84617 .51266 Mdot
.84618 .51265 Mdot
.84619 .51264 Mdot
.8462 .51262 Mdot
.84621 .51261 Mdot
.84622 .5126 Mdot
.84623 .51259 Mdot
.84624 .51258 Mdot
.84625 .51256 Mdot
.84626 .51255 Mdot
.84627 .51254 Mdot
.84628 .51253 Mdot
.84629 .51252 Mdot
.8463 .5125 Mdot
.8463 .51249 Mdot
.84631 .51248 Mdot
.84632 .51247 Mdot
.84633 .51246 Mdot
.84634 .51244 Mdot
.84635 .51243 Mdot
.84636 .51242 Mdot
.84637 .51241 Mdot
.84638 .5124 Mdot
.84639 .51238 Mdot
.8464 .51237 Mdot
.84641 .51236 Mdot
.84642 .51235 Mdot
.84643 .51233 Mdot
.84644 .51232 Mdot
.84645 .51231 Mdot
.84646 .5123 Mdot
.84647 .51229 Mdot
.84648 .51227 Mdot
.84649 .51226 Mdot
.8465 .51225 Mdot
.8465 .51224 Mdot
.84651 .51223 Mdot
.84652 .51221 Mdot
.84653 .5122 Mdot
.84654 .51219 Mdot
.84655 .51218 Mdot
.84656 .51217 Mdot
.84657 .51215 Mdot
.84658 .51214 Mdot
.84659 .51213 Mdot
.8466 .51212 Mdot
.84661 .5121 Mdot
.84662 .51209 Mdot
.84663 .51208 Mdot
.84664 .51207 Mdot
.84665 .51206 Mdot
.84666 .51204 Mdot
.84667 .51203 Mdot
.84668 .51202 Mdot
.84669 .51201 Mdot
.8467 .512 Mdot
.8467 .51198 Mdot
.84671 .51197 Mdot
.84672 .51196 Mdot
.84673 .51195 Mdot
.84674 .51194 Mdot
.84675 .51192 Mdot
.84676 .51191 Mdot
.84677 .5119 Mdot
.84678 .51189 Mdot
.84679 .51187 Mdot
.8468 .51186 Mdot
.84681 .51185 Mdot
.84682 .51184 Mdot
.84683 .51183 Mdot
.84684 .51181 Mdot
.84685 .5118 Mdot
.84686 .51179 Mdot
.84687 .51178 Mdot
.84688 .51177 Mdot
.84689 .51175 Mdot
.8469 .51174 Mdot
.8469 .51173 Mdot
.84691 .51172 Mdot
.84692 .5117 Mdot
.84693 .51169 Mdot
.84694 .51168 Mdot
.84695 .51167 Mdot
.84696 .51166 Mdot
.84697 .51164 Mdot
.84698 .51163 Mdot
.84699 .51162 Mdot
.847 .51161 Mdot
.84701 .5116 Mdot
.84702 .51158 Mdot
.84703 .51157 Mdot
.84704 .51156 Mdot
.84705 .51155 Mdot
.84706 .51153 Mdot
.84707 .51152 Mdot
.84708 .51151 Mdot
.84709 .5115 Mdot
.8471 .51149 Mdot
.8471 .51147 Mdot
.84711 .51146 Mdot
.84712 .51145 Mdot
.84713 .51144 Mdot
.84714 .51143 Mdot
.84715 .51141 Mdot
.84716 .5114 Mdot
.84717 .51139 Mdot
.84718 .51138 Mdot
.84719 .51136 Mdot
.8472 .51135 Mdot
.84721 .51134 Mdot
.84722 .51133 Mdot
.84723 .51132 Mdot
.84724 .5113 Mdot
.84725 .51129 Mdot
.84726 .51128 Mdot
.84727 .51127 Mdot
.84728 .51126 Mdot
.84729 .51124 Mdot
.8473 .51123 Mdot
.8473 .51122 Mdot
.84731 .51121 Mdot
.84732 .51119 Mdot
.84733 .51118 Mdot
.84734 .51117 Mdot
.84735 .51116 Mdot
.84736 .51115 Mdot
.84737 .51113 Mdot
.84738 .51112 Mdot
.84739 .51111 Mdot
.8474 .5111 Mdot
.84741 .51109 Mdot
.84742 .51107 Mdot
.84743 .51106 Mdot
.84744 .51105 Mdot
.84745 .51104 Mdot
.84746 .51102 Mdot
.84747 .51101 Mdot
.84748 .511 Mdot
.84749 .51099 Mdot
.8475 .51098 Mdot
.8475 .51096 Mdot
.84751 .51095 Mdot
.84752 .51094 Mdot
.84753 .51093 Mdot
.84754 .51092 Mdot
.84755 .5109 Mdot
.84756 .51089 Mdot
.84757 .51088 Mdot
.84758 .51087 Mdot
.84759 .51085 Mdot
.8476 .51084 Mdot
.84761 .51083 Mdot
.84762 .51082 Mdot
.84763 .51081 Mdot
.84764 .51079 Mdot
.84765 .51078 Mdot
.84766 .51077 Mdot
.84767 .51076 Mdot
.84768 .51074 Mdot
.84769 .51073 Mdot
.8477 .51072 Mdot
.8477 .51071 Mdot
.84771 .5107 Mdot
.84772 .51068 Mdot
.84773 .51067 Mdot
.84774 .51066 Mdot
.84775 .51065 Mdot
.84776 .51063 Mdot
.84777 .51062 Mdot
.84778 .51061 Mdot
.84779 .5106 Mdot
.8478 .51059 Mdot
.84781 .51057 Mdot
.84782 .51056 Mdot
.84783 .51055 Mdot
.84784 .51054 Mdot
.84785 .51053 Mdot
.84786 .51051 Mdot
.84787 .5105 Mdot
.84788 .51049 Mdot
.84789 .51048 Mdot
.8479 .51046 Mdot
.8479 .51045 Mdot
.84791 .51044 Mdot
.84792 .51043 Mdot
.84793 .51042 Mdot
.84794 .5104 Mdot
.84795 .51039 Mdot
.84796 .51038 Mdot
.84797 .51037 Mdot
.84798 .51035 Mdot
.84799 .51034 Mdot
.848 .51033 Mdot
.84801 .51032 Mdot
.84802 .51031 Mdot
.84803 .51029 Mdot
.84804 .51028 Mdot
.84805 .51027 Mdot
.84806 .51026 Mdot
.84807 .51024 Mdot
.84808 .51023 Mdot
.84809 .51022 Mdot
.8481 .51021 Mdot
.8481 .5102 Mdot
.84811 .51018 Mdot
.84812 .51017 Mdot
.84813 .51016 Mdot
.84814 .51015 Mdot
.84815 .51013 Mdot
.84816 .51012 Mdot
.84817 .51011 Mdot
.84818 .5101 Mdot
.84819 .51009 Mdot
.8482 .51007 Mdot
.84821 .51006 Mdot
.84822 .51005 Mdot
.84823 .51004 Mdot
.84824 .51002 Mdot
.84825 .51001 Mdot
.84826 .51 Mdot
.84827 .50999 Mdot
.84828 .50998 Mdot
.84829 .50996 Mdot
.8483 .50995 Mdot
.8483 .50994 Mdot
.84831 .50993 Mdot
.84832 .50991 Mdot
.84833 .5099 Mdot
.84834 .50989 Mdot
.84835 .50988 Mdot
.84836 .50987 Mdot
.84837 .50985 Mdot
.84838 .50984 Mdot
.84839 .50983 Mdot
.8484 .50982 Mdot
.84841 .5098 Mdot
.84842 .50979 Mdot
.84843 .50978 Mdot
.84844 .50977 Mdot
.84845 .50976 Mdot
.84846 .50974 Mdot
.84847 .50973 Mdot
.84848 .50972 Mdot
.84849 .50971 Mdot
.8485 .50969 Mdot
.8485 .50968 Mdot
.84851 .50967 Mdot
.84852 .50966 Mdot
.84853 .50965 Mdot
.84854 .50963 Mdot
.84855 .50962 Mdot
.84856 .50961 Mdot
.84857 .5096 Mdot
.84858 .50958 Mdot
.84859 .50957 Mdot
.8486 .50956 Mdot
.84861 .50955 Mdot
.84862 .50954 Mdot
.84863 .50952 Mdot
.84864 .50951 Mdot
.84865 .5095 Mdot
.84866 .50949 Mdot
.84867 .50947 Mdot
.84868 .50946 Mdot
.84869 .50945 Mdot
.8487 .50944 Mdot
.8487 .50943 Mdot
.84871 .50941 Mdot
.84872 .5094 Mdot
.84873 .50939 Mdot
.84874 .50938 Mdot
.84875 .50936 Mdot
.84876 .50935 Mdot
.84877 .50934 Mdot
.84878 .50933 Mdot
.84879 .50932 Mdot
.8488 .5093 Mdot
.84881 .50929 Mdot
.84882 .50928 Mdot
.84883 .50927 Mdot
.84884 .50925 Mdot
.84885 .50924 Mdot
.84886 .50923 Mdot
.84887 .50922 Mdot
.84888 .50921 Mdot
.84889 .50919 Mdot
.8489 .50918 Mdot
.8489 .50917 Mdot
.84891 .50916 Mdot
.84892 .50914 Mdot
.84893 .50913 Mdot
.84894 .50912 Mdot
.84895 .50911 Mdot
.84896 .50909 Mdot
.84897 .50908 Mdot
.84898 .50907 Mdot
.84899 .50906 Mdot
.849 .50905 Mdot
.84901 .50903 Mdot
.84902 .50902 Mdot
.84903 .50901 Mdot
.84904 .509 Mdot
.84905 .50898 Mdot
.84906 .50897 Mdot
.84907 .50896 Mdot
.84908 .50895 Mdot
.84909 .50894 Mdot
.8491 .50892 Mdot
.8491 .50891 Mdot
.84911 .5089 Mdot
.84912 .50889 Mdot
.84913 .50887 Mdot
.84914 .50886 Mdot
.84915 .50885 Mdot
.84916 .50884 Mdot
.84917 .50882 Mdot
.84918 .50881 Mdot
.84919 .5088 Mdot
.8492 .50879 Mdot
.84921 .50878 Mdot
.84922 .50876 Mdot
.84923 .50875 Mdot
.84924 .50874 Mdot
.84925 .50873 Mdot
.84926 .50871 Mdot
.84927 .5087 Mdot
.84928 .50869 Mdot
.84929 .50868 Mdot
.8493 .50867 Mdot
.8493 .50865 Mdot
.84931 .50864 Mdot
.84932 .50863 Mdot
.84933 .50862 Mdot
.84934 .5086 Mdot
.84935 .50859 Mdot
.84936 .50858 Mdot
.84937 .50857 Mdot
.84938 .50855 Mdot
.84939 .50854 Mdot
.8494 .50853 Mdot
.84941 .50852 Mdot
.84942 .50851 Mdot
.84943 .50849 Mdot
.84944 .50848 Mdot
.84945 .50847 Mdot
.84946 .50846 Mdot
.84947 .50844 Mdot
.84948 .50843 Mdot
.84949 .50842 Mdot
.8495 .50841 Mdot
.8495 .50839 Mdot
.84951 .50838 Mdot
.84952 .50837 Mdot
.84953 .50836 Mdot
.84954 .50835 Mdot
.84955 .50833 Mdot
.84956 .50832 Mdot
.84957 .50831 Mdot
.84958 .5083 Mdot
.84959 .50828 Mdot
.8496 .50827 Mdot
.84961 .50826 Mdot
.84962 .50825 Mdot
.84963 .50823 Mdot
.84964 .50822 Mdot
.84965 .50821 Mdot
.84966 .5082 Mdot
.84967 .50819 Mdot
.84968 .50817 Mdot
.84969 .50816 Mdot
.8497 .50815 Mdot
.8497 .50814 Mdot
.84971 .50812 Mdot
.84972 .50811 Mdot
.84973 .5081 Mdot
.84974 .50809 Mdot
.84975 .50807 Mdot
.84976 .50806 Mdot
.84977 .50805 Mdot
.84978 .50804 Mdot
.84979 .50803 Mdot
.8498 .50801 Mdot
.84981 .508 Mdot
.84982 .50799 Mdot
.84983 .50798 Mdot
.84984 .50796 Mdot
.84985 .50795 Mdot
.84986 .50794 Mdot
.84987 .50793 Mdot
.84988 .50791 Mdot
.84989 .5079 Mdot
.8499 .50789 Mdot
.8499 .50788 Mdot
.84991 .50787 Mdot
.84992 .50785 Mdot
.84993 .50784 Mdot
.84994 .50783 Mdot
.84995 .50782 Mdot
.84996 .5078 Mdot
.84997 .50779 Mdot
.84998 .50778 Mdot
.84999 .50777 Mdot
.85 .50775 Mdot
.85001 .50774 Mdot
.85002 .50773 Mdot
.85003 .50772 Mdot
.85004 .50771 Mdot
.85005 .50769 Mdot
.85006 .50768 Mdot
.85007 .50767 Mdot
.85008 .50766 Mdot
.85009 .50764 Mdot
.8501 .50763 Mdot
.8501 .50762 Mdot
.85011 .50761 Mdot
.85012 .50759 Mdot
.85013 .50758 Mdot
.85014 .50757 Mdot
.85015 .50756 Mdot
.85016 .50754 Mdot
.85017 .50753 Mdot
.85018 .50752 Mdot
.85019 .50751 Mdot
.8502 .5075 Mdot
.85021 .50748 Mdot
.85022 .50747 Mdot
.85023 .50746 Mdot
.85024 .50745 Mdot
.85025 .50743 Mdot
.85026 .50742 Mdot
.85027 .50741 Mdot
.85028 .5074 Mdot
.85029 .50738 Mdot
.8503 .50737 Mdot
.8503 .50736 Mdot
.85031 .50735 Mdot
.85032 .50733 Mdot
.85033 .50732 Mdot
.85034 .50731 Mdot
.85035 .5073 Mdot
.85036 .50729 Mdot
.85037 .50727 Mdot
.85038 .50726 Mdot
.85039 .50725 Mdot
.8504 .50724 Mdot
.85041 .50722 Mdot
.85042 .50721 Mdot
.85043 .5072 Mdot
.85044 .50719 Mdot
.85045 .50717 Mdot
.85046 .50716 Mdot
.85047 .50715 Mdot
.85048 .50714 Mdot
.85049 .50712 Mdot
.8505 .50711 Mdot
.8505 .5071 Mdot
.85051 .50709 Mdot
.85052 .50708 Mdot
.85053 .50706 Mdot
.85054 .50705 Mdot
.85055 .50704 Mdot
.85056 .50703 Mdot
.85057 .50701 Mdot
.85058 .507 Mdot
.85059 .50699 Mdot
.8506 .50698 Mdot
.85061 .50696 Mdot
.85062 .50695 Mdot
.85063 .50694 Mdot
.85064 .50693 Mdot
.85065 .50691 Mdot
.85066 .5069 Mdot
.85067 .50689 Mdot
.85068 .50688 Mdot
.85069 .50687 Mdot
.8507 .50685 Mdot
.8507 .50684 Mdot
.85071 .50683 Mdot
.85072 .50682 Mdot
.85073 .5068 Mdot
.85074 .50679 Mdot
.85075 .50678 Mdot
.85076 .50677 Mdot
.85077 .50675 Mdot
.85078 .50674 Mdot
.85079 .50673 Mdot
.8508 .50672 Mdot
.85081 .5067 Mdot
.85082 .50669 Mdot
.85083 .50668 Mdot
.85084 .50667 Mdot
.85085 .50665 Mdot
.85086 .50664 Mdot
.85087 .50663 Mdot
.85088 .50662 Mdot
.85089 .50661 Mdot
.8509 .50659 Mdot
.8509 .50658 Mdot
.85091 .50657 Mdot
.85092 .50656 Mdot
.85093 .50654 Mdot
.85094 .50653 Mdot
.85095 .50652 Mdot
.85096 .50651 Mdot
.85097 .50649 Mdot
.85098 .50648 Mdot
.85099 .50647 Mdot
.851 .50646 Mdot
.85101 .50644 Mdot
.85102 .50643 Mdot
.85103 .50642 Mdot
.85104 .50641 Mdot
.85105 .50639 Mdot
.85106 .50638 Mdot
.85107 .50637 Mdot
.85108 .50636 Mdot
.85109 .50634 Mdot
.8511 .50633 Mdot
.8511 .50632 Mdot
.85111 .50631 Mdot
.85112 .5063 Mdot
.85113 .50628 Mdot
.85114 .50627 Mdot
.85115 .50626 Mdot
.85116 .50625 Mdot
.85117 .50623 Mdot
.85118 .50622 Mdot
.85119 .50621 Mdot
.8512 .5062 Mdot
.85121 .50618 Mdot
.85122 .50617 Mdot
.85123 .50616 Mdot
.85124 .50615 Mdot
.85125 .50613 Mdot
.85126 .50612 Mdot
.85127 .50611 Mdot
.85128 .5061 Mdot
.85129 .50608 Mdot
.8513 .50607 Mdot
.8513 .50606 Mdot
.85131 .50605 Mdot
.85132 .50603 Mdot
.85133 .50602 Mdot
.85134 .50601 Mdot
.85135 .506 Mdot
.85136 .50599 Mdot
.85137 .50597 Mdot
.85138 .50596 Mdot
.85139 .50595 Mdot
.8514 .50594 Mdot
.85141 .50592 Mdot
.85142 .50591 Mdot
.85143 .5059 Mdot
.85144 .50589 Mdot
.85145 .50587 Mdot
.85146 .50586 Mdot
.85147 .50585 Mdot
.85148 .50584 Mdot
.85149 .50582 Mdot
.8515 .50581 Mdot
.8515 .5058 Mdot
.85151 .50579 Mdot
.85152 .50577 Mdot
.85153 .50576 Mdot
.85154 .50575 Mdot
.85155 .50574 Mdot
.85156 .50572 Mdot
.85157 .50571 Mdot
.85158 .5057 Mdot
.85159 .50569 Mdot
.8516 .50567 Mdot
.85161 .50566 Mdot
.85162 .50565 Mdot
.85163 .50564 Mdot
.85164 .50562 Mdot
.85165 .50561 Mdot
.85166 .5056 Mdot
.85167 .50559 Mdot
.85168 .50557 Mdot
.85169 .50556 Mdot
.8517 .50555 Mdot
.8517 .50554 Mdot
.85171 .50553 Mdot
.85172 .50551 Mdot
.85173 .5055 Mdot
.85174 .50549 Mdot
.85175 .50548 Mdot
.85176 .50546 Mdot
.85177 .50545 Mdot
.85178 .50544 Mdot
.85179 .50543 Mdot
.8518 .50541 Mdot
.85181 .5054 Mdot
.85182 .50539 Mdot
.85183 .50538 Mdot
.85184 .50536 Mdot
.85185 .50535 Mdot
.85186 .50534 Mdot
.85187 .50533 Mdot
.85188 .50531 Mdot
.85189 .5053 Mdot
.8519 .50529 Mdot
.8519 .50528 Mdot
.85191 .50526 Mdot
.85192 .50525 Mdot
.85193 .50524 Mdot
.85194 .50523 Mdot
.85195 .50521 Mdot
.85196 .5052 Mdot
.85197 .50519 Mdot
.85198 .50518 Mdot
.85199 .50516 Mdot
.852 .50515 Mdot
.85201 .50514 Mdot
.85202 .50513 Mdot
.85203 .50511 Mdot
.85204 .5051 Mdot
.85205 .50509 Mdot
.85206 .50508 Mdot
.85207 .50506 Mdot
.85208 .50505 Mdot
.85209 .50504 Mdot
.8521 .50503 Mdot
.8521 .50501 Mdot
.85211 .505 Mdot
.85212 .50499 Mdot
.85213 .50498 Mdot
.85214 .50496 Mdot
.85215 .50495 Mdot
.85216 .50494 Mdot
.85217 .50493 Mdot
.85218 .50491 Mdot
.85219 .5049 Mdot
.8522 .50489 Mdot
.85221 .50488 Mdot
.85222 .50487 Mdot
.85223 .50485 Mdot
.85224 .50484 Mdot
.85225 .50483 Mdot
.85226 .50482 Mdot
.85227 .5048 Mdot
.85228 .50479 Mdot
.85229 .50478 Mdot
.8523 .50477 Mdot
.8523 .50475 Mdot
.85231 .50474 Mdot
.85232 .50473 Mdot
.85233 .50472 Mdot
.85234 .5047 Mdot
.85235 .50469 Mdot
.85236 .50468 Mdot
.85237 .50467 Mdot
.85238 .50465 Mdot
.85239 .50464 Mdot
.8524 .50463 Mdot
.85241 .50462 Mdot
.85242 .5046 Mdot
.85243 .50459 Mdot
.85244 .50458 Mdot
.85245 .50457 Mdot
.85246 .50455 Mdot
.85247 .50454 Mdot
.85248 .50453 Mdot
.85249 .50452 Mdot
.8525 .5045 Mdot
.8525 .50449 Mdot
.85251 .50448 Mdot
.85252 .50447 Mdot
.85253 .50445 Mdot
.85254 .50444 Mdot
.85255 .50443 Mdot
.85256 .50442 Mdot
.85257 .5044 Mdot
.85258 .50439 Mdot
.85259 .50438 Mdot
.8526 .50437 Mdot
.85261 .50435 Mdot
.85262 .50434 Mdot
.85263 .50433 Mdot
.85264 .50432 Mdot
.85265 .5043 Mdot
.85266 .50429 Mdot
.85267 .50428 Mdot
.85268 .50427 Mdot
.85269 .50425 Mdot
.8527 .50424 Mdot
.8527 .50423 Mdot
.85271 .50422 Mdot
.85272 .5042 Mdot
.85273 .50419 Mdot
.85274 .50418 Mdot
.85275 .50417 Mdot
.85276 .50415 Mdot
.85277 .50414 Mdot
.85278 .50413 Mdot
.85279 .50412 Mdot
.8528 .5041 Mdot
.85281 .50409 Mdot
.85282 .50408 Mdot
.85283 .50407 Mdot
.85284 .50405 Mdot
.85285 .50404 Mdot
.85286 .50403 Mdot
.85287 .50402 Mdot
.85288 .504 Mdot
.85289 .50399 Mdot
.8529 .50398 Mdot
.8529 .50397 Mdot
.85291 .50395 Mdot
.85292 .50394 Mdot
.85293 .50393 Mdot
.85294 .50392 Mdot
.85295 .5039 Mdot
.85296 .50389 Mdot
.85297 .50388 Mdot
.85298 .50387 Mdot
.85299 .50385 Mdot
.853 .50384 Mdot
.85301 .50383 Mdot
.85302 .50382 Mdot
.85303 .5038 Mdot
.85304 .50379 Mdot
.85305 .50378 Mdot
.85306 .50377 Mdot
.85307 .50375 Mdot
.85308 .50374 Mdot
.85309 .50373 Mdot
.8531 .50372 Mdot
.8531 .5037 Mdot
.85311 .50369 Mdot
.85312 .50368 Mdot
.85313 .50367 Mdot
.85314 .50365 Mdot
.85315 .50364 Mdot
.85316 .50363 Mdot
.85317 .50362 Mdot
.85318 .5036 Mdot
.85319 .50359 Mdot
.8532 .50358 Mdot
.85321 .50356 Mdot
.85322 .50355 Mdot
.85323 .50354 Mdot
.85324 .50353 Mdot
.85325 .50351 Mdot
.85326 .5035 Mdot
.85327 .50349 Mdot
.85328 .50348 Mdot
.85329 .50346 Mdot
.8533 .50345 Mdot
.8533 .50344 Mdot
.85331 .50343 Mdot
.85332 .50341 Mdot
.85333 .5034 Mdot
.85334 .50339 Mdot
.85335 .50338 Mdot
.85336 .50336 Mdot
.85337 .50335 Mdot
.85338 .50334 Mdot
.85339 .50333 Mdot
.8534 .50331 Mdot
.85341 .5033 Mdot
.85342 .50329 Mdot
.85343 .50328 Mdot
.85344 .50326 Mdot
.85345 .50325 Mdot
.85346 .50324 Mdot
.85347 .50323 Mdot
.85348 .50321 Mdot
.85349 .5032 Mdot
.8535 .50319 Mdot
.8535 .50318 Mdot
.85351 .50316 Mdot
.85352 .50315 Mdot
.85353 .50314 Mdot
.85354 .50313 Mdot
.85355 .50311 Mdot
.85356 .5031 Mdot
.85357 .50309 Mdot
.85358 .50308 Mdot
.85359 .50306 Mdot
.8536 .50305 Mdot
.85361 .50304 Mdot
.85362 .50303 Mdot
.85363 .50301 Mdot
.85364 .503 Mdot
.85365 .50299 Mdot
.85366 .50298 Mdot
.85367 .50296 Mdot
.85368 .50295 Mdot
.85369 .50294 Mdot
.8537 .50292 Mdot
.8537 .50291 Mdot
.85371 .5029 Mdot
.85372 .50289 Mdot
.85373 .50287 Mdot
.85374 .50286 Mdot
.85375 .50285 Mdot
.85376 .50284 Mdot
.85377 .50282 Mdot
.85378 .50281 Mdot
.85379 .5028 Mdot
.8538 .50279 Mdot
.85381 .50277 Mdot
.85382 .50276 Mdot
.85383 .50275 Mdot
.85384 .50274 Mdot
.85385 .50272 Mdot
.85386 .50271 Mdot
.85387 .5027 Mdot
.85388 .50269 Mdot
.85389 .50267 Mdot
.8539 .50266 Mdot
.8539 .50265 Mdot
.85391 .50264 Mdot
.85392 .50262 Mdot
.85393 .50261 Mdot
.85394 .5026 Mdot
.85395 .50259 Mdot
.85396 .50257 Mdot
.85397 .50256 Mdot
.85398 .50255 Mdot
.85399 .50254 Mdot
.854 .50252 Mdot
.85401 .50251 Mdot
.85402 .5025 Mdot
.85403 .50248 Mdot
.85404 .50247 Mdot
.85405 .50246 Mdot
.85406 .50245 Mdot
.85407 .50243 Mdot
.85408 .50242 Mdot
.85409 .50241 Mdot
.8541 .5024 Mdot
.8541 .50238 Mdot
.85411 .50237 Mdot
.85412 .50236 Mdot
.85413 .50235 Mdot
.85414 .50233 Mdot
.85415 .50232 Mdot
.85416 .50231 Mdot
.85417 .5023 Mdot
.85418 .50228 Mdot
.85419 .50227 Mdot
.8542 .50226 Mdot
.85421 .50225 Mdot
.85422 .50223 Mdot
.85423 .50222 Mdot
.85424 .50221 Mdot
.85425 .5022 Mdot
.85426 .50218 Mdot
.85427 .50217 Mdot
.85428 .50216 Mdot
.85429 .50214 Mdot
.8543 .50213 Mdot
.8543 .50212 Mdot
.85431 .50211 Mdot
.85432 .50209 Mdot
.85433 .50208 Mdot
.85434 .50207 Mdot
.85435 .50206 Mdot
.85436 .50204 Mdot
.85437 .50203 Mdot
.85438 .50202 Mdot
.85439 .50201 Mdot
.8544 .50199 Mdot
.85441 .50198 Mdot
.85442 .50197 Mdot
.85443 .50196 Mdot
.85444 .50194 Mdot
.85445 .50193 Mdot
.85446 .50192 Mdot
.85447 .50191 Mdot
.85448 .50189 Mdot
.85449 .50188 Mdot
.8545 .50187 Mdot
.8545 .50185 Mdot
.85451 .50184 Mdot
.85452 .50183 Mdot
.85453 .50182 Mdot
.85454 .5018 Mdot
.85455 .50179 Mdot
.85456 .50178 Mdot
.85457 .50177 Mdot
.85458 .50175 Mdot
.85459 .50174 Mdot
.8546 .50173 Mdot
.85461 .50172 Mdot
.85462 .5017 Mdot
.85463 .50169 Mdot
.85464 .50168 Mdot
.85465 .50167 Mdot
.85466 .50165 Mdot
.85467 .50164 Mdot
.85468 .50163 Mdot
.85469 .50162 Mdot
.8547 .5016 Mdot
.8547 .50159 Mdot
.85471 .50158 Mdot
.85472 .50156 Mdot
.85473 .50155 Mdot
.85474 .50154 Mdot
.85475 .50153 Mdot
.85476 .50151 Mdot
.85477 .5015 Mdot
.85478 .50149 Mdot
.85479 .50148 Mdot
.8548 .50146 Mdot
.85481 .50145 Mdot
.85482 .50144 Mdot
.85483 .50143 Mdot
.85484 .50141 Mdot
.85485 .5014 Mdot
.85486 .50139 Mdot
.85487 .50138 Mdot
.85488 .50136 Mdot
.85489 .50135 Mdot
.8549 .50134 Mdot
.8549 .50132 Mdot
.85491 .50131 Mdot
.85492 .5013 Mdot
.85493 .50129 Mdot
.85494 .50127 Mdot
.85495 .50126 Mdot
.85496 .50125 Mdot
.85497 .50124 Mdot
.85498 .50122 Mdot
.85499 .50121 Mdot
.855 .5012 Mdot
.85501 .50119 Mdot
.85502 .50117 Mdot
.85503 .50116 Mdot
.85504 .50115 Mdot
.85505 .50113 Mdot
.85506 .50112 Mdot
.85507 .50111 Mdot
.85508 .5011 Mdot
.85509 .50108 Mdot
.8551 .50107 Mdot
.8551 .50106 Mdot
.85511 .50105 Mdot
.85512 .50103 Mdot
.85513 .50102 Mdot
.85514 .50101 Mdot
.85515 .501 Mdot
.85516 .50098 Mdot
.85517 .50097 Mdot
.85518 .50096 Mdot
.85519 .50095 Mdot
.8552 .50093 Mdot
.85521 .50092 Mdot
.85522 .50091 Mdot
.85523 .50089 Mdot
.85524 .50088 Mdot
.85525 .50087 Mdot
.85526 .50086 Mdot
.85527 .50084 Mdot
.85528 .50083 Mdot
.85529 .50082 Mdot
.8553 .50081 Mdot
.8553 .50079 Mdot
.85531 .50078 Mdot
.85532 .50077 Mdot
.85533 .50076 Mdot
.85534 .50074 Mdot
.85535 .50073 Mdot
.85536 .50072 Mdot
.85537 .5007 Mdot
.85538 .50069 Mdot
.85539 .50068 Mdot
.8554 .50067 Mdot
.85541 .50065 Mdot
.85542 .50064 Mdot
.85543 .50063 Mdot
.85544 .50062 Mdot
.85545 .5006 Mdot
.85546 .50059 Mdot
.85547 .50058 Mdot
.85548 .50057 Mdot
.85549 .50055 Mdot
.8555 .50054 Mdot
.8555 .50053 Mdot
.85551 .50051 Mdot
.85552 .5005 Mdot
.85553 .50049 Mdot
.85554 .50048 Mdot
.85555 .50046 Mdot
.85556 .50045 Mdot
.85557 .50044 Mdot
.85558 .50043 Mdot
.85559 .50041 Mdot
.8556 .5004 Mdot
.85561 .50039 Mdot
.85562 .50037 Mdot
.85563 .50036 Mdot
.85564 .50035 Mdot
.85565 .50034 Mdot
.85566 .50032 Mdot
.85567 .50031 Mdot
.85568 .5003 Mdot
.85569 .50029 Mdot
.8557 .50027 Mdot
.8557 .50026 Mdot
.85571 .50025 Mdot
.85572 .50024 Mdot
.85573 .50022 Mdot
.85574 .50021 Mdot
.85575 .5002 Mdot
.85576 .50018 Mdot
.85577 .50017 Mdot
.85578 .50016 Mdot
.85579 .50015 Mdot
.8558 .50013 Mdot
.85581 .50012 Mdot
.85582 .50011 Mdot
.85583 .5001 Mdot
.85584 .50008 Mdot
.85585 .50007 Mdot
.85586 .50006 Mdot
.85587 .50005 Mdot
.85588 .50003 Mdot
.85589 .50002 Mdot
.8559 .50001 Mdot
.8559 .49999 Mdot
.85591 .49998 Mdot
.85592 .49997 Mdot
.85593 .49996 Mdot
.85594 .49994 Mdot
.85595 .49993 Mdot
.85596 .49992 Mdot
.85597 .49991 Mdot
.85598 .49989 Mdot
.85599 .49988 Mdot
.856 .49987 Mdot
.85601 .49985 Mdot
.85602 .49984 Mdot
.85603 .49983 Mdot
.85604 .49982 Mdot
.85605 .4998 Mdot
.85606 .49979 Mdot
.85607 .49978 Mdot
.85608 .49977 Mdot
.85609 .49975 Mdot
.8561 .49974 Mdot
.8561 .49973 Mdot
.85611 .49971 Mdot
.85612 .4997 Mdot
.85613 .49969 Mdot
.85614 .49968 Mdot
.85615 .49966 Mdot
.85616 .49965 Mdot
.85617 .49964 Mdot
.85618 .49963 Mdot
.85619 .49961 Mdot
.8562 .4996 Mdot
.85621 .49959 Mdot
.85622 .49957 Mdot
.85623 .49956 Mdot
.85624 .49955 Mdot
.85625 .49954 Mdot
.85626 .49952 Mdot
.85627 .49951 Mdot
.85628 .4995 Mdot
.85629 .49949 Mdot
.8563 .49947 Mdot
.8563 .49946 Mdot
.85631 .49945 Mdot
.85632 .49943 Mdot
.85633 .49942 Mdot
.85634 .49941 Mdot
.85635 .4994 Mdot
.85636 .49938 Mdot
.85637 .49937 Mdot
.85638 .49936 Mdot
.85639 .49935 Mdot
.8564 .49933 Mdot
.85641 .49932 Mdot
.85642 .49931 Mdot
.85643 .49929 Mdot
.85644 .49928 Mdot
.85645 .49927 Mdot
.85646 .49926 Mdot
.85647 .49924 Mdot
.85648 .49923 Mdot
.85649 .49922 Mdot
.8565 .49921 Mdot
.8565 .49919 Mdot
.85651 .49918 Mdot
.85652 .49917 Mdot
.85653 .49915 Mdot
.85654 .49914 Mdot
.85655 .49913 Mdot
.85656 .49912 Mdot
.85657 .4991 Mdot
.85658 .49909 Mdot
.85659 .49908 Mdot
.8566 .49907 Mdot
.85661 .49905 Mdot
.85662 .49904 Mdot
.85663 .49903 Mdot
.85664 .49901 Mdot
.85665 .499 Mdot
.85666 .49899 Mdot
.85667 .49898 Mdot
.85668 .49896 Mdot
.85669 .49895 Mdot
.8567 .49894 Mdot
.8567 .49893 Mdot
.85671 .49891 Mdot
.85672 .4989 Mdot
.85673 .49889 Mdot
.85674 .49887 Mdot
.85675 .49886 Mdot
.85676 .49885 Mdot
.85677 .49884 Mdot
.85678 .49882 Mdot
.85679 .49881 Mdot
.8568 .4988 Mdot
.85681 .49879 Mdot
.85682 .49877 Mdot
.85683 .49876 Mdot
.85684 .49875 Mdot
.85685 .49873 Mdot
.85686 .49872 Mdot
.85687 .49871 Mdot
.85688 .4987 Mdot
.85689 .49868 Mdot
.8569 .49867 Mdot
.8569 .49866 Mdot
.85691 .49864 Mdot
.85692 .49863 Mdot
.85693 .49862 Mdot
.85694 .49861 Mdot
.85695 .49859 Mdot
.85696 .49858 Mdot
.85697 .49857 Mdot
.85698 .49856 Mdot
.85699 .49854 Mdot
.857 .49853 Mdot
.85701 .49852 Mdot
.85702 .4985 Mdot
.85703 .49849 Mdot
.85704 .49848 Mdot
.85705 .49847 Mdot
.85706 .49845 Mdot
.85707 .49844 Mdot
.85708 .49843 Mdot
.85709 .49841 Mdot
.8571 .4984 Mdot
.8571 .49839 Mdot
.85711 .49838 Mdot
.85712 .49836 Mdot
.85713 .49835 Mdot
.85714 .49834 Mdot
.85715 .49833 Mdot
.85716 .49831 Mdot
.85717 .4983 Mdot
.85718 .49829 Mdot
.85719 .49827 Mdot
.8572 .49826 Mdot
.85721 .49825 Mdot
.85722 .49824 Mdot
.85723 .49822 Mdot
.85724 .49821 Mdot
.85725 .4982 Mdot
.85726 .49818 Mdot
.85727 .49817 Mdot
.85728 .49816 Mdot
.85729 .49815 Mdot
.8573 .49813 Mdot
.8573 .49812 Mdot
.85731 .49811 Mdot
.85732 .4981 Mdot
.85733 .49808 Mdot
.85734 .49807 Mdot
.85735 .49806 Mdot
.85736 .49804 Mdot
.85737 .49803 Mdot
.85738 .49802 Mdot
.85739 .49801 Mdot
.8574 .49799 Mdot
.85741 .49798 Mdot
.85742 .49797 Mdot
.85743 .49795 Mdot
.85744 .49794 Mdot
.85745 .49793 Mdot
.85746 .49792 Mdot
.85747 .4979 Mdot
.85748 .49789 Mdot
.85749 .49788 Mdot
.8575 .49787 Mdot
.8575 .49785 Mdot
.85751 .49784 Mdot
.85752 .49783 Mdot
.85753 .49781 Mdot
.85754 .4978 Mdot
.85755 .49779 Mdot
.85756 .49778 Mdot
.85757 .49776 Mdot
.85758 .49775 Mdot
.85759 .49774 Mdot
.8576 .49772 Mdot
.85761 .49771 Mdot
.85762 .4977 Mdot
.85763 .49769 Mdot
.85764 .49767 Mdot
.85765 .49766 Mdot
.85766 .49765 Mdot
.85767 .49763 Mdot
.85768 .49762 Mdot
.85769 .49761 Mdot
.8577 .4976 Mdot
.8577 .49758 Mdot
.85771 .49757 Mdot
.85772 .49756 Mdot
.85773 .49754 Mdot
.85774 .49753 Mdot
.85775 .49752 Mdot
.85776 .49751 Mdot
.85777 .49749 Mdot
.85778 .49748 Mdot
.85779 .49747 Mdot
.8578 .49746 Mdot
.85781 .49744 Mdot
.85782 .49743 Mdot
.85783 .49742 Mdot
.85784 .4974 Mdot
.85785 .49739 Mdot
.85786 .49738 Mdot
.85787 .49737 Mdot
.85788 .49735 Mdot
.85789 .49734 Mdot
.8579 .49733 Mdot
.8579 .49731 Mdot
.85791 .4973 Mdot
.85792 .49729 Mdot
.85793 .49728 Mdot
.85794 .49726 Mdot
.85795 .49725 Mdot
.85796 .49724 Mdot
.85797 .49722 Mdot
.85798 .49721 Mdot
.85799 .4972 Mdot
.858 .49719 Mdot
.85801 .49717 Mdot
.85802 .49716 Mdot
.85803 .49715 Mdot
.85804 .49713 Mdot
.85805 .49712 Mdot
.85806 .49711 Mdot
.85807 .4971 Mdot
.85808 .49708 Mdot
.85809 .49707 Mdot
.8581 .49706 Mdot
.8581 .49704 Mdot
.85811 .49703 Mdot
.85812 .49702 Mdot
.85813 .49701 Mdot
.85814 .49699 Mdot
.85815 .49698 Mdot
.85816 .49697 Mdot
.85817 .49696 Mdot
.85818 .49694 Mdot
.85819 .49693 Mdot
.8582 .49692 Mdot
.85821 .4969 Mdot
.85822 .49689 Mdot
.85823 .49688 Mdot
.85824 .49687 Mdot
.85825 .49685 Mdot
.85826 .49684 Mdot
.85827 .49683 Mdot
.85828 .49681 Mdot
.85829 .4968 Mdot
.8583 .49679 Mdot
.8583 .49678 Mdot
.85831 .49676 Mdot
.85832 .49675 Mdot
.85833 .49674 Mdot
.85834 .49672 Mdot
.85835 .49671 Mdot
.85836 .4967 Mdot
.85837 .49669 Mdot
.85838 .49667 Mdot
.85839 .49666 Mdot
.8584 .49665 Mdot
.85841 .49663 Mdot
.85842 .49662 Mdot
.85843 .49661 Mdot
.85844 .4966 Mdot
.85845 .49658 Mdot
.85846 .49657 Mdot
.85847 .49656 Mdot
.85848 .49654 Mdot
.85849 .49653 Mdot
.8585 .49652 Mdot
.8585 .49651 Mdot
.85851 .49649 Mdot
.85852 .49648 Mdot
.85853 .49647 Mdot
.85854 .49645 Mdot
.85855 .49644 Mdot
.85856 .49643 Mdot
.85857 .49642 Mdot
.85858 .4964 Mdot
.85859 .49639 Mdot
.8586 .49638 Mdot
.85861 .49636 Mdot
.85862 .49635 Mdot
.85863 .49634 Mdot
.85864 .49633 Mdot
.85865 .49631 Mdot
.85866 .4963 Mdot
.85867 .49629 Mdot
.85868 .49627 Mdot
.85869 .49626 Mdot
.8587 .49625 Mdot
.8587 .49624 Mdot
.85871 .49622 Mdot
.85872 .49621 Mdot
.85873 .4962 Mdot
.85874 .49618 Mdot
.85875 .49617 Mdot
.85876 .49616 Mdot
.85877 .49615 Mdot
.85878 .49613 Mdot
.85879 .49612 Mdot
.8588 .49611 Mdot
.85881 .49609 Mdot
.85882 .49608 Mdot
.85883 .49607 Mdot
.85884 .49605 Mdot
.85885 .49604 Mdot
.85886 .49603 Mdot
.85887 .49602 Mdot
.85888 .496 Mdot
.85889 .49599 Mdot
.8589 .49598 Mdot
.8589 .49596 Mdot
.85891 .49595 Mdot
.85892 .49594 Mdot
.85893 .49593 Mdot
.85894 .49591 Mdot
.85895 .4959 Mdot
.85896 .49589 Mdot
.85897 .49587 Mdot
.85898 .49586 Mdot
.85899 .49585 Mdot
.859 .49584 Mdot
.85901 .49582 Mdot
.85902 .49581 Mdot
.85903 .4958 Mdot
.85904 .49578 Mdot
.85905 .49577 Mdot
.85906 .49576 Mdot
.85907 .49575 Mdot
.85908 .49573 Mdot
.85909 .49572 Mdot
.8591 .49571 Mdot
.8591 .49569 Mdot
.85911 .49568 Mdot
.85912 .49567 Mdot
.85913 .49566 Mdot
.85914 .49564 Mdot
.85915 .49563 Mdot
.85916 .49562 Mdot
.85917 .4956 Mdot
.85918 .49559 Mdot
.85919 .49558 Mdot
.8592 .49557 Mdot
.85921 .49555 Mdot
.85922 .49554 Mdot
.85923 .49553 Mdot
.85924 .49551 Mdot
.85925 .4955 Mdot
.85926 .49549 Mdot
.85927 .49547 Mdot
.85928 .49546 Mdot
.85929 .49545 Mdot
.8593 .49544 Mdot
.8593 .49542 Mdot
.85931 .49541 Mdot
.85932 .4954 Mdot
.85933 .49538 Mdot
.85934 .49537 Mdot
.85935 .49536 Mdot
.85936 .49535 Mdot
.85937 .49533 Mdot
.85938 .49532 Mdot
.85939 .49531 Mdot
.8594 .49529 Mdot
.85941 .49528 Mdot
.85942 .49527 Mdot
.85943 .49526 Mdot
.85944 .49524 Mdot
.85945 .49523 Mdot
.85946 .49522 Mdot
.85947 .4952 Mdot
.85948 .49519 Mdot
.85949 .49518 Mdot
.8595 .49516 Mdot
.8595 .49515 Mdot
.85951 .49514 Mdot
.85952 .49513 Mdot
.85953 .49511 Mdot
.85954 .4951 Mdot
.85955 .49509 Mdot
.85956 .49507 Mdot
.85957 .49506 Mdot
.85958 .49505 Mdot
.85959 .49504 Mdot
.8596 .49502 Mdot
.85961 .49501 Mdot
.85962 .495 Mdot
.85963 .49498 Mdot
.85964 .49497 Mdot
.85965 .49496 Mdot
.85966 .49495 Mdot
.85967 .49493 Mdot
.85968 .49492 Mdot
.85969 .49491 Mdot
.8597 .49489 Mdot
.8597 .49488 Mdot
.85971 .49487 Mdot
.85972 .49485 Mdot
.85973 .49484 Mdot
.85974 .49483 Mdot
.85975 .49482 Mdot
.85976 .4948 Mdot
.85977 .49479 Mdot
.85978 .49478 Mdot
.85979 .49476 Mdot
.8598 .49475 Mdot
.85981 .49474 Mdot
.85982 .49473 Mdot
.85983 .49471 Mdot
.85984 .4947 Mdot
.85985 .49469 Mdot
.85986 .49467 Mdot
.85987 .49466 Mdot
.85988 .49465 Mdot
.85989 .49463 Mdot
.8599 .49462 Mdot
.8599 .49461 Mdot
.85991 .4946 Mdot
.85992 .49458 Mdot
.85993 .49457 Mdot
.85994 .49456 Mdot
.85995 .49454 Mdot
.85996 .49453 Mdot
.85997 .49452 Mdot
.85998 .49451 Mdot
.85999 .49449 Mdot
.86 .49448 Mdot
.86001 .49447 Mdot
.86002 .49445 Mdot
.86003 .49444 Mdot
.86004 .49443 Mdot
.86005 .49441 Mdot
.86006 .4944 Mdot
.86007 .49439 Mdot
.86008 .49438 Mdot
.86009 .49436 Mdot
.8601 .49435 Mdot
.8601 .49434 Mdot
.86011 .49432 Mdot
.86012 .49431 Mdot
.86013 .4943 Mdot
.86014 .49429 Mdot
.86015 .49427 Mdot
.86016 .49426 Mdot
.86017 .49425 Mdot
.86018 .49423 Mdot
.86019 .49422 Mdot
.8602 .49421 Mdot
.86021 .49419 Mdot
.86022 .49418 Mdot
.86023 .49417 Mdot
.86024 .49416 Mdot
.86025 .49414 Mdot
.86026 .49413 Mdot
.86027 .49412 Mdot
.86028 .4941 Mdot
.86029 .49409 Mdot
.8603 .49408 Mdot
.8603 .49406 Mdot
.86031 .49405 Mdot
.86032 .49404 Mdot
.86033 .49403 Mdot
.86034 .49401 Mdot
.86035 .494 Mdot
.86036 .49399 Mdot
.86037 .49397 Mdot
.86038 .49396 Mdot
.86039 .49395 Mdot
.8604 .49394 Mdot
.86041 .49392 Mdot
.86042 .49391 Mdot
.86043 .4939 Mdot
.86044 .49388 Mdot
.86045 .49387 Mdot
.86046 .49386 Mdot
.86047 .49384 Mdot
.86048 .49383 Mdot
.86049 .49382 Mdot
.8605 .49381 Mdot
.8605 .49379 Mdot
.86051 .49378 Mdot
.86052 .49377 Mdot
.86053 .49375 Mdot
.86054 .49374 Mdot
.86055 .49373 Mdot
.86056 .49371 Mdot
.86057 .4937 Mdot
.86058 .49369 Mdot
.86059 .49368 Mdot
.8606 .49366 Mdot
.86061 .49365 Mdot
.86062 .49364 Mdot
.86063 .49362 Mdot
.86064 .49361 Mdot
.86065 .4936 Mdot
.86066 .49358 Mdot
.86067 .49357 Mdot
.86068 .49356 Mdot
.86069 .49355 Mdot
.8607 .49353 Mdot
.8607 .49352 Mdot
.86071 .49351 Mdot
.86072 .49349 Mdot
.86073 .49348 Mdot
.86074 .49347 Mdot
.86075 .49345 Mdot
.86076 .49344 Mdot
.86077 .49343 Mdot
.86078 .49342 Mdot
.86079 .4934 Mdot
.8608 .49339 Mdot
.86081 .49338 Mdot
.86082 .49336 Mdot
.86083 .49335 Mdot
.86084 .49334 Mdot
.86085 .49332 Mdot
.86086 .49331 Mdot
.86087 .4933 Mdot
.86088 .49329 Mdot
.86089 .49327 Mdot
.8609 .49326 Mdot
.8609 .49325 Mdot
.86091 .49323 Mdot
.86092 .49322 Mdot
.86093 .49321 Mdot
.86094 .49319 Mdot
.86095 .49318 Mdot
.86096 .49317 Mdot
.86097 .49316 Mdot
.86098 .49314 Mdot
.86099 .49313 Mdot
.861 .49312 Mdot
.86101 .4931 Mdot
.86102 .49309 Mdot
.86103 .49308 Mdot
.86104 .49306 Mdot
.86105 .49305 Mdot
.86106 .49304 Mdot
.86107 .49303 Mdot
.86108 .49301 Mdot
.86109 .493 Mdot
.8611 .49299 Mdot
.8611 .49297 Mdot
.86111 .49296 Mdot
.86112 .49295 Mdot
.86113 .49293 Mdot
.86114 .49292 Mdot
.86115 .49291 Mdot
.86116 .4929 Mdot
.86117 .49288 Mdot
.86118 .49287 Mdot
.86119 .49286 Mdot
.8612 .49284 Mdot
.86121 .49283 Mdot
.86122 .49282 Mdot
.86123 .4928 Mdot
.86124 .49279 Mdot
.86125 .49278 Mdot
.86126 .49277 Mdot
.86127 .49275 Mdot
.86128 .49274 Mdot
.86129 .49273 Mdot
.8613 .49271 Mdot
.8613 .4927 Mdot
.86131 .49269 Mdot
.86132 .49267 Mdot
.86133 .49266 Mdot
.86134 .49265 Mdot
.86135 .49264 Mdot
.86136 .49262 Mdot
.86137 .49261 Mdot
.86138 .4926 Mdot
.86139 .49258 Mdot
.8614 .49257 Mdot
.86141 .49256 Mdot
.86142 .49254 Mdot
.86143 .49253 Mdot
.86144 .49252 Mdot
.86145 .4925 Mdot
.86146 .49249 Mdot
.86147 .49248 Mdot
.86148 .49247 Mdot
.86149 .49245 Mdot
.8615 .49244 Mdot
.8615 .49243 Mdot
.86151 .49241 Mdot
.86152 .4924 Mdot
.86153 .49239 Mdot
.86154 .49237 Mdot
.86155 .49236 Mdot
.86156 .49235 Mdot
.86157 .49234 Mdot
.86158 .49232 Mdot
.86159 .49231 Mdot
.8616 .4923 Mdot
.86161 .49228 Mdot
.86162 .49227 Mdot
.86163 .49226 Mdot
.86164 .49224 Mdot
.86165 .49223 Mdot
.86166 .49222 Mdot
.86167 .4922 Mdot
.86168 .49219 Mdot
.86169 .49218 Mdot
.8617 .49217 Mdot
.8617 .49215 Mdot
.86171 .49214 Mdot
.86172 .49213 Mdot
.86173 .49211 Mdot
.86174 .4921 Mdot
.86175 .49209 Mdot
.86176 .49207 Mdot
.86177 .49206 Mdot
.86178 .49205 Mdot
.86179 .49204 Mdot
.8618 .49202 Mdot
.86181 .49201 Mdot
.86182 .492 Mdot
.86183 .49198 Mdot
.86184 .49197 Mdot
.86185 .49196 Mdot
.86186 .49194 Mdot
.86187 .49193 Mdot
.86188 .49192 Mdot
.86189 .4919 Mdot
.8619 .49189 Mdot
.8619 .49188 Mdot
.86191 .49187 Mdot
.86192 .49185 Mdot
.86193 .49184 Mdot
.86194 .49183 Mdot
.86195 .49181 Mdot
.86196 .4918 Mdot
.86197 .49179 Mdot
.86198 .49177 Mdot
.86199 .49176 Mdot
.862 .49175 Mdot
.86201 .49173 Mdot
.86202 .49172 Mdot
.86203 .49171 Mdot
.86204 .4917 Mdot
.86205 .49168 Mdot
.86206 .49167 Mdot
.86207 .49166 Mdot
.86208 .49164 Mdot
.86209 .49163 Mdot
.8621 .49162 Mdot
.8621 .4916 Mdot
.86211 .49159 Mdot
.86212 .49158 Mdot
.86213 .49156 Mdot
.86214 .49155 Mdot
.86215 .49154 Mdot
.86216 .49153 Mdot
.86217 .49151 Mdot
.86218 .4915 Mdot
.86219 .49149 Mdot
.8622 .49147 Mdot
.86221 .49146 Mdot
.86222 .49145 Mdot
.86223 .49143 Mdot
.86224 .49142 Mdot
.86225 .49141 Mdot
.86226 .49139 Mdot
.86227 .49138 Mdot
.86228 .49137 Mdot
.86229 .49136 Mdot
.8623 .49134 Mdot
.8623 .49133 Mdot
.86231 .49132 Mdot
.86232 .4913 Mdot
.86233 .49129 Mdot
.86234 .49128 Mdot
.86235 .49126 Mdot
.86236 .49125 Mdot
.86237 .49124 Mdot
.86238 .49122 Mdot
.86239 .49121 Mdot
.8624 .4912 Mdot
.86241 .49119 Mdot
.86242 .49117 Mdot
.86243 .49116 Mdot
.86244 .49115 Mdot
.86245 .49113 Mdot
.86246 .49112 Mdot
.86247 .49111 Mdot
.86248 .49109 Mdot
.86249 .49108 Mdot
.8625 .49107 Mdot
.8625 .49105 Mdot
.86251 .49104 Mdot
.86252 .49103 Mdot
.86253 .49102 Mdot
.86254 .491 Mdot
.86255 .49099 Mdot
.86256 .49098 Mdot
.86257 .49096 Mdot
.86258 .49095 Mdot
.86259 .49094 Mdot
.8626 .49092 Mdot
.86261 .49091 Mdot
.86262 .4909 Mdot
.86263 .49088 Mdot
.86264 .49087 Mdot
.86265 .49086 Mdot
.86266 .49084 Mdot
.86267 .49083 Mdot
.86268 .49082 Mdot
.86269 .49081 Mdot
.8627 .49079 Mdot
.8627 .49078 Mdot
.86271 .49077 Mdot
.86272 .49075 Mdot
.86273 .49074 Mdot
.86274 .49073 Mdot
.86275 .49071 Mdot
.86276 .4907 Mdot
.86277 .49069 Mdot
.86278 .49067 Mdot
.86279 .49066 Mdot
.8628 .49065 Mdot
.86281 .49064 Mdot
.86282 .49062 Mdot
.86283 .49061 Mdot
.86284 .4906 Mdot
.86285 .49058 Mdot
.86286 .49057 Mdot
.86287 .49056 Mdot
.86288 .49054 Mdot
.86289 .49053 Mdot
.8629 .49052 Mdot
.8629 .4905 Mdot
.86291 .49049 Mdot
.86292 .49048 Mdot
.86293 .49046 Mdot
.86294 .49045 Mdot
.86295 .49044 Mdot
.86296 .49043 Mdot
.86297 .49041 Mdot
.86298 .4904 Mdot
.86299 .49039 Mdot
.863 .49037 Mdot
.86301 .49036 Mdot
.86302 .49035 Mdot
.86303 .49033 Mdot
.86304 .49032 Mdot
.86305 .49031 Mdot
.86306 .49029 Mdot
.86307 .49028 Mdot
.86308 .49027 Mdot
.86309 .49025 Mdot
.8631 .49024 Mdot
.8631 .49023 Mdot
.86311 .49022 Mdot
.86312 .4902 Mdot
.86313 .49019 Mdot
.86314 .49018 Mdot
.86315 .49016 Mdot
.86316 .49015 Mdot
.86317 .49014 Mdot
.86318 .49012 Mdot
.86319 .49011 Mdot
.8632 .4901 Mdot
.86321 .49008 Mdot
.86322 .49007 Mdot
.86323 .49006 Mdot
.86324 .49004 Mdot
.86325 .49003 Mdot
.86326 .49002 Mdot
.86327 .49001 Mdot
.86328 .48999 Mdot
.86329 .48998 Mdot
.8633 .48997 Mdot
.8633 .48995 Mdot
.86331 .48994 Mdot
.86332 .48993 Mdot
.86333 .48991 Mdot
.86334 .4899 Mdot
.86335 .48989 Mdot
.86336 .48987 Mdot
.86337 .48986 Mdot
.86338 .48985 Mdot
.86339 .48983 Mdot
.8634 .48982 Mdot
.86341 .48981 Mdot
.86342 .48979 Mdot
.86343 .48978 Mdot
.86344 .48977 Mdot
.86345 .48976 Mdot
.86346 .48974 Mdot
.86347 .48973 Mdot
.86348 .48972 Mdot
.86349 .4897 Mdot
.8635 .48969 Mdot
.8635 .48968 Mdot
.86351 .48966 Mdot
.86352 .48965 Mdot
.86353 .48964 Mdot
.86354 .48962 Mdot
.86355 .48961 Mdot
.86356 .4896 Mdot
.86357 .48958 Mdot
.86358 .48957 Mdot
.86359 .48956 Mdot
.8636 .48954 Mdot
.86361 .48953 Mdot
.86362 .48952 Mdot
.86363 .48951 Mdot
.86364 .48949 Mdot
.86365 .48948 Mdot
.86366 .48947 Mdot
.86367 .48945 Mdot
.86368 .48944 Mdot
.86369 .48943 Mdot
.8637 .48941 Mdot
.8637 .4894 Mdot
.86371 .48939 Mdot
.86372 .48937 Mdot
.86373 .48936 Mdot
.86374 .48935 Mdot
.86375 .48933 Mdot
.86376 .48932 Mdot
.86377 .48931 Mdot
.86378 .48929 Mdot
.86379 .48928 Mdot
.8638 .48927 Mdot
.86381 .48926 Mdot
.86382 .48924 Mdot
.86383 .48923 Mdot
.86384 .48922 Mdot
.86385 .4892 Mdot
.86386 .48919 Mdot
.86387 .48918 Mdot
.86388 .48916 Mdot
.86389 .48915 Mdot
.8639 .48914 Mdot
.8639 .48912 Mdot
.86391 .48911 Mdot
.86392 .4891 Mdot
.86393 .48908 Mdot
.86394 .48907 Mdot
.86395 .48906 Mdot
.86396 .48904 Mdot
.86397 .48903 Mdot
.86398 .48902 Mdot
.86399 .489 Mdot
.864 .48899 Mdot
.86401 .48898 Mdot
.86402 .48897 Mdot
.86403 .48895 Mdot
.86404 .48894 Mdot
.86405 .48893 Mdot
.86406 .48891 Mdot
.86407 .4889 Mdot
.86408 .48889 Mdot
.86409 .48887 Mdot
.8641 .48886 Mdot
.8641 .48885 Mdot
.86411 .48883 Mdot
.86412 .48882 Mdot
.86413 .48881 Mdot
.86414 .48879 Mdot
.86415 .48878 Mdot
.86416 .48877 Mdot
.86417 .48875 Mdot
.86418 .48874 Mdot
.86419 .48873 Mdot
.8642 .48871 Mdot
.86421 .4887 Mdot
.86422 .48869 Mdot
.86423 .48868 Mdot
.86424 .48866 Mdot
.86425 .48865 Mdot
.86426 .48864 Mdot
.86427 .48862 Mdot
.86428 .48861 Mdot
.86429 .4886 Mdot
.8643 .48858 Mdot
.8643 .48857 Mdot
.86431 .48856 Mdot
.86432 .48854 Mdot
.86433 .48853 Mdot
.86434 .48852 Mdot
.86435 .4885 Mdot
.86436 .48849 Mdot
.86437 .48848 Mdot
.86438 .48846 Mdot
.86439 .48845 Mdot
.8644 .48844 Mdot
.86441 .48842 Mdot
.86442 .48841 Mdot
.86443 .4884 Mdot
.86444 .48838 Mdot
.86445 .48837 Mdot
.86446 .48836 Mdot
.86447 .48835 Mdot
.86448 .48833 Mdot
.86449 .48832 Mdot
.8645 .48831 Mdot
.8645 .48829 Mdot
.86451 .48828 Mdot
.86452 .48827 Mdot
.86453 .48825 Mdot
.86454 .48824 Mdot
.86455 .48823 Mdot
.86456 .48821 Mdot
.86457 .4882 Mdot
.86458 .48819 Mdot
.86459 .48817 Mdot
.8646 .48816 Mdot
.86461 .48815 Mdot
.86462 .48813 Mdot
.86463 .48812 Mdot
.86464 .48811 Mdot
.86465 .48809 Mdot
.86466 .48808 Mdot
.86467 .48807 Mdot
.86468 .48805 Mdot
.86469 .48804 Mdot
.8647 .48803 Mdot
.8647 .48801 Mdot
.86471 .488 Mdot
.86472 .48799 Mdot
.86473 .48798 Mdot
.86474 .48796 Mdot
.86475 .48795 Mdot
.86476 .48794 Mdot
.86477 .48792 Mdot
.86478 .48791 Mdot
.86479 .4879 Mdot
.8648 .48788 Mdot
.86481 .48787 Mdot
.86482 .48786 Mdot
.86483 .48784 Mdot
.86484 .48783 Mdot
.86485 .48782 Mdot
.86486 .4878 Mdot
.86487 .48779 Mdot
.86488 .48778 Mdot
.86489 .48776 Mdot
.8649 .48775 Mdot
.8649 .48774 Mdot
.86491 .48772 Mdot
.86492 .48771 Mdot
.86493 .4877 Mdot
.86494 .48768 Mdot
.86495 .48767 Mdot
.86496 .48766 Mdot
.86497 .48764 Mdot
.86498 .48763 Mdot
.86499 .48762 Mdot
.865 .4876 Mdot
.86501 .48759 Mdot
.86502 .48758 Mdot
.86503 .48756 Mdot
.86504 .48755 Mdot
.86505 .48754 Mdot
.86506 .48753 Mdot
.86507 .48751 Mdot
.86508 .4875 Mdot
.86509 .48749 Mdot
.8651 .48747 Mdot
.8651 .48746 Mdot
.86511 .48745 Mdot
.86512 .48743 Mdot
.86513 .48742 Mdot
.86514 .48741 Mdot
.86515 .48739 Mdot
.86516 .48738 Mdot
.86517 .48737 Mdot
.86518 .48735 Mdot
.86519 .48734 Mdot
.8652 .48733 Mdot
.86521 .48731 Mdot
.86522 .4873 Mdot
.86523 .48729 Mdot
.86524 .48727 Mdot
.86525 .48726 Mdot
.86526 .48725 Mdot
.86527 .48723 Mdot
.86528 .48722 Mdot
.86529 .48721 Mdot
.8653 .48719 Mdot
.8653 .48718 Mdot
.86531 .48717 Mdot
.86532 .48715 Mdot
.86533 .48714 Mdot
.86534 .48713 Mdot
.86535 .48711 Mdot
.86536 .4871 Mdot
.86537 .48709 Mdot
.86538 .48707 Mdot
.86539 .48706 Mdot
.8654 .48705 Mdot
.86541 .48703 Mdot
.86542 .48702 Mdot
.86543 .48701 Mdot
.86544 .48699 Mdot
.86545 .48698 Mdot
.86546 .48697 Mdot
.86547 .48696 Mdot
.86548 .48694 Mdot
.86549 .48693 Mdot
.8655 .48692 Mdot
.8655 .4869 Mdot
.86551 .48689 Mdot
.86552 .48688 Mdot
.86553 .48686 Mdot
.86554 .48685 Mdot
.86555 .48684 Mdot
.86556 .48682 Mdot
.86557 .48681 Mdot
.86558 .4868 Mdot
.86559 .48678 Mdot
.8656 .48677 Mdot
.86561 .48676 Mdot
.86562 .48674 Mdot
.86563 .48673 Mdot
.86564 .48672 Mdot
.86565 .4867 Mdot
.86566 .48669 Mdot
.86567 .48668 Mdot
.86568 .48666 Mdot
.86569 .48665 Mdot
.8657 .48664 Mdot
.8657 .48662 Mdot
.86571 .48661 Mdot
.86572 .4866 Mdot
.86573 .48658 Mdot
.86574 .48657 Mdot
.86575 .48656 Mdot
.86576 .48654 Mdot
.86577 .48653 Mdot
.86578 .48652 Mdot
.86579 .4865 Mdot
.8658 .48649 Mdot
.86581 .48648 Mdot
.86582 .48646 Mdot
.86583 .48645 Mdot
.86584 .48644 Mdot
.86585 .48642 Mdot
.86586 .48641 Mdot
.86587 .4864 Mdot
.86588 .48638 Mdot
.86589 .48637 Mdot
.8659 .48636 Mdot
.8659 .48634 Mdot
.86591 .48633 Mdot
.86592 .48632 Mdot
.86593 .4863 Mdot
.86594 .48629 Mdot
.86595 .48628 Mdot
.86596 .48626 Mdot
.86597 .48625 Mdot
.86598 .48624 Mdot
.86599 .48622 Mdot
.866 .48621 Mdot
.86601 .4862 Mdot
.86602 .48618 Mdot
.86603 .48617 Mdot
.86604 .48616 Mdot
.86605 .48614 Mdot
.86606 .48613 Mdot
.86607 .48612 Mdot
.86608 .4861 Mdot
.86609 .48609 Mdot
.8661 .48608 Mdot
.8661 .48607 Mdot
.86611 .48605 Mdot
.86612 .48604 Mdot
.86613 .48603 Mdot
.86614 .48601 Mdot
.86615 .486 Mdot
.86616 .48599 Mdot
.86617 .48597 Mdot
.86618 .48596 Mdot
.86619 .48595 Mdot
.8662 .48593 Mdot
.86621 .48592 Mdot
.86622 .48591 Mdot
.86623 .48589 Mdot
.86624 .48588 Mdot
.86625 .48587 Mdot
.86626 .48585 Mdot
.86627 .48584 Mdot
.86628 .48583 Mdot
.86629 .48581 Mdot
.8663 .4858 Mdot
.8663 .48579 Mdot
.86631 .48577 Mdot
.86632 .48576 Mdot
.86633 .48575 Mdot
.86634 .48573 Mdot
.86635 .48572 Mdot
.86636 .48571 Mdot
.86637 .48569 Mdot
.86638 .48568 Mdot
.86639 .48567 Mdot
.8664 .48565 Mdot
.86641 .48564 Mdot
.86642 .48563 Mdot
.86643 .48561 Mdot
.86644 .4856 Mdot
.86645 .48559 Mdot
.86646 .48557 Mdot
.86647 .48556 Mdot
.86648 .48555 Mdot
.86649 .48553 Mdot
.8665 .48552 Mdot
.8665 .48551 Mdot
.86651 .48549 Mdot
.86652 .48548 Mdot
.86653 .48547 Mdot
.86654 .48545 Mdot
.86655 .48544 Mdot
.86656 .48543 Mdot
.86657 .48541 Mdot
.86658 .4854 Mdot
.86659 .48539 Mdot
.8666 .48537 Mdot
.86661 .48536 Mdot
.86662 .48535 Mdot
.86663 .48533 Mdot
.86664 .48532 Mdot
.86665 .48531 Mdot
.86666 .48529 Mdot
.86667 .48528 Mdot
.86668 .48527 Mdot
.86669 .48525 Mdot
.8667 .48524 Mdot
.8667 .48523 Mdot
.86671 .48521 Mdot
.86672 .4852 Mdot
.86673 .48519 Mdot
.86674 .48517 Mdot
.86675 .48516 Mdot
.86676 .48515 Mdot
.86677 .48513 Mdot
.86678 .48512 Mdot
.86679 .48511 Mdot
.8668 .48509 Mdot
.86681 .48508 Mdot
.86682 .48507 Mdot
.86683 .48505 Mdot
.86684 .48504 Mdot
.86685 .48503 Mdot
.86686 .48501 Mdot
.86687 .485 Mdot
.86688 .48499 Mdot
.86689 .48497 Mdot
.8669 .48496 Mdot
.8669 .48495 Mdot
.86691 .48493 Mdot
.86692 .48492 Mdot
.86693 .48491 Mdot
.86694 .48489 Mdot
.86695 .48488 Mdot
.86696 .48487 Mdot
.86697 .48485 Mdot
.86698 .48484 Mdot
.86699 .48483 Mdot
.867 .48481 Mdot
.86701 .4848 Mdot
.86702 .48479 Mdot
.86703 .48477 Mdot
.86704 .48476 Mdot
.86705 .48475 Mdot
.86706 .48473 Mdot
.86707 .48472 Mdot
.86708 .48471 Mdot
.86709 .48469 Mdot
.8671 .48468 Mdot
.8671 .48467 Mdot
.86711 .48465 Mdot
.86712 .48464 Mdot
.86713 .48463 Mdot
.86714 .48461 Mdot
.86715 .4846 Mdot
.86716 .48459 Mdot
.86717 .48457 Mdot
.86718 .48456 Mdot
.86719 .48455 Mdot
.8672 .48453 Mdot
.86721 .48452 Mdot
.86722 .4845 Mdot
.86723 .48449 Mdot
.86724 .48448 Mdot
.86725 .48446 Mdot
.86726 .48445 Mdot
.86727 .48444 Mdot
.86728 .48442 Mdot
.86729 .48441 Mdot
.8673 .4844 Mdot
.8673 .48438 Mdot
.86731 .48437 Mdot
.86732 .48436 Mdot
.86733 .48434 Mdot
.86734 .48433 Mdot
.86735 .48432 Mdot
.86736 .4843 Mdot
.86737 .48429 Mdot
.86738 .48428 Mdot
.86739 .48426 Mdot
.8674 .48425 Mdot
.86741 .48424 Mdot
.86742 .48422 Mdot
.86743 .48421 Mdot
.86744 .4842 Mdot
.86745 .48418 Mdot
.86746 .48417 Mdot
.86747 .48416 Mdot
.86748 .48414 Mdot
.86749 .48413 Mdot
.8675 .48412 Mdot
.8675 .4841 Mdot
.86751 .48409 Mdot
.86752 .48408 Mdot
.86753 .48406 Mdot
.86754 .48405 Mdot
.86755 .48404 Mdot
.86756 .48402 Mdot
.86757 .48401 Mdot
.86758 .484 Mdot
.86759 .48398 Mdot
.8676 .48397 Mdot
.86761 .48396 Mdot
.86762 .48394 Mdot
.86763 .48393 Mdot
.86764 .48392 Mdot
.86765 .4839 Mdot
.86766 .48389 Mdot
.86767 .48388 Mdot
.86768 .48386 Mdot
.86769 .48385 Mdot
.8677 .48384 Mdot
.8677 .48382 Mdot
.86771 .48381 Mdot
.86772 .4838 Mdot
.86773 .48378 Mdot
.86774 .48377 Mdot
.86775 .48376 Mdot
.86776 .48374 Mdot
.86777 .48373 Mdot
.86778 .48372 Mdot
.86779 .4837 Mdot
.8678 .48369 Mdot
.86781 .48368 Mdot
.86782 .48366 Mdot
.86783 .48365 Mdot
.86784 .48364 Mdot
.86785 .48362 Mdot
.86786 .48361 Mdot
.86787 .48359 Mdot
.86788 .48358 Mdot
.86789 .48357 Mdot
.8679 .48355 Mdot
.8679 .48354 Mdot
.86791 .48353 Mdot
.86792 .48351 Mdot
.86793 .4835 Mdot
.86794 .48349 Mdot
.86795 .48347 Mdot
.86796 .48346 Mdot
.86797 .48345 Mdot
.86798 .48343 Mdot
.86799 .48342 Mdot
.868 .48341 Mdot
.86801 .48339 Mdot
.86802 .48338 Mdot
.86803 .48337 Mdot
.86804 .48335 Mdot
.86805 .48334 Mdot
.86806 .48333 Mdot
.86807 .48331 Mdot
.86808 .4833 Mdot
.86809 .48329 Mdot
.8681 .48327 Mdot
.8681 .48326 Mdot
.86811 .48325 Mdot
.86812 .48323 Mdot
.86813 .48322 Mdot
.86814 .48321 Mdot
.86815 .48319 Mdot
.86816 .48318 Mdot
.86817 .48317 Mdot
.86818 .48315 Mdot
.86819 .48314 Mdot
.8682 .48313 Mdot
.86821 .48311 Mdot
.86822 .4831 Mdot
.86823 .48309 Mdot
.86824 .48307 Mdot
.86825 .48306 Mdot
.86826 .48304 Mdot
.86827 .48303 Mdot
.86828 .48302 Mdot
.86829 .483 Mdot
.8683 .48299 Mdot
.8683 .48298 Mdot
.86831 .48296 Mdot
.86832 .48295 Mdot
.86833 .48294 Mdot
.86834 .48292 Mdot
.86835 .48291 Mdot
.86836 .4829 Mdot
.86837 .48288 Mdot
.86838 .48287 Mdot
.86839 .48286 Mdot
.8684 .48284 Mdot
.86841 .48283 Mdot
.86842 .48282 Mdot
.86843 .4828 Mdot
.86844 .48279 Mdot
.86845 .48278 Mdot
.86846 .48276 Mdot
.86847 .48275 Mdot
.86848 .48274 Mdot
.86849 .48272 Mdot
.8685 .48271 Mdot
.8685 .4827 Mdot
.86851 .48268 Mdot
.86852 .48267 Mdot
.86853 .48266 Mdot
.86854 .48264 Mdot
.86855 .48263 Mdot
.86856 .48262 Mdot
.86857 .4826 Mdot
.86858 .48259 Mdot
.86859 .48257 Mdot
.8686 .48256 Mdot
.86861 .48255 Mdot
.86862 .48253 Mdot
.86863 .48252 Mdot
.86864 .48251 Mdot
.86865 .48249 Mdot
.86866 .48248 Mdot
.86867 .48247 Mdot
.86868 .48245 Mdot
.86869 .48244 Mdot
.8687 .48243 Mdot
.8687 .48241 Mdot
.86871 .4824 Mdot
.86872 .48239 Mdot
.86873 .48237 Mdot
.86874 .48236 Mdot
.86875 .48235 Mdot
.86876 .48233 Mdot
.86877 .48232 Mdot
.86878 .48231 Mdot
.86879 .48229 Mdot
.8688 .48228 Mdot
.86881 .48227 Mdot
.86882 .48225 Mdot
.86883 .48224 Mdot
.86884 .48223 Mdot
.86885 .48221 Mdot
.86886 .4822 Mdot
.86887 .48218 Mdot
.86888 .48217 Mdot
.86889 .48216 Mdot
.8689 .48214 Mdot
.8689 .48213 Mdot
.86891 .48212 Mdot
.86892 .4821 Mdot
.86893 .48209 Mdot
.86894 .48208 Mdot
.86895 .48206 Mdot
.86896 .48205 Mdot
.86897 .48204 Mdot
.86898 .48202 Mdot
.86899 .48201 Mdot
.869 .482 Mdot
.86901 .48198 Mdot
.86902 .48197 Mdot
.86903 .48196 Mdot
.86904 .48194 Mdot
.86905 .48193 Mdot
.86906 .48192 Mdot
.86907 .4819 Mdot
.86908 .48189 Mdot
.86909 .48188 Mdot
.8691 .48186 Mdot
.8691 .48185 Mdot
.86911 .48183 Mdot
.86912 .48182 Mdot
.86913 .48181 Mdot
.86914 .48179 Mdot
.86915 .48178 Mdot
.86916 .48177 Mdot
.86917 .48175 Mdot
.86918 .48174 Mdot
.86919 .48173 Mdot
.8692 .48171 Mdot
.86921 .4817 Mdot
.86922 .48169 Mdot
.86923 .48167 Mdot
.86924 .48166 Mdot
.86925 .48165 Mdot
.86926 .48163 Mdot
.86927 .48162 Mdot
.86928 .48161 Mdot
.86929 .48159 Mdot
.8693 .48158 Mdot
.8693 .48157 Mdot
.86931 .48155 Mdot
.86932 .48154 Mdot
.86933 .48152 Mdot
.86934 .48151 Mdot
.86935 .4815 Mdot
.86936 .48148 Mdot
.86937 .48147 Mdot
.86938 .48146 Mdot
.86939 .48144 Mdot
.8694 .48143 Mdot
.86941 .48142 Mdot
.86942 .4814 Mdot
.86943 .48139 Mdot
.86944 .48138 Mdot
.86945 .48136 Mdot
.86946 .48135 Mdot
.86947 .48134 Mdot
.86948 .48132 Mdot
.86949 .48131 Mdot
.8695 .4813 Mdot
.8695 .48128 Mdot
.86951 .48127 Mdot
.86952 .48125 Mdot
.86953 .48124 Mdot
.86954 .48123 Mdot
.86955 .48121 Mdot
.86956 .4812 Mdot
.86957 .48119 Mdot
.86958 .48117 Mdot
.86959 .48116 Mdot
.8696 .48115 Mdot
.86961 .48113 Mdot
.86962 .48112 Mdot
.86963 .48111 Mdot
.86964 .48109 Mdot
.86965 .48108 Mdot
.86966 .48107 Mdot
.86967 .48105 Mdot
.86968 .48104 Mdot
.86969 .48103 Mdot
.8697 .48101 Mdot
.8697 .481 Mdot
.86971 .48098 Mdot
.86972 .48097 Mdot
.86973 .48096 Mdot
.86974 .48094 Mdot
.86975 .48093 Mdot
.86976 .48092 Mdot
.86977 .4809 Mdot
.86978 .48089 Mdot
.86979 .48088 Mdot
.8698 .48086 Mdot
.86981 .48085 Mdot
.86982 .48084 Mdot
.86983 .48082 Mdot
.86984 .48081 Mdot
.86985 .4808 Mdot
.86986 .48078 Mdot
.86987 .48077 Mdot
.86988 .48076 Mdot
.86989 .48074 Mdot
.8699 .48073 Mdot
.8699 .48071 Mdot
.86991 .4807 Mdot
.86992 .48069 Mdot
.86993 .48067 Mdot
.86994 .48066 Mdot
.86995 .48065 Mdot
.86996 .48063 Mdot
.86997 .48062 Mdot
.86998 .48061 Mdot
.86999 .48059 Mdot
.87 .48058 Mdot
.87001 .48057 Mdot
.87002 .48055 Mdot
.87003 .48054 Mdot
.87004 .48053 Mdot
.87005 .48051 Mdot
.87006 .4805 Mdot
.87007 .48048 Mdot
.87008 .48047 Mdot
.87009 .48046 Mdot
.8701 .48044 Mdot
.8701 .48043 Mdot
.87011 .48042 Mdot
.87012 .4804 Mdot
.87013 .48039 Mdot
.87014 .48038 Mdot
.87015 .48036 Mdot
.87016 .48035 Mdot
.87017 .48034 Mdot
.87018 .48032 Mdot
.87019 .48031 Mdot
.8702 .4803 Mdot
.87021 .48028 Mdot
.87022 .48027 Mdot
.87023 .48025 Mdot
.87024 .48024 Mdot
.87025 .48023 Mdot
.87026 .48021 Mdot
.87027 .4802 Mdot
.87028 .48019 Mdot
.87029 .48017 Mdot
.8703 .48016 Mdot
.8703 .48015 Mdot
.87031 .48013 Mdot
.87032 .48012 Mdot
.87033 .48011 Mdot
.87034 .48009 Mdot
.87035 .48008 Mdot
.87036 .48007 Mdot
.87037 .48005 Mdot
.87038 .48004 Mdot
.87039 .48002 Mdot
.8704 .48001 Mdot
.87041 .48 Mdot
.87042 .47998 Mdot
.87043 .47997 Mdot
.87044 .47996 Mdot
.87045 .47994 Mdot
.87046 .47993 Mdot
.87047 .47992 Mdot
.87048 .4799 Mdot
.87049 .47989 Mdot
.8705 .47988 Mdot
.8705 .47986 Mdot
.87051 .47985 Mdot
.87052 .47984 Mdot
.87053 .47982 Mdot
.87054 .47981 Mdot
.87055 .47979 Mdot
.87056 .47978 Mdot
.87057 .47977 Mdot
.87058 .47975 Mdot
.87059 .47974 Mdot
.8706 .47973 Mdot
.87061 .47971 Mdot
.87062 .4797 Mdot
.87063 .47969 Mdot
.87064 .47967 Mdot
.87065 .47966 Mdot
.87066 .47965 Mdot
.87067 .47963 Mdot
.87068 .47962 Mdot
.87069 .4796 Mdot
.8707 .47959 Mdot
.8707 .47958 Mdot
.87071 .47956 Mdot
.87072 .47955 Mdot
.87073 .47954 Mdot
.87074 .47952 Mdot
.87075 .47951 Mdot
.87076 .4795 Mdot
.87077 .47948 Mdot
.87078 .47947 Mdot
.87079 .47946 Mdot
.8708 .47944 Mdot
.87081 .47943 Mdot
.87082 .47941 Mdot
.87083 .4794 Mdot
.87084 .47939 Mdot
.87085 .47937 Mdot
.87086 .47936 Mdot
.87087 .47935 Mdot
.87088 .47933 Mdot
.87089 .47932 Mdot
.8709 .47931 Mdot
.8709 .47929 Mdot
.87091 .47928 Mdot
.87092 .47927 Mdot
.87093 .47925 Mdot
.87094 .47924 Mdot
.87095 .47923 Mdot
.87096 .47921 Mdot
.87097 .4792 Mdot
.87098 .47918 Mdot
.87099 .47917 Mdot
.871 .47916 Mdot
.87101 .47914 Mdot
.87102 .47913 Mdot
.87103 .47912 Mdot
.87104 .4791 Mdot
.87105 .47909 Mdot
.87106 .47908 Mdot
.87107 .47906 Mdot
.87108 .47905 Mdot
.87109 .47903 Mdot
.8711 .47902 Mdot
.8711 .47901 Mdot
.87111 .47899 Mdot
.87112 .47898 Mdot
.87113 .47897 Mdot
.87114 .47895 Mdot
.87115 .47894 Mdot
.87116 .47893 Mdot
.87117 .47891 Mdot
.87118 .4789 Mdot
.87119 .47889 Mdot
.8712 .47887 Mdot
.87121 .47886 Mdot
.87122 .47884 Mdot
.87123 .47883 Mdot
.87124 .47882 Mdot
.87125 .4788 Mdot
.87126 .47879 Mdot
.87127 .47878 Mdot
.87128 .47876 Mdot
.87129 .47875 Mdot
.8713 .47874 Mdot
.8713 .47872 Mdot
.87131 .47871 Mdot
.87132 .4787 Mdot
.87133 .47868 Mdot
.87134 .47867 Mdot
.87135 .47865 Mdot
.87136 .47864 Mdot
.87137 .47863 Mdot
.87138 .47861 Mdot
.87139 .4786 Mdot
.8714 .47859 Mdot
.87141 .47857 Mdot
.87142 .47856 Mdot
.87143 .47855 Mdot
.87144 .47853 Mdot
.87145 .47852 Mdot
.87146 .4785 Mdot
.87147 .47849 Mdot
.87148 .47848 Mdot
.87149 .47846 Mdot
.8715 .47845 Mdot
.8715 .47844 Mdot
.87151 .47842 Mdot
.87152 .47841 Mdot
.87153 .4784 Mdot
.87154 .47838 Mdot
.87155 .47837 Mdot
.87156 .47836 Mdot
.87157 .47834 Mdot
.87158 .47833 Mdot
.87159 .47831 Mdot
.8716 .4783 Mdot
.87161 .47829 Mdot
.87162 .47827 Mdot
.87163 .47826 Mdot
.87164 .47825 Mdot
.87165 .47823 Mdot
.87166 .47822 Mdot
.87167 .47821 Mdot
.87168 .47819 Mdot
.87169 .47818 Mdot
.8717 .47816 Mdot
.8717 .47815 Mdot
.87171 .47814 Mdot
.87172 .47812 Mdot
.87173 .47811 Mdot
.87174 .4781 Mdot
.87175 .47808 Mdot
.87176 .47807 Mdot
.87177 .47806 Mdot
.87178 .47804 Mdot
.87179 .47803 Mdot
.8718 .47802 Mdot
.87181 .478 Mdot
.87182 .47799 Mdot
.87183 .47797 Mdot
.87184 .47796 Mdot
.87185 .47795 Mdot
.87186 .47793 Mdot
.87187 .47792 Mdot
.87188 .47791 Mdot
.87189 .47789 Mdot
.8719 .47788 Mdot
.8719 .47787 Mdot
.87191 .47785 Mdot
.87192 .47784 Mdot
.87193 .47782 Mdot
.87194 .47781 Mdot
.87195 .4778 Mdot
.87196 .47778 Mdot
.87197 .47777 Mdot
.87198 .47776 Mdot
.87199 .47774 Mdot
.872 .47773 Mdot
.87201 .47772 Mdot
.87202 .4777 Mdot
.87203 .47769 Mdot
.87204 .47767 Mdot
.87205 .47766 Mdot
.87206 .47765 Mdot
.87207 .47763 Mdot
.87208 .47762 Mdot
.87209 .47761 Mdot
.8721 .47759 Mdot
.8721 .47758 Mdot
.87211 .47757 Mdot
.87212 .47755 Mdot
.87213 .47754 Mdot
.87214 .47752 Mdot
.87215 .47751 Mdot
.87216 .4775 Mdot
.87217 .47748 Mdot
.87218 .47747 Mdot
.87219 .47746 Mdot
.8722 .47744 Mdot
.87221 .47743 Mdot
.87222 .47742 Mdot
.87223 .4774 Mdot
.87224 .47739 Mdot
.87225 .47737 Mdot
.87226 .47736 Mdot
.87227 .47735 Mdot
.87228 .47733 Mdot
.87229 .47732 Mdot
.8723 .47731 Mdot
.8723 .47729 Mdot
.87231 .47728 Mdot
.87232 .47727 Mdot
.87233 .47725 Mdot
.87234 .47724 Mdot
.87235 .47722 Mdot
.87236 .47721 Mdot
.87237 .4772 Mdot
.87238 .47718 Mdot
.87239 .47717 Mdot
.8724 .47716 Mdot
.87241 .47714 Mdot
.87242 .47713 Mdot
.87243 .47712 Mdot
.87244 .4771 Mdot
.87245 .47709 Mdot
.87246 .47707 Mdot
.87247 .47706 Mdot
.87248 .47705 Mdot
.87249 .47703 Mdot
.8725 .47702 Mdot
.8725 .47701 Mdot
.87251 .47699 Mdot
.87252 .47698 Mdot
.87253 .47697 Mdot
.87254 .47695 Mdot
.87255 .47694 Mdot
.87256 .47692 Mdot
.87257 .47691 Mdot
.87258 .4769 Mdot
.87259 .47688 Mdot
.8726 .47687 Mdot
.87261 .47686 Mdot
.87262 .47684 Mdot
.87263 .47683 Mdot
.87264 .47681 Mdot
.87265 .4768 Mdot
.87266 .47679 Mdot
.87267 .47677 Mdot
.87268 .47676 Mdot
.87269 .47675 Mdot
.8727 .47673 Mdot
.8727 .47672 Mdot
.87271 .47671 Mdot
.87272 .47669 Mdot
.87273 .47668 Mdot
.87274 .47666 Mdot
.87275 .47665 Mdot
.87276 .47664 Mdot
.87277 .47662 Mdot
.87278 .47661 Mdot
.87279 .4766 Mdot
.8728 .47658 Mdot
.87281 .47657 Mdot
.87282 .47656 Mdot
.87283 .47654 Mdot
.87284 .47653 Mdot
.87285 .47651 Mdot
.87286 .4765 Mdot
.87287 .47649 Mdot
.87288 .47647 Mdot
.87289 .47646 Mdot
.8729 .47645 Mdot
.8729 .47643 Mdot
.87291 .47642 Mdot
.87292 .4764 Mdot
.87293 .47639 Mdot
.87294 .47638 Mdot
.87295 .47636 Mdot
.87296 .47635 Mdot
.87297 .47634 Mdot
.87298 .47632 Mdot
.87299 .47631 Mdot
.873 .4763 Mdot
.87301 .47628 Mdot
.87302 .47627 Mdot
.87303 .47625 Mdot
.87304 .47624 Mdot
.87305 .47623 Mdot
.87306 .47621 Mdot
.87307 .4762 Mdot
.87308 .47619 Mdot
.87309 .47617 Mdot
.8731 .47616 Mdot
.8731 .47614 Mdot
.87311 .47613 Mdot
.87312 .47612 Mdot
.87313 .4761 Mdot
.87314 .47609 Mdot
.87315 .47608 Mdot
.87316 .47606 Mdot
.87317 .47605 Mdot
.87318 .47604 Mdot
.87319 .47602 Mdot
.8732 .47601 Mdot
.87321 .47599 Mdot
.87322 .47598 Mdot
.87323 .47597 Mdot
.87324 .47595 Mdot
.87325 .47594 Mdot
.87326 .47593 Mdot
.87327 .47591 Mdot
.87328 .4759 Mdot
.87329 .47588 Mdot
.8733 .47587 Mdot
.8733 .47586 Mdot
.87331 .47584 Mdot
.87332 .47583 Mdot
.87333 .47582 Mdot
.87334 .4758 Mdot
.87335 .47579 Mdot
.87336 .47577 Mdot
.87337 .47576 Mdot
.87338 .47575 Mdot
.87339 .47573 Mdot
.8734 .47572 Mdot
.87341 .47571 Mdot
.87342 .47569 Mdot
.87343 .47568 Mdot
.87344 .47567 Mdot
.87345 .47565 Mdot
.87346 .47564 Mdot
.87347 .47562 Mdot
.87348 .47561 Mdot
.87349 .4756 Mdot
.8735 .47558 Mdot
.8735 .47557 Mdot
.87351 .47556 Mdot
.87352 .47554 Mdot
.87353 .47553 Mdot
.87354 .47551 Mdot
.87355 .4755 Mdot
.87356 .47549 Mdot
.87357 .47547 Mdot
.87358 .47546 Mdot
.87359 .47545 Mdot
.8736 .47543 Mdot
.87361 .47542 Mdot
.87362 .4754 Mdot
.87363 .47539 Mdot
.87364 .47538 Mdot
.87365 .47536 Mdot
.87366 .47535 Mdot
.87367 .47534 Mdot
.87368 .47532 Mdot
.87369 .47531 Mdot
.8737 .4753 Mdot
.8737 .47528 Mdot
.87371 .47527 Mdot
.87372 .47525 Mdot
.87373 .47524 Mdot
.87374 .47523 Mdot
.87375 .47521 Mdot
.87376 .4752 Mdot
.87377 .47519 Mdot
.87378 .47517 Mdot
.87379 .47516 Mdot
.8738 .47514 Mdot
.87381 .47513 Mdot
.87382 .47512 Mdot
.87383 .4751 Mdot
.87384 .47509 Mdot
.87385 .47508 Mdot
.87386 .47506 Mdot
.87387 .47505 Mdot
.87388 .47503 Mdot
.87389 .47502 Mdot
.8739 .47501 Mdot
.8739 .47499 Mdot
.87391 .47498 Mdot
.87392 .47497 Mdot
.87393 .47495 Mdot
.87394 .47494 Mdot
.87395 .47492 Mdot
.87396 .47491 Mdot
.87397 .4749 Mdot
.87398 .47488 Mdot
.87399 .47487 Mdot
.874 .47486 Mdot
.87401 .47484 Mdot
.87402 .47483 Mdot
.87403 .47481 Mdot
.87404 .4748 Mdot
.87405 .47479 Mdot
.87406 .47477 Mdot
.87407 .47476 Mdot
.87408 .47475 Mdot
.87409 .47473 Mdot
.8741 .47472 Mdot
.8741 .4747 Mdot
.87411 .47469 Mdot
.87412 .47468 Mdot
.87413 .47466 Mdot
.87414 .47465 Mdot
.87415 .47464 Mdot
.87416 .47462 Mdot
.87417 .47461 Mdot
.87418 .47459 Mdot
.87419 .47458 Mdot
.8742 .47457 Mdot
.87421 .47455 Mdot
.87422 .47454 Mdot
.87423 .47453 Mdot
.87424 .47451 Mdot
.87425 .4745 Mdot
.87426 .47448 Mdot
.87427 .47447 Mdot
.87428 .47446 Mdot
.87429 .47444 Mdot
.8743 .47443 Mdot
.8743 .47442 Mdot
.87431 .4744 Mdot
.87432 .47439 Mdot
.87433 .47437 Mdot
.87434 .47436 Mdot
.87435 .47435 Mdot
.87436 .47433 Mdot
.87437 .47432 Mdot
.87438 .47431 Mdot
.87439 .47429 Mdot
.8744 .47428 Mdot
.87441 .47426 Mdot
.87442 .47425 Mdot
.87443 .47424 Mdot
.87444 .47422 Mdot
.87445 .47421 Mdot
.87446 .4742 Mdot
.87447 .47418 Mdot
.87448 .47417 Mdot
.87449 .47415 Mdot
.8745 .47414 Mdot
.8745 .47413 Mdot
.87451 .47411 Mdot
.87452 .4741 Mdot
.87453 .47409 Mdot
.87454 .47407 Mdot
.87455 .47406 Mdot
.87456 .47404 Mdot
.87457 .47403 Mdot
.87458 .47402 Mdot
.87459 .474 Mdot
.8746 .47399 Mdot
.87461 .47398 Mdot
.87462 .47396 Mdot
.87463 .47395 Mdot
.87464 .47393 Mdot
.87465 .47392 Mdot
.87466 .47391 Mdot
.87467 .47389 Mdot
.87468 .47388 Mdot
.87469 .47387 Mdot
.8747 .47385 Mdot
.8747 .47384 Mdot
.87471 .47382 Mdot
.87472 .47381 Mdot
.87473 .4738 Mdot
.87474 .47378 Mdot
.87475 .47377 Mdot
.87476 .47376 Mdot
.87477 .47374 Mdot
.87478 .47373 Mdot
.87479 .47371 Mdot
.8748 .4737 Mdot
.87481 .47369 Mdot
.87482 .47367 Mdot
.87483 .47366 Mdot
.87484 .47365 Mdot
.87485 .47363 Mdot
.87486 .47362 Mdot
.87487 .4736 Mdot
.87488 .47359 Mdot
.87489 .47358 Mdot
.8749 .47356 Mdot
.8749 .47355 Mdot
.87491 .47353 Mdot
.87492 .47352 Mdot
.87493 .47351 Mdot
.87494 .47349 Mdot
.87495 .47348 Mdot
.87496 .47347 Mdot
.87497 .47345 Mdot
.87498 .47344 Mdot
.87499 .47342 Mdot
.875 .47341 Mdot
.87501 .4734 Mdot
.87502 .47338 Mdot
.87503 .47337 Mdot
.87504 .47336 Mdot
.87505 .47334 Mdot
.87506 .47333 Mdot
.87507 .47331 Mdot
.87508 .4733 Mdot
.87509 .47329 Mdot
.8751 .47327 Mdot
.8751 .47326 Mdot
.87511 .47325 Mdot
.87512 .47323 Mdot
.87513 .47322 Mdot
.87514 .4732 Mdot
.87515 .47319 Mdot
.87516 .47318 Mdot
.87517 .47316 Mdot
.87518 .47315 Mdot
.87519 .47314 Mdot
.8752 .47312 Mdot
.87521 .47311 Mdot
.87522 .47309 Mdot
.87523 .47308 Mdot
.87524 .47307 Mdot
.87525 .47305 Mdot
.87526 .47304 Mdot
.87527 .47302 Mdot
.87528 .47301 Mdot
.87529 .473 Mdot
.8753 .47298 Mdot
.8753 .47297 Mdot
.87531 .47296 Mdot
.87532 .47294 Mdot
.87533 .47293 Mdot
.87534 .47291 Mdot
.87535 .4729 Mdot
.87536 .47289 Mdot
.87537 .47287 Mdot
.87538 .47286 Mdot
.87539 .47285 Mdot
.8754 .47283 Mdot
.87541 .47282 Mdot
.87542 .4728 Mdot
.87543 .47279 Mdot
.87544 .47278 Mdot
.87545 .47276 Mdot
.87546 .47275 Mdot
.87547 .47273 Mdot
.87548 .47272 Mdot
.87549 .47271 Mdot
.8755 .47269 Mdot
.8755 .47268 Mdot
.87551 .47267 Mdot
.87552 .47265 Mdot
.87553 .47264 Mdot
.87554 .47262 Mdot
.87555 .47261 Mdot
.87556 .4726 Mdot
.87557 .47258 Mdot
.87558 .47257 Mdot
.87559 .47256 Mdot
.8756 .47254 Mdot
.87561 .47253 Mdot
.87562 .47251 Mdot
.87563 .4725 Mdot
.87564 .47249 Mdot
.87565 .47247 Mdot
.87566 .47246 Mdot
.87567 .47244 Mdot
.87568 .47243 Mdot
.87569 .47242 Mdot
.8757 .4724 Mdot
.8757 .47239 Mdot
.87571 .47238 Mdot
.87572 .47236 Mdot
.87573 .47235 Mdot
.87574 .47233 Mdot
.87575 .47232 Mdot
.87576 .47231 Mdot
.87577 .47229 Mdot
.87578 .47228 Mdot
.87579 .47226 Mdot
.8758 .47225 Mdot
.87581 .47224 Mdot
.87582 .47222 Mdot
.87583 .47221 Mdot
.87584 .4722 Mdot
.87585 .47218 Mdot
.87586 .47217 Mdot
.87587 .47215 Mdot
.87588 .47214 Mdot
.87589 .47213 Mdot
.8759 .47211 Mdot
.8759 .4721 Mdot
.87591 .47208 Mdot
.87592 .47207 Mdot
.87593 .47206 Mdot
.87594 .47204 Mdot
.87595 .47203 Mdot
.87596 .47202 Mdot
.87597 .472 Mdot
.87598 .47199 Mdot
.87599 .47197 Mdot
.876 .47196 Mdot
.87601 .47195 Mdot
.87602 .47193 Mdot
.87603 .47192 Mdot
.87604 .47191 Mdot
.87605 .47189 Mdot
.87606 .47188 Mdot
.87607 .47186 Mdot
.87608 .47185 Mdot
.87609 .47184 Mdot
.8761 .47182 Mdot
.8761 .47181 Mdot
.87611 .47179 Mdot
.87612 .47178 Mdot
.87613 .47177 Mdot
.87614 .47175 Mdot
.87615 .47174 Mdot
.87616 .47173 Mdot
.87617 .47171 Mdot
.87618 .4717 Mdot
.87619 .47168 Mdot
.8762 .47167 Mdot
.87621 .47166 Mdot
.87622 .47164 Mdot
.87623 .47163 Mdot
.87624 .47161 Mdot
.87625 .4716 Mdot
.87626 .47159 Mdot
.87627 .47157 Mdot
.87628 .47156 Mdot
.87629 .47155 Mdot
.8763 .47153 Mdot
.8763 .47152 Mdot
.87631 .4715 Mdot
.87632 .47149 Mdot
.87633 .47148 Mdot
.87634 .47146 Mdot
.87635 .47145 Mdot
.87636 .47143 Mdot
.87637 .47142 Mdot
.87638 .47141 Mdot
.87639 .47139 Mdot
.8764 .47138 Mdot
.87641 .47136 Mdot
.87642 .47135 Mdot
.87643 .47134 Mdot
.87644 .47132 Mdot
.87645 .47131 Mdot
.87646 .4713 Mdot
.87647 .47128 Mdot
.87648 .47127 Mdot
.87649 .47125 Mdot
.8765 .47124 Mdot
.8765 .47123 Mdot
.87651 .47121 Mdot
.87652 .4712 Mdot
.87653 .47118 Mdot
.87654 .47117 Mdot
.87655 .47116 Mdot
.87656 .47114 Mdot
.87657 .47113 Mdot
.87658 .47112 Mdot
.87659 .4711 Mdot
.8766 .47109 Mdot
.87661 .47107 Mdot
.87662 .47106 Mdot
.87663 .47105 Mdot
.87664 .47103 Mdot
.87665 .47102 Mdot
.87666 .471 Mdot
.87667 .47099 Mdot
.87668 .47098 Mdot
.87669 .47096 Mdot
.8767 .47095 Mdot
.8767 .47093 Mdot
.87671 .47092 Mdot
.87672 .47091 Mdot
.87673 .47089 Mdot
.87674 .47088 Mdot
.87675 .47087 Mdot
.87676 .47085 Mdot
.87677 .47084 Mdot
.87678 .47082 Mdot
.87679 .47081 Mdot
.8768 .4708 Mdot
.87681 .47078 Mdot
.87682 .47077 Mdot
.87683 .47075 Mdot
.87684 .47074 Mdot
.87685 .47073 Mdot
.87686 .47071 Mdot
.87687 .4707 Mdot
.87688 .47069 Mdot
.87689 .47067 Mdot
.8769 .47066 Mdot
.8769 .47064 Mdot
.87691 .47063 Mdot
.87692 .47062 Mdot
.87693 .4706 Mdot
.87694 .47059 Mdot
.87695 .47057 Mdot
.87696 .47056 Mdot
.87697 .47055 Mdot
.87698 .47053 Mdot
.87699 .47052 Mdot
.877 .4705 Mdot
.87701 .47049 Mdot
.87702 .47048 Mdot
.87703 .47046 Mdot
.87704 .47045 Mdot
.87705 .47044 Mdot
.87706 .47042 Mdot
.87707 .47041 Mdot
.87708 .47039 Mdot
.87709 .47038 Mdot
.8771 .47037 Mdot
.8771 .47035 Mdot
.87711 .47034 Mdot
.87712 .47032 Mdot
.87713 .47031 Mdot
.87714 .4703 Mdot
.87715 .47028 Mdot
.87716 .47027 Mdot
.87717 .47025 Mdot
.87718 .47024 Mdot
.87719 .47023 Mdot
.8772 .47021 Mdot
.87721 .4702 Mdot
.87722 .47018 Mdot
.87723 .47017 Mdot
.87724 .47016 Mdot
.87725 .47014 Mdot
.87726 .47013 Mdot
.87727 .47012 Mdot
.87728 .4701 Mdot
.87729 .47009 Mdot
.8773 .47007 Mdot
.8773 .47006 Mdot
.87731 .47005 Mdot
.87732 .47003 Mdot
.87733 .47002 Mdot
.87734 .47 Mdot
.87735 .46999 Mdot
.87736 .46998 Mdot
.87737 .46996 Mdot
.87738 .46995 Mdot
.87739 .46993 Mdot
.8774 .46992 Mdot
.87741 .46991 Mdot
.87742 .46989 Mdot
.87743 .46988 Mdot
.87744 .46987 Mdot
.87745 .46985 Mdot
.87746 .46984 Mdot
.87747 .46982 Mdot
.87748 .46981 Mdot
.87749 .4698 Mdot
.8775 .46978 Mdot
.8775 .46977 Mdot
.87751 .46975 Mdot
.87752 .46974 Mdot
.87753 .46973 Mdot
.87754 .46971 Mdot
.87755 .4697 Mdot
.87756 .46968 Mdot
.87757 .46967 Mdot
.87758 .46966 Mdot
.87759 .46964 Mdot
.8776 .46963 Mdot
.87761 .46961 Mdot
.87762 .4696 Mdot
.87763 .46959 Mdot
.87764 .46957 Mdot
.87765 .46956 Mdot
.87766 .46954 Mdot
.87767 .46953 Mdot
.87768 .46952 Mdot
.87769 .4695 Mdot
.8777 .46949 Mdot
.8777 .46948 Mdot
.87771 .46946 Mdot
.87772 .46945 Mdot
.87773 .46943 Mdot
.87774 .46942 Mdot
.87775 .46941 Mdot
.87776 .46939 Mdot
.87777 .46938 Mdot
.87778 .46936 Mdot
.87779 .46935 Mdot
.8778 .46934 Mdot
.87781 .46932 Mdot
.87782 .46931 Mdot
.87783 .46929 Mdot
.87784 .46928 Mdot
.87785 .46927 Mdot
.87786 .46925 Mdot
.87787 .46924 Mdot
.87788 .46922 Mdot
.87789 .46921 Mdot
.8779 .4692 Mdot
.8779 .46918 Mdot
.87791 .46917 Mdot
.87792 .46915 Mdot
.87793 .46914 Mdot
.87794 .46913 Mdot
.87795 .46911 Mdot
.87796 .4691 Mdot
.87797 .46909 Mdot
.87798 .46907 Mdot
.87799 .46906 Mdot
.878 .46904 Mdot
.87801 .46903 Mdot
.87802 .46902 Mdot
.87803 .469 Mdot
.87804 .46899 Mdot
.87805 .46897 Mdot
.87806 .46896 Mdot
.87807 .46895 Mdot
.87808 .46893 Mdot
.87809 .46892 Mdot
.8781 .4689 Mdot
.8781 .46889 Mdot
.87811 .46888 Mdot
.87812 .46886 Mdot
.87813 .46885 Mdot
.87814 .46883 Mdot
.87815 .46882 Mdot
.87816 .46881 Mdot
.87817 .46879 Mdot
.87818 .46878 Mdot
.87819 .46876 Mdot
.8782 .46875 Mdot
.87821 .46874 Mdot
.87822 .46872 Mdot
.87823 .46871 Mdot
.87824 .46869 Mdot
.87825 .46868 Mdot
.87826 .46867 Mdot
.87827 .46865 Mdot
.87828 .46864 Mdot
.87829 .46862 Mdot
.8783 .46861 Mdot
.8783 .4686 Mdot
.87831 .46858 Mdot
.87832 .46857 Mdot
.87833 .46855 Mdot
.87834 .46854 Mdot
.87835 .46853 Mdot
.87836 .46851 Mdot
.87837 .4685 Mdot
.87838 .46849 Mdot
.87839 .46847 Mdot
.8784 .46846 Mdot
.87841 .46844 Mdot
.87842 .46843 Mdot
.87843 .46842 Mdot
.87844 .4684 Mdot
.87845 .46839 Mdot
.87846 .46837 Mdot
.87847 .46836 Mdot
.87848 .46835 Mdot
.87849 .46833 Mdot
.8785 .46832 Mdot
.8785 .4683 Mdot
.87851 .46829 Mdot
.87852 .46828 Mdot
.87853 .46826 Mdot
.87854 .46825 Mdot
.87855 .46823 Mdot
.87856 .46822 Mdot
.87857 .46821 Mdot
.87858 .46819 Mdot
.87859 .46818 Mdot
.8786 .46816 Mdot
.87861 .46815 Mdot
.87862 .46814 Mdot
.87863 .46812 Mdot
.87864 .46811 Mdot
.87865 .46809 Mdot
.87866 .46808 Mdot
.87867 .46807 Mdot
.87868 .46805 Mdot
.87869 .46804 Mdot
.8787 .46802 Mdot
.8787 .46801 Mdot
.87871 .468 Mdot
.87872 .46798 Mdot
.87873 .46797 Mdot
.87874 .46795 Mdot
.87875 .46794 Mdot
.87876 .46793 Mdot
.87877 .46791 Mdot
.87878 .4679 Mdot
.87879 .46788 Mdot
.8788 .46787 Mdot
.87881 .46786 Mdot
.87882 .46784 Mdot
.87883 .46783 Mdot
.87884 .46781 Mdot
.87885 .4678 Mdot
.87886 .46779 Mdot
.87887 .46777 Mdot
.87888 .46776 Mdot
.87889 .46774 Mdot
.8789 .46773 Mdot
.8789 .46772 Mdot
.87891 .4677 Mdot
.87892 .46769 Mdot
.87893 .46767 Mdot
.87894 .46766 Mdot
.87895 .46765 Mdot
.87896 .46763 Mdot
.87897 .46762 Mdot
.87898 .4676 Mdot
.87899 .46759 Mdot
.879 .46758 Mdot
.87901 .46756 Mdot
.87902 .46755 Mdot
.87903 .46753 Mdot
.87904 .46752 Mdot
.87905 .46751 Mdot
.87906 .46749 Mdot
.87907 .46748 Mdot
.87908 .46746 Mdot
.87909 .46745 Mdot
.8791 .46744 Mdot
.8791 .46742 Mdot
.87911 .46741 Mdot
.87912 .46739 Mdot
.87913 .46738 Mdot
.87914 .46737 Mdot
.87915 .46735 Mdot
.87916 .46734 Mdot
.87917 .46732 Mdot
.87918 .46731 Mdot
.87919 .4673 Mdot
.8792 .46728 Mdot
.87921 .46727 Mdot
.87922 .46725 Mdot
.87923 .46724 Mdot
.87924 .46723 Mdot
.87925 .46721 Mdot
.87926 .4672 Mdot
.87927 .46718 Mdot
.87928 .46717 Mdot
.87929 .46716 Mdot
.8793 .46714 Mdot
.8793 .46713 Mdot
.87931 .46711 Mdot
.87932 .4671 Mdot
.87933 .46709 Mdot
.87934 .46707 Mdot
.87935 .46706 Mdot
.87936 .46704 Mdot
.87937 .46703 Mdot
.87938 .46702 Mdot
.87939 .467 Mdot
.8794 .46699 Mdot
.87941 .46697 Mdot
.87942 .46696 Mdot
.87943 .46695 Mdot
.87944 .46693 Mdot
.87945 .46692 Mdot
.87946 .4669 Mdot
.87947 .46689 Mdot
.87948 .46688 Mdot
.87949 .46686 Mdot
.8795 .46685 Mdot
.8795 .46683 Mdot
.87951 .46682 Mdot
.87952 .46681 Mdot
.87953 .46679 Mdot
.87954 .46678 Mdot
.87955 .46676 Mdot
.87956 .46675 Mdot
.87957 .46674 Mdot
.87958 .46672 Mdot
.87959 .46671 Mdot
.8796 .46669 Mdot
.87961 .46668 Mdot
.87962 .46667 Mdot
.87963 .46665 Mdot
.87964 .46664 Mdot
.87965 .46662 Mdot
.87966 .46661 Mdot
.87967 .4666 Mdot
.87968 .46658 Mdot
.87969 .46657 Mdot
.8797 .46655 Mdot
.8797 .46654 Mdot
.87971 .46653 Mdot
.87972 .46651 Mdot
.87973 .4665 Mdot
.87974 .46648 Mdot
.87975 .46647 Mdot
.87976 .46646 Mdot
.87977 .46644 Mdot
.87978 .46643 Mdot
.87979 .46641 Mdot
.8798 .4664 Mdot
.87981 .46639 Mdot
.87982 .46637 Mdot
.87983 .46636 Mdot
.87984 .46634 Mdot
.87985 .46633 Mdot
.87986 .46632 Mdot
.87987 .4663 Mdot
.87988 .46629 Mdot
.87989 .46627 Mdot
.8799 .46626 Mdot
.8799 .46625 Mdot
.87991 .46623 Mdot
.87992 .46622 Mdot
.87993 .4662 Mdot
.87994 .46619 Mdot
.87995 .46617 Mdot
.87996 .46616 Mdot
.87997 .46615 Mdot
.87998 .46613 Mdot
.87999 .46612 Mdot
.88 .4661 Mdot
.88001 .46609 Mdot
.88002 .46608 Mdot
.88003 .46606 Mdot
.88004 .46605 Mdot
.88005 .46603 Mdot
.88006 .46602 Mdot
.88007 .46601 Mdot
.88008 .46599 Mdot
.88009 .46598 Mdot
.8801 .46596 Mdot
.8801 .46595 Mdot
.88011 .46594 Mdot
.88012 .46592 Mdot
.88013 .46591 Mdot
.88014 .46589 Mdot
.88015 .46588 Mdot
.88016 .46587 Mdot
.88017 .46585 Mdot
.88018 .46584 Mdot
.88019 .46582 Mdot
.8802 .46581 Mdot
.88021 .4658 Mdot
.88022 .46578 Mdot
.88023 .46577 Mdot
.88024 .46575 Mdot
.88025 .46574 Mdot
.88026 .46573 Mdot
.88027 .46571 Mdot
.88028 .4657 Mdot
.88029 .46568 Mdot
.8803 .46567 Mdot
.8803 .46566 Mdot
.88031 .46564 Mdot
.88032 .46563 Mdot
.88033 .46561 Mdot
.88034 .4656 Mdot
.88035 .46558 Mdot
.88036 .46557 Mdot
.88037 .46556 Mdot
.88038 .46554 Mdot
.88039 .46553 Mdot
.8804 .46551 Mdot
.88041 .4655 Mdot
.88042 .46549 Mdot
.88043 .46547 Mdot
.88044 .46546 Mdot
.88045 .46544 Mdot
.88046 .46543 Mdot
.88047 .46542 Mdot
.88048 .4654 Mdot
.88049 .46539 Mdot
.8805 .46537 Mdot
.8805 .46536 Mdot
.88051 .46535 Mdot
.88052 .46533 Mdot
.88053 .46532 Mdot
.88054 .4653 Mdot
.88055 .46529 Mdot
.88056 .46528 Mdot
.88057 .46526 Mdot
.88058 .46525 Mdot
.88059 .46523 Mdot
.8806 .46522 Mdot
.88061 .4652 Mdot
.88062 .46519 Mdot
.88063 .46518 Mdot
.88064 .46516 Mdot
.88065 .46515 Mdot
.88066 .46513 Mdot
.88067 .46512 Mdot
.88068 .46511 Mdot
.88069 .46509 Mdot
.8807 .46508 Mdot
.8807 .46506 Mdot
.88071 .46505 Mdot
.88072 .46504 Mdot
.88073 .46502 Mdot
.88074 .46501 Mdot
.88075 .46499 Mdot
.88076 .46498 Mdot
.88077 .46497 Mdot
.88078 .46495 Mdot
.88079 .46494 Mdot
.8808 .46492 Mdot
.88081 .46491 Mdot
.88082 .4649 Mdot
.88083 .46488 Mdot
.88084 .46487 Mdot
.88085 .46485 Mdot
.88086 .46484 Mdot
.88087 .46482 Mdot
.88088 .46481 Mdot
.88089 .4648 Mdot
.8809 .46478 Mdot
.8809 .46477 Mdot
.88091 .46475 Mdot
.88092 .46474 Mdot
.88093 .46473 Mdot
.88094 .46471 Mdot
.88095 .4647 Mdot
.88096 .46468 Mdot
.88097 .46467 Mdot
.88098 .46466 Mdot
.88099 .46464 Mdot
.881 .46463 Mdot
.88101 .46461 Mdot
.88102 .4646 Mdot
.88103 .46459 Mdot
.88104 .46457 Mdot
.88105 .46456 Mdot
.88106 .46454 Mdot
.88107 .46453 Mdot
.88108 .46451 Mdot
.88109 .4645 Mdot
.8811 .46449 Mdot
.8811 .46447 Mdot
.88111 .46446 Mdot
.88112 .46444 Mdot
.88113 .46443 Mdot
.88114 .46442 Mdot
.88115 .4644 Mdot
.88116 .46439 Mdot
.88117 .46437 Mdot
.88118 .46436 Mdot
.88119 .46435 Mdot
.8812 .46433 Mdot
.88121 .46432 Mdot
.88122 .4643 Mdot
.88123 .46429 Mdot
.88124 .46428 Mdot
.88125 .46426 Mdot
.88126 .46425 Mdot
.88127 .46423 Mdot
.88128 .46422 Mdot
.88129 .4642 Mdot
.8813 .46419 Mdot
.8813 .46418 Mdot
.88131 .46416 Mdot
.88132 .46415 Mdot
.88133 .46413 Mdot
.88134 .46412 Mdot
.88135 .46411 Mdot
.88136 .46409 Mdot
.88137 .46408 Mdot
.88138 .46406 Mdot
.88139 .46405 Mdot
.8814 .46404 Mdot
.88141 .46402 Mdot
.88142 .46401 Mdot
.88143 .46399 Mdot
.88144 .46398 Mdot
.88145 .46396 Mdot
.88146 .46395 Mdot
.88147 .46394 Mdot
.88148 .46392 Mdot
.88149 .46391 Mdot
.8815 .46389 Mdot
.8815 .46388 Mdot
.88151 .46387 Mdot
.88152 .46385 Mdot
.88153 .46384 Mdot
.88154 .46382 Mdot
.88155 .46381 Mdot
.88156 .4638 Mdot
.88157 .46378 Mdot
.88158 .46377 Mdot
.88159 .46375 Mdot
.8816 .46374 Mdot
.88161 .46372 Mdot
.88162 .46371 Mdot
.88163 .4637 Mdot
.88164 .46368 Mdot
.88165 .46367 Mdot
.88166 .46365 Mdot
.88167 .46364 Mdot
.88168 .46363 Mdot
.88169 .46361 Mdot
.8817 .4636 Mdot
.8817 .46358 Mdot
.88171 .46357 Mdot
.88172 .46356 Mdot
.88173 .46354 Mdot
.88174 .46353 Mdot
.88175 .46351 Mdot
.88176 .4635 Mdot
.88177 .46348 Mdot
.88178 .46347 Mdot
.88179 .46346 Mdot
.8818 .46344 Mdot
.88181 .46343 Mdot
.88182 .46341 Mdot
.88183 .4634 Mdot
.88184 .46339 Mdot
.88185 .46337 Mdot
.88186 .46336 Mdot
.88187 .46334 Mdot
.88188 .46333 Mdot
.88189 .46331 Mdot
.8819 .4633 Mdot
.8819 .46329 Mdot
.88191 .46327 Mdot
.88192 .46326 Mdot
.88193 .46324 Mdot
.88194 .46323 Mdot
.88195 .46322 Mdot
.88196 .4632 Mdot
.88197 .46319 Mdot
.88198 .46317 Mdot
.88199 .46316 Mdot
.882 .46315 Mdot
.88201 .46313 Mdot
.88202 .46312 Mdot
.88203 .4631 Mdot
.88204 .46309 Mdot
.88205 .46307 Mdot
.88206 .46306 Mdot
.88207 .46305 Mdot
.88208 .46303 Mdot
.88209 .46302 Mdot
.8821 .463 Mdot
.8821 .46299 Mdot
.88211 .46298 Mdot
.88212 .46296 Mdot
.88213 .46295 Mdot
.88214 .46293 Mdot
.88215 .46292 Mdot
.88216 .4629 Mdot
.88217 .46289 Mdot
.88218 .46288 Mdot
.88219 .46286 Mdot
.8822 .46285 Mdot
.88221 .46283 Mdot
.88222 .46282 Mdot
.88223 .46281 Mdot
.88224 .46279 Mdot
.88225 .46278 Mdot
.88226 .46276 Mdot
.88227 .46275 Mdot
.88228 .46273 Mdot
.88229 .46272 Mdot
.8823 .46271 Mdot
.8823 .46269 Mdot
.88231 .46268 Mdot
.88232 .46266 Mdot
.88233 .46265 Mdot
.88234 .46264 Mdot
.88235 .46262 Mdot
.88236 .46261 Mdot
.88237 .46259 Mdot
.88238 .46258 Mdot
.88239 .46257 Mdot
.8824 .46255 Mdot
.88241 .46254 Mdot
.88242 .46252 Mdot
.88243 .46251 Mdot
.88244 .46249 Mdot
.88245 .46248 Mdot
.88246 .46247 Mdot
.88247 .46245 Mdot
.88248 .46244 Mdot
.88249 .46242 Mdot
.8825 .46241 Mdot
.8825 .4624 Mdot
.88251 .46238 Mdot
.88252 .46237 Mdot
.88253 .46235 Mdot
.88254 .46234 Mdot
.88255 .46232 Mdot
.88256 .46231 Mdot
.88257 .4623 Mdot
.88258 .46228 Mdot
.88259 .46227 Mdot
.8826 .46225 Mdot
.88261 .46224 Mdot
.88262 .46223 Mdot
.88263 .46221 Mdot
.88264 .4622 Mdot
.88265 .46218 Mdot
.88266 .46217 Mdot
.88267 .46215 Mdot
.88268 .46214 Mdot
.88269 .46213 Mdot
.8827 .46211 Mdot
.8827 .4621 Mdot
.88271 .46208 Mdot
.88272 .46207 Mdot
.88273 .46205 Mdot
.88274 .46204 Mdot
.88275 .46203 Mdot
.88276 .46201 Mdot
.88277 .462 Mdot
.88278 .46198 Mdot
.88279 .46197 Mdot
.8828 .46196 Mdot
.88281 .46194 Mdot
.88282 .46193 Mdot
.88283 .46191 Mdot
.88284 .4619 Mdot
.88285 .46188 Mdot
.88286 .46187 Mdot
.88287 .46186 Mdot
.88288 .46184 Mdot
.88289 .46183 Mdot
.8829 .46181 Mdot
.8829 .4618 Mdot
.88291 .46179 Mdot
.88292 .46177 Mdot
.88293 .46176 Mdot
.88294 .46174 Mdot
.88295 .46173 Mdot
.88296 .46171 Mdot
.88297 .4617 Mdot
.88298 .46169 Mdot
.88299 .46167 Mdot
.883 .46166 Mdot
.88301 .46164 Mdot
.88302 .46163 Mdot
.88303 .46162 Mdot
.88304 .4616 Mdot
.88305 .46159 Mdot
.88306 .46157 Mdot
.88307 .46156 Mdot
.88308 .46154 Mdot
.88309 .46153 Mdot
.8831 .46152 Mdot
.8831 .4615 Mdot
.88311 .46149 Mdot
.88312 .46147 Mdot
.88313 .46146 Mdot
.88314 .46144 Mdot
.88315 .46143 Mdot
.88316 .46142 Mdot
.88317 .4614 Mdot
.88318 .46139 Mdot
.88319 .46137 Mdot
.8832 .46136 Mdot
.88321 .46135 Mdot
.88322 .46133 Mdot
.88323 .46132 Mdot
.88324 .4613 Mdot
.88325 .46129 Mdot
.88326 .46127 Mdot
.88327 .46126 Mdot
.88328 .46125 Mdot
.88329 .46123 Mdot
.8833 .46122 Mdot
.8833 .4612 Mdot
.88331 .46119 Mdot
.88332 .46117 Mdot
.88333 .46116 Mdot
.88334 .46115 Mdot
.88335 .46113 Mdot
.88336 .46112 Mdot
.88337 .4611 Mdot
.88338 .46109 Mdot
.88339 .46108 Mdot
.8834 .46106 Mdot
.88341 .46105 Mdot
.88342 .46103 Mdot
.88343 .46102 Mdot
.88344 .461 Mdot
.88345 .46099 Mdot
.88346 .46098 Mdot
.88347 .46096 Mdot
.88348 .46095 Mdot
.88349 .46093 Mdot
.8835 .46092 Mdot
.8835 .4609 Mdot
.88351 .46089 Mdot
.88352 .46088 Mdot
.88353 .46086 Mdot
.88354 .46085 Mdot
.88355 .46083 Mdot
.88356 .46082 Mdot
.88357 .46081 Mdot
.88358 .46079 Mdot
.88359 .46078 Mdot
.8836 .46076 Mdot
.88361 .46075 Mdot
.88362 .46073 Mdot
.88363 .46072 Mdot
.88364 .46071 Mdot
.88365 .46069 Mdot
.88366 .46068 Mdot
.88367 .46066 Mdot
.88368 .46065 Mdot
.88369 .46063 Mdot
.8837 .46062 Mdot
.8837 .46061 Mdot
.88371 .46059 Mdot
.88372 .46058 Mdot
.88373 .46056 Mdot
.88374 .46055 Mdot
.88375 .46054 Mdot
.88376 .46052 Mdot
.88377 .46051 Mdot
.88378 .46049 Mdot
.88379 .46048 Mdot
.8838 .46046 Mdot
.88381 .46045 Mdot
.88382 .46044 Mdot
.88383 .46042 Mdot
.88384 .46041 Mdot
.88385 .46039 Mdot
.88386 .46038 Mdot
.88387 .46036 Mdot
.88388 .46035 Mdot
.88389 .46034 Mdot
.8839 .46032 Mdot
.8839 .46031 Mdot
.88391 .46029 Mdot
.88392 .46028 Mdot
.88393 .46026 Mdot
.88394 .46025 Mdot
.88395 .46024 Mdot
.88396 .46022 Mdot
.88397 .46021 Mdot
.88398 .46019 Mdot
.88399 .46018 Mdot
.884 .46017 Mdot
.88401 .46015 Mdot
.88402 .46014 Mdot
.88403 .46012 Mdot
.88404 .46011 Mdot
.88405 .46009 Mdot
.88406 .46008 Mdot
.88407 .46007 Mdot
.88408 .46005 Mdot
.88409 .46004 Mdot
.8841 .46002 Mdot
.8841 .46001 Mdot
.88411 .45999 Mdot
.88412 .45998 Mdot
.88413 .45997 Mdot
.88414 .45995 Mdot
.88415 .45994 Mdot
.88416 .45992 Mdot
.88417 .45991 Mdot
.88418 .45989 Mdot
.88419 .45988 Mdot
.8842 .45987 Mdot
.88421 .45985 Mdot
.88422 .45984 Mdot
.88423 .45982 Mdot
.88424 .45981 Mdot
.88425 .45979 Mdot
.88426 .45978 Mdot
.88427 .45977 Mdot
.88428 .45975 Mdot
.88429 .45974 Mdot
.8843 .45972 Mdot
.8843 .45971 Mdot
.88431 .4597 Mdot
.88432 .45968 Mdot
.88433 .45967 Mdot
.88434 .45965 Mdot
.88435 .45964 Mdot
.88436 .45962 Mdot
.88437 .45961 Mdot
.88438 .4596 Mdot
.88439 .45958 Mdot
.8844 .45957 Mdot
.88441 .45955 Mdot
.88442 .45954 Mdot
.88443 .45952 Mdot
.88444 .45951 Mdot
.88445 .4595 Mdot
.88446 .45948 Mdot
.88447 .45947 Mdot
.88448 .45945 Mdot
.88449 .45944 Mdot
.8845 .45942 Mdot
.8845 .45941 Mdot
.88451 .4594 Mdot
.88452 .45938 Mdot
.88453 .45937 Mdot
.88454 .45935 Mdot
.88455 .45934 Mdot
.88456 .45932 Mdot
.88457 .45931 Mdot
.88458 .4593 Mdot
.88459 .45928 Mdot
.8846 .45927 Mdot
.88461 .45925 Mdot
.88462 .45924 Mdot
.88463 .45922 Mdot
.88464 .45921 Mdot
.88465 .4592 Mdot
.88466 .45918 Mdot
.88467 .45917 Mdot
.88468 .45915 Mdot
.88469 .45914 Mdot
.8847 .45912 Mdot
.8847 .45911 Mdot
.88471 .4591 Mdot
.88472 .45908 Mdot
.88473 .45907 Mdot
.88474 .45905 Mdot
.88475 .45904 Mdot
.88476 .45902 Mdot
.88477 .45901 Mdot
.88478 .459 Mdot
.88479 .45898 Mdot
.8848 .45897 Mdot
.88481 .45895 Mdot
.88482 .45894 Mdot
.88483 .45892 Mdot
.88484 .45891 Mdot
.88485 .4589 Mdot
.88486 .45888 Mdot
.88487 .45887 Mdot
.88488 .45885 Mdot
.88489 .45884 Mdot
.8849 .45882 Mdot
.8849 .45881 Mdot
.88491 .4588 Mdot
.88492 .45878 Mdot
.88493 .45877 Mdot
.88494 .45875 Mdot
.88495 .45874 Mdot
.88496 .45872 Mdot
.88497 .45871 Mdot
.88498 .4587 Mdot
.88499 .45868 Mdot
.885 .45867 Mdot
.88501 .45865 Mdot
.88502 .45864 Mdot
.88503 .45862 Mdot
.88504 .45861 Mdot
.88505 .4586 Mdot
.88506 .45858 Mdot
.88507 .45857 Mdot
.88508 .45855 Mdot
.88509 .45854 Mdot
.8851 .45852 Mdot
.8851 .45851 Mdot
.88511 .4585 Mdot
.88512 .45848 Mdot
.88513 .45847 Mdot
.88514 .45845 Mdot
.88515 .45844 Mdot
.88516 .45842 Mdot
.88517 .45841 Mdot
.88518 .4584 Mdot
.88519 .45838 Mdot
.8852 .45837 Mdot
.88521 .45835 Mdot
.88522 .45834 Mdot
.88523 .45832 Mdot
.88524 .45831 Mdot
.88525 .4583 Mdot
.88526 .45828 Mdot
.88527 .45827 Mdot
.88528 .45825 Mdot
.88529 .45824 Mdot
.8853 .45822 Mdot
.8853 .45821 Mdot
.88531 .4582 Mdot
.88532 .45818 Mdot
.88533 .45817 Mdot
.88534 .45815 Mdot
.88535 .45814 Mdot
.88536 .45812 Mdot
.88537 .45811 Mdot
.88538 .4581 Mdot
.88539 .45808 Mdot
.8854 .45807 Mdot
.88541 .45805 Mdot
.88542 .45804 Mdot
.88543 .45802 Mdot
.88544 .45801 Mdot
.88545 .458 Mdot
.88546 .45798 Mdot
.88547 .45797 Mdot
.88548 .45795 Mdot
.88549 .45794 Mdot
.8855 .45792 Mdot
.8855 .45791 Mdot
.88551 .4579 Mdot
.88552 .45788 Mdot
.88553 .45787 Mdot
.88554 .45785 Mdot
.88555 .45784 Mdot
.88556 .45782 Mdot
.88557 .45781 Mdot
.88558 .4578 Mdot
.88559 .45778 Mdot
.8856 .45777 Mdot
.88561 .45775 Mdot
.88562 .45774 Mdot
.88563 .45772 Mdot
.88564 .45771 Mdot
.88565 .4577 Mdot
.88566 .45768 Mdot
.88567 .45767 Mdot
.88568 .45765 Mdot
.88569 .45764 Mdot
.8857 .45762 Mdot
.8857 .45761 Mdot
.88571 .45759 Mdot
.88572 .45758 Mdot
.88573 .45757 Mdot
.88574 .45755 Mdot
.88575 .45754 Mdot
.88576 .45752 Mdot
.88577 .45751 Mdot
.88578 .45749 Mdot
.88579 .45748 Mdot
.8858 .45747 Mdot
.88581 .45745 Mdot
.88582 .45744 Mdot
.88583 .45742 Mdot
.88584 .45741 Mdot
.88585 .45739 Mdot
.88586 .45738 Mdot
.88587 .45737 Mdot
.88588 .45735 Mdot
.88589 .45734 Mdot
.8859 .45732 Mdot
.8859 .45731 Mdot
.88591 .45729 Mdot
.88592 .45728 Mdot
.88593 .45727 Mdot
.88594 .45725 Mdot
.88595 .45724 Mdot
.88596 .45722 Mdot
.88597 .45721 Mdot
.88598 .45719 Mdot
.88599 .45718 Mdot
.886 .45716 Mdot
.88601 .45715 Mdot
.88602 .45714 Mdot
.88603 .45712 Mdot
.88604 .45711 Mdot
.88605 .45709 Mdot
.88606 .45708 Mdot
.88607 .45706 Mdot
.88608 .45705 Mdot
.88609 .45704 Mdot
.8861 .45702 Mdot
.8861 .45701 Mdot
.88611 .45699 Mdot
.88612 .45698 Mdot
.88613 .45696 Mdot
.88614 .45695 Mdot
.88615 .45694 Mdot
.88616 .45692 Mdot
.88617 .45691 Mdot
.88618 .45689 Mdot
.88619 .45688 Mdot
.8862 .45686 Mdot
.88621 .45685 Mdot
.88622 .45684 Mdot
.88623 .45682 Mdot
.88624 .45681 Mdot
.88625 .45679 Mdot
.88626 .45678 Mdot
.88627 .45676 Mdot
.88628 .45675 Mdot
.88629 .45673 Mdot
.8863 .45672 Mdot
.8863 .45671 Mdot
.88631 .45669 Mdot
.88632 .45668 Mdot
.88633 .45666 Mdot
.88634 .45665 Mdot
.88635 .45663 Mdot
.88636 .45662 Mdot
.88637 .45661 Mdot
.88638 .45659 Mdot
.88639 .45658 Mdot
.8864 .45656 Mdot
.88641 .45655 Mdot
.88642 .45653 Mdot
.88643 .45652 Mdot
.88644 .45651 Mdot
.88645 .45649 Mdot
.88646 .45648 Mdot
.88647 .45646 Mdot
.88648 .45645 Mdot
.88649 .45643 Mdot
.8865 .45642 Mdot
.8865 .4564 Mdot
.88651 .45639 Mdot
.88652 .45638 Mdot
.88653 .45636 Mdot
.88654 .45635 Mdot
.88655 .45633 Mdot
.88656 .45632 Mdot
.88657 .4563 Mdot
.88658 .45629 Mdot
.88659 .45628 Mdot
.8866 .45626 Mdot
.88661 .45625 Mdot
.88662 .45623 Mdot
.88663 .45622 Mdot
.88664 .4562 Mdot
.88665 .45619 Mdot
.88666 .45617 Mdot
.88667 .45616 Mdot
.88668 .45615 Mdot
.88669 .45613 Mdot
.8867 .45612 Mdot
.8867 .4561 Mdot
.88671 .45609 Mdot
.88672 .45607 Mdot
.88673 .45606 Mdot
.88674 .45605 Mdot
.88675 .45603 Mdot
.88676 .45602 Mdot
.88677 .456 Mdot
.88678 .45599 Mdot
.88679 .45597 Mdot
.8868 .45596 Mdot
.88681 .45595 Mdot
.88682 .45593 Mdot
.88683 .45592 Mdot
.88684 .4559 Mdot
.88685 .45589 Mdot
.88686 .45587 Mdot
.88687 .45586 Mdot
.88688 .45584 Mdot
.88689 .45583 Mdot
.8869 .45582 Mdot
.8869 .4558 Mdot
.88691 .45579 Mdot
.88692 .45577 Mdot
.88693 .45576 Mdot
.88694 .45574 Mdot
.88695 .45573 Mdot
.88696 .45572 Mdot
.88697 .4557 Mdot
.88698 .45569 Mdot
.88699 .45567 Mdot
.887 .45566 Mdot
.88701 .45564 Mdot
.88702 .45563 Mdot
.88703 .45561 Mdot
.88704 .4556 Mdot
.88705 .45559 Mdot
.88706 .45557 Mdot
.88707 .45556 Mdot
.88708 .45554 Mdot
.88709 .45553 Mdot
.8871 .45551 Mdot
.8871 .4555 Mdot
.88711 .45548 Mdot
.88712 .45547 Mdot
.88713 .45546 Mdot
.88714 .45544 Mdot
.88715 .45543 Mdot
.88716 .45541 Mdot
.88717 .4554 Mdot
.88718 .45538 Mdot
.88719 .45537 Mdot
.8872 .45536 Mdot
.88721 .45534 Mdot
.88722 .45533 Mdot
.88723 .45531 Mdot
.88724 .4553 Mdot
.88725 .45528 Mdot
.88726 .45527 Mdot
.88727 .45525 Mdot
.88728 .45524 Mdot
.88729 .45523 Mdot
.8873 .45521 Mdot
.8873 .4552 Mdot
.88731 .45518 Mdot
.88732 .45517 Mdot
.88733 .45515 Mdot
.88734 .45514 Mdot
.88735 .45513 Mdot
.88736 .45511 Mdot
.88737 .4551 Mdot
.88738 .45508 Mdot
.88739 .45507 Mdot
.8874 .45505 Mdot
.88741 .45504 Mdot
.88742 .45502 Mdot
.88743 .45501 Mdot
.88744 .455 Mdot
.88745 .45498 Mdot
.88746 .45497 Mdot
.88747 .45495 Mdot
.88748 .45494 Mdot
.88749 .45492 Mdot
.8875 .45491 Mdot
.8875 .45489 Mdot
.88751 .45488 Mdot
.88752 .45487 Mdot
.88753 .45485 Mdot
.88754 .45484 Mdot
.88755 .45482 Mdot
.88756 .45481 Mdot
.88757 .45479 Mdot
.88758 .45478 Mdot
.88759 .45477 Mdot
.8876 .45475 Mdot
.88761 .45474 Mdot
.88762 .45472 Mdot
.88763 .45471 Mdot
.88764 .45469 Mdot
.88765 .45468 Mdot
.88766 .45466 Mdot
.88767 .45465 Mdot
.88768 .45464 Mdot
.88769 .45462 Mdot
.8877 .45461 Mdot
.8877 .45459 Mdot
.88771 .45458 Mdot
.88772 .45456 Mdot
.88773 .45455 Mdot
.88774 .45453 Mdot
.88775 .45452 Mdot
.88776 .45451 Mdot
.88777 .45449 Mdot
.88778 .45448 Mdot
.88779 .45446 Mdot
.8878 .45445 Mdot
.88781 .45443 Mdot
.88782 .45442 Mdot
.88783 .4544 Mdot
.88784 .45439 Mdot
.88785 .45438 Mdot
.88786 .45436 Mdot
.88787 .45435 Mdot
.88788 .45433 Mdot
.88789 .45432 Mdot
.8879 .4543 Mdot
.8879 .45429 Mdot
.88791 .45427 Mdot
.88792 .45426 Mdot
.88793 .45425 Mdot
.88794 .45423 Mdot
.88795 .45422 Mdot
.88796 .4542 Mdot
.88797 .45419 Mdot
.88798 .45417 Mdot
.88799 .45416 Mdot
.888 .45415 Mdot
.88801 .45413 Mdot
.88802 .45412 Mdot
.88803 .4541 Mdot
.88804 .45409 Mdot
.88805 .45407 Mdot
.88806 .45406 Mdot
.88807 .45404 Mdot
.88808 .45403 Mdot
.88809 .45402 Mdot
.8881 .454 Mdot
.8881 .45399 Mdot
.88811 .45397 Mdot
.88812 .45396 Mdot
.88813 .45394 Mdot
.88814 .45393 Mdot
.88815 .45391 Mdot
.88816 .4539 Mdot
.88817 .45389 Mdot
.88818 .45387 Mdot
.88819 .45386 Mdot
.8882 .45384 Mdot
.88821 .45383 Mdot
.88822 .45381 Mdot
.88823 .4538 Mdot
.88824 .45378 Mdot
.88825 .45377 Mdot
.88826 .45376 Mdot
.88827 .45374 Mdot
.88828 .45373 Mdot
.88829 .45371 Mdot
.8883 .4537 Mdot
.8883 .45368 Mdot
.88831 .45367 Mdot
.88832 .45365 Mdot
.88833 .45364 Mdot
.88834 .45363 Mdot
.88835 .45361 Mdot
.88836 .4536 Mdot
.88837 .45358 Mdot
.88838 .45357 Mdot
.88839 .45355 Mdot
.8884 .45354 Mdot
.88841 .45352 Mdot
.88842 .45351 Mdot
.88843 .4535 Mdot
.88844 .45348 Mdot
.88845 .45347 Mdot
.88846 .45345 Mdot
.88847 .45344 Mdot
.88848 .45342 Mdot
.88849 .45341 Mdot
.8885 .45339 Mdot
.8885 .45338 Mdot
.88851 .45337 Mdot
.88852 .45335 Mdot
.88853 .45334 Mdot
.88854 .45332 Mdot
.88855 .45331 Mdot
.88856 .45329 Mdot
.88857 .45328 Mdot
.88858 .45326 Mdot
.88859 .45325 Mdot
.8886 .45324 Mdot
.88861 .45322 Mdot
.88862 .45321 Mdot
.88863 .45319 Mdot
.88864 .45318 Mdot
.88865 .45316 Mdot
.88866 .45315 Mdot
.88867 .45313 Mdot
.88868 .45312 Mdot
.88869 .45311 Mdot
.8887 .45309 Mdot
.8887 .45308 Mdot
.88871 .45306 Mdot
.88872 .45305 Mdot
.88873 .45303 Mdot
.88874 .45302 Mdot
.88875 .453 Mdot
.88876 .45299 Mdot
.88877 .45298 Mdot
.88878 .45296 Mdot
.88879 .45295 Mdot
.8888 .45293 Mdot
.88881 .45292 Mdot
.88882 .4529 Mdot
.88883 .45289 Mdot
.88884 .45287 Mdot
.88885 .45286 Mdot
.88886 .45284 Mdot
.88887 .45283 Mdot
.88888 .45282 Mdot
.88889 .4528 Mdot
.8889 .45279 Mdot
.8889 .45277 Mdot
.88891 .45276 Mdot
.88892 .45274 Mdot
.88893 .45273 Mdot
.88894 .45271 Mdot
.88895 .4527 Mdot
.88896 .45269 Mdot
.88897 .45267 Mdot
.88898 .45266 Mdot
.88899 .45264 Mdot
.889 .45263 Mdot
.88901 .45261 Mdot
.88902 .4526 Mdot
.88903 .45258 Mdot
.88904 .45257 Mdot
.88905 .45256 Mdot
.88906 .45254 Mdot
.88907 .45253 Mdot
.88908 .45251 Mdot
.88909 .4525 Mdot
.8891 .45248 Mdot
.8891 .45247 Mdot
.88911 .45245 Mdot
.88912 .45244 Mdot
.88913 .45243 Mdot
.88914 .45241 Mdot
.88915 .4524 Mdot
.88916 .45238 Mdot
.88917 .45237 Mdot
.88918 .45235 Mdot
.88919 .45234 Mdot
.8892 .45232 Mdot
.88921 .45231 Mdot
.88922 .45229 Mdot
.88923 .45228 Mdot
.88924 .45227 Mdot
.88925 .45225 Mdot
.88926 .45224 Mdot
.88927 .45222 Mdot
.88928 .45221 Mdot
.88929 .45219 Mdot
.8893 .45218 Mdot
.8893 .45216 Mdot
.88931 .45215 Mdot
.88932 .45214 Mdot
.88933 .45212 Mdot
.88934 .45211 Mdot
.88935 .45209 Mdot
.88936 .45208 Mdot
.88937 .45206 Mdot
.88938 .45205 Mdot
.88939 .45203 Mdot
.8894 .45202 Mdot
.88941 .45201 Mdot
.88942 .45199 Mdot
.88943 .45198 Mdot
.88944 .45196 Mdot
.88945 .45195 Mdot
.88946 .45193 Mdot
.88947 .45192 Mdot
.88948 .4519 Mdot
.88949 .45189 Mdot
.8895 .45187 Mdot
.8895 .45186 Mdot
.88951 .45185 Mdot
.88952 .45183 Mdot
.88953 .45182 Mdot
.88954 .4518 Mdot
.88955 .45179 Mdot
.88956 .45177 Mdot
.88957 .45176 Mdot
.88958 .45174 Mdot
.88959 .45173 Mdot
.8896 .45172 Mdot
.88961 .4517 Mdot
.88962 .45169 Mdot
.88963 .45167 Mdot
.88964 .45166 Mdot
.88965 .45164 Mdot
.88966 .45163 Mdot
.88967 .45161 Mdot
.88968 .4516 Mdot
.88969 .45158 Mdot
.8897 .45157 Mdot
.8897 .45156 Mdot
.88971 .45154 Mdot
.88972 .45153 Mdot
.88973 .45151 Mdot
.88974 .4515 Mdot
.88975 .45148 Mdot
.88976 .45147 Mdot
.88977 .45145 Mdot
.88978 .45144 Mdot
.88979 .45143 Mdot
.8898 .45141 Mdot
.88981 .4514 Mdot
.88982 .45138 Mdot
.88983 .45137 Mdot
.88984 .45135 Mdot
.88985 .45134 Mdot
.88986 .45132 Mdot
.88987 .45131 Mdot
.88988 .45129 Mdot
.88989 .45128 Mdot
.8899 .45127 Mdot
.8899 .45125 Mdot
.88991 .45124 Mdot
.88992 .45122 Mdot
.88993 .45121 Mdot
.88994 .45119 Mdot
.88995 .45118 Mdot
.88996 .45116 Mdot
.88997 .45115 Mdot
.88998 .45113 Mdot
.88999 .45112 Mdot
.89 .45111 Mdot
.89001 .45109 Mdot
.89002 .45108 Mdot
.89003 .45106 Mdot
.89004 .45105 Mdot
.89005 .45103 Mdot
.89006 .45102 Mdot
.89007 .451 Mdot
.89008 .45099 Mdot
.89009 .45098 Mdot
.8901 .45096 Mdot
.8901 .45095 Mdot
.89011 .45093 Mdot
.89012 .45092 Mdot
.89013 .4509 Mdot
.89014 .45089 Mdot
.89015 .45087 Mdot
.89016 .45086 Mdot
.89017 .45084 Mdot
.89018 .45083 Mdot
.89019 .45082 Mdot
.8902 .4508 Mdot
.89021 .45079 Mdot
.89022 .45077 Mdot
.89023 .45076 Mdot
.89024 .45074 Mdot
.89025 .45073 Mdot
.89026 .45071 Mdot
.89027 .4507 Mdot
.89028 .45068 Mdot
.89029 .45067 Mdot
.8903 .45066 Mdot
.8903 .45064 Mdot
.89031 .45063 Mdot
.89032 .45061 Mdot
.89033 .4506 Mdot
.89034 .45058 Mdot
.89035 .45057 Mdot
.89036 .45055 Mdot
.89037 .45054 Mdot
.89038 .45052 Mdot
.89039 .45051 Mdot
.8904 .4505 Mdot
.89041 .45048 Mdot
.89042 .45047 Mdot
.89043 .45045 Mdot
.89044 .45044 Mdot
.89045 .45042 Mdot
.89046 .45041 Mdot
.89047 .45039 Mdot
.89048 .45038 Mdot
.89049 .45036 Mdot
.8905 .45035 Mdot
.8905 .45034 Mdot
.89051 .45032 Mdot
.89052 .45031 Mdot
.89053 .45029 Mdot
.89054 .45028 Mdot
.89055 .45026 Mdot
.89056 .45025 Mdot
.89057 .45023 Mdot
.89058 .45022 Mdot
.89059 .4502 Mdot
.8906 .45019 Mdot
.89061 .45018 Mdot
.89062 .45016 Mdot
.89063 .45015 Mdot
.89064 .45013 Mdot
.89065 .45012 Mdot
.89066 .4501 Mdot
.89067 .45009 Mdot
.89068 .45007 Mdot
.89069 .45006 Mdot
.8907 .45004 Mdot
.8907 .45003 Mdot
.89071 .45002 Mdot
.89072 .45 Mdot
.89073 .44999 Mdot
.89074 .44997 Mdot
.89075 .44996 Mdot
.89076 .44994 Mdot
.89077 .44993 Mdot
.89078 .44991 Mdot
.89079 .4499 Mdot
.8908 .44988 Mdot
.89081 .44987 Mdot
.89082 .44986 Mdot
.89083 .44984 Mdot
.89084 .44983 Mdot
.89085 .44981 Mdot
.89086 .4498 Mdot
.89087 .44978 Mdot
.89088 .44977 Mdot
.89089 .44975 Mdot
.8909 .44974 Mdot
.8909 .44972 Mdot
.89091 .44971 Mdot
.89092 .4497 Mdot
.89093 .44968 Mdot
.89094 .44967 Mdot
.89095 .44965 Mdot
.89096 .44964 Mdot
.89097 .44962 Mdot
.89098 .44961 Mdot
.89099 .44959 Mdot
.891 .44958 Mdot
.89101 .44956 Mdot
.89102 .44955 Mdot
.89103 .44954 Mdot
.89104 .44952 Mdot
.89105 .44951 Mdot
.89106 .44949 Mdot
.89107 .44948 Mdot
.89108 .44946 Mdot
.89109 .44945 Mdot
.8911 .44943 Mdot
.8911 .44942 Mdot
.89111 .4494 Mdot
.89112 .44939 Mdot
.89113 .44938 Mdot
.89114 .44936 Mdot
.89115 .44935 Mdot
.89116 .44933 Mdot
.89117 .44932 Mdot
.89118 .4493 Mdot
.89119 .44929 Mdot
.8912 .44927 Mdot
.89121 .44926 Mdot
.89122 .44924 Mdot
.89123 .44923 Mdot
.89124 .44921 Mdot
.89125 .4492 Mdot
.89126 .44919 Mdot
.89127 .44917 Mdot
.89128 .44916 Mdot
.89129 .44914 Mdot
.8913 .44913 Mdot
.8913 .44911 Mdot
.89131 .4491 Mdot
.89132 .44908 Mdot
.89133 .44907 Mdot
.89134 .44905 Mdot
.89135 .44904 Mdot
.89136 .44903 Mdot
.89137 .44901 Mdot
.89138 .449 Mdot
.89139 .44898 Mdot
.8914 .44897 Mdot
.89141 .44895 Mdot
.89142 .44894 Mdot
.89143 .44892 Mdot
.89144 .44891 Mdot
.89145 .44889 Mdot
.89146 .44888 Mdot
.89147 .44887 Mdot
.89148 .44885 Mdot
.89149 .44884 Mdot
.8915 .44882 Mdot
.8915 .44881 Mdot
.89151 .44879 Mdot
.89152 .44878 Mdot
.89153 .44876 Mdot
.89154 .44875 Mdot
.89155 .44873 Mdot
.89156 .44872 Mdot
.89157 .4487 Mdot
.89158 .44869 Mdot
.89159 .44868 Mdot
.8916 .44866 Mdot
.89161 .44865 Mdot
.89162 .44863 Mdot
.89163 .44862 Mdot
.89164 .4486 Mdot
.89165 .44859 Mdot
.89166 .44857 Mdot
.89167 .44856 Mdot
.89168 .44854 Mdot
.89169 .44853 Mdot
.8917 .44851 Mdot
.8917 .4485 Mdot
.89171 .44849 Mdot
.89172 .44847 Mdot
.89173 .44846 Mdot
.89174 .44844 Mdot
.89175 .44843 Mdot
.89176 .44841 Mdot
.89177 .4484 Mdot
.89178 .44838 Mdot
.89179 .44837 Mdot
.8918 .44835 Mdot
.89181 .44834 Mdot
.89182 .44833 Mdot
.89183 .44831 Mdot
.89184 .4483 Mdot
.89185 .44828 Mdot
.89186 .44827 Mdot
.89187 .44825 Mdot
.89188 .44824 Mdot
.89189 .44822 Mdot
.8919 .44821 Mdot
.8919 .44819 Mdot
.89191 .44818 Mdot
.89192 .44816 Mdot
.89193 .44815 Mdot
.89194 .44814 Mdot
.89195 .44812 Mdot
.89196 .44811 Mdot
.89197 .44809 Mdot
.89198 .44808 Mdot
.89199 .44806 Mdot
.892 .44805 Mdot
.89201 .44803 Mdot
.89202 .44802 Mdot
.89203 .448 Mdot
.89204 .44799 Mdot
.89205 .44797 Mdot
.89206 .44796 Mdot
.89207 .44795 Mdot
.89208 .44793 Mdot
.89209 .44792 Mdot
.8921 .4479 Mdot
.8921 .44789 Mdot
.89211 .44787 Mdot
.89212 .44786 Mdot
.89213 .44784 Mdot
.89214 .44783 Mdot
.89215 .44781 Mdot
.89216 .4478 Mdot
.89217 .44778 Mdot
.89218 .44777 Mdot
.89219 .44776 Mdot
.8922 .44774 Mdot
.89221 .44773 Mdot
.89222 .44771 Mdot
.89223 .4477 Mdot
.89224 .44768 Mdot
.89225 .44767 Mdot
.89226 .44765 Mdot
.89227 .44764 Mdot
.89228 .44762 Mdot
.89229 .44761 Mdot
.8923 .44759 Mdot
.8923 .44758 Mdot
.89231 .44757 Mdot
.89232 .44755 Mdot
.89233 .44754 Mdot
.89234 .44752 Mdot
.89235 .44751 Mdot
.89236 .44749 Mdot
.89237 .44748 Mdot
.89238 .44746 Mdot
.89239 .44745 Mdot
.8924 .44743 Mdot
.89241 .44742 Mdot
.89242 .4474 Mdot
.89243 .44739 Mdot
.89244 .44738 Mdot
.89245 .44736 Mdot
.89246 .44735 Mdot
.89247 .44733 Mdot
.89248 .44732 Mdot
.89249 .4473 Mdot
.8925 .44729 Mdot
.8925 .44727 Mdot
.89251 .44726 Mdot
.89252 .44724 Mdot
.89253 .44723 Mdot
.89254 .44721 Mdot
.89255 .4472 Mdot
.89256 .44719 Mdot
.89257 .44717 Mdot
.89258 .44716 Mdot
.89259 .44714 Mdot
.8926 .44713 Mdot
.89261 .44711 Mdot
.89262 .4471 Mdot
.89263 .44708 Mdot
.89264 .44707 Mdot
.89265 .44705 Mdot
.89266 .44704 Mdot
.89267 .44702 Mdot
.89268 .44701 Mdot
.89269 .447 Mdot
.8927 .44698 Mdot
.8927 .44697 Mdot
.89271 .44695 Mdot
.89272 .44694 Mdot
.89273 .44692 Mdot
.89274 .44691 Mdot
.89275 .44689 Mdot
.89276 .44688 Mdot
.89277 .44686 Mdot
.89278 .44685 Mdot
.89279 .44683 Mdot
.8928 .44682 Mdot
.89281 .4468 Mdot
.89282 .44679 Mdot
.89283 .44678 Mdot
.89284 .44676 Mdot
.89285 .44675 Mdot
.89286 .44673 Mdot
.89287 .44672 Mdot
.89288 .4467 Mdot
.89289 .44669 Mdot
.8929 .44667 Mdot
.8929 .44666 Mdot
.89291 .44664 Mdot
.89292 .44663 Mdot
.89293 .44661 Mdot
.89294 .4466 Mdot
.89295 .44659 Mdot
.89296 .44657 Mdot
.89297 .44656 Mdot
.89298 .44654 Mdot
.89299 .44653 Mdot
.893 .44651 Mdot
.89301 .4465 Mdot
.89302 .44648 Mdot
.89303 .44647 Mdot
.89304 .44645 Mdot
.89305 .44644 Mdot
.89306 .44642 Mdot
.89307 .44641 Mdot
.89308 .44639 Mdot
.89309 .44638 Mdot
.8931 .44637 Mdot
.8931 .44635 Mdot
.89311 .44634 Mdot
.89312 .44632 Mdot
.89313 .44631 Mdot
.89314 .44629 Mdot
.89315 .44628 Mdot
.89316 .44626 Mdot
.89317 .44625 Mdot
.89318 .44623 Mdot
.89319 .44622 Mdot
.8932 .4462 Mdot
.89321 .44619 Mdot
.89322 .44617 Mdot
.89323 .44616 Mdot
.89324 .44615 Mdot
.89325 .44613 Mdot
.89326 .44612 Mdot
.89327 .4461 Mdot
.89328 .44609 Mdot
.89329 .44607 Mdot
.8933 .44606 Mdot
.8933 .44604 Mdot
.89331 .44603 Mdot
.89332 .44601 Mdot
.89333 .446 Mdot
.89334 .44598 Mdot
.89335 .44597 Mdot
.89336 .44595 Mdot
.89337 .44594 Mdot
.89338 .44593 Mdot
.89339 .44591 Mdot
.8934 .4459 Mdot
.89341 .44588 Mdot
.89342 .44587 Mdot
.89343 .44585 Mdot
.89344 .44584 Mdot
.89345 .44582 Mdot
.89346 .44581 Mdot
.89347 .44579 Mdot
.89348 .44578 Mdot
.89349 .44576 Mdot
.8935 .44575 Mdot
.8935 .44573 Mdot
.89351 .44572 Mdot
.89352 .44571 Mdot
.89353 .44569 Mdot
.89354 .44568 Mdot
.89355 .44566 Mdot
.89356 .44565 Mdot
.89357 .44563 Mdot
.89358 .44562 Mdot
.89359 .4456 Mdot
.8936 .44559 Mdot
.89361 .44557 Mdot
.89362 .44556 Mdot
.89363 .44554 Mdot
.89364 .44553 Mdot
.89365 .44551 Mdot
.89366 .4455 Mdot
.89367 .44549 Mdot
.89368 .44547 Mdot
.89369 .44546 Mdot
.8937 .44544 Mdot
.8937 .44543 Mdot
.89371 .44541 Mdot
.89372 .4454 Mdot
.89373 .44538 Mdot
.89374 .44537 Mdot
.89375 .44535 Mdot
.89376 .44534 Mdot
.89377 .44532 Mdot
.89378 .44531 Mdot
.89379 .44529 Mdot
.8938 .44528 Mdot
.89381 .44527 Mdot
.89382 .44525 Mdot
.89383 .44524 Mdot
.89384 .44522 Mdot
.89385 .44521 Mdot
.89386 .44519 Mdot
.89387 .44518 Mdot
.89388 .44516 Mdot
.89389 .44515 Mdot
.8939 .44513 Mdot
.8939 .44512 Mdot
.89391 .4451 Mdot
.89392 .44509 Mdot
.89393 .44507 Mdot
.89394 .44506 Mdot
.89395 .44504 Mdot
.89396 .44503 Mdot
.89397 .44502 Mdot
.89398 .445 Mdot
.89399 .44499 Mdot
.894 .44497 Mdot
.89401 .44496 Mdot
.89402 .44494 Mdot
.89403 .44493 Mdot
.89404 .44491 Mdot
.89405 .4449 Mdot
.89406 .44488 Mdot
.89407 .44487 Mdot
.89408 .44485 Mdot
.89409 .44484 Mdot
.8941 .44482 Mdot
.8941 .44481 Mdot
.89411 .44479 Mdot
.89412 .44478 Mdot
.89413 .44477 Mdot
.89414 .44475 Mdot
.89415 .44474 Mdot
.89416 .44472 Mdot
.89417 .44471 Mdot
.89418 .44469 Mdot
.89419 .44468 Mdot
.8942 .44466 Mdot
.89421 .44465 Mdot
.89422 .44463 Mdot
.89423 .44462 Mdot
.89424 .4446 Mdot
.89425 .44459 Mdot
.89426 .44457 Mdot
.89427 .44456 Mdot
.89428 .44454 Mdot
.89429 .44453 Mdot
.8943 .44452 Mdot
.8943 .4445 Mdot
.89431 .44449 Mdot
.89432 .44447 Mdot
.89433 .44446 Mdot
.89434 .44444 Mdot
.89435 .44443 Mdot
.89436 .44441 Mdot
.89437 .4444 Mdot
.89438 .44438 Mdot
.89439 .44437 Mdot
.8944 .44435 Mdot
.89441 .44434 Mdot
.89442 .44432 Mdot
.89443 .44431 Mdot
.89444 .44429 Mdot
.89445 .44428 Mdot
.89446 .44427 Mdot
.89447 .44425 Mdot
.89448 .44424 Mdot
.89449 .44422 Mdot
.8945 .44421 Mdot
.8945 .44419 Mdot
.89451 .44418 Mdot
.89452 .44416 Mdot
.89453 .44415 Mdot
.89454 .44413 Mdot
.89455 .44412 Mdot
.89456 .4441 Mdot
.89457 .44409 Mdot
.89458 .44407 Mdot
.89459 .44406 Mdot
.8946 .44404 Mdot
.89461 .44403 Mdot
.89462 .44402 Mdot
.89463 .444 Mdot
.89464 .44399 Mdot
.89465 .44397 Mdot
.89466 .44396 Mdot
.89467 .44394 Mdot
.89468 .44393 Mdot
.89469 .44391 Mdot
.8947 .4439 Mdot
.8947 .44388 Mdot
.89471 .44387 Mdot
.89472 .44385 Mdot
.89473 .44384 Mdot
.89474 .44382 Mdot
.89475 .44381 Mdot
.89476 .44379 Mdot
.89477 .44378 Mdot
.89478 .44376 Mdot
.89479 .44375 Mdot
.8948 .44374 Mdot
.89481 .44372 Mdot
.89482 .44371 Mdot
.89483 .44369 Mdot
.89484 .44368 Mdot
.89485 .44366 Mdot
.89486 .44365 Mdot
.89487 .44363 Mdot
.89488 .44362 Mdot
.89489 .4436 Mdot
.8949 .44359 Mdot
.8949 .44357 Mdot
.89491 .44356 Mdot
.89492 .44354 Mdot
.89493 .44353 Mdot
.89494 .44351 Mdot
.89495 .4435 Mdot
.89496 .44349 Mdot
.89497 .44347 Mdot
.89498 .44346 Mdot
.89499 .44344 Mdot
.895 .44343 Mdot
.89501 .44341 Mdot
.89502 .4434 Mdot
.89503 .44338 Mdot
.89504 .44337 Mdot
.89505 .44335 Mdot
.89506 .44334 Mdot
.89507 .44332 Mdot
.89508 .44331 Mdot
.89509 .44329 Mdot
.8951 .44328 Mdot
.8951 .44326 Mdot
.89511 .44325 Mdot
.89512 .44323 Mdot
.89513 .44322 Mdot
.89514 .44321 Mdot
.89515 .44319 Mdot
.89516 .44318 Mdot
.89517 .44316 Mdot
.89518 .44315 Mdot
.89519 .44313 Mdot
.8952 .44312 Mdot
.89521 .4431 Mdot
.89522 .44309 Mdot
.89523 .44307 Mdot
.89524 .44306 Mdot
.89525 .44304 Mdot
.89526 .44303 Mdot
.89527 .44301 Mdot
.89528 .443 Mdot
.89529 .44298 Mdot
.8953 .44297 Mdot
.8953 .44295 Mdot
.89531 .44294 Mdot
.89532 .44292 Mdot
.89533 .44291 Mdot
.89534 .4429 Mdot
.89535 .44288 Mdot
.89536 .44287 Mdot
.89537 .44285 Mdot
.89538 .44284 Mdot
.89539 .44282 Mdot
.8954 .44281 Mdot
.89541 .44279 Mdot
.89542 .44278 Mdot
.89543 .44276 Mdot
.89544 .44275 Mdot
.89545 .44273 Mdot
.89546 .44272 Mdot
.89547 .4427 Mdot
.89548 .44269 Mdot
.89549 .44267 Mdot
.8955 .44266 Mdot
.8955 .44264 Mdot
.89551 .44263 Mdot
.89552 .44262 Mdot
.89553 .4426 Mdot
.89554 .44259 Mdot
.89555 .44257 Mdot
.89556 .44256 Mdot
.89557 .44254 Mdot
.89558 .44253 Mdot
.89559 .44251 Mdot
.8956 .4425 Mdot
.89561 .44248 Mdot
.89562 .44247 Mdot
.89563 .44245 Mdot
.89564 .44244 Mdot
.89565 .44242 Mdot
.89566 .44241 Mdot
.89567 .44239 Mdot
.89568 .44238 Mdot
.89569 .44236 Mdot
.8957 .44235 Mdot
.8957 .44233 Mdot
.89571 .44232 Mdot
.89572 .44231 Mdot
.89573 .44229 Mdot
.89574 .44228 Mdot
.89575 .44226 Mdot
.89576 .44225 Mdot
.89577 .44223 Mdot
.89578 .44222 Mdot
.89579 .4422 Mdot
.8958 .44219 Mdot
.89581 .44217 Mdot
.89582 .44216 Mdot
.89583 .44214 Mdot
.89584 .44213 Mdot
.89585 .44211 Mdot
.89586 .4421 Mdot
.89587 .44208 Mdot
.89588 .44207 Mdot
.89589 .44205 Mdot
.8959 .44204 Mdot
.8959 .44202 Mdot
.89591 .44201 Mdot
.89592 .44199 Mdot
.89593 .44198 Mdot
.89594 .44197 Mdot
.89595 .44195 Mdot
.89596 .44194 Mdot
.89597 .44192 Mdot
.89598 .44191 Mdot
.89599 .44189 Mdot
.896 .44188 Mdot
.89601 .44186 Mdot
.89602 .44185 Mdot
.89603 .44183 Mdot
.89604 .44182 Mdot
.89605 .4418 Mdot
.89606 .44179 Mdot
.89607 .44177 Mdot
.89608 .44176 Mdot
.89609 .44174 Mdot
.8961 .44173 Mdot
.8961 .44171 Mdot
.89611 .4417 Mdot
.89612 .44168 Mdot
.89613 .44167 Mdot
.89614 .44165 Mdot
.89615 .44164 Mdot
.89616 .44163 Mdot
.89617 .44161 Mdot
.89618 .4416 Mdot
.89619 .44158 Mdot
.8962 .44157 Mdot
.89621 .44155 Mdot
.89622 .44154 Mdot
.89623 .44152 Mdot
.89624 .44151 Mdot
.89625 .44149 Mdot
.89626 .44148 Mdot
.89627 .44146 Mdot
.89628 .44145 Mdot
.89629 .44143 Mdot
.8963 .44142 Mdot
.8963 .4414 Mdot
.89631 .44139 Mdot
.89632 .44137 Mdot
.89633 .44136 Mdot
.89634 .44134 Mdot
.89635 .44133 Mdot
.89636 .44131 Mdot
.89637 .4413 Mdot
.89638 .44129 Mdot
.89639 .44127 Mdot
.8964 .44126 Mdot
.89641 .44124 Mdot
.89642 .44123 Mdot
.89643 .44121 Mdot
.89644 .4412 Mdot
.89645 .44118 Mdot
.89646 .44117 Mdot
.89647 .44115 Mdot
.89648 .44114 Mdot
.89649 .44112 Mdot
.8965 .44111 Mdot
.8965 .44109 Mdot
.89651 .44108 Mdot
.89652 .44106 Mdot
.89653 .44105 Mdot
.89654 .44103 Mdot
.89655 .44102 Mdot
.89656 .441 Mdot
.89657 .44099 Mdot
.89658 .44097 Mdot
.89659 .44096 Mdot
.8966 .44094 Mdot
.89661 .44093 Mdot
.89662 .44092 Mdot
.89663 .4409 Mdot
.89664 .44089 Mdot
.89665 .44087 Mdot
.89666 .44086 Mdot
.89667 .44084 Mdot
.89668 .44083 Mdot
.89669 .44081 Mdot
.8967 .4408 Mdot
.8967 .44078 Mdot
.89671 .44077 Mdot
.89672 .44075 Mdot
.89673 .44074 Mdot
.89674 .44072 Mdot
.89675 .44071 Mdot
.89676 .44069 Mdot
.89677 .44068 Mdot
.89678 .44066 Mdot
.89679 .44065 Mdot
.8968 .44063 Mdot
.89681 .44062 Mdot
.89682 .4406 Mdot
.89683 .44059 Mdot
.89684 .44057 Mdot
.89685 .44056 Mdot
.89686 .44054 Mdot
.89687 .44053 Mdot
.89688 .44052 Mdot
.89689 .4405 Mdot
.8969 .44049 Mdot
.8969 .44047 Mdot
.89691 .44046 Mdot
.89692 .44044 Mdot
.89693 .44043 Mdot
.89694 .44041 Mdot
.89695 .4404 Mdot
.89696 .44038 Mdot
.89697 .44037 Mdot
.89698 .44035 Mdot
.89699 .44034 Mdot
.897 .44032 Mdot
.89701 .44031 Mdot
.89702 .44029 Mdot
.89703 .44028 Mdot
.89704 .44026 Mdot
.89705 .44025 Mdot
.89706 .44023 Mdot
.89707 .44022 Mdot
.89708 .4402 Mdot
.89709 .44019 Mdot
.8971 .44017 Mdot
.8971 .44016 Mdot
.89711 .44014 Mdot
.89712 .44013 Mdot
.89713 .44012 Mdot
.89714 .4401 Mdot
.89715 .44009 Mdot
.89716 .44007 Mdot
.89717 .44006 Mdot
.89718 .44004 Mdot
.89719 .44003 Mdot
.8972 .44001 Mdot
.89721 .44 Mdot
.89722 .43998 Mdot
.89723 .43997 Mdot
.89724 .43995 Mdot
.89725 .43994 Mdot
.89726 .43992 Mdot
.89727 .43991 Mdot
.89728 .43989 Mdot
.89729 .43988 Mdot
.8973 .43986 Mdot
.8973 .43985 Mdot
.89731 .43983 Mdot
.89732 .43982 Mdot
.89733 .4398 Mdot
.89734 .43979 Mdot
.89735 .43977 Mdot
.89736 .43976 Mdot
.89737 .43974 Mdot
.89738 .43973 Mdot
.89739 .43971 Mdot
.8974 .4397 Mdot
.89741 .43969 Mdot
.89742 .43967 Mdot
.89743 .43966 Mdot
.89744 .43964 Mdot
.89745 .43963 Mdot
.89746 .43961 Mdot
.89747 .4396 Mdot
.89748 .43958 Mdot
.89749 .43957 Mdot
.8975 .43955 Mdot
.8975 .43954 Mdot
.89751 .43952 Mdot
.89752 .43951 Mdot
.89753 .43949 Mdot
.89754 .43948 Mdot
.89755 .43946 Mdot
.89756 .43945 Mdot
.89757 .43943 Mdot
.89758 .43942 Mdot
.89759 .4394 Mdot
.8976 .43939 Mdot
.89761 .43937 Mdot
.89762 .43936 Mdot
.89763 .43934 Mdot
.89764 .43933 Mdot
.89765 .43931 Mdot
.89766 .4393 Mdot
.89767 .43928 Mdot
.89768 .43927 Mdot
.89769 .43925 Mdot
.8977 .43924 Mdot
.8977 .43922 Mdot
.89771 .43921 Mdot
.89772 .4392 Mdot
.89773 .43918 Mdot
.89774 .43917 Mdot
.89775 .43915 Mdot
.89776 .43914 Mdot
.89777 .43912 Mdot
.89778 .43911 Mdot
.89779 .43909 Mdot
.8978 .43908 Mdot
.89781 .43906 Mdot
.89782 .43905 Mdot
.89783 .43903 Mdot
.89784 .43902 Mdot
.89785 .439 Mdot
.89786 .43899 Mdot
.89787 .43897 Mdot
.89788 .43896 Mdot
.89789 .43894 Mdot
.8979 .43893 Mdot
.8979 .43891 Mdot
.89791 .4389 Mdot
.89792 .43888 Mdot
.89793 .43887 Mdot
.89794 .43885 Mdot
.89795 .43884 Mdot
.89796 .43882 Mdot
.89797 .43881 Mdot
.89798 .43879 Mdot
.89799 .43878 Mdot
.898 .43876 Mdot
.89801 .43875 Mdot
.89802 .43873 Mdot
.89803 .43872 Mdot
.89804 .4387 Mdot
.89805 .43869 Mdot
.89806 .43868 Mdot
.89807 .43866 Mdot
.89808 .43865 Mdot
.89809 .43863 Mdot
.8981 .43862 Mdot
.8981 .4386 Mdot
.89811 .43859 Mdot
.89812 .43857 Mdot
.89813 .43856 Mdot
.89814 .43854 Mdot
.89815 .43853 Mdot
.89816 .43851 Mdot
.89817 .4385 Mdot
.89818 .43848 Mdot
.89819 .43847 Mdot
.8982 .43845 Mdot
.89821 .43844 Mdot
.89822 .43842 Mdot
.89823 .43841 Mdot
.89824 .43839 Mdot
.89825 .43838 Mdot
.89826 .43836 Mdot
.89827 .43835 Mdot
.89828 .43833 Mdot
.89829 .43832 Mdot
.8983 .4383 Mdot
.8983 .43829 Mdot
.89831 .43827 Mdot
.89832 .43826 Mdot
.89833 .43824 Mdot
.89834 .43823 Mdot
.89835 .43821 Mdot
.89836 .4382 Mdot
.89837 .43818 Mdot
.89838 .43817 Mdot
.89839 .43815 Mdot
.8984 .43814 Mdot
.89841 .43812 Mdot
.89842 .43811 Mdot
.89843 .4381 Mdot
.89844 .43808 Mdot
.89845 .43807 Mdot
.89846 .43805 Mdot
.89847 .43804 Mdot
.89848 .43802 Mdot
.89849 .43801 Mdot
.8985 .43799 Mdot
.8985 .43798 Mdot
.89851 .43796 Mdot
.89852 .43795 Mdot
.89853 .43793 Mdot
.89854 .43792 Mdot
.89855 .4379 Mdot
.89856 .43789 Mdot
.89857 .43787 Mdot
.89858 .43786 Mdot
.89859 .43784 Mdot
.8986 .43783 Mdot
.89861 .43781 Mdot
.89862 .4378 Mdot
.89863 .43778 Mdot
.89864 .43777 Mdot
.89865 .43775 Mdot
.89866 .43774 Mdot
.89867 .43772 Mdot
.89868 .43771 Mdot
.89869 .43769 Mdot
.8987 .43768 Mdot
.8987 .43766 Mdot
.89871 .43765 Mdot
.89872 .43763 Mdot
.89873 .43762 Mdot
.89874 .4376 Mdot
.89875 .43759 Mdot
.89876 .43757 Mdot
.89877 .43756 Mdot
.89878 .43754 Mdot
.89879 .43753 Mdot
.8988 .43751 Mdot
.89881 .4375 Mdot
.89882 .43748 Mdot
.89883 .43747 Mdot
.89884 .43746 Mdot
.89885 .43744 Mdot
.89886 .43743 Mdot
.89887 .43741 Mdot
.89888 .4374 Mdot
.89889 .43738 Mdot
.8989 .43737 Mdot
.8989 .43735 Mdot
.89891 .43734 Mdot
.89892 .43732 Mdot
.89893 .43731 Mdot
.89894 .43729 Mdot
.89895 .43728 Mdot
.89896 .43726 Mdot
.89897 .43725 Mdot
.89898 .43723 Mdot
.89899 .43722 Mdot
.899 .4372 Mdot
.89901 .43719 Mdot
.89902 .43717 Mdot
.89903 .43716 Mdot
.89904 .43714 Mdot
.89905 .43713 Mdot
.89906 .43711 Mdot
.89907 .4371 Mdot
.89908 .43708 Mdot
.89909 .43707 Mdot
.8991 .43705 Mdot
.8991 .43704 Mdot
.89911 .43702 Mdot
.89912 .43701 Mdot
.89913 .43699 Mdot
.89914 .43698 Mdot
.89915 .43696 Mdot
.89916 .43695 Mdot
.89917 .43693 Mdot
.89918 .43692 Mdot
.89919 .4369 Mdot
.8992 .43689 Mdot
.89921 .43687 Mdot
.89922 .43686 Mdot
.89923 .43684 Mdot
.89924 .43683 Mdot
.89925 .43681 Mdot
.89926 .4368 Mdot
.89927 .43678 Mdot
.89928 .43677 Mdot
.89929 .43675 Mdot
.8993 .43674 Mdot
.8993 .43672 Mdot
.89931 .43671 Mdot
.89932 .43669 Mdot
.89933 .43668 Mdot
.89934 .43667 Mdot
.89935 .43665 Mdot
.89936 .43664 Mdot
.89937 .43662 Mdot
.89938 .43661 Mdot
.89939 .43659 Mdot
.8994 .43658 Mdot
.89941 .43656 Mdot
.89942 .43655 Mdot
.89943 .43653 Mdot
.89944 .43652 Mdot
.89945 .4365 Mdot
.89946 .43649 Mdot
.89947 .43647 Mdot
.89948 .43646 Mdot
.89949 .43644 Mdot
.8995 .43643 Mdot
.8995 .43641 Mdot
.89951 .4364 Mdot
.89952 .43638 Mdot
.89953 .43637 Mdot
.89954 .43635 Mdot
.89955 .43634 Mdot
.89956 .43632 Mdot
.89957 .43631 Mdot
.89958 .43629 Mdot
.89959 .43628 Mdot
.8996 .43626 Mdot
.89961 .43625 Mdot
.89962 .43623 Mdot
.89963 .43622 Mdot
.89964 .4362 Mdot
.89965 .43619 Mdot
.89966 .43617 Mdot
.89967 .43616 Mdot
.89968 .43614 Mdot
.89969 .43613 Mdot
.8997 .43611 Mdot
.8997 .4361 Mdot
.89971 .43608 Mdot
.89972 .43607 Mdot
.89973 .43605 Mdot
.89974 .43604 Mdot
.89975 .43602 Mdot
.89976 .43601 Mdot
.89977 .43599 Mdot
.89978 .43598 Mdot
.89979 .43596 Mdot
.8998 .43595 Mdot
.89981 .43593 Mdot
.89982 .43592 Mdot
.89983 .4359 Mdot
.89984 .43589 Mdot
.89985 .43587 Mdot
.89986 .43586 Mdot
.89987 .43584 Mdot
.89988 .43583 Mdot
.89989 .43581 Mdot
.8999 .4358 Mdot
.8999 .43578 Mdot
.89991 .43577 Mdot
.89992 .43575 Mdot
.89993 .43574 Mdot
.89994 .43572 Mdot
.89995 .43571 Mdot
.89996 .43569 Mdot
.89997 .43568 Mdot
.89998 .43566 Mdot
.89999 .43565 Mdot
.9 .43563 Mdot
.90001 .43562 Mdot
.90002 .43561 Mdot
.90003 .43559 Mdot
.90004 .43558 Mdot
.90005 .43556 Mdot
.90006 .43555 Mdot
.90007 .43553 Mdot
.90008 .43552 Mdot
.90009 .4355 Mdot
.9001 .43549 Mdot
.9001 .43547 Mdot
.90011 .43546 Mdot
.90012 .43544 Mdot
.90013 .43543 Mdot
.90014 .43541 Mdot
.90015 .4354 Mdot
.90016 .43538 Mdot
.90017 .43537 Mdot
.90018 .43535 Mdot
.90019 .43534 Mdot
.9002 .43532 Mdot
.90021 .43531 Mdot
.90022 .43529 Mdot
.90023 .43528 Mdot
.90024 .43526 Mdot
.90025 .43525 Mdot
.90026 .43523 Mdot
.90027 .43522 Mdot
.90028 .4352 Mdot
.90029 .43519 Mdot
.9003 .43517 Mdot
.9003 .43516 Mdot
.90031 .43514 Mdot
.90032 .43513 Mdot
.90033 .43511 Mdot
.90034 .4351 Mdot
.90035 .43508 Mdot
.90036 .43507 Mdot
.90037 .43505 Mdot
.90038 .43504 Mdot
.90039 .43502 Mdot
.9004 .43501 Mdot
.90041 .43499 Mdot
.90042 .43498 Mdot
.90043 .43496 Mdot
.90044 .43495 Mdot
.90045 .43493 Mdot
.90046 .43492 Mdot
.90047 .4349 Mdot
.90048 .43489 Mdot
.90049 .43487 Mdot
.9005 .43486 Mdot
.9005 .43484 Mdot
.90051 .43483 Mdot
.90052 .43481 Mdot
.90053 .4348 Mdot
.90054 .43478 Mdot
.90055 .43477 Mdot
.90056 .43475 Mdot
.90057 .43474 Mdot
.90058 .43472 Mdot
.90059 .43471 Mdot
.9006 .43469 Mdot
.90061 .43468 Mdot
.90062 .43466 Mdot
.90063 .43465 Mdot
.90064 .43463 Mdot
.90065 .43462 Mdot
.90066 .4346 Mdot
.90067 .43459 Mdot
.90068 .43457 Mdot
.90069 .43456 Mdot
.9007 .43454 Mdot
.9007 .43453 Mdot
.90071 .43451 Mdot
.90072 .4345 Mdot
.90073 .43448 Mdot
.90074 .43447 Mdot
.90075 .43445 Mdot
.90076 .43444 Mdot
.90077 .43442 Mdot
.90078 .43441 Mdot
.90079 .43439 Mdot
.9008 .43438 Mdot
.90081 .43436 Mdot
.90082 .43435 Mdot
.90083 .43433 Mdot
.90084 .43432 Mdot
.90085 .4343 Mdot
.90086 .43429 Mdot
.90087 .43427 Mdot
.90088 .43426 Mdot
.90089 .43424 Mdot
.9009 .43423 Mdot
.9009 .43421 Mdot
.90091 .4342 Mdot
.90092 .43418 Mdot
.90093 .43417 Mdot
.90094 .43415 Mdot
.90095 .43414 Mdot
.90096 .43412 Mdot
.90097 .43411 Mdot
.90098 .43409 Mdot
.90099 .43408 Mdot
.901 .43406 Mdot
.90101 .43405 Mdot
.90102 .43403 Mdot
.90103 .43402 Mdot
.90104 .434 Mdot
.90105 .43399 Mdot
.90106 .43397 Mdot
.90107 .43396 Mdot
.90108 .43394 Mdot
.90109 .43393 Mdot
.9011 .43391 Mdot
.9011 .4339 Mdot
.90111 .43388 Mdot
.90112 .43387 Mdot
.90113 .43385 Mdot
.90114 .43384 Mdot
.90115 .43382 Mdot
.90116 .43381 Mdot
.90117 .43379 Mdot
.90118 .43378 Mdot
.90119 .43376 Mdot
.9012 .43375 Mdot
.90121 .43373 Mdot
.90122 .43372 Mdot
.90123 .4337 Mdot
.90124 .43369 Mdot
.90125 .43367 Mdot
.90126 .43366 Mdot
.90127 .43364 Mdot
.90128 .43363 Mdot
.90129 .43361 Mdot
.9013 .4336 Mdot
.9013 .43358 Mdot
.90131 .43357 Mdot
.90132 .43355 Mdot
.90133 .43354 Mdot
.90134 .43352 Mdot
.90135 .43351 Mdot
.90136 .43349 Mdot
.90137 .43348 Mdot
.90138 .43346 Mdot
.90139 .43345 Mdot
.9014 .43343 Mdot
.90141 .43342 Mdot
.90142 .4334 Mdot
.90143 .43339 Mdot
.90144 .43337 Mdot
.90145 .43336 Mdot
.90146 .43334 Mdot
.90147 .43333 Mdot
.90148 .43331 Mdot
.90149 .4333 Mdot
.9015 .43328 Mdot
.9015 .43327 Mdot
.90151 .43325 Mdot
.90152 .43324 Mdot
.90153 .43322 Mdot
.90154 .43321 Mdot
.90155 .43319 Mdot
.90156 .43318 Mdot
.90157 .43316 Mdot
.90158 .43315 Mdot
.90159 .43313 Mdot
.9016 .43312 Mdot
.90161 .4331 Mdot
.90162 .43309 Mdot
.90163 .43307 Mdot
.90164 .43306 Mdot
.90165 .43304 Mdot
.90166 .43303 Mdot
.90167 .43301 Mdot
.90168 .433 Mdot
.90169 .43298 Mdot
.9017 .43297 Mdot
.9017 .43295 Mdot
.90171 .43294 Mdot
.90172 .43292 Mdot
.90173 .43291 Mdot
.90174 .43289 Mdot
.90175 .43288 Mdot
.90176 .43286 Mdot
.90177 .43285 Mdot
.90178 .43283 Mdot
.90179 .43282 Mdot
.9018 .4328 Mdot
.90181 .43279 Mdot
.90182 .43277 Mdot
.90183 .43276 Mdot
.90184 .43274 Mdot
.90185 .43273 Mdot
.90186 .43271 Mdot
.90187 .4327 Mdot
.90188 .43268 Mdot
.90189 .43267 Mdot
.9019 .43265 Mdot
.9019 .43264 Mdot
.90191 .43262 Mdot
.90192 .43261 Mdot
.90193 .43259 Mdot
.90194 .43258 Mdot
.90195 .43256 Mdot
.90196 .43255 Mdot
.90197 .43253 Mdot
.90198 .43252 Mdot
.90199 .4325 Mdot
.902 .43249 Mdot
.90201 .43247 Mdot
.90202 .43246 Mdot
.90203 .43244 Mdot
.90204 .43243 Mdot
.90205 .43241 Mdot
.90206 .4324 Mdot
.90207 .43238 Mdot
.90208 .43237 Mdot
.90209 .43235 Mdot
.9021 .43234 Mdot
.9021 .43232 Mdot
.90211 .43231 Mdot
.90212 .43229 Mdot
.90213 .43228 Mdot
.90214 .43226 Mdot
.90215 .43225 Mdot
.90216 .43223 Mdot
.90217 .43222 Mdot
.90218 .4322 Mdot
.90219 .43219 Mdot
.9022 .43217 Mdot
.90221 .43216 Mdot
.90222 .43214 Mdot
.90223 .43213 Mdot
.90224 .43211 Mdot
.90225 .4321 Mdot
.90226 .43208 Mdot
.90227 .43207 Mdot
.90228 .43205 Mdot
.90229 .43204 Mdot
.9023 .43202 Mdot
.9023 .43201 Mdot
.90231 .43199 Mdot
.90232 .43198 Mdot
.90233 .43196 Mdot
.90234 .43195 Mdot
.90235 .43193 Mdot
.90236 .43192 Mdot
.90237 .4319 Mdot
.90238 .43189 Mdot
.90239 .43187 Mdot
.9024 .43186 Mdot
.90241 .43184 Mdot
.90242 .43183 Mdot
.90243 .43181 Mdot
.90244 .4318 Mdot
.90245 .43178 Mdot
.90246 .43177 Mdot
.90247 .43175 Mdot
.90248 .43174 Mdot
.90249 .43172 Mdot
.9025 .43171 Mdot
.9025 .43169 Mdot
.90251 .43168 Mdot
.90252 .43166 Mdot
.90253 .43165 Mdot
.90254 .43163 Mdot
.90255 .43162 Mdot
.90256 .4316 Mdot
.90257 .43159 Mdot
.90258 .43157 Mdot
.90259 .43156 Mdot
.9026 .43154 Mdot
.90261 .43153 Mdot
.90262 .43151 Mdot
.90263 .4315 Mdot
.90264 .43148 Mdot
.90265 .43147 Mdot
.90266 .43145 Mdot
.90267 .43144 Mdot
.90268 .43142 Mdot
.90269 .43141 Mdot
.9027 .43139 Mdot
.9027 .43138 Mdot
.90271 .43136 Mdot
.90272 .43135 Mdot
.90273 .43133 Mdot
.90274 .43132 Mdot
.90275 .4313 Mdot
.90276 .43129 Mdot
.90277 .43127 Mdot
.90278 .43126 Mdot
.90279 .43124 Mdot
.9028 .43123 Mdot
.90281 .43121 Mdot
.90282 .4312 Mdot
.90283 .43118 Mdot
.90284 .43117 Mdot
.90285 .43115 Mdot
.90286 .43114 Mdot
.90287 .43112 Mdot
.90288 .43111 Mdot
.90289 .43109 Mdot
.9029 .43108 Mdot
.9029 .43106 Mdot
.90291 .43104 Mdot
.90292 .43103 Mdot
.90293 .43101 Mdot
.90294 .431 Mdot
.90295 .43098 Mdot
.90296 .43097 Mdot
.90297 .43095 Mdot
.90298 .43094 Mdot
.90299 .43092 Mdot
.903 .43091 Mdot
.90301 .43089 Mdot
.90302 .43088 Mdot
.90303 .43086 Mdot
.90304 .43085 Mdot
.90305 .43083 Mdot
.90306 .43082 Mdot
.90307 .4308 Mdot
.90308 .43079 Mdot
.90309 .43077 Mdot
.9031 .43076 Mdot
.9031 .43074 Mdot
.90311 .43073 Mdot
.90312 .43071 Mdot
.90313 .4307 Mdot
.90314 .43068 Mdot
.90315 .43067 Mdot
.90316 .43065 Mdot
.90317 .43064 Mdot
.90318 .43062 Mdot
.90319 .43061 Mdot
.9032 .43059 Mdot
.90321 .43058 Mdot
.90322 .43056 Mdot
.90323 .43055 Mdot
.90324 .43053 Mdot
.90325 .43052 Mdot
.90326 .4305 Mdot
.90327 .43049 Mdot
.90328 .43047 Mdot
.90329 .43046 Mdot
.9033 .43044 Mdot
.9033 .43043 Mdot
.90331 .43041 Mdot
.90332 .4304 Mdot
.90333 .43038 Mdot
.90334 .43037 Mdot
.90335 .43035 Mdot
.90336 .43034 Mdot
.90337 .43032 Mdot
.90338 .43031 Mdot
.90339 .43029 Mdot
.9034 .43028 Mdot
.90341 .43026 Mdot
.90342 .43025 Mdot
.90343 .43023 Mdot
.90344 .43022 Mdot
.90345 .4302 Mdot
.90346 .43019 Mdot
.90347 .43017 Mdot
.90348 .43016 Mdot
.90349 .43014 Mdot
.9035 .43013 Mdot
.9035 .43011 Mdot
.90351 .4301 Mdot
.90352 .43008 Mdot
.90353 .43007 Mdot
.90354 .43005 Mdot
.90355 .43004 Mdot
.90356 .43002 Mdot
.90357 .43001 Mdot
.90358 .42999 Mdot
.90359 .42998 Mdot
.9036 .42996 Mdot
.90361 .42994 Mdot
.90362 .42993 Mdot
.90363 .42991 Mdot
.90364 .4299 Mdot
.90365 .42988 Mdot
.90366 .42987 Mdot
.90367 .42985 Mdot
.90368 .42984 Mdot
.90369 .42982 Mdot
.9037 .42981 Mdot
.9037 .42979 Mdot
.90371 .42978 Mdot
.90372 .42976 Mdot
.90373 .42975 Mdot
.90374 .42973 Mdot
.90375 .42972 Mdot
.90376 .4297 Mdot
.90377 .42969 Mdot
.90378 .42967 Mdot
.90379 .42966 Mdot
.9038 .42964 Mdot
.90381 .42963 Mdot
.90382 .42961 Mdot
.90383 .4296 Mdot
.90384 .42958 Mdot
.90385 .42957 Mdot
.90386 .42955 Mdot
.90387 .42954 Mdot
.90388 .42952 Mdot
.90389 .42951 Mdot
.9039 .42949 Mdot
.9039 .42948 Mdot
.90391 .42946 Mdot
.90392 .42945 Mdot
.90393 .42943 Mdot
.90394 .42942 Mdot
.90395 .4294 Mdot
.90396 .42939 Mdot
.90397 .42937 Mdot
.90398 .42936 Mdot
.90399 .42934 Mdot
.904 .42933 Mdot
.90401 .42931 Mdot
.90402 .4293 Mdot
.90403 .42928 Mdot
.90404 .42927 Mdot
.90405 .42925 Mdot
.90406 .42924 Mdot
.90407 .42922 Mdot
.90408 .42921 Mdot
.90409 .42919 Mdot
.9041 .42918 Mdot
.9041 .42916 Mdot
.90411 .42914 Mdot
.90412 .42913 Mdot
.90413 .42911 Mdot
.90414 .4291 Mdot
.90415 .42908 Mdot
.90416 .42907 Mdot
.90417 .42905 Mdot
.90418 .42904 Mdot
.90419 .42902 Mdot
.9042 .42901 Mdot
.90421 .42899 Mdot
.90422 .42898 Mdot
.90423 .42896 Mdot
.90424 .42895 Mdot
.90425 .42893 Mdot
.90426 .42892 Mdot
.90427 .4289 Mdot
.90428 .42889 Mdot
.90429 .42887 Mdot
.9043 .42886 Mdot
.9043 .42884 Mdot
.90431 .42883 Mdot
.90432 .42881 Mdot
.90433 .4288 Mdot
.90434 .42878 Mdot
.90435 .42877 Mdot
.90436 .42875 Mdot
.90437 .42874 Mdot
.90438 .42872 Mdot
.90439 .42871 Mdot
.9044 .42869 Mdot
.90441 .42868 Mdot
.90442 .42866 Mdot
.90443 .42865 Mdot
.90444 .42863 Mdot
.90445 .42862 Mdot
.90446 .4286 Mdot
.90447 .42859 Mdot
.90448 .42857 Mdot
.90449 .42856 Mdot
.9045 .42854 Mdot
.9045 .42853 Mdot
.90451 .42851 Mdot
.90452 .4285 Mdot
.90453 .42848 Mdot
.90454 .42846 Mdot
.90455 .42845 Mdot
.90456 .42843 Mdot
.90457 .42842 Mdot
.90458 .4284 Mdot
.90459 .42839 Mdot
.9046 .42837 Mdot
.90461 .42836 Mdot
.90462 .42834 Mdot
.90463 .42833 Mdot
.90464 .42831 Mdot
.90465 .4283 Mdot
.90466 .42828 Mdot
.90467 .42827 Mdot
.90468 .42825 Mdot
.90469 .42824 Mdot
.9047 .42822 Mdot
.9047 .42821 Mdot
.90471 .42819 Mdot
.90472 .42818 Mdot
.90473 .42816 Mdot
.90474 .42815 Mdot
.90475 .42813 Mdot
.90476 .42812 Mdot
.90477 .4281 Mdot
.90478 .42809 Mdot
.90479 .42807 Mdot
.9048 .42806 Mdot
.90481 .42804 Mdot
.90482 .42803 Mdot
.90483 .42801 Mdot
.90484 .428 Mdot
.90485 .42798 Mdot
.90486 .42797 Mdot
.90487 .42795 Mdot
.90488 .42794 Mdot
.90489 .42792 Mdot
.9049 .42791 Mdot
.9049 .42789 Mdot
.90491 .42788 Mdot
.90492 .42786 Mdot
.90493 .42784 Mdot
.90494 .42783 Mdot
.90495 .42781 Mdot
.90496 .4278 Mdot
.90497 .42778 Mdot
.90498 .42777 Mdot
.90499 .42775 Mdot
.905 .42774 Mdot
.90501 .42772 Mdot
.90502 .42771 Mdot
.90503 .42769 Mdot
.90504 .42768 Mdot
.90505 .42766 Mdot
.90506 .42765 Mdot
.90507 .42763 Mdot
.90508 .42762 Mdot
.90509 .4276 Mdot
.9051 .42759 Mdot
.9051 .42757 Mdot
.90511 .42756 Mdot
.90512 .42754 Mdot
.90513 .42753 Mdot
.90514 .42751 Mdot
.90515 .4275 Mdot
.90516 .42748 Mdot
.90517 .42747 Mdot
.90518 .42745 Mdot
.90519 .42744 Mdot
.9052 .42742 Mdot
.90521 .42741 Mdot
.90522 .42739 Mdot
.90523 .42738 Mdot
.90524 .42736 Mdot
.90525 .42735 Mdot
.90526 .42733 Mdot
.90527 .42731 Mdot
.90528 .4273 Mdot
.90529 .42728 Mdot
.9053 .42727 Mdot
.9053 .42725 Mdot
.90531 .42724 Mdot
.90532 .42722 Mdot
.90533 .42721 Mdot
.90534 .42719 Mdot
.90535 .42718 Mdot
.90536 .42716 Mdot
.90537 .42715 Mdot
.90538 .42713 Mdot
.90539 .42712 Mdot
.9054 .4271 Mdot
.90541 .42709 Mdot
.90542 .42707 Mdot
.90543 .42706 Mdot
.90544 .42704 Mdot
.90545 .42703 Mdot
.90546 .42701 Mdot
.90547 .427 Mdot
.90548 .42698 Mdot
.90549 .42697 Mdot
.9055 .42695 Mdot
.9055 .42694 Mdot
.90551 .42692 Mdot
.90552 .42691 Mdot
.90553 .42689 Mdot
.90554 .42688 Mdot
.90555 .42686 Mdot
.90556 .42685 Mdot
.90557 .42683 Mdot
.90558 .42681 Mdot
.90559 .4268 Mdot
.9056 .42678 Mdot
.90561 .42677 Mdot
.90562 .42675 Mdot
.90563 .42674 Mdot
.90564 .42672 Mdot
.90565 .42671 Mdot
.90566 .42669 Mdot
.90567 .42668 Mdot
.90568 .42666 Mdot
.90569 .42665 Mdot
.9057 .42663 Mdot
.9057 .42662 Mdot
.90571 .4266 Mdot
.90572 .42659 Mdot
.90573 .42657 Mdot
.90574 .42656 Mdot
.90575 .42654 Mdot
.90576 .42653 Mdot
.90577 .42651 Mdot
.90578 .4265 Mdot
.90579 .42648 Mdot
.9058 .42647 Mdot
.90581 .42645 Mdot
.90582 .42644 Mdot
.90583 .42642 Mdot
.90584 .42641 Mdot
.90585 .42639 Mdot
.90586 .42638 Mdot
.90587 .42636 Mdot
.90588 .42634 Mdot
.90589 .42633 Mdot
.9059 .42631 Mdot
.9059 .4263 Mdot
.90591 .42628 Mdot
.90592 .42627 Mdot
.90593 .42625 Mdot
.90594 .42624 Mdot
.90595 .42622 Mdot
.90596 .42621 Mdot
.90597 .42619 Mdot
.90598 .42618 Mdot
.90599 .42616 Mdot
.906 .42615 Mdot
.90601 .42613 Mdot
.90602 .42612 Mdot
.90603 .4261 Mdot
.90604 .42609 Mdot
.90605 .42607 Mdot
.90606 .42606 Mdot
.90607 .42604 Mdot
.90608 .42603 Mdot
.90609 .42601 Mdot
.9061 .426 Mdot
.9061 .42598 Mdot
.90611 .42597 Mdot
.90612 .42595 Mdot
.90613 .42594 Mdot
.90614 .42592 Mdot
.90615 .4259 Mdot
.90616 .42589 Mdot
.90617 .42587 Mdot
.90618 .42586 Mdot
.90619 .42584 Mdot
.9062 .42583 Mdot
.90621 .42581 Mdot
.90622 .4258 Mdot
.90623 .42578 Mdot
.90624 .42577 Mdot
.90625 .42575 Mdot
.90626 .42574 Mdot
.90627 .42572 Mdot
.90628 .42571 Mdot
.90629 .42569 Mdot
.9063 .42568 Mdot
.9063 .42566 Mdot
.90631 .42565 Mdot
.90632 .42563 Mdot
.90633 .42562 Mdot
.90634 .4256 Mdot
.90635 .42559 Mdot
.90636 .42557 Mdot
.90637 .42556 Mdot
.90638 .42554 Mdot
.90639 .42553 Mdot
.9064 .42551 Mdot
.90641 .42549 Mdot
.90642 .42548 Mdot
.90643 .42546 Mdot
.90644 .42545 Mdot
.90645 .42543 Mdot
.90646 .42542 Mdot
.90647 .4254 Mdot
.90648 .42539 Mdot
.90649 .42537 Mdot
.9065 .42536 Mdot
.9065 .42534 Mdot
.90651 .42533 Mdot
.90652 .42531 Mdot
.90653 .4253 Mdot
.90654 .42528 Mdot
.90655 .42527 Mdot
.90656 .42525 Mdot
.90657 .42524 Mdot
.90658 .42522 Mdot
.90659 .42521 Mdot
.9066 .42519 Mdot
.90661 .42518 Mdot
.90662 .42516 Mdot
.90663 .42515 Mdot
.90664 .42513 Mdot
.90665 .42512 Mdot
.90666 .4251 Mdot
.90667 .42508 Mdot
.90668 .42507 Mdot
.90669 .42505 Mdot
.9067 .42504 Mdot
.9067 .42502 Mdot
.90671 .42501 Mdot
.90672 .42499 Mdot
.90673 .42498 Mdot
.90674 .42496 Mdot
.90675 .42495 Mdot
.90676 .42493 Mdot
.90677 .42492 Mdot
.90678 .4249 Mdot
.90679 .42489 Mdot
.9068 .42487 Mdot
.90681 .42486 Mdot
.90682 .42484 Mdot
.90683 .42483 Mdot
.90684 .42481 Mdot
.90685 .4248 Mdot
.90686 .42478 Mdot
.90687 .42477 Mdot
.90688 .42475 Mdot
.90689 .42474 Mdot
.9069 .42472 Mdot
.9069 .4247 Mdot
.90691 .42469 Mdot
.90692 .42467 Mdot
.90693 .42466 Mdot
.90694 .42464 Mdot
.90695 .42463 Mdot
.90696 .42461 Mdot
.90697 .4246 Mdot
.90698 .42458 Mdot
.90699 .42457 Mdot
.907 .42455 Mdot
.90701 .42454 Mdot
.90702 .42452 Mdot
.90703 .42451 Mdot
.90704 .42449 Mdot
.90705 .42448 Mdot
.90706 .42446 Mdot
.90707 .42445 Mdot
.90708 .42443 Mdot
.90709 .42442 Mdot
.9071 .4244 Mdot
.9071 .42439 Mdot
.90711 .42437 Mdot
.90712 .42435 Mdot
.90713 .42434 Mdot
.90714 .42432 Mdot
.90715 .42431 Mdot
.90716 .42429 Mdot
.90717 .42428 Mdot
.90718 .42426 Mdot
.90719 .42425 Mdot
.9072 .42423 Mdot
.90721 .42422 Mdot
.90722 .4242 Mdot
.90723 .42419 Mdot
.90724 .42417 Mdot
.90725 .42416 Mdot
.90726 .42414 Mdot
.90727 .42413 Mdot
.90728 .42411 Mdot
.90729 .4241 Mdot
.9073 .42408 Mdot
.9073 .42407 Mdot
.90731 .42405 Mdot
.90732 .42404 Mdot
.90733 .42402 Mdot
.90734 .424 Mdot
.90735 .42399 Mdot
.90736 .42397 Mdot
.90737 .42396 Mdot
.90738 .42394 Mdot
.90739 .42393 Mdot
.9074 .42391 Mdot
.90741 .4239 Mdot
.90742 .42388 Mdot
.90743 .42387 Mdot
.90744 .42385 Mdot
.90745 .42384 Mdot
.90746 .42382 Mdot
.90747 .42381 Mdot
.90748 .42379 Mdot
.90749 .42378 Mdot
.9075 .42376 Mdot
.9075 .42375 Mdot
.90751 .42373 Mdot
.90752 .42372 Mdot
.90753 .4237 Mdot
.90754 .42369 Mdot
.90755 .42367 Mdot
.90756 .42365 Mdot
.90757 .42364 Mdot
.90758 .42362 Mdot
.90759 .42361 Mdot
.9076 .42359 Mdot
.90761 .42358 Mdot
.90762 .42356 Mdot
.90763 .42355 Mdot
.90764 .42353 Mdot
.90765 .42352 Mdot
.90766 .4235 Mdot
.90767 .42349 Mdot
.90768 .42347 Mdot
.90769 .42346 Mdot
.9077 .42344 Mdot
.9077 .42343 Mdot
.90771 .42341 Mdot
.90772 .4234 Mdot
.90773 .42338 Mdot
.90774 .42337 Mdot
.90775 .42335 Mdot
.90776 .42333 Mdot
.90777 .42332 Mdot
.90778 .4233 Mdot
.90779 .42329 Mdot
.9078 .42327 Mdot
.90781 .42326 Mdot
.90782 .42324 Mdot
.90783 .42323 Mdot
.90784 .42321 Mdot
.90785 .4232 Mdot
.90786 .42318 Mdot
.90787 .42317 Mdot
.90788 .42315 Mdot
.90789 .42314 Mdot
.9079 .42312 Mdot
.9079 .42311 Mdot
.90791 .42309 Mdot
.90792 .42308 Mdot
.90793 .42306 Mdot
.90794 .42305 Mdot
.90795 .42303 Mdot
.90796 .42301 Mdot
.90797 .423 Mdot
.90798 .42298 Mdot
.90799 .42297 Mdot
.908 .42295 Mdot
.90801 .42294 Mdot
.90802 .42292 Mdot
.90803 .42291 Mdot
.90804 .42289 Mdot
.90805 .42288 Mdot
.90806 .42286 Mdot
.90807 .42285 Mdot
.90808 .42283 Mdot
.90809 .42282 Mdot
.9081 .4228 Mdot
.9081 .42279 Mdot
.90811 .42277 Mdot
.90812 .42276 Mdot
.90813 .42274 Mdot
.90814 .42272 Mdot
.90815 .42271 Mdot
.90816 .42269 Mdot
.90817 .42268 Mdot
.90818 .42266 Mdot
.90819 .42265 Mdot
.9082 .42263 Mdot
.90821 .42262 Mdot
.90822 .4226 Mdot
.90823 .42259 Mdot
.90824 .42257 Mdot
.90825 .42256 Mdot
.90826 .42254 Mdot
.90827 .42253 Mdot
.90828 .42251 Mdot
.90829 .4225 Mdot
.9083 .42248 Mdot
.9083 .42247 Mdot
.90831 .42245 Mdot
.90832 .42244 Mdot
.90833 .42242 Mdot
.90834 .4224 Mdot
.90835 .42239 Mdot
.90836 .42237 Mdot
.90837 .42236 Mdot
.90838 .42234 Mdot
.90839 .42233 Mdot
.9084 .42231 Mdot
.90841 .4223 Mdot
.90842 .42228 Mdot
.90843 .42227 Mdot
.90844 .42225 Mdot
.90845 .42224 Mdot
.90846 .42222 Mdot
.90847 .42221 Mdot
.90848 .42219 Mdot
.90849 .42218 Mdot
.9085 .42216 Mdot
.9085 .42215 Mdot
.90851 .42213 Mdot
.90852 .42211 Mdot
.90853 .4221 Mdot
.90854 .42208 Mdot
.90855 .42207 Mdot
.90856 .42205 Mdot
.90857 .42204 Mdot
.90858 .42202 Mdot
.90859 .42201 Mdot
.9086 .42199 Mdot
.90861 .42198 Mdot
.90862 .42196 Mdot
.90863 .42195 Mdot
.90864 .42193 Mdot
.90865 .42192 Mdot
.90866 .4219 Mdot
.90867 .42189 Mdot
.90868 .42187 Mdot
.90869 .42186 Mdot
.9087 .42184 Mdot
.9087 .42182 Mdot
.90871 .42181 Mdot
.90872 .42179 Mdot
.90873 .42178 Mdot
.90874 .42176 Mdot
.90875 .42175 Mdot
.90876 .42173 Mdot
.90877 .42172 Mdot
.90878 .4217 Mdot
.90879 .42169 Mdot
.9088 .42167 Mdot
.90881 .42166 Mdot
.90882 .42164 Mdot
.90883 .42163 Mdot
.90884 .42161 Mdot
.90885 .4216 Mdot
.90886 .42158 Mdot
.90887 .42156 Mdot
.90888 .42155 Mdot
.90889 .42153 Mdot
.9089 .42152 Mdot
.9089 .4215 Mdot
.90891 .42149 Mdot
.90892 .42147 Mdot
.90893 .42146 Mdot
.90894 .42144 Mdot
.90895 .42143 Mdot
.90896 .42141 Mdot
.90897 .4214 Mdot
.90898 .42138 Mdot
.90899 .42137 Mdot
.909 .42135 Mdot
.90901 .42134 Mdot
.90902 .42132 Mdot
.90903 .42131 Mdot
.90904 .42129 Mdot
.90905 .42127 Mdot
.90906 .42126 Mdot
.90907 .42124 Mdot
.90908 .42123 Mdot
.90909 .42121 Mdot
.9091 .4212 Mdot
.9091 .42118 Mdot
.90911 .42117 Mdot
.90912 .42115 Mdot
.90913 .42114 Mdot
.90914 .42112 Mdot
.90915 .42111 Mdot
.90916 .42109 Mdot
.90917 .42108 Mdot
.90918 .42106 Mdot
.90919 .42105 Mdot
.9092 .42103 Mdot
.90921 .42101 Mdot
.90922 .421 Mdot
.90923 .42098 Mdot
.90924 .42097 Mdot
.90925 .42095 Mdot
.90926 .42094 Mdot
.90927 .42092 Mdot
.90928 .42091 Mdot
.90929 .42089 Mdot
.9093 .42088 Mdot
.9093 .42086 Mdot
.90931 .42085 Mdot
.90932 .42083 Mdot
.90933 .42082 Mdot
.90934 .4208 Mdot
.90935 .42079 Mdot
.90936 .42077 Mdot
.90937 .42075 Mdot
.90938 .42074 Mdot
.90939 .42072 Mdot
.9094 .42071 Mdot
.90941 .42069 Mdot
.90942 .42068 Mdot
.90943 .42066 Mdot
.90944 .42065 Mdot
.90945 .42063 Mdot
.90946 .42062 Mdot
.90947 .4206 Mdot
.90948 .42059 Mdot
.90949 .42057 Mdot
.9095 .42056 Mdot
.9095 .42054 Mdot
.90951 .42053 Mdot
.90952 .42051 Mdot
.90953 .42049 Mdot
.90954 .42048 Mdot
.90955 .42046 Mdot
.90956 .42045 Mdot
.90957 .42043 Mdot
.90958 .42042 Mdot
.90959 .4204 Mdot
.9096 .42039 Mdot
.90961 .42037 Mdot
.90962 .42036 Mdot
.90963 .42034 Mdot
.90964 .42033 Mdot
.90965 .42031 Mdot
.90966 .4203 Mdot
.90967 .42028 Mdot
.90968 .42027 Mdot
.90969 .42025 Mdot
.9097 .42023 Mdot
.9097 .42022 Mdot
.90971 .4202 Mdot
.90972 .42019 Mdot
.90973 .42017 Mdot
.90974 .42016 Mdot
.90975 .42014 Mdot
.90976 .42013 Mdot
.90977 .42011 Mdot
.90978 .4201 Mdot
.90979 .42008 Mdot
.9098 .42007 Mdot
.90981 .42005 Mdot
.90982 .42004 Mdot
.90983 .42002 Mdot
.90984 .42 Mdot
.90985 .41999 Mdot
.90986 .41997 Mdot
.90987 .41996 Mdot
.90988 .41994 Mdot
.90989 .41993 Mdot
.9099 .41991 Mdot
.9099 .4199 Mdot
.90991 .41988 Mdot
.90992 .41987 Mdot
.90993 .41985 Mdot
.90994 .41984 Mdot
.90995 .41982 Mdot
.90996 .41981 Mdot
.90997 .41979 Mdot
.90998 .41978 Mdot
.90999 .41976 Mdot
.91 .41974 Mdot
.91001 .41973 Mdot
.91002 .41971 Mdot
.91003 .4197 Mdot
.91004 .41968 Mdot
.91005 .41967 Mdot
.91006 .41965 Mdot
.91007 .41964 Mdot
.91008 .41962 Mdot
.91009 .41961 Mdot
.9101 .41959 Mdot
.9101 .41958 Mdot
.91011 .41956 Mdot
.91012 .41955 Mdot
.91013 .41953 Mdot
.91014 .41951 Mdot
.91015 .4195 Mdot
.91016 .41948 Mdot
.91017 .41947 Mdot
.91018 .41945 Mdot
.91019 .41944 Mdot
.9102 .41942 Mdot
.91021 .41941 Mdot
.91022 .41939 Mdot
.91023 .41938 Mdot
.91024 .41936 Mdot
.91025 .41935 Mdot
.91026 .41933 Mdot
.91027 .41932 Mdot
.91028 .4193 Mdot
.91029 .41928 Mdot
.9103 .41927 Mdot
.9103 .41925 Mdot
.91031 .41924 Mdot
.91032 .41922 Mdot
.91033 .41921 Mdot
.91034 .41919 Mdot
.91035 .41918 Mdot
.91036 .41916 Mdot
.91037 .41915 Mdot
.91038 .41913 Mdot
.91039 .41912 Mdot
.9104 .4191 Mdot
.91041 .41909 Mdot
.91042 .41907 Mdot
.91043 .41906 Mdot
.91044 .41904 Mdot
.91045 .41902 Mdot
.91046 .41901 Mdot
.91047 .41899 Mdot
.91048 .41898 Mdot
.91049 .41896 Mdot
.9105 .41895 Mdot
.9105 .41893 Mdot
.91051 .41892 Mdot
.91052 .4189 Mdot
.91053 .41889 Mdot
.91054 .41887 Mdot
.91055 .41886 Mdot
.91056 .41884 Mdot
.91057 .41883 Mdot
.91058 .41881 Mdot
.91059 .41879 Mdot
.9106 .41878 Mdot
.91061 .41876 Mdot
.91062 .41875 Mdot
.91063 .41873 Mdot
.91064 .41872 Mdot
.91065 .4187 Mdot
.91066 .41869 Mdot
.91067 .41867 Mdot
.91068 .41866 Mdot
.91069 .41864 Mdot
.9107 .41863 Mdot
.9107 .41861 Mdot
.91071 .41859 Mdot
.91072 .41858 Mdot
.91073 .41856 Mdot
.91074 .41855 Mdot
.91075 .41853 Mdot
.91076 .41852 Mdot
.91077 .4185 Mdot
.91078 .41849 Mdot
.91079 .41847 Mdot
.9108 .41846 Mdot
.91081 .41844 Mdot
.91082 .41843 Mdot
.91083 .41841 Mdot
.91084 .4184 Mdot
.91085 .41838 Mdot
.91086 .41836 Mdot
.91087 .41835 Mdot
.91088 .41833 Mdot
.91089 .41832 Mdot
.9109 .4183 Mdot
.9109 .41829 Mdot
.91091 .41827 Mdot
.91092 .41826 Mdot
.91093 .41824 Mdot
.91094 .41823 Mdot
.91095 .41821 Mdot
.91096 .4182 Mdot
.91097 .41818 Mdot
.91098 .41817 Mdot
.91099 .41815 Mdot
.911 .41813 Mdot
.91101 .41812 Mdot
.91102 .4181 Mdot
.91103 .41809 Mdot
.91104 .41807 Mdot
.91105 .41806 Mdot
.91106 .41804 Mdot
.91107 .41803 Mdot
.91108 .41801 Mdot
.91109 .418 Mdot
.9111 .41798 Mdot
.9111 .41797 Mdot
.91111 .41795 Mdot
.91112 .41793 Mdot
.91113 .41792 Mdot
.91114 .4179 Mdot
.91115 .41789 Mdot
.91116 .41787 Mdot
.91117 .41786 Mdot
.91118 .41784 Mdot
.91119 .41783 Mdot
.9112 .41781 Mdot
.91121 .4178 Mdot
.91122 .41778 Mdot
.91123 .41777 Mdot
.91124 .41775 Mdot
.91125 .41774 Mdot
.91126 .41772 Mdot
.91127 .4177 Mdot
.91128 .41769 Mdot
.91129 .41767 Mdot
.9113 .41766 Mdot
.9113 .41764 Mdot
.91131 .41763 Mdot
.91132 .41761 Mdot
.91133 .4176 Mdot
.91134 .41758 Mdot
.91135 .41757 Mdot
.91136 .41755 Mdot
.91137 .41754 Mdot
.91138 .41752 Mdot
.91139 .4175 Mdot
.9114 .41749 Mdot
.91141 .41747 Mdot
.91142 .41746 Mdot
.91143 .41744 Mdot
.91144 .41743 Mdot
.91145 .41741 Mdot
.91146 .4174 Mdot
.91147 .41738 Mdot
.91148 .41737 Mdot
.91149 .41735 Mdot
.9115 .41734 Mdot
.9115 .41732 Mdot
.91151 .41731 Mdot
.91152 .41729 Mdot
.91153 .41727 Mdot
.91154 .41726 Mdot
.91155 .41724 Mdot
.91156 .41723 Mdot
.91157 .41721 Mdot
.91158 .4172 Mdot
.91159 .41718 Mdot
.9116 .41717 Mdot
.91161 .41715 Mdot
.91162 .41714 Mdot
.91163 .41712 Mdot
.91164 .41711 Mdot
.91165 .41709 Mdot
.91166 .41707 Mdot
.91167 .41706 Mdot
.91168 .41704 Mdot
.91169 .41703 Mdot
.9117 .41701 Mdot
.9117 .417 Mdot
.91171 .41698 Mdot
.91172 .41697 Mdot
.91173 .41695 Mdot
.91174 .41694 Mdot
.91175 .41692 Mdot
.91176 .41691 Mdot
.91177 .41689 Mdot
.91178 .41687 Mdot
.91179 .41686 Mdot
.9118 .41684 Mdot
.91181 .41683 Mdot
.91182 .41681 Mdot
.91183 .4168 Mdot
.91184 .41678 Mdot
.91185 .41677 Mdot
.91186 .41675 Mdot
.91187 .41674 Mdot
.91188 .41672 Mdot
.91189 .41671 Mdot
.9119 .41669 Mdot
.9119 .41667 Mdot
.91191 .41666 Mdot
.91192 .41664 Mdot
.91193 .41663 Mdot
.91194 .41661 Mdot
.91195 .4166 Mdot
.91196 .41658 Mdot
.91197 .41657 Mdot
.91198 .41655 Mdot
.91199 .41654 Mdot
.912 .41652 Mdot
.91201 .41651 Mdot
.91202 .41649 Mdot
.91203 .41647 Mdot
.91204 .41646 Mdot
.91205 .41644 Mdot
.91206 .41643 Mdot
.91207 .41641 Mdot
.91208 .4164 Mdot
.91209 .41638 Mdot
.9121 .41637 Mdot
.9121 .41635 Mdot
.91211 .41634 Mdot
.91212 .41632 Mdot
.91213 .41631 Mdot
.91214 .41629 Mdot
.91215 .41627 Mdot
.91216 .41626 Mdot
.91217 .41624 Mdot
.91218 .41623 Mdot
.91219 .41621 Mdot
.9122 .4162 Mdot
.91221 .41618 Mdot
.91222 .41617 Mdot
.91223 .41615 Mdot
.91224 .41614 Mdot
.91225 .41612 Mdot
.91226 .41611 Mdot
.91227 .41609 Mdot
.91228 .41607 Mdot
.91229 .41606 Mdot
.9123 .41604 Mdot
.9123 .41603 Mdot
.91231 .41601 Mdot
.91232 .416 Mdot
.91233 .41598 Mdot
.91234 .41597 Mdot
.91235 .41595 Mdot
.91236 .41594 Mdot
.91237 .41592 Mdot
.91238 .41591 Mdot
.91239 .41589 Mdot
.9124 .41587 Mdot
.91241 .41586 Mdot
.91242 .41584 Mdot
.91243 .41583 Mdot
.91244 .41581 Mdot
.91245 .4158 Mdot
.91246 .41578 Mdot
.91247 .41577 Mdot
.91248 .41575 Mdot
.91249 .41574 Mdot
.9125 .41572 Mdot
.9125 .41571 Mdot
.91251 .41569 Mdot
.91252 .41567 Mdot
.91253 .41566 Mdot
.91254 .41564 Mdot
.91255 .41563 Mdot
.91256 .41561 Mdot
.91257 .4156 Mdot
.91258 .41558 Mdot
.91259 .41557 Mdot
.9126 .41555 Mdot
.91261 .41554 Mdot
.91262 .41552 Mdot
.91263 .4155 Mdot
.91264 .41549 Mdot
.91265 .41547 Mdot
.91266 .41546 Mdot
.91267 .41544 Mdot
.91268 .41543 Mdot
.91269 .41541 Mdot
.9127 .4154 Mdot
.9127 .41538 Mdot
.91271 .41537 Mdot
.91272 .41535 Mdot
.91273 .41534 Mdot
.91274 .41532 Mdot
.91275 .4153 Mdot
.91276 .41529 Mdot
.91277 .41527 Mdot
.91278 .41526 Mdot
.91279 .41524 Mdot
.9128 .41523 Mdot
.91281 .41521 Mdot
.91282 .4152 Mdot
.91283 .41518 Mdot
.91284 .41517 Mdot
.91285 .41515 Mdot
.91286 .41513 Mdot
.91287 .41512 Mdot
.91288 .4151 Mdot
.91289 .41509 Mdot
.9129 .41507 Mdot
.9129 .41506 Mdot
.91291 .41504 Mdot
.91292 .41503 Mdot
.91293 .41501 Mdot
.91294 .415 Mdot
.91295 .41498 Mdot
.91296 .41497 Mdot
.91297 .41495 Mdot
.91298 .41493 Mdot
.91299 .41492 Mdot
.913 .4149 Mdot
.91301 .41489 Mdot
.91302 .41487 Mdot
.91303 .41486 Mdot
.91304 .41484 Mdot
.91305 .41483 Mdot
.91306 .41481 Mdot
.91307 .4148 Mdot
.91308 .41478 Mdot
.91309 .41476 Mdot
.9131 .41475 Mdot
.9131 .41473 Mdot
.91311 .41472 Mdot
.91312 .4147 Mdot
.91313 .41469 Mdot
.91314 .41467 Mdot
.91315 .41466 Mdot
.91316 .41464 Mdot
.91317 .41463 Mdot
.91318 .41461 Mdot
.91319 .4146 Mdot
.9132 .41458 Mdot
.91321 .41456 Mdot
.91322 .41455 Mdot
.91323 .41453 Mdot
.91324 .41452 Mdot
.91325 .4145 Mdot
.91326 .41449 Mdot
.91327 .41447 Mdot
.91328 .41446 Mdot
.91329 .41444 Mdot
.9133 .41443 Mdot
.9133 .41441 Mdot
.91331 .41439 Mdot
.91332 .41438 Mdot
.91333 .41436 Mdot
.91334 .41435 Mdot
.91335 .41433 Mdot
.91336 .41432 Mdot
.91337 .4143 Mdot
.91338 .41429 Mdot
.91339 .41427 Mdot
.9134 .41426 Mdot
.91341 .41424 Mdot
.91342 .41422 Mdot
.91343 .41421 Mdot
.91344 .41419 Mdot
.91345 .41418 Mdot
.91346 .41416 Mdot
.91347 .41415 Mdot
.91348 .41413 Mdot
.91349 .41412 Mdot
.9135 .4141 Mdot
.9135 .41409 Mdot
.91351 .41407 Mdot
.91352 .41406 Mdot
.91353 .41404 Mdot
.91354 .41402 Mdot
.91355 .41401 Mdot
.91356 .41399 Mdot
.91357 .41398 Mdot
.91358 .41396 Mdot
.91359 .41395 Mdot
.9136 .41393 Mdot
.91361 .41392 Mdot
.91362 .4139 Mdot
.91363 .41389 Mdot
.91364 .41387 Mdot
.91365 .41385 Mdot
.91366 .41384 Mdot
.91367 .41382 Mdot
.91368 .41381 Mdot
.91369 .41379 Mdot
.9137 .41378 Mdot
.9137 .41376 Mdot
.91371 .41375 Mdot
.91372 .41373 Mdot
.91373 .41372 Mdot
.91374 .4137 Mdot
.91375 .41368 Mdot
.91376 .41367 Mdot
.91377 .41365 Mdot
.91378 .41364 Mdot
.91379 .41362 Mdot
.9138 .41361 Mdot
.91381 .41359 Mdot
.91382 .41358 Mdot
.91383 .41356 Mdot
.91384 .41355 Mdot
.91385 .41353 Mdot
.91386 .41351 Mdot
.91387 .4135 Mdot
.91388 .41348 Mdot
.91389 .41347 Mdot
.9139 .41345 Mdot
.9139 .41344 Mdot
.91391 .41342 Mdot
.91392 .41341 Mdot
.91393 .41339 Mdot
.91394 .41338 Mdot
.91395 .41336 Mdot
.91396 .41334 Mdot
.91397 .41333 Mdot
.91398 .41331 Mdot
.91399 .4133 Mdot
.914 .41328 Mdot
.91401 .41327 Mdot
.91402 .41325 Mdot
.91403 .41324 Mdot
.91404 .41322 Mdot
.91405 .41321 Mdot
.91406 .41319 Mdot
.91407 .41317 Mdot
.91408 .41316 Mdot
.91409 .41314 Mdot
.9141 .41313 Mdot
.9141 .41311 Mdot
.91411 .4131 Mdot
.91412 .41308 Mdot
.91413 .41307 Mdot
.91414 .41305 Mdot
.91415 .41304 Mdot
.91416 .41302 Mdot
.91417 .413 Mdot
.91418 .41299 Mdot
.91419 .41297 Mdot
.9142 .41296 Mdot
.91421 .41294 Mdot
.91422 .41293 Mdot
.91423 .41291 Mdot
.91424 .4129 Mdot
.91425 .41288 Mdot
.91426 .41287 Mdot
.91427 .41285 Mdot
.91428 .41283 Mdot
.91429 .41282 Mdot
.9143 .4128 Mdot
.9143 .41279 Mdot
.91431 .41277 Mdot
.91432 .41276 Mdot
.91433 .41274 Mdot
.91434 .41273 Mdot
.91435 .41271 Mdot
.91436 .4127 Mdot
.91437 .41268 Mdot
.91438 .41266 Mdot
.91439 .41265 Mdot
.9144 .41263 Mdot
.91441 .41262 Mdot
.91442 .4126 Mdot
.91443 .41259 Mdot
.91444 .41257 Mdot
.91445 .41256 Mdot
.91446 .41254 Mdot
.91447 .41253 Mdot
.91448 .41251 Mdot
.91449 .41249 Mdot
.9145 .41248 Mdot
.9145 .41246 Mdot
.91451 .41245 Mdot
.91452 .41243 Mdot
.91453 .41242 Mdot
.91454 .4124 Mdot
.91455 .41239 Mdot
.91456 .41237 Mdot
.91457 .41236 Mdot
.91458 .41234 Mdot
.91459 .41232 Mdot
.9146 .41231 Mdot
.91461 .41229 Mdot
.91462 .41228 Mdot
.91463 .41226 Mdot
.91464 .41225 Mdot
.91465 .41223 Mdot
.91466 .41222 Mdot
.91467 .4122 Mdot
.91468 .41219 Mdot
.91469 .41217 Mdot
.9147 .41215 Mdot
.9147 .41214 Mdot
.91471 .41212 Mdot
.91472 .41211 Mdot
.91473 .41209 Mdot
.91474 .41208 Mdot
.91475 .41206 Mdot
.91476 .41205 Mdot
.91477 .41203 Mdot
.91478 .41201 Mdot
.91479 .412 Mdot
.9148 .41198 Mdot
.91481 .41197 Mdot
.91482 .41195 Mdot
.91483 .41194 Mdot
.91484 .41192 Mdot
.91485 .41191 Mdot
.91486 .41189 Mdot
.91487 .41188 Mdot
.91488 .41186 Mdot
.91489 .41184 Mdot
.9149 .41183 Mdot
.9149 .41181 Mdot
.91491 .4118 Mdot
.91492 .41178 Mdot
.91493 .41177 Mdot
.91494 .41175 Mdot
.91495 .41174 Mdot
.91496 .41172 Mdot
.91497 .41171 Mdot
.91498 .41169 Mdot
.91499 .41167 Mdot
.915 .41166 Mdot
.91501 .41164 Mdot
.91502 .41163 Mdot
.91503 .41161 Mdot
.91504 .4116 Mdot
.91505 .41158 Mdot
.91506 .41157 Mdot
.91507 .41155 Mdot
.91508 .41153 Mdot
.91509 .41152 Mdot
.9151 .4115 Mdot
.9151 .41149 Mdot
.91511 .41147 Mdot
.91512 .41146 Mdot
.91513 .41144 Mdot
.91514 .41143 Mdot
.91515 .41141 Mdot
.91516 .4114 Mdot
.91517 .41138 Mdot
.91518 .41136 Mdot
.91519 .41135 Mdot
.9152 .41133 Mdot
.91521 .41132 Mdot
.91522 .4113 Mdot
.91523 .41129 Mdot
.91524 .41127 Mdot
.91525 .41126 Mdot
.91526 .41124 Mdot
.91527 .41123 Mdot
.91528 .41121 Mdot
.91529 .41119 Mdot
.9153 .41118 Mdot
.9153 .41116 Mdot
.91531 .41115 Mdot
.91532 .41113 Mdot
.91533 .41112 Mdot
.91534 .4111 Mdot
.91535 .41109 Mdot
.91536 .41107 Mdot
.91537 .41105 Mdot
.91538 .41104 Mdot
.91539 .41102 Mdot
.9154 .41101 Mdot
.91541 .41099 Mdot
.91542 .41098 Mdot
.91543 .41096 Mdot
.91544 .41095 Mdot
.91545 .41093 Mdot
.91546 .41092 Mdot
.91547 .4109 Mdot
.91548 .41088 Mdot
.91549 .41087 Mdot
.9155 .41085 Mdot
.9155 .41084 Mdot
.91551 .41082 Mdot
.91552 .41081 Mdot
.91553 .41079 Mdot
.91554 .41078 Mdot
.91555 .41076 Mdot
.91556 .41074 Mdot
.91557 .41073 Mdot
.91558 .41071 Mdot
.91559 .4107 Mdot
.9156 .41068 Mdot
.91561 .41067 Mdot
.91562 .41065 Mdot
.91563 .41064 Mdot
.91564 .41062 Mdot
.91565 .41061 Mdot
.91566 .41059 Mdot
.91567 .41057 Mdot
.91568 .41056 Mdot
.91569 .41054 Mdot
.9157 .41053 Mdot
.9157 .41051 Mdot
.91571 .4105 Mdot
.91572 .41048 Mdot
.91573 .41047 Mdot
.91574 .41045 Mdot
.91575 .41043 Mdot
.91576 .41042 Mdot
.91577 .4104 Mdot
.91578 .41039 Mdot
.91579 .41037 Mdot
.9158 .41036 Mdot
.91581 .41034 Mdot
.91582 .41033 Mdot
.91583 .41031 Mdot
.91584 .4103 Mdot
.91585 .41028 Mdot
.91586 .41026 Mdot
.91587 .41025 Mdot
.91588 .41023 Mdot
.91589 .41022 Mdot
.9159 .4102 Mdot
.9159 .41019 Mdot
.91591 .41017 Mdot
.91592 .41016 Mdot
.91593 .41014 Mdot
.91594 .41012 Mdot
.91595 .41011 Mdot
.91596 .41009 Mdot
.91597 .41008 Mdot
.91598 .41006 Mdot
.91599 .41005 Mdot
.916 .41003 Mdot
.91601 .41002 Mdot
.91602 .41 Mdot
.91603 .40998 Mdot
.91604 .40997 Mdot
.91605 .40995 Mdot
.91606 .40994 Mdot
.91607 .40992 Mdot
.91608 .40991 Mdot
.91609 .40989 Mdot
.9161 .40988 Mdot
.9161 .40986 Mdot
.91611 .40985 Mdot
.91612 .40983 Mdot
.91613 .40981 Mdot
.91614 .4098 Mdot
.91615 .40978 Mdot
.91616 .40977 Mdot
.91617 .40975 Mdot
.91618 .40974 Mdot
.91619 .40972 Mdot
.9162 .40971 Mdot
.91621 .40969 Mdot
.91622 .40967 Mdot
.91623 .40966 Mdot
.91624 .40964 Mdot
.91625 .40963 Mdot
.91626 .40961 Mdot
.91627 .4096 Mdot
.91628 .40958 Mdot
.91629 .40957 Mdot
.9163 .40955 Mdot
.9163 .40953 Mdot
.91631 .40952 Mdot
.91632 .4095 Mdot
.91633 .40949 Mdot
.91634 .40947 Mdot
.91635 .40946 Mdot
.91636 .40944 Mdot
.91637 .40943 Mdot
.91638 .40941 Mdot
.91639 .40939 Mdot
.9164 .40938 Mdot
.91641 .40936 Mdot
.91642 .40935 Mdot
.91643 .40933 Mdot
.91644 .40932 Mdot
.91645 .4093 Mdot
.91646 .40929 Mdot
.91647 .40927 Mdot
.91648 .40926 Mdot
.91649 .40924 Mdot
.9165 .40922 Mdot
.9165 .40921 Mdot
.91651 .40919 Mdot
.91652 .40918 Mdot
.91653 .40916 Mdot
.91654 .40915 Mdot
.91655 .40913 Mdot
.91656 .40912 Mdot
.91657 .4091 Mdot
.91658 .40908 Mdot
.91659 .40907 Mdot
.9166 .40905 Mdot
.91661 .40904 Mdot
.91662 .40902 Mdot
.91663 .40901 Mdot
.91664 .40899 Mdot
.91665 .40898 Mdot
.91666 .40896 Mdot
.91667 .40894 Mdot
.91668 .40893 Mdot
.91669 .40891 Mdot
.9167 .4089 Mdot
.9167 .40888 Mdot
.91671 .40887 Mdot
.91672 .40885 Mdot
.91673 .40884 Mdot
.91674 .40882 Mdot
.91675 .4088 Mdot
.91676 .40879 Mdot
.91677 .40877 Mdot
.91678 .40876 Mdot
.91679 .40874 Mdot
.9168 .40873 Mdot
.91681 .40871 Mdot
.91682 .4087 Mdot
.91683 .40868 Mdot
.91684 .40866 Mdot
.91685 .40865 Mdot
.91686 .40863 Mdot
.91687 .40862 Mdot
.91688 .4086 Mdot
.91689 .40859 Mdot
.9169 .40857 Mdot
.9169 .40856 Mdot
.91691 .40854 Mdot
.91692 .40852 Mdot
.91693 .40851 Mdot
.91694 .40849 Mdot
.91695 .40848 Mdot
.91696 .40846 Mdot
.91697 .40845 Mdot
.91698 .40843 Mdot
.91699 .40842 Mdot
.917 .4084 Mdot
.91701 .40838 Mdot
.91702 .40837 Mdot
.91703 .40835 Mdot
.91704 .40834 Mdot
.91705 .40832 Mdot
.91706 .40831 Mdot
.91707 .40829 Mdot
.91708 .40828 Mdot
.91709 .40826 Mdot
.9171 .40824 Mdot
.9171 .40823 Mdot
.91711 .40821 Mdot
.91712 .4082 Mdot
.91713 .40818 Mdot
.91714 .40817 Mdot
.91715 .40815 Mdot
.91716 .40814 Mdot
.91717 .40812 Mdot
.91718 .40811 Mdot
.91719 .40809 Mdot
.9172 .40807 Mdot
.91721 .40806 Mdot
.91722 .40804 Mdot
.91723 .40803 Mdot
.91724 .40801 Mdot
.91725 .408 Mdot
.91726 .40798 Mdot
.91727 .40797 Mdot
.91728 .40795 Mdot
.91729 .40793 Mdot
.9173 .40792 Mdot
.9173 .4079 Mdot
.91731 .40789 Mdot
.91732 .40787 Mdot
.91733 .40786 Mdot
.91734 .40784 Mdot
.91735 .40783 Mdot
.91736 .40781 Mdot
.91737 .40779 Mdot
.91738 .40778 Mdot
.91739 .40776 Mdot
.9174 .40775 Mdot
.91741 .40773 Mdot
.91742 .40772 Mdot
.91743 .4077 Mdot
.91744 .40768 Mdot
.91745 .40767 Mdot
.91746 .40765 Mdot
.91747 .40764 Mdot
.91748 .40762 Mdot
.91749 .40761 Mdot
.9175 .40759 Mdot
.9175 .40758 Mdot
.91751 .40756 Mdot
.91752 .40754 Mdot
.91753 .40753 Mdot
.91754 .40751 Mdot
.91755 .4075 Mdot
.91756 .40748 Mdot
.91757 .40747 Mdot
.91758 .40745 Mdot
.91759 .40744 Mdot
.9176 .40742 Mdot
.91761 .4074 Mdot
.91762 .40739 Mdot
.91763 .40737 Mdot
.91764 .40736 Mdot
.91765 .40734 Mdot
.91766 .40733 Mdot
.91767 .40731 Mdot
.91768 .4073 Mdot
.91769 .40728 Mdot
.9177 .40726 Mdot
.9177 .40725 Mdot
.91771 .40723 Mdot
.91772 .40722 Mdot
.91773 .4072 Mdot
.91774 .40719 Mdot
.91775 .40717 Mdot
.91776 .40716 Mdot
.91777 .40714 Mdot
.91778 .40712 Mdot
.91779 .40711 Mdot
.9178 .40709 Mdot
.91781 .40708 Mdot
.91782 .40706 Mdot
.91783 .40705 Mdot
.91784 .40703 Mdot
.91785 .40702 Mdot
.91786 .407 Mdot
.91787 .40698 Mdot
.91788 .40697 Mdot
.91789 .40695 Mdot
.9179 .40694 Mdot
.9179 .40692 Mdot
.91791 .40691 Mdot
.91792 .40689 Mdot
.91793 .40688 Mdot
.91794 .40686 Mdot
.91795 .40684 Mdot
.91796 .40683 Mdot
.91797 .40681 Mdot
.91798 .4068 Mdot
.91799 .40678 Mdot
.918 .40677 Mdot
.91801 .40675 Mdot
.91802 .40674 Mdot
.91803 .40672 Mdot
.91804 .4067 Mdot
.91805 .40669 Mdot
.91806 .40667 Mdot
.91807 .40666 Mdot
.91808 .40664 Mdot
.91809 .40663 Mdot
.9181 .40661 Mdot
.9181 .40659 Mdot
.91811 .40658 Mdot
.91812 .40656 Mdot
.91813 .40655 Mdot
.91814 .40653 Mdot
.91815 .40652 Mdot
.91816 .4065 Mdot
.91817 .40649 Mdot
.91818 .40647 Mdot
.91819 .40645 Mdot
.9182 .40644 Mdot
.91821 .40642 Mdot
.91822 .40641 Mdot
.91823 .40639 Mdot
.91824 .40638 Mdot
.91825 .40636 Mdot
.91826 .40635 Mdot
.91827 .40633 Mdot
.91828 .40631 Mdot
.91829 .4063 Mdot
.9183 .40628 Mdot
.9183 .40627 Mdot
.91831 .40625 Mdot
.91832 .40624 Mdot
.91833 .40622 Mdot
.91834 .40621 Mdot
.91835 .40619 Mdot
.91836 .40617 Mdot
.91837 .40616 Mdot
.91838 .40614 Mdot
.91839 .40613 Mdot
.9184 .40611 Mdot
.91841 .4061 Mdot
.91842 .40608 Mdot
.91843 .40607 Mdot
.91844 .40605 Mdot
.91845 .40603 Mdot
.91846 .40602 Mdot
.91847 .406 Mdot
.91848 .40599 Mdot
.91849 .40597 Mdot
.9185 .40596 Mdot
.9185 .40594 Mdot
.91851 .40592 Mdot
.91852 .40591 Mdot
.91853 .40589 Mdot
.91854 .40588 Mdot
.91855 .40586 Mdot
.91856 .40585 Mdot
.91857 .40583 Mdot
.91858 .40582 Mdot
.91859 .4058 Mdot
.9186 .40578 Mdot
.91861 .40577 Mdot
.91862 .40575 Mdot
.91863 .40574 Mdot
.91864 .40572 Mdot
.91865 .40571 Mdot
.91866 .40569 Mdot
.91867 .40568 Mdot
.91868 .40566 Mdot
.91869 .40564 Mdot
.9187 .40563 Mdot
.9187 .40561 Mdot
.91871 .4056 Mdot
.91872 .40558 Mdot
.91873 .40557 Mdot
.91874 .40555 Mdot
.91875 .40553 Mdot
.91876 .40552 Mdot
.91877 .4055 Mdot
.91878 .40549 Mdot
.91879 .40547 Mdot
.9188 .40546 Mdot
.91881 .40544 Mdot
.91882 .40543 Mdot
.91883 .40541 Mdot
.91884 .40539 Mdot
.91885 .40538 Mdot
.91886 .40536 Mdot
.91887 .40535 Mdot
.91888 .40533 Mdot
.91889 .40532 Mdot
.9189 .4053 Mdot
.9189 .40529 Mdot
.91891 .40527 Mdot
.91892 .40525 Mdot
.91893 .40524 Mdot
.91894 .40522 Mdot
.91895 .40521 Mdot
.91896 .40519 Mdot
.91897 .40518 Mdot
.91898 .40516 Mdot
.91899 .40514 Mdot
.919 .40513 Mdot
.91901 .40511 Mdot
.91902 .4051 Mdot
.91903 .40508 Mdot
.91904 .40507 Mdot
.91905 .40505 Mdot
.91906 .40504 Mdot
.91907 .40502 Mdot
.91908 .405 Mdot
.91909 .40499 Mdot
.9191 .40497 Mdot
.9191 .40496 Mdot
.91911 .40494 Mdot
.91912 .40493 Mdot
.91913 .40491 Mdot
.91914 .40489 Mdot
.91915 .40488 Mdot
.91916 .40486 Mdot
.91917 .40485 Mdot
.91918 .40483 Mdot
.91919 .40482 Mdot
.9192 .4048 Mdot
.91921 .40479 Mdot
.91922 .40477 Mdot
.91923 .40475 Mdot
.91924 .40474 Mdot
.91925 .40472 Mdot
.91926 .40471 Mdot
.91927 .40469 Mdot
.91928 .40468 Mdot
.91929 .40466 Mdot
.9193 .40464 Mdot
.9193 .40463 Mdot
.91931 .40461 Mdot
.91932 .4046 Mdot
.91933 .40458 Mdot
.91934 .40457 Mdot
.91935 .40455 Mdot
.91936 .40454 Mdot
.91937 .40452 Mdot
.91938 .4045 Mdot
.91939 .40449 Mdot
.9194 .40447 Mdot
.91941 .40446 Mdot
.91942 .40444 Mdot
.91943 .40443 Mdot
.91944 .40441 Mdot
.91945 .4044 Mdot
.91946 .40438 Mdot
.91947 .40436 Mdot
.91948 .40435 Mdot
.91949 .40433 Mdot
.9195 .40432 Mdot
.9195 .4043 Mdot
.91951 .40429 Mdot
.91952 .40427 Mdot
.91953 .40425 Mdot
.91954 .40424 Mdot
.91955 .40422 Mdot
.91956 .40421 Mdot
.91957 .40419 Mdot
.91958 .40418 Mdot
.91959 .40416 Mdot
.9196 .40415 Mdot
.91961 .40413 Mdot
.91962 .40411 Mdot
.91963 .4041 Mdot
.91964 .40408 Mdot
.91965 .40407 Mdot
.91966 .40405 Mdot
.91967 .40404 Mdot
.91968 .40402 Mdot
.91969 .404 Mdot
.9197 .40399 Mdot
.9197 .40397 Mdot
.91971 .40396 Mdot
.91972 .40394 Mdot
.91973 .40393 Mdot
.91974 .40391 Mdot
.91975 .40389 Mdot
.91976 .40388 Mdot
.91977 .40386 Mdot
.91978 .40385 Mdot
.91979 .40383 Mdot
.9198 .40382 Mdot
.91981 .4038 Mdot
.91982 .40379 Mdot
.91983 .40377 Mdot
.91984 .40375 Mdot
.91985 .40374 Mdot
.91986 .40372 Mdot
.91987 .40371 Mdot
.91988 .40369 Mdot
.91989 .40368 Mdot
.9199 .40366 Mdot
.9199 .40364 Mdot
.91991 .40363 Mdot
.91992 .40361 Mdot
.91993 .4036 Mdot
.91994 .40358 Mdot
.91995 .40357 Mdot
.91996 .40355 Mdot
.91997 .40354 Mdot
.91998 .40352 Mdot
.91999 .4035 Mdot
.92 .40349 Mdot
.92001 .40347 Mdot
.92002 .40346 Mdot
.92003 .40344 Mdot
.92004 .40343 Mdot
.92005 .40341 Mdot
.92006 .40339 Mdot
.92007 .40338 Mdot
.92008 .40336 Mdot
.92009 .40335 Mdot
.9201 .40333 Mdot
.9201 .40332 Mdot
.92011 .4033 Mdot
.92012 .40329 Mdot
.92013 .40327 Mdot
.92014 .40325 Mdot
.92015 .40324 Mdot
.92016 .40322 Mdot
.92017 .40321 Mdot
.92018 .40319 Mdot
.92019 .40318 Mdot
.9202 .40316 Mdot
.92021 .40314 Mdot
.92022 .40313 Mdot
.92023 .40311 Mdot
.92024 .4031 Mdot
.92025 .40308 Mdot
.92026 .40307 Mdot
.92027 .40305 Mdot
.92028 .40303 Mdot
.92029 .40302 Mdot
.9203 .403 Mdot
.9203 .40299 Mdot
.92031 .40297 Mdot
.92032 .40296 Mdot
.92033 .40294 Mdot
.92034 .40293 Mdot
.92035 .40291 Mdot
.92036 .40289 Mdot
.92037 .40288 Mdot
.92038 .40286 Mdot
.92039 .40285 Mdot
.9204 .40283 Mdot
.92041 .40282 Mdot
.92042 .4028 Mdot
.92043 .40278 Mdot
.92044 .40277 Mdot
.92045 .40275 Mdot
.92046 .40274 Mdot
.92047 .40272 Mdot
.92048 .40271 Mdot
.92049 .40269 Mdot
.9205 .40267 Mdot
.9205 .40266 Mdot
.92051 .40264 Mdot
.92052 .40263 Mdot
.92053 .40261 Mdot
.92054 .4026 Mdot
.92055 .40258 Mdot
.92056 .40257 Mdot
.92057 .40255 Mdot
.92058 .40253 Mdot
.92059 .40252 Mdot
.9206 .4025 Mdot
.92061 .40249 Mdot
.92062 .40247 Mdot
.92063 .40246 Mdot
.92064 .40244 Mdot
.92065 .40242 Mdot
.92066 .40241 Mdot
.92067 .40239 Mdot
.92068 .40238 Mdot
.92069 .40236 Mdot
.9207 .40235 Mdot
.9207 .40233 Mdot
.92071 .40231 Mdot
.92072 .4023 Mdot
.92073 .40228 Mdot
.92074 .40227 Mdot
.92075 .40225 Mdot
.92076 .40224 Mdot
.92077 .40222 Mdot
.92078 .40221 Mdot
.92079 .40219 Mdot
.9208 .40217 Mdot
.92081 .40216 Mdot
.92082 .40214 Mdot
.92083 .40213 Mdot
.92084 .40211 Mdot
.92085 .4021 Mdot
.92086 .40208 Mdot
.92087 .40206 Mdot
.92088 .40205 Mdot
.92089 .40203 Mdot
.9209 .40202 Mdot
.9209 .402 Mdot
.92091 .40199 Mdot
.92092 .40197 Mdot
.92093 .40195 Mdot
.92094 .40194 Mdot
.92095 .40192 Mdot
.92096 .40191 Mdot
.92097 .40189 Mdot
.92098 .40188 Mdot
.92099 .40186 Mdot
.921 .40184 Mdot
.92101 .40183 Mdot
.92102 .40181 Mdot
.92103 .4018 Mdot
.92104 .40178 Mdot
.92105 .40177 Mdot
.92106 .40175 Mdot
.92107 .40174 Mdot
.92108 .40172 Mdot
.92109 .4017 Mdot
.9211 .40169 Mdot
.9211 .40167 Mdot
.92111 .40166 Mdot
.92112 .40164 Mdot
.92113 .40163 Mdot
.92114 .40161 Mdot
.92115 .40159 Mdot
.92116 .40158 Mdot
.92117 .40156 Mdot
.92118 .40155 Mdot
.92119 .40153 Mdot
.9212 .40152 Mdot
.92121 .4015 Mdot
.92122 .40148 Mdot
.92123 .40147 Mdot
.92124 .40145 Mdot
.92125 .40144 Mdot
.92126 .40142 Mdot
.92127 .40141 Mdot
.92128 .40139 Mdot
.92129 .40137 Mdot
.9213 .40136 Mdot
.9213 .40134 Mdot
.92131 .40133 Mdot
.92132 .40131 Mdot
.92133 .4013 Mdot
.92134 .40128 Mdot
.92135 .40126 Mdot
.92136 .40125 Mdot
.92137 .40123 Mdot
.92138 .40122 Mdot
.92139 .4012 Mdot
.9214 .40119 Mdot
.92141 .40117 Mdot
.92142 .40116 Mdot
.92143 .40114 Mdot
.92144 .40112 Mdot
.92145 .40111 Mdot
.92146 .40109 Mdot
.92147 .40108 Mdot
.92148 .40106 Mdot
.92149 .40105 Mdot
.9215 .40103 Mdot
.9215 .40101 Mdot
.92151 .401 Mdot
.92152 .40098 Mdot
.92153 .40097 Mdot
.92154 .40095 Mdot
.92155 .40094 Mdot
.92156 .40092 Mdot
.92157 .4009 Mdot
.92158 .40089 Mdot
.92159 .40087 Mdot
.9216 .40086 Mdot
.92161 .40084 Mdot
.92162 .40083 Mdot
.92163 .40081 Mdot
.92164 .40079 Mdot
.92165 .40078 Mdot
.92166 .40076 Mdot
.92167 .40075 Mdot
.92168 .40073 Mdot
.92169 .40072 Mdot
.9217 .4007 Mdot
.9217 .40068 Mdot
.92171 .40067 Mdot
.92172 .40065 Mdot
.92173 .40064 Mdot
.92174 .40062 Mdot
.92175 .40061 Mdot
.92176 .40059 Mdot
.92177 .40057 Mdot
.92178 .40056 Mdot
.92179 .40054 Mdot
.9218 .40053 Mdot
.92181 .40051 Mdot
.92182 .4005 Mdot
.92183 .40048 Mdot
.92184 .40046 Mdot
.92185 .40045 Mdot
.92186 .40043 Mdot
.92187 .40042 Mdot
.92188 .4004 Mdot
.92189 .40039 Mdot
.9219 .40037 Mdot
.9219 .40035 Mdot
.92191 .40034 Mdot
.92192 .40032 Mdot
.92193 .40031 Mdot
.92194 .40029 Mdot
.92195 .40028 Mdot
.92196 .40026 Mdot
.92197 .40025 Mdot
.92198 .40023 Mdot
.92199 .40021 Mdot
.922 .4002 Mdot
.92201 .40018 Mdot
.92202 .40017 Mdot
.92203 .40015 Mdot
.92204 .40014 Mdot
.92205 .40012 Mdot
.92206 .4001 Mdot
.92207 .40009 Mdot
.92208 .40007 Mdot
.92209 .40006 Mdot
.9221 .40004 Mdot
.9221 .40003 Mdot
.92211 .40001 Mdot
.92212 .39999 Mdot
.92213 .39998 Mdot
.92214 .39996 Mdot
.92215 .39995 Mdot
.92216 .39993 Mdot
.92217 .39992 Mdot
.92218 .3999 Mdot
.92219 .39988 Mdot
.9222 .39987 Mdot
.92221 .39985 Mdot
.92222 .39984 Mdot
.92223 .39982 Mdot
.92224 .39981 Mdot
.92225 .39979 Mdot
.92226 .39977 Mdot
.92227 .39976 Mdot
.92228 .39974 Mdot
.92229 .39973 Mdot
.9223 .39971 Mdot
.9223 .3997 Mdot
.92231 .39968 Mdot
.92232 .39966 Mdot
.92233 .39965 Mdot
.92234 .39963 Mdot
.92235 .39962 Mdot
.92236 .3996 Mdot
.92237 .39959 Mdot
.92238 .39957 Mdot
.92239 .39955 Mdot
.9224 .39954 Mdot
.92241 .39952 Mdot
.92242 .39951 Mdot
.92243 .39949 Mdot
.92244 .39948 Mdot
.92245 .39946 Mdot
.92246 .39944 Mdot
.92247 .39943 Mdot
.92248 .39941 Mdot
.92249 .3994 Mdot
.9225 .39938 Mdot
.9225 .39937 Mdot
.92251 .39935 Mdot
.92252 .39933 Mdot
.92253 .39932 Mdot
.92254 .3993 Mdot
.92255 .39929 Mdot
.92256 .39927 Mdot
.92257 .39926 Mdot
.92258 .39924 Mdot
.92259 .39922 Mdot
.9226 .39921 Mdot
.92261 .39919 Mdot
.92262 .39918 Mdot
.92263 .39916 Mdot
.92264 .39915 Mdot
.92265 .39913 Mdot
.92266 .39911 Mdot
.92267 .3991 Mdot
.92268 .39908 Mdot
.92269 .39907 Mdot
.9227 .39905 Mdot
.9227 .39904 Mdot
.92271 .39902 Mdot
.92272 .399 Mdot
.92273 .39899 Mdot
.92274 .39897 Mdot
.92275 .39896 Mdot
.92276 .39894 Mdot
.92277 .39893 Mdot
.92278 .39891 Mdot
.92279 .39889 Mdot
.9228 .39888 Mdot
.92281 .39886 Mdot
.92282 .39885 Mdot
.92283 .39883 Mdot
.92284 .39882 Mdot
.92285 .3988 Mdot
.92286 .39878 Mdot
.92287 .39877 Mdot
.92288 .39875 Mdot
.92289 .39874 Mdot
.9229 .39872 Mdot
.9229 .39871 Mdot
.92291 .39869 Mdot
.92292 .39867 Mdot
.92293 .39866 Mdot
.92294 .39864 Mdot
.92295 .39863 Mdot
.92296 .39861 Mdot
.92297 .3986 Mdot
.92298 .39858 Mdot
.92299 .39856 Mdot
.923 .39855 Mdot
.92301 .39853 Mdot
.92302 .39852 Mdot
.92303 .3985 Mdot
.92304 .39849 Mdot
.92305 .39847 Mdot
.92306 .39845 Mdot
.92307 .39844 Mdot
.92308 .39842 Mdot
.92309 .39841 Mdot
.9231 .39839 Mdot
.9231 .39838 Mdot
.92311 .39836 Mdot
.92312 .39834 Mdot
.92313 .39833 Mdot
.92314 .39831 Mdot
.92315 .3983 Mdot
.92316 .39828 Mdot
.92317 .39827 Mdot
.92318 .39825 Mdot
.92319 .39823 Mdot
.9232 .39822 Mdot
.92321 .3982 Mdot
.92322 .39819 Mdot
.92323 .39817 Mdot
.92324 .39816 Mdot
.92325 .39814 Mdot
.92326 .39812 Mdot
.92327 .39811 Mdot
.92328 .39809 Mdot
.92329 .39808 Mdot
.9233 .39806 Mdot
.9233 .39804 Mdot
.92331 .39803 Mdot
.92332 .39801 Mdot
.92333 .398 Mdot
.92334 .39798 Mdot
.92335 .39797 Mdot
.92336 .39795 Mdot
.92337 .39793 Mdot
.92338 .39792 Mdot
.92339 .3979 Mdot
.9234 .39789 Mdot
.92341 .39787 Mdot
.92342 .39786 Mdot
.92343 .39784 Mdot
.92344 .39782 Mdot
.92345 .39781 Mdot
.92346 .39779 Mdot
.92347 .39778 Mdot
.92348 .39776 Mdot
.92349 .39775 Mdot
.9235 .39773 Mdot
.9235 .39771 Mdot
.92351 .3977 Mdot
.92352 .39768 Mdot
.92353 .39767 Mdot
.92354 .39765 Mdot
.92355 .39764 Mdot
.92356 .39762 Mdot
.92357 .3976 Mdot
.92358 .39759 Mdot
.92359 .39757 Mdot
.9236 .39756 Mdot
.92361 .39754 Mdot
.92362 .39753 Mdot
.92363 .39751 Mdot
.92364 .39749 Mdot
.92365 .39748 Mdot
.92366 .39746 Mdot
.92367 .39745 Mdot
.92368 .39743 Mdot
.92369 .39742 Mdot
.9237 .3974 Mdot
.9237 .39738 Mdot
.92371 .39737 Mdot
.92372 .39735 Mdot
.92373 .39734 Mdot
.92374 .39732 Mdot
.92375 .39731 Mdot
.92376 .39729 Mdot
.92377 .39727 Mdot
.92378 .39726 Mdot
.92379 .39724 Mdot
.9238 .39723 Mdot
.92381 .39721 Mdot
.92382 .39719 Mdot
.92383 .39718 Mdot
.92384 .39716 Mdot
.92385 .39715 Mdot
.92386 .39713 Mdot
.92387 .39712 Mdot
.92388 .3971 Mdot
.92389 .39708 Mdot
.9239 .39707 Mdot
.9239 .39705 Mdot
.92391 .39704 Mdot
.92392 .39702 Mdot
.92393 .39701 Mdot
.92394 .39699 Mdot
.92395 .39697 Mdot
.92396 .39696 Mdot
.92397 .39694 Mdot
.92398 .39693 Mdot
.92399 .39691 Mdot
.924 .3969 Mdot
.92401 .39688 Mdot
.92402 .39686 Mdot
.92403 .39685 Mdot
.92404 .39683 Mdot
.92405 .39682 Mdot
.92406 .3968 Mdot
.92407 .39679 Mdot
.92408 .39677 Mdot
.92409 .39675 Mdot
.9241 .39674 Mdot
.9241 .39672 Mdot
.92411 .39671 Mdot
.92412 .39669 Mdot
.92413 .39668 Mdot
.92414 .39666 Mdot
.92415 .39664 Mdot
.92416 .39663 Mdot
.92417 .39661 Mdot
.92418 .3966 Mdot
.92419 .39658 Mdot
.9242 .39656 Mdot
.92421 .39655 Mdot
.92422 .39653 Mdot
.92423 .39652 Mdot
.92424 .3965 Mdot
.92425 .39649 Mdot
.92426 .39647 Mdot
.92427 .39645 Mdot
.92428 .39644 Mdot
.92429 .39642 Mdot
.9243 .39641 Mdot
.9243 .39639 Mdot
.92431 .39638 Mdot
.92432 .39636 Mdot
.92433 .39634 Mdot
.92434 .39633 Mdot
.92435 .39631 Mdot
.92436 .3963 Mdot
.92437 .39628 Mdot
.92438 .39627 Mdot
.92439 .39625 Mdot
.9244 .39623 Mdot
.92441 .39622 Mdot
.92442 .3962 Mdot
.92443 .39619 Mdot
.92444 .39617 Mdot
.92445 .39615 Mdot
.92446 .39614 Mdot
.92447 .39612 Mdot
.92448 .39611 Mdot
.92449 .39609 Mdot
.9245 .39608 Mdot
.9245 .39606 Mdot
.92451 .39604 Mdot
.92452 .39603 Mdot
.92453 .39601 Mdot
.92454 .396 Mdot
.92455 .39598 Mdot
.92456 .39597 Mdot
.92457 .39595 Mdot
.92458 .39593 Mdot
.92459 .39592 Mdot
.9246 .3959 Mdot
.92461 .39589 Mdot
.92462 .39587 Mdot
.92463 .39586 Mdot
.92464 .39584 Mdot
.92465 .39582 Mdot
.92466 .39581 Mdot
.92467 .39579 Mdot
.92468 .39578 Mdot
.92469 .39576 Mdot
.9247 .39574 Mdot
.9247 .39573 Mdot
.92471 .39571 Mdot
.92472 .3957 Mdot
.92473 .39568 Mdot
.92474 .39567 Mdot
.92475 .39565 Mdot
.92476 .39563 Mdot
.92477 .39562 Mdot
.92478 .3956 Mdot
.92479 .39559 Mdot
.9248 .39557 Mdot
.92481 .39556 Mdot
.92482 .39554 Mdot
.92483 .39552 Mdot
.92484 .39551 Mdot
.92485 .39549 Mdot
.92486 .39548 Mdot
.92487 .39546 Mdot
.92488 .39545 Mdot
.92489 .39543 Mdot
.9249 .39541 Mdot
.9249 .3954 Mdot
.92491 .39538 Mdot
.92492 .39537 Mdot
.92493 .39535 Mdot
.92494 .39533 Mdot
.92495 .39532 Mdot
.92496 .3953 Mdot
.92497 .39529 Mdot
.92498 .39527 Mdot
.92499 .39526 Mdot
.925 .39524 Mdot
.92501 .39522 Mdot
.92502 .39521 Mdot
.92503 .39519 Mdot
.92504 .39518 Mdot
.92505 .39516 Mdot
.92506 .39515 Mdot
.92507 .39513 Mdot
.92508 .39511 Mdot
.92509 .3951 Mdot
.9251 .39508 Mdot
.9251 .39507 Mdot
.92511 .39505 Mdot
.92512 .39503 Mdot
.92513 .39502 Mdot
.92514 .395 Mdot
.92515 .39499 Mdot
.92516 .39497 Mdot
.92517 .39496 Mdot
.92518 .39494 Mdot
.92519 .39492 Mdot
.9252 .39491 Mdot
.92521 .39489 Mdot
.92522 .39488 Mdot
.92523 .39486 Mdot
.92524 .39485 Mdot
.92525 .39483 Mdot
.92526 .39481 Mdot
.92527 .3948 Mdot
.92528 .39478 Mdot
.92529 .39477 Mdot
.9253 .39475 Mdot
.9253 .39473 Mdot
.92531 .39472 Mdot
.92532 .3947 Mdot
.92533 .39469 Mdot
.92534 .39467 Mdot
.92535 .39466 Mdot
.92536 .39464 Mdot
.92537 .39462 Mdot
.92538 .39461 Mdot
.92539 .39459 Mdot
.9254 .39458 Mdot
.92541 .39456 Mdot
.92542 .39455 Mdot
.92543 .39453 Mdot
.92544 .39451 Mdot
.92545 .3945 Mdot
.92546 .39448 Mdot
.92547 .39447 Mdot
.92548 .39445 Mdot
.92549 .39443 Mdot
.9255 .39442 Mdot
.9255 .3944 Mdot
.92551 .39439 Mdot
.92552 .39437 Mdot
.92553 .39436 Mdot
.92554 .39434 Mdot
.92555 .39432 Mdot
.92556 .39431 Mdot
.92557 .39429 Mdot
.92558 .39428 Mdot
.92559 .39426 Mdot
.9256 .39425 Mdot
.92561 .39423 Mdot
.92562 .39421 Mdot
.92563 .3942 Mdot
.92564 .39418 Mdot
.92565 .39417 Mdot
.92566 .39415 Mdot
.92567 .39413 Mdot
.92568 .39412 Mdot
.92569 .3941 Mdot
.9257 .39409 Mdot
.9257 .39407 Mdot
.92571 .39406 Mdot
.92572 .39404 Mdot
.92573 .39402 Mdot
.92574 .39401 Mdot
.92575 .39399 Mdot
.92576 .39398 Mdot
.92577 .39396 Mdot
.92578 .39395 Mdot
.92579 .39393 Mdot
.9258 .39391 Mdot
.92581 .3939 Mdot
.92582 .39388 Mdot
.92583 .39387 Mdot
.92584 .39385 Mdot
.92585 .39383 Mdot
.92586 .39382 Mdot
.92587 .3938 Mdot
.92588 .39379 Mdot
.92589 .39377 Mdot
.9259 .39376 Mdot
.9259 .39374 Mdot
.92591 .39372 Mdot
.92592 .39371 Mdot
.92593 .39369 Mdot
.92594 .39368 Mdot
.92595 .39366 Mdot
.92596 .39364 Mdot
.92597 .39363 Mdot
.92598 .39361 Mdot
.92599 .3936 Mdot
.926 .39358 Mdot
.92601 .39357 Mdot
.92602 .39355 Mdot
.92603 .39353 Mdot
.92604 .39352 Mdot
.92605 .3935 Mdot
.92606 .39349 Mdot
.92607 .39347 Mdot
.92608 .39346 Mdot
.92609 .39344 Mdot
.9261 .39342 Mdot
.9261 .39341 Mdot
.92611 .39339 Mdot
.92612 .39338 Mdot
.92613 .39336 Mdot
.92614 .39334 Mdot
.92615 .39333 Mdot
.92616 .39331 Mdot
.92617 .3933 Mdot
.92618 .39328 Mdot
.92619 .39327 Mdot
.9262 .39325 Mdot
.92621 .39323 Mdot
.92622 .39322 Mdot
.92623 .3932 Mdot
.92624 .39319 Mdot
.92625 .39317 Mdot
.92626 .39315 Mdot
.92627 .39314 Mdot
.92628 .39312 Mdot
.92629 .39311 Mdot
.9263 .39309 Mdot
.9263 .39308 Mdot
.92631 .39306 Mdot
.92632 .39304 Mdot
.92633 .39303 Mdot
.92634 .39301 Mdot
.92635 .393 Mdot
.92636 .39298 Mdot
.92637 .39296 Mdot
.92638 .39295 Mdot
.92639 .39293 Mdot
.9264 .39292 Mdot
.92641 .3929 Mdot
.92642 .39289 Mdot
.92643 .39287 Mdot
.92644 .39285 Mdot
.92645 .39284 Mdot
.92646 .39282 Mdot
.92647 .39281 Mdot
.92648 .39279 Mdot
.92649 .39278 Mdot
.9265 .39276 Mdot
.9265 .39274 Mdot
.92651 .39273 Mdot
.92652 .39271 Mdot
.92653 .3927 Mdot
.92654 .39268 Mdot
.92655 .39266 Mdot
.92656 .39265 Mdot
.92657 .39263 Mdot
.92658 .39262 Mdot
.92659 .3926 Mdot
.9266 .39259 Mdot
.92661 .39257 Mdot
.92662 .39255 Mdot
.92663 .39254 Mdot
.92664 .39252 Mdot
.92665 .39251 Mdot
.92666 .39249 Mdot
.92667 .39247 Mdot
.92668 .39246 Mdot
.92669 .39244 Mdot
.9267 .39243 Mdot
.9267 .39241 Mdot
.92671 .3924 Mdot
.92672 .39238 Mdot
.92673 .39236 Mdot
.92674 .39235 Mdot
.92675 .39233 Mdot
.92676 .39232 Mdot
.92677 .3923 Mdot
.92678 .39228 Mdot
.92679 .39227 Mdot
.9268 .39225 Mdot
.92681 .39224 Mdot
.92682 .39222 Mdot
.92683 .39221 Mdot
.92684 .39219 Mdot
.92685 .39217 Mdot
.92686 .39216 Mdot
.92687 .39214 Mdot
.92688 .39213 Mdot
.92689 .39211 Mdot
.9269 .39209 Mdot
.9269 .39208 Mdot
.92691 .39206 Mdot
.92692 .39205 Mdot
.92693 .39203 Mdot
.92694 .39202 Mdot
.92695 .392 Mdot
.92696 .39198 Mdot
.92697 .39197 Mdot
.92698 .39195 Mdot
.92699 .39194 Mdot
.927 .39192 Mdot
.92701 .3919 Mdot
.92702 .39189 Mdot
.92703 .39187 Mdot
.92704 .39186 Mdot
.92705 .39184 Mdot
.92706 .39183 Mdot
.92707 .39181 Mdot
.92708 .39179 Mdot
.92709 .39178 Mdot
.9271 .39176 Mdot
.9271 .39175 Mdot
.92711 .39173 Mdot
.92712 .39171 Mdot
.92713 .3917 Mdot
.92714 .39168 Mdot
.92715 .39167 Mdot
.92716 .39165 Mdot
.92717 .39164 Mdot
.92718 .39162 Mdot
.92719 .3916 Mdot
.9272 .39159 Mdot
.92721 .39157 Mdot
.92722 .39156 Mdot
.92723 .39154 Mdot
.92724 .39152 Mdot
.92725 .39151 Mdot
.92726 .39149 Mdot
.92727 .39148 Mdot
.92728 .39146 Mdot
.92729 .39145 Mdot
.9273 .39143 Mdot
.9273 .39141 Mdot
.92731 .3914 Mdot
.92732 .39138 Mdot
.92733 .39137 Mdot
.92734 .39135 Mdot
.92735 .39133 Mdot
.92736 .39132 Mdot
.92737 .3913 Mdot
.92738 .39129 Mdot
.92739 .39127 Mdot
.9274 .39126 Mdot
.92741 .39124 Mdot
.92742 .39122 Mdot
.92743 .39121 Mdot
.92744 .39119 Mdot
.92745 .39118 Mdot
.92746 .39116 Mdot
.92747 .39114 Mdot
.92748 .39113 Mdot
.92749 .39111 Mdot
.9275 .3911 Mdot
.9275 .39108 Mdot
.92751 .39106 Mdot
.92752 .39105 Mdot
.92753 .39103 Mdot
.92754 .39102 Mdot
.92755 .391 Mdot
.92756 .39099 Mdot
.92757 .39097 Mdot
.92758 .39095 Mdot
.92759 .39094 Mdot
.9276 .39092 Mdot
.92761 .39091 Mdot
.92762 .39089 Mdot
.92763 .39087 Mdot
.92764 .39086 Mdot
.92765 .39084 Mdot
.92766 .39083 Mdot
.92767 .39081 Mdot
.92768 .3908 Mdot
.92769 .39078 Mdot
.9277 .39076 Mdot
.9277 .39075 Mdot
.92771 .39073 Mdot
.92772 .39072 Mdot
.92773 .3907 Mdot
.92774 .39068 Mdot
.92775 .39067 Mdot
.92776 .39065 Mdot
.92777 .39064 Mdot
.92778 .39062 Mdot
.92779 .39061 Mdot
.9278 .39059 Mdot
.92781 .39057 Mdot
.92782 .39056 Mdot
.92783 .39054 Mdot
.92784 .39053 Mdot
.92785 .39051 Mdot
.92786 .39049 Mdot
.92787 .39048 Mdot
.92788 .39046 Mdot
.92789 .39045 Mdot
.9279 .39043 Mdot
.9279 .39041 Mdot
.92791 .3904 Mdot
.92792 .39038 Mdot
.92793 .39037 Mdot
.92794 .39035 Mdot
.92795 .39034 Mdot
.92796 .39032 Mdot
.92797 .3903 Mdot
.92798 .39029 Mdot
.92799 .39027 Mdot
.928 .39026 Mdot
.92801 .39024 Mdot
.92802 .39022 Mdot
.92803 .39021 Mdot
.92804 .39019 Mdot
.92805 .39018 Mdot
.92806 .39016 Mdot
.92807 .39015 Mdot
.92808 .39013 Mdot
.92809 .39011 Mdot
.9281 .3901 Mdot
.9281 .39008 Mdot
.92811 .39007 Mdot
.92812 .39005 Mdot
.92813 .39003 Mdot
.92814 .39002 Mdot
.92815 .39 Mdot
.92816 .38999 Mdot
.92817 .38997 Mdot
.92818 .38996 Mdot
.92819 .38994 Mdot
.9282 .38992 Mdot
.92821 .38991 Mdot
.92822 .38989 Mdot
.92823 .38988 Mdot
.92824 .38986 Mdot
.92825 .38984 Mdot
.92826 .38983 Mdot
.92827 .38981 Mdot
.92828 .3898 Mdot
.92829 .38978 Mdot
.9283 .38976 Mdot
.9283 .38975 Mdot
.92831 .38973 Mdot
.92832 .38972 Mdot
.92833 .3897 Mdot
.92834 .38969 Mdot
.92835 .38967 Mdot
.92836 .38965 Mdot
.92837 .38964 Mdot
.92838 .38962 Mdot
.92839 .38961 Mdot
.9284 .38959 Mdot
.92841 .38957 Mdot
.92842 .38956 Mdot
.92843 .38954 Mdot
.92844 .38953 Mdot
.92845 .38951 Mdot
.92846 .38949 Mdot
.92847 .38948 Mdot
.92848 .38946 Mdot
.92849 .38945 Mdot
.9285 .38943 Mdot
.9285 .38942 Mdot
.92851 .3894 Mdot
.92852 .38938 Mdot
.92853 .38937 Mdot
.92854 .38935 Mdot
.92855 .38934 Mdot
.92856 .38932 Mdot
.92857 .3893 Mdot
.92858 .38929 Mdot
.92859 .38927 Mdot
.9286 .38926 Mdot
.92861 .38924 Mdot
.92862 .38922 Mdot
.92863 .38921 Mdot
.92864 .38919 Mdot
.92865 .38918 Mdot
.92866 .38916 Mdot
.92867 .38915 Mdot
.92868 .38913 Mdot
.92869 .38911 Mdot
.9287 .3891 Mdot
.9287 .38908 Mdot
.92871 .38907 Mdot
.92872 .38905 Mdot
.92873 .38903 Mdot
.92874 .38902 Mdot
.92875 .389 Mdot
.92876 .38899 Mdot
.92877 .38897 Mdot
.92878 .38896 Mdot
.92879 .38894 Mdot
.9288 .38892 Mdot
.92881 .38891 Mdot
.92882 .38889 Mdot
.92883 .38888 Mdot
.92884 .38886 Mdot
.92885 .38884 Mdot
.92886 .38883 Mdot
.92887 .38881 Mdot
.92888 .3888 Mdot
.92889 .38878 Mdot
.9289 .38876 Mdot
.9289 .38875 Mdot
.92891 .38873 Mdot
.92892 .38872 Mdot
.92893 .3887 Mdot
.92894 .38869 Mdot
.92895 .38867 Mdot
.92896 .38865 Mdot
.92897 .38864 Mdot
.92898 .38862 Mdot
.92899 .38861 Mdot
.929 .38859 Mdot
.92901 .38857 Mdot
.92902 .38856 Mdot
.92903 .38854 Mdot
.92904 .38853 Mdot
.92905 .38851 Mdot
.92906 .38849 Mdot
.92907 .38848 Mdot
.92908 .38846 Mdot
.92909 .38845 Mdot
.9291 .38843 Mdot
.9291 .38842 Mdot
.92911 .3884 Mdot
.92912 .38838 Mdot
.92913 .38837 Mdot
.92914 .38835 Mdot
.92915 .38834 Mdot
.92916 .38832 Mdot
.92917 .3883 Mdot
.92918 .38829 Mdot
.92919 .38827 Mdot
.9292 .38826 Mdot
.92921 .38824 Mdot
.92922 .38822 Mdot
.92923 .38821 Mdot
.92924 .38819 Mdot
.92925 .38818 Mdot
.92926 .38816 Mdot
.92927 .38814 Mdot
.92928 .38813 Mdot
.92929 .38811 Mdot
.9293 .3881 Mdot
.9293 .38808 Mdot
.92931 .38807 Mdot
.92932 .38805 Mdot
.92933 .38803 Mdot
.92934 .38802 Mdot
.92935 .388 Mdot
.92936 .38799 Mdot
.92937 .38797 Mdot
.92938 .38795 Mdot
.92939 .38794 Mdot
.9294 .38792 Mdot
.92941 .38791 Mdot
.92942 .38789 Mdot
.92943 .38787 Mdot
.92944 .38786 Mdot
.92945 .38784 Mdot
.92946 .38783 Mdot
.92947 .38781 Mdot
.92948 .3878 Mdot
.92949 .38778 Mdot
.9295 .38776 Mdot
.9295 .38775 Mdot
.92951 .38773 Mdot
.92952 .38772 Mdot
.92953 .3877 Mdot
.92954 .38768 Mdot
.92955 .38767 Mdot
.92956 .38765 Mdot
.92957 .38764 Mdot
.92958 .38762 Mdot
.92959 .3876 Mdot
.9296 .38759 Mdot
.92961 .38757 Mdot
.92962 .38756 Mdot
.92963 .38754 Mdot
.92964 .38752 Mdot
.92965 .38751 Mdot
.92966 .38749 Mdot
.92967 .38748 Mdot
.92968 .38746 Mdot
.92969 .38745 Mdot
.9297 .38743 Mdot
.9297 .38741 Mdot
.92971 .3874 Mdot
.92972 .38738 Mdot
.92973 .38737 Mdot
.92974 .38735 Mdot
.92975 .38733 Mdot
.92976 .38732 Mdot
.92977 .3873 Mdot
.92978 .38729 Mdot
.92979 .38727 Mdot
.9298 .38725 Mdot
.92981 .38724 Mdot
.92982 .38722 Mdot
.92983 .38721 Mdot
.92984 .38719 Mdot
.92985 .38718 Mdot
.92986 .38716 Mdot
.92987 .38714 Mdot
.92988 .38713 Mdot
.92989 .38711 Mdot
.9299 .3871 Mdot
.9299 .38708 Mdot
.92991 .38706 Mdot
.92992 .38705 Mdot
.92993 .38703 Mdot
.92994 .38702 Mdot
.92995 .387 Mdot
.92996 .38698 Mdot
.92997 .38697 Mdot
.92998 .38695 Mdot
.92999 .38694 Mdot
.93 .38692 Mdot
.93001 .3869 Mdot
.93002 .38689 Mdot
.93003 .38687 Mdot
.93004 .38686 Mdot
.93005 .38684 Mdot
.93006 .38683 Mdot
.93007 .38681 Mdot
.93008 .38679 Mdot
.93009 .38678 Mdot
.9301 .38676 Mdot
.9301 .38675 Mdot
.93011 .38673 Mdot
.93012 .38671 Mdot
.93013 .3867 Mdot
.93014 .38668 Mdot
.93015 .38667 Mdot
.93016 .38665 Mdot
.93017 .38663 Mdot
.93018 .38662 Mdot
.93019 .3866 Mdot
.9302 .38659 Mdot
.93021 .38657 Mdot
.93022 .38655 Mdot
.93023 .38654 Mdot
.93024 .38652 Mdot
.93025 .38651 Mdot
.93026 .38649 Mdot
.93027 .38647 Mdot
.93028 .38646 Mdot
.93029 .38644 Mdot
.9303 .38643 Mdot
.9303 .38641 Mdot
.93031 .3864 Mdot
.93032 .38638 Mdot
.93033 .38636 Mdot
.93034 .38635 Mdot
.93035 .38633 Mdot
.93036 .38632 Mdot
.93037 .3863 Mdot
.93038 .38628 Mdot
.93039 .38627 Mdot
.9304 .38625 Mdot
.93041 .38624 Mdot
.93042 .38622 Mdot
.93043 .3862 Mdot
.93044 .38619 Mdot
.93045 .38617 Mdot
.93046 .38616 Mdot
.93047 .38614 Mdot
.93048 .38612 Mdot
.93049 .38611 Mdot
.9305 .38609 Mdot
.9305 .38608 Mdot
.93051 .38606 Mdot
.93052 .38605 Mdot
.93053 .38603 Mdot
.93054 .38601 Mdot
.93055 .386 Mdot
.93056 .38598 Mdot
.93057 .38597 Mdot
.93058 .38595 Mdot
.93059 .38593 Mdot
.9306 .38592 Mdot
.93061 .3859 Mdot
.93062 .38589 Mdot
.93063 .38587 Mdot
.93064 .38585 Mdot
.93065 .38584 Mdot
.93066 .38582 Mdot
.93067 .38581 Mdot
.93068 .38579 Mdot
.93069 .38577 Mdot
.9307 .38576 Mdot
.9307 .38574 Mdot
.93071 .38573 Mdot
.93072 .38571 Mdot
.93073 .38569 Mdot
.93074 .38568 Mdot
.93075 .38566 Mdot
.93076 .38565 Mdot
.93077 .38563 Mdot
.93078 .38562 Mdot
.93079 .3856 Mdot
.9308 .38558 Mdot
.93081 .38557 Mdot
.93082 .38555 Mdot
.93083 .38554 Mdot
.93084 .38552 Mdot
.93085 .3855 Mdot
.93086 .38549 Mdot
.93087 .38547 Mdot
.93088 .38546 Mdot
.93089 .38544 Mdot
.9309 .38542 Mdot
.9309 .38541 Mdot
.93091 .38539 Mdot
.93092 .38538 Mdot
.93093 .38536 Mdot
.93094 .38534 Mdot
.93095 .38533 Mdot
.93096 .38531 Mdot
.93097 .3853 Mdot
.93098 .38528 Mdot
.93099 .38526 Mdot
.931 .38525 Mdot
.93101 .38523 Mdot
.93102 .38522 Mdot
.93103 .3852 Mdot
.93104 .38518 Mdot
.93105 .38517 Mdot
.93106 .38515 Mdot
.93107 .38514 Mdot
.93108 .38512 Mdot
.93109 .38511 Mdot
.9311 .38509 Mdot
.9311 .38507 Mdot
.93111 .38506 Mdot
.93112 .38504 Mdot
.93113 .38503 Mdot
.93114 .38501 Mdot
.93115 .38499 Mdot
.93116 .38498 Mdot
.93117 .38496 Mdot
.93118 .38495 Mdot
.93119 .38493 Mdot
.9312 .38491 Mdot
.93121 .3849 Mdot
.93122 .38488 Mdot
.93123 .38487 Mdot
.93124 .38485 Mdot
.93125 .38483 Mdot
.93126 .38482 Mdot
.93127 .3848 Mdot
.93128 .38479 Mdot
.93129 .38477 Mdot
.9313 .38475 Mdot
.9313 .38474 Mdot
.93131 .38472 Mdot
.93132 .38471 Mdot
.93133 .38469 Mdot
.93134 .38467 Mdot
.93135 .38466 Mdot
.93136 .38464 Mdot
.93137 .38463 Mdot
.93138 .38461 Mdot
.93139 .3846 Mdot
.9314 .38458 Mdot
.93141 .38456 Mdot
.93142 .38455 Mdot
.93143 .38453 Mdot
.93144 .38452 Mdot
.93145 .3845 Mdot
.93146 .38448 Mdot
.93147 .38447 Mdot
.93148 .38445 Mdot
.93149 .38444 Mdot
.9315 .38442 Mdot
.9315 .3844 Mdot
.93151 .38439 Mdot
.93152 .38437 Mdot
.93153 .38436 Mdot
.93154 .38434 Mdot
.93155 .38432 Mdot
.93156 .38431 Mdot
.93157 .38429 Mdot
.93158 .38428 Mdot
.93159 .38426 Mdot
.9316 .38424 Mdot
.93161 .38423 Mdot
.93162 .38421 Mdot
.93163 .3842 Mdot
.93164 .38418 Mdot
.93165 .38416 Mdot
.93166 .38415 Mdot
.93167 .38413 Mdot
.93168 .38412 Mdot
.93169 .3841 Mdot
.9317 .38408 Mdot
.9317 .38407 Mdot
.93171 .38405 Mdot
.93172 .38404 Mdot
.93173 .38402 Mdot
.93174 .38401 Mdot
.93175 .38399 Mdot
.93176 .38397 Mdot
.93177 .38396 Mdot
.93178 .38394 Mdot
.93179 .38393 Mdot
.9318 .38391 Mdot
.93181 .38389 Mdot
.93182 .38388 Mdot
.93183 .38386 Mdot
.93184 .38385 Mdot
.93185 .38383 Mdot
.93186 .38381 Mdot
.93187 .3838 Mdot
.93188 .38378 Mdot
.93189 .38377 Mdot
.9319 .38375 Mdot
.9319 .38373 Mdot
.93191 .38372 Mdot
.93192 .3837 Mdot
.93193 .38369 Mdot
.93194 .38367 Mdot
.93195 .38365 Mdot
.93196 .38364 Mdot
.93197 .38362 Mdot
.93198 .38361 Mdot
.93199 .38359 Mdot
.932 .38357 Mdot
.93201 .38356 Mdot
.93202 .38354 Mdot
.93203 .38353 Mdot
.93204 .38351 Mdot
.93205 .38349 Mdot
.93206 .38348 Mdot
.93207 .38346 Mdot
.93208 .38345 Mdot
.93209 .38343 Mdot
.9321 .38341 Mdot
.9321 .3834 Mdot
.93211 .38338 Mdot
.93212 .38337 Mdot
.93213 .38335 Mdot
.93214 .38333 Mdot
.93215 .38332 Mdot
.93216 .3833 Mdot
.93217 .38329 Mdot
.93218 .38327 Mdot
.93219 .38326 Mdot
.9322 .38324 Mdot
.93221 .38322 Mdot
.93222 .38321 Mdot
.93223 .38319 Mdot
.93224 .38318 Mdot
.93225 .38316 Mdot
.93226 .38314 Mdot
.93227 .38313 Mdot
.93228 .38311 Mdot
.93229 .3831 Mdot
.9323 .38308 Mdot
.9323 .38306 Mdot
.93231 .38305 Mdot
.93232 .38303 Mdot
.93233 .38302 Mdot
.93234 .383 Mdot
.93235 .38298 Mdot
.93236 .38297 Mdot
.93237 .38295 Mdot
.93238 .38294 Mdot
.93239 .38292 Mdot
.9324 .3829 Mdot
.93241 .38289 Mdot
.93242 .38287 Mdot
.93243 .38286 Mdot
.93244 .38284 Mdot
.93245 .38282 Mdot
.93246 .38281 Mdot
.93247 .38279 Mdot
.93248 .38278 Mdot
.93249 .38276 Mdot
.9325 .38274 Mdot
.9325 .38273 Mdot
.93251 .38271 Mdot
.93252 .3827 Mdot
.93253 .38268 Mdot
.93254 .38266 Mdot
.93255 .38265 Mdot
.93256 .38263 Mdot
.93257 .38262 Mdot
.93258 .3826 Mdot
.93259 .38258 Mdot
.9326 .38257 Mdot
.93261 .38255 Mdot
.93262 .38254 Mdot
.93263 .38252 Mdot
.93264 .3825 Mdot
.93265 .38249 Mdot
.93266 .38247 Mdot
.93267 .38246 Mdot
.93268 .38244 Mdot
.93269 .38242 Mdot
.9327 .38241 Mdot
.9327 .38239 Mdot
.93271 .38238 Mdot
.93272 .38236 Mdot
.93273 .38234 Mdot
.93274 .38233 Mdot
.93275 .38231 Mdot
.93276 .3823 Mdot
.93277 .38228 Mdot
.93278 .38226 Mdot
.93279 .38225 Mdot
.9328 .38223 Mdot
.93281 .38222 Mdot
.93282 .3822 Mdot
.93283 .38219 Mdot
.93284 .38217 Mdot
.93285 .38215 Mdot
.93286 .38214 Mdot
.93287 .38212 Mdot
.93288 .38211 Mdot
.93289 .38209 Mdot
.9329 .38207 Mdot
.9329 .38206 Mdot
.93291 .38204 Mdot
.93292 .38203 Mdot
.93293 .38201 Mdot
.93294 .38199 Mdot
.93295 .38198 Mdot
.93296 .38196 Mdot
.93297 .38195 Mdot
.93298 .38193 Mdot
.93299 .38191 Mdot
.933 .3819 Mdot
.93301 .38188 Mdot
.93302 .38187 Mdot
.93303 .38185 Mdot
.93304 .38183 Mdot
.93305 .38182 Mdot
.93306 .3818 Mdot
.93307 .38179 Mdot
.93308 .38177 Mdot
.93309 .38175 Mdot
.9331 .38174 Mdot
.9331 .38172 Mdot
.93311 .38171 Mdot
.93312 .38169 Mdot
.93313 .38167 Mdot
.93314 .38166 Mdot
.93315 .38164 Mdot
.93316 .38163 Mdot
.93317 .38161 Mdot
.93318 .38159 Mdot
.93319 .38158 Mdot
.9332 .38156 Mdot
.93321 .38155 Mdot
.93322 .38153 Mdot
.93323 .38151 Mdot
.93324 .3815 Mdot
.93325 .38148 Mdot
.93326 .38147 Mdot
.93327 .38145 Mdot
.93328 .38143 Mdot
.93329 .38142 Mdot
.9333 .3814 Mdot
.9333 .38139 Mdot
.93331 .38137 Mdot
.93332 .38135 Mdot
.93333 .38134 Mdot
.93334 .38132 Mdot
.93335 .38131 Mdot
.93336 .38129 Mdot
.93337 .38127 Mdot
.93338 .38126 Mdot
.93339 .38124 Mdot
.9334 .38123 Mdot
.93341 .38121 Mdot
.93342 .38119 Mdot
.93343 .38118 Mdot
.93344 .38116 Mdot
.93345 .38115 Mdot
.93346 .38113 Mdot
.93347 .38111 Mdot
.93348 .3811 Mdot
.93349 .38108 Mdot
.9335 .38107 Mdot
.9335 .38105 Mdot
.93351 .38103 Mdot
.93352 .38102 Mdot
.93353 .381 Mdot
.93354 .38099 Mdot
.93355 .38097 Mdot
.93356 .38095 Mdot
.93357 .38094 Mdot
.93358 .38092 Mdot
.93359 .38091 Mdot
.9336 .38089 Mdot
.93361 .38087 Mdot
.93362 .38086 Mdot
.93363 .38084 Mdot
.93364 .38083 Mdot
.93365 .38081 Mdot
.93366 .38079 Mdot
.93367 .38078 Mdot
.93368 .38076 Mdot
.93369 .38075 Mdot
.9337 .38073 Mdot
.9337 .38071 Mdot
.93371 .3807 Mdot
.93372 .38068 Mdot
.93373 .38067 Mdot
.93374 .38065 Mdot
.93375 .38063 Mdot
.93376 .38062 Mdot
.93377 .3806 Mdot
.93378 .38059 Mdot
.93379 .38057 Mdot
.9338 .38055 Mdot
.93381 .38054 Mdot
.93382 .38052 Mdot
.93383 .38051 Mdot
.93384 .38049 Mdot
.93385 .38047 Mdot
.93386 .38046 Mdot
.93387 .38044 Mdot
.93388 .38043 Mdot
.93389 .38041 Mdot
.9339 .38039 Mdot
.9339 .38038 Mdot
.93391 .38036 Mdot
.93392 .38035 Mdot
.93393 .38033 Mdot
.93394 .38031 Mdot
.93395 .3803 Mdot
.93396 .38028 Mdot
.93397 .38027 Mdot
.93398 .38025 Mdot
.93399 .38023 Mdot
.934 .38022 Mdot
.93401 .3802 Mdot
.93402 .38019 Mdot
.93403 .38017 Mdot
.93404 .38015 Mdot
.93405 .38014 Mdot
.93406 .38012 Mdot
.93407 .38011 Mdot
.93408 .38009 Mdot
.93409 .38007 Mdot
.9341 .38006 Mdot
.9341 .38004 Mdot
.93411 .38003 Mdot
.93412 .38001 Mdot
.93413 .37999 Mdot
.93414 .37998 Mdot
.93415 .37996 Mdot
.93416 .37995 Mdot
.93417 .37993 Mdot
.93418 .37991 Mdot
.93419 .3799 Mdot
.9342 .37988 Mdot
.93421 .37987 Mdot
.93422 .37985 Mdot
.93423 .37983 Mdot
.93424 .37982 Mdot
.93425 .3798 Mdot
.93426 .37979 Mdot
.93427 .37977 Mdot
.93428 .37975 Mdot
.93429 .37974 Mdot
.9343 .37972 Mdot
.9343 .37971 Mdot
.93431 .37969 Mdot
.93432 .37967 Mdot
.93433 .37966 Mdot
.93434 .37964 Mdot
.93435 .37963 Mdot
.93436 .37961 Mdot
.93437 .37959 Mdot
.93438 .37958 Mdot
.93439 .37956 Mdot
.9344 .37955 Mdot
.93441 .37953 Mdot
.93442 .37951 Mdot
.93443 .3795 Mdot
.93444 .37948 Mdot
.93445 .37947 Mdot
.93446 .37945 Mdot
.93447 .37943 Mdot
.93448 .37942 Mdot
.93449 .3794 Mdot
.9345 .37939 Mdot
.9345 .37937 Mdot
.93451 .37935 Mdot
.93452 .37934 Mdot
.93453 .37932 Mdot
.93454 .37931 Mdot
.93455 .37929 Mdot
.93456 .37927 Mdot
.93457 .37926 Mdot
.93458 .37924 Mdot
.93459 .37923 Mdot
.9346 .37921 Mdot
.93461 .37919 Mdot
.93462 .37918 Mdot
.93463 .37916 Mdot
.93464 .37915 Mdot
.93465 .37913 Mdot
.93466 .37911 Mdot
.93467 .3791 Mdot
.93468 .37908 Mdot
.93469 .37907 Mdot
.9347 .37905 Mdot
.9347 .37903 Mdot
.93471 .37902 Mdot
.93472 .379 Mdot
.93473 .37899 Mdot
.93474 .37897 Mdot
.93475 .37895 Mdot
.93476 .37894 Mdot
.93477 .37892 Mdot
.93478 .37891 Mdot
.93479 .37889 Mdot
.9348 .37887 Mdot
.93481 .37886 Mdot
.93482 .37884 Mdot
.93483 .37883 Mdot
.93484 .37881 Mdot
.93485 .37879 Mdot
.93486 .37878 Mdot
.93487 .37876 Mdot
.93488 .37875 Mdot
.93489 .37873 Mdot
.9349 .37871 Mdot
.9349 .3787 Mdot
.93491 .37868 Mdot
.93492 .37866 Mdot
.93493 .37865 Mdot
.93494 .37863 Mdot
.93495 .37862 Mdot
.93496 .3786 Mdot
.93497 .37858 Mdot
.93498 .37857 Mdot
.93499 .37855 Mdot
.935 .37854 Mdot
.93501 .37852 Mdot
.93502 .3785 Mdot
.93503 .37849 Mdot
.93504 .37847 Mdot
.93505 .37846 Mdot
.93506 .37844 Mdot
.93507 .37842 Mdot
.93508 .37841 Mdot
.93509 .37839 Mdot
.9351 .37838 Mdot
.9351 .37836 Mdot
.93511 .37834 Mdot
.93512 .37833 Mdot
.93513 .37831 Mdot
.93514 .3783 Mdot
.93515 .37828 Mdot
.93516 .37826 Mdot
.93517 .37825 Mdot
.93518 .37823 Mdot
.93519 .37822 Mdot
.9352 .3782 Mdot
.93521 .37818 Mdot
.93522 .37817 Mdot
.93523 .37815 Mdot
.93524 .37814 Mdot
.93525 .37812 Mdot
.93526 .3781 Mdot
.93527 .37809 Mdot
.93528 .37807 Mdot
.93529 .37806 Mdot
.9353 .37804 Mdot
.9353 .37802 Mdot
.93531 .37801 Mdot
.93532 .37799 Mdot
.93533 .37798 Mdot
.93534 .37796 Mdot
.93535 .37794 Mdot
.93536 .37793 Mdot
.93537 .37791 Mdot
.93538 .3779 Mdot
.93539 .37788 Mdot
.9354 .37786 Mdot
.93541 .37785 Mdot
.93542 .37783 Mdot
.93543 .37782 Mdot
.93544 .3778 Mdot
.93545 .37778 Mdot
.93546 .37777 Mdot
.93547 .37775 Mdot
.93548 .37774 Mdot
.93549 .37772 Mdot
.9355 .3777 Mdot
.9355 .37769 Mdot
.93551 .37767 Mdot
.93552 .37765 Mdot
.93553 .37764 Mdot
.93554 .37762 Mdot
.93555 .37761 Mdot
.93556 .37759 Mdot
.93557 .37757 Mdot
.93558 .37756 Mdot
.93559 .37754 Mdot
.9356 .37753 Mdot
.93561 .37751 Mdot
.93562 .37749 Mdot
.93563 .37748 Mdot
.93564 .37746 Mdot
.93565 .37745 Mdot
.93566 .37743 Mdot
.93567 .37741 Mdot
.93568 .3774 Mdot
.93569 .37738 Mdot
.9357 .37737 Mdot
.9357 .37735 Mdot
.93571 .37733 Mdot
.93572 .37732 Mdot
.93573 .3773 Mdot
.93574 .37729 Mdot
.93575 .37727 Mdot
.93576 .37725 Mdot
.93577 .37724 Mdot
.93578 .37722 Mdot
.93579 .37721 Mdot
.9358 .37719 Mdot
.93581 .37717 Mdot
.93582 .37716 Mdot
.93583 .37714 Mdot
.93584 .37713 Mdot
.93585 .37711 Mdot
.93586 .37709 Mdot
.93587 .37708 Mdot
.93588 .37706 Mdot
.93589 .37705 Mdot
.9359 .37703 Mdot
.9359 .37701 Mdot
.93591 .377 Mdot
.93592 .37698 Mdot
.93593 .37697 Mdot
.93594 .37695 Mdot
.93595 .37693 Mdot
.93596 .37692 Mdot
.93597 .3769 Mdot
.93598 .37688 Mdot
.93599 .37687 Mdot
.936 .37685 Mdot
.93601 .37684 Mdot
.93602 .37682 Mdot
.93603 .3768 Mdot
.93604 .37679 Mdot
.93605 .37677 Mdot
.93606 .37676 Mdot
.93607 .37674 Mdot
.93608 .37672 Mdot
.93609 .37671 Mdot
.9361 .37669 Mdot
.9361 .37668 Mdot
.93611 .37666 Mdot
.93612 .37664 Mdot
.93613 .37663 Mdot
.93614 .37661 Mdot
.93615 .3766 Mdot
.93616 .37658 Mdot
.93617 .37656 Mdot
.93618 .37655 Mdot
.93619 .37653 Mdot
.9362 .37652 Mdot
.93621 .3765 Mdot
.93622 .37648 Mdot
.93623 .37647 Mdot
.93624 .37645 Mdot
.93625 .37644 Mdot
.93626 .37642 Mdot
.93627 .3764 Mdot
.93628 .37639 Mdot
.93629 .37637 Mdot
.9363 .37636 Mdot
.9363 .37634 Mdot
.93631 .37632 Mdot
.93632 .37631 Mdot
.93633 .37629 Mdot
.93634 .37627 Mdot
.93635 .37626 Mdot
.93636 .37624 Mdot
.93637 .37623 Mdot
.93638 .37621 Mdot
.93639 .37619 Mdot
.9364 .37618 Mdot
.93641 .37616 Mdot
.93642 .37615 Mdot
.93643 .37613 Mdot
.93644 .37611 Mdot
.93645 .3761 Mdot
.93646 .37608 Mdot
.93647 .37607 Mdot
.93648 .37605 Mdot
.93649 .37603 Mdot
.9365 .37602 Mdot
.9365 .376 Mdot
.93651 .37599 Mdot
.93652 .37597 Mdot
.93653 .37595 Mdot
.93654 .37594 Mdot
.93655 .37592 Mdot
.93656 .37591 Mdot
.93657 .37589 Mdot
.93658 .37587 Mdot
.93659 .37586 Mdot
.9366 .37584 Mdot
.93661 .37583 Mdot
.93662 .37581 Mdot
.93663 .37579 Mdot
.93664 .37578 Mdot
.93665 .37576 Mdot
.93666 .37575 Mdot
.93667 .37573 Mdot
.93668 .37571 Mdot
.93669 .3757 Mdot
.9367 .37568 Mdot
.9367 .37566 Mdot
.93671 .37565 Mdot
.93672 .37563 Mdot
.93673 .37562 Mdot
.93674 .3756 Mdot
.93675 .37558 Mdot
.93676 .37557 Mdot
.93677 .37555 Mdot
.93678 .37554 Mdot
.93679 .37552 Mdot
.9368 .3755 Mdot
.93681 .37549 Mdot
.93682 .37547 Mdot
.93683 .37546 Mdot
.93684 .37544 Mdot
.93685 .37542 Mdot
.93686 .37541 Mdot
.93687 .37539 Mdot
.93688 .37538 Mdot
.93689 .37536 Mdot
.9369 .37534 Mdot
.9369 .37533 Mdot
.93691 .37531 Mdot
.93692 .3753 Mdot
.93693 .37528 Mdot
.93694 .37526 Mdot
.93695 .37525 Mdot
.93696 .37523 Mdot
.93697 .37521 Mdot
.93698 .3752 Mdot
.93699 .37518 Mdot
.937 .37517 Mdot
.93701 .37515 Mdot
.93702 .37513 Mdot
.93703 .37512 Mdot
.93704 .3751 Mdot
.93705 .37509 Mdot
.93706 .37507 Mdot
.93707 .37505 Mdot
.93708 .37504 Mdot
.93709 .37502 Mdot
.9371 .37501 Mdot
.9371 .37499 Mdot
.93711 .37497 Mdot
.93712 .37496 Mdot
.93713 .37494 Mdot
.93714 .37493 Mdot
.93715 .37491 Mdot
.93716 .37489 Mdot
.93717 .37488 Mdot
.93718 .37486 Mdot
.93719 .37485 Mdot
.9372 .37483 Mdot
.93721 .37481 Mdot
.93722 .3748 Mdot
.93723 .37478 Mdot
.93724 .37476 Mdot
.93725 .37475 Mdot
.93726 .37473 Mdot
.93727 .37472 Mdot
.93728 .3747 Mdot
.93729 .37468 Mdot
.9373 .37467 Mdot
.9373 .37465 Mdot
.93731 .37464 Mdot
.93732 .37462 Mdot
.93733 .3746 Mdot
.93734 .37459 Mdot
.93735 .37457 Mdot
.93736 .37456 Mdot
.93737 .37454 Mdot
.93738 .37452 Mdot
.93739 .37451 Mdot
.9374 .37449 Mdot
.93741 .37448 Mdot
.93742 .37446 Mdot
.93743 .37444 Mdot
.93744 .37443 Mdot
.93745 .37441 Mdot
.93746 .3744 Mdot
.93747 .37438 Mdot
.93748 .37436 Mdot
.93749 .37435 Mdot
.9375 .37433 Mdot
.9375 .37431 Mdot
.93751 .3743 Mdot
.93752 .37428 Mdot
.93753 .37427 Mdot
.93754 .37425 Mdot
.93755 .37423 Mdot
.93756 .37422 Mdot
.93757 .3742 Mdot
.93758 .37419 Mdot
.93759 .37417 Mdot
.9376 .37415 Mdot
.93761 .37414 Mdot
.93762 .37412 Mdot
.93763 .37411 Mdot
.93764 .37409 Mdot
.93765 .37407 Mdot
.93766 .37406 Mdot
.93767 .37404 Mdot
.93768 .37403 Mdot
.93769 .37401 Mdot
.9377 .37399 Mdot
.9377 .37398 Mdot
.93771 .37396 Mdot
.93772 .37394 Mdot
.93773 .37393 Mdot
.93774 .37391 Mdot
.93775 .3739 Mdot
.93776 .37388 Mdot
.93777 .37386 Mdot
.93778 .37385 Mdot
.93779 .37383 Mdot
.9378 .37382 Mdot
.93781 .3738 Mdot
.93782 .37378 Mdot
.93783 .37377 Mdot
.93784 .37375 Mdot
.93785 .37374 Mdot
.93786 .37372 Mdot
.93787 .3737 Mdot
.93788 .37369 Mdot
.93789 .37367 Mdot
.9379 .37366 Mdot
.9379 .37364 Mdot
.93791 .37362 Mdot
.93792 .37361 Mdot
.93793 .37359 Mdot
.93794 .37357 Mdot
.93795 .37356 Mdot
.93796 .37354 Mdot
.93797 .37353 Mdot
.93798 .37351 Mdot
.93799 .37349 Mdot
.938 .37348 Mdot
.93801 .37346 Mdot
.93802 .37345 Mdot
.93803 .37343 Mdot
.93804 .37341 Mdot
.93805 .3734 Mdot
.93806 .37338 Mdot
.93807 .37337 Mdot
.93808 .37335 Mdot
.93809 .37333 Mdot
.9381 .37332 Mdot
.9381 .3733 Mdot
.93811 .37329 Mdot
.93812 .37327 Mdot
.93813 .37325 Mdot
.93814 .37324 Mdot
.93815 .37322 Mdot
.93816 .3732 Mdot
.93817 .37319 Mdot
.93818 .37317 Mdot
.93819 .37316 Mdot
.9382 .37314 Mdot
.93821 .37312 Mdot
.93822 .37311 Mdot
.93823 .37309 Mdot
.93824 .37308 Mdot
.93825 .37306 Mdot
.93826 .37304 Mdot
.93827 .37303 Mdot
.93828 .37301 Mdot
.93829 .373 Mdot
.9383 .37298 Mdot
.9383 .37296 Mdot
.93831 .37295 Mdot
.93832 .37293 Mdot
.93833 .37292 Mdot
.93834 .3729 Mdot
.93835 .37288 Mdot
.93836 .37287 Mdot
.93837 .37285 Mdot
.93838 .37283 Mdot
.93839 .37282 Mdot
.9384 .3728 Mdot
.93841 .37279 Mdot
.93842 .37277 Mdot
.93843 .37275 Mdot
.93844 .37274 Mdot
.93845 .37272 Mdot
.93846 .37271 Mdot
.93847 .37269 Mdot
.93848 .37267 Mdot
.93849 .37266 Mdot
.9385 .37264 Mdot
.9385 .37263 Mdot
.93851 .37261 Mdot
.93852 .37259 Mdot
.93853 .37258 Mdot
.93854 .37256 Mdot
.93855 .37254 Mdot
.93856 .37253 Mdot
.93857 .37251 Mdot
.93858 .3725 Mdot
.93859 .37248 Mdot
.9386 .37246 Mdot
.93861 .37245 Mdot
.93862 .37243 Mdot
.93863 .37242 Mdot
.93864 .3724 Mdot
.93865 .37238 Mdot
.93866 .37237 Mdot
.93867 .37235 Mdot
.93868 .37234 Mdot
.93869 .37232 Mdot
.9387 .3723 Mdot
.9387 .37229 Mdot
.93871 .37227 Mdot
.93872 .37226 Mdot
.93873 .37224 Mdot
.93874 .37222 Mdot
.93875 .37221 Mdot
.93876 .37219 Mdot
.93877 .37217 Mdot
.93878 .37216 Mdot
.93879 .37214 Mdot
.9388 .37213 Mdot
.93881 .37211 Mdot
.93882 .37209 Mdot
.93883 .37208 Mdot
.93884 .37206 Mdot
.93885 .37205 Mdot
.93886 .37203 Mdot
.93887 .37201 Mdot
.93888 .372 Mdot
.93889 .37198 Mdot
.9389 .37197 Mdot
.9389 .37195 Mdot
.93891 .37193 Mdot
.93892 .37192 Mdot
.93893 .3719 Mdot
.93894 .37188 Mdot
.93895 .37187 Mdot
.93896 .37185 Mdot
.93897 .37184 Mdot
.93898 .37182 Mdot
.93899 .3718 Mdot
.939 .37179 Mdot
.93901 .37177 Mdot
.93902 .37176 Mdot
.93903 .37174 Mdot
.93904 .37172 Mdot
.93905 .37171 Mdot
.93906 .37169 Mdot
.93907 .37168 Mdot
.93908 .37166 Mdot
.93909 .37164 Mdot
.9391 .37163 Mdot
.9391 .37161 Mdot
.93911 .37159 Mdot
.93912 .37158 Mdot
.93913 .37156 Mdot
.93914 .37155 Mdot
.93915 .37153 Mdot
.93916 .37151 Mdot
.93917 .3715 Mdot
.93918 .37148 Mdot
.93919 .37147 Mdot
.9392 .37145 Mdot
.93921 .37143 Mdot
.93922 .37142 Mdot
.93923 .3714 Mdot
.93924 .37139 Mdot
.93925 .37137 Mdot
.93926 .37135 Mdot
.93927 .37134 Mdot
.93928 .37132 Mdot
.93929 .3713 Mdot
.9393 .37129 Mdot
.9393 .37127 Mdot
.93931 .37126 Mdot
.93932 .37124 Mdot
.93933 .37122 Mdot
.93934 .37121 Mdot
.93935 .37119 Mdot
.93936 .37118 Mdot
.93937 .37116 Mdot
.93938 .37114 Mdot
.93939 .37113 Mdot
.9394 .37111 Mdot
.93941 .3711 Mdot
.93942 .37108 Mdot
.93943 .37106 Mdot
.93944 .37105 Mdot
.93945 .37103 Mdot
.93946 .37101 Mdot
.93947 .371 Mdot
.93948 .37098 Mdot
.93949 .37097 Mdot
.9395 .37095 Mdot
.9395 .37093 Mdot
.93951 .37092 Mdot
.93952 .3709 Mdot
.93953 .37089 Mdot
.93954 .37087 Mdot
.93955 .37085 Mdot
.93956 .37084 Mdot
.93957 .37082 Mdot
.93958 .37081 Mdot
.93959 .37079 Mdot
.9396 .37077 Mdot
.93961 .37076 Mdot
.93962 .37074 Mdot
.93963 .37072 Mdot
.93964 .37071 Mdot
.93965 .37069 Mdot
.93966 .37068 Mdot
.93967 .37066 Mdot
.93968 .37064 Mdot
.93969 .37063 Mdot
.9397 .37061 Mdot
.9397 .3706 Mdot
.93971 .37058 Mdot
.93972 .37056 Mdot
.93973 .37055 Mdot
.93974 .37053 Mdot
.93975 .37051 Mdot
.93976 .3705 Mdot
.93977 .37048 Mdot
.93978 .37047 Mdot
.93979 .37045 Mdot
.9398 .37043 Mdot
.93981 .37042 Mdot
.93982 .3704 Mdot
.93983 .37039 Mdot
.93984 .37037 Mdot
.93985 .37035 Mdot
.93986 .37034 Mdot
.93987 .37032 Mdot
.93988 .37031 Mdot
.93989 .37029 Mdot
.9399 .37027 Mdot
.9399 .37026 Mdot
.93991 .37024 Mdot
.93992 .37022 Mdot
.93993 .37021 Mdot
.93994 .37019 Mdot
.93995 .37018 Mdot
.93996 .37016 Mdot
.93997 .37014 Mdot
.93998 .37013 Mdot
.93999 .37011 Mdot
.94 .3701 Mdot
.94001 .37008 Mdot
.94002 .37006 Mdot
.94003 .37005 Mdot
.94004 .37003 Mdot
.94005 .37001 Mdot
.94006 .37 Mdot
.94007 .36998 Mdot
.94008 .36997 Mdot
.94009 .36995 Mdot
.9401 .36993 Mdot
.9401 .36992 Mdot
.94011 .3699 Mdot
.94012 .36989 Mdot
.94013 .36987 Mdot
.94014 .36985 Mdot
.94015 .36984 Mdot
.94016 .36982 Mdot
.94017 .36981 Mdot
.94018 .36979 Mdot
.94019 .36977 Mdot
.9402 .36976 Mdot
.94021 .36974 Mdot
.94022 .36972 Mdot
.94023 .36971 Mdot
.94024 .36969 Mdot
.94025 .36968 Mdot
.94026 .36966 Mdot
.94027 .36964 Mdot
.94028 .36963 Mdot
.94029 .36961 Mdot
.9403 .3696 Mdot
.9403 .36958 Mdot
.94031 .36956 Mdot
.94032 .36955 Mdot
.94033 .36953 Mdot
.94034 .36951 Mdot
.94035 .3695 Mdot
.94036 .36948 Mdot
.94037 .36947 Mdot
.94038 .36945 Mdot
.94039 .36943 Mdot
.9404 .36942 Mdot
.94041 .3694 Mdot
.94042 .36939 Mdot
.94043 .36937 Mdot
.94044 .36935 Mdot
.94045 .36934 Mdot
.94046 .36932 Mdot
.94047 .3693 Mdot
.94048 .36929 Mdot
.94049 .36927 Mdot
.9405 .36926 Mdot
.9405 .36924 Mdot
.94051 .36922 Mdot
.94052 .36921 Mdot
.94053 .36919 Mdot
.94054 .36918 Mdot
.94055 .36916 Mdot
.94056 .36914 Mdot
.94057 .36913 Mdot
.94058 .36911 Mdot
.94059 .3691 Mdot
.9406 .36908 Mdot
.94061 .36906 Mdot
.94062 .36905 Mdot
.94063 .36903 Mdot
.94064 .36901 Mdot
.94065 .369 Mdot
.94066 .36898 Mdot
.94067 .36897 Mdot
.94068 .36895 Mdot
.94069 .36893 Mdot
.9407 .36892 Mdot
.9407 .3689 Mdot
.94071 .36889 Mdot
.94072 .36887 Mdot
.94073 .36885 Mdot
.94074 .36884 Mdot
.94075 .36882 Mdot
.94076 .3688 Mdot
.94077 .36879 Mdot
.94078 .36877 Mdot
.94079 .36876 Mdot
.9408 .36874 Mdot
.94081 .36872 Mdot
.94082 .36871 Mdot
.94083 .36869 Mdot
.94084 .36868 Mdot
.94085 .36866 Mdot
.94086 .36864 Mdot
.94087 .36863 Mdot
.94088 .36861 Mdot
.94089 .36859 Mdot
.9409 .36858 Mdot
.9409 .36856 Mdot
.94091 .36855 Mdot
.94092 .36853 Mdot
.94093 .36851 Mdot
.94094 .3685 Mdot
.94095 .36848 Mdot
.94096 .36847 Mdot
.94097 .36845 Mdot
.94098 .36843 Mdot
.94099 .36842 Mdot
.941 .3684 Mdot
.94101 .36838 Mdot
.94102 .36837 Mdot
.94103 .36835 Mdot
.94104 .36834 Mdot
.94105 .36832 Mdot
.94106 .3683 Mdot
.94107 .36829 Mdot
.94108 .36827 Mdot
.94109 .36826 Mdot
.9411 .36824 Mdot
.9411 .36822 Mdot
.94111 .36821 Mdot
.94112 .36819 Mdot
.94113 .36817 Mdot
.94114 .36816 Mdot
.94115 .36814 Mdot
.94116 .36813 Mdot
.94117 .36811 Mdot
.94118 .36809 Mdot
.94119 .36808 Mdot
.9412 .36806 Mdot
.94121 .36805 Mdot
.94122 .36803 Mdot
.94123 .36801 Mdot
.94124 .368 Mdot
.94125 .36798 Mdot
.94126 .36796 Mdot
.94127 .36795 Mdot
.94128 .36793 Mdot
.94129 .36792 Mdot
.9413 .3679 Mdot
.9413 .36788 Mdot
.94131 .36787 Mdot
.94132 .36785 Mdot
.94133 .36784 Mdot
.94134 .36782 Mdot
.94135 .3678 Mdot
.94136 .36779 Mdot
.94137 .36777 Mdot
.94138 .36775 Mdot
.94139 .36774 Mdot
.9414 .36772 Mdot
.94141 .36771 Mdot
.94142 .36769 Mdot
.94143 .36767 Mdot
.94144 .36766 Mdot
.94145 .36764 Mdot
.94146 .36763 Mdot
.94147 .36761 Mdot
.94148 .36759 Mdot
.94149 .36758 Mdot
.9415 .36756 Mdot
.9415 .36754 Mdot
.94151 .36753 Mdot
.94152 .36751 Mdot
.94153 .3675 Mdot
.94154 .36748 Mdot
.94155 .36746 Mdot
.94156 .36745 Mdot
.94157 .36743 Mdot
.94158 .36742 Mdot
.94159 .3674 Mdot
.9416 .36738 Mdot
.94161 .36737 Mdot
.94162 .36735 Mdot
.94163 .36733 Mdot
.94164 .36732 Mdot
.94165 .3673 Mdot
.94166 .36729 Mdot
.94167 .36727 Mdot
.94168 .36725 Mdot
.94169 .36724 Mdot
.9417 .36722 Mdot
.9417 .36721 Mdot
.94171 .36719 Mdot
.94172 .36717 Mdot
.94173 .36716 Mdot
.94174 .36714 Mdot
.94175 .36712 Mdot
.94176 .36711 Mdot
.94177 .36709 Mdot
.94178 .36708 Mdot
.94179 .36706 Mdot
.9418 .36704 Mdot
.94181 .36703 Mdot
.94182 .36701 Mdot
.94183 .367 Mdot
.94184 .36698 Mdot
.94185 .36696 Mdot
.94186 .36695 Mdot
.94187 .36693 Mdot
.94188 .36691 Mdot
.94189 .3669 Mdot
.9419 .36688 Mdot
.9419 .36687 Mdot
.94191 .36685 Mdot
.94192 .36683 Mdot
.94193 .36682 Mdot
.94194 .3668 Mdot
.94195 .36679 Mdot
.94196 .36677 Mdot
.94197 .36675 Mdot
.94198 .36674 Mdot
.94199 .36672 Mdot
.942 .3667 Mdot
.94201 .36669 Mdot
.94202 .36667 Mdot
.94203 .36666 Mdot
.94204 .36664 Mdot
.94205 .36662 Mdot
.94206 .36661 Mdot
.94207 .36659 Mdot
.94208 .36658 Mdot
.94209 .36656 Mdot
.9421 .36654 Mdot
.9421 .36653 Mdot
.94211 .36651 Mdot
.94212 .36649 Mdot
.94213 .36648 Mdot
.94214 .36646 Mdot
.94215 .36645 Mdot
.94216 .36643 Mdot
.94217 .36641 Mdot
.94218 .3664 Mdot
.94219 .36638 Mdot
.9422 .36636 Mdot
.94221 .36635 Mdot
.94222 .36633 Mdot
.94223 .36632 Mdot
.94224 .3663 Mdot
.94225 .36628 Mdot
.94226 .36627 Mdot
.94227 .36625 Mdot
.94228 .36624 Mdot
.94229 .36622 Mdot
.9423 .3662 Mdot
.9423 .36619 Mdot
.94231 .36617 Mdot
.94232 .36615 Mdot
.94233 .36614 Mdot
.94234 .36612 Mdot
.94235 .36611 Mdot
.94236 .36609 Mdot
.94237 .36607 Mdot
.94238 .36606 Mdot
.94239 .36604 Mdot
.9424 .36603 Mdot
.94241 .36601 Mdot
.94242 .36599 Mdot
.94243 .36598 Mdot
.94244 .36596 Mdot
.94245 .36594 Mdot
.94246 .36593 Mdot
.94247 .36591 Mdot
.94248 .3659 Mdot
.94249 .36588 Mdot
.9425 .36586 Mdot
.9425 .36585 Mdot
.94251 .36583 Mdot
.94252 .36582 Mdot
.94253 .3658 Mdot
.94254 .36578 Mdot
.94255 .36577 Mdot
.94256 .36575 Mdot
.94257 .36573 Mdot
.94258 .36572 Mdot
.94259 .3657 Mdot
.9426 .36569 Mdot
.94261 .36567 Mdot
.94262 .36565 Mdot
.94263 .36564 Mdot
.94264 .36562 Mdot
.94265 .3656 Mdot
.94266 .36559 Mdot
.94267 .36557 Mdot
.94268 .36556 Mdot
.94269 .36554 Mdot
.9427 .36552 Mdot
.9427 .36551 Mdot
.94271 .36549 Mdot
.94272 .36548 Mdot
.94273 .36546 Mdot
.94274 .36544 Mdot
.94275 .36543 Mdot
.94276 .36541 Mdot
.94277 .36539 Mdot
.94278 .36538 Mdot
.94279 .36536 Mdot
.9428 .36535 Mdot
.94281 .36533 Mdot
.94282 .36531 Mdot
.94283 .3653 Mdot
.94284 .36528 Mdot
.94285 .36527 Mdot
.94286 .36525 Mdot
.94287 .36523 Mdot
.94288 .36522 Mdot
.94289 .3652 Mdot
.9429 .36518 Mdot
.9429 .36517 Mdot
.94291 .36515 Mdot
.94292 .36514 Mdot
.94293 .36512 Mdot
.94294 .3651 Mdot
.94295 .36509 Mdot
.94296 .36507 Mdot
.94297 .36505 Mdot
.94298 .36504 Mdot
.94299 .36502 Mdot
.943 .36501 Mdot
.94301 .36499 Mdot
.94302 .36497 Mdot
.94303 .36496 Mdot
.94304 .36494 Mdot
.94305 .36493 Mdot
.94306 .36491 Mdot
.94307 .36489 Mdot
.94308 .36488 Mdot
.94309 .36486 Mdot
.9431 .36484 Mdot
.9431 .36483 Mdot
.94311 .36481 Mdot
.94312 .3648 Mdot
.94313 .36478 Mdot
.94314 .36476 Mdot
.94315 .36475 Mdot
.94316 .36473 Mdot
.94317 .36471 Mdot
.94318 .3647 Mdot
.94319 .36468 Mdot
.9432 .36467 Mdot
.94321 .36465 Mdot
.94322 .36463 Mdot
.94323 .36462 Mdot
.94324 .3646 Mdot
.94325 .36459 Mdot
.94326 .36457 Mdot
.94327 .36455 Mdot
.94328 .36454 Mdot
.94329 .36452 Mdot
.9433 .3645 Mdot
.9433 .36449 Mdot
.94331 .36447 Mdot
.94332 .36446 Mdot
.94333 .36444 Mdot
.94334 .36442 Mdot
.94335 .36441 Mdot
.94336 .36439 Mdot
.94337 .36437 Mdot
.94338 .36436 Mdot
.94339 .36434 Mdot
.9434 .36433 Mdot
.94341 .36431 Mdot
.94342 .36429 Mdot
.94343 .36428 Mdot
.94344 .36426 Mdot
.94345 .36425 Mdot
.94346 .36423 Mdot
.94347 .36421 Mdot
.94348 .3642 Mdot
.94349 .36418 Mdot
.9435 .36416 Mdot
.9435 .36415 Mdot
.94351 .36413 Mdot
.94352 .36412 Mdot
.94353 .3641 Mdot
.94354 .36408 Mdot
.94355 .36407 Mdot
.94356 .36405 Mdot
.94357 .36403 Mdot
.94358 .36402 Mdot
.94359 .364 Mdot
.9436 .36399 Mdot
.94361 .36397 Mdot
.94362 .36395 Mdot
.94363 .36394 Mdot
.94364 .36392 Mdot
.94365 .36391 Mdot
.94366 .36389 Mdot
.94367 .36387 Mdot
.94368 .36386 Mdot
.94369 .36384 Mdot
.9437 .36382 Mdot
.9437 .36381 Mdot
.94371 .36379 Mdot
.94372 .36378 Mdot
.94373 .36376 Mdot
.94374 .36374 Mdot
.94375 .36373 Mdot
.94376 .36371 Mdot
.94377 .36369 Mdot
.94378 .36368 Mdot
.94379 .36366 Mdot
.9438 .36365 Mdot
.94381 .36363 Mdot
.94382 .36361 Mdot
.94383 .3636 Mdot
.94384 .36358 Mdot
.94385 .36357 Mdot
.94386 .36355 Mdot
.94387 .36353 Mdot
.94388 .36352 Mdot
.94389 .3635 Mdot
.9439 .36348 Mdot
.9439 .36347 Mdot
.94391 .36345 Mdot
.94392 .36344 Mdot
.94393 .36342 Mdot
.94394 .3634 Mdot
.94395 .36339 Mdot
.94396 .36337 Mdot
.94397 .36335 Mdot
.94398 .36334 Mdot
.94399 .36332 Mdot
.944 .36331 Mdot
.94401 .36329 Mdot
.94402 .36327 Mdot
.94403 .36326 Mdot
.94404 .36324 Mdot
.94405 .36322 Mdot
.94406 .36321 Mdot
.94407 .36319 Mdot
.94408 .36318 Mdot
.94409 .36316 Mdot
.9441 .36314 Mdot
.9441 .36313 Mdot
.94411 .36311 Mdot
.94412 .3631 Mdot
.94413 .36308 Mdot
.94414 .36306 Mdot
.94415 .36305 Mdot
.94416 .36303 Mdot
.94417 .36301 Mdot
.94418 .363 Mdot
.94419 .36298 Mdot
.9442 .36297 Mdot
.94421 .36295 Mdot
.94422 .36293 Mdot
.94423 .36292 Mdot
.94424 .3629 Mdot
.94425 .36288 Mdot
.94426 .36287 Mdot
.94427 .36285 Mdot
.94428 .36284 Mdot
.94429 .36282 Mdot
.9443 .3628 Mdot
.9443 .36279 Mdot
.94431 .36277 Mdot
.94432 .36275 Mdot
.94433 .36274 Mdot
.94434 .36272 Mdot
.94435 .36271 Mdot
.94436 .36269 Mdot
.94437 .36267 Mdot
.94438 .36266 Mdot
.94439 .36264 Mdot
.9444 .36263 Mdot
.94441 .36261 Mdot
.94442 .36259 Mdot
.94443 .36258 Mdot
.94444 .36256 Mdot
.94445 .36254 Mdot
.94446 .36253 Mdot
.94447 .36251 Mdot
.94448 .3625 Mdot
.94449 .36248 Mdot
.9445 .36246 Mdot
.9445 .36245 Mdot
.94451 .36243 Mdot
.94452 .36241 Mdot
.94453 .3624 Mdot
.94454 .36238 Mdot
.94455 .36237 Mdot
.94456 .36235 Mdot
.94457 .36233 Mdot
.94458 .36232 Mdot
.94459 .3623 Mdot
.9446 .36228 Mdot
.94461 .36227 Mdot
.94462 .36225 Mdot
.94463 .36224 Mdot
.94464 .36222 Mdot
.94465 .3622 Mdot
.94466 .36219 Mdot
.94467 .36217 Mdot
.94468 .36216 Mdot
.94469 .36214 Mdot
.9447 .36212 Mdot
.9447 .36211 Mdot
.94471 .36209 Mdot
.94472 .36207 Mdot
.94473 .36206 Mdot
.94474 .36204 Mdot
.94475 .36203 Mdot
.94476 .36201 Mdot
.94477 .36199 Mdot
.94478 .36198 Mdot
.94479 .36196 Mdot
.9448 .36194 Mdot
.94481 .36193 Mdot
.94482 .36191 Mdot
.94483 .3619 Mdot
.94484 .36188 Mdot
.94485 .36186 Mdot
.94486 .36185 Mdot
.94487 .36183 Mdot
.94488 .36181 Mdot
.94489 .3618 Mdot
.9449 .36178 Mdot
.9449 .36177 Mdot
.94491 .36175 Mdot
.94492 .36173 Mdot
.94493 .36172 Mdot
.94494 .3617 Mdot
.94495 .36168 Mdot
.94496 .36167 Mdot
.94497 .36165 Mdot
.94498 .36164 Mdot
.94499 .36162 Mdot
.945 .3616 Mdot
.94501 .36159 Mdot
.94502 .36157 Mdot
.94503 .36156 Mdot
.94504 .36154 Mdot
.94505 .36152 Mdot
.94506 .36151 Mdot
.94507 .36149 Mdot
.94508 .36147 Mdot
.94509 .36146 Mdot
.9451 .36144 Mdot
.9451 .36143 Mdot
.94511 .36141 Mdot
.94512 .36139 Mdot
.94513 .36138 Mdot
.94514 .36136 Mdot
.94515 .36134 Mdot
.94516 .36133 Mdot
.94517 .36131 Mdot
.94518 .3613 Mdot
.94519 .36128 Mdot
.9452 .36126 Mdot
.94521 .36125 Mdot
.94522 .36123 Mdot
.94523 .36121 Mdot
.94524 .3612 Mdot
.94525 .36118 Mdot
.94526 .36117 Mdot
.94527 .36115 Mdot
.94528 .36113 Mdot
.94529 .36112 Mdot
.9453 .3611 Mdot
.9453 .36108 Mdot
.94531 .36107 Mdot
.94532 .36105 Mdot
.94533 .36104 Mdot
.94534 .36102 Mdot
.94535 .361 Mdot
.94536 .36099 Mdot
.94537 .36097 Mdot
.94538 .36095 Mdot
.94539 .36094 Mdot
.9454 .36092 Mdot
.94541 .36091 Mdot
.94542 .36089 Mdot
.94543 .36087 Mdot
.94544 .36086 Mdot
.94545 .36084 Mdot
.94546 .36083 Mdot
.94547 .36081 Mdot
.94548 .36079 Mdot
.94549 .36078 Mdot
.9455 .36076 Mdot
.9455 .36074 Mdot
.94551 .36073 Mdot
.94552 .36071 Mdot
.94553 .3607 Mdot
.94554 .36068 Mdot
.94555 .36066 Mdot
.94556 .36065 Mdot
.94557 .36063 Mdot
.94558 .36061 Mdot
.94559 .3606 Mdot
.9456 .36058 Mdot
.94561 .36057 Mdot
.94562 .36055 Mdot
.94563 .36053 Mdot
.94564 .36052 Mdot
.94565 .3605 Mdot
.94566 .36048 Mdot
.94567 .36047 Mdot
.94568 .36045 Mdot
.94569 .36044 Mdot
.9457 .36042 Mdot
.9457 .3604 Mdot
.94571 .36039 Mdot
.94572 .36037 Mdot
.94573 .36035 Mdot
.94574 .36034 Mdot
.94575 .36032 Mdot
.94576 .36031 Mdot
.94577 .36029 Mdot
.94578 .36027 Mdot
.94579 .36026 Mdot
.9458 .36024 Mdot
.94581 .36022 Mdot
.94582 .36021 Mdot
.94583 .36019 Mdot
.94584 .36018 Mdot
.94585 .36016 Mdot
.94586 .36014 Mdot
.94587 .36013 Mdot
.94588 .36011 Mdot
.94589 .36009 Mdot
.9459 .36008 Mdot
.9459 .36006 Mdot
.94591 .36005 Mdot
.94592 .36003 Mdot
.94593 .36001 Mdot
.94594 .36 Mdot
.94595 .35998 Mdot
.94596 .35997 Mdot
.94597 .35995 Mdot
.94598 .35993 Mdot
.94599 .35992 Mdot
.946 .3599 Mdot
.94601 .35988 Mdot
.94602 .35987 Mdot
.94603 .35985 Mdot
.94604 .35984 Mdot
.94605 .35982 Mdot
.94606 .3598 Mdot
.94607 .35979 Mdot
.94608 .35977 Mdot
.94609 .35975 Mdot
.9461 .35974 Mdot
.9461 .35972 Mdot
.94611 .35971 Mdot
.94612 .35969 Mdot
.94613 .35967 Mdot
.94614 .35966 Mdot
.94615 .35964 Mdot
.94616 .35962 Mdot
.94617 .35961 Mdot
.94618 .35959 Mdot
.94619 .35958 Mdot
.9462 .35956 Mdot
.94621 .35954 Mdot
.94622 .35953 Mdot
.94623 .35951 Mdot
.94624 .35949 Mdot
.94625 .35948 Mdot
.94626 .35946 Mdot
.94627 .35945 Mdot
.94628 .35943 Mdot
.94629 .35941 Mdot
.9463 .3594 Mdot
.9463 .35938 Mdot
.94631 .35936 Mdot
.94632 .35935 Mdot
.94633 .35933 Mdot
.94634 .35932 Mdot
.94635 .3593 Mdot
.94636 .35928 Mdot
.94637 .35927 Mdot
.94638 .35925 Mdot
.94639 .35923 Mdot
.9464 .35922 Mdot
.94641 .3592 Mdot
.94642 .35919 Mdot
.94643 .35917 Mdot
.94644 .35915 Mdot
.94645 .35914 Mdot
.94646 .35912 Mdot
.94647 .3591 Mdot
.94648 .35909 Mdot
.94649 .35907 Mdot
.9465 .35906 Mdot
.9465 .35904 Mdot
.94651 .35902 Mdot
.94652 .35901 Mdot
.94653 .35899 Mdot
.94654 .35897 Mdot
.94655 .35896 Mdot
.94656 .35894 Mdot
.94657 .35893 Mdot
.94658 .35891 Mdot
.94659 .35889 Mdot
.9466 .35888 Mdot
.94661 .35886 Mdot
.94662 .35884 Mdot
.94663 .35883 Mdot
.94664 .35881 Mdot
.94665 .3588 Mdot
.94666 .35878 Mdot
.94667 .35876 Mdot
.94668 .35875 Mdot
.94669 .35873 Mdot
.9467 .35871 Mdot
.9467 .3587 Mdot
.94671 .35868 Mdot
.94672 .35867 Mdot
.94673 .35865 Mdot
.94674 .35863 Mdot
.94675 .35862 Mdot
.94676 .3586 Mdot
.94677 .35858 Mdot
.94678 .35857 Mdot
.94679 .35855 Mdot
.9468 .35854 Mdot
.94681 .35852 Mdot
.94682 .3585 Mdot
.94683 .35849 Mdot
.94684 .35847 Mdot
.94685 .35845 Mdot
.94686 .35844 Mdot
.94687 .35842 Mdot
.94688 .35841 Mdot
.94689 .35839 Mdot
.9469 .35837 Mdot
.9469 .35836 Mdot
.94691 .35834 Mdot
.94692 .35832 Mdot
.94693 .35831 Mdot
.94694 .35829 Mdot
.94695 .35828 Mdot
.94696 .35826 Mdot
.94697 .35824 Mdot
.94698 .35823 Mdot
.94699 .35821 Mdot
.947 .35819 Mdot
.94701 .35818 Mdot
.94702 .35816 Mdot
.94703 .35815 Mdot
.94704 .35813 Mdot
.94705 .35811 Mdot
.94706 .3581 Mdot
.94707 .35808 Mdot
.94708 .35806 Mdot
.94709 .35805 Mdot
.9471 .35803 Mdot
.9471 .35802 Mdot
.94711 .358 Mdot
.94712 .35798 Mdot
.94713 .35797 Mdot
.94714 .35795 Mdot
.94715 .35793 Mdot
.94716 .35792 Mdot
.94717 .3579 Mdot
.94718 .35789 Mdot
.94719 .35787 Mdot
.9472 .35785 Mdot
.94721 .35784 Mdot
.94722 .35782 Mdot
.94723 .3578 Mdot
.94724 .35779 Mdot
.94725 .35777 Mdot
.94726 .35776 Mdot
.94727 .35774 Mdot
.94728 .35772 Mdot
.94729 .35771 Mdot
.9473 .35769 Mdot
.9473 .35767 Mdot
.94731 .35766 Mdot
.94732 .35764 Mdot
.94733 .35763 Mdot
.94734 .35761 Mdot
.94735 .35759 Mdot
.94736 .35758 Mdot
.94737 .35756 Mdot
.94738 .35754 Mdot
.94739 .35753 Mdot
.9474 .35751 Mdot
.94741 .3575 Mdot
.94742 .35748 Mdot
.94743 .35746 Mdot
.94744 .35745 Mdot
.94745 .35743 Mdot
.94746 .35741 Mdot
.94747 .3574 Mdot
.94748 .35738 Mdot
.94749 .35737 Mdot
.9475 .35735 Mdot
.9475 .35733 Mdot
.94751 .35732 Mdot
.94752 .3573 Mdot
.94753 .35728 Mdot
.94754 .35727 Mdot
.94755 .35725 Mdot
.94756 .35724 Mdot
.94757 .35722 Mdot
.94758 .3572 Mdot
.94759 .35719 Mdot
.9476 .35717 Mdot
.94761 .35715 Mdot
.94762 .35714 Mdot
.94763 .35712 Mdot
.94764 .35711 Mdot
.94765 .35709 Mdot
.94766 .35707 Mdot
.94767 .35706 Mdot
.94768 .35704 Mdot
.94769 .35702 Mdot
.9477 .35701 Mdot
.9477 .35699 Mdot
.94771 .35698 Mdot
.94772 .35696 Mdot
.94773 .35694 Mdot
.94774 .35693 Mdot
.94775 .35691 Mdot
.94776 .35689 Mdot
.94777 .35688 Mdot
.94778 .35686 Mdot
.94779 .35685 Mdot
.9478 .35683 Mdot
.94781 .35681 Mdot
.94782 .3568 Mdot
.94783 .35678 Mdot
.94784 .35676 Mdot
.94785 .35675 Mdot
.94786 .35673 Mdot
.94787 .35672 Mdot
.94788 .3567 Mdot
.94789 .35668 Mdot
.9479 .35667 Mdot
.9479 .35665 Mdot
.94791 .35663 Mdot
.94792 .35662 Mdot
.94793 .3566 Mdot
.94794 .35659 Mdot
.94795 .35657 Mdot
.94796 .35655 Mdot
.94797 .35654 Mdot
.94798 .35652 Mdot
.94799 .3565 Mdot
.948 .35649 Mdot
.94801 .35647 Mdot
.94802 .35645 Mdot
.94803 .35644 Mdot
.94804 .35642 Mdot
.94805 .35641 Mdot
.94806 .35639 Mdot
.94807 .35637 Mdot
.94808 .35636 Mdot
.94809 .35634 Mdot
.9481 .35632 Mdot
.9481 .35631 Mdot
.94811 .35629 Mdot
.94812 .35628 Mdot
.94813 .35626 Mdot
.94814 .35624 Mdot
.94815 .35623 Mdot
.94816 .35621 Mdot
.94817 .35619 Mdot
.94818 .35618 Mdot
.94819 .35616 Mdot
.9482 .35615 Mdot
.94821 .35613 Mdot
.94822 .35611 Mdot
.94823 .3561 Mdot
.94824 .35608 Mdot
.94825 .35606 Mdot
.94826 .35605 Mdot
.94827 .35603 Mdot
.94828 .35602 Mdot
.94829 .356 Mdot
.9483 .35598 Mdot
.9483 .35597 Mdot
.94831 .35595 Mdot
.94832 .35593 Mdot
.94833 .35592 Mdot
.94834 .3559 Mdot
.94835 .35589 Mdot
.94836 .35587 Mdot
.94837 .35585 Mdot
.94838 .35584 Mdot
.94839 .35582 Mdot
.9484 .3558 Mdot
.94841 .35579 Mdot
.94842 .35577 Mdot
.94843 .35576 Mdot
.94844 .35574 Mdot
.94845 .35572 Mdot
.94846 .35571 Mdot
.94847 .35569 Mdot
.94848 .35567 Mdot
.94849 .35566 Mdot
.9485 .35564 Mdot
.9485 .35563 Mdot
.94851 .35561 Mdot
.94852 .35559 Mdot
.94853 .35558 Mdot
.94854 .35556 Mdot
.94855 .35554 Mdot
.94856 .35553 Mdot
.94857 .35551 Mdot
.94858 .3555 Mdot
.94859 .35548 Mdot
.9486 .35546 Mdot
.94861 .35545 Mdot
.94862 .35543 Mdot
.94863 .35541 Mdot
.94864 .3554 Mdot
.94865 .35538 Mdot
.94866 .35536 Mdot
.94867 .35535 Mdot
.94868 .35533 Mdot
.94869 .35532 Mdot
.9487 .3553 Mdot
.9487 .35528 Mdot
.94871 .35527 Mdot
.94872 .35525 Mdot
.94873 .35523 Mdot
.94874 .35522 Mdot
.94875 .3552 Mdot
.94876 .35519 Mdot
.94877 .35517 Mdot
.94878 .35515 Mdot
.94879 .35514 Mdot
.9488 .35512 Mdot
.94881 .3551 Mdot
.94882 .35509 Mdot
.94883 .35507 Mdot
.94884 .35506 Mdot
.94885 .35504 Mdot
.94886 .35502 Mdot
.94887 .35501 Mdot
.94888 .35499 Mdot
.94889 .35497 Mdot
.9489 .35496 Mdot
.9489 .35494 Mdot
.94891 .35493 Mdot
.94892 .35491 Mdot
.94893 .35489 Mdot
.94894 .35488 Mdot
.94895 .35486 Mdot
.94896 .35484 Mdot
.94897 .35483 Mdot
.94898 .35481 Mdot
.94899 .3548 Mdot
.949 .35478 Mdot
.94901 .35476 Mdot
.94902 .35475 Mdot
.94903 .35473 Mdot
.94904 .35471 Mdot
.94905 .3547 Mdot
.94906 .35468 Mdot
.94907 .35466 Mdot
.94908 .35465 Mdot
.94909 .35463 Mdot
.9491 .35462 Mdot
.9491 .3546 Mdot
.94911 .35458 Mdot
.94912 .35457 Mdot
.94913 .35455 Mdot
.94914 .35453 Mdot
.94915 .35452 Mdot
.94916 .3545 Mdot
.94917 .35449 Mdot
.94918 .35447 Mdot
.94919 .35445 Mdot
.9492 .35444 Mdot
.94921 .35442 Mdot
.94922 .3544 Mdot
.94923 .35439 Mdot
.94924 .35437 Mdot
.94925 .35436 Mdot
.94926 .35434 Mdot
.94927 .35432 Mdot
.94928 .35431 Mdot
.94929 .35429 Mdot
.9493 .35427 Mdot
.9493 .35426 Mdot
.94931 .35424 Mdot
.94932 .35423 Mdot
.94933 .35421 Mdot
.94934 .35419 Mdot
.94935 .35418 Mdot
.94936 .35416 Mdot
.94937 .35414 Mdot
.94938 .35413 Mdot
.94939 .35411 Mdot
.9494 .35409 Mdot
.94941 .35408 Mdot
.94942 .35406 Mdot
.94943 .35405 Mdot
.94944 .35403 Mdot
.94945 .35401 Mdot
.94946 .354 Mdot
.94947 .35398 Mdot
.94948 .35396 Mdot
.94949 .35395 Mdot
.9495 .35393 Mdot
.9495 .35392 Mdot
.94951 .3539 Mdot
.94952 .35388 Mdot
.94953 .35387 Mdot
.94954 .35385 Mdot
.94955 .35383 Mdot
.94956 .35382 Mdot
.94957 .3538 Mdot
.94958 .35379 Mdot
.94959 .35377 Mdot
.9496 .35375 Mdot
.94961 .35374 Mdot
.94962 .35372 Mdot
.94963 .3537 Mdot
.94964 .35369 Mdot
.94965 .35367 Mdot
.94966 .35366 Mdot
.94967 .35364 Mdot
.94968 .35362 Mdot
.94969 .35361 Mdot
.9497 .35359 Mdot
.9497 .35357 Mdot
.94971 .35356 Mdot
.94972 .35354 Mdot
.94973 .35352 Mdot
.94974 .35351 Mdot
.94975 .35349 Mdot
.94976 .35348 Mdot
.94977 .35346 Mdot
.94978 .35344 Mdot
.94979 .35343 Mdot
.9498 .35341 Mdot
.94981 .35339 Mdot
.94982 .35338 Mdot
.94983 .35336 Mdot
.94984 .35335 Mdot
.94985 .35333 Mdot
.94986 .35331 Mdot
.94987 .3533 Mdot
.94988 .35328 Mdot
.94989 .35326 Mdot
.9499 .35325 Mdot
.9499 .35323 Mdot
.94991 .35322 Mdot
.94992 .3532 Mdot
.94993 .35318 Mdot
.94994 .35317 Mdot
.94995 .35315 Mdot
.94996 .35313 Mdot
.94997 .35312 Mdot
.94998 .3531 Mdot
.94999 .35308 Mdot
.95 .35307 Mdot
.95001 .35305 Mdot
.95002 .35304 Mdot
.95003 .35302 Mdot
.95004 .353 Mdot
.95005 .35299 Mdot
.95006 .35297 Mdot
.95007 .35295 Mdot
.95008 .35294 Mdot
.95009 .35292 Mdot
.9501 .35291 Mdot
.9501 .35289 Mdot
.95011 .35287 Mdot
.95012 .35286 Mdot
.95013 .35284 Mdot
.95014 .35282 Mdot
.95015 .35281 Mdot
.95016 .35279 Mdot
.95017 .35278 Mdot
.95018 .35276 Mdot
.95019 .35274 Mdot
.9502 .35273 Mdot
.95021 .35271 Mdot
.95022 .35269 Mdot
.95023 .35268 Mdot
.95024 .35266 Mdot
.95025 .35264 Mdot
.95026 .35263 Mdot
.95027 .35261 Mdot
.95028 .3526 Mdot
.95029 .35258 Mdot
.9503 .35256 Mdot
.9503 .35255 Mdot
.95031 .35253 Mdot
.95032 .35251 Mdot
.95033 .3525 Mdot
.95034 .35248 Mdot
.95035 .35247 Mdot
.95036 .35245 Mdot
.95037 .35243 Mdot
.95038 .35242 Mdot
.95039 .3524 Mdot
.9504 .35238 Mdot
.95041 .35237 Mdot
.95042 .35235 Mdot
.95043 .35234 Mdot
.95044 .35232 Mdot
.95045 .3523 Mdot
.95046 .35229 Mdot
.95047 .35227 Mdot
.95048 .35225 Mdot
.95049 .35224 Mdot
.9505 .35222 Mdot
.9505 .3522 Mdot
.95051 .35219 Mdot
.95052 .35217 Mdot
.95053 .35216 Mdot
.95054 .35214 Mdot
.95055 .35212 Mdot
.95056 .35211 Mdot
.95057 .35209 Mdot
.95058 .35207 Mdot
.95059 .35206 Mdot
.9506 .35204 Mdot
.95061 .35203 Mdot
.95062 .35201 Mdot
.95063 .35199 Mdot
.95064 .35198 Mdot
.95065 .35196 Mdot
.95066 .35194 Mdot
.95067 .35193 Mdot
.95068 .35191 Mdot
.95069 .3519 Mdot
.9507 .35188 Mdot
.9507 .35186 Mdot
.95071 .35185 Mdot
.95072 .35183 Mdot
.95073 .35181 Mdot
.95074 .3518 Mdot
.95075 .35178 Mdot
.95076 .35176 Mdot
.95077 .35175 Mdot
.95078 .35173 Mdot
.95079 .35172 Mdot
.9508 .3517 Mdot
.95081 .35168 Mdot
.95082 .35167 Mdot
.95083 .35165 Mdot
.95084 .35163 Mdot
.95085 .35162 Mdot
.95086 .3516 Mdot
.95087 .35159 Mdot
.95088 .35157 Mdot
.95089 .35155 Mdot
.9509 .35154 Mdot
.9509 .35152 Mdot
.95091 .3515 Mdot
.95092 .35149 Mdot
.95093 .35147 Mdot
.95094 .35145 Mdot
.95095 .35144 Mdot
.95096 .35142 Mdot
.95097 .35141 Mdot
.95098 .35139 Mdot
.95099 .35137 Mdot
.951 .35136 Mdot
.95101 .35134 Mdot
.95102 .35132 Mdot
.95103 .35131 Mdot
.95104 .35129 Mdot
.95105 .35128 Mdot
.95106 .35126 Mdot
.95107 .35124 Mdot
.95108 .35123 Mdot
.95109 .35121 Mdot
.9511 .35119 Mdot
.9511 .35118 Mdot
.95111 .35116 Mdot
.95112 .35114 Mdot
.95113 .35113 Mdot
.95114 .35111 Mdot
.95115 .3511 Mdot
.95116 .35108 Mdot
.95117 .35106 Mdot
.95118 .35105 Mdot
.95119 .35103 Mdot
.9512 .35101 Mdot
.95121 .351 Mdot
.95122 .35098 Mdot
.95123 .35097 Mdot
.95124 .35095 Mdot
.95125 .35093 Mdot
.95126 .35092 Mdot
.95127 .3509 Mdot
.95128 .35088 Mdot
.95129 .35087 Mdot
.9513 .35085 Mdot
.9513 .35084 Mdot
.95131 .35082 Mdot
.95132 .3508 Mdot
.95133 .35079 Mdot
.95134 .35077 Mdot
.95135 .35075 Mdot
.95136 .35074 Mdot
.95137 .35072 Mdot
.95138 .3507 Mdot
.95139 .35069 Mdot
.9514 .35067 Mdot
.95141 .35066 Mdot
.95142 .35064 Mdot
.95143 .35062 Mdot
.95144 .35061 Mdot
.95145 .35059 Mdot
.95146 .35057 Mdot
.95147 .35056 Mdot
.95148 .35054 Mdot
.95149 .35053 Mdot
.9515 .35051 Mdot
.9515 .35049 Mdot
.95151 .35048 Mdot
.95152 .35046 Mdot
.95153 .35044 Mdot
.95154 .35043 Mdot
.95155 .35041 Mdot
.95156 .35039 Mdot
.95157 .35038 Mdot
.95158 .35036 Mdot
.95159 .35035 Mdot
.9516 .35033 Mdot
.95161 .35031 Mdot
.95162 .3503 Mdot
.95163 .35028 Mdot
.95164 .35026 Mdot
.95165 .35025 Mdot
.95166 .35023 Mdot
.95167 .35022 Mdot
.95168 .3502 Mdot
.95169 .35018 Mdot
.9517 .35017 Mdot
.9517 .35015 Mdot
.95171 .35013 Mdot
.95172 .35012 Mdot
.95173 .3501 Mdot
.95174 .35008 Mdot
.95175 .35007 Mdot
.95176 .35005 Mdot
.95177 .35004 Mdot
.95178 .35002 Mdot
.95179 .35 Mdot
.9518 .34999 Mdot
.95181 .34997 Mdot
.95182 .34995 Mdot
.95183 .34994 Mdot
.95184 .34992 Mdot
.95185 .34991 Mdot
.95186 .34989 Mdot
.95187 .34987 Mdot
.95188 .34986 Mdot
.95189 .34984 Mdot
.9519 .34982 Mdot
.9519 .34981 Mdot
.95191 .34979 Mdot
.95192 .34977 Mdot
.95193 .34976 Mdot
.95194 .34974 Mdot
.95195 .34973 Mdot
.95196 .34971 Mdot
.95197 .34969 Mdot
.95198 .34968 Mdot
.95199 .34966 Mdot
.952 .34964 Mdot
.95201 .34963 Mdot
.95202 .34961 Mdot
.95203 .34959 Mdot
.95204 .34958 Mdot
.95205 .34956 Mdot
.95206 .34955 Mdot
.95207 .34953 Mdot
.95208 .34951 Mdot
.95209 .3495 Mdot
.9521 .34948 Mdot
.9521 .34946 Mdot
.95211 .34945 Mdot
.95212 .34943 Mdot
.95213 .34942 Mdot
.95214 .3494 Mdot
.95215 .34938 Mdot
.95216 .34937 Mdot
.95217 .34935 Mdot
.95218 .34933 Mdot
.95219 .34932 Mdot
.9522 .3493 Mdot
.95221 .34928 Mdot
.95222 .34927 Mdot
.95223 .34925 Mdot
.95224 .34924 Mdot
.95225 .34922 Mdot
.95226 .3492 Mdot
.95227 .34919 Mdot
.95228 .34917 Mdot
.95229 .34915 Mdot
.9523 .34914 Mdot
.9523 .34912 Mdot
.95231 .34911 Mdot
.95232 .34909 Mdot
.95233 .34907 Mdot
.95234 .34906 Mdot
.95235 .34904 Mdot
.95236 .34902 Mdot
.95237 .34901 Mdot
.95238 .34899 Mdot
.95239 .34897 Mdot
.9524 .34896 Mdot
.95241 .34894 Mdot
.95242 .34893 Mdot
.95243 .34891 Mdot
.95244 .34889 Mdot
.95245 .34888 Mdot
.95246 .34886 Mdot
.95247 .34884 Mdot
.95248 .34883 Mdot
.95249 .34881 Mdot
.9525 .3488 Mdot
.9525 .34878 Mdot
.95251 .34876 Mdot
.95252 .34875 Mdot
.95253 .34873 Mdot
.95254 .34871 Mdot
.95255 .3487 Mdot
.95256 .34868 Mdot
.95257 .34866 Mdot
.95258 .34865 Mdot
.95259 .34863 Mdot
.9526 .34862 Mdot
.95261 .3486 Mdot
.95262 .34858 Mdot
.95263 .34857 Mdot
.95264 .34855 Mdot
.95265 .34853 Mdot
.95266 .34852 Mdot
.95267 .3485 Mdot
.95268 .34848 Mdot
.95269 .34847 Mdot
.9527 .34845 Mdot
.9527 .34844 Mdot
.95271 .34842 Mdot
.95272 .3484 Mdot
.95273 .34839 Mdot
.95274 .34837 Mdot
.95275 .34835 Mdot
.95276 .34834 Mdot
.95277 .34832 Mdot
.95278 .34831 Mdot
.95279 .34829 Mdot
.9528 .34827 Mdot
.95281 .34826 Mdot
.95282 .34824 Mdot
.95283 .34822 Mdot
.95284 .34821 Mdot
.95285 .34819 Mdot
.95286 .34817 Mdot
.95287 .34816 Mdot
.95288 .34814 Mdot
.95289 .34813 Mdot
.9529 .34811 Mdot
.9529 .34809 Mdot
.95291 .34808 Mdot
.95292 .34806 Mdot
.95293 .34804 Mdot
.95294 .34803 Mdot
.95295 .34801 Mdot
.95296 .34799 Mdot
.95297 .34798 Mdot
.95298 .34796 Mdot
.95299 .34795 Mdot
.953 .34793 Mdot
.95301 .34791 Mdot
.95302 .3479 Mdot
.95303 .34788 Mdot
.95304 .34786 Mdot
.95305 .34785 Mdot
.95306 .34783 Mdot
.95307 .34782 Mdot
.95308 .3478 Mdot
.95309 .34778 Mdot
.9531 .34777 Mdot
.9531 .34775 Mdot
.95311 .34773 Mdot
.95312 .34772 Mdot
.95313 .3477 Mdot
.95314 .34768 Mdot
.95315 .34767 Mdot
.95316 .34765 Mdot
.95317 .34764 Mdot
.95318 .34762 Mdot
.95319 .3476 Mdot
.9532 .34759 Mdot
.95321 .34757 Mdot
.95322 .34755 Mdot
.95323 .34754 Mdot
.95324 .34752 Mdot
.95325 .3475 Mdot
.95326 .34749 Mdot
.95327 .34747 Mdot
.95328 .34746 Mdot
.95329 .34744 Mdot
.9533 .34742 Mdot
.9533 .34741 Mdot
.95331 .34739 Mdot
.95332 .34737 Mdot
.95333 .34736 Mdot
.95334 .34734 Mdot
.95335 .34733 Mdot
.95336 .34731 Mdot
.95337 .34729 Mdot
.95338 .34728 Mdot
.95339 .34726 Mdot
.9534 .34724 Mdot
.95341 .34723 Mdot
.95342 .34721 Mdot
.95343 .34719 Mdot
.95344 .34718 Mdot
.95345 .34716 Mdot
.95346 .34715 Mdot
.95347 .34713 Mdot
.95348 .34711 Mdot
.95349 .3471 Mdot
.9535 .34708 Mdot
.9535 .34706 Mdot
.95351 .34705 Mdot
.95352 .34703 Mdot
.95353 .34701 Mdot
.95354 .347 Mdot
.95355 .34698 Mdot
.95356 .34697 Mdot
.95357 .34695 Mdot
.95358 .34693 Mdot
.95359 .34692 Mdot
.9536 .3469 Mdot
.95361 .34688 Mdot
.95362 .34687 Mdot
.95363 .34685 Mdot
.95364 .34683 Mdot
.95365 .34682 Mdot
.95366 .3468 Mdot
.95367 .34679 Mdot
.95368 .34677 Mdot
.95369 .34675 Mdot
.9537 .34674 Mdot
.9537 .34672 Mdot
.95371 .3467 Mdot
.95372 .34669 Mdot
.95373 .34667 Mdot
.95374 .34666 Mdot
.95375 .34664 Mdot
.95376 .34662 Mdot
.95377 .34661 Mdot
.95378 .34659 Mdot
.95379 .34657 Mdot
.9538 .34656 Mdot
.95381 .34654 Mdot
.95382 .34652 Mdot
.95383 .34651 Mdot
.95384 .34649 Mdot
.95385 .34648 Mdot
.95386 .34646 Mdot
.95387 .34644 Mdot
.95388 .34643 Mdot
.95389 .34641 Mdot
.9539 .34639 Mdot
.9539 .34638 Mdot
.95391 .34636 Mdot
.95392 .34634 Mdot
.95393 .34633 Mdot
.95394 .34631 Mdot
.95395 .3463 Mdot
.95396 .34628 Mdot
.95397 .34626 Mdot
.95398 .34625 Mdot
.95399 .34623 Mdot
.954 .34621 Mdot
.95401 .3462 Mdot
.95402 .34618 Mdot
.95403 .34616 Mdot
.95404 .34615 Mdot
.95405 .34613 Mdot
.95406 .34612 Mdot
.95407 .3461 Mdot
.95408 .34608 Mdot
.95409 .34607 Mdot
.9541 .34605 Mdot
.9541 .34603 Mdot
.95411 .34602 Mdot
.95412 .346 Mdot
.95413 .34598 Mdot
.95414 .34597 Mdot
.95415 .34595 Mdot
.95416 .34594 Mdot
.95417 .34592 Mdot
.95418 .3459 Mdot
.95419 .34589 Mdot
.9542 .34587 Mdot
.95421 .34585 Mdot
.95422 .34584 Mdot
.95423 .34582 Mdot
.95424 .34581 Mdot
.95425 .34579 Mdot
.95426 .34577 Mdot
.95427 .34576 Mdot
.95428 .34574 Mdot
.95429 .34572 Mdot
.9543 .34571 Mdot
.9543 .34569 Mdot
.95431 .34567 Mdot
.95432 .34566 Mdot
.95433 .34564 Mdot
.95434 .34563 Mdot
.95435 .34561 Mdot
.95436 .34559 Mdot
.95437 .34558 Mdot
.95438 .34556 Mdot
.95439 .34554 Mdot
.9544 .34553 Mdot
.95441 .34551 Mdot
.95442 .34549 Mdot
.95443 .34548 Mdot
.95444 .34546 Mdot
.95445 .34545 Mdot
.95446 .34543 Mdot
.95447 .34541 Mdot
.95448 .3454 Mdot
.95449 .34538 Mdot
.9545 .34536 Mdot
.9545 .34535 Mdot
.95451 .34533 Mdot
.95452 .34531 Mdot
.95453 .3453 Mdot
.95454 .34528 Mdot
.95455 .34527 Mdot
.95456 .34525 Mdot
.95457 .34523 Mdot
.95458 .34522 Mdot
.95459 .3452 Mdot
.9546 .34518 Mdot
.95461 .34517 Mdot
.95462 .34515 Mdot
.95463 .34513 Mdot
.95464 .34512 Mdot
.95465 .3451 Mdot
.95466 .34509 Mdot
.95467 .34507 Mdot
.95468 .34505 Mdot
.95469 .34504 Mdot
.9547 .34502 Mdot
.9547 .345 Mdot
.95471 .34499 Mdot
.95472 .34497 Mdot
.95473 .34495 Mdot
.95474 .34494 Mdot
.95475 .34492 Mdot
.95476 .34491 Mdot
.95477 .34489 Mdot
.95478 .34487 Mdot
.95479 .34486 Mdot
.9548 .34484 Mdot
.95481 .34482 Mdot
.95482 .34481 Mdot
.95483 .34479 Mdot
.95484 .34477 Mdot
.95485 .34476 Mdot
.95486 .34474 Mdot
.95487 .34473 Mdot
.95488 .34471 Mdot
.95489 .34469 Mdot
.9549 .34468 Mdot
.9549 .34466 Mdot
.95491 .34464 Mdot
.95492 .34463 Mdot
.95493 .34461 Mdot
.95494 .34459 Mdot
.95495 .34458 Mdot
.95496 .34456 Mdot
.95497 .34455 Mdot
.95498 .34453 Mdot
.95499 .34451 Mdot
.955 .3445 Mdot
.95501 .34448 Mdot
.95502 .34446 Mdot
.95503 .34445 Mdot
.95504 .34443 Mdot
.95505 .34442 Mdot
.95506 .3444 Mdot
.95507 .34438 Mdot
.95508 .34437 Mdot
.95509 .34435 Mdot
.9551 .34433 Mdot
.9551 .34432 Mdot
.95511 .3443 Mdot
.95512 .34428 Mdot
.95513 .34427 Mdot
.95514 .34425 Mdot
.95515 .34424 Mdot
.95516 .34422 Mdot
.95517 .3442 Mdot
.95518 .34419 Mdot
.95519 .34417 Mdot
.9552 .34415 Mdot
.95521 .34414 Mdot
.95522 .34412 Mdot
.95523 .3441 Mdot
.95524 .34409 Mdot
.95525 .34407 Mdot
.95526 .34406 Mdot
.95527 .34404 Mdot
.95528 .34402 Mdot
.95529 .34401 Mdot
.9553 .34399 Mdot
.9553 .34397 Mdot
.95531 .34396 Mdot
.95532 .34394 Mdot
.95533 .34392 Mdot
.95534 .34391 Mdot
.95535 .34389 Mdot
.95536 .34388 Mdot
.95537 .34386 Mdot
.95538 .34384 Mdot
.95539 .34383 Mdot
.9554 .34381 Mdot
.95541 .34379 Mdot
.95542 .34378 Mdot
.95543 .34376 Mdot
.95544 .34374 Mdot
.95545 .34373 Mdot
.95546 .34371 Mdot
.95547 .3437 Mdot
.95548 .34368 Mdot
.95549 .34366 Mdot
.9555 .34365 Mdot
.9555 .34363 Mdot
.95551 .34361 Mdot
.95552 .3436 Mdot
.95553 .34358 Mdot
.95554 .34356 Mdot
.95555 .34355 Mdot
.95556 .34353 Mdot
.95557 .34352 Mdot
.95558 .3435 Mdot
.95559 .34348 Mdot
.9556 .34347 Mdot
.95561 .34345 Mdot
.95562 .34343 Mdot
.95563 .34342 Mdot
.95564 .3434 Mdot
.95565 .34338 Mdot
.95566 .34337 Mdot
.95567 .34335 Mdot
.95568 .34334 Mdot
.95569 .34332 Mdot
.9557 .3433 Mdot
.9557 .34329 Mdot
.95571 .34327 Mdot
.95572 .34325 Mdot
.95573 .34324 Mdot
.95574 .34322 Mdot
.95575 .3432 Mdot
.95576 .34319 Mdot
.95577 .34317 Mdot
.95578 .34316 Mdot
.95579 .34314 Mdot
.9558 .34312 Mdot
.95581 .34311 Mdot
.95582 .34309 Mdot
.95583 .34307 Mdot
.95584 .34306 Mdot
.95585 .34304 Mdot
.95586 .34302 Mdot
.95587 .34301 Mdot
.95588 .34299 Mdot
.95589 .34298 Mdot
.9559 .34296 Mdot
.9559 .34294 Mdot
.95591 .34293 Mdot
.95592 .34291 Mdot
.95593 .34289 Mdot
.95594 .34288 Mdot
.95595 .34286 Mdot
.95596 .34284 Mdot
.95597 .34283 Mdot
.95598 .34281 Mdot
.95599 .3428 Mdot
.956 .34278 Mdot
.95601 .34276 Mdot
.95602 .34275 Mdot
.95603 .34273 Mdot
.95604 .34271 Mdot
.95605 .3427 Mdot
.95606 .34268 Mdot
.95607 .34266 Mdot
.95608 .34265 Mdot
.95609 .34263 Mdot
.9561 .34261 Mdot
.9561 .3426 Mdot
.95611 .34258 Mdot
.95612 .34257 Mdot
.95613 .34255 Mdot
.95614 .34253 Mdot
.95615 .34252 Mdot
.95616 .3425 Mdot
.95617 .34248 Mdot
.95618 .34247 Mdot
.95619 .34245 Mdot
.9562 .34243 Mdot
.95621 .34242 Mdot
.95622 .3424 Mdot
.95623 .34239 Mdot
.95624 .34237 Mdot
.95625 .34235 Mdot
.95626 .34234 Mdot
.95627 .34232 Mdot
.95628 .3423 Mdot
.95629 .34229 Mdot
.9563 .34227 Mdot
.9563 .34225 Mdot
.95631 .34224 Mdot
.95632 .34222 Mdot
.95633 .34221 Mdot
.95634 .34219 Mdot
.95635 .34217 Mdot
.95636 .34216 Mdot
.95637 .34214 Mdot
.95638 .34212 Mdot
.95639 .34211 Mdot
.9564 .34209 Mdot
.95641 .34207 Mdot
.95642 .34206 Mdot
.95643 .34204 Mdot
.95644 .34203 Mdot
.95645 .34201 Mdot
.95646 .34199 Mdot
.95647 .34198 Mdot
.95648 .34196 Mdot
.95649 .34194 Mdot
.9565 .34193 Mdot
.9565 .34191 Mdot
.95651 .34189 Mdot
.95652 .34188 Mdot
.95653 .34186 Mdot
.95654 .34185 Mdot
.95655 .34183 Mdot
.95656 .34181 Mdot
.95657 .3418 Mdot
.95658 .34178 Mdot
.95659 .34176 Mdot
.9566 .34175 Mdot
.95661 .34173 Mdot
.95662 .34171 Mdot
.95663 .3417 Mdot
.95664 .34168 Mdot
.95665 .34167 Mdot
.95666 .34165 Mdot
.95667 .34163 Mdot
.95668 .34162 Mdot
.95669 .3416 Mdot
.9567 .34158 Mdot
.9567 .34157 Mdot
.95671 .34155 Mdot
.95672 .34153 Mdot
.95673 .34152 Mdot
.95674 .3415 Mdot
.95675 .34149 Mdot
.95676 .34147 Mdot
.95677 .34145 Mdot
.95678 .34144 Mdot
.95679 .34142 Mdot
.9568 .3414 Mdot
.95681 .34139 Mdot
.95682 .34137 Mdot
.95683 .34135 Mdot
.95684 .34134 Mdot
.95685 .34132 Mdot
.95686 .34131 Mdot
.95687 .34129 Mdot
.95688 .34127 Mdot
.95689 .34126 Mdot
.9569 .34124 Mdot
.9569 .34122 Mdot
.95691 .34121 Mdot
.95692 .34119 Mdot
.95693 .34117 Mdot
.95694 .34116 Mdot
.95695 .34114 Mdot
.95696 .34112 Mdot
.95697 .34111 Mdot
.95698 .34109 Mdot
.95699 .34108 Mdot
.957 .34106 Mdot
.95701 .34104 Mdot
.95702 .34103 Mdot
.95703 .34101 Mdot
.95704 .34099 Mdot
.95705 .34098 Mdot
.95706 .34096 Mdot
.95707 .34094 Mdot
.95708 .34093 Mdot
.95709 .34091 Mdot
.9571 .3409 Mdot
.9571 .34088 Mdot
.95711 .34086 Mdot
.95712 .34085 Mdot
.95713 .34083 Mdot
.95714 .34081 Mdot
.95715 .3408 Mdot
.95716 .34078 Mdot
.95717 .34076 Mdot
.95718 .34075 Mdot
.95719 .34073 Mdot
.9572 .34072 Mdot
.95721 .3407 Mdot
.95722 .34068 Mdot
.95723 .34067 Mdot
.95724 .34065 Mdot
.95725 .34063 Mdot
.95726 .34062 Mdot
.95727 .3406 Mdot
.95728 .34058 Mdot
.95729 .34057 Mdot
.9573 .34055 Mdot
.9573 .34054 Mdot
.95731 .34052 Mdot
.95732 .3405 Mdot
.95733 .34049 Mdot
.95734 .34047 Mdot
.95735 .34045 Mdot
.95736 .34044 Mdot
.95737 .34042 Mdot
.95738 .3404 Mdot
.95739 .34039 Mdot
.9574 .34037 Mdot
.95741 .34035 Mdot
.95742 .34034 Mdot
.95743 .34032 Mdot
.95744 .34031 Mdot
.95745 .34029 Mdot
.95746 .34027 Mdot
.95747 .34026 Mdot
.95748 .34024 Mdot
.95749 .34022 Mdot
.9575 .34021 Mdot
.9575 .34019 Mdot
.95751 .34017 Mdot
.95752 .34016 Mdot
.95753 .34014 Mdot
.95754 .34013 Mdot
.95755 .34011 Mdot
.95756 .34009 Mdot
.95757 .34008 Mdot
.95758 .34006 Mdot
.95759 .34004 Mdot
.9576 .34003 Mdot
.95761 .34001 Mdot
.95762 .33999 Mdot
.95763 .33998 Mdot
.95764 .33996 Mdot
.95765 .33995 Mdot
.95766 .33993 Mdot
.95767 .33991 Mdot
.95768 .3399 Mdot
.95769 .33988 Mdot
.9577 .33986 Mdot
.9577 .33985 Mdot
.95771 .33983 Mdot
.95772 .33981 Mdot
.95773 .3398 Mdot
.95774 .33978 Mdot
.95775 .33977 Mdot
.95776 .33975 Mdot
.95777 .33973 Mdot
.95778 .33972 Mdot
.95779 .3397 Mdot
.9578 .33968 Mdot
.95781 .33967 Mdot
.95782 .33965 Mdot
.95783 .33963 Mdot
.95784 .33962 Mdot
.95785 .3396 Mdot
.95786 .33958 Mdot
.95787 .33957 Mdot
.95788 .33955 Mdot
.95789 .33954 Mdot
.9579 .33952 Mdot
.9579 .3395 Mdot
.95791 .33949 Mdot
.95792 .33947 Mdot
.95793 .33945 Mdot
.95794 .33944 Mdot
.95795 .33942 Mdot
.95796 .3394 Mdot
.95797 .33939 Mdot
.95798 .33937 Mdot
.95799 .33936 Mdot
.958 .33934 Mdot
.95801 .33932 Mdot
.95802 .33931 Mdot
.95803 .33929 Mdot
.95804 .33927 Mdot
.95805 .33926 Mdot
.95806 .33924 Mdot
.95807 .33922 Mdot
.95808 .33921 Mdot
.95809 .33919 Mdot
.9581 .33918 Mdot
.9581 .33916 Mdot
.95811 .33914 Mdot
.95812 .33913 Mdot
.95813 .33911 Mdot
.95814 .33909 Mdot
.95815 .33908 Mdot
.95816 .33906 Mdot
.95817 .33904 Mdot
.95818 .33903 Mdot
.95819 .33901 Mdot
.9582 .33899 Mdot
.95821 .33898 Mdot
.95822 .33896 Mdot
.95823 .33895 Mdot
.95824 .33893 Mdot
.95825 .33891 Mdot
.95826 .3389 Mdot
.95827 .33888 Mdot
.95828 .33886 Mdot
.95829 .33885 Mdot
.9583 .33883 Mdot
.9583 .33881 Mdot
.95831 .3388 Mdot
.95832 .33878 Mdot
.95833 .33877 Mdot
.95834 .33875 Mdot
.95835 .33873 Mdot
.95836 .33872 Mdot
.95837 .3387 Mdot
.95838 .33868 Mdot
.95839 .33867 Mdot
.9584 .33865 Mdot
.95841 .33863 Mdot
.95842 .33862 Mdot
.95843 .3386 Mdot
.95844 .33859 Mdot
.95845 .33857 Mdot
.95846 .33855 Mdot
.95847 .33854 Mdot
.95848 .33852 Mdot
.95849 .3385 Mdot
.9585 .33849 Mdot
.9585 .33847 Mdot
.95851 .33845 Mdot
.95852 .33844 Mdot
.95853 .33842 Mdot
.95854 .3384 Mdot
.95855 .33839 Mdot
.95856 .33837 Mdot
.95857 .33836 Mdot
.95858 .33834 Mdot
.95859 .33832 Mdot
.9586 .33831 Mdot
.95861 .33829 Mdot
.95862 .33827 Mdot
.95863 .33826 Mdot
.95864 .33824 Mdot
.95865 .33822 Mdot
.95866 .33821 Mdot
.95867 .33819 Mdot
.95868 .33818 Mdot
.95869 .33816 Mdot
.9587 .33814 Mdot
.9587 .33813 Mdot
.95871 .33811 Mdot
.95872 .33809 Mdot
.95873 .33808 Mdot
.95874 .33806 Mdot
.95875 .33804 Mdot
.95876 .33803 Mdot
.95877 .33801 Mdot
.95878 .33799 Mdot
.95879 .33798 Mdot
.9588 .33796 Mdot
.95881 .33795 Mdot
.95882 .33793 Mdot
.95883 .33791 Mdot
.95884 .3379 Mdot
.95885 .33788 Mdot
.95886 .33786 Mdot
.95887 .33785 Mdot
.95888 .33783 Mdot
.95889 .33781 Mdot
.9589 .3378 Mdot
.9589 .33778 Mdot
.95891 .33777 Mdot
.95892 .33775 Mdot
.95893 .33773 Mdot
.95894 .33772 Mdot
.95895 .3377 Mdot
.95896 .33768 Mdot
.95897 .33767 Mdot
.95898 .33765 Mdot
.95899 .33763 Mdot
.959 .33762 Mdot
.95901 .3376 Mdot
.95902 .33758 Mdot
.95903 .33757 Mdot
.95904 .33755 Mdot
.95905 .33754 Mdot
.95906 .33752 Mdot
.95907 .3375 Mdot
.95908 .33749 Mdot
.95909 .33747 Mdot
.9591 .33745 Mdot
.9591 .33744 Mdot
.95911 .33742 Mdot
.95912 .3374 Mdot
.95913 .33739 Mdot
.95914 .33737 Mdot
.95915 .33736 Mdot
.95916 .33734 Mdot
.95917 .33732 Mdot
.95918 .33731 Mdot
.95919 .33729 Mdot
.9592 .33727 Mdot
.95921 .33726 Mdot
.95922 .33724 Mdot
.95923 .33722 Mdot
.95924 .33721 Mdot
.95925 .33719 Mdot
.95926 .33717 Mdot
.95927 .33716 Mdot
.95928 .33714 Mdot
.95929 .33713 Mdot
.9593 .33711 Mdot
.9593 .33709 Mdot
.95931 .33708 Mdot
.95932 .33706 Mdot
.95933 .33704 Mdot
.95934 .33703 Mdot
.95935 .33701 Mdot
.95936 .33699 Mdot
.95937 .33698 Mdot
.95938 .33696 Mdot
.95939 .33695 Mdot
.9594 .33693 Mdot
.95941 .33691 Mdot
.95942 .3369 Mdot
.95943 .33688 Mdot
.95944 .33686 Mdot
.95945 .33685 Mdot
.95946 .33683 Mdot
.95947 .33681 Mdot
.95948 .3368 Mdot
.95949 .33678 Mdot
.9595 .33676 Mdot
.9595 .33675 Mdot
.95951 .33673 Mdot
.95952 .33672 Mdot
.95953 .3367 Mdot
.95954 .33668 Mdot
.95955 .33667 Mdot
.95956 .33665 Mdot
.95957 .33663 Mdot
.95958 .33662 Mdot
.95959 .3366 Mdot
.9596 .33658 Mdot
.95961 .33657 Mdot
.95962 .33655 Mdot
.95963 .33654 Mdot
.95964 .33652 Mdot
.95965 .3365 Mdot
.95966 .33649 Mdot
.95967 .33647 Mdot
.95968 .33645 Mdot
.95969 .33644 Mdot
.9597 .33642 Mdot
.9597 .3364 Mdot
.95971 .33639 Mdot
.95972 .33637 Mdot
.95973 .33635 Mdot
.95974 .33634 Mdot
.95975 .33632 Mdot
.95976 .33631 Mdot
.95977 .33629 Mdot
.95978 .33627 Mdot
.95979 .33626 Mdot
.9598 .33624 Mdot
.95981 .33622 Mdot
.95982 .33621 Mdot
.95983 .33619 Mdot
.95984 .33617 Mdot
.95985 .33616 Mdot
.95986 .33614 Mdot
.95987 .33613 Mdot
.95988 .33611 Mdot
.95989 .33609 Mdot
.9599 .33608 Mdot
.9599 .33606 Mdot
.95991 .33604 Mdot
.95992 .33603 Mdot
.95993 .33601 Mdot
.95994 .33599 Mdot
.95995 .33598 Mdot
.95996 .33596 Mdot
.95997 .33594 Mdot
.95998 .33593 Mdot
.95999 .33591 Mdot
.96 .3359 Mdot
.96001 .33588 Mdot
.96002 .33586 Mdot
.96003 .33585 Mdot
.96004 .33583 Mdot
.96005 .33581 Mdot
.96006 .3358 Mdot
.96007 .33578 Mdot
.96008 .33576 Mdot
.96009 .33575 Mdot
.9601 .33573 Mdot
.9601 .33571 Mdot
.96011 .3357 Mdot
.96012 .33568 Mdot
.96013 .33567 Mdot
.96014 .33565 Mdot
.96015 .33563 Mdot
.96016 .33562 Mdot
.96017 .3356 Mdot
.96018 .33558 Mdot
.96019 .33557 Mdot
.9602 .33555 Mdot
.96021 .33553 Mdot
.96022 .33552 Mdot
.96023 .3355 Mdot
.96024 .33549 Mdot
.96025 .33547 Mdot
.96026 .33545 Mdot
.96027 .33544 Mdot
.96028 .33542 Mdot
.96029 .3354 Mdot
.9603 .33539 Mdot
.9603 .33537 Mdot
.96031 .33535 Mdot
.96032 .33534 Mdot
.96033 .33532 Mdot
.96034 .3353 Mdot
.96035 .33529 Mdot
.96036 .33527 Mdot
.96037 .33526 Mdot
.96038 .33524 Mdot
.96039 .33522 Mdot
.9604 .33521 Mdot
.96041 .33519 Mdot
.96042 .33517 Mdot
.96043 .33516 Mdot
.96044 .33514 Mdot
.96045 .33512 Mdot
.96046 .33511 Mdot
.96047 .33509 Mdot
.96048 .33507 Mdot
.96049 .33506 Mdot
.9605 .33504 Mdot
.9605 .33503 Mdot
.96051 .33501 Mdot
.96052 .33499 Mdot
.96053 .33498 Mdot
.96054 .33496 Mdot
.96055 .33494 Mdot
.96056 .33493 Mdot
.96057 .33491 Mdot
.96058 .33489 Mdot
.96059 .33488 Mdot
.9606 .33486 Mdot
.96061 .33485 Mdot
.96062 .33483 Mdot
.96063 .33481 Mdot
.96064 .3348 Mdot
.96065 .33478 Mdot
.96066 .33476 Mdot
.96067 .33475 Mdot
.96068 .33473 Mdot
.96069 .33471 Mdot
.9607 .3347 Mdot
.9607 .33468 Mdot
.96071 .33466 Mdot
.96072 .33465 Mdot
.96073 .33463 Mdot
.96074 .33462 Mdot
.96075 .3346 Mdot
.96076 .33458 Mdot
.96077 .33457 Mdot
.96078 .33455 Mdot
.96079 .33453 Mdot
.9608 .33452 Mdot
.96081 .3345 Mdot
.96082 .33448 Mdot
.96083 .33447 Mdot
.96084 .33445 Mdot
.96085 .33443 Mdot
.96086 .33442 Mdot
.96087 .3344 Mdot
.96088 .33439 Mdot
.96089 .33437 Mdot
.9609 .33435 Mdot
.9609 .33434 Mdot
.96091 .33432 Mdot
.96092 .3343 Mdot
.96093 .33429 Mdot
.96094 .33427 Mdot
.96095 .33425 Mdot
.96096 .33424 Mdot
.96097 .33422 Mdot
.96098 .3342 Mdot
.96099 .33419 Mdot
.961 .33417 Mdot
.96101 .33416 Mdot
.96102 .33414 Mdot
.96103 .33412 Mdot
.96104 .33411 Mdot
.96105 .33409 Mdot
.96106 .33407 Mdot
.96107 .33406 Mdot
.96108 .33404 Mdot
.96109 .33402 Mdot
.9611 .33401 Mdot
.9611 .33399 Mdot
.96111 .33398 Mdot
.96112 .33396 Mdot
.96113 .33394 Mdot
.96114 .33393 Mdot
.96115 .33391 Mdot
.96116 .33389 Mdot
.96117 .33388 Mdot
.96118 .33386 Mdot
.96119 .33384 Mdot
.9612 .33383 Mdot
.96121 .33381 Mdot
.96122 .33379 Mdot
.96123 .33378 Mdot
.96124 .33376 Mdot
.96125 .33375 Mdot
.96126 .33373 Mdot
.96127 .33371 Mdot
.96128 .3337 Mdot
.96129 .33368 Mdot
.9613 .33366 Mdot
.9613 .33365 Mdot
.96131 .33363 Mdot
.96132 .33361 Mdot
.96133 .3336 Mdot
.96134 .33358 Mdot
.96135 .33356 Mdot
.96136 .33355 Mdot
.96137 .33353 Mdot
.96138 .33352 Mdot
.96139 .3335 Mdot
.9614 .33348 Mdot
.96141 .33347 Mdot
.96142 .33345 Mdot
.96143 .33343 Mdot
.96144 .33342 Mdot
.96145 .3334 Mdot
.96146 .33338 Mdot
.96147 .33337 Mdot
.96148 .33335 Mdot
.96149 .33333 Mdot
.9615 .33332 Mdot
.9615 .3333 Mdot
.96151 .33329 Mdot
.96152 .33327 Mdot
.96153 .33325 Mdot
.96154 .33324 Mdot
.96155 .33322 Mdot
.96156 .3332 Mdot
.96157 .33319 Mdot
.96158 .33317 Mdot
.96159 .33315 Mdot
.9616 .33314 Mdot
.96161 .33312 Mdot
.96162 .3331 Mdot
.96163 .33309 Mdot
.96164 .33307 Mdot
.96165 .33306 Mdot
.96166 .33304 Mdot
.96167 .33302 Mdot
.96168 .33301 Mdot
.96169 .33299 Mdot
.9617 .33297 Mdot
.9617 .33296 Mdot
.96171 .33294 Mdot
.96172 .33292 Mdot
.96173 .33291 Mdot
.96174 .33289 Mdot
.96175 .33288 Mdot
.96176 .33286 Mdot
.96177 .33284 Mdot
.96178 .33283 Mdot
.96179 .33281 Mdot
.9618 .33279 Mdot
.96181 .33278 Mdot
.96182 .33276 Mdot
.96183 .33274 Mdot
.96184 .33273 Mdot
.96185 .33271 Mdot
.96186 .33269 Mdot
.96187 .33268 Mdot
.96188 .33266 Mdot
.96189 .33265 Mdot
.9619 .33263 Mdot
.9619 .33261 Mdot
.96191 .3326 Mdot
.96192 .33258 Mdot
.96193 .33256 Mdot
.96194 .33255 Mdot
.96195 .33253 Mdot
.96196 .33251 Mdot
.96197 .3325 Mdot
.96198 .33248 Mdot
.96199 .33246 Mdot
.962 .33245 Mdot
.96201 .33243 Mdot
.96202 .33242 Mdot
.96203 .3324 Mdot
.96204 .33238 Mdot
.96205 .33237 Mdot
.96206 .33235 Mdot
.96207 .33233 Mdot
.96208 .33232 Mdot
.96209 .3323 Mdot
.9621 .33228 Mdot
.9621 .33227 Mdot
.96211 .33225 Mdot
.96212 .33223 Mdot
.96213 .33222 Mdot
.96214 .3322 Mdot
.96215 .33219 Mdot
.96216 .33217 Mdot
.96217 .33215 Mdot
.96218 .33214 Mdot
.96219 .33212 Mdot
.9622 .3321 Mdot
.96221 .33209 Mdot
.96222 .33207 Mdot
.96223 .33205 Mdot
.96224 .33204 Mdot
.96225 .33202 Mdot
.96226 .332 Mdot
.96227 .33199 Mdot
.96228 .33197 Mdot
.96229 .33196 Mdot
.9623 .33194 Mdot
.9623 .33192 Mdot
.96231 .33191 Mdot
.96232 .33189 Mdot
.96233 .33187 Mdot
.96234 .33186 Mdot
.96235 .33184 Mdot
.96236 .33182 Mdot
.96237 .33181 Mdot
.96238 .33179 Mdot
.96239 .33177 Mdot
.9624 .33176 Mdot
.96241 .33174 Mdot
.96242 .33173 Mdot
.96243 .33171 Mdot
.96244 .33169 Mdot
.96245 .33168 Mdot
.96246 .33166 Mdot
.96247 .33164 Mdot
.96248 .33163 Mdot
.96249 .33161 Mdot
.9625 .33159 Mdot
.9625 .33158 Mdot
.96251 .33156 Mdot
.96252 .33154 Mdot
.96253 .33153 Mdot
.96254 .33151 Mdot
.96255 .3315 Mdot
.96256 .33148 Mdot
.96257 .33146 Mdot
.96258 .33145 Mdot
.96259 .33143 Mdot
.9626 .33141 Mdot
.96261 .3314 Mdot
.96262 .33138 Mdot
.96263 .33136 Mdot
.96264 .33135 Mdot
.96265 .33133 Mdot
.96266 .33131 Mdot
.96267 .3313 Mdot
.96268 .33128 Mdot
.96269 .33127 Mdot
.9627 .33125 Mdot
.9627 .33123 Mdot
.96271 .33122 Mdot
.96272 .3312 Mdot
.96273 .33118 Mdot
.96274 .33117 Mdot
.96275 .33115 Mdot
.96276 .33113 Mdot
.96277 .33112 Mdot
.96278 .3311 Mdot
.96279 .33108 Mdot
.9628 .33107 Mdot
.96281 .33105 Mdot
.96282 .33104 Mdot
.96283 .33102 Mdot
.96284 .331 Mdot
.96285 .33099 Mdot
.96286 .33097 Mdot
.96287 .33095 Mdot
.96288 .33094 Mdot
.96289 .33092 Mdot
.9629 .3309 Mdot
.9629 .33089 Mdot
.96291 .33087 Mdot
.96292 .33085 Mdot
.96293 .33084 Mdot
.96294 .33082 Mdot
.96295 .33081 Mdot
.96296 .33079 Mdot
.96297 .33077 Mdot
.96298 .33076 Mdot
.96299 .33074 Mdot
.963 .33072 Mdot
.96301 .33071 Mdot
.96302 .33069 Mdot
.96303 .33067 Mdot
.96304 .33066 Mdot
.96305 .33064 Mdot
.96306 .33062 Mdot
.96307 .33061 Mdot
.96308 .33059 Mdot
.96309 .33058 Mdot
.9631 .33056 Mdot
.9631 .33054 Mdot
.96311 .33053 Mdot
.96312 .33051 Mdot
.96313 .33049 Mdot
.96314 .33048 Mdot
.96315 .33046 Mdot
.96316 .33044 Mdot
.96317 .33043 Mdot
.96318 .33041 Mdot
.96319 .33039 Mdot
.9632 .33038 Mdot
.96321 .33036 Mdot
.96322 .33035 Mdot
.96323 .33033 Mdot
.96324 .33031 Mdot
.96325 .3303 Mdot
.96326 .33028 Mdot
.96327 .33026 Mdot
.96328 .33025 Mdot
.96329 .33023 Mdot
.9633 .33021 Mdot
.9633 .3302 Mdot
.96331 .33018 Mdot
.96332 .33016 Mdot
.96333 .33015 Mdot
.96334 .33013 Mdot
.96335 .33012 Mdot
.96336 .3301 Mdot
.96337 .33008 Mdot
.96338 .33007 Mdot
.96339 .33005 Mdot
.9634 .33003 Mdot
.96341 .33002 Mdot
.96342 .33 Mdot
.96343 .32998 Mdot
.96344 .32997 Mdot
.96345 .32995 Mdot
.96346 .32993 Mdot
.96347 .32992 Mdot
.96348 .3299 Mdot
.96349 .32989 Mdot
.9635 .32987 Mdot
.9635 .32985 Mdot
.96351 .32984 Mdot
.96352 .32982 Mdot
.96353 .3298 Mdot
.96354 .32979 Mdot
.96355 .32977 Mdot
.96356 .32975 Mdot
.96357 .32974 Mdot
.96358 .32972 Mdot
.96359 .3297 Mdot
.9636 .32969 Mdot
.96361 .32967 Mdot
.96362 .32965 Mdot
.96363 .32964 Mdot
.96364 .32962 Mdot
.96365 .32961 Mdot
.96366 .32959 Mdot
.96367 .32957 Mdot
.96368 .32956 Mdot
.96369 .32954 Mdot
.9637 .32952 Mdot
.9637 .32951 Mdot
.96371 .32949 Mdot
.96372 .32947 Mdot
.96373 .32946 Mdot
.96374 .32944 Mdot
.96375 .32942 Mdot
.96376 .32941 Mdot
.96377 .32939 Mdot
.96378 .32938 Mdot
.96379 .32936 Mdot
.9638 .32934 Mdot
.96381 .32933 Mdot
.96382 .32931 Mdot
.96383 .32929 Mdot
.96384 .32928 Mdot
.96385 .32926 Mdot
.96386 .32924 Mdot
.96387 .32923 Mdot
.96388 .32921 Mdot
.96389 .32919 Mdot
.9639 .32918 Mdot
.9639 .32916 Mdot
.96391 .32915 Mdot
.96392 .32913 Mdot
.96393 .32911 Mdot
.96394 .3291 Mdot
.96395 .32908 Mdot
.96396 .32906 Mdot
.96397 .32905 Mdot
.96398 .32903 Mdot
.96399 .32901 Mdot
.964 .329 Mdot
.96401 .32898 Mdot
.96402 .32896 Mdot
.96403 .32895 Mdot
.96404 .32893 Mdot
.96405 .32892 Mdot
.96406 .3289 Mdot
.96407 .32888 Mdot
.96408 .32887 Mdot
.96409 .32885 Mdot
.9641 .32883 Mdot
.9641 .32882 Mdot
.96411 .3288 Mdot
.96412 .32878 Mdot
.96413 .32877 Mdot
.96414 .32875 Mdot
.96415 .32873 Mdot
.96416 .32872 Mdot
.96417 .3287 Mdot
.96418 .32869 Mdot
.96419 .32867 Mdot
.9642 .32865 Mdot
.96421 .32864 Mdot
.96422 .32862 Mdot
.96423 .3286 Mdot
.96424 .32859 Mdot
.96425 .32857 Mdot
.96426 .32855 Mdot
.96427 .32854 Mdot
.96428 .32852 Mdot
.96429 .3285 Mdot
.9643 .32849 Mdot
.9643 .32847 Mdot
.96431 .32846 Mdot
.96432 .32844 Mdot
.96433 .32842 Mdot
.96434 .32841 Mdot
.96435 .32839 Mdot
.96436 .32837 Mdot
.96437 .32836 Mdot
.96438 .32834 Mdot
.96439 .32832 Mdot
.9644 .32831 Mdot
.96441 .32829 Mdot
.96442 .32827 Mdot
.96443 .32826 Mdot
.96444 .32824 Mdot
.96445 .32822 Mdot
.96446 .32821 Mdot
.96447 .32819 Mdot
.96448 .32818 Mdot
.96449 .32816 Mdot
.9645 .32814 Mdot
.9645 .32813 Mdot
.96451 .32811 Mdot
.96452 .32809 Mdot
.96453 .32808 Mdot
.96454 .32806 Mdot
.96455 .32804 Mdot
.96456 .32803 Mdot
.96457 .32801 Mdot
.96458 .32799 Mdot
.96459 .32798 Mdot
.9646 .32796 Mdot
.96461 .32795 Mdot
.96462 .32793 Mdot
.96463 .32791 Mdot
.96464 .3279 Mdot
.96465 .32788 Mdot
.96466 .32786 Mdot
.96467 .32785 Mdot
.96468 .32783 Mdot
.96469 .32781 Mdot
.9647 .3278 Mdot
.9647 .32778 Mdot
.96471 .32776 Mdot
.96472 .32775 Mdot
.96473 .32773 Mdot
.96474 .32772 Mdot
.96475 .3277 Mdot
.96476 .32768 Mdot
.96477 .32767 Mdot
.96478 .32765 Mdot
.96479 .32763 Mdot
.9648 .32762 Mdot
.96481 .3276 Mdot
.96482 .32758 Mdot
.96483 .32757 Mdot
.96484 .32755 Mdot
.96485 .32753 Mdot
.96486 .32752 Mdot
.96487 .3275 Mdot
.96488 .32748 Mdot
.96489 .32747 Mdot
.9649 .32745 Mdot
.9649 .32744 Mdot
.96491 .32742 Mdot
.96492 .3274 Mdot
.96493 .32739 Mdot
.96494 .32737 Mdot
.96495 .32735 Mdot
.96496 .32734 Mdot
.96497 .32732 Mdot
.96498 .3273 Mdot
.96499 .32729 Mdot
.965 .32727 Mdot
.96501 .32725 Mdot
.96502 .32724 Mdot
.96503 .32722 Mdot
.96504 .32721 Mdot
.96505 .32719 Mdot
.96506 .32717 Mdot
.96507 .32716 Mdot
.96508 .32714 Mdot
.96509 .32712 Mdot
.9651 .32711 Mdot
.9651 .32709 Mdot
.96511 .32707 Mdot
.96512 .32706 Mdot
.96513 .32704 Mdot
.96514 .32702 Mdot
.96515 .32701 Mdot
.96516 .32699 Mdot
.96517 .32698 Mdot
.96518 .32696 Mdot
.96519 .32694 Mdot
.9652 .32693 Mdot
.96521 .32691 Mdot
.96522 .32689 Mdot
.96523 .32688 Mdot
.96524 .32686 Mdot
.96525 .32684 Mdot
.96526 .32683 Mdot
.96527 .32681 Mdot
.96528 .32679 Mdot
.96529 .32678 Mdot
.9653 .32676 Mdot
.9653 .32674 Mdot
.96531 .32673 Mdot
.96532 .32671 Mdot
.96533 .3267 Mdot
.96534 .32668 Mdot
.96535 .32666 Mdot
.96536 .32665 Mdot
.96537 .32663 Mdot
.96538 .32661 Mdot
.96539 .3266 Mdot
.9654 .32658 Mdot
.96541 .32656 Mdot
.96542 .32655 Mdot
.96543 .32653 Mdot
.96544 .32651 Mdot
.96545 .3265 Mdot
.96546 .32648 Mdot
.96547 .32647 Mdot
.96548 .32645 Mdot
.96549 .32643 Mdot
.9655 .32642 Mdot
.9655 .3264 Mdot
.96551 .32638 Mdot
.96552 .32637 Mdot
.96553 .32635 Mdot
.96554 .32633 Mdot
.96555 .32632 Mdot
.96556 .3263 Mdot
.96557 .32628 Mdot
.96558 .32627 Mdot
.96559 .32625 Mdot
.9656 .32624 Mdot
.96561 .32622 Mdot
.96562 .3262 Mdot
.96563 .32619 Mdot
.96564 .32617 Mdot
.96565 .32615 Mdot
.96566 .32614 Mdot
.96567 .32612 Mdot
.96568 .3261 Mdot
.96569 .32609 Mdot
.9657 .32607 Mdot
.9657 .32605 Mdot
.96571 .32604 Mdot
.96572 .32602 Mdot
.96573 .326 Mdot
.96574 .32599 Mdot
.96575 .32597 Mdot
.96576 .32596 Mdot
.96577 .32594 Mdot
.96578 .32592 Mdot
.96579 .32591 Mdot
.9658 .32589 Mdot
.96581 .32587 Mdot
.96582 .32586 Mdot
.96583 .32584 Mdot
.96584 .32582 Mdot
.96585 .32581 Mdot
.96586 .32579 Mdot
.96587 .32577 Mdot
.96588 .32576 Mdot
.96589 .32574 Mdot
.9659 .32573 Mdot
.9659 .32571 Mdot
.96591 .32569 Mdot
.96592 .32568 Mdot
.96593 .32566 Mdot
.96594 .32564 Mdot
.96595 .32563 Mdot
.96596 .32561 Mdot
.96597 .32559 Mdot
.96598 .32558 Mdot
.96599 .32556 Mdot
.966 .32554 Mdot
.96601 .32553 Mdot
.96602 .32551 Mdot
.96603 .32549 Mdot
.96604 .32548 Mdot
.96605 .32546 Mdot
.96606 .32545 Mdot
.96607 .32543 Mdot
.96608 .32541 Mdot
.96609 .3254 Mdot
.9661 .32538 Mdot
.9661 .32536 Mdot
.96611 .32535 Mdot
.96612 .32533 Mdot
.96613 .32531 Mdot
.96614 .3253 Mdot
.96615 .32528 Mdot
.96616 .32526 Mdot
.96617 .32525 Mdot
.96618 .32523 Mdot
.96619 .32522 Mdot
.9662 .3252 Mdot
.96621 .32518 Mdot
.96622 .32517 Mdot
.96623 .32515 Mdot
.96624 .32513 Mdot
.96625 .32512 Mdot
.96626 .3251 Mdot
.96627 .32508 Mdot
.96628 .32507 Mdot
.96629 .32505 Mdot
.9663 .32503 Mdot
.9663 .32502 Mdot
.96631 .325 Mdot
.96632 .32498 Mdot
.96633 .32497 Mdot
.96634 .32495 Mdot
.96635 .32494 Mdot
.96636 .32492 Mdot
.96637 .3249 Mdot
.96638 .32489 Mdot
.96639 .32487 Mdot
.9664 .32485 Mdot
.96641 .32484 Mdot
.96642 .32482 Mdot
.96643 .3248 Mdot
.96644 .32479 Mdot
.96645 .32477 Mdot
.96646 .32475 Mdot
.96647 .32474 Mdot
.96648 .32472 Mdot
.96649 .32471 Mdot
.9665 .32469 Mdot
.9665 .32467 Mdot
.96651 .32466 Mdot
.96652 .32464 Mdot
.96653 .32462 Mdot
.96654 .32461 Mdot
.96655 .32459 Mdot
.96656 .32457 Mdot
.96657 .32456 Mdot
.96658 .32454 Mdot
.96659 .32452 Mdot
.9666 .32451 Mdot
.96661 .32449 Mdot
.96662 .32447 Mdot
.96663 .32446 Mdot
.96664 .32444 Mdot
.96665 .32443 Mdot
.96666 .32441 Mdot
.96667 .32439 Mdot
.96668 .32438 Mdot
.96669 .32436 Mdot
.9667 .32434 Mdot
.9667 .32433 Mdot
.96671 .32431 Mdot
.96672 .32429 Mdot
.96673 .32428 Mdot
.96674 .32426 Mdot
.96675 .32424 Mdot
.96676 .32423 Mdot
.96677 .32421 Mdot
.96678 .3242 Mdot
.96679 .32418 Mdot
.9668 .32416 Mdot
.96681 .32415 Mdot
.96682 .32413 Mdot
.96683 .32411 Mdot
.96684 .3241 Mdot
.96685 .32408 Mdot
.96686 .32406 Mdot
.96687 .32405 Mdot
.96688 .32403 Mdot
.96689 .32401 Mdot
.9669 .324 Mdot
.9669 .32398 Mdot
.96691 .32396 Mdot
.96692 .32395 Mdot
.96693 .32393 Mdot
.96694 .32392 Mdot
.96695 .3239 Mdot
.96696 .32388 Mdot
.96697 .32387 Mdot
.96698 .32385 Mdot
.96699 .32383 Mdot
.967 .32382 Mdot
.96701 .3238 Mdot
.96702 .32378 Mdot
.96703 .32377 Mdot
.96704 .32375 Mdot
.96705 .32373 Mdot
.96706 .32372 Mdot
.96707 .3237 Mdot
.96708 .32369 Mdot
.96709 .32367 Mdot
.9671 .32365 Mdot
.9671 .32364 Mdot
.96711 .32362 Mdot
.96712 .3236 Mdot
.96713 .32359 Mdot
.96714 .32357 Mdot
.96715 .32355 Mdot
.96716 .32354 Mdot
.96717 .32352 Mdot
.96718 .3235 Mdot
.96719 .32349 Mdot
.9672 .32347 Mdot
.96721 .32345 Mdot
.96722 .32344 Mdot
.96723 .32342 Mdot
.96724 .32341 Mdot
.96725 .32339 Mdot
.96726 .32337 Mdot
.96727 .32336 Mdot
.96728 .32334 Mdot
.96729 .32332 Mdot
.9673 .32331 Mdot
.9673 .32329 Mdot
.96731 .32327 Mdot
.96732 .32326 Mdot
.96733 .32324 Mdot
.96734 .32322 Mdot
.96735 .32321 Mdot
.96736 .32319 Mdot
.96737 .32318 Mdot
.96738 .32316 Mdot
.96739 .32314 Mdot
.9674 .32313 Mdot
.96741 .32311 Mdot
.96742 .32309 Mdot
.96743 .32308 Mdot
.96744 .32306 Mdot
.96745 .32304 Mdot
.96746 .32303 Mdot
.96747 .32301 Mdot
.96748 .32299 Mdot
.96749 .32298 Mdot
.9675 .32296 Mdot
.9675 .32294 Mdot
.96751 .32293 Mdot
.96752 .32291 Mdot
.96753 .3229 Mdot
.96754 .32288 Mdot
.96755 .32286 Mdot
.96756 .32285 Mdot
.96757 .32283 Mdot
.96758 .32281 Mdot
.96759 .3228 Mdot
.9676 .32278 Mdot
.96761 .32276 Mdot
.96762 .32275 Mdot
.96763 .32273 Mdot
.96764 .32271 Mdot
.96765 .3227 Mdot
.96766 .32268 Mdot
.96767 .32266 Mdot
.96768 .32265 Mdot
.96769 .32263 Mdot
.9677 .32262 Mdot
.9677 .3226 Mdot
.96771 .32258 Mdot
.96772 .32257 Mdot
.96773 .32255 Mdot
.96774 .32253 Mdot
.96775 .32252 Mdot
.96776 .3225 Mdot
.96777 .32248 Mdot
.96778 .32247 Mdot
.96779 .32245 Mdot
.9678 .32243 Mdot
.96781 .32242 Mdot
.96782 .3224 Mdot
.96783 .32239 Mdot
.96784 .32237 Mdot
.96785 .32235 Mdot
.96786 .32234 Mdot
.96787 .32232 Mdot
.96788 .3223 Mdot
.96789 .32229 Mdot
.9679 .32227 Mdot
.9679 .32225 Mdot
.96791 .32224 Mdot
.96792 .32222 Mdot
.96793 .3222 Mdot
.96794 .32219 Mdot
.96795 .32217 Mdot
.96796 .32215 Mdot
.96797 .32214 Mdot
.96798 .32212 Mdot
.96799 .32211 Mdot
.968 .32209 Mdot
.96801 .32207 Mdot
.96802 .32206 Mdot
.96803 .32204 Mdot
.96804 .32202 Mdot
.96805 .32201 Mdot
.96806 .32199 Mdot
.96807 .32197 Mdot
.96808 .32196 Mdot
.96809 .32194 Mdot
.9681 .32192 Mdot
.9681 .32191 Mdot
.96811 .32189 Mdot
.96812 .32187 Mdot
.96813 .32186 Mdot
.96814 .32184 Mdot
.96815 .32183 Mdot
.96816 .32181 Mdot
.96817 .32179 Mdot
.96818 .32178 Mdot
.96819 .32176 Mdot
.9682 .32174 Mdot
.96821 .32173 Mdot
.96822 .32171 Mdot
.96823 .32169 Mdot
.96824 .32168 Mdot
.96825 .32166 Mdot
.96826 .32164 Mdot
.96827 .32163 Mdot
.96828 .32161 Mdot
.96829 .32159 Mdot
.9683 .32158 Mdot
.9683 .32156 Mdot
.96831 .32155 Mdot
.96832 .32153 Mdot
.96833 .32151 Mdot
.96834 .3215 Mdot
.96835 .32148 Mdot
.96836 .32146 Mdot
.96837 .32145 Mdot
.96838 .32143 Mdot
.96839 .32141 Mdot
.9684 .3214 Mdot
.96841 .32138 Mdot
.96842 .32136 Mdot
.96843 .32135 Mdot
.96844 .32133 Mdot
.96845 .32132 Mdot
.96846 .3213 Mdot
.96847 .32128 Mdot
.96848 .32127 Mdot
.96849 .32125 Mdot
.9685 .32123 Mdot
.9685 .32122 Mdot
.96851 .3212 Mdot
.96852 .32118 Mdot
.96853 .32117 Mdot
.96854 .32115 Mdot
.96855 .32113 Mdot
.96856 .32112 Mdot
.96857 .3211 Mdot
.96858 .32108 Mdot
.96859 .32107 Mdot
.9686 .32105 Mdot
.96861 .32104 Mdot
.96862 .32102 Mdot
.96863 .321 Mdot
.96864 .32099 Mdot
.96865 .32097 Mdot
.96866 .32095 Mdot
.96867 .32094 Mdot
.96868 .32092 Mdot
.96869 .3209 Mdot
.9687 .32089 Mdot
.9687 .32087 Mdot
.96871 .32085 Mdot
.96872 .32084 Mdot
.96873 .32082 Mdot
.96874 .3208 Mdot
.96875 .32079 Mdot
.96876 .32077 Mdot
.96877 .32076 Mdot
.96878 .32074 Mdot
.96879 .32072 Mdot
.9688 .32071 Mdot
.96881 .32069 Mdot
.96882 .32067 Mdot
.96883 .32066 Mdot
.96884 .32064 Mdot
.96885 .32062 Mdot
.96886 .32061 Mdot
.96887 .32059 Mdot
.96888 .32057 Mdot
.96889 .32056 Mdot
.9689 .32054 Mdot
.9689 .32052 Mdot
.96891 .32051 Mdot
.96892 .32049 Mdot
.96893 .32048 Mdot
.96894 .32046 Mdot
.96895 .32044 Mdot
.96896 .32043 Mdot
.96897 .32041 Mdot
.96898 .32039 Mdot
.96899 .32038 Mdot
.969 .32036 Mdot
.96901 .32034 Mdot
.96902 .32033 Mdot
.96903 .32031 Mdot
.96904 .32029 Mdot
.96905 .32028 Mdot
.96906 .32026 Mdot
.96907 .32025 Mdot
.96908 .32023 Mdot
.96909 .32021 Mdot
.9691 .3202 Mdot
.9691 .32018 Mdot
.96911 .32016 Mdot
.96912 .32015 Mdot
.96913 .32013 Mdot
.96914 .32011 Mdot
.96915 .3201 Mdot
.96916 .32008 Mdot
.96917 .32006 Mdot
.96918 .32005 Mdot
.96919 .32003 Mdot
.9692 .32001 Mdot
.96921 .32 Mdot
.96922 .31998 Mdot
.96923 .31997 Mdot
.96924 .31995 Mdot
.96925 .31993 Mdot
.96926 .31992 Mdot
.96927 .3199 Mdot
.96928 .31988 Mdot
.96929 .31987 Mdot
.9693 .31985 Mdot
.9693 .31983 Mdot
.96931 .31982 Mdot
.96932 .3198 Mdot
.96933 .31978 Mdot
.96934 .31977 Mdot
.96935 .31975 Mdot
.96936 .31973 Mdot
.96937 .31972 Mdot
.96938 .3197 Mdot
.96939 .31969 Mdot
.9694 .31967 Mdot
.96941 .31965 Mdot
.96942 .31964 Mdot
.96943 .31962 Mdot
.96944 .3196 Mdot
.96945 .31959 Mdot
.96946 .31957 Mdot
.96947 .31955 Mdot
.96948 .31954 Mdot
.96949 .31952 Mdot
.9695 .3195 Mdot
.9695 .31949 Mdot
.96951 .31947 Mdot
.96952 .31945 Mdot
.96953 .31944 Mdot
.96954 .31942 Mdot
.96955 .31941 Mdot
.96956 .31939 Mdot
.96957 .31937 Mdot
.96958 .31936 Mdot
.96959 .31934 Mdot
.9696 .31932 Mdot
.96961 .31931 Mdot
.96962 .31929 Mdot
.96963 .31927 Mdot
.96964 .31926 Mdot
.96965 .31924 Mdot
.96966 .31922 Mdot
.96967 .31921 Mdot
.96968 .31919 Mdot
.96969 .31917 Mdot
.9697 .31916 Mdot
.9697 .31914 Mdot
.96971 .31913 Mdot
.96972 .31911 Mdot
.96973 .31909 Mdot
.96974 .31908 Mdot
.96975 .31906 Mdot
.96976 .31904 Mdot
.96977 .31903 Mdot
.96978 .31901 Mdot
.96979 .31899 Mdot
.9698 .31898 Mdot
.96981 .31896 Mdot
.96982 .31894 Mdot
.96983 .31893 Mdot
.96984 .31891 Mdot
.96985 .31889 Mdot
.96986 .31888 Mdot
.96987 .31886 Mdot
.96988 .31885 Mdot
.96989 .31883 Mdot
.9699 .31881 Mdot
.9699 .3188 Mdot
.96991 .31878 Mdot
.96992 .31876 Mdot
.96993 .31875 Mdot
.96994 .31873 Mdot
.96995 .31871 Mdot
.96996 .3187 Mdot
.96997 .31868 Mdot
.96998 .31866 Mdot
.96999 .31865 Mdot
.97 .31863 Mdot
.97001 .31861 Mdot
.97002 .3186 Mdot
.97003 .31858 Mdot
.97004 .31857 Mdot
.97005 .31855 Mdot
.97006 .31853 Mdot
.97007 .31852 Mdot
.97008 .3185 Mdot
.97009 .31848 Mdot
.9701 .31847 Mdot
.9701 .31845 Mdot
.97011 .31843 Mdot
.97012 .31842 Mdot
.97013 .3184 Mdot
.97014 .31838 Mdot
.97015 .31837 Mdot
.97016 .31835 Mdot
.97017 .31834 Mdot
.97018 .31832 Mdot
.97019 .3183 Mdot
.9702 .31829 Mdot
.97021 .31827 Mdot
.97022 .31825 Mdot
.97023 .31824 Mdot
.97024 .31822 Mdot
.97025 .3182 Mdot
.97026 .31819 Mdot
.97027 .31817 Mdot
.97028 .31815 Mdot
.97029 .31814 Mdot
.9703 .31812 Mdot
.9703 .3181 Mdot
.97031 .31809 Mdot
.97032 .31807 Mdot
.97033 .31806 Mdot
.97034 .31804 Mdot
.97035 .31802 Mdot
.97036 .31801 Mdot
.97037 .31799 Mdot
.97038 .31797 Mdot
.97039 .31796 Mdot
.9704 .31794 Mdot
.97041 .31792 Mdot
.97042 .31791 Mdot
.97043 .31789 Mdot
.97044 .31787 Mdot
.97045 .31786 Mdot
.97046 .31784 Mdot
.97047 .31782 Mdot
.97048 .31781 Mdot
.97049 .31779 Mdot
.9705 .31778 Mdot
.9705 .31776 Mdot
.97051 .31774 Mdot
.97052 .31773 Mdot
.97053 .31771 Mdot
.97054 .31769 Mdot
.97055 .31768 Mdot
.97056 .31766 Mdot
.97057 .31764 Mdot
.97058 .31763 Mdot
.97059 .31761 Mdot
.9706 .31759 Mdot
.97061 .31758 Mdot
.97062 .31756 Mdot
.97063 .31754 Mdot
.97064 .31753 Mdot
.97065 .31751 Mdot
.97066 .3175 Mdot
.97067 .31748 Mdot
.97068 .31746 Mdot
.97069 .31745 Mdot
.9707 .31743 Mdot
.9707 .31741 Mdot
.97071 .3174 Mdot
.97072 .31738 Mdot
.97073 .31736 Mdot
.97074 .31735 Mdot
.97075 .31733 Mdot
.97076 .31731 Mdot
.97077 .3173 Mdot
.97078 .31728 Mdot
.97079 .31726 Mdot
.9708 .31725 Mdot
.97081 .31723 Mdot
.97082 .31722 Mdot
.97083 .3172 Mdot
.97084 .31718 Mdot
.97085 .31717 Mdot
.97086 .31715 Mdot
.97087 .31713 Mdot
.97088 .31712 Mdot
.97089 .3171 Mdot
.9709 .31708 Mdot
.9709 .31707 Mdot
.97091 .31705 Mdot
.97092 .31703 Mdot
.97093 .31702 Mdot
.97094 .317 Mdot
.97095 .31698 Mdot
.97096 .31697 Mdot
.97097 .31695 Mdot
.97098 .31694 Mdot
.97099 .31692 Mdot
.971 .3169 Mdot
.97101 .31689 Mdot
.97102 .31687 Mdot
.97103 .31685 Mdot
.97104 .31684 Mdot
.97105 .31682 Mdot
.97106 .3168 Mdot
.97107 .31679 Mdot
.97108 .31677 Mdot
.97109 .31675 Mdot
.9711 .31674 Mdot
.9711 .31672 Mdot
.97111 .3167 Mdot
.97112 .31669 Mdot
.97113 .31667 Mdot
.97114 .31666 Mdot
.97115 .31664 Mdot
.97116 .31662 Mdot
.97117 .31661 Mdot
.97118 .31659 Mdot
.97119 .31657 Mdot
.9712 .31656 Mdot
.97121 .31654 Mdot
.97122 .31652 Mdot
.97123 .31651 Mdot
.97124 .31649 Mdot
.97125 .31647 Mdot
.97126 .31646 Mdot
.97127 .31644 Mdot
.97128 .31642 Mdot
.97129 .31641 Mdot
.9713 .31639 Mdot
.9713 .31638 Mdot
.97131 .31636 Mdot
.97132 .31634 Mdot
.97133 .31633 Mdot
.97134 .31631 Mdot
.97135 .31629 Mdot
.97136 .31628 Mdot
.97137 .31626 Mdot
.97138 .31624 Mdot
.97139 .31623 Mdot
.9714 .31621 Mdot
.97141 .31619 Mdot
.97142 .31618 Mdot
.97143 .31616 Mdot
.97144 .31614 Mdot
.97145 .31613 Mdot
.97146 .31611 Mdot
.97147 .3161 Mdot
.97148 .31608 Mdot
.97149 .31606 Mdot
.9715 .31605 Mdot
.9715 .31603 Mdot
.97151 .31601 Mdot
.97152 .316 Mdot
.97153 .31598 Mdot
.97154 .31596 Mdot
.97155 .31595 Mdot
.97156 .31593 Mdot
.97157 .31591 Mdot
.97158 .3159 Mdot
.97159 .31588 Mdot
.9716 .31586 Mdot
.97161 .31585 Mdot
.97162 .31583 Mdot
.97163 .31582 Mdot
.97164 .3158 Mdot
.97165 .31578 Mdot
.97166 .31577 Mdot
.97167 .31575 Mdot
.97168 .31573 Mdot
.97169 .31572 Mdot
.9717 .3157 Mdot
.9717 .31568 Mdot
.97171 .31567 Mdot
.97172 .31565 Mdot
.97173 .31563 Mdot
.97174 .31562 Mdot
.97175 .3156 Mdot
.97176 .31558 Mdot
.97177 .31557 Mdot
.97178 .31555 Mdot
.97179 .31554 Mdot
.9718 .31552 Mdot
.97181 .3155 Mdot
.97182 .31549 Mdot
.97183 .31547 Mdot
.97184 .31545 Mdot
.97185 .31544 Mdot
.97186 .31542 Mdot
.97187 .3154 Mdot
.97188 .31539 Mdot
.97189 .31537 Mdot
.9719 .31535 Mdot
.9719 .31534 Mdot
.97191 .31532 Mdot
.97192 .3153 Mdot
.97193 .31529 Mdot
.97194 .31527 Mdot
.97195 .31526 Mdot
.97196 .31524 Mdot
.97197 .31522 Mdot
.97198 .31521 Mdot
.97199 .31519 Mdot
.972 .31517 Mdot
.97201 .31516 Mdot
.97202 .31514 Mdot
.97203 .31512 Mdot
.97204 .31511 Mdot
.97205 .31509 Mdot
.97206 .31507 Mdot
.97207 .31506 Mdot
.97208 .31504 Mdot
.97209 .31502 Mdot
.9721 .31501 Mdot
.9721 .31499 Mdot
.97211 .31498 Mdot
.97212 .31496 Mdot
.97213 .31494 Mdot
.97214 .31493 Mdot
.97215 .31491 Mdot
.97216 .31489 Mdot
.97217 .31488 Mdot
.97218 .31486 Mdot
.97219 .31484 Mdot
.9722 .31483 Mdot
.97221 .31481 Mdot
.97222 .31479 Mdot
.97223 .31478 Mdot
.97224 .31476 Mdot
.97225 .31474 Mdot
.97226 .31473 Mdot
.97227 .31471 Mdot
.97228 .31469 Mdot
.97229 .31468 Mdot
.9723 .31466 Mdot
.9723 .31465 Mdot
.97231 .31463 Mdot
.97232 .31461 Mdot
.97233 .3146 Mdot
.97234 .31458 Mdot
.97235 .31456 Mdot
.97236 .31455 Mdot
.97237 .31453 Mdot
.97238 .31451 Mdot
.97239 .3145 Mdot
.9724 .31448 Mdot
.97241 .31446 Mdot
.97242 .31445 Mdot
.97243 .31443 Mdot
.97244 .31441 Mdot
.97245 .3144 Mdot
.97246 .31438 Mdot
.97247 .31437 Mdot
.97248 .31435 Mdot
.97249 .31433 Mdot
.9725 .31432 Mdot
.9725 .3143 Mdot
.97251 .31428 Mdot
.97252 .31427 Mdot
.97253 .31425 Mdot
.97254 .31423 Mdot
.97255 .31422 Mdot
.97256 .3142 Mdot
.97257 .31418 Mdot
.97258 .31417 Mdot
.97259 .31415 Mdot
.9726 .31413 Mdot
.97261 .31412 Mdot
.97262 .3141 Mdot
.97263 .31409 Mdot
.97264 .31407 Mdot
.97265 .31405 Mdot
.97266 .31404 Mdot
.97267 .31402 Mdot
.97268 .314 Mdot
.97269 .31399 Mdot
.9727 .31397 Mdot
.9727 .31395 Mdot
.97271 .31394 Mdot
.97272 .31392 Mdot
.97273 .3139 Mdot
.97274 .31389 Mdot
.97275 .31387 Mdot
.97276 .31385 Mdot
.97277 .31384 Mdot
.97278 .31382 Mdot
.97279 .31381 Mdot
.9728 .31379 Mdot
.97281 .31377 Mdot
.97282 .31376 Mdot
.97283 .31374 Mdot
.97284 .31372 Mdot
.97285 .31371 Mdot
.97286 .31369 Mdot
.97287 .31367 Mdot
.97288 .31366 Mdot
.97289 .31364 Mdot
.9729 .31362 Mdot
.9729 .31361 Mdot
.97291 .31359 Mdot
.97292 .31357 Mdot
.97293 .31356 Mdot
.97294 .31354 Mdot
.97295 .31353 Mdot
.97296 .31351 Mdot
.97297 .31349 Mdot
.97298 .31348 Mdot
.97299 .31346 Mdot
.973 .31344 Mdot
.97301 .31343 Mdot
.97302 .31341 Mdot
.97303 .31339 Mdot
.97304 .31338 Mdot
.97305 .31336 Mdot
.97306 .31334 Mdot
.97307 .31333 Mdot
.97308 .31331 Mdot
.97309 .31329 Mdot
.9731 .31328 Mdot
.9731 .31326 Mdot
.97311 .31325 Mdot
.97312 .31323 Mdot
.97313 .31321 Mdot
.97314 .3132 Mdot
.97315 .31318 Mdot
.97316 .31316 Mdot
.97317 .31315 Mdot
.97318 .31313 Mdot
.97319 .31311 Mdot
.9732 .3131 Mdot
.97321 .31308 Mdot
.97322 .31306 Mdot
.97323 .31305 Mdot
.97324 .31303 Mdot
.97325 .31301 Mdot
.97326 .313 Mdot
.97327 .31298 Mdot
.97328 .31297 Mdot
.97329 .31295 Mdot
.9733 .31293 Mdot
.9733 .31292 Mdot
.97331 .3129 Mdot
.97332 .31288 Mdot
.97333 .31287 Mdot
.97334 .31285 Mdot
.97335 .31283 Mdot
.97336 .31282 Mdot
.97337 .3128 Mdot
.97338 .31278 Mdot
.97339 .31277 Mdot
.9734 .31275 Mdot
.97341 .31273 Mdot
.97342 .31272 Mdot
.97343 .3127 Mdot
.97344 .31269 Mdot
.97345 .31267 Mdot
.97346 .31265 Mdot
.97347 .31264 Mdot
.97348 .31262 Mdot
.97349 .3126 Mdot
.9735 .31259 Mdot
.9735 .31257 Mdot
.97351 .31255 Mdot
.97352 .31254 Mdot
.97353 .31252 Mdot
.97354 .3125 Mdot
.97355 .31249 Mdot
.97356 .31247 Mdot
.97357 .31245 Mdot
.97358 .31244 Mdot
.97359 .31242 Mdot
.9736 .31241 Mdot
.97361 .31239 Mdot
.97362 .31237 Mdot
.97363 .31236 Mdot
.97364 .31234 Mdot
.97365 .31232 Mdot
.97366 .31231 Mdot
.97367 .31229 Mdot
.97368 .31227 Mdot
.97369 .31226 Mdot
.9737 .31224 Mdot
.9737 .31222 Mdot
.97371 .31221 Mdot
.97372 .31219 Mdot
.97373 .31217 Mdot
.97374 .31216 Mdot
.97375 .31214 Mdot
.97376 .31212 Mdot
.97377 .31211 Mdot
.97378 .31209 Mdot
.97379 .31208 Mdot
.9738 .31206 Mdot
.97381 .31204 Mdot
.97382 .31203 Mdot
.97383 .31201 Mdot
.97384 .31199 Mdot
.97385 .31198 Mdot
.97386 .31196 Mdot
.97387 .31194 Mdot
.97388 .31193 Mdot
.97389 .31191 Mdot
.9739 .31189 Mdot
.9739 .31188 Mdot
.97391 .31186 Mdot
.97392 .31184 Mdot
.97393 .31183 Mdot
.97394 .31181 Mdot
.97395 .3118 Mdot
.97396 .31178 Mdot
.97397 .31176 Mdot
.97398 .31175 Mdot
.97399 .31173 Mdot
.974 .31171 Mdot
.97401 .3117 Mdot
.97402 .31168 Mdot
.97403 .31166 Mdot
.97404 .31165 Mdot
.97405 .31163 Mdot
.97406 .31161 Mdot
.97407 .3116 Mdot
.97408 .31158 Mdot
.97409 .31156 Mdot
.9741 .31155 Mdot
.9741 .31153 Mdot
.97411 .31152 Mdot
.97412 .3115 Mdot
.97413 .31148 Mdot
.97414 .31147 Mdot
.97415 .31145 Mdot
.97416 .31143 Mdot
.97417 .31142 Mdot
.97418 .3114 Mdot
.97419 .31138 Mdot
.9742 .31137 Mdot
.97421 .31135 Mdot
.97422 .31133 Mdot
.97423 .31132 Mdot
.97424 .3113 Mdot
.97425 .31128 Mdot
.97426 .31127 Mdot
.97427 .31125 Mdot
.97428 .31124 Mdot
.97429 .31122 Mdot
.9743 .3112 Mdot
.9743 .31119 Mdot
.97431 .31117 Mdot
.97432 .31115 Mdot
.97433 .31114 Mdot
.97434 .31112 Mdot
.97435 .3111 Mdot
.97436 .31109 Mdot
.97437 .31107 Mdot
.97438 .31105 Mdot
.97439 .31104 Mdot
.9744 .31102 Mdot
.97441 .311 Mdot
.97442 .31099 Mdot
.97443 .31097 Mdot
.97444 .31096 Mdot
.97445 .31094 Mdot
.97446 .31092 Mdot
.97447 .31091 Mdot
.97448 .31089 Mdot
.97449 .31087 Mdot
.9745 .31086 Mdot
.9745 .31084 Mdot
.97451 .31082 Mdot
.97452 .31081 Mdot
.97453 .31079 Mdot
.97454 .31077 Mdot
.97455 .31076 Mdot
.97456 .31074 Mdot
.97457 .31072 Mdot
.97458 .31071 Mdot
.97459 .31069 Mdot
.9746 .31067 Mdot
.97461 .31066 Mdot
.97462 .31064 Mdot
.97463 .31063 Mdot
.97464 .31061 Mdot
.97465 .31059 Mdot
.97466 .31058 Mdot
.97467 .31056 Mdot
.97468 .31054 Mdot
.97469 .31053 Mdot
.9747 .31051 Mdot
.9747 .31049 Mdot
.97471 .31048 Mdot
.97472 .31046 Mdot
.97473 .31044 Mdot
.97474 .31043 Mdot
.97475 .31041 Mdot
.97476 .31039 Mdot
.97477 .31038 Mdot
.97478 .31036 Mdot
.97479 .31035 Mdot
.9748 .31033 Mdot
.97481 .31031 Mdot
.97482 .3103 Mdot
.97483 .31028 Mdot
.97484 .31026 Mdot
.97485 .31025 Mdot
.97486 .31023 Mdot
.97487 .31021 Mdot
.97488 .3102 Mdot
.97489 .31018 Mdot
.9749 .31016 Mdot
.9749 .31015 Mdot
.97491 .31013 Mdot
.97492 .31011 Mdot
.97493 .3101 Mdot
.97494 .31008 Mdot
.97495 .31007 Mdot
.97496 .31005 Mdot
.97497 .31003 Mdot
.97498 .31002 Mdot
.97499 .31 Mdot
.975 .30998 Mdot
.97501 .30997 Mdot
.97502 .30995 Mdot
.97503 .30993 Mdot
.97504 .30992 Mdot
.97505 .3099 Mdot
.97506 .30988 Mdot
.97507 .30987 Mdot
.97508 .30985 Mdot
.97509 .30983 Mdot
.9751 .30982 Mdot
.9751 .3098 Mdot
.97511 .30979 Mdot
.97512 .30977 Mdot
.97513 .30975 Mdot
.97514 .30974 Mdot
.97515 .30972 Mdot
.97516 .3097 Mdot
.97517 .30969 Mdot
.97518 .30967 Mdot
.97519 .30965 Mdot
.9752 .30964 Mdot
.97521 .30962 Mdot
.97522 .3096 Mdot
.97523 .30959 Mdot
.97524 .30957 Mdot
.97525 .30955 Mdot
.97526 .30954 Mdot
.97527 .30952 Mdot
.97528 .30951 Mdot
.97529 .30949 Mdot
.9753 .30947 Mdot
.9753 .30946 Mdot
.97531 .30944 Mdot
.97532 .30942 Mdot
.97533 .30941 Mdot
.97534 .30939 Mdot
.97535 .30937 Mdot
.97536 .30936 Mdot
.97537 .30934 Mdot
.97538 .30932 Mdot
.97539 .30931 Mdot
.9754 .30929 Mdot
.97541 .30927 Mdot
.97542 .30926 Mdot
.97543 .30924 Mdot
.97544 .30923 Mdot
.97545 .30921 Mdot
.97546 .30919 Mdot
.97547 .30918 Mdot
.97548 .30916 Mdot
.97549 .30914 Mdot
.9755 .30913 Mdot
.9755 .30911 Mdot
.97551 .30909 Mdot
.97552 .30908 Mdot
.97553 .30906 Mdot
.97554 .30904 Mdot
.97555 .30903 Mdot
.97556 .30901 Mdot
.97557 .30899 Mdot
.97558 .30898 Mdot
.97559 .30896 Mdot
.9756 .30894 Mdot
.97561 .30893 Mdot
.97562 .30891 Mdot
.97563 .3089 Mdot
.97564 .30888 Mdot
.97565 .30886 Mdot
.97566 .30885 Mdot
.97567 .30883 Mdot
.97568 .30881 Mdot
.97569 .3088 Mdot
.9757 .30878 Mdot
.9757 .30876 Mdot
.97571 .30875 Mdot
.97572 .30873 Mdot
.97573 .30871 Mdot
.97574 .3087 Mdot
.97575 .30868 Mdot
.97576 .30866 Mdot
.97577 .30865 Mdot
.97578 .30863 Mdot
.97579 .30862 Mdot
.9758 .3086 Mdot
.97581 .30858 Mdot
.97582 .30857 Mdot
.97583 .30855 Mdot
.97584 .30853 Mdot
.97585 .30852 Mdot
.97586 .3085 Mdot
.97587 .30848 Mdot
.97588 .30847 Mdot
.97589 .30845 Mdot
.9759 .30843 Mdot
.9759 .30842 Mdot
.97591 .3084 Mdot
.97592 .30838 Mdot
.97593 .30837 Mdot
.97594 .30835 Mdot
.97595 .30834 Mdot
.97596 .30832 Mdot
.97597 .3083 Mdot
.97598 .30829 Mdot
.97599 .30827 Mdot
.976 .30825 Mdot
.97601 .30824 Mdot
.97602 .30822 Mdot
.97603 .3082 Mdot
.97604 .30819 Mdot
.97605 .30817 Mdot
.97606 .30815 Mdot
.97607 .30814 Mdot
.97608 .30812 Mdot
.97609 .3081 Mdot
.9761 .30809 Mdot
.9761 .30807 Mdot
.97611 .30806 Mdot
.97612 .30804 Mdot
.97613 .30802 Mdot
.97614 .30801 Mdot
.97615 .30799 Mdot
.97616 .30797 Mdot
.97617 .30796 Mdot
.97618 .30794 Mdot
.97619 .30792 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009`3oool0
0`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000
oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`0i0?ooo``00000/@3oool002L0oooo0P00
000g0?oooa800000[P3oool002L0oooo00<000000?ooo`3oool0<`3oool7000000X0oooo1P00002/
0?ooo`009`3oool00`000000oooo0?ooo`0a0?ooo`H00000403oool500000:X0oooo000W0?ooo`03
0000003oool0oooo0300oooo1000000E0?ooo`@00000Z@3oool002L0oooo00<000000?ooo`3oool0
;P3oool4000001T0oooo0`00002X0?ooo`009`3oool2000002h0oooo1000000K0?ooo`@00000YP3o
ool002L0oooo00<000000?ooo`3oool0:`3oool4000001h0oooo1000002U0?ooo`009`3oool00`00
0000oooo0?ooo`0Z0?ooo`@000008@3oool300000:@0oooo000W0?ooo`030000003oool0oooo02T0
oooo0`00000T0?ooo`<00000X`3oool002L0oooo00<000000?ooo`3oool0:03oool3000002H0oooo
0`00002R0?ooo`009`3oool00`000000oooo0?ooo`0W0?ooo`<00000:03oool300000:40oooo000W
0?ooo`8000009`3oool3000002X0oooo0`00002P0?ooo`009`3oool00`000000oooo0?ooo`0U0?oo
o`<00000;03oool3000009l0oooo000W0?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`<0
0000WP3oool002L0oooo00<000000?ooo`3oool08`3oool300000300oooo0P00002N0?ooo`009`3o
ool00`000000oooo0?ooo`0R0?ooo`<00000<P3oool2000009d0oooo000W0?ooo`8000008P3oool3
000003<0oooo0`00002L0?ooo`009`3oool00`000000oooo0?ooo`0P0?ooo`<00000=@3oool30000
09/0oooo000W0?ooo`030000003oool0oooo0200oooo0P00000g0?ooo`800000V`3oool000h0oooo
0P0000040?ooo`800000103oool2000000<0oooo1@0000030?ooo`030000003oool0oooo01l0oooo
0P00000i0?ooo`800000VP3oool000d0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool3000003T0
oooo0`00002I0?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool2000001h0oooo0`00000k0?ooo`800000V@3oool000L0
oooo100000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo0`00000m0?ooo`800000V03oool0
00d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0703oool2000003h0oooo0`00002G0?ooo`003P3oool2
000000X0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`800000@03oool2
000009L0oooo000W0?ooo`030000003oool0oooo01X0oooo0`0000110?ooo`800000UP3oool002L0
oooo0P00000J0?ooo`<00000@P3oool3000009D0oooo000W0?ooo`030000003oool0oooo01T0oooo
0P0000140?ooo`800000U@3oool002L0oooo00<000000?ooo`3oool0603oool2000004H0oooo0P00
002D0?ooo`009`3oool00`000000oooo0?ooo`0G0?ooo`<00000AP3oool2000009@0oooo000W0?oo
o`030000003oool0oooo01H0oooo0`0000180?ooo`800000T`3oool002L0oooo00<000000?ooo`3o
ool05P3oool2000004T0oooo0P00002C0?ooo`009`3oool2000001H0oooo0P00001;0?ooo`800000
TP3oool002L0oooo00<000000?ooo`3oool0503oool3000004/0oooo0`00002A0?ooo`009`3oool0
0`000000oooo0?ooo`0D0?ooo`800000C@3oool200000940oooo000W0?ooo`030000003oool0oooo
01<0oooo0P00001?0?ooo`800000T03oool002L0oooo00<000000?ooo`3oool04P3oool3000004l0
oooo0P00002@0?ooo`009`3oool2000001<0oooo0P00001A0?ooo`800000S`3oool002L0oooo00<0
00000?ooo`3oool04@3oool200000580oooo0P00002?0?ooo`009`3oool00`000000oooo0?ooo`0@
0?ooo`<00000D`3oool2000008h0oooo000W0?ooo`030000003oool0oooo0100oooo0P00001D0?oo
o`800000SP3oool002L0oooo00<000000?ooo`3oool03`3oool2000005H0oooo0P00002=0?ooo`00
9`3oool2000000l0oooo0`00001F0?ooo`800000S@3oool002L0oooo00<000000?ooo`3oool03P3o
ool2000005P0oooo00<000000?ooo`3oool0R`3oool002L0oooo00<000000?ooo`3oool03@3oool2
000005T0oooo0P00002<0?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo00d0oooo0P00001I0?ooo`800000S03oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`800000
F`3oool2000008/0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo0P00000<0?oo
o`<00000F`3oool2000008/0oooo00000`3oool000000000000200000080oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00
00050?ooo`030000003oool0oooo00/0oooo0P00001M0?ooo`800000RP3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`800000GP3oool2000008X0
oooo00080?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`<00000103oool00`000000oooo
0?ooo`0:0?ooo`800000G`3oool2000008T0oooo000W0?ooo`030000003oool0oooo00T0oooo0P00
001P0?ooo`800000R@3oool002L0oooo00<000000?ooo`3oool0203oool300000640oooo0P000028
0?ooo`009`3oool2000000T0oooo0P00001R0?ooo`800000R03oool002L0oooo00<000000?ooo`3o
ool01`3oool2000006@0oooo00<000000?ooo`3oool0QP3oool002L0oooo00<000000?ooo`3oool0
1`3oool2000006@0oooo0P0000270?ooo`009`3oool00`000000oooo0?ooo`060?ooo`800000I@3o
ool2000008L0oooo000W0?ooo`030000003oool0oooo00D0oooo0`00001V0?ooo`800000QP3oool0
02L0oooo0P0000060?ooo`800000I`3oool2000008H0oooo000W0?ooo`030000003oool0oooo00@0
oooo0P00001Y0?ooo`030000003oool0oooo08@0oooo000W0?ooo`030000003oool0oooo00@0oooo
0P00001Y0?ooo`800000Q@3oool002L0oooo00<000000?ooo`3oool00`3oool2000006X0oooo0P00
00250?ooo`009`3oool00`000000oooo0?ooo`020?ooo`<00000J`3oool2000008@0oooo000W0?oo
o`8000000`3oool200000280oooo0P0000040?ooo`8000000`3oool400000240oooo0P0000040?oo
o`8000001@3oool3000000X0oooo0P00000E0?ooo`800000103oool2000000<0oooo0`00000R0?oo
o`800000103oool2000000@0oooo0P00000W0?ooo`D000001@3oool002L0oooo00@000000?ooo`3o
ool0oooo0P00000R0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool08@3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000200oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000X0?ooo`030000003oool0oooo00D0oooo000W0?oo
o`040000003oool0oooo0?ooo`8000008P3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo0200oooo00@000000?ooo`3oool00000203oool5000000/0oooo0P00000C0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000803oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000002P0oooo00<000000?ooo`3oool01@3oool002L0oooo00<00000
0?ooo`3oool00P00000S0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool07`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo0P00000C0?ooo`04
0000003oool0oooo000000P0oooo0`00000Q0?ooo`040000003oool0oooo000000T0oooo0P00000Y
0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo008000008`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo00000200oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0000000=0?ooo`8000004P3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo0200oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000X
0?ooo`030000003oool0oooo00D0oooo000W0?ooo`@000009@3oool2000000X0oooo0P00000R0?oo
o`8000002`3oool2000000d0oooo0P00000C0?ooo`8000002P3oool300000240oooo0P00000:0?oo
o`800000:03oool2000000L0oooo000W0?ooo`<00000L`3oool00`000000oooo0?ooo`200?ooo`00
9`3oool3000007<0oooo0P0000210?ooo`009`3oool2000007@0oooo0P0000210?ooo`009`3oool2
000007D0oooo00<000000?ooo`3oool0O`3oool002H0oooo0P00001f0?ooo`800000N03oool00`00
0000oooo0?ooo`050?ooo`008@3ooooo000000009`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`800000
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool2000000L0oooo000W0?ooo`030000003oool0oooo07D0oooo0P00001e0?ooo`800000203o
ool002L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1c0?ooo`800000203oool0
02L0oooo00<000000?ooo`3oool0MP3oool2000007<0oooo0P0000090?ooo`009`3oool2000007L0
oooo0P00001b0?ooo`8000002P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`1`0?ooo`8000002P3oool002L0oooo00<000000?ooo`3oool0M`3oool200000700oooo0P00
000;0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`800000L03oool2000000/0oooo000W0?oo
o`030000003oool0oooo07P0oooo0P00001^0?ooo`800000303oool002L0oooo0P00001i0?ooo`80
0000K@3oool3000000`0oooo000W0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
J`3oool2000000d0oooo000W0?ooo`030000003oool0oooo07T0oooo0P00001[0?ooo`8000003P3o
ool002L0oooo00<000000?ooo`3oool0N@3oool2000006/0oooo0P00000>0?ooo`009`3oool00`00
0000oooo0?ooo`1j0?ooo`800000J@3oool2000000l0oooo000W0?ooo`030000003oool0oooo07X0
oooo0P00001X0?ooo`<000003`3oool002L0oooo0P00001l0?ooo`030000003oool0oooo06H0oooo
0P00000@0?ooo`009`3oool00`000000oooo0?ooo`1k0?ooo`800000IP3oool200000140oooo000W
0?ooo`030000003oool0oooo07/0oooo0P00001V0?ooo`8000004@3oool002L0oooo00<000000?oo
o`3oool0O03oool2000006@0oooo0P00000B0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`80
0000I03oool200000180oooo000W0?ooo`800000OP3oool200000680oooo0P00000C0?ooo`009`3o
ool00`000000oooo0?ooo`1m0?ooo`800000H@3oool3000001<0oooo000W0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0G`3oool2000001@0oooo00080?ooo`800000103oool20000
00@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0OP3oool20000
05l0oooo0P00000E0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo07h0oooo0P00001N0?ooo`<000005@3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00P3oool200000800oooo0P00001M0?ooo`8000005P3oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00
00050?ooo`030000003oool0oooo07l0oooo0P00001L0?ooo`8000005`3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`200?ooo`800000F`3oool2000001L0
oooo00080?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`<00000103oool00`000000oooo
0?ooo`200?ooo`800000FP3oool2000001P0oooo000W0?ooo`030000003oool0oooo0840oooo0P00
001H0?ooo`<00000603oool002L0oooo0P0000220?ooo`800000F03oool2000001T0oooo000W0?oo
o`030000003oool0oooo0880oooo0P00001F0?ooo`8000006P3oool002L0oooo00<000000?ooo`3o
ool0PP3oool2000005D0oooo0`00000J0?ooo`009`3oool00`000000oooo0?ooo`230?ooo`800000
E03oool2000001/0oooo000W0?ooo`030000003oool0oooo08<0oooo0P00001C0?ooo`800000703o
ool002L0oooo00<000000?ooo`3oool0Q03oool200000540oooo0`00000L0?ooo`009`3oool20000
08D0oooo0P00001A0?ooo`8000007@3oool002L0oooo00<000000?ooo`3oool0Q@3oool2000004l0
oooo0P00000N0?ooo`009`3oool00`000000oooo0?ooo`250?ooo`800000CP3oool3000001h0oooo
000W0?ooo`030000003oool0oooo08H0oooo0P00001=0?ooo`8000007`3oool002L0oooo00<00000
0?ooo`3oool0QP3oool2000004`0oooo0P00000P0?ooo`009`3oool2000008P0oooo0P00001:0?oo
o`<00000803oool002L0oooo00<000000?ooo`3oool0Q`3oool2000004X0oooo0P00000Q0?ooo`00
9`3oool00`000000oooo0?ooo`280?ooo`800000B03oool200000280oooo000W0?ooo`030000003o
ool0oooo08P0oooo0P0000170?ooo`<000008P3oool002L0oooo00<000000?ooo`3oool0R@3oool2
000004H0oooo0P00000S0?ooo`009`3oool2000008X0oooo0`0000140?ooo`800000903oool002L0
oooo00<000000?ooo`3oool0RP3oool2000004<0oooo0`00000T0?ooo`009`3oool00`000000oooo
0?ooo`2;0?ooo`800000@@3oool3000002D0oooo000>0?ooo`800000103oool2000000@0oooo0P00
00030?ooo`D000000`3oool00`000000oooo0?ooo`2;0?ooo`<00000@03oool2000002H0oooo000=
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo08`0oooo0P00000o0?ooo`8000009`3oool000d0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo0P00002>0?ooo`800000?@3oool3000002L0oooo000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
08d0oooo0`00000k0?ooo`<00000:03oool000d0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0SP3oool2
000003X0oooo0`00000Y0?ooo`003P3oool2000000X0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`2?0?ooo`800000>03oool3000002X0oooo000W0?ooo`030000003oool0oooo08l0
oooo0`00000g0?ooo`800000:`3oool002L0oooo00<000000?ooo`3oool0T03oool2000003H0oooo
0P00000/0?ooo`009`3oool200000980oooo0P00000d0?ooo`<00000;03oool002L0oooo00<00000
0?ooo`3oool0T@3oool300000380oooo0`00000]0?ooo`009`3oool00`000000oooo0?ooo`2B0?oo
o`<00000<03oool3000002h0oooo000W0?ooo`030000003oool0oooo09<0oooo0`00000^0?ooo`<0
0000;`3oool002L0oooo00<000000?ooo`3oool0U03oool3000002`0oooo0`00000`0?ooo`009`3o
ool2000009H0oooo0`00000Z0?ooo`<00000<@3oool002L0oooo00<000000?ooo`3oool0UP3oool3
000002P0oooo0`00000b0?ooo`009`3oool00`000000oooo0?ooo`2G0?ooo`<000009P3oool30000
03<0oooo000W0?ooo`030000003oool0oooo09P0oooo0`00000S0?ooo`@00000=03oool002L0oooo
00<000000?ooo`3oool0V@3oool300000240oooo1000000e0?ooo`009`3oool2000009/0oooo0`00
000O0?ooo`<00000=`3oool002L0oooo00<000000?ooo`3oool0V`3oool3000001`0oooo1000000h
0?ooo`009`3oool00`000000oooo0?ooo`2L0?ooo`@00000603oool5000003T0oooo000W0?ooo`03
0000003oool0oooo09d0oooo1@00000E0?ooo`@00000>`3oool002L0oooo00<000000?ooo`3oool0
W`3oool500000100oooo1@00000m0?ooo`009`3oool200000:80oooo1P00000:0?ooo`L00000?P3o
ool002L0oooo00<000000?ooo`3oool0X`3ooolB00000440oooo000W0?ooo`030000003oool0oooo
0:H0oooo300000140?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo
0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162024, -0.0167711, \
0.00413596, 0.000190175}}]
}, Open  ]],

Cell["\<\
Find the root of the difference between the approximate \
eigenfunction and the sine function.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[\(Interpolation[
          Transpose[{grid, sine\  - \ v\ Norm[sine]\ Sign[Max[v]]}]]\)[
        x], {x,  .4,  .6}]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \({x \[Rule] 0.49879782714800286`}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Working\ with\ data\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s flexibility makes it possible to work with a huge variety of data.  "
}], "Text"],

Cell["\<\
Import of data from a wide variety of  file formats is supported so \
that you can easily work with data from different sources or instruments \
fairly easily.\
\>", "Text"],

Cell["\<\
Since data is imported as symbolic expressions, it is possible to \
work with symbolic substitutions as well as with mathematical and numerical \
commands.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Image\ data\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
As a straightforward example of data import and processing, I will \
show an example of working with image data.\
\>", "Text"],

Cell["\<\
Import a JPEG image showing a picture of bacteria and limestone \
accretions in the runoff from a geothermal hot spring.\
\>", "MathCaption"],

Cell[BoxData[
    \(image\ \  = \ Import["\<Bacteria.jpg\>"]\)], "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  "Show the image in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook."
}], "MathCaption"],

Cell[BoxData[
    \(\(Show[image];\)\)], "Input",
  CellLabel->"In[15]:="],

Cell[TextData[{
  "You have probably already guessed this from what I have said so far; the \
image is stored in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as a symbolic expression.  "
}], "Text"],

Cell["\<\
Give a shortened form of the corresponding symbolic \
expression.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Short[InputForm[image], 10]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    TagBox[
      FrameBox[\("Graphics[Raster[{{{173, 138, 48}, {173, 138, 46}, {178, \
142, 45}, {171, 136, 34}, {162, 127, 23}, {155, 121, 14}, {161, 124, 18}, \
{163, 126, 20}, {167, 128, 23}, {166, 127, 22}, {165, 126, 23}, {161, 122, \
21}, {162, 120, 22}, {159, 116, 22}, {162, 119, 27}, {165, 121, 34}, {170, \
129, 41}, {173, 131, 45}, {176, 136, 48}, {181, 142, 51}, {180, 145, 51}, \
{180, 146, 48}, {179, 147, 46}, {177, 146, 40}, {183, 152, 44}, {172, 142, \
32}, {170, 138, 29}, {164, 132, 23}, {164, 130, 23}, {163, 128, 24}, {173, \
136, 32}, {178, 140, 39}, {179, 142, 36}, {180, 143, 37}, {179, 141, 34}, \
<<1547>>, {167, 135, 50}, {168, 136, 51}, {169, 137, 50}, {168, 136, 49}, \
{169, 135, 45}, {168, 133, 43}, {167, 132, 38}, {167, 130, 39}, {169, 130, \
39}, {168, 128, 40}, {169, 127, 41}, {167, 125, 39}, {167, 126, 38}, {169, \
128, 40}, {172, 132, 44}, {172, 132, 44}, {166, 129, 41}, {168, 131, 43}}, \
<<1199>>}, <<3>>], <<3>>]"\),
        BoxFrame->False,
        BoxMargins->False],
      (Short[ #, 10]&)]], "Output",
  CellLabel->"Out[9]//Short="]
}, Open  ]],

Cell["\<\
The image data consists of a matrix of triples giving the values \
for each color channel at each pixel.\
\>", "Text"],

Cell["Extract a part of the image data from the Graphics object.", \
"MathCaption"],

Cell[BoxData[
    \(\(imagedata\  = \ 
        image[\([1, 1, \ \(-Range[100]\), \ Range[51, 150]]\)];\)\)], "Input",\

  CellLabel->"In[16]:="],

Cell["\<\
Show the part of the data that was extracted with the true \
colors.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics[
          Raster[imagedata, \ {{1, 1}, {100, 100}}, {0, 255}, 
            ColorFunction \[Rule] RGBColor]], 
        AspectRatio \[Rule] Automatic];\)\)], "Input",
  CellLabel->"In[17]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 0.0141895 0.00962001 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
300 string
100 100 8 [100 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
A187569679418C6F2D8968217D5B13825E14936D269A742D97712A9B752E9F7B31A37F35
A68538AA893CAD8B41B6944AB39147B6944ABC984CBC984CBC9948BC9948BF9B47BF9B47
BA9640B6923CB99340BA9441BC9645C19B4ABF9946BC9643BC9643BA9441BA9544B89342
B89343BD9848C19C4EC09B4DC09B4DC19C4EBF9849BE9748C39D4CC59F4EC4A150C29E50
C29E50BC984CBC964DC39D54C19C4EC29D4FC9A352CDA756BE9847B58E3FB58C3DBC9248
C3974EC59B53C69E58C59F58C5A059C49F58C29D57C39E58BE9C54C09E56C4A056CAA65C
C5A157C09C52C09A53C09A53C39C57C7A05BC7A25BC7A25BC3A15AC19F58C5A05CC6A15D
C7A05DC9A25FC9A15BC69E58C1974DBE944ABE944AC2984EC79D53C69C52C49D52C29B50
C19951C09850C29C53C9A35A
9D824D96783C8D6F2985631B7F5B0F8A6419956D259B732B9A742BA07A31A27E32A68236
AB873BAD893DAF8E41B39245B28E42B69246B79345B59143B79242BC9747CBA753BF9B47
BB9540B9933EB8923FBA9441BC9643BE9845BE9845BE9845BC9844BA9642B99541B99541
B99443BB9646BE9949C09B4DC09B4DC09B4DC19A4BC0994AC29C4BC49E4DC39E4EC29D4D
C09B4DBC9749BF994EC19B50C09B4DC49F51C9A352C7A150C09A47BA9443B78E3EBB9145
C1974BC0964CC39D54C49E55C49F58C39E57C09B55C09B55C19C55C5A059C6A258CDA95F
CBA75DC39F55C09A53C09A53C59D58CAA25DD3AC67C9A25DC5A05AC6A15BC5A05CC49F5B
C7A05BC8A05BCCA45ECA9F5AC69A53C59952C4984FC4984FC69C52C79D53C59B4FC3994D
C0994CC0994CC39C51C8A156
9B7E42977835916F2786601588611291671B956B1F9B71279E782DA68035A88335AA8537
AC883AAC883AB28F3EB49140B38F41B59143B59042B38E40B48F3FBA9545C6A04DBC9643
BA943FB9933EBA913FBB9240BE9543C69D4BBE9A46BE9A46BE9A44C19D47BC9842B8943E
B89440BB9645BF9A49C6A151C39E50BD984AC0994CC29B4EC29B4CC19A4BC29C4BC49E4D
C19A4BBC9546C0994CBF984BC09A49C39D4CC59F4CC39D4AC09A47BD9744BB9544BB9445
C09748C0964CBF994EC19B52C39D56C49E57C09B54BE9952C19C55C49F58C7A25BD3AE67
CCA65FC59F58C59F58C09A53C59D57CAA25CCBA45FCEA762CAA35EC29B56C39E58C5A05A
C69F5AC69E59C9A15CCBA05CCBA05BC79C57C39951C39951C49A50C69C50C59C4DC19848
BE9847C09A49C49D4EC8A152
9E813D96762D906B1B8D64148E651594691B986D1F9D71269E772AA57E31A78232A88333
AD8837B18C3BB28D3CB5903FB89342B99443B79242B59040B6903FBB9544BE9845BD9744
BB9540B7913CBB933EBE9641BF9644C49B49C8A450BF9B47BA9640C09C46BE9A42B8943C
B9953FBC9844BD9945C09B4AC09B4BC29D4DC59E51C29B4EBF984BC19A4DC19848C29949
C39A4AC19848C09A49BF9948C09A47C29C49C29E48C39F49C19D49BE9A46BE9847BD9746
BA9344BC9548BA9449C09A51C49E55C8A259C39D56BE9851C09B54C5A059CAA45DC9A35C
CAA45DC59F58C29C55C59F58C79F59C9A15CC69F5AC9A25FCAA55FC8A35DC49F58C49F58
C5A059C6A059C59E59C9A15CCCA45FC8A05BC49C56C49C56C49D52C49D50C59C4AC29A45
BD9744BE9845C19B48C49E4B
9D7D309A7726936D1A906612976D199A6D1C9B711FA07526A07A29A57F2EA98330A8822F
AC8633B48E3BB38F3BB4903CB99541BC9844BA9443B89241B6903FBC9645BE9845BD9744
B9933EBA943FBC943FBC943FBF9644C29947C29E4AC09C48C19D47C29E48BE9A42B7933B
BA953DBB9540BF9944BC9643BD9746C09A49C19A4BC0994AC0994AC29B4CC39A4ABD9444
C59C4CC89F4FC09A49BE9847BD9744BF9946C4A04AC4A04AC39F4BC19C4BBC9746BC9747
BA9547B99348BB954AC19B52C59F56CAA45BC39D54BF9950C29C55C8A25BC9A35CCAA45D
C8A25BC39D56C09A53C19B54C69E58CBA35EC8A15CC7A05DC6A15BCBA660C4A25AC2A058
C19F57C3A159C6A15BC5A05AC8A15CC7A05BC7A158C7A158C49E53C49D50C39D4AC49C47
C09A45BE9843BD9742BD9742
A382319E7A2698731B9A7119986E189C6F1C9F721FA57827A67D2BAA812FAC8631A9832E
AB8530B28C37B38F39B5913BB99541BB9743B7933FB7933FB8923FBB9542BD9742C19B46
B9943CB69139BA943FBD9742C09A47BF9946C19C4BC19C4BC29E4ABF9B47BE9941BB963E
BC973FBB963EBC9641BB9540BE9845BE9845BD9746C09A49BF9948BB9544C09747C59C4C
C59C4CC49B4BC59F4CC09A47B38F3BBE9A46C39F4BC7A34FC19E4CC09D4CBD9A49BE9A4C
BC984CBE9A50BF9B51C19C55C29E54C4A056C29C53C19B52C39D54C7A158CCA65FC6A059
CDA661C59E59B8914CBF9853C69F5ACCA560C6A15DC8A35FC29F5BC29F5BC1A059C2A15A
C09E56C4A25AC49F58C39E57C49E55C59F56C6A055C8A257C7A156C49F51C59F4EC49E4B
C29C49BF9946BC9641BC9641
AA8733A58028A07B22A0771F9D741C9C6F1CA57825AA7D2CAB812FAB812FAD8530AD8530
AE8931B38E36B5913BB7933DBA9642B99541B5913DB89440B9953FB9953FBE9A42C6A24A
BA963EAF8B33B7933DC29E48C29E4ABB9743BE9948C09B4AC59F4CC49E4BC19B46BD9742
BD953EBF9740C69E49BE9641BD9442BE9543BD9442BE9543BF9742C09745C09745C09747
C69D4DC59C4CC19B48C29C49BD9945BD9945C3A04EC8A554C29F4EC09C4EC09C50C19D51
BE9C52C09E56C19C55C39E58C5A157C19D53C19D51C19D51C39F53C29E54C59F56C7A15A
C9A25DC49D58BD9651C09954CAA35ECDA661C8A15EC69F5CC6A15DC6A15DC19E5AC19E5A
C4A25AC4A25AC4A056C4A056C39D52C39D52C59E51C8A154C9A255C7A053C7A252C49F4F
C39D4CC19B4ABF9946C09A47
B18D37AA852DA88328A47C24A0771FA07622A87B28AB7E2DAF8531AD832FAE862FB08831
B18C34B28C37B7933DB7933FB99541BA9642B6923CB7933DB9953DBA963EC3A046BD9A40
B7943AB59139B8943CBB9741BE9A46C09B4AC29C4BC19A4BC19B48C19B48C19B46C09A45
BD9540BE9641CFA752C69E49C29A45C09843C09843C09843BE963FBF9742C19848C2994A
C39D4CC39D4CC6A04DC49E4BC29E4AC29D4CC4A14FC5A153C39F51C29E52BE9C52BF9D53
C5A35BC19F57C09B55C5A05ACDA95FC4A056C39F53C19D51C4A054C29E52C49E55C59F58
C6A059C49D58C19A57C59E5BCBA45FC7A05BC7A05DC9A25FCAA463C59F5EC6A15DC39E5A
C49F59C39E57CAA45BC59F54C29B4EC49D50C79E4FC69D4EC89E52C99F53C8A355C49F51
C49F4FC29D4DC09A49C19B4A
B5913BAF8B35AE8B31AB882EA47F269E7920A57D25A88028AD832DAF8531B18733B18735
B08737B18838B5913BB9953FBC9840BA963EB9943CB48F37B8903BC29A45C79D4BC39947
C09644BE9442B9933EBB9540BC9840C09C46C19F48C19D49BE9A46C49B49C39A48C39947
C09642BF9541C7A24ACBA64EC7A34BC6A24AC19D45BB973FBD9742BD9442BF9644C39849
C59C4AC59C4ABF9946C09A47C29D4CC39E4EC39F51C7A359C09E54BF9D55C09E56BE9C54
C09E57C4A25BC5A05CC5A05CC8A35DC7A25CC69F5AC69F5AC39D56C39D56C29C55C6A059
C6A059C49E57C39E58C39E58C39E58C49F59C5A05CCCA763C7A160C49E5DC59F5EC19B5A
C29B56C49D58C69E56CAA25AC59E51C69F52C39C4DC59E4FC69D4EC99F53C6A055C49E55
C39C4FC59C4DC59C4CC49A48
B89342B48F3EB38F39B18D37AC872FA8832BAA822BAB832CAE842EB08632B18733B28836
B48B39B68D3BB5913BB7933DBE9A42B7933BB69139B48F37B38B36BC943FC89E4CC19745
C09546C19647BD9744BC9643BC9842C19D47C4A04AC09C46C29C49C19846C19846C19745
BB933EBB933EC09A45C59F4AC19F48C19F48C39F49C19D47C09A47BD9744BD9444C09747
CBA252C29949B89241BE9748BF9A4AC29C51C49E53C6A057C39E57C19C55BF9D55BD9B53
BD9B53C5A35CD3AE68CAA561C7A25EC7A25EC59E59C59E59C6A059C49E57BE9851C29C55
C59E59C59E59C59E5BC59E5BC7A05DC8A15EC8A35DC7A25CC7A25EC5A05CC6A15DC5A05C
BD9651BE9752C29C53C8A259C59E53C19A4FC39C4FC59E51C49D50C69F52C39F53C49E53
C39E4EC39D4CC39A48C29A45
B79347B18D41B49140B79443B4903CAF8936AD8830AC842DAC822CAE842EAF852FB28832
B68E39B78F3AB5913BB5913BB7933DB6923CB9943CB69139B8903BBD9540C39947BE9442
BF9445C19647BD9444BD9444C09A49CAA453C5A14BC39D48C29C49C19846C29947C19846
BF9644BF9644BC9844BE9A46B99642BA9743C39E4DC49F4EC0994ABF9849BF9948BF9948
C39D4CC29C4BBA9344BA9346C0994CC19951C39B53C59D57C7A15AC59F58C29D56BF9A53
BB994FC2A058C49F58C7A25CC8A35DCAA55FCBA45FC9A25DC7A05BC59E59BF9853C19A55
C59C5AC59C5AC39C59C59E5BC8A160CBA461C7A25CC5A059C7A25CC39E58C5A05AC9A45E
C29B56BF9853C39D56C39D56C6A057C49E55C7A156C59F54C6A055C59F54C5A153C4A052
C29D4CC19B48C19B46C49C45
B6914AB59049B79649B89748B69342B38E3DB28E38AC8631AB832BAC842CAE862EB38B33
B89038B78F38B59038B58F3AB58F3AB9933EBF9944BB9540B9933EB7913CBD9442BD9442
C09546C09546BE9546C09748C0994AC39C4DC59F4EC6A04FC39A4BC2994AC39A4BC19849
C49D4EC29B4CBF9A49BC9746B79442B99645C29D4DC5A052C19B50C29C51C39E4EBF9A4A
C19C4CBF9A4ABD9647BF9849C0994CBF984DC19A4FC69E56C9A35AC8A259C4A056C19D53
BE9A4EC09C52BA984EC2A058C4A25AC7A55DCCA760CAA55EC8A35DC7A25CC59E59C49D58
C49D5AC49D5AC39C59C39C59C69F5CC7A05DC8A35CC8A35CC49F58C5A059C5A05AC19C56
C29D57C29D57C29C55C29C55C59F56C49E55CCA65DC7A158C49E53C8A257CAA354C8A152
C49E4BC29C49C39B44C49C45
B6944CB9974FBA9A4FBA994CBC9B4CC3A04EB7933FB28C37AD882FAC842CAC852AB28B30
B89136B78F37B59038B38D38B6903BB48E39BA9640BD9943B8923DB58F3ABC9341BE9543
C19846BF9644BE9545C09747BE9748BD9647C19A4DC59E51C3994FC49A50C1974DC1974D
C39C4FC29B4EC09B4BBB9646B99645BA9648C09C4EC39F53C39D54C59F56C4A054C19D51
C09B4DC19C4EC19C4CBF9A4AC19A4BC39C4DC39C4FC7A053C8A257C9A358C5A155C09C50
C09C50C09C50BF9F54C0A055C1A156C4A459C5A359C5A359C9A75FC9A75FC7A25BC5A059
C49F58C5A059C49F59C49F59C29D57C09B55C49F58CBA65FC5A05AC29D57C29D57BF9A54
C39E58C09B55C39E58C19C56C49F58C39E57C7A156C8A257C8A355C7A053CCA556C9A051
C69D4BC79E4CC79D49C59B47
BD9C55BE9D56BE9E55BC9C53BB9A4DBB9749B99644B8923DB38E36AF872FAC842CB08830
B68E36B9913AB89039B8903BB6903DB48E3BB7933FB99541B99541B89440B99340BA9441
BE9845BD9744BD9744BE9845BD9847BD9848BC9546C0994CC69C52C49A50C1974DC49A50
C2984CC3994DC19A4BBD9647BB9648B99446BC984CC19D53C4A056C7A25BC7A25BC29D56
B99549C09C50C6A151C29D4DC49F4FC49F4FC49F4FC6A153C8A355CCA65BC7A357C09C50
C19D51C19D51BF9F52C0A053C1A156C2A257C4A258C5A359C7A55DC5A35BC6A15AC6A15A
C5A059C5A059C5A157C5A157C29E54BF9B51C19C55C39E57C29D56C39E57C6A15BC39E58
C29D57C49F59C49D58C49D58C49D58C39C57C7A158C6A057C49F51C69F52CDA357C89C51
C69B4DC99E50CA9F50C89D4E
B79951B69850B89A54BB9D55BA9A51B59447B89748BA9544B89440B38D38B18934B38B36
B98F3BBC923EBC923EBC923EB7913EBA9441BB9645B79241BA9544B99443B99541B89440
BC9641BF9944C19D47C19D47BC9945BA9642B89342BD9746C59C4CC39A4AC29949C69D4D
C59A4BC59A4BC49B4BC09747BB9445BA9346BC984AC09C52C2A056C9A75FCBA962C19F58
C09B54BC9750C29E52CAA65AC4A054C29E52C39F53C5A155C9A55BCAA65CC3A157C09E54
C19F55C19F55C2A056C3A157C19F57C09E56C4A25AC8A65EC6A15AC19C55C39E57C7A25B
C8A35CC5A059C39F55C39F55C29E52C09C50BF9B51C09C52C39F55C29E54C49F58C8A35C
C59E59C59E59C49D5AC29B58C49D5AC69F5CC7A15AC39D56C49E53C49D52C69F54C69C52
C89E54C99F55C99F53CAA054
B69850B79953B79855B79855B89750B7954DB79649BB9648B99443B89241B9903EB9903E
BB9041BC9142BD933FBB913FBB9240BA9141BA9545BA9545BA9544BA9544B89440B89440
BB973FBE9A42BF9D44C19F46BF9D46BE9A44B8943CBE9941C39B46C19944C39945C39945
C69C4AC39947C29846BF9445B89241BC9548C09C4EBF9B51C0A055CBAA63D3B16ACAA763
C7A55EC2A059C19F57C6A45CC4A25AC4A25AC2A058C4A25AC9A75FC4A25ABE9C52C19F55
C3A157C3A157C6A15AC19C55C49F59C49F59C39E58C7A25CC8A15CC49D58BF9853C8A15C
CCA65FC8A25BC49E55C39D54C19B50C09A4FC09C50BE9A4EBF9B4FC09C50C19D53C49F58
C6A059C59E59C49D5AC69F5CC7A05FC59E5DC9A15CC69E59C9A159C79F57C69E58C69E58
C79F57C79F57C9A257CEA75C
B8964FB99750B89752BC9B56B7964FB6954EB8964CB9974DB99547BB9749BA9544B99443
BA9642BF9B47BD9746B99342B99342B99342BA9545C29D4DC09B4BBE9949BD9847BC9746
BB9743BD9945BF9B45C09C46C19C44C39E46BF9A42BD9840BE9843BF9944C19846C29949
C09747C09748BF9549BD9347BA9547BD984ABB974BBD994DC1A053CDAB61C9A75FBF9D56
BD9A56BD9A56C4A15FC7A462C4A35EC2A15CBF9F56BE9E55BF9D53C19F57C09E56C3A15A
C19E5AC3A05EC3A05EC5A262C39D5CB6904FC59E59CEA762CAA35EC49D58BE9754C39C59
C69F5AC69F5AC8A058C59D55C3994DC2984CC19C4EC09B4DBE994BBB9648C09A4FC59F56
C5A157C5A05AC59E59C49D5AC59E5BC9A25FC6A059C7A15AC8A058C8A058C79F57C8A058
C79F57C49C54C9A257D4AD60
B6964DB7974EB5974FB69850B5974FB89750B7974CBA994CBC984ABA9746B99443BC9746
BB9743C09C48C29C49BB9542BB9544BA9443BA9443BC9645BB9645BD9847BC9746BE9948
BF9B47BE9A46BE9A44BF9B45C09C46C19D47C19B46BF9944BE9845BD9744BE9545C19849
C39A4BC49A4EC29B50BF984DB89247B89247B99549BF9B4FC2A154C5A457C2A056BD9B53
AD8B43BA9851C3A05CC8A561D0AD69C4A15DBA9850BA9850BB994FBD9B51C8A65EC09E57
BC9A53C6A361CFAE6BC5A363C19E5CBC9655BF9A56C9A25FCBA461C69F5CBF9A56C09B57
C7A25EC7A25ED3AD66C49E57C29B50C39C51C19B50BE984DBD974CBB954AC19B50C6A055
C5A155C5A157C6A057C59F58C7A15AC6A059CAA45DC7A15AC9A159C9A159C6A057C59F56
C9A35AC6A057C59F54C7A156
B6944AB7954BB5974EB5974EB4964DB79950BA9A4DBC9B4EB99847BA9746BA9544BC9746
BD9945BE9A46C09C48BB9743BD9744B8923FB6903DB6903DB8923FBA9441BC9643BE9845
BF9B47C09C48C29E4AC39F4BC19E4AC19E4AC09C48C09C48C09A49BD9647BB9445BE974A
C39C51C59E53C29A52C49C54BC964DBA944BBB954AC09A4FC4A052C5A153BD9C4BBB9A4B
B59447B7954DC19C56CBA662CAA561C8A35DC29D56BB974DB9984BBD9B51BD9D52C09F58
C1A059C3A25FC8A666CAA869C4A161BC9959BE9857C59F5ECAA463CEA867C6A05FC19B5A
C29D59CCA763CEA963C7A25CC39D56C6A059C59F56C19B52C09A4FBF994EC39E50C5A052
C5A052C5A052C49E53C6A055C6A057C59F56C6A057C8A259C8A259CEA85FC9A35AC39D54
C7A158C6A057C6A055C59F54
B69246B89448B8984DB5954AB3964AB6994DBC9C4FBC9B4EC1A04FBC9948B79241B69140
B58F3EBD9746BE9A46BD9945BF9B47BA9642B8923DB8923DB9933EBA943FC39D48C19B46
BE9A46BF9B47BF9C4AC09D4BC09D4BC29F4DC19D49C19C4BC19C4BBF9A4ABE994BBE984D
C29C51C39D54C59D55C59D55C09A4FBD974CBD984AC09B4DC39E4EC49F4FC9A654BB9847
BC984ABE9A50C39D56C69F5AC9A05ECDA560CBA55EC29C53B89448B99549B8964CBF9D55
BE9E55C2A15CC6A562C6A464C29F5FC39D5EC29C5DC49C5EC7A05FCCA564CFAA66C7A25E
C5A05AC7A25CC5A05AC39E58C59E59C69F5AC59F58C39D56C49E55C29C53C59F56C59F56
C59F54C8A257C59F54C6A055C6A057C7A158C6A057C7A158C29C53C8A259CDA75CCBA55A
C6A055C49E53C69F52C69F52
BA9547BA9449B8974AB7954BB9994EBF9F54BA994CBC984CBB9847BB9646BA9344B99243
BD9445C09748BE9948BD9847BD9945BD9945BB9540B9933EB7923AB8933BBA953DBC973F
BE9843C09A45C09C48C29E4AC6A351CBA856C19D49C09C48C29D4CC29D4DC29D4DC09B4D
C19B50C29C51C59F54C59F54C5A052BF9A4CBE9748C19A4BC19B4AC39D4CC29D4CC29D4D
C0994CC09850C69B56C59A56CB9F5ED1A564CBA05BCBA05BC19B50B79146BD994FC19C55
C09E56BF9C58C3A05CC6A361C7A160C6A05FC39B5DBD9557C49B59CBA260CEA861CAA45D
C7A158C09A51C39D56C09A53C49D58C69F5AC69F5AC8A15CCAA35EC7A05BC7A05BC69F5A
C9A25DCDA661C7A05BC19A55C59F58C59F58C9A35AC7A158C6A057C6A057C49D50BE974A
C79E4FD0A758C9A051C79E4F
B79345BA964AB8964CB9974DB6964BB9994EBD9C4FBE9A4EC39F51BC9749BA9344BC9546
BC9546BF9849BD9848BE9949BD9847BD9847BB9542BB9542B6903BB58F3AB18C34B8933B
BD9840BD9840BB9741BC9842BF9B45C29E48C19D47C09C46C5A14DC39E4DC29F4DC09D4C
C09C4EC19D4FBF9B4DC5A153CDA85AC49F51BF9948BF9948BE9847C39C4DC5A050C09A4F
BF984DC59D57C89D58C99E5AC99D5CCB9F5ECCA15CC89D58C8A058C79F57C39D54C29C53
C19C55C09B55BE9C55C3A05CC9A362C8A160C59D5FC1985AC59C5AC8A05BC9A15BC8A058
C49E53C29C51BF9950C19B54C39D56C69F5AC6A15BC9A45ECDA663CAA362C9A261C8A062
CBA365CFA769D0A966C8A15EC8A25BC7A15AC59F56C6A057C5A155C59F54BF984BBE9448
C09748C39A4BC9A050C89F4F
B79649BD9C4FBD9D52C0A055B7974CB39348BB9A4DBE9D50C29E50BF9B4DBF9A4CBF9A4C
C09C4EBC984ABF9A4CC09B4DBF9A4ABE9949BD9945BD9945BB9741B9953FBB963EBD9840
BE9940BD983FBC973EBB963DBD983FC09B43C29E48C39F4BCAA652C29D4CBF9C4AC09D4C
BE9D4EBE9D4EBB9749C29E50CBA759C7A254C19C4CBF9849BD9647C0994CC6A057C9A35C
C29B56C59E59C8A05BC9A15CCAA15FCAA15FC8A05BCAA25DC9A35CC9A35CC39E57C49F58
BF9A53BF9A54BF9E57BF9C5AC9A664D0AA6BC8A063C0985BC79E5EC9A05EC9A35CC6A057
C4A052C29E52BE9A4EBF9A53C29D56C39E58C49F5BC6A15DC9A362C8A261CAA264CAA264
CBA365CEA668CBA461CAA360CAA45DCCA65FC4A056C6A258C6A256C7A156C7A055C79D53
C29B4EBF984BC39D4CC59F4E
B29245B8984DB6994DBD9F56B6984FB4964DB5954ABA9A4FC3A255C2A154BE9D4EBA994A
BB9A4BBD994BBF9B4DBE994BBE994BBE994BC09B4ABD9847BE9A44C09C46C09C44BC9840
BB963DBB963DBA953AB79237B99237BE963EC49E49C8A24FCFAA59C39E4DBE9B4AC09D4C
BE9D4EBD9C4DBB9A4BC09F50CAA658C8A456C49F51BC9749BD9649C29B50C5A05AC19C58
BF9A56C49F5BCDA862CCA761CBA45FC9A25DC8A35FC6A15DC8A35DC6A15BC6A15AC39E57
BE9C52BB9951C1A05BC2A060C6A363CBA567CEA76CC9A164C69E60C7A05DC5A059C6A258
C4A052C19D51C09F52C09E56C19F57C3A15AC6A15DC6A15DC8A261C7A160CAA264CAA264
C9A261CAA362C9A25DC8A15CCAA45BC7A158C4A054C4A054C8A458C8A257C6A057C59D55
C39C51C59E53C29D4DC39E4E
B49344B19041B79649C2A154B7974AB7974AB69649B7974ABB9A4BBE9D4EC09C4EBD994B
BD984ABD984ABE994BBC9749BC9546BC9546BF9948C09A49BF9946C19B48BF9A42BF9A42
BD9840B9943CBA923AB58D35B88E38BA923BC49F47C6A24AC29E48C19D49BE9A46BE9949
BE9949BE994BBD974CC19B50C8A458D7B367C39F51BA9648BE9A4CC19D4FC39D52C49E55
C39E57C39E58C29F5BC4A15DC6A35FC6A35FC5A05CC9A25FCDA663CFA664C8A05BC09852
C29A52BC964DBB9650C29F5BC29F5DC9A664C9A666C29F5FC3A05CC2A059C19F57C5A359
C39F51C29E52C29C51C49E57C7A05BCAA360C69F5AC39C57C9A05EC79E5CC9A060D0A767
CAA15FC89F5DC9A15CC9A15CC9A15BC79F59C49E55C59F56C39E57C6A059C6A059C79F59
C49D52C29B50C19C4CC49F4F
AC8B3CB39243B79647B69546B99849B99849B89748B99849BC984ABD994BBD9A49BD9A49
BF9A4ABF9A4ABE9845BC9643B8923FB99340BE9543C09745C29947C39A48C09A47BE9845
BD9742BC9641B9913CBB933EBC943DC09843C19B46C39D4AC19B48C09A47BD9847BD9848
C09B4BC19C4EC09A4FC49E53C19D53C5A157C09C50BF9B4FC09D4CBC9948C19C4EC49E53
C4A056C49F59C19E5AC29F5DC3A05EC4A15FC6A15DC7A25ECDA663CDA663C9A25DC49E57
C29C53BC964DAF8D45BB9854C3A05CC7A464C9A666C4A062C3A05EC4A15DC6A15BC39E57
C09C50C09C52C39D54C69F5AC7A05BC9A25FC7A25EC5A05CC69F5CC69F5CC69F5CC7A05D
C9A25DC9A25DC8A25BCAA45DCFA960C9A35AC7A15AC6A059C7A25CC49F59C6A057C6A057
C49D50C29B4EC19C4CC29D4D
B69544B59443B79442BA9745BB9846BD9A48BC9948BC9948BD984ABC9749BD9848BF9A4A
C19D49C39D4ABD9840BC943DB78F37B89038BC923CBE943EC19944C49B49C09A47BE9847
BF9A49BF9A49BA9441BC9643BD9742BF9946C19B4AC59E4FC6A04FC29C4BBF9948BF9849
BF9A4ABE984DC49E53CAA45BC5A059C19D53C19D51BD994BBA9745BA9745BE9949C29D4F
C29E54C49F59C09D5BC19E5EC29F5DC5A260C39E5AC49F5BCEA764CDA663CAA35EC8A15C
C39F55BE9A50B29249B3924BC09D59C8A565CAA767C5A163C59F60C7A160C5A05CC49F59
C59F58BE9851BD9750C19A55C29B56C39C59C5A05CC8A35FC7A25EC5A05CC19E5AC29F5B
C6A45DC4A25BC6A15AC8A35CC8A35CC9A45DCEA861CCA65FC7A05BC8A15CC79F57C69E56
C49D50C19A4DC09A49C09A49
BA9648B89544B69341B89541BC9746C19C4CC29D4DC19C4EBF994EBD974CBC9747BE9949
BF9B47C19B48C29D45BF9740BA9139B99038BB9238BC933BBD953DC09843BD9742BC9645
C29D4CBF9A4ABD9847BC9746BD9943BF9B47C09B4BC29D4FC7A252C39E4EC29D4DC19C4C
C09B4DBF994EC09A4FC29C53C19B52C19B52C7A254C29D4FBD9746BD9746BB9645BC9747
BA964CBF9A54C19E5CC4A161C29F5FC5A262C29F5BC3A05CCCA763CBA662C7A25BC6A15A
C09E54BE9C52B5954AB5954CBD9B53C09D59C8A561C8A563C7A160C8A261C8A15EC9A25F
CBA55EC39D56BD9750BD9750C19A55C39C57C39E5AC6A15DC7A460C29F5BC09D59C5A25E
C6A45DC4A25BC5A35CC4A25BC7A25CCAA55FD9B26DCEA762C8A05BC8A05BC8A058C7A055
C79D51C59C4DC39A48C19848
B89448B89446B79442B79442B69141BE994BC5A052C39D52C09A51BE984FBD984ABD984A
BE9B49C09B4AC49E4DC29949BE9440BB913DBC933BBE953DBB933BBB933CBA953DBC9643
C19D49BE9948BD9A48BC9947BD9A46C19E4CC29F4DBE9B4AC3A04FC09D4CC19D4FC19D4F
C09A4FC19B50C19B50BE984DBC9548BC9548C39A4BC79E4FC49B4BC29949BD9847BA9545
B59147BC9751C4A15DC7A462C3A05EC3A05EC4A25BC4A25BC9A45ECBA660CAA55ECAA55E
C8A75AC7A659B99849B59447BC9B4EBF9D55C19F58C3A05CCAA463C8A261CBA660CAA55F
CBA55EC8A25BC29C55BC964FC19B54C39D56C69F5AC59E59C49F5BC29D59C19E5CC5A260
C8A563C9A664C8A563C8A563C7A25ECAA561CDA760CFA962CCA45CCCA45CCBA159C99F55
C89E52C69D4EC69B4CC4994A
B69244B79345B99644B79443B48F3FBC964BC6A057C59F58C29B56C09954BE9A50BF9B4F
C19D4FC39E4EC29D4FC59E51C59C4CC19846BF9742C09841BE963EBB933BB8933BBC9641
BF9B45C09C48BE9B49BE9B49BC9746C19C4BC09D49BF9C4AC3A04EBF9C4BBE9A4CC29E50
C29E52C39F53C39E50C39E50C49D4EC49D4EC0994AC29B4CC39A4BC09748C09A49BE9748
B99549BE9952C6A45DC5A25EC09E57C2A059C3A159C4A25AC6A15AC9A45DC6A258C29E54
BF9E4FBE9D4EBE9B4ABD994BBF9B4DC19D53C2A058BF9D56C49F5BC8A35FCAA561CAA561
C8A35DC8A35DC49E57BE9851C19B54C39C57C8A15CC8A15EC39C59C39C59C39D5CC6A05F
CAA767C8A565C3A060C7A464CBA564C9A460CDA661CCA65FCCA65BC8A257C9A159C79F57
CAA054C79D51C89D4FC89D4F
B59240B69341B79442B08D3CB69342BE9A4EC39F55C49F58C19F58BF9D56BE9C52BF9D53
C09F50C09F50C4A052C7A355C6A151C7A252C6A04DBF9946BD9742BA943FB8923DBA943F
BD9945C29E4AC19C4BC19C4BBE9949C09B4BBE9A46BE9A46BD9847BE9948BE9B49C4A150
C9A655C9A557C7A355C6A254C39F51C29E50C09B4BC09B4BC29D4CC39E4DBF9849C0994C
BF9A4CC19B52C8A65CC2A058BD9B51C19F55C39F55C5A157C6A258CAA65CC6A256C29E52
C09D4CBF9C4BC09B4DBF994EC19D51C29D56C19C55C39E58C3A05CC29F5BC6A35FC8A561
C9A460C9A460C7A05DC59E5BC59E5BC8A160C9A261CAA264C49E5FC39D5EC39D5EC6A061
C9A666C5A262C7A464C9A666C7A462C7A462C8A65FC9A75FC9A75DC6A558C8A45AC7A359
CAA459C9A257C9A255CBA155
C8A551B79440B2923FB39241B29140B69548B9974DBC9A52BE9C55BE9C55BF9D53C19F55
C1A051C09F50C2A150BF9E4DBC9948C9A454CCA756C09A49BE9847BA9443B6923EB5913D
BB9645C09B4AC39E4EC29D4DC5A050C59E4FCAA451C29947B58F3ABD9742BF9B45C09C48
C6A34FC6A352C5A153C8A458C4A356C2A154C4A150C29F4EC09D49C09B4AC09B4AC19A4D
C09B4DC49E53CCAA60C4A258BE9D50C1A053C4A054C39F53C29E54C6A258C6A254C5A153
C19E4CC29D4DC19C4EBF984DC09A51C39D56C29D56C19C58BD9A56C3A05EC7A462C6A361
C6A361C6A361C6A05FC49E5DC29B5AC79F61CAA465C6A062C6A062C49E60C19E5EC4A161
C5A262C7A464C6A464C3A161C7A663C7A663C7A65FC8A760CDB064C5A85CC5A55AC6A45A
C8A65CC9A35AC9A358CBA459
B89440B6923EB4913DB4913DB4913FB18E3CB49342B99847BA994ABB9A4BBE9D4EBF9E4F
C09F50BF9E4FBD9C4DBD9C4DC09F50C9A859C7A452BF9A49BA9642BC9341B78F38B58B35
BB913DC09642C49E4BC49E4BC39E4DC39E4DC49F4EC19B4ABF9944C19944BF953FB98F3B
C19944C49B4BC8A353C9A358C7A659C3A255C6A254C19E4DC39F4BBF9B47BF9C4ABF9C4B
C29F4EC6A256CEAA5ED0AC62C6A15AC39E57C39E57C49F58C39F53C6A256C6A254C39F51
C4A14FC49F4EC29D4DBE974AC0994EC69E58C19A55C29B5AC49E5DC39D5EC4A062C6A264
C5A262C6A363C09E5EC2A060C1A05DC4A262C4A263CBA96CC7A367C29E62C39F61C29E60
C4A15FC3A05EC4A15DC3A05CC3A25BC09F58C2A15AC3A25BC2A15AC5A45DC5A35BC3A159
C6A15AC7A359CCA65BC8A353
B28C39B48E3BB5913DB89440BC9746B99443B89342B89342B99644BD9A48BF9C4BC09D4C
C19E4DC19E4DC29D4FC39E50C49F51C7A254C5A050C29B4CBE9847BC9343BB933EB8903B
BB933EBF9742C29E4AC29E4AC19E4CBF9C4ABF9A4AC39C4DC59F4CBF9644BE9440BA903C
B88F3DC29949C29D4CC8A353C7A657C4A354C4A052C29E50C49F4EC09B4AC19E4CC19E4C
C29F4EC39F51C9A557CCA85CC6A258C5A157C39F55C4A056C29E52C29E52C5A153C6A254
C3A04FC09C4EBB9648C09A4FC09A51C09A53C29D56C19C56BF9C58C29F5BC4A15FCAA765
C6A562C4A360C19F5FC2A060C3A162C5A366C6A467CAA76DC8A669C5A366C4A161C29F5F
C29F5BC3A05CC7A55EC5A35CC3A15AC4A25BC1A059BD9C55C09F58C4A35CC3A159C2A058
C5A059C5A157CAA459C9A454
B38B36B78E3CB79140B89241BD9647BB9445BC9645B89241BB9542BE9845BD9744BE9845
C09A49C19A4BC59C4DC69C50C49D50C59E51C59E51C29B4EC49B4CC19849BF9644BC9341
BA9441BD9744C09C48C29E4ABE9E49BC9947C19E4CCFAA5AC8A251C39D4CC39A48BB9240
BC9643BB9542BF9A49C39E4DC09F4EC1A04FC3A04FC5A251C49F4FBF9A4AC19C4BC29D4C
C39E4DC19C4BC39E4EC6A151C39E50C49F51C49E53C6A055C29E50C19D4FC29E50C8A456
C3A04FBD994BB69246BB974DBF9B51BD994FBD9B53BC9A52BE9D56C09F58C2A15AC7A661
C5A45FC4A262C6A464C4A265C2A063C29F65C5A56AC7A76CC8A667C7A566C7A462CAA765
C49F59BC9751C6A258C6A258C6A258C9A55BC19F57B8964EBE9E55C4A45BC5A35CC4A25B
C7A25BC6A258CAA459C9A454
B48B39B78E3FB79041B89144BC9548BE974ABC9645B89241BA9441BB9542BD9442BF9644
C19846C29949C49B4BC69D4EC89E52C69C50C39C4FBF984BC49B4CC39A4BC19846C09745
BE9641C09843BF9B45C09C46BF9D46BD9A46C29E4AC8A352CEA857C8A251C29949C19848
BD9746BF9948BC9948BF9C4BC19E4DC4A150C3A04FC19E4DC19C4CC29D4DC19C4BC29D4C
C39F4BC29E4AC39E4DC39E4DBF9A49BF9A4AC39E4EC7A254C49F51C29D4FC09C4EC4A052
C19D4FBD994BB59145BC984CBF9D53BD9B51BD9B51BE9C52C09E56C09E56C2A15AC4A35C
C3A25DC2A15EC4A262C2A063C39F63C5A167C9A96CC9A96CC6A464C7A565C6A35FC8A65F
C5A059C39F55C59F54C59F54C4A054C5A155C19F55BE9C52BF9D55C09E56C7A25CC5A05A
C9A45DC8A45ACAA459C6A151
B18B3AB18A3DB69143BA9449BB954AC19B50BE9949BA9545BA9642BA9642BB9542BB9542
BB9544C09A49C19B4AC49E4DC6A04FC29C4BC0994ABF9849C39C4DC19A4BC29947C39A48
C19944C29A45BE9941BD9840BF9B43BF9B45BF9B45C09C48C19B4AC6A04FC59E4FC29B4C
C39E50C09B4DC29D4FC19C4EC19E4DC3A04FC4A150C19E4DC19C4CC29D4DC39E4DC29D4C
C49E4BC49E4BC59F4AC39D48BF9946BD9746C39E4DC8A353C5A052C49F51C19C4EC19C4E
C09D4CBC9948BB9847B79345BF9B4DC9A559C19D53BE9A50C29D56C49F58C3A15AC2A059
C5A25EC09D5BC39D5CC49E5FC49E60C39F61C5A366CDAE6ECAA868C8A561C6A45DCAA55E
C8A257C59F54C5A050C39E4EC5A052C39E50C29E52C4A054BE9A50BF9B51C49F58C6A15A
CBA65FC7A25BC8A257C49F51
B38E3EB28D3FB69246BA964ABB974BC09C50C09C4EBB9749B99644BA9745BB9743B7933F
B79241BD9847C09C48C19D49C29D4CC19C4BBF9A4ABF9A4AC39D4CC39D4CC59C4AC49B49
C59B47C49A46C29A43C09841C19942C09841BE9843C29C47C09A47BF9948C19A4BC19A4D
C49E53C59F54C39D52C39D52C5A052C39E50C49F4FC49F4FC49F4EC5A04FC59F4EC39D4C
C29C47C39D48C39D48C29C47BF9946BE9847C39D4CC7A051C5A052C49F51C39E50BF9A4C
BD9A49BA9746B89342BE9949BE9949BF994EBF9B4FC29D56C39E57C6A15BC09B55C6A15B
CEA965C49F5BBD9854BE9955C29B5AC49E5DC7A464CEAC6CC9A662CAA861CDA861CAA65C
C8A355C7A254C39E4EC19C4CC7A252C49F51C29D4FC39D52BC984EBC984EC39F55C8A45A
CFA962C6A059C59E53C59E53
B48F3FB59040B69244BA9648BD9C4DBD9C4DBA9948B79645B69643B99946BC9945BA9743
BC9844BE9A46BE9948BF9A49BF9C4BC29F4EC09D4CBE9B4AC09B4BC19C4CC49E4BC39D4A
C79F4AC49C47C49C47C39B46C39A48C19846C19B48C49E4BC09A47B89241BC9746C19C4E
C39E50C39D52C6A055C49E53C19B50C19B50C5A052CBA658C7A252C29D4DC39D4AC39D4A
C59F4AC6A04BC79F4AC59D48C49B49C39A4AC19B4AC49D4EC8A154C49D50C39E4EBF9A4A
BA9745B89543BB9743BD9847BD9847BC9749BC984CC29D56C6A15AC8A35DC8A35DCAA55F
C6A15BBF9A54BE9953C09B55C19C56C09B57C5A05CCEA867D0AB65D0AB65D0AC62CDA95F
C8A456C39F51C29D4DBF9A4AC29D4DC39E50C29D4FC59F54C59F56BE984FC39F53C8A458
CFA960C59F56C49C54C59D55
B18C3BB48F3EB59241BA9746C09F4EB99847B89746B79645B79744BA9A47BC9945BD9A46
C19D47BD9945B6923EBD9847C19C4CC49F4FBF9B4DC09C4EC29D4DC29D4DC09A49C49E4D
CCA351C69D4BC49B4BC39A4AC59C4CC49B4BC49B49C59C4AC19B4ABD9746BF9A49BF9A4A
C49F4FC49F51C59F54C29C51C0994EC19A4FC29B50C9A257C49D50C19A4DC09A49C39D4C
C8A24DC9A34EC9A14CC69E49C59C4AC39A4AC19B4AC49D4ECEA75AC7A053C49F4FC19C4C
BB9844BA9743BC9844BC9746BD9847BC9749BD994BBF9B51C4A056C5A059C6A45CCAA860
C3A159C19F57C09E56BC9A52C09B55C19C56C8A35FC9A460CCA761CCA761CCA85ECAA65C
C6A254C4A052C09D4CBF9C4BBE9949C19C4EBF9A4CC6A055D2AA62C79F57C39F51C7A357
CFA95EC8A259C79F59C69E56
B4913DB4913DB5933CB5933CB6923CB8943EB99541BC9844BD9A48BC9947BE9B49BD9A48
C09C48BE9A46BC9842BC9842C09C48C5A04FC19C4BC49F4FC19C4EC29D4FC39F53C29E52
C29E50C19D4FC49F51C09B4DC29B4CC9A253C49F4EC29D4CC09B4AC29D4CBF9A49C09B4A
C39E4DCBA655C5A050C29D4DC49D4EC49D4EC59E51C7A053C39C4FBE9748C09A49C39D4A
C49E4BCAA451C7A14EC39D4AC19C4BC29D4CC09D4BC3A04EC4A150C4A150C49F51C29D4F
C19A4DBC9548BB9445B99243BB9447BB9447BD964BC09850C49E55C49E57C5A05ACFAA64
C3A15AC2A059BE9C55BF9D56BE9C55BF9D56C09E56C4A25AC7A55DC9A75FCCA760C8A35C
C59F56C59F56C49E55C39D54C19B52C09A51BA9449C9A358D1AB60CBA55ACCA65BCAA459
CBA55ACCA65BCAA459C7A156
B79442B69341B6943DB6923CB4903AB6903BB89440BC9844BB9846BC9947B99946BE9B49
C3A04EC6A150C3A04CBC9945BE9948BF9A49BE9949BD9848BF9A4CC19C4EC29E52C29E52
C19D51C19D51C5A155C39F53C39E50C29D4FC29D4CC29D4CC19C4BC29D4CC19C4BC29D4C
C19C4BC29D4CC29D4CC29D4CC39E4EC39E4EC59E4FC69F50C39C4FC29B4CC19B4AC39D4A
C69D4BC59C4AC69D4BC9A04EC9A350C8A24FC39E4DC49F4EC29F4DC4A14FC8A353C09B4B
BE974AB99245B79140B79140BD9445BD9347BC9548BF984DC49E55C49E55C2A058C19F57
C1A156BE9E53BF9D53BD9B51BD9C4FC09F52BF9D53C3A157C7A359C7A359C8A45AC7A359
C6A057C6A057C6A057C7A158C29C53BE984FB58F46C39D54CCA65DC9A35AD0AA61CDA75E
CAA65CCBA75DCCA85ECAA65C
BB9645B99443B8943EB7933DB59038B59038B58F3AB99541BB9844BB9B48B69745B99A48
C1A051C5A455C19E4CBD9A48BE9B49BB9846BC9746BA9544BE9949C09B4DC19D4FC4A054
C39F55C29E54C29E52C09C50C19C4EBD984AC19C4CC19C4CC09B4BC19C4CC29D4CC5A04F
C39E4DC29D4CC19C4BC09B4AC09B4BC29D4DC8A353C9A454C49F4FC49D4EC59F4EC69D4D
C69D4BC39A48C79D49C89E4AC69E49C49C47BF9944B8923DBF9B47C39F4BC7A251BF9A49
BC9747B68F40B58F3CB58C3ABA9141BF9647C0994AC19A4DC29E52C19D51C09E54C2A056
BF9E51C09F52BD9C4BBB9A49C4A14FC4A150BE9B4AC19D4FC4A054C5A155C7A357C7A357
C5A157C4A056C6A059CCA65FC39D56BC964FBF9751C49C56C59D57C9A15BC9A55BC8A45A
C9A55BCCA85ECCAA60C9A75D
BD9847BA9544BA943FB9933EB89039B89039B28D35BB9741BF9D46BB9B48B59643B99A4A
C1A051C09F50BC9B4ABB9B48BE9B47BC9945BB9743BC9844BE9948BF9A4ABF9C4BBF9B4D
BF9B4FC29E52C4A054C29E52C6A153C39E50C49D4EC29B4CBF9A4AC19C4CC39E4DC49F4E
C49F4EC39E4DBC9947BD9A48C09D4CC4A150CAA555CAA555C6A153C7A053C7A150C89F4F
C89F4DC69D4BCAA04CC99F4BC39943C09640BD953EB9913AB8923DBF9944C7A34FBF9B47
BC9746B5903FB58F3AAF8934B28C39BB9544C19C4BC19C4EBF9B4DBF9B4FC1A053C09F52
C09F4EC29F4EC09D49C5A14DC49E49C39D4AC09B4AC09B4BC09B4DC39E50C5A155C5A155
C5A157C5A157C7A158C8A259C6A057C49C54C69F54C69C52C89E54C7A055C6A055C6A256
C8A458CBA75BCAA85EC8A65C
BD9847BC9746BD9742BB9540BA923BB9913AB9933EB9953FBD9A46BE9E4BB99A47B69747
BE9D4EC3A253C09D4BBD9A46BC9844BD9945BD9943BE9A44BF9B47BF9B47C09B4AC19C4B
C29F4EC4A150C29D4DBE9949C49F4FC6A151C59E4FC39C4DC29B4CC39C4DC39E4DC29D4C
C29D4CC19C4BBC9746BC9746C29D4DC6A151C8A355C9A456C7A254C8A154C8A152CBA253
CBA252C9A050CAA14FCCA351C59D48C09843B9913AAD852EB08831B58D36B9943CBD9840
BB9741B6923CB28E36AD8931AF8B35B5913DBB9645BB9648BD994BBF9B4FC29E52C09C50
C39E4EC29B4CC49E4BC69D4BC79D49C69C4ABE9748BF984BC09B4DC29D4FC29E52C4A054
C6A258C7A359C7A359C6A258C8A257C8A257C7A053C49D50C89F50C49D4EC49F51C5A153
C7A357C9A559CBA75DCAA65C
BE9948BE9948BF9B47BE9845BA9441BA913FB7913EBA9441BC9945BB9846B99946B99847
C29E50C3A04FC09D4BBD9A46BD9945BB9743BF9B47BF9B47C29E4AC19D49BE9B47BE9B47
BE9B47BF9C48C29E4AC19D49C6A04FC39D4CC29C4BC39D4CC49E4DC19B4AC29C4BC39D4C
C39D4CC19B4AC09B4BBE9949C39C4FC7A053C8A156CAA358CAA25AC9A159CCA258CDA359
CCA55ACDA65BCAA356C9A255C39C4DBF9849BD9442BA913FB48C37B48C37B48F37B59038
B49137B39036AF8D33AE8C33B08C34B28E3AB6923EB89343BC9749BD974CBE9A50C39F55
C29C51C59E53C59E51C79D51CA9F50C4994BBB9447C0994EC49E55C39D54C29C55C59F58
C7A25BC8A35CC7A25BC9A45DC8A257C8A257C7A053C69F52C29B4CBF9849BE9949C29D4F
C6A153C9A358CBA55CC9A35A
BD9945BE9948C09B4BC09B4BBD9647BB9445B79140B89241B6933FB89541BA9745BB9846
C09B4AC29D4CBF9B47BF9A49BE9847BD9647C19A4DC29B4EC49F4FC49F4FC19E4AC09D49
C19D47C09C46C19B48C19B48C69D4DC59C4CC39A48C49B49C49B49C29947C19B48C19B48
C39D4CC29C4BC19A4BC39C4DC7A053C8A156C99F55CAA058CCA15CCFA45FCDA560CDA560
CFA863D2AB66CDA661C8A15CC59F58C19B54BF984DB99245BA9142B78E3EB08A35B28C37
B18C33B38E35B08D31AF8C32B08B32B18B36B6903DB79041B99245B99149BD974EBF9952
C29C55C49E57C69E56CFA75FCBA159BF954DBF974FC19951C39D56C39D56C19A55C49D58
C9A25FCCA562C8A35FC6A15DC7A25BC9A45DCAA45BC59F56C29D4FBB9648BF984BC29B50
C49D52C69E56C7A15AC7A15A
BC9844BB9645BD9A48C09B4BBE994BBD9649BB9445B99243B4913DB89541BA9743BC9844
BE9A46C39D4AC49E4DC0994AB99243BF984DC0994EC39B53C39E50C7A254C7A452C3A04E
C29E48C19B46C09A47C09745C39849C59A4BC89F4DC69D4BC69D4BC69D4BC69D4BC39A48
C49B49C49B4BC29949C59B4FC89E52C89E56CBA159CCA15CCDA05DD0A360CFA664D1A866
D4AD6CD2AB6ACBA566C7A162C8A261C19B5AC09954BB954EB68F44B28B3CB28C3BB18B36
AF8A32B18C33B28D32AE8930AF872FB18934B68D3BB58C3DB58E41B89048BD974EBE9851
C19C56C19C56C59E5BC7A05DD1AA65C59E59C39B55C09852C19954C59C5AC59E5BC49D5C
C79F61CAA264C8A263C9A364C9A460C8A35FD2AD67C5A05AC29D56C49E57C19B52C39B53
C39B55C69E58C7A05BC69F5A
B99340BA9344BB9749BE9A4EBF9B4DBF9C4BBE9B49BD9A46BA963EBB973FBC9842BC9844
BD9A46C5A251C3A251C1A051BF9E51BD9C4FC09C52BF9B51C19D51C6A256C7A254C8A355
C39E4DBF9A49C19B4ABF9948C49B4BC59C4CC49E4DC8A251C59F4AC49E49C49E49C39D4A
C4A04CC29D4CC39D4CC39D4CC6A04FCEA758C99F53C89E56CDA25ECEA263D2A56AD8AD76
D0A76FCEA770C9A66EC9A66CC6A266C19D5FBD9C59B69550B3924BAE8C42AB8A39AE8A36
AB862DAE852DB0872FB88B36B18731AE8430B08735B18839B18A3FB68E48BA944DBD9651
C09A53C19B54C29D56C39E57C3A15AC5A35BBD9D50B59447BC9B4EC49F58C29B56C69F5E
C69F5EC79F61C8A263D4AE6FC8A565C6A363C7A460C6A35FC7A25CCFAA64C29D56BD9851
BD9851BF9A53C29D56C49F58
B89241BB9445B99547BC984AC09D4CBF9C4AC29E4ABE9A44BC9840BB973FBB9741BC9842
BC9945BC9947BE9D4CBE9D4EC09C50BF9B4FBF9B4FBE9A4EC19D4FC6A254C5A050C39E4E
C59F4EC19B4AC19B48BE9845C09745C69D4BC29947C79E4CC59F4AC29C47C09A45C6A04B
CCA653C7A14EC59F4EC7A150C7A150C7A051C39C4FC69E56CEA35FD1A566D3AB70D2A973
CCA770CDA873C8A772C5A46FC0A067BF9F66BE9E61B69757B39451AE8D46A9893CAD8A39
AB8731AD852EAE862EAD842CAC842CAC842DAC842DAF8634B18A3DB28A42B69047BA944D
BD9851C09B54C19F57C3A159C3A15AC3A159BE9E53BD9C4FBD9B51BF9A53BF9853C39C5B
C49D5CC59D5FC6A062CCA668C8A565CAA767C8A563C8A563C7A460C4A15DC3A159C2A058
C5A059C5A059C39E57C39E57
BA9344BC9546BB9646BA9545BA9544BC9746BF9B45BD9943BF9A42BE9941BD9840BA953D
B9953FB7933FBE9B4AC09C4EC09C4EBF9B4DBF9B4DBF9B4DC19E4DC3A04FC39E4DB99443
BE9843C09A45C09843BE9641C19944C39B46C49B49C69D4BC59D48C29A45C29A45C59D48
C59F4CC7A14EC9A352C8A251CAA554CAA555C7A254CCA65DCFA962CFA867CBA769CBA870
CDAC77CAAA79C4A674C4A576C0A270BFA16FBC9E68B59860B39559AE8F4FA78941AA883E
AC8938AC8834AD882FA68126A98225AA8328A88126AD852EB48B3BB3893DB28A42B8904A
BC9750C19C55C19F57C19F57C09F58C2A259C4A258BE9D50C09C52C09B54C49D58C9A261
C39C5BC39B5DC59D60C8A063CAA466CDA769C9A666C9A666C8A563C09D59C5A35CC7A55D
C9A45DC8A35CC39E57C39E57
B79140B99342BC9643BC9643BC9641BF9944BE9843BE9843C09A45C29C47C29C47BB9540
B9933EBC9643BE9B49C09D4CC09C4EBF9B4DBF9C4BC19E4DC19C4BC19C4BBE9A44C09C46
C19C44C19C44C09841BD953EC39B46C39B46C99F4DC69C4AC59B47C59B47C69E49C59D48
C39A48C9A04EC9A350C9A350C9A551CAA554CDA858CEA85DCBA65FD0AD6BD9B778CDAD74
CBAD79C9AA7BC1A679BDA277BB9E74BB9E74BD9E70B79869B59761AF9057A78A48A78641
A8873AAA8736AB872FA58228A68224A68224A88126AE862EB28A35B18838B18A3DB68F44
BA964CBF9B51BF9D53BE9C52BE9E55C19F55C1A053C29E50C39D52C59F56C29C55C59E5B
C8A15EC49D5CC49C5EC79F61C7A162C8A263CAA767CAA767CAA765C5A25EC4A25BC6A45C
C4A25AC4A25AC49F58C5A059
BB933EBD9540BD953EBE963FBD9840BB963EBF9944BE9843C09A47C49E4BC19B4ABD9746
BD9444C09747BD9848C09B4BC29D4DC09B4BBF9A49C19C4BC29E4AC29E4AC39F49BF9B45
C29D45CBA64EC39B46BA923DC19944C29947C79D4BC4994AC79D49C79D49C49A46C69C48
C79E4CC89F4DC9A350C59F4CCAA652CDA857CAA756C9A559CAA65CCFAC68D7B576CEAF78
CDAF7BC8AB7FBFA37BB99D78BC9E7ABFA17BBB9B74B8996DB59765B1925CAA8A4DA68343
A58039A98338AC8736A7812CA58028A37B23A47B21AD842CB38933B38937B28B3CB48D40
B79345BE9A4CBF9E4FBD9C4DBC9B4EC09C50C29F4EBD984AC39E50C8A259C8A259C8A15C
C29B56C29B58C49D5CC59E5DC39D5CC39D5CCBA564CDA766CBA864C6A35FC3A159C3A159
C2A059C3A15AC5A05AC6A15B
BF9740BE963FBF953FBF953FBE9641BF9742C09A47BC9643BE9847C39D4CBC9645BB9544
BF9646BE9545BA9544BF9A49C39E4DBF9A49BC9746BC9746C19D49C29E4AC19D47C29E48
C29E48C29E48C19B48C09A47C09A49C19B4AC59C4DC79E4FCAA151C69D4DC49A48C59B49
C79E4ECAA151CBA252CCA353CCA854CAA554CBA857CAA65AC7A55BCEAB67D3B474D3B47D
CEB07EC5A87EBCA07BB99C7CBA9B7EB59677B89776B89872B59668B2925FAE8E55A78345
A47F3BA8823BAC8739A57F2EA47E2BA57B27A37923AE812CB78A37B68938B58C3AB78E3E
B99443C09B4AC19E4CBE9B4ABD9A49BF9B4DC29D4FC29D4FBF994EC49E53C8A259C6A059
C29C55C59E59C69F5CC49D5AC69F5CC7A05DC8A35DC9A45EC9A760C3A15AC19F58C19F58
C3A05CC5A25EC6A05FC59F5E
C19741BE943EBF9541BD933FBC9341C19846C19B48BB9542BB9743C19D49C09B4ABB9645
BB9544BC9645BA9441BF9946C6A04DBF9946BB9743B99541BF9B45C09C46C09C46C09C46
C09C46C29E4AC19D49C39E4DC5A050C7A254C69F52CAA358CDA455CAA152C9A050C89F4F
C9A051CFA657CDA454CBA252CEA857CBA455C9A454CBA55ACDA95FCDAA66D2B277D6B683
CDB182C2A47EB59B7AB4997CB6987EB7997DB79879B79975B5986EB49566B0915BAA874D
A58242A67F3CA68035A57C2DA57C2CAA7D2CAC7F2CB0812FB38635B38635B48B39B88F3D
B99541BE9A46BF9A49BD9848BE9748C19A4DBF994EC19B50C19B52BE984FC5A059CDA861
C39C57C09954C8A05BC69E59CAA25DCAA25DC69F5AC69F5AC7A25CC39E58C19E5AC19E5A
C5A260C4A15FC6A061C59F60
BE9440BF9541C29846C39947C19848C19848C19B48BA9441B7933FC09C48CAA652BF9B47
B7913EBC9643BE9845C19B48C8A24FC19B48BF9B47BB9743C19D47C09C46BD9B44BE9C45
B6933FBD9A48C29F4DC29F4EC49F51C39D52C8A156C9A159CCA558CBA457CAA152CBA253
CDA254CDA254C89F50CAA152CFA958CFA859CDA858CBA55ACBA75DCBA866CEAE73D9BB89
D0B387BFA37EB3987AB99E83B79B83B4997EB4967AB39676B3966EB49567AF915DAA8A51
A78546A5803CA47C34A77B30A17627A57729AE7F2DAD7E2CAE7F2FB38635B68C3AB78E3C
B6923CB99541BC9643BC9546BF9549C1974FC19B52BF9952C29C55C49E57C49F59C6A15B
C29B58C49D5AC79E5CC69D5BC79E5CC79E5CC69F5AC69F5AC5A05AC5A05CC3A05CC19E5C
C5A262C3A060C4A161C5A262
BF9644C09745C19848C89F4FC49D4EC0994AC0994ABC9546B89343BE9949C6A150C19C4B
BE9A46BD9945BD9742C19B46C8A24FC7A14EC29C4BBD9746BF9946C09A47C09C48BC9844
BD9945BD9847BB9846BE9B4AC09C4EC39F53C8A259CBA55ECDA75CC9A358C9A456C9A456
CBA457CBA457CCA354CEA556CDA455D0A65ACEA861CEA764CCA668CDA871D9B583DDBC91
C9AC84BDA07EB09779B99F84BCA287B3987DB19679B5987AB09172B5956FB49465AE8B55
A88646A580399F7C2B9E7825A07624A27323A87929AA7B2BAE8032AF8636B18B3AB18C3B
B69140B89241BE9847BD9444BF9445C09547BF984BC19A4FC39D54C6A059C6A059C59E59
C39E5AC49F5BC5A05AC6A15BC7A15AC49E57BF9752BC944FC8A05BCBA35EC69F5CC49D5A
C3A05EC4A15FC1A25FC3A461
BE9543C29949C39A4AC69D4EC49D50C39C4FBF994EBB954ABA9547BF9A4CC49F4FC5A050
C49F4EBC9746BA9642BD9945C49F4EC6A150C5A14DC39F4BC29E4ABF9B47BD9943C09C46
BB9743BB9645B79442BA9648BF9B4DC29E54C6A057C9A35CCDA75CCCA65BCCA759CBA658
CCA558CAA356CCA556CBA455CAA356CDA65BCFA863D0A968D2AB70D5B07BDFBA8DDDBB95
C9AB87BB9E80AC9279B79D86BFA58EB39781AF937BB2947AB49579B79675B3936AAC8A5A
A7874CA07D3B9873259C73239C7122A07224A57628AB7D2FAE8335AF8839B18C3CB59241
B79242B89142BE974AC0964AC1954AC1954AC2994AC2994ABF984BC0994EC19B50C49E55
C39E57C29D56C39E57C39E57C59F56C39D54C39B55C19953C69B57C89D59C7A05BC59E59
C3A05CC5A25EBFA15BC4A660
BC9341C49B4CC49D4EC49D52C49D52C39B53BF9950C09A51BF9950BF9950C09B4DC19C4E
C19C4EBE994BBB9645BC9746C49F4EC5A04FC6A34FC5A24EC2A049BD9B44BC9A43C09E47
BD9A46BC9947BB9846BA9648BF9A4CC49E55C7A158C7A15ACAA45BCCA65DCFA95ED0AA5F
CEA85DC8A257CAA356CAA356CCA55ACEA65ECFA865D1A96BD2AE74D5B17DDDBC8FD7B993
C9AC8ABDA285B39980B79D86BCA08AB1957FAF9179B0927AB4967AB39676B2956DAC8D5E
A88B539E7F3E98742896701F996E1F97691BA57628AB7D2FB38839AE8837B28D3CBA9745
BA9545B58E3FBC9548C3994DC4984DC3984AC59A4BC49A48C29949C09748BC9747BD984A
BF9B4FC29E52C29E52C29E52C29C51C29C51C49C54C89E56C79C57C99E59C8A05ACCA65F
C2A058BC9A52C4A45BD6B66D
B78F3ABF9646C39C4DC59E53C29C51C09A51C9A35CC29C55BD974EBC964DBA9547BF9A4C
C39C4FC19A4DBE9948BF9A49C4A14FC3A04EC3A04EC3A04EBE9E4BBC9C49BC9C47BC9C47
C3A04EBE9B49C19C4CBF9A4CC09B4DC49E55C6A057C7A15ACBA55CCBA55CCBA75BCDA95D
D1AB62CDA75ECBA55ACBA55ACBA55CC9A35CCCA763D3AD6ED8B47AD9B581DEBD90DABC96
C9AC8ABBA083B99F86B89E87B89C84B49880B2947CB3957BB5977BB29573B59870AE9262
A88B539D803E91701F94701A99711C9A701CA37623AB7E2BB38935B58B37B38D3AB8923F
B89241BA9443C09748C19849BE9748C39A4BC59C4CC4994AC19849C09748BE9748BE9748
BF9A4CC29D4FC29D4FC39E50C39D52C29C51C49D52C59E53C69C54C59B53C6A057C7A158
C6A258C39F55C39F55C7A359
B68E37BB9240C0994AC7A053C39D52C29C51C59F54C8A257C49F51BF9A4CC0994ABF9849
BF9849C69F50BF9A49BF9A49C5A050C39E4EC19E4DC19E4DBD9C4BBC9B4ABB9A49BB9A49
C7A452C3A04EC39E4EC19C4CC09B4BC39E50C7A156C6A057C7A156C7A156C9A559CEAA5E
D1AB62CCA65DCDA75CCDA75CCBA55CC49E57C3A05CD2AF6FDAB77DD7B681DEBD92DEC09A
CDB090BA9F82BAA087BB9F89B89C86B89984B6967FB4947BB5977BB59876B79A72B49868
AD90569D803C927320916F169671199C721CA67926AF802EB48734B68936B68D3BBB9240
BD9444BD9444BC9546C0994AC09C4EC09B4DC19C4EC39C4FC49D50C29B4EC0994CBF984B
C0994CC29B4EC49D52C39C51C29B50C29B50C49D52C39C51C9A257C59E53C8A058CEA65E
CCA45CC69E56C7A055C29B50
BA923BBC9341BF9948C69F52C29D4FC19B50C09C4EC5A153CAA554C49F4EC09A49BE9847
BE9847BE9847C09A49C09A49C49F4FC39E50C29D4FC19B50BE9A4EBC984CBC984ABD994B
C6A351CFAC5AC9A453BF9A49BE9948C39E4EC39E4EC5A052C8A355C7A254C7A254CAA557
CEA85DCDA75CCBA55ACEA85DCDA75EC49E57BE9B57D0AD6DDAB87BDAB984DEBD90DDBC99
D1B494C5A78DBFA38DBDA18CBC9D88BA9A85B89881B39178B49579B89A78B99970B59765
B193579F813B937221916D1798721F9C7220A77D2BAF8231B48638B7893BBA9142BA9142
BE9448C0964ABE984DC09A4FC09E54C09E54C09C52C6A258CAA459C49E53BF9A4CC09B4D
C29B50C19A4FC59E53C29B50C09850C19951C49E55C49E55CDA75EC9A35AC79F59CAA25C
CCA45EC9A15BC49C54C49C54
B9913CBC9343BF9849C49D50BF9B4DBD994BBC9948C5A251CCA854C19D49BD9744B8923F
BD9444C29949C0994AC19A4BC69F52C59E51C39C51C29B50BF994EBB954ABD9848BE9949
C5A04FD1AC5BCBA655C09B4ABB9645C19C4BC49D4EC49D4EC5A04FC5A04FC8A353C9A454
CBA658CAA557CCA65BCEA85DCEA85DC7A158BE9C55D1AE6CDCBA7DE2BF89DFBF90DAB892
D3B591CEAF92C3A88DBFA189BC9E84BC9C83BA987CB49374B89774BD9D74BC9C6BB09057
A98B459C7B2E926F1B916C1499711CA27826AD802FBB8D3FB18839B48B3CB38C3FB68F42
BB9449BE974CC39D54C59F56C19F55BC9A50C1A053C4A356C6A254C19D4FC09D4CC29F4E
C49F51C29C51C39D52C29C53C29C55C49E57C69F5AC59E59C8A25BC6A059C7A05BCBA45F
D0A964C8A15CC8A25BCBA55E
B68D3BBA9142BF9849C49D50C29E50BE9A4CBD9A48BE9B49C8A450C19D49C09A47BC9643
C19848C09748C0994CC49D52C8A156C69F54C39C51C19A4FC19A4DBD9649BE9847BD9746
C59F4EC6A04FC5A04FC29D4CB99443BE9948C39D4CC49E4DC5A14DC5A14DC7A251C5A050
C7A252C9A456CDA85ACBA658CBA55AC9A35AC09E56D0AD69D5B374D9B67EDAB984D8B78A
D7B78ED2B490C8AB8BC0A385BB9C7DBB9A7BB59471B79570BC9B70C1A170C5A56AAD8C49
A182329875218F6A11936B139E751DA07620A87E2AB58B39AE8835B38C3DB59040B38E40
B69143BB9648C6A153C5A052C4A052C4A052C4A354C3A253C1A04FBE9D4CBB9B48BC9C49
BE9D4CC09F50C19D51C29D56C49F58C49F59C59E5BC59E5BC59C5AC89F5DC6A15DC8A35F
D9B46ECBA660C7A25CC7A25C
B89241B6903FBC9747C09B4BC19C4CC09B4BBF9849BF9849C39A4AC39A4AC29949C19848
BE9847C29B4CC19D4FC49E53C7A156C8A156C79E4FC49B4CC09A49BE9847BF9946BF9946
C39A48C49B49C49E4BBF9946B5923EBC9947C09D4BC19E4DC39F51C5A153C39F51C39F51
C6A151C29D4DC7A254CBA55ACAA55EC9A460C6A15DD0AA69DAB473D6B274DAB77DDAB984
DEBC8EE0BD93CDAB85C6A47FC4A47BBFA074BB9C6DBB9B68BB9C63C7A566B7954EAD883A
A07C24977013996E109C6F129F7718A47B21AA822AB08833B08833B28937B4893AB78C3D
B88D3FBA9044BF984BC19D51C2A056C6A65BC7A75AC4A457C0A14FBB9C4ABC9C49BA9A47
BE9B4ABF9B4DC19C4EC39D54C39D56C19A55C29B58C59E5BC59F5EC39D5CC19E5AC6A35F
D0AE67C7A55EC2A058C4A25A
BE9845BC9643BB9645BF9A49C49F4FC19C4CBE9949BD9848BD9848BE9949C09B4BBF9A4A
BD9A49C09D4CC19D4FC39E50C39E4EC69F50C9A051C89F50C39D4CC39D4CC39A48C39A48
C49A48C69C4ACAA24DC09843B28E38BE9A46BF9C4BC29E50C5A155C8A458C8A257C6A055
C6A153C49F51C7A254CAA459CAA45BC9A35CCAA45DD0AA63D9B56BDDB871D8B772D8B676
D7B47AD4B17BD1B07BD1B07DD9B882CDAD74C8A86DC5A364BE9C5CBD9852B69045AF8634
9E761EA0771BA37819A27719A47C1DA98026AE872CB18932B48C35B8903BB88E3CB58A3B
B58C3CB98F43BC9749C19B50C2A056C5A359CCAC5FC8A85BBD9E4EBC9D4DBA9A47BA9745
BC9947C19C4CC19C4CC29C51C49C54C29A54C19A55C49D58C69F5CC59E5BC29D57C6A15B
CDA862C8A35DC49F58C6A15A
BF9644BE9543BD9744C09A47C49F4EC39E4DC09B4BBC9747B99446BD984AC09F50BF9E4F
BB9C4CBC9B4CC0A04DC7A251C49F4EC29C4BC39A48C69D4BC59C4AC59C4AC69E49C59B47
C89E4ACB9E4BC79D49C39945BC9641BF9946C19D4FC4A056C6A057C8A25BC8A25BC59F58
C69F54C7A055C8A154CAA356C9A257C8A156CBA658CCA759D5B05FDCB766D1B15ECFAE5D
CEAD60CFAD65D1AF67D8B66FD7B56ECEAC65CAA85EC6A258C09C4EBB9445B58D38B48831
B1862AA97C1FA67B1DA87D1FAA8125AD842AB28B30B58D36B9913ABA923DBA913FB38A3A
B88F3FBE9546BD984AC09A4FC09F52C2A056C9A95EC9A95EC1A051C3A253C09D4CB89544
BC9746C29D4DC39C4DC49D52C69F54C79F57CA9F5ACBA05BCA9F5BC89D59C39B55C69E58
C8A25BC8A25BC19C55C39E57
C59C4ABE9543B7913EC29C49CBA552C39D4AC29C4BBF9948B99444BF9A4AC6A254C6A254
BF9F52BE9D4EC09D4BC59F4CC39D4AC19846BE9440C49A46C59D48C59D48C49C47C69E49
C89E4AC49A46C39945C59B47C19B46C29C49C19D4FC39F55C59F56C8A25BC9A15BC79F59
C69E56C49C54C69F52C7A053C9A255CAA356CCA756CAA652CBA751CEAA52CDA84DCDA84F
CBA64DCDA752D0AA55CFA958D4AF5ECEA959C7A251BE9948BC9641B78F38BA9139BA8E35
B6892CB4872AAC8125B08529B38A30B48B33B99139BC943DC19944BE9543BB9240B99041
BD9647BC9548B99348C19B50C19F55C19F55C2A257C1A156C09F52C4A356C7A355BD994B
BD9848C09B4BC39C4DC59E51CAA054CDA359CFA55DCEA35ECBA05BC79C58C79D55C89E56
C8A058C9A159C29C55C19B54
C29949BA9141BF9644C9A04ECAA14FC29947C29846C19745BE9545C39A4AC8A152C8A152
C6A153C69F50C6A04FC59C4AC49A46C39945C1943FC59843C59D46C59D46C49C45C39B44
C79D49C89E4AC59C4AC49B49C29E4AC6A150C6A352C5A155C6A055C8A259C8A25BCAA45D
CBA35BC79F57C8A154C8A154C9A255CBA457CCA655CCA653C9A34EC8A048CCA548C8A041
C69D41C49B41C59C44CCA24ED1A856D6AD5DC6A04FC29C4BB9933EB38B34BB933BBB9238
BC9135B98D34B1882EB28931B38B33B38B33B78F38B78F3ABC9641BB9544B99342B58E41
BE974AC49D52C19D53C09C52BE9C52C2A056C09E54BE9C52C09E54C2A056C7A357C19D51
BF9A4CC09B4DC39C4FC59E51C99F55CBA157CBA159CBA159CBA05BC99E59C99F57C99F57
C9A159CAA25AC39D54BE984F
C09747BF9646C19848C59C4CC79E4CC19846BF9541C09642C29846C69C4AC79E4EC79E4F
C69F50C7A053CBA252C89D4EC79D4BC89B4AC49742C49742C39B44C19942BF9A42C09B43
C59D48CAA14FCAA451C7A150C5A050CAA555CCA85AC9A559C6A256C6A258C6A258C9A55B
CEA85DC9A358C9A456C8A355C8A257CBA55ACBA455CEA758CBA552C9A14CC79D47C49841
BD9138C59942C59843CB9E4DCEA555D2A95AC59E4FC59F4EBE9845B7913CB89038BC943C
C79E46BD943CB98F39B88E38B89039B68E37B78F38B8903BBB9540BA9443B79140B89144
BD984AC09A4FBF9B4FC19D51C39F55C4A056C2A056C2A056C4A056C5A157C4A056C6A258
C29C53C29C53C29C53C59F56C9A159C8A058C59D57C59D57C69E59C79F5ACAA058CAA058
CAA25ACBA35BC49C54BD954D
BE9440BD9341C49B4BC9A050C79E4CBF9644C09843BF9742C29A45C69D4BC79E4CC79E4F
C59E51C69F54C69D4EC69D4EC89D4EC69B4CC79D49C59B47C49C44C19941BC973FB8923D
C09843C89F4FC79E4EC89E52C8A355C7A156C9A559C8A458C7A359C7A359C5A359C5A359
C6A556C3A253C5A153C5A153CAA65ACDA75CCDA75CCFA85DCCA556C9A051C79E4EC09546
C39945C69C48CBA14DCEA452D2A959D5AC5DCDA756C39D4AC19B46BD9840B9943BBC973F
C29A43C59D48BA923ABA923ABC943CBA923AB99139BB933BBA953DB8923DB6923EB48F3F
B99645C09C4EC09C4EBF9B4DC09C4EC19D4FC5A155C4A054C29E54C49F58C6A15ACCA761
C9A45EC39E58C49E57C6A059C9A35CC8A25BC69F5AC69F5AC7A05DC69F5ACAA25CCAA25A
CCA45CCEA65EC69F54C0994E
BD943CBE9440BF9946C39D4CC49E4DBE9847C09A45BA943FBC9641C29C49C59F4EC7A053
C59F54C49E55C29B4EC19A4DC49B4CC69D4DD0A654CBA14DC5A047C39E45B9943CB9913C
B8903BBE9344C4994BC59950C39C51C79F57C6A256C9A55BC8A45AC8A35CC6A45AC4A258
C3A454C3A454C4A354C4A354CAA65AC9A559CCA65BCCA65BCCA558CCA558CCA55AC8A154
C89F4FC69D4BC69E49CFA654D8B25FDAB463DEBA66CCA852C29E46C09D43BA953CBD9840
C49C47C59D48BF9740BA923ABD963BC0993EBE973CBD963BB9943BBA953DBF9B45B69140
B79442C09D4CC29F4EC09D4CC19E4DC09C4EBE9A4CBF9B51C09C52C19C55C6A15BCCA761
D0AB67C8A35FC49F5BC5A05CC6A15BC7A25CC8A35DCBA660CAA561C7A25CC8A25BC8A259
CAA45BCFA960C8A156C59E53
BE953DBE943EC09642BF9541BE9641BE9641BC943DBB933CBB9540C09A47C6A150C5A052
C5A153C29E50BF9A49C19B4AC39D4CC69D4EC9A051D2A95ACCA854C39F49BF9A42BB933B
BA923AB98F39BD933FC09546C3994DC69C54C59F56C6A059CAA55FC9A45EC9A45ECBA660
C2A058C3A159C3A255C6A558CAA65ACAA65AC9A55BCAA65CCCA65FCCA65FCDA760CFA962
C8A058C39B53C9A255CAA356CDA657CCA556CDA454CFA656C9A352C6A04FBF9948C09A49
C39D4CC49E4DC19846BD9540BC973FBE9940BC993DBA973DBA973DBB9741B99740B99642
BC9945C09D49C5A14BC5A14BC09C46B6923CB99642BB9846BC9948BF9B4FC29E54C9A45E
CCA761C8A35FC39D5CC49E5DC6A15DC6A15DC9A760D1AF68CAA861C5A35BC7A359C6A256
CBA55ACDA75CCBA457C7A053
BF963EBE9440BC923EBF9543BF9644BC9341BC943FBC943FB9933EC09A47C7A34FC49F4E
C29D4DC39E4DBD9945BF9B45C59F4CC59F4CC6A04FCCA655CBA751C5A149C19E44BB963B
B69138B89039BD933FC29748C39A4BC59B51C59F56C9A35CCCA560CDA661CAA55FC9A45E
C4A25AC5A35BC5A359C6A45AC9A75DCEAC62CCA760CAA55EC8A35CCCA760D5AF68CEA861
C7A158C6A057C7A254C8A355CCA556C59E4FBA9443C29C4BC7A150C39D4CBF9849C0994A
C5A050CAA354BF9948BF9644BF9740BE963EBA953ABB963DBC993FBC9842B9953FBA9642
BD9945C19D49C8A24FC49E4BC19B4ABE9847BA9642B69140A88332BC9749C39F53C39E57
D3AE67C49F59C49F5BC39E5AC09E57C2A059C4A25BC7A55EC6A45DC7A55DC4A258C3A255
C8A458CAA65AC9A456CAA557
C19941BF9742C09843BD9442C19846C29947BF9742B68E39B9943CC5A048C19B46BF9944
C6A04DCAA44FC2A047BF9B43C19D45C29C47C59F4AC6A04BC4A249C09E45C19E42BD983D
B79237BB933BBF9740C59C4AC09A49C19A4DC39D52C8A259CBA55ED0A964CCA761C8A35F
C6A35FC9A662C7A55EC3A15ACBA962D8B66FCAA860C4A25AC5A059CDA861D7B26BD5B069
CDA75EC7A158C7A254C5A052C7A252C39E4EBC9746BB9645BE9948BE9948BE9949BD9848
C7A254D5AE61CBA252C89E4CC19944BD953EBD963BBB933BBC973EC59F4ABD9742BC9643
BD9744C19B48C9A352C49E4DC39A4BC19848BC9641B28C37B38D38BB9544C09B4BC39D52
C29E54C49F58C09E56C09E56BE9C54C2A058C4A25BC19F58C5A35CC7A55DC4A258C4A356
C5A455C5A455C8A456CDA95B
C79F47C29A43C29A45C19846C09745C29947C09843C19944BC943DC09841C49C44C69E46
C39E45C5A047C7A649BE9B3FBD9A40C29D44C6A149C49F47C2A046C4A248C2A144BF9C40
BB983CBD983FC39B44C79E4CC09B4AC09B4DBB974BC39F55C6A15AC9A45DC8A65FC9A662
CAA763C9A664C8A563CAA765CFAA66D3AE6ACBA660CAA55FC49E57C8A25BD9B36CD4AE67
CBA55CC7A158C8A355C6A153C8A152C39C4DC09A49BF9948BF9946BE9845C09A49C39D4C
C8A251CFA958DBB260C9A04EBE963FBD953EBB933BBC943DBE9941C29C49C09A47BC9645
BC9645C29C4BC8A251C49E4DC39C4DBF9948BF9740BC943DBE963FC19846C29D4CC19C4C
BD994BC09C4EBE9D50BE9D50BD9B51C09E54C5A35BC3A159C8A35CC7A25BC7A357C7A357
C8A456C7A355C9A557CDA95B
BF983DC29A43C39B44C8A04BC29947C39A48C39B46C8A04BBD953DBB933BC59E43C9A247
C39C3FC49D40C5A244BF9C3EC09B40C49F44C39E45C39E45C2A046C7A54BC3A245C09D41
BF9C42BE9941C09B43C19B48BF9B47BF9A4AB99847BC9B4EBF9E51C4A25AC7A55DCBA962
CAA763CBA864D0AA69CDA766D2AB68D3AC69CCA45EC9A15BC49C54C59D55D0A860D6AE66
CDA55DC59D55CCA558CDA659CAA354C59E4FBF9946BE9845C09745C09745C09843C69E49
C9A14CCEA651CCA74FC8A34BC29D44BD983FBB963EBC9641C09A47C59F4EC59E4FBD9647
C09A49C9A352C39D4ABF9946C19B4AC39A48C39B44C19840C39B44C29A45C39D48C39D4A
C09B4ABE9948BE9B4ABD9A49BE9A4CBF9B4DC39F53C39F53C6A057C7A158C9A257C9A257
C9A358CAA459C9A559CBA75B
B0892EBB933CC19942C29A45C39A48C69D4BC79F4AC49C47C09841C09841C0993EC39C41
C7A041C69F40C39F41C29E40C39C41C49D42C39B43C59D45C09D43C19E44C19E44BE9B41
C19C44BF9A42BF9944BF9946BF9B47BF9A49BD9C4BBB9A49BE9D4EC1A053C6A558CBA961
C8A65ECAA861CBA662D2AD69D7B06BD0A964CEA65EC8A058C49A4EC49A4ECBA157D3A95F
D6AC62D0A65CCAA054CCA256D0A65AC69C50BB9242C19848C39A48C29947C29947CAA14F
CDA34FCBA14DCAA54DC6A149C39E45BE9941B9943CBF9946C9A352CCA556C69F50BD9647
C29C49CCA653C19B46BB9540BE9843C59D48C49C44C79E46C59D46C49C45C39D48BF9944
C29C47BF9944BD9943BC9842BF9B47C09B4AC19B4AC0994AC0994CC69F52C7A055C9A257
CBA459CCA55AC9A559C9A559
BD943ABE953DBE963EBF9740C69E49C9A14CC59D48C69E49C49C45C19942C19A3FC49D42
C79E42C2993DC49B3FC49B3FC69A41C59940C49B43C79E46C29D45C09B43C09C44BE9A42
C39D48C29C47C09A47C29C49C19E4CBF9C4ABF9A49C19C4BC09D4CBE9B4AC19D4FCBA75B
C9A559C7A359CFA962CDA760D1AB62D0AA61CEA75ACAA356C89F4FC2994AC89F50CCA256
CCA558CDA659CBA459C49D52C59E53C59E53C49D52C49D52C79D51C99F53C89F50CCA354
D1A858D0A755C49E49C5A048C39E46C19C44C09A45BD9744BF9948C69F50C29C4BBC9645
C19B46C7A14CC19C43BE9940BE9941C5A048C69E47C79F48C59D48C49C47C79F4AC59D48
C8A049C29A43BC943CBE963EC29A43C49C45C29A45C09745C09745C79E4FC7A053CBA459
CCA65BCBA55AC6A258C5A157
C39A40BD943CB68D35C09640C19944C59D48C59D48C49C47C29A43C19942C39B43C39B43
C79E42C59C40C49B41C59C42C99D46C69A43C69944C39943C39B44C49F47C39F47BF9B43
C29C47C29C47BE9845C29C49C19E4CC09B4AC29D4CC19B4AC09A49C29C4BC39E4EC6A153
C7A254CBA55ACEA85FCDA75ECCA65BCAA459C9A454CBA656CBA552C49E4DBF9948C59E4F
C59E51C69F54C8A156C49C54C49E57C49E57C69E58CBA35DD1A961D1A961CFA85DD1AA5F
D6AC60CEA556C59C4AC19944BB933CBD953EC49C47C19846BD9442C09747C39A48C39B46
C59D46C39B43C39B43C29A42BF9740C59D46CCA44FC69E49C79F4AC69E49C59D46C8A049
D1A850C39A42BA9137BE953BC0973FC39A42C29842C29842C39945C69D4DC9A255CCA65D
CDA95FC9A55BC39F55C39F55
C19A3FBF983DBF963EBF963EBD943CBF963EC19941C19941C19941C19941C19840C49841
C89B46CEA04BC79B44C69A43C79A45C79A47C89B48C69948C89B4AC89B4AC59B47C49A46
C29A43C49C45C09C46C09C46C09D49C09C48C19B48C49B49C39A48C39A4AC39C4DC59E53
C6A055CAA45BCBA75DCDA95DC5A251BC9945C39F49CAA64EC8A34BC6A04BC4A04AC4A04C
C39E4DC19C4CC19C4CC19B50C19B50C39D56C59F58C8A15CCEA660CFA761C9A257CBA459
CEA758CDA756C89F4DC29A45BB9240BA913FC39A4AC89F4FC4994AC29748C69C4AC49A48
C69C48C49A46C49A46C29844C09745C29947C39A48C59C4AC79F4ACAA24DC7A24AC7A24A
CBA64DC49F46C29B3EBE973ABF9839C0993CC49B3FC29941C39947C49B4CC6A151D0AC5E
CDA95DC6A256C19F55C09E54
C39C41C39B43C29A42BB933CBA923BBA923BBD953EBE963FC09840C09840C29842C29842
C59843C89B46C69C48C59B47C49A48C59B49C79C4DC79C4DC89D4EC59A4BC59B49C49A48
C59D48C69E49C49C45C39B44C19C44BE9941BF9742C19944C29A45C19846C19846C19849
C29D4DC7A254CAA658CCA958C8A553BF9D46BF9B43C19E44C19C44C6A04BCBA753C5A04F
C19C4BC09B4BBD9848B99348BB954AC39D54C39D56C8A25BC9A35ACAA45BC9A456CAA557
CAA554CCA756CFA956C29C49BB9542C09A47C49B4BC49B4BC49B4BC39A4AC59B49C39947
C39B46C39B46C69D4BC59C4AC09A47BE9845C19846C29947C39B46C79F4ACAA24DCCA44F
CEA651C8A04BCAA24AC19941BE973CC0993EC49C44C19942C19944C49B4BC39E4ECDA85A
CCA759C7A156C4A054C39F55
BE963ED1A952C39E46C39D48C09843C09843BF9742C09843C19743C29844C29844C19743
C59B47CDA351CAA453C59E4FC39A4BC49B4CC79E4FC69D4EC79E4FC59C4DC99E50C79C4E
C89E4CC69C48C49A44C49B43C49B3FC2993FC0973DC19840C1983EC1983EC19840C19741
C19B46C59F4CC8A450CEAA56C8A64DC19F46BC993FB9963CC09B42C19C44C4A14DC4A14F
C29F4DBF9C4ABE9949BF9A4AC09B4DC19C4EC09C50C19D51C4A054C8A458C7A355C8A456
C9A655CCA958C49F4EBD9847BB9645C19C4BC19B4ABF9948C59C4AC59C4AC59D48C59D48
C69E49C59D48C29C49C29C49C29D4CBF9A49BF9948BF9948C29947C69D4BCAA14FCDA452
CEA354CA9F50C79E4CC79E4CC49C45C29A43C29D45C19C44C09A45BF9946C39D4CCAA354
C9A456C7A254C6A055C49E53
BD983FC29D45CCA651CAA44FCCA653C59C4AC29947C39947C39945C39945C29844C09642
C49B49CEA555CCA655C49D4EBF9849C19A4BC49D50C29B4EC49D50C59E51C79D51C79D51
CA9F50C89E4CC99C49C69A43C3973EC3983CC3983CC1963AC09537C09537BE9637BF963A
C0993EC49C44C6A149C9A44CC9A64CC3A046BA953AB89338BE963EC39B44BF9B47BE9948
BC9844BD9945BF9A49C09B4AC19C4CC29D4DC39E50C39E50C49E53C6A055C5A155C9A559
CAA65ACAA65ACCA85AC4A052BD9848BF9849C19B4AC39A4AC49A48C39947C69C48C69C48
C49B49C29947C19B4AC59F4ECAA555C7A252BF9948BE9847C29947C49B49C89E4ACAA04C
C99F4DC99F4DC89F4DC69D4BC19B46C29C47C7A24AC5A048C49E49C39D4AC49F4FC7A254
C8A355C5A052C5A052C5A052
B9943CC29C47C6A04BC9A350CAA451C59C4AC69D4BC59B49C39947C39947C29947C19846
C29C49C8A251CAA151C49B4CC19849C39A4BC39C4FC29B4EC49D52C59E53C7A055C8A156
CAA152C79E4EC99F4DC59B45C39A42C59C42C29739C09537BE9432BE9432BE9432BE9334
BF9738C2993FC5A045C8A34AC7A247C9A449BE993EB48F34C09840C59D46C19C44BE9843
BE9641C09843C19944C09745C19846C59C4DC59E4FC8A156C49D52C29A52C49E57C9A35C
C8A25BC8A25BD0AA5FC49E53C0994AC29B4CC59C4AC19846BF9541C49A46C49744C69946
C69C4AC29748BE9847C39C4DCEA75AD0A95CC0994ABE9847C19846C39945C59B45C99C47
C59B47C69C48C8A04BC8A04BC6A149C39E46C29E46C19D47C6A04BCBA554C8A355C8A257
C6A254C4A052C3A04EC3A04E
C09841BF9740C39B46C69E49C39B46C39B46C19944C19944C09843C09843C19846C39A48
C49E4BC79E4CC89F4DC69C4AC39A4AC39A4BC59C4DC69C50C8A156C7A055C49D52C7A055
CBA253CCA353CDA452C69E49C49C44C2993FC1983CC09537BE9432BE9432BF9531C09634
BE9636BE9539C7A045C79F47C8A34AC9A44BC29A42BC943CC09840C49C45C49C45C69E49
C69E49C49C47C49A46C39947C29947C39A4BC59C4DC69C52C59E53C8A058C49E57C39D56
C49E57C8A25BDCB66BC8A257C19A4BC29B4CC59C4AC59C4AC59B47C69C48C89E4CC69C4A
C39A4AC09747C19A4BC59E4FCAA354C8A152C59E4FC09A49C29947C39945C59B45C99C47
C59B45C49A44C29D44C39E45C4A147BF9C42BE9A42C29E48C6A04FC7A053C8A458C8A458
C7A355C4A150C19E4AC29F4B
C0973FC29941C39943C29842C29842C49A44BE963FBA923BB8933BBC973FBE9843C09A47
C29C49C29C4BC79E4CC59C4CC39A4AC49B4CC79D51C99F53CEA45ACDA359C79D51C69C50
C89F4FC9A050C9A14CC59D48C9A149C19941BF963ABC9435BE9334C09634C19735C19637
BE9637BB9238C39B43C79F48C6A149C7A24AC49C44C09840C59B45C29844C69E49C79E4C
C79F4AC69E49C59C4AC49B49C49B4BC69D4EC59C4DC2984EC69F54CEA65EC6A059C09A53
C29D56C8A35CCFAB5FC6A256C39E4EC39E4EC39D4AC39D4AC49E49C39D48C6A04DC49E4B
C49E4DC29C4BC39C4DC59E4FC5A050C49F4FC59F4EC29C4BC49B49C39A48C49A46C89E4A
C89E48C49A44BD983FBC973EC3A044C09D43BD9840BD9744C39A4BCAA056CBA55ACCA65B
CAA557C6A150C19D49C29E48
C49841C49841C79B44C79B44C59942C69A43C9A149BC943CB59037BA953DBE9941BF9944
C29C49C49E4BC7A14EC29C4BC19B4AC59E51C9A255C7A055CBA157CBA157C89F50C69D4E
C89F4DC9A04EC79F48C79F48CEA64EC19941BB9236BC9435BF9737C19937C09836BF9737
BF963ABC933BC19942C59D48CAA24DCBA34EC69E47C49C45C79D47C89E4AC59F4CC6A04F
C89F4FC9A050CAA151C9A050C89F50C79E4FC49D50C19A4FC29C51C7A158C39F55C09C52
BE9D50C2A154CBA75BCBA75BC4A150C3A04FC6A34FC3A04CC39F49C39F49C5A14DC39F4B
C49F4EC29D4CC5A050C6A151C3A04EC39E4DC29D4CC39D4CC69D4BC49B49C49A48C99F4D
CBA250C79E4CC39F47C09C44C5A248BD9941B8933BBE9543C19849C69A4FCEA75CD0A95C
CCA556C6A04FC09A45C29C47
C69D45C89F47CBA14BCBA14BC59B45C59B45C59D45BF973FBA9336BD963BBE993EC09B43
C49E49C59C4ACBA250C49A48C29949C59C4CC8A251C9A352CAA354C7A051C7A053C39C4F
C89F4FC89F4DCBA14DC89E48CEA54BC59C42BB9334B58C30BF963ACEA54DCBA34BC29A43
BA943FB9933EBB9741C29E48C7A34BCAA54DC6A04BC69E49C49B49C79E4CC49E4BC7A14E
CCA353CDA454CEA556CBA253C7A053C59E51C49D4EC39C4DC19E4DC29F4EBD9C4BBB9A49
BD9E4EC1A051C8A458D3AD62C8A458C29E52C7A453CCA957C3A04CC2A049C29F4BC29F4D
C4A14FBF9C4BC4A052C5A153C4A150C6A151C6A150C49E4DC49B4BC49B4BC59B49C79D4B
C99F4DCBA14FCDA752D5AF5AC39D48BF9944BB963EB69139BE963FC59D48C7A34FCDA857
CAA44FC8A24DC4A147C29F45
C69E46C69E46C89F47C89F47C49A44C59B45C39C41C0993EBC9538BE973CC39E43C29D45
C29C49C59F4ECCA351C79E4CBF9948C29C4BC49F4EC49F4EC7A252C7A252C7A252C6A151
C7A150C7A14EC59D48C69E47CAA147C59C42BE9637B99034BD9438C39A42DBB35BC49C45
B9933EBA943FBA9640C19D47C39F49C5A14BC49E4BC49E4BC69D4DC79E4EC59F4EC7A150
CEA758CEA75AD2AB5ED0A95EC7A055C69F54C69F52C29B4EC09B4BC19C4CBD994BBC984A
BD9C4DC1A053C6A558C6A45AC6A258CAA65AC8A456C8A554C3A04CC09D49C19E4AC3A04E
C3A04EC4A150C4A052C39F51C5A251C49F4FCCA655C89F4FC59A4BC29748C99C4BC89B4A
C89E4CC99F4DCEA651D1A954C8A24DC39D48C39B46C29A45C29A45C79E4CC6A04DCAA453
CCA44FC9A14CC6A149C49F47
C59D45C49C44C49C44C39B43C49A44C59B45C69D43C9A046BF983DB48C34BE9940C29C47
C29C4BC49D4ECAA554CDA857C19D49C09C48C09D4BC3A04EC6A351C29F4DC19C4BC5A04F
CBA753CDA955C7A24AC49F47C59E43C2993FC09839C2973BBE9539C19840C9A149C79F4A
C09A45BA9441B7933FBE9A46C19C4BC7A251CAA354C9A253C7A051C39C4DC39E4EC39E50
CAA356CDA55DD4AC64D8B06ACEA65EC79F57C7A053CCA558C59E4FBB9445BA9547BE994B
BF994EC29E54C3A157C3A35AC7A55DCDAB61CAA65AC8A554C49F4EBB9743BF9B47C39E4D
CAA554CBA656C5A052C49F51C4A14FC39E4DC7A14ECEA553C89E4CBD9341C79A49C79A49
C79A47CB9E4BCBA14DCCA24ECBA34ED0A853CEA553C69D4BC89F4DCAA14FCBA250CAA14F
CBA250C89F4DCBA14FC99F4D
C39E46C19C44C29A42C19941C49B43C69D45CCA349C39A40BD9639B48D32B59037BF9944
C6A04DC6A04FC9A453C8A352BF9B47C19D49C29E4AC29E4AC5A14DC39F4BC39F4BC4A04C
CCA653CEA855CBA64EC49F47C39B43C29941C0973BC2973BBE953BC29941C29D44C39D48
C39D48BD9744B89241BD9746C7A051CCA556CDA85ACDA85AC7A254C6A153C09B4DC39D52
C7A156CCA65FCDA760D3AC67D6AE68CDA55DCAA358C7A053C59F4EC19B4ABD9647BE9748
C0994CBF994EC5A359C7A75EC6A45ACBA75BCAA658C7A251C29C49C09A45C09843C39A48
C59C4AC79E4EC49E4DC59F4EC9A551C49E4BC39D4AC79E4CC9A04EC89F4DC79D49C59B47
C69C48C79D49C99F4BC99F4BCAA14FD2A957D0A755C69D4BC79E4EC9A050C8A24FC7A14E
CCA44FCAA24DCAA04EC89E4C
C39D4AC29C49C39B44C19942C59D45C8A048C69D43C1983EBC9538B68F32B58E33BF973F
C29D45C8A24DCAA451C49E4BC09A45C19B46C39D48C29C47C49E49C39D48C39D4AC29C49
C89F4DCAA14FCCA44FC9A14CC79F48C59B45C39A42C49841C09840BF973FC09B43BC9641
C6A04BCAA453BB9544B89142C59E51CAA356D1AB60D4AE63C7A359C6A258C39E50C39D52
C39D52C6A057C8A25BCCA65FD2AC63CEA85FCDA659CAA356C7A150C49E4DC29949BE9545
BF9646C19A4BC49F51CCA85CC8A355C49D50C6A04FC9A04EC49A46C29842BF923DC09340
C79D49C39947C59C4CCAA151C6A04BC59F4CC49E4BC49E4DC6A04DC6A04DC7A14EC59F4C
C69E49C59D48C79F4AC59D48C59F4CC59F4CC6A04FC8A251C29D4DC7A252CFAA59C9A453
C9A34EC9A34EC79F48C79F4A
C39D4AC39D4AC59D46C49C45C69E47C9A14AC19A3FC0993EBE973AB89134B18A2DBB9439
C39B43CAA24BCEA651C79F4AC69E47C39B44C49C45C49C45C49C45C39B44C09843C49C47
C69D4BC9A04ECAA151CBA252CAA151C89F4FC79D49C49A46C19944C29A45C19D45C29E46
C59F4AC09A47BD9744BD9647B89142C49D52D0AA5FCFA960CFAD63CAA65CC7A355C19C4E
BE984DBF994EC7A359C8A45ACAA45BCFA960DCB769C9A456C49E4DC6A04FC29C49BF9946
C29947C09747C39E4DC6A151C69F50C79E4FC69D4BC49A48C29540C39641BC8F3CC39645
CBA14FC79C4DC89F4FC89F4FC59F4AC39D4AC09B4AC09B4BC49F4ECBA655D8B460C6A24E
BD9742C39D48C49B49C49B49C19B4AC09A49C29D4DC49F4FC29E50C8A456D6B362CDAA59
C6A24EC6A04DC39E46C69E47
C49C47C59D48C59D45C49C44C79F47CBA34BC79F47C39B43BD9639B99235B78E34B99036
BE953DCEA44ECDA54EC69E49C59D45C69E46C59D45C19941BF973FC29A43C29A43C69D4B
C79E4CC9A050C9A253C8A152C9A255CAA054C9A051C89D4FC39D4AC09A47C29E46BF9B43
BF9B43BF9944BF9944BD9444BE9546BF954BC49E53C9A35ACBA961D3AE67CAA65CC39D54
C29C51C09A4FC5A157C5A157CBA75DD1AD63CEAA5ECDA95DCCA759C8A353C49E4DC29C49
C29C47C19B46C49E4BC59F4CCBA252C69D4DC29846C29846C19743C19743C19745C29748
C89F4FC59C4DC59E4FC9A253C5A14DC49F4EBE9748BE974AC7A252CDA858D6B160CBA655
C6A04DC19B48C59C4AC69D4BC39A4AC49B4CC49D4EC0994CC39F53C6A256CFAA5CCBA656
C7A150C59F4CC29D45C09B43
C59B45C39A42C29B40C39C41C8A048CEA64ECCA44CC49C44C0993EBB9439B68D33B78E36
BE923BC29842CAA24BC9A44CC8A048C69E46C39C41C0993EBB933BBC943DC39B44C39A48
C39D4CC8A154D1AA5DCAA358CAA459C9A257C69F52C79D51C6A04FC59F4CC29E48C29E46
C09C44BF9944BC9641BF9646C09748C2984EC39D52C39D54C6A45CCBA65FD0AB64C8A25B
C59F56C39D54C29E52C29E52D1AD63CDA95FCDA95FCDA95FCFA95ECDA85AC8A353C49F4E
C49E49C49E49C39B46C59D48CDA452C9A04EC49B4BC39A4AC19846C39A4AC49B4BC59B4F
C59E51C69F54C59F54C7A156C6A352C6A151B69143BB9447C59E4FCCA556D3AD5CCFA958
CAA14FC19846C79D4BC59A4BC79C4DC29749C39C4FC59E51C6A055C7A156C8A154C9A255
C8A251C7A150C59F4AC29C47
C49D42C29B40C29B3EC49D42C49F46CCA651C7A14CC59F4CBF9944BA943FBB933BB58D35
B99038BE953DC79D47D2A852CAA149C59C42C89F43CFA748BC9337B88F37C19944C59C4D
C49C54C9A15BCCA65DC9A358CBA759C5A250C29E48C8A44EC7A14CC59F4CC69D4BC79E4C
C49C45C29A43C09843BB9240BF9948C0994CBE984DC29C53C39E57C7A25BCAA45BD0AA61
C59F54C49E53C29C51C19B50C6A057CBA55CC9A55BCBA75DCDA95DCDA95BC7A453C4A14D
C6A44DC39F47BF9B45C09A45C79F4ACBA34EC89E4AC49A48BF9644C39A4BC59E4FC69F52
C7A254C5A052C7A254C6A153C7A254CBA658C19C4BB99443C29F4EC7A453D3AF61DAB668
CAA555BF9A4AC49E4DC7A150C69D4DC2994AC39C4DC59E53C8A058C79F59C59F54C6A055
C8A353C8A352C3A04CC09E47
C1983EBD9438BA9336C0993EC7A045CCA44DC8A34BC59F4AC5A048C39E46BF973FBF973F
BA9137BD943CC29941CDA34DC89F47C59C44C49B3FC59C40C2993FBB923AC09745C49B4C
C59F56C9A35CC9A55BCAA65ACBAA5BC3A04EB7953EC5A14BCBA550C9A350C6A04DC39D4A
C49C45C29A43BF9740BB933EBA943FBB9544C0994AC49D50C49F51C6A055C9A358CDA75E
D2AC61C6A055BD984ABF9A4CC19D51C5A155C9A559C8A458CAA658CAA658C5A250CAA755
CFAB55C5A14BBF9B47C19D49C59F4CC7A14EC89F4DC69D4BC09A49C49D4ECAA555C7A254
C8A257C6A055C7A156C59F54C6A153CBA658C59F4EBF9948BF9A4AC5A050CEAA5CD0AC5E
CCA958C8A353C7A251C8A251C59F4EC29B4CBD9647C39C51CAA358C9A159C59F56C8A259
CEA85DC9A358C39E4EC39E4E
BC9339BC9337B88F33BD943AC59E43CBA34CCCA74FCEA853C7A24AC49F47BF9A3FBD983D
BB9439BE963EC29A42CBA34CC59C44BF963EC69D41C89F43C2993FBE953DBE9641B99040
C29C51C5A157C8A65CD0B063C8AB5BBD9E4CB89541C4A04CCAA554C7A251C7A14EC49E49
C59D46C19941BF983DBB933BB99139BC943FC29A45C69D4BC49E4BC59F4EC99F53D3A95F
D6AF62CAA356C29D4DC09B4BC19E4DC5A251C5A251C6A352C7A453C7A453C9A453CEA958
CEAA56C5A14DC29D4CC19C4BC29C49C59F4CC6A04DC49E4BC39D4CCFA859CFAA5AC9A456
C7A156C7A156C7A156C49E53C6A055CBA457C69F50C39A4ABA9545C39E4ECBA759C7A355
C9A655C9A655C9A453C8A352C59F4EC39C4DBA9344BE974CC69F54CBA35DC9A45DC7A25C
CAA45DC9A35CC49E55C6A057
BE953BB58C32AF862CB48B33C39B43CFA752CFA954CAA451C09A45C09A45C39E45BF9A41
BD963BBA9338BE963EC39B43C59D45C59D45C49B41C39A40C0973DC0973FB6903BB99342
C29E50C9A559C6A65BC7A75AC6AB5ABFA350B89748C4A052CCA65BCBA55ACBA455C7A150
C79F4AC29A43C0993EBE973CBC933BC0973FC29A42C29A42C49C44C69E47C59A4BCDA254
E2BB6CCEA758C6A151C09B4BC3A04FC29F4EBE9B4AC4A150C8A353C7A252C7A251C7A251
C6A04DC39D4AC29C49C39D4AC49E4BC39D4AC79F4AC8A04BC69D4BCBA250CEA857C8A152
C6A151C5A052C69F52C59E51C7A053C9A255D0A757C29949B58E3FC19A4BCCA759C5A052
C5A153C8A456C7A453CAA756C6A151C19C4CBB9447BD9649C3994FC9A159CBA55CC6A15A
C29B56CAA35EC8A15CC69F5A
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{288, 288},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`002P3oool40:67EP@0UWU1102<Kbd408UX8@@0OE/C1022GQ@509=]9P@0
VW@]102GLBX409]e;P@0Wg/a102SOcD40:J5>0@0ZXTl102]Rd450;JDBP@0/i57102fU4X80;bHC0P0
_9U8202oVdL50;ZF@0@0]Y8l102iTd040;ZD@@@0_9I51031VdX40;nIAPT0_9I3102jU4440;ZEA0@0
^9=2102hTd<40;fHB0@0`Ia>2030Vdd50<6LCP@0_iQ9102nUdP40<>MC0@0aIm>1034XE080<:ND0@0
_9Q<1@2lUTd40<>ME0@0`Ia>1032WDl40<VSDP@0cJMF102nV4L40;F>?`@0]H`m1@2lTTP40<>GCP@0
aI]C1036WUP40<FOF0@0aJ1I1034WeP40<:ME`D0`iiH102nW5@40<2NEP@0a:1F103:YU`40<FQE`@0
`9aB2030VU<50<>LE`@0aj1K2037XU/40<>QFP@0`ImH1035X5`40<JQG@@0aj1M1@39XUl40<VQF`@0
aYiH1031Udd80;jDBP@0`YQ>1037WE<50<JLDP@0a9eB1032Ve040<6ID@@0`9Q@1032W5<40<VSFP/0
oooo000:0?ooo`@0XHMF102FND4408a_;@@0RFPQ101mFa<4089N50D0TfdV102JM2d409Ma:P@0VgD^
102ONc440:=o=@@0YXDh102ZRC`40:f;@@D0]YA:102cTDL40;JDBPP0_9Q<202lVDP80;nKA`D0^YI0
102fTS`40;VC@0@0^YA1102lUTD40<6KBP@0_iU62@2lUT<40;ZD@@@0^YE4102hTd840;RC@`@0_IQ8
1031W4h80<2KC@D0`Ia>102oV4T40;jGB0@0`ie<1035Wdh40<BQD0P0`Yi@102lV4`50;bFC@@0`ieD
1031W4h40<:MC`@0bJ=B103=YeH40;jHA`@0]Hho102eS3d50;bBB0@0`iM>1035Ve<40<JNF0@0aImH
1035X5T40<BOF0@0`YeG1@33WUP40;jLE0@0`9iF1034X5H40<ZVG0@0aJ5G1030W5880<2JD`D0`iaG
1037X5/80<NRF`@0`j5J1031WeP40<FPG0@0aZ5M1037X5d50<VRG`@0bJ5K1036WUP40<6GC@P0_YA:
1032V4h40<NMD`D0aYaB1034WE840<:KD0@0`IUA1030V5040<:LD`@0bJ=J2`3oool000X0oooo102Q
QeH409Ii@@@0S6l]1029J24407eK4`@0PUhD1@2CKBH409Yd;@@0Ug4Z102KMBh409mk<@@0Xgle102V
QCP40:Z9?0@0[H]11@2fU4X40;>AA`@0]YA:202lV4`80;bIB0P0_i]71@2jUT040;JB?0@0^I=0102j
U4440;bFA@@0`I]:102oVDH90;bF@`@0^YA1102jUD@40;RC@P@0^9=3102mV4P40<6LCPP0`9]=1@31
W4h40;nHB@@0_YM81033WD`40<FOCP@0a:5@2032WU040;bHC0D0_9I=1033WE@40<6LCP@0`Ye?1039
Xe840<fWEP@0_YQ7102eSSl40;F<?@D0_9981033Udh40<FKD`@0aYiH1035WeP40<FPF@@0a9mH1032
WEL50<>NF0@0_YaD1030WUH40<BPEP@0bZIL1035XEL40<2LDPP0`9YC1@33W5L40<NPF`P0aj9K1033
XEX40<6OF0@0aJ1L1036XEd40<NPG@D0bJ9O1039XE/40<JNF0@0`IM=202nU4X40<:HCP@0aieC1@36
W5840<BMDP@0`Y]@1031VE440<2HD0@0`YaC1039XeX;0?ooo`002P3oool40:67EP@0UWU1102<Kbd4
08UX8@@0OE/C1022GQ@509=]9P@0VW@]102GLBX409]e;P@0Wg/a102SOcD40:J5>0@0ZXTl102]Rd45
0;JDBP@0/i57102fU4X80;bHC0P0_9U8202oVdL50;ZF@0@0]Y8l102iTd040;ZD@@@0_9I51031VdX4
0;nIAPT0_9I3102jU4440;ZEA0@0^9=2102hTd<40;fHB0@0`Ia>2030Vdd50<6LCP@0_iQ9102nUdP4
0<>MC0@0aIm>1034XE080<:ND0@0_9Q<1@2lUTd40<>ME0@0`Ia>1032WDl40<VSDP@0cJMF102nV4L4
0;F>?`@0]H`m1@2lTTP40<>GCP@0aI]C1036WUP40<FOF0@0aJ1I1034WeP40<:ME`D0`iiH102nW5@4
0<2NEP@0a:1F103:YU`40<FQE`@0`9aB2030VU<50<>LE`@0aj1K2037XU/40<>QFP@0`ImH1035X5`4
0<JQG@@0aj1M1@39XUl40<VQF`@0aYiH1031Udd80;jDBP@0`YQ>1037WE<50<JLDP@0a9eB1032Ve04
0<6ID@@0`9Q@1032W5<40<VSFP/0oooo000:0?ooo`@0WH9=102FN3`408e_:@@0QF<K101oF`l408YT
6@D0UFdU102KLb/409Yd:`@0X7Xa102ROS840:J2=P@0ZhLk102]RCd40:n>@@D0/i95102bST840;JB
AP@0]i=5102eTD<40;NB@P@0_9M7103;Ye<40;nKA`D0^iE0102iTch40;RB?`@0^YA1102lUT<<0;jH
A@D0_9Q4102jUT880;VE@@@0^IA3102kUTH40;jIB@d0`9]=1031VT/40<2IBP@0`Ya;1034WTd40<>N
CP@0`Ye=1030Vdd40;bGB@D0_iU>1031Ve040<2KC@@0a9mA1039Xe840<NQD0@0`9Y7102jU4<40;N>
?PD0^i551031Ud/40<2FC0@0`ieD1034WUD40<BOF0@0`iiG2@30VeD40<6LE@@0aJ1I1036XUP40<fY
G`@0bjMM1033WeD80<2JD`D0aIeH103:XUd40=>/I`@0bJ9M1035X5X40<JQF`@0aJ1L1034We/40<NP
F`D0b:1K103<Y5h40<ZOFP@0aYYC1035VE880<BHC`@0aYaB1@37WE<40<FKC`@0`iU=2030VD`40<>L
D@@0b:5F2`3oool000X0oooo102MPTd409Ih?0@0SFlY1025Ha/407mK3`@0RV@I1@2EKBD409]c:`@0
VW@[102PNS440:9n<P@0YX8f102[Qc/40:f9?@@0[hi11@2cTTD40;:>@P@0]Y96102gTdD40;FA@`@0
]i92102lUdL40<^WD`@0_i]71@2kUD040;VC?P@0^98o102jU4440;bF@``0_YQ51@2lV4@40;ZF@PP0
^IE1102iU4<40;^FAP@0_YU93@30Vdd40<6JB`@0`9U:1032W4/40<BNC@@0`ii>1032WDd40<2KC@@0
_9M91@2oVDh40<6KD0@0`9]=1034We440<VSDP@0aj5@1030VTL40;ZD@`@0]hhn1@2kTDD40<6GB`@0
`9I<1033WE@40<BNE@@0a9mH1033WUL90<2KE@@0`IaE1035X5T40<JRF0@0cJUO103;Yed40<>OE@P0
`9YC1@35WEP40<ZRG@@0djaW1039XUd40<FPFP@0aZ5K1035X5`40<BOF`@0aj1K1@38X5/40<bTGP@0
bYmJ1036VU<40<FIDPP0a9Q?1036W5850<NMD`@0aI]?1033VDd80<2IC0@0`iaA1038XEH;0?ooo`00
2P3oool409f2C@@0UWPl102=KbT408ES6`@0Oe/?102:I1T509E]9@@0Vg<[102JM2/40:1j<@@0XWhb
102VPSH40:^7>`@0[HTm102_ST450;>BA@@0/Xi2102fTTH40;NCA@@0]I53102gTT840;bGA`@0bjMC
102oVdL50;^E@0@0^I<n102hTSl40;ZD@@@0_9I3302nV4D50;bHA0@0^YI2202iUD440;VD@`@0^iI6
102nVDT=0<2KC@@0`IY;1030VDX40<:LB`@0a9i=1033WTh40<:MC@@0`9]=102lUdT50;nICP@0`I]@
1030Vdd40<BOD@@0bJ=B1037XE040<2JA`@0^YA3102gSSh50;^AA@@0`IM;1030UT`40<>ME0@0a9iE
1034WeP40<>NE`T0`9]E1031W5D40<FPF@@0aZ9H103=ZEl40<^WG@@0`imE2030VU<50<FMF0@0bZ9M
103C[6L40<VRG@@0aJ1J1036XE/40<FPG0@0a9mK1037X5/50<RPF`@0c:AN103:WeX40<JJD`@0aIUB
2034V4l40<JLDPD0aieC1035Vdl40<>IC@P0`9U<1033W5440<RQEP/0oooo000:0?ooo`@0WH9=102F
N3`408e_:@@0QF<K101oF`l408YT6@D0UFdU102KLb/409Yd:`@0X7Xa102ROS840:J2=P@0ZhLk102]
RCd40:n>@@D0/i95102bST840;JBAP@0]i=5102eTD<40;NB@P@0_9M7103;Ye<40;nKA`D0^iE0102i
Tch40;RB?`@0^YA1102lUT<<0;jHA@D0_9Q4102jUT880;VE@@@0^IA3102kUTH40;jIB@d0`9]=1031
VT/40<2IBP@0`Ya;1034WTd40<>NCP@0`Ye=1030Vdd40;bGB@D0_iU>1031Ve040<2KC@@0a9mA1039
Xe840<NQD0@0`9Y7102jU4<40;N>?PD0^i551031Ud/40<2FC0@0`ieD1034WUD40<BOF0@0`iiG2@30
VeD40<6LE@@0aJ1I1036XUP40<fYG`@0bjMM1033WeD80<2JD`D0aIeH103:XUd40=>/I`@0bJ9M1035
X5X40<JQF`@0aJ1L1034We/40<NPF`D0b:1K103<Y5h40<ZOFP@0aYYC1035VE880<BHC`@0aYaB1@37
WE<40<FKC`@0`iU=2030VD`40<>LD@@0b:5F2`3oool000X0oooo102KOT8409Mh=@@0TFlW1026H1D4
08QQ4P@0TFLK1@2EJal409]a9`@0WWP]102VP3D40:R3=@@0ZXDg202/R3X40;:??PD0]950102cSd44
0;FA@`@0]I12102cST040;B??`@0^YE51036X4d40;bF@`D0^Y@o102iTch40;ZA?`@0^i90102nUD<4
0<JMB`P0_YY61@2nVT@40<6MA`@0_9Q2102hU3h40;RD@0@0^iI5102oVTT40<JQD@@0`ii@1@2mV4X4
0<2IC0@0`Y]>1032Vd`40<6JB`@0`Ya;1034WTd40<6JB`@0_9E61@30VD`40;nHB`@0`9Y91033WD`4
0<FOC0@0`ie:1030VTL40;fGA0@0^iE41@2kU4D40<2GB0@0`9I<102oVDh40<6KDP@0`ieF1034WUL4
0<2KE0D0_YUB1031W5D40<BOF0@0aj9K103C[VL40<bVG`P0aImH1030VU<50<FME`@0bZ9L103;Y5l4
0<jWHP@0bZ=N1032VeH40<>NF0@0aJ1J1036WeX50<JNF@@0bJ5L103;X5`40<^PF`@0aiaG2033VE44
0<BJD0D0aYa@1035W4d40<6HB0@0_YQ71030VTT40<BMCP@0b:5B2`3oool000X0oooo102KOT8409Mh
=@@0TFlW1026H1D408QQ4P@0TFLK1@2EJal409]a9`@0WWP]102VP3D40:R3=@@0ZXDg202/R3X40;:?
?PD0]950102cSd440;FA@`@0]I12102cST040;B??`@0^YE51036X4d40;bF@`D0^Y@o102iTch40;ZA
?`@0^i90102nUD<40<JMB`P0_YY61@2nVT@40<6MA`@0_9Q2102hU3h40;RD@0@0^iI5102oVTT40<JQ
D@@0`ii@1@2mV4X40<2IC0@0`Y]>1032Vd`40<6JB`@0`Ya;1034WTd40<6JB`@0_9E61@30VD`40;nH
B`@0`9Y91033WD`40<FOC0@0`ie:1030VTL40;fGA0@0^iE41@2kU4D40<2GB0@0`9I<102oVDh40<6K
DP@0`ieF1034WUL40<2KE0D0_YUB1031W5D40<BOF0@0aj9K103C[VL40<bVG`P0aImH1030VU<50<FM
E`@0bZ9L103;Y5l40<jWHP@0bZ=N1032VeH40<>NF0@0aJ1J1036WeX50<JNF@@0bJ5L103;X5`40<^P
F`@0aiaG2033VE440<BJD0D0aYa@1035W4d40<6HB0@0_YQ71030VTT40<BMCP@0b:5B2`3oool000X0
oooo102KOT8409Mh=@@0TFlW1026H1D408QQ4P@0TFLK1@2EJal409]a9`@0WWP]102VP3D40:R3=@@0
ZXDg202/R3X40;:??PD0]950102cSd440;FA@`@0]I12102cST040;B??`@0^YE51036X4d40;bF@`D0
^Y@o102iTch40;ZA?`@0^i90102nUD<40<JMB`P0_YY61@2nVT@40<6MA`@0_9Q2102hU3h40;RD@0@0
^iI5102oVTT40<JQD@@0`ii@1@2mV4X40<2IC0@0`Y]>1032Vd`40<6JB`@0`Ya;1034WTd40<6JB`@0
_9E61@30VD`40;nHB`@0`9Y91033WD`40<FOC0@0`ie:1030VTL40;fGA0@0^iE41@2kU4D40<2GB0@0
`9I<102oVDh40<6KDP@0`ieF1034WUL40<2KE0D0_YUB1031W5D40<BOF0@0aj9K103C[VL40<bVG`P0
aImH1030VU<50<FME`@0bZ9L103;Y5l40<jWHP@0bZ=N1032VeH40<>NF0@0aJ1J1036WeX50<JNF@@0
bJ5L103;X5`40<^PF`@0aiaG2033VE440<BJD0D0aYa@1035W4d40<6HB0@0_YQ71030VTT40<BMCP@0
b:5B2`3oool000X0oooo102KOT8409Mh=@@0TFlW1026H1D408QQ4P@0TFLK1@2EJal409]a9`@0WWP]
102VP3D40:R3=@@0ZXDg202/R3X40;:??PD0]950102cSd440;FA@`@0]I12102cST040;B??`@0^YE5
1036X4d40;bF@`D0^Y@o102iTch40;ZA?`@0^i90102nUD<40<JMB`P0_YY61@2nVT@40<6MA`@0_9Q2
102hU3h40;RD@0@0^iI5102oVTT40<JQD@@0`ii@1@2mV4X40<2IC0@0`Y]>1032Vd`40<6JB`@0`Ya;
1034WTd40<6JB`@0_9E61@30VD`40;nHB`@0`9Y91033WD`40<FOC0@0`ie:1030VTL40;fGA0@0^iE4
1@2kU4D40<2GB0@0`9I<102oVDh40<6KDP@0`ieF1034WUL40<2KE0D0_YUB1031W5D40<BOF0@0aj9K
103C[VL40<bVG`P0aImH1030VU<50<FME`@0bZ9L103;Y5l40<jWHP@0bZ=N1032VeH40<>NF0@0aJ1J
1036WeX50<JNF@@0bJ5L103;X5`40<^PF`@0aiaG2033VE440<BJD0D0aYa@1035W4d40<6HB0@0_YQ7
1030VTT40<BMCP@0b:5B2`3oool000X0oooo102NPCd409If;@@0T6/K102=I1@408iU5@@0U6TK1@2H
KAl409ea9P@0WWLZ102UOS440:N2<P@0Z8<c102]R3L40;6<>`@0/Xdl1@2eT3l40;RC@P@0^IA3102g
TT840;F@@0@0]Y0o102kUD@40;jHA@@0_IM41@2kUD040;NA?0@0^i<n102nUT440;nFA0@0a9]91038
Y5040;nKA`D0^YI01030W4H40;jJ@P@0^9@l102iUCl40;bHA0@0_IU51030VdX40<2KB`D0`Ye=1035
WU440<:KCP@0_iQ;1031VTd40<6HB0@0`YU91033VTX40<6HB0D0`9Y9102oVDP40<2JA`@0`Ya91032
WTP40<>OB@@0`Ie9102nVTH40;jHA`D0_IM6102jTd@40;bEB0@0^YA91030VU440<BNE@@0b:9I1033
WEH50;jHD@@0`9]D1035X5T40<ZTG@@0bJ=L103:Y5d40<FOF0@0`YaE1035WeP50<NOF@@0bJ5L1036
WeX40<VRG`@0bZEO1038Xed80<BOF0@0aJ1I1@36X5T40<FNF@@0bJ5L103<Y5l40<RPF`P0a9aF1034
WE850<BMD0@0aIa:1032VTD40;fGA0@0_YQ51031VdP40<BNB`/0oooo000:0?ooo`@0WX4m102FMRd4
091[6`@0SF@D102>IAD409AY6`D0V6dO102MLBH409ig:P@0YGha102WPS840:R3<`@0[HPg102aS3/4
0;:=?0D0]I0o102hTd840;VD@`@0]i92102eT4040;J@?`@0^iE4102nV4D40;fGA0D0^iE0102gTC`4
0;^C?P@0_YI1102oUT@40<BKB@@0b:A@102oVdL50;ZF@0@0`9a6102nVT840;RD?0@0^IDo102lV4@4
0;fIA@@0`9]:1030Vd/50<:MC@@0aIiA1032Vdh40;nHB`@0`IY=1031V4P40<:IB@@0`iY:1031V4P5
0<2JB@@0_iU81030VTL40<:LB@@0`Yi81033WdT40<6MB@@0_YY6102nV4L50;fGAP@0^Y=4102lUDP4
0;ZDB@@0`9YA1034WUD40<RRF@@0`ieF1@2nV5440<2KE0@0aJ1I103:Y5d40<VSG0@0bZAM1035WeP4
0<:LE@@0aImH1@37WeT40<VQG0@0aYmJ1039XUl40<ZUG`@0b:=M2034WeP40<FPF@D0aZ1I1035WUT4
0<VQG0@0c:AO1038X5/80<BLEP@0a9eB1@34WE040<FLBP@0`YY5102mUd@40;jHA@@0`I]81034WT/;
0?ooo`002P3oool409j1?@@0UWH]102@Ja/408eT50@0SVDE102DJA/509Q]7`@0WG4V102NMbX40:En
<@@0Yh8b102XPc<40:f8=`@0/H`k102bSC`50;F@?`@0^9=2102iU4<40;NB@P@0]I10102fT3l40;^E
A0@0_YQ5102mUd@50;^E@0@0]i4l102kTch40;jF@@@0_iI41034VdT40<RTD0@0_i]71@2jUT040<2L
AP@0_YY2102hU3`40;VE?`@0_9Q4102mVDD40<2KBP@0`9];1@32WDd40<FND@@0`Y]>102oV4/40<6J
C@@0`IQ81032VDT40<>JBP@0`IQ81@30VTT40;nIB0@0`9Y71032W4T40<:NB0@0`im91031WDT40;jJ
AP@0_YQ71@2mUdH40;ZCA0@0_9E8102jU4T40<2JD@@0a9iE1038XUT40<>MEPD0_YQA1030Ve@40<FP
F@@0bZAM1039Xe`40<ZTG@@0aImH1032W5D40<FOF0D0aimI1039XE`40<JOFP@0bJ9O103:YEl40<RS
G@P0a9mH1035X5T50<JPF@@0aIiI1039XE`40<bTG`@0b:1K2034W5H40<BMDPD0a9e@1035W4X40<:J
A@@0_IM4102nV4D40<6KB0@0a9i;2`3oool000X0oooo102NPCd409If;@@0T6/K102=I1@408iU5@@0
U6TK1@2HKAl409ea9P@0WWLZ102UOS440:N2<P@0Z8<c102]R3L40;6<>`@0/Xdl1@2eT3l40;RC@P@0
^IA3102gTT840;F@@0@0]Y0o102kUD@40;jHA@@0_IM41@2kUD040;NA?0@0^i<n102nUT440;nFA0@0
a9]91038Y5040;nKA`D0^YI01030W4H40;jJ@P@0^9@l102iUCl40;bHA0@0_IU51030VdX40<2KB`D0
`Ye=1035WU440<:KCP@0_iQ;1031VTd40<6HB0@0`YU91033VTX40<6HB0D0`9Y9102oVDP40<2JA`@0
`Ya91032WTP40<>OB@@0`Ie9102nVTH40;jHA`D0_IM6102jTd@40;bEB0@0^YA91030VU440<BNE@@0
b:9I1033WEH50;jHD@@0`9]D1035X5T40<ZTG@@0bJ=L103:Y5d40<FOF0@0`YaE1035WeP50<NOF@@0
bJ5L1036WeX40<VRG`@0bZEO1038Xed80<BOF0@0aJ1I1@36X5T40<FNF@@0bJ5L103<Y5l40<RPF`P0
a9aF1034WE850<BMD0@0aIa:1032VTD40;fGA0@0_YQ51031VdP40<BNB`/0oooo000:0?ooo`@0WGd`
102JMbH409=]6P@0T6HB102GKAT409Y]70D0Vg4O102PMBH40:1j:@@0YGl^102YPc040:R2;`@0[8Hc
102dSS/40;>?>`D0]90l102iUD440;bHA0@0^YA3102hTT440;J@?`@0_9I5102nV4D40;fGA0D0^I<n
102jU3l80;bD?`@0_iI41032VDL40<:NBP@0`9a81@31WDL40<:NB0@0_YY2102gTc/40;ZE?@@0^iE0
102oVD@40;bF@`@0_IM61@30VTT40<6JB`P0`9U:1032Vd`40<>JBP@0_IA41035W4`40<ROC`D0`9Y9
102nV4L40;fGA0@0_iU62034X4X40<>OB`@0`Ia;102lUdH50;bGA`@0^YE7102iTdP40;^EBP@0`I]B
1035WeH40<ZTF`@0`ieD1@2oVE040<:LE@@0b:9K1039Xe`40<ZTG@@0b:9K1033WEH40<2JD`@0`I]D
1@36WUP40<^SGP@0b:5L1037X5d40<JQF`@0bjIP1034XUX40<:PF0@0`ImG1@33XET40<JQF`@0aJ1J
1038XE`40<NPF`P0aj5H1034WU<50<BMD0@0`ie:1034W4L40<2JA@@0_YQ3202mUd8;0?ooo`002P3o
ool409em<0@0VWLV102CKAX4091V4P@0UfdI102JKA`509]a7`@0X7DV102PNRT40:Eo;P@0ZH<`102X
PRl40:b6<`@0]8hk102cSc/50;B@?0@0^IE1102lV4@40;ZD@`@0^991102fT3l40;bFA@@0_YQ5102m
Ud@50;VC?P@0^Y@o202lU3l40;nFA0@0`YU71032WTX40<2LB0D0`Ie71032WTP40;jJ@P@0]i<k102j
UCd40;^E@0@0_iU4102lUT<40;fGAPD0`9Y91031VT/80<2IBP@0`Y]<1033VTX40;fDA0@0aIa<1038
Wdl50<2JB@@0_YQ7102mUd@40;nIAPP0a:1:1033Wd/40<6LB`@0_9M61@2lUdL40;ZEA`@0^I=8102k
UDX40<6KDP@0aImF103:Y5/40<>ME0D0_iU@1032W5D40<RRF`@0bJ=L103:Y5d40<RRF`@0`ieF1030
VU<40<6KE0D0aYiH103;Xeh40<RQG0@0aj1M1036XE/40<^VH0@0a:9J1032X5P40<6OE`D0`j5I1036
XE/40<FPFP@0b:5L1037X5/80<NQF0@0a9iC1@34WE040<>MBP@0a9a71030VTD40;jH@`P0_IM22`3o
ool000X0oooo102MOC0409Yg9P@0TfdJ102@IQ8409M]6@@0VVdL1@2KLAl40:1e9P@0X7XY102UObh4
0:V3<0@0Z88_102/QS<40;B>>`@0/hlk1@2dT3`40;VE@@@0_9Q4102jU4<40;RB@@@0]Y0o102lUTD4
0;jHA@@0_IM41@2iTch40;ZD?`P0_9@o102oUT@40<:IA`@0`Yi:1030W4P50<6MA`@0`Yi8102nVT84
0;NC>`@0^YDm102kUD040;nIA0@0_9I3102mUdH50<2JB@@0`IY;2030VDX40<:KC0@0`iY:102mU4@4
0<FLC0@0b9m?1@30VTT40;jHA`@0_IM4102oVDH80<BPBP@0`im;1031W4/40;bGAPD0_9M7102jUDL4
0;VCB0@0^iE:1031Ve840<FOEP@0bZAK1033WE@50;nID0@0`YaE1038XU/40<VSG0@0bZAM1038XU/4
0<>MEP@0`9YC1031Ve@50<JNF0@0bj=N1038XE`40<NPG@@0aZ5K103;YV040<BRFP@0`Z1H1031WeL5
0<>QF@@0aZ5K1035X5X40<RQG0@0aj1K2037XEP40<BND`D0a9e@1033WDX40<BLA`@0`9Y5102nV4<8
0;fG@P/0oooo000:0?ooo`@0WGd`102JMbH409=]6P@0T6HB102GKAT409Y]70D0Vg4O102PMBH40:1j
:@@0YGl^102YPc040:R2;`@0[8Hc102dSS/40;>?>`D0]90l102iUD440;bHA0@0^YA3102hTT440;J@
?`@0_9I5102nV4D40;fGA0D0^I<n102jU3l80;bD?`@0_iI41032VDL40<:NBP@0`9a81@31WDL40<:N
B0@0_YY2102gTc/40;ZE?@@0^iE0102oVD@40;bF@`@0_IM61@30VTT40<6JB`P0`9U:1032Vd`40<>J
BP@0_IA41035W4`40<ROC`D0`9Y9102nV4L40;fGA0@0_iU62034X4X40<>OB`@0`Ia;102lUdH50;bG
A`@0^YE7102iTdP40;^EBP@0`I]B1035WeH40<ZTF`@0`ieD1@2oVE040<:LE@@0b:9K1039Xe`40<ZT
G@@0b:9K1033WEH40<2JD`@0`I]D1@36WUP40<^SGP@0b:5L1037X5d40<JQF`@0bjIP1034XUX40<:P
F0@0`ImG1@33XET40<JQF`@0aJ1J1038XE`40<NPF`P0aj5H1034WU<50<BMD0@0`ie:1034W4L40<2J
A@@0_YQ3202mUd8;0?ooo`002P3oool40:>2<@@0WWXV102HLa/409Ya6@@0V6hH102LKa`509mb7`@0
YGPW102VOB/40:Z1;`@0[8Ha102YPbh40:^5<0@0/X`g102cScT50;FA>`@0^IE1102kUd<80;NC?`@0
^98o102kUD840;fG@P@0`I]61@2iU3`40;JA>@@0^Y@o102mUd840<2JA`@0_iU62031W4/50<:NBP@0
_i]7102nVD440;^F?P@0_9Lo102kUSh40;bF@@@0^iE02@2nV4D40;fGAP@0`9Y9102oVDP40;^EA0@0
`9M72035W4`40<BKB`D0aIm<1030VTL40;>?>`@0_YY61033Wd/40<NSC`@0`Ii<1030WD`40;fJB@D0
_YY<102lV4`40;jJD0@0_i]A1031W5D40<:NE0@0a:1F1032W5<50<6KDP@0`ieD1037XEP40<bVG`@0
aZ1I103=YV440<FNF@@0^95<102oV5<50<JOFP@0c:EP1036XEd40<RSG`P0`YmK1031X5T40<:QFP@0
`9iF1@34XUX40<BOF0@0`iiG1034WUD40<FOEP@0aZ1E1038XUL40<NQEPD0a9mA1035Wdh40<BNB`@0
`Ya9102oVDH80;bF@@/0oooo000:0?ooo`@0Xh8a102NNRH409Qc6`@0VW4I102HKQP409a_70D0Wg8O
102UN2L40:Im:`@0ZX4_102/QS440:V3;P@0ZhD`102bS3L40;>?>@D0]I4k102iUD440;^G@`P0]i<o
102hTSl40;^E@P@0_IM21031VdH50;VD?0@0]Y4i102jU3l40;fG@P@0`9Y7102oVDH80<6LB`D0`Yi:
102oVdL40;jI@@@0^iHn102lUcl40;^F?P@0_9I1102kUD090;jHA@@0_IM61030VTT40;nIB0@0^iE4
1030UdL80<FLC0@0a9];1@35Wd`40<2JA`@0/hlk102nVTH40<>OB`@0aj=?1031WT`40<2MC0@0_IY9
1@2nVT`40;bHC0@0_YY@102oVe440<6LE@@0`YiD1034X5H40<:LD`D0`I]B1033WE@40<NQF0@0c:IO
1036X5T40<fVH@@0aIiI102hTD`40;nHD`D0aYmJ103<YF040<JQG@@0b:=O2032We/40<6PF@@0`Z5J
1030WUH50<BRFP@0a9mH1033WUL40<BNE@@0aImF1036X5D40<RRE`@0aj5F1@34We440<FOCP@0a9i;
1032W4T40;nIAPP0_9I12`3oool000X0oooo102SPS4409ij9P@0V7<K102JLAT409Q^60@0W6lL1@2O
LQl40:Eh9`@0YWd[102ZPBl40:b6<@@0ZH<^102[QC040;:<=`@0/hli1@2eTC/40;VE@@@0^iM3202g
Tcl40;RB?`@0^iE2102mUd840<6KAPD0^I@l102fTCT40;ZD?`@0_IM21030VTL40;nIAPP0`Ia;1@32
WTX40;nKA`@0_YU1102kUSh40;bG?`@0^iHn102lUT440;^E@0T0_YQ5102mUdH40<2JB@@0_iU8102k
UD@40<2GA`P0aIa<1034Vd/50<FOC0@0`9Y7102cSc/40;jJAP@0`im;1037Xdl40<6NC0@0`9e<102m
VTT50;jJC0@0_9Q<102nVU040;nKD@@0`IaE1032WU@40<BPEP@0`YaC1@31Ve840<>ME0@0aj5H103<
YUl40<JPF@@0cJIQ1035WUT40;RAC0@0_iQC1@36WeX40<bUH0@0aZ5M1038Xel80<:OF`@0`J1I1032
XEX40<2NEPD0a:9J1034WeP40<>NE`@0a9iE1035WeH40<JPE@@0b:9G1037XEH50<BOD@@0aIm>1034
WT/40<:LB@@0_iU6202lUT4;0?ooo`002P3oool40:>2<@@0WWXV102HLa/409Ya6@@0V6hH102LKa`5
09mb7`@0YGPW102VOB/40:Z1;`@0[8Ha102YPbh40:^5<0@0/X`g102cScT50;FA>`@0^IE1102kUd<8
0;NC?`@0^98o102kUD840;fG@P@0`I]61@2iU3`40;JA>@@0^Y@o102mUd840<2JA`@0_iU62031W4/5
0<:NBP@0_i]7102nVD440;^F?P@0_9Lo102kUSh40;bF@@@0^iE02@2nV4D40;fGAP@0`9Y9102oVDP4
0;^EA0@0`9M72035W4`40<BKB`D0aIm<1030VTL40;>?>`@0_YY61033Wd/40<NSC`@0`Ii<1030WD`4
0;fJB@D0_YY<102lV4`40;jJD0@0_i]A1031W5D40<:NE0@0a:1F1032W5<50<6KDP@0`ieD1037XEP4
0<bVG`@0aZ1I103=YV440<FNF@@0^95<102oV5<50<JOFP@0c:EP1036XEd40<RSG`P0`YmK1031X5T4
0<:QFP@0`9iF1@34XUX40<BOF0@0`iiG1034WUD40<FOEP@0aZ1E1038XUL40<NQEPD0a9mA1035Wdh4
0<BNB`@0`Ya9102oVDH80;bF@@/0oooo000:0?ooo`@0ZXLc102UP2P40:1k8P@0X7LO102MM1`409a_
70D0YGPU102ZOB`80:^1;`P0[HD`102^RC440;>>=P@0]I4k1@2gTcd40;ZF@P@0^IE1102eTCd40;RD
@0P0^IDo102nVT840<JRBPD0^YHn102_Rc<40;NC?@@0`Yi81032WTX40;^G@`@0_YU81030VdX50<FO
C0@0a9i;1031VdH40;fG@P@0_IDn102oUd040<JNB@@0_YI1102mU4850;jE@`@0_IA2102nUD<40;nG
@PP0`9M51030UdL40<JMC@@0aIa<1@31VdP40<:LB@P0_IU51033X4h40<RUE0@0`Ym>1030W4h40<2L
D0D0`IeA102nW5840<2NEP@0`IaE1033WUP40<FQE`@0`IeC2@31WE440<>OD`@0`YiD1035WeH40<NQ
FP@0bJ9M1034WEP40;fFD@@0`9UD1@3:Xeh40<fVH@@0b:5N1036We`80<JQG@P0`IiJ2@34XUX80<BP
EPP0`ieB1035WU440<RQE0@0bJ9E1@37X5<40<NRDP@0a9m?1033WD`40<6KBP@0_iU61030VTL;0?oo
o`002P3oool40:Z7<`@0YH0X102PNb840:1g7`@0WG@L102LKa`50:Eh9@@0ZWd/202[PBl80:f5<0@0
[XTa102cSSH40;FA>`D0]i<m102jUT840;VE@@@0]I4m102hU4080;VE?`@0_YY21036XTX50;ZF?P@0
[h/c102gTcd40<:NB0@0`Yi:102kUd<40;jIB0@0`9]:1@35Wd`40<BNB`@0`I]6102mUd840;fE?P@0
_iM01036WTT40;jF@@@0_IA21@2nUD<40;fD@P@0_YE3102oUd880<2GA@@0`9M71036WDd40<FLC0D0
`I]81032W4T80;fIA@@0`j1>1038YE@40<:OCP@0`9a>1030W5050<6MD@@0_YaB1030WUH40<6LE@@0
`iiH1035XEL40<6MD`T0`IeA1033We<40<:NE0@0aImF1037XEX40<VRG@@0a9eH102mUU440<2IE0D0
bZ=N103=YV440<RQGP@0aYmL2036XEd80<6NFPT0a:9J2034X5H80<>MDP@0aIiA1038XE@40<VRE@D0
aj1C1037XU840<BOC`@0`ie<1031VdX40;nIAP@0`9Y72`3oool000X0oooo102ZQc<40:F0:0@0X7/R
102PMal409ed70@0W6lL1@2UN2D40:Ym;0P0Zh4_202]QC040:j9<@@0/hhf102eTC/50;NC?@@0^YI2
102iUD440;FA?@@0^9A0202iUCl40;jJ@P@0aZ9:1@2jUSh40:n;<`@0]i<m1032WTP40<:NBP@0^iM3
102nVDP40<2KBPD0aIm<1034WT/40<6KAP@0_IM2102mUCh40;nG@0@0aYi9102nUT440;fD@PD0_YE3
102mU4840;jE@`@0_iM22030UdD40<2GA`@0aYe=1035W4`50<6KB0@0`Ya9202mVDD40<>PCP@0b:ED
1032Wdh40<2LCP@0`9a@1@31WE440;jLDP@0`9iF1031W5D40<>NF0@0aJ5G1031WE<90<6MD@@0`imC
1032WU@40<FOEP@0aj5J1039XUd40<BMF0@0_IIA1030VE@50<ZSGP@0cJIQ1038XEh40<JOG0P0aZ5M
2031WUX90<BRFPP0a:1F2033WE840<FND@@0b:5D1039XUD50<NPD`@0aj9B1034Wdl40<>MC0@0`I]:
102oVDH40<2JA`/0oooo000:0?ooo`@0ZXLc102UP2P40:1k8P@0X7LO102MM1`409a_70D0YGPU102Z
OB`80:^1;`P0[HD`102^RC440;>>=P@0]I4k1@2gTcd40;ZF@P@0^IE1102eTCd40;RD@0P0^IDo102n
VT840<JRBPD0^YHn102_Rc<40;NC?@@0`Yi81032WTX40;^G@`@0_YU81030VdX50<FOC0@0a9i;1031
VdH40;fG@P@0_IDn102oUd040<JNB@@0_YI1102mU4850;jE@`@0_IA2102nUD<40;nG@PP0`9M51030
UdL40<JMC@@0aIa<1@31VdP40<:LB@P0_IU51033X4h40<RUE0@0`Ym>1030W4h40<2LD0D0`IeA102n
W5840<2NEP@0`IaE1033WUP40<FQE`@0`IeC2@31WE440<>OD`@0`YiD1035WeH40<NQFP@0bJ9M1034
WEP40;fFD@@0`9UD1@3:Xeh40<fVH@@0b:5N1036We`80<JQG@P0`IiJ2@34XUX80<BPEPP0`ieB1035
WU440<RQE0@0bJ9E1@37X5<40<NRDP@0a9m?1033WD`40<6KBP@0_iU61030VTL;0?ooo`002P3oool4
0;6==`@0ZXD]102XPbP40:Al90@0X7LO102PMR850:Qk:0@0Zgh]102_QC440:f3;`@0[XH_102`R344
0;6<=0@0/X`g102gTcd50;NC?`@0^IE1102jUT840;JB?0@0]i<m102iUCd40;ZF?P@0`j16102mVT05
0;ND>P@0]I4i102hU3`40;^G@@@0_YY61030VdX40<:LB`@0`IY;2@31VdP40<6KAP@0`9Y5102mUD04
0;jF@@@0cjMB1036WTT40<:JA@d0`9Q3102nUSl40;nG@P@0`IQ81032VDX80<>MC0D0aZ1=1034WT/4
0<:NBP@0`Ye<1034XDl40<FQD`@0`imA1032WU840;jLDPD0_ieC1035Xe/40<6OE`@0`9]E1035X5X4
0<fYG`@0a:1F1033We<50<6MD@@0a:1D1032WU840<BNE@@0aImH1036X5T40<BMF0@0`IYG1035WU/5
0<^TG`@0aj1K1037X5d40<VRG`@0bZAS1035Weh40<JQG@@0`iiJ1034WeT50<>NE`@0bZAK1035We@4
0<:KCP@0a9e@1037WTl40<JMCP@0b9iB1@39We<40<RSE@@0a9mA1034Wdl40<:MC@@0`9Y91031VdX;
0?ooo`002P3oool40;6==`@0ZXD]102XPbP40:Al90@0X7LO102PMR850:Qk:0@0Zgh]102_QC440:f3
;`@0[XH_102`R3440;6<=0@0/X`g102gTcd50;NC?`@0^IE1102jUT840;JB?0@0]i<m102iUCd40;ZF
?P@0`j16102mVT050;ND>P@0]I4i102hU3`40;^G@@@0_YY61030VdX40<:LB`@0`IY;2@31VdP40<6K
AP@0`9Y5102mUD040;jF@@@0cjMB1036WTT40<:JA@d0`9Q3102nUSl40;nG@P@0`IQ81032VDX80<>M
C0D0aZ1=1034WT/40<:NBP@0`Ye<1034XDl40<FQD`@0`imA1032WU840;jLDPD0_ieC1035Xe/40<6O
E`@0`9]E1035X5X40<fYG`@0a:1F1033We<50<6MD@@0a:1D1032WU840<BNE@@0aImH1036X5T40<BM
F0@0`IYG1035WU/50<^TG`@0aj1K1037X5d40<VRG`@0bZAS1035Weh40<JQG@@0`iiJ1034WeT50<>N
E`@0bZAK1035We@40<:KCP@0a9e@1037WTl40<JMCP@0b9iB1@39We<40<RSE@@0a9mA1034Wdl40<:M
C@@0`9Y91031VdX;0?ooo`002P3oool40;6==`@0ZXD]102XPbP40:Al90@0X7LO102PMR850:Qk:0@0
Zgh]102_QC440:f3;`@0[XH_102`R3440;6<=0@0/X`g102gTcd50;NC?`@0^IE1102jUT840;JB?0@0
]i<m102iUCd40;ZF?P@0`j16102mVT050;ND>P@0]I4i102hU3`40;^G@@@0_YY61030VdX40<:LB`@0
`IY;2@31VdP40<6KAP@0`9Y5102mUD040;jF@@@0cjMB1036WTT40<:JA@d0`9Q3102nUSl40;nG@P@0
`IQ81032VDX80<>MC0D0aZ1=1034WT/40<:NBP@0`Ye<1034XDl40<FQD`@0`imA1032WU840;jLDPD0
_ieC1035Xe/40<6OE`@0`9]E1035X5X40<fYG`@0a:1F1033We<50<6MD@@0a:1D1032WU840<BNE@@0
aImH1036X5T40<BMF0@0`IYG1035WU/50<^TG`@0aj1K1037X5d40<VRG`@0bZAS1035Weh40<JQG@@0
`iiJ1034WeT50<>NE`@0bZAK1035We@40<:KCP@0a9e@1037WTl40<JMCP@0b9iB1@39We<40<RSE@@0
a9mA1034Wdl40<:MC@@0`9Y91031VdX;0?ooo`002P3oool40;6==`@0ZXD]102XPbP40:Al90@0X7LO
102PMR850:Qk:0@0Zgh]102_QC440:f3;`@0[XH_102`R3440;6<=0@0/X`g102gTcd50;NC?`@0^IE1
102jUT840;JB?0@0]i<m102iUCd40;ZF?P@0`j16102mVT050;ND>P@0]I4i102hU3`40;^G@@@0_YY6
1030VdX40<:LB`@0`IY;2@31VdP40<6KAP@0`9Y5102mUD040;jF@@@0cjMB1036WTT40<:JA@d0`9Q3
102nUSl40;nG@P@0`IQ81032VDX80<>MC0D0aZ1=1034WT/40<:NBP@0`Ye<1034XDl40<FQD`@0`imA
1032WU840;jLDPD0_ieC1035Xe/40<6OE`@0`9]E1035X5X40<fYG`@0a:1F1033We<50<6MD@@0a:1D
1032WU840<BNE@@0aImH1036X5T40<BMF0@0`IYG1035WU/50<^TG`@0aj1K1037X5d40<VRG`@0bZAS
1035Weh40<JQG@@0`iiJ1034WeT50<>NE`@0bZAK1035We@40<:KCP@0a9e@1037WTl40<JMCP@0b9iB
1@39We<40<RSE@@0a9mA1034Wdl40<:MC@@0`9Y91031VdX;0?ooo`002P3oool40;6==`@0ZXD]102X
PbP40:Al90@0X7LO102PMR850:Qk:0@0Zgh]102_QC440:f3;`@0[XH_102`R3440;6<=0@0/X`g102g
Tcd50;NC?`@0^IE1102jUT840;JB?0@0]i<m102iUCd40;ZF?P@0`j16102mVT050;ND>P@0]I4i102h
U3`40;^G@@@0_YY61030VdX40<:LB`@0`IY;2@31VdP40<6KAP@0`9Y5102mUD040;jF@@@0cjMB1036
WTT40<:JA@d0`9Q3102nUSl40;nG@P@0`IQ81032VDX80<>MC0D0aZ1=1034WT/40<:NBP@0`Ye<1034
XDl40<FQD`@0`imA1032WU840;jLDPD0_ieC1035Xe/40<6OE`@0`9]E1035X5X40<fYG`@0a:1F1033
We<50<6MD@@0a:1D1032WU840<BNE@@0aImH1036X5T40<BMF0@0`IYG1035WU/50<^TG`@0aj1K1037
X5d40<VRG`@0bZAS1035Weh40<JQG@@0`iiJ1034WeT50<>NE`@0bZAK1035We@40<:KCP@0a9e@1037
WTl40<JMCP@0b9iB1@39We<40<RSE@@0a9mA1034Wdl40<:MC@@0`9Y91031VdX;0?ooo`002P3oool4
0;FA>`@0[h/e102^Rc440:^8;P@0Y7lV102NNB050:Em9@@0Z80X102]Pbd40:n5<@@0/HLc102aQcD4
0;27=`@0/HPh102eTC/50;VE?`@0_9Q0102jUSh40;VD?0@0]8lg102hT3/40<:JA@@0aie;1033VDL5
0<2FA0@0_YA2102iTch40;^E@0@0_9Q01030W4H40<6OB0@0`Ie91@2nVTH40<BKB@@0`iY81033VDL4
0<2F@P@0_iE11037XTX40<^VCP@0aj=;1@36XTX40<6MA@@0^iLo102mUd840;fD@P@0_iI41033V4T8
0<FLBPD0_iU61030VTL40<:MC0@0`ii>1033We440<NSF@@0`9iD102oWED40<2NEPD0_YaD1030WUL4
0<BRF`P0aJ1L1038Xed40<NRG0T0aYmJ2033WEH40<:LE@P0aZ1I1034WUL=0<>NF0@0a9mI1035X5`4
0<bWH`@0aj5P1034WUd40<FOGP@0`I]J1032VeH50<BMF0@0aYiF103:XUX40<FND@@0aYmB1033W4d4
0<FNC`@0aYe>1@39We<40<JPE@@0a9iE1033W4l40<FLC@@0aIa<1034VTP;0?ooo`002P3oool40;FA
>`@0[h/e102^Rc440:^8;P@0Y7lV102NNB050:Em9@@0Z80X102]Pbd40:n5<@@0/HLc102aQcD40;27
=`@0/HPh102eTC/50;VE?`@0_9Q0102jUSh40;VD?0@0]8lg102hT3/40<:JA@@0aie;1033VDL50<2F
A0@0_YA2102iTch40;^E@0@0_9Q01030W4H40<6OB0@0`Ie91@2nVTH40<BKB@@0`iY81033VDL40<2F
@P@0_iE11037XTX40<^VCP@0aj=;1@36XTX40<6MA@@0^iLo102mUd840;fD@P@0_iI41033V4T80<FL
BPD0_iU61030VTL40<:MC0@0`ii>1033We440<NSF@@0`9iD102oWED40<2NEPD0_YaD1030WUL40<BR
F`P0aJ1L1038Xed40<NRG0T0aYmJ2033WEH40<:LE@P0aZ1I1034WUL=0<>NF0@0a9mI1035X5`40<bW
H`@0aj5P1034WUd40<FOGP@0`I]J1032VeH50<BMF0@0aYiF103:XUX40<FND@@0aYmB1033W4d40<FN
C`@0aYe>1@39We<40<JPE@@0a9iE1033W4l40<FLC@@0aIa<1034VTP;0?ooo`002P3oool40;FA>`@0
[h/e102^Rc440:^8;P@0Y7lV102NNB050:Em9@@0Z80X102]Pbd40:n5<@@0/HLc102aQcD40;27=`@0
/HPh102eTC/50;VE?`@0_9Q0102jUSh40;VD?0@0]8lg102hT3/40<:JA@@0aie;1033VDL50<2FA0@0
_YA2102iTch40;^E@0@0_9Q01030W4H40<6OB0@0`Ie91@2nVTH40<BKB@@0`iY81033VDL40<2F@P@0
_iE11037XTX40<^VCP@0aj=;1@36XTX40<6MA@@0^iLo102mUd840;fD@P@0_iI41033V4T80<FLBPD0
_iU61030VTL40<:MC0@0`ii>1033We440<NSF@@0`9iD102oWED40<2NEPD0_YaD1030WUL40<BRF`P0
aJ1L1038Xed40<NRG0T0aYmJ2033WEH40<:LE@P0aZ1I1034WUL=0<>NF0@0a9mI1035X5`40<bWH`@0
aj5P1034WUd40<FOGP@0`I]J1032VeH50<BMF0@0aYiF103:XUX40<FND@@0aYmB1033W4d40<FNC`@0
aYe>1@39We<40<JPE@@0a9iE1033W4l40<FLC@@0aIa<1034VTP;0?ooo`002P3oool40;FA>`@0[h/e
102^Rc440:^8;P@0Y7lV102NNB050:Em9@@0Z80X102]Pbd40:n5<@@0/HLc102aQcD40;27=`@0/HPh
102eTC/50;VE?`@0_9Q0102jUSh40;VD?0@0]8lg102hT3/40<:JA@@0aie;1033VDL50<2FA0@0_YA2
102iTch40;^E@0@0_9Q01030W4H40<6OB0@0`Ie91@2nVTH40<BKB@@0`iY81033VDL40<2F@P@0_iE1
1037XTX40<^VCP@0aj=;1@36XTX40<6MA@@0^iLo102mUd840;fD@P@0_iI41033V4T80<FLBPD0_iU6
1030VTL40<:MC0@0`ii>1033We440<NSF@@0`9iD102oWED40<2NEPD0_YaD1030WUL40<BRF`P0aJ1L
1038Xed40<NRG0T0aYmJ2033WEH40<:LE@P0aZ1I1034WUL=0<>NF0@0a9mI1035X5`40<bWH`@0aj5P
1034WUd40<FOGP@0`I]J1032VeH50<BMF0@0aYiF103:XUX40<FND@@0aYmB1033W4d40<FNC`@0aYe>
1@39We<40<JPE@@0a9iE1033W4l40<FLC@@0aIa<1034VTP;0?ooo`002P3oool40;RC@P@0]8ln102c
ScT40;6==`@0[8L_102XPb/50:Z2:`@0Zh</102^Q2h40;26<P@0/HLc102bR3H40;B;>@@0]Xdk102e
TC/50;NC?@@0_YY2102gTc/40;JA>@@0]8lg102cRcH40;bD?`@0b9i<1031UdD50<2EAP@0`II7102m
Ud@40;bF@`@0_9Q21031WDL40<BPBP@0`9a61@32W4T80<6HAP@0`IM5202kTch40<2JA@@0aIm:2@31
WdP40<>OB@@0`Ie71030VTL40;fGA0@0_IA41030UdL40<^RDP@0`YU91@2hTT440;jGB0@0_iY:1032
W5440<BND`@0aZ1G1033WUL40<6LE@@0_ieE2@2mVe<40<FSG0@0djiX103:YF480<NRGPT0aIiI1036
X5T40<BNE`@0_YQA1032W5D80<FNF@P0aIiK1@37X5d40<RQGP@0b:=M1037XU`40<NRGP@0aJ1L1036
XEd40<FPG0@0_IIA1@2nUe840<:LD`@0b:9I1035WU<40<6JC`@0`ia?1035WU440<BMD0D0aYmB1033
We<40<BND`@0`ii>1033WD`40<>JB0@0`YY52`3oool000X0oooo102hTd840;B??P@0/hli102aSCL4
0:b7;`@0Z8<[1@2ZPR/40:^3;0@0[X@^102`QS840;67<`@0/XPf102dRcT40;J=>`@0]I4k1@2gTcd4
0;jJ@P@0]i<k102fTCT40;B?=`@0/h/f102lU3l40<RNC0@0`IM51@30UDH40<6FA`@0_IM4102lUT<4
0;bH@P@0`Ie71034X4X40<2LAPD0`Ya92031V4H40<6GA@P0^i<n1030VTD40<FOBPT0`Im81033WdT4
0<6MA`@0`9Y7102mUd@40;fDA0@0`9M7103;XU840<:IB@D0^991102nUdP40;nJBP@0`YaA1034WU<4
0<JPE`@0`iiG1031W5D40;nME@T0_I]C1035Xe`40=>^J0@0bZEQ2037XUh90<FNF@@0aZ1I1034WUL4
0;jHD@@0`YaE2035WUT80<FNF`D0aj1M1038XEh40<RSG@@0aj9L1037XUh40<FPG0@0aZ5M1035X5`4
0;fFD@D0_YMB1032W5<40<RRF@@0aIiC1031VTl40<>LC`@0aIiA1034WE050<JODP@0`imC1034WU<4
0<>NCP@0`ie<1033VTP40<:JA@/0oooo000:0?ooo`@0^9=2102dSch40;>?>@@0/Hdg102/Qbl40:R3
:`D0ZX8[102[Pb`40:j4;P@0/8Hb102aQc<40;:8=P@0]8/i102fSC/40;FA>`D0]i<m102nVT840;NC
>`@0]Y4i102dScL40;>;=P@0_9@o1038WT`40<6GA@D0`9E61031UTL40;fGA0@0_9I3102lV4840<6M
A`@0a:1:1030W4H50<:LB@P0`IQ61031UdD80;^C?P@0`9Y51035WdX90<6OB0@0`im91031WDL40<2J
A`@0_IM4102mU4@40<2GA`@0bj9B1032VDT50;RB@@@0_YM8102oVTX40<:LD@@0a9iC1036X5L40<>N
E`@0`IaE102oWED90;fKD`@0aJ=L103C[VP40<ZUH@P0aj9N2@35WUT40<JPF@@0a9iG102nV5440<:L
E@P0aIiI2035WU/50<NPG@@0b:5N1038Xed40<NRG0@0aj9N1035X5`40<JQG@@0aJ1L102mUU450;jG
DP@0`YaC1038XUT40<FND`@0`IY?1033W4l40<FND@@0a9e@1@36We840<>OD`@0a9iC1033WTh40<>M
C0@0`iY81032VTD;0?ooo`002P3oool40;RC@P@0]8ln102cScT40;6==`@0[8L_102XPb/50:Z2:`@0
Zh</102^Q2h40;26<P@0/HLc102bR3H40;B;>@@0]Xdk102eTC/50;NC?@@0_YY2102gTc/40;JA>@@0
]8lg102cRcH40;bD?`@0b9i<1031UdD50<2EAP@0`II7102mUd@40;bF@`@0_9Q21031WDL40<BPBP@0
`9a61@32W4T80<6HAP@0`IM5202kTch40<2JA@@0aIm:2@31WdP40<>OB@@0`Ie71030VTL40;fGA0@0
_IA41030UdL40<^RDP@0`YU91@2hTT440;jGB0@0_iY:1032W5440<BND`@0aZ1G1033WUL40<6LE@@0
_ieE2@2mVe<40<FSG0@0djiX103:YF480<NRGPT0aIiI1036X5T40<BNE`@0_YQA1032W5D80<FNF@P0
aIiK1@37X5d40<RQGP@0b:=M1037XU`40<NRGP@0aJ1L1036XEd40<FPG0@0_IIA1@2nUe840<:LD`@0
b:9I1035WU<40<6JC`@0`ia?1035WU440<BMD0D0aYmB1033We<40<BND`@0`ii>1033WD`40<>JB0@0
`YY52`3oool000X0oooo102gTdL40;6=@@@0]950102gU4<40;B@?0@0[hTf1@2]R3040:b4;@@0[88/
102^Q2h40:n5;`@0/XPb102fSST40;N?>PT0]I4k102gTcd40;JB?0@0^I@l102fTCT40;R@>`@0_IE0
1033VDL40;jD@PD0_iA51031UTL80;fDA0@0`9Y9103:Y5<40<FQB`@0`ie81@32W4T40<6HAP@0`YU7
1031V4H80;nFA0@0_9Q4102nVTH40;VF@PD0^YM31033WTd40<BOCP@0`9U:102oV4T80;nIB0@0`ie<
1032W4/50;ZCA0@0^Y=61030VD`40<6ID@@0`i]C1035WEL40<NQFP@0aImH1032WEH50;nJD`@0^iU?
1032X5P40<BOF0@0aj9L1038Xed40<ZUG`@0bjAO1@39XUd40<NPF`@0aIiI102oV5<40<6JE@P0aIaJ
1033W5T40<FNF`D0b:5P103;Y6440<NRG0@0aJ1I1037XU`40<>NF0@0aJ1J1039Y5h40<:KEPD0_iQC
2033WEH40<JPE`@0a9iE1037XEH40<FOE0@0aZ1E1@35We@40<FQD`@0a:1B1032WD`40<6KB0@0`I]6
1034W4D;0?ooo`002P3oool40;NCA`@0/He1102dTD040;ND@`@0]90l102_RCH50:f8<0@0[8@]102/
PR`40:j4;P@0[hD_102bR3840;J>>@@0]hlj2@2eTC/40;NC?@@0]Y8l102iU3`40;JA>@@0^90k102m
UD040<>IA`@0_YA21@2oU4D40<6FA`P0_IA41030VTT40<ZTD`@0aJ5;1033WDP50<:LB@@0`IQ61032
VDL40<6HAPP0_iI4102lV4@40;jJAP@0^II21@2jUd<40<>NC@@0a9m>1030VDX40;nHB@P0_iU81033
WD`40<:LB`D0^Y=4102jTdH40<2IC0@0`IUA1033Ve<40<FME`@0aj5J1035WeP40<:MEPD0_iYC102k
VDl40<:PF0@0a9mH1037XU`40<RSG@@0bZEO103;Y5l50<VRG@@0aj1K1035WUT40;nHD`@0`IYE2035
W5X40<>LF@@0aIiK1@38XF040<^TH@@0aj9L1035X5T40<NRG0@0`iiH1035X5X40<VTGP@0`Y]F1@2o
V5<80<>MEP@0aZ1G1034WUD40<NQEP@0aImD1036X5D50<FOE0@0aJ5C1034X5840<:MC0@0`I]81031
VdH40<BLA@/0oooo000:0?ooo`@0]i=7102aSD440;BA@0@0]iA3102dT3`40:n9=PD0[HP`102/Q2d4
0:b2;0@0[X@^102_QBl40;:8<P@0]Xhi102gScX90;FA>`@0]i<m102fTS`40;VD?0@0]Y4i102hT3/4
0;fE@0@0`iU7102nU4850;nDA@@0`II7202mU4@40<2JB@@0bZAC1035XD/40<>MB0D0`Ya91031V4H4
0<:IA`@0`IQ6202oUT@40;bHA0@0_YY6102iUT850;ZG@`@0`ii=1034Wdh40<2IBP@0_iQ9202oVDP4
0<>MC0@0`Ya;1@2jTd@40;ZCAP@0`9U<1031VE440<>KD`@0aIeG1037XEX40<FOF0@0`YeF1@2oVU<4
0;^IC`@0`Z1H1034WeP40<NRG0@0b:=M103:YEl40<^TG`D0bJ9M1037X5/40<FNF@@0_iQC1031VUD8
0<FLFP@0`iaI1035WU/50<RQH0@0bjAQ1037XU`40<FPF@@0aj9L1033WUP40<FPFP@0bJAN1032VeH5
0;nHD`P0`ieF1036X5L40<BNE@@0aj5F1035We@40<JPE@D0aImD1035XE<40<BPDP@0`Ye<1031VdP4
0<6KAP@0a9a52`3oool000X0oooo102gTdL40;6=@@@0]950102gU4<40;B@?0@0[hTf1@2]R3040:b4
;@@0[88/102^Q2h40:n5;`@0/XPb102fSST40;N?>PT0]I4k102gTcd40;JB?0@0^I@l102fTCT40;R@
>`@0_IE01033VDL40;jD@PD0_iA51031UTL80;fDA0@0`9Y9103:Y5<40<FQB`@0`ie81@32W4T40<6H
AP@0`YU71031V4H80;nFA0@0_9Q4102nVTH40;VF@PD0^YM31033WTd40<BOCP@0`9U:102oV4T80;nI
B0@0`ie<1032W4/50;ZCA0@0^Y=61030VD`40<6ID@@0`i]C1035WEL40<NQFP@0aImH1032WEH50;nJ
D`@0^iU?1032X5P40<BOF0@0aj9L1038Xed40<ZUG`@0bjAO1@39XUd40<NPF`@0aIiI102oV5<40<6J
E@P0aIaJ1033W5T40<FNF`D0b:5P103;Y6440<NRG0@0aJ1I1037XU`40<>NF0@0aJ1J1039Y5h40<:K
EPD0_iQC2033WEH40<JPE`@0a9iE1037XEH40<FOE0@0aZ1E1@35We@40<FQD`@0a:1B1032WD`40<6K
B0@0`I]61034W4D;0?ooo`002P3oool40;JABP@0]I19102gUTT40;RGB0@0]Y=2102cSSd50;:>>0@0
[8Ha102[Pb/40:b4;0@0[XH^102cRc<40;R@>0@0]hlh102eT3P90;F?>P@0^I<n102oVD@40;^E@0@0
^I<n102gTC`80;fD@PT0`9E6102nUDH40<2GB0@0`9U:1033W4d40<FOCP@0aZ1?1@33VT/40<:IBP@0
`iY;1031V4T40<BMCP@0`Y]<102oVTT40;bGAP@0]iA21@2iUTD40<:MC@@0aJ1B1031Ve040<:LD@@0
`ii>102oVTX40<6LC0@0_iY:1@2mUTL40;nHB@@0`9U<102oV4d40<6JC`@0aYiF1039XeX40<RRF@@0
a:1F1@31WE<40;jJCP@0`9aB102jV4h40<:PF0@0a:9J1037YEd40<bWH0D0bZEN1038Xed40<NRG0@0
aIiI1034WEP80<BMFPP0`iaI1@36We`40<NPG@P0b:=L1034WeP40<FPF@@0aJ1J1031W5H90<:ME`P0
`YaE1035WeH40<BNE@@0c:IM1037XEP40<BND`D0b:9G103:Xe@40<RQDP@0a9i;1032W4T40<>KA0@0
a9a52`3oool000X0oooo102fTDX40;F@B@@0]iI9102hUdP40;JC@P@0/hhm1@2bSSP40:b6<@@0Zh<[
102/Q2`40:j6;P@0/h/c102hT3P40;N?>0@0]I0h2@2eScX40;VC?P@0_iU4102kUD040;VC?P@0]i4l
202mU4890<2EAP@0_YE61030UdP40<2IBP@0`ia=1035Wdh40<JPC`D0`iY;1032VDX40<>JB`@0`IQ9
1034WDh40<:KC0@0_iY9102lUdH40;ND@PD0^II51032WDd40<FPDP@0`I]@1032W5440<>NCP@0_iY:
1031W4`40;nJBPD0_II7102oV4T40<2IC0@0_iQ=1031VTl40<JNEP@0bJ=J1038XUT40<BPEPD0`IeC
102nVTh40<2LDP@0^YQ>1032X5P40<BRFP@0ajEM103<Yf050<ZUGP@0b:=M1037XU`40<FNF@@0a9eH
2034WEX80<>LF@D0aYmL1037X5d80<RSG0@0a9mH1035X5T40<FPFP@0`IaF2@32WEL80<:LE@@0aImF
1034WUD40<bVG@@0aj5H1034WU<50<RRE`@0bZ=D1038XE840<BNB`@0`Ya91033Vd@40<BLA@/0oooo
000:0?ooo`@0]Y5:102eT4T40;NFB@@0^9M8102fTd840;>>?@D0/Xhh102/QS440:^3:`@0[8@/102^
QRh40;>;<`@0^90h102gScP40;F@>0T0]Hlj102iTch40;nIA0@0^iE0102iTch40;NA?0P0_IA22@30
UDH40;jEAP@0`9M81030VDX40<>LC@@0aIm>1036X4l50<>JB`@0`YU:1033VT/40<6HB@@0a9e>1032
Vd`40;nJB@@0_9M6102gU4850;VFA@@0`Ye=1035X5840<6KD0@0`YaA1033WTh40;nJBP@0`Ia<102o
VTX50;fFA`@0_iQ91030VD`40;nHC@@0`IY?1036WUH40<VSFP@0b:9I1034X5H50<6MD`@0_YY>1030
W5840;ZHCP@0`Z1H1034XUX40<NUG@@0c:MP1@3:YEh40<RSG@@0aj9L1035WUT40<BMF0P0a9eJ2033
W5T50<JOG0@0aj1M2038Xe`40<BOF0@0aJ1I1035X5X40<6LEPT0`YeG2032W5D40<FOEP@0a9iE103<
YUd40<NQF0@0a9iC1@38XUL40<ZSE0@0b:5B1034WT/40<:LB@@0`i]41034W4D;0?ooo`002P3oool4
0;JABP@0]I19102gUTT40;RGB0@0]Y=2102cSSd50;:>>0@0[8Ha102[Pb/40:b4;0@0[XH^102cRc<4
0;R@>0@0]hlh102eT3P90;F?>P@0^I<n102oVD@40;^E@0@0^I<n102gTC`80;fD@PT0`9E6102nUDH4
0<2GB0@0`9U:1033W4d40<FOCP@0aZ1?1@33VT/40<:IBP@0`iY;1031V4T40<BMCP@0`Y]<102oVTT4
0;bGAP@0]iA21@2iUTD40<:MC@@0aJ1B1031Ve040<:LD@@0`ii>102oVTX40<6LC0@0_iY:1@2mUTL4
0;nHB@@0`9U<102oV4d40<6JC`@0aYiF1039XeX40<RRF@@0a:1F1@31WE<40;jJCP@0`9aB102jV4h4
0<:PF0@0a:9J1037YEd40<bWH0D0bZEN1038Xed40<NRG0@0aIiI1034WEP80<BMFPP0`iaI1@36We`4
0<NPG@P0b:=L1034WeP40<FPF@@0aJ1J1031W5H90<:ME`P0`YaE1035WeH40<BNE@@0c:IM1037XEP4
0<BND`D0b:9G103:Xe@40<RQDP@0a9i;1032W4T40<>KA0@0a9a52`3oool000X0oooo102fU4`40;VG
C`@0^YY?102jVD`40;bKC0@0`j1>1@2gTcl40;:<=`@0[HP_102/Q2`40:b5:P@0/X/`102hTCH40;N?
=`@0]I0h1@2cSCP40;J@>`@0]8hi102jUT040;fI@`@0^98m102eScX40;bC@@@0_YE31@31V4H40;nF
A0@0_YE51030UdL40;jGB0@0_II71031VTd40<FND@D0`iU?1034VU080<6GC@@0`ia?1032Vdh40<2K
B`@0^iI6102iUTD50;ZFB0@0`9a>1033We<40<>ME0@0aImF1034X5@40<6MD@@0`9]=1031W4h50<6L
C0@0_iY:1031VT/40<>LC@@0`ia?1037X5<40<RRE`@0bJ=H1035XED=0<2LD0@0_imD1030X5D40<6Q
EP@0a:AI2@35XeT80<VWG`@0aj9K1035X5T40<BOF0@0aJ1I2034WeT50<:ME`@0`9]E1034WeP40<^V
G`@0aJ1J2032WEL40;nJE0@0`iiH1@30VeD40<>NF0@0`IaF1034WeP40<>NE`@0aj5F1038XUL40<RS
E@D0aj1C103<YEH40<VPD@@0aYe;1037WT`40<NMB@@0aI]72`3oool000X0oooo102fU4`40;VGC`@0
^YY?102jVD`40;bKC0@0`j1>1@2gTcl40;:<=`@0[HP_102/Q2`40:b5:P@0/X/`102hTCH40;N?=`@0
]I0h1@2cSCP40;J@>`@0]8hi102jUT040;fI@`@0^98m102eScX40;bC@@@0_YE31@31V4H40;nFA0@0
_YE51030UdL40;jGB0@0_II71031VTd40<FND@D0`iU?1034VU080<6GC@@0`ia?1032Vdh40<2KB`@0
^iI6102iUTD50;ZFB0@0`9a>1033We<40<>ME0@0aImF1034X5@40<6MD@@0`9]=1031W4h50<6LC0@0
_iY:1031VT/40<>LC@@0`ia?1037X5<40<RRE`@0bJ=H1035XED=0<2LD0@0_imD1030X5D40<6QEP@0
a:AI2@35XeT80<VWG`@0aj9K1035X5T40<BOF0@0aJ1I2034WeT50<:ME`@0`9]E1034WeP40<^VG`@0
aJ1J2032WEL40;nJE0@0`iiH1@30VeD40<>NF0@0`IaF1034WeP40<>NE`@0aj5F1038XUL40<RSE@D0
aj1C103<YEH40<VPD@@0aYe;1037WT`40<NMB@@0aI]72`3oool000X0oooo102fU4`40;VGC`@0^YY?
102jVD`40;bKC0@0`j1>1@2gTcl40;:<=`@0[HP_102/Q2`40:b5:P@0/X/`102hTCH40;N?=`@0]I0h
1@2cSCP40;J@>`@0]8hi102jUT040;fI@`@0^98m102eScX40;bC@@@0_YE31@31V4H40;nFA0@0_YE5
1030UdL40;jGB0@0_II71031VTd40<FND@D0`iU?1034VU080<6GC@@0`ia?1032Vdh40<2KB`@0^iI6
102iUTD50;ZFB0@0`9a>1033We<40<>ME0@0aImF1034X5@40<6MD@@0`9]=1031W4h50<6LC0@0_iY:
1031VT/40<>LC@@0`ia?1037X5<40<RRE`@0bJ=H1035XED=0<2LD0@0_imD1030X5D40<6QEP@0a:AI
2@35XeT80<VWG`@0aj9K1035X5T40<BOF0@0aJ1I2034WeT50<:ME`@0`9]E1034WeP40<^VG`@0aJ1J
2032WEL40;nJE0@0`iiH1@30VeD40<>NF0@0`IaF1034WeP40<>NE`@0aj5F1038XUL40<RSE@D0aj1C
103<YEH40<VPD@@0aYe;1037WT`40<NMB@@0aI]72`3oool000X0oooo102fU4`40;VGC`@0^YY?102j
VD`40;bKC0@0`j1>1@2gTcl40;:<=`@0[HP_102/Q2`40:b5:P@0/X/`102hTCH40;N?=`@0]I0h1@2c
SCP40;J@>`@0]8hi102jUT040;fI@`@0^98m102eScX40;bC@@@0_YE31@31V4H40;nFA0@0_YE51030
UdL40;jGB0@0_II71031VTd40<FND@D0`iU?1034VU080<6GC@@0`ia?1032Vdh40<2KB`@0^iI6102i
UTD50;ZFB0@0`9a>1033We<40<>ME0@0aImF1034X5@40<6MD@@0`9]=1031W4h50<6LC0@0_iY:1031
VT/40<>LC@@0`ia?1037X5<40<RRE`@0bJ=H1035XED=0<2LD0@0_imD1030X5D40<6QEP@0a:AI2@35
XeT80<VWG`@0aj9K1035X5T40<BOF0@0aJ1I2034WeT50<:ME`@0`9]E1034WeP40<^VG`@0aJ1J2032
WEL40;nJE0@0`iiH1@30VeD40<>NF0@0`IaF1034WeP40<>NE`@0aj5F1038XUL40<RSE@D0aj1C103<
YEH40<VPD@@0aYe;1037WT`40<NMB@@0aI]72`3oool000X0oooo102mW5D40;jMEP@0_YiE102lW5<4
0;^JC@@0^iM91@2iUT@40;RB?@@0/hhf102_Qbl40:b4;0@0/8P`102fSSH40;VA>P@0^90i1@2hT3/4
0;J@?@@0]8hk102gTcl80;VE@@@0^9A0102iTd040;ZD@@D0_YQ5202mUd@40;jHA@@0_IQ7102mV4P4
0;bEAP@0`9U<1@36W5840<BJD0@0`IM=1034VU040<:HC0@0`iU=1031VT/40;fFA`@0^iI81@2iU4H4
0;bHC0@0`IeC1034X5H80<NRF`@0`YeF102iUDT40<2LD0D0aZ5A1032WDd<0<BOC`@0aZ5C1038XeD4
0<bVF`@0aj=G1@30W5080<6MD@@0_imB1030X5<40<6QEP@0`Z9G1034XUP50<FSF@@0ajEM1035Xe/8
0<JQFPP0aJ1I2035XEL50<:NE0@0_i]A1031W5D40<>NE`@0`YeF1033WUL40<JQF`@0`iiH1032WEL5
0<BOF@`0a9eH1033W5L40<NQF0@0aZ1G1034We450<JODP@0cJ=G1038W5440<JKC@@0bIi@103:We04
0<RMCP/0oooo000:0?ooo`@0_IaE102nWEH40;jNE@@0_9aC102kVTd40;^GB@D0^II4102hTSd40;>>
=P@0[hL_102/Q2`40;28<0@0]Xhf102iTCX40;R@>@D0^90k102fT3d40;B>>`@0]i<o202iUD440;RD
@0@0^I=0102jU4450;jHA@P0_IM4102nV4D40;fHA`@0_IQ8102lUDH40<2IC0D0aYaB1034VU040<6G
C@@0a9Y@1032V4`40<>IC@@0`IY;102mUTL40;^FB0D0^IA6102lV4`40<6MD`@0a:1F2037XU/40<:M
EP@0^IE91030W5050<JQD@@0`Ye=3034Wdl40<JQD`@0b:=E103<YU/40<NSE`D0`9a@2031WE440;nO
DP@0`:1C1031XEH40<:RE`@0a:9H1@35XeT40<NUG@@0aJ=K2036XEX80<FPF@P0aJ5G1@32WU@40;nK
D@@0`IaE1033WUL40<:MEP@0`iiG1036XE/40<>NF0@0`YeG1@34WeT<0<BMF0@0`iaG1037XEP40<JP
E`@0a9mA1@36We840<fSE`@0b9aA1036Vdd40<VND0@0bYm@1038WDh;0?ooo`002P3oool40;fLE@@0
_YeF102nWUD40;bLD`@0^iY=102kUdT50;VFA0@0^98m102cSSH40:n7;`@0[8@/102`R3040;J>=P@0
^I4j102hT3T50;R@>`@0]Y0m102dSS/40;NC?`P0^IE1102hU4040;VC@0@0^YA11@2nV4D80;fGA0@0
_YQ5102mV4L40;fHB0@0_9E61030VD`50<JLDP@0a9Y@1031Udd40<BJD0@0`YQ<1033VDd40<6JB`@0
_II7102kUTP50;VDAP@0_9Q<1031WE<40<BPEPP0aj9K1032WEH40;VEB@@0`9a@1@36XE440<:MC@`0
a9m?1036XE<40<RSE@@0c:IK1037XeL50<2LD0P0`IeA102oWe840<2PD`@0`J5F1032XUL40<BRF0D0
aJ=I1037YEd40<FSF`P0aZ5J2035X5T80<FQE`D0`YiD102oVe440<6LE@@0`iiG1032WEH40<>NE`@0
aZ5K1033WUP40<:ME`D0a9mI3034WEP40<>LE`@0aj5H1036X5L40<BOD@D0aYmB103=XeL40<RLD@@0
aY]=1039WU040<ZOD0@0b9e>2`3oool000X0oooo102mW5D40;jMEP@0_YiE102lW5<40;^JC@@0^iM9
1@2iUT@40;RB?@@0/hhf102_Qbl40:b4;0@0/8P`102fSSH40;VA>P@0^90i1@2hT3/40;J@?@@0]8hk
102gTcl80;VE@@@0^9A0102iTd040;ZD@@D0_YQ5202mUd@40;jHA@@0_IQ7102mV4P40;bEAP@0`9U<
1@36W5840<BJD0@0`IM=1034VU040<:HC0@0`iU=1031VT/40;fFA`@0^iI81@2iU4H40;bHC0@0`IeC
1034X5H80<NRF`@0`YeF102iUDT40<2LD0D0aZ5A1032WDd<0<BOC`@0aZ5C1038XeD40<bVF`@0aj=G
1@30W5080<6MD@@0_imB1030X5<40<6QEP@0`Z9G1034XUP50<FSF@@0ajEM1035Xe/80<JQFPP0aJ1I
2035XEL50<:NE0@0_i]A1031W5D40<>NE`@0`YeF1033WUL40<JQF`@0`iiH1032WEL50<BOF@`0a9eH
1033W5L40<NQF0@0aZ1G1034We450<JODP@0cJ=G1038W5440<JKC@@0bIi@103:We040<RMCP/0oooo
000:0?ooo`@0]iUA102fV5040;RJE0@0^ieE102jVU440;FDA`D0^9M8102jUD@40;RD@0@0/hdh102a
RC@40;>;=P@0^Hlk3@2lTSh40;NA?P@0^YA1102kUTD40;NB@@@0^YE4102iU4<40;VE@@@0^9A01@2l
UT440;nIA0P0`Ie7102lVDD40;ZF@P@0^9=2102mUdH50<FLC0@0`iY:1032VDT40<JMC@P0aIY;1034
Vd/40<2GA`@0^iA51@2jTdH40;bHBP@0`9aB1032X5H40<VWG`@0bjUR1031WeP40<2KE0@0_9M@1@32
WU840<ZVFP@0a:1D1032WU840<>OD`@0aJ5E1039YE/40<ZVG0@0`j5G1@30WU@80<6OE@@0`Z1F1033
XEL40<6OE`@0`9iF1034XUX50<RVGP@0aZ5J1031W5D40<>NE`@0aj9K1038Xe`40<FPF@P0`imE1@32
WU840<2LD0@0_i]A1030W5840<>OE@@0`YiD1034WeP40<RSG0T0aIiI1034WEX40<:KF0@0a9eJ1036
We`40<NQFP@0`ieF1034WU<50<BMDP@0aYmD1036W5840<RNE0@0bImE1039We<40<ZPE0/0oooo000:
0?ooo`@0]iUA102fV5040;RJE0@0^ieE102jVU440;FDA`D0^9M8102jUD@40;RD@0@0/hdh102aRC@4
0;>;=P@0^Hlk3@2lTSh40;NA?P@0^YA1102kUTD40;NB@@@0^YE4102iU4<40;VE@@@0^9A01@2lUT44
0;nIA0P0`Ie7102lVDD40;ZF@P@0^9=2102mUdH50<FLC0@0`iY:1032VDT40<JMC@P0aIY;1034Vd/4
0<2GA`@0^iA51@2jTdH40;bHBP@0`9aB1032X5H40<VWG`@0bjUR1031WeP40<2KE0@0_9M@1@32WU84
0<ZVFP@0a:1D1032WU840<>OD`@0aJ5E1039YE/40<ZVG0@0`j5G1@30WU@80<6OE@@0`Z1F1033XEL4
0<6OE`@0`9iF1034XUX50<RVGP@0aZ5J1031W5D40<>NE`@0aj9K1038Xe`40<FPF@P0`imE1@32WU84
0<2LD0@0_i]A1030W5840<>OE@@0`YiD1034WeP40<RSG0T0aIiI1034WEX40<:KF0@0a9eJ1036We`4
0<NQFP@0`ieF1034WU<50<BMDP@0aYmD1036W5840<RNE0@0bImE1039We<40<ZPE0/0oooo000:0?oo
o`@0]iUA102fV5040;RJE0@0^ieE102jVU440;FDA`D0^9M8102jUD@40;RD@0@0/hdh102aRC@40;>;
=P@0^Hlk3@2lTSh40;NA?P@0^YA1102kUTD40;NB@@@0^YE4102iU4<40;VE@@@0^9A01@2lUT440;nI
A0P0`Ie7102lVDD40;ZF@P@0^9=2102mUdH50<FLC0@0`iY:1032VDT40<JMC@P0aIY;1034Vd/40<2G
A`@0^iA51@2jTdH40;bHBP@0`9aB1032X5H40<VWG`@0bjUR1031WeP40<2KE0@0_9M@1@32WU840<ZV
FP@0a:1D1032WU840<>OD`@0aJ5E1039YE/40<ZVG0@0`j5G1@30WU@80<6OE@@0`Z1F1033XEL40<6O
E`@0`9iF1034XUX50<RVGP@0aZ5J1031W5D40<>NE`@0aj9K1038Xe`40<FPF@P0`imE1@32WU840<2L
D0@0_i]A1030W5840<>OE@@0`YiD1034WeP40<RSG0T0aIiI1034WEX40<:KF0@0a9eJ1036We`40<NQ
FP@0`ieF1034WU<50<BMDP@0aYmD1036W5840<RNE0@0bImE1039We<40<ZPE0/0oooo000:0?ooo`@0
]iUA102fV5040;RJE0@0^ieE102jVU440;FDA`D0^9M8102jUD@40;RD@0@0/hdh102aRC@40;>;=P@0
^Hlk3@2lTSh40;NA?P@0^YA1102kUTD40;NB@@@0^YE4102iU4<40;VE@@@0^9A01@2lUT440;nIA0P0
`Ie7102lVDD40;ZF@P@0^9=2102mUdH50<FLC0@0`iY:1032VDT40<JMC@P0aIY;1034Vd/40<2GA`@0
^iA51@2jTdH40;bHBP@0`9aB1032X5H40<VWG`@0bjUR1031WeP40<2KE0@0_9M@1@32WU840<ZVFP@0
a:1D1032WU840<>OD`@0aJ5E1039YE/40<ZVG0@0`j5G1@30WU@80<6OE@@0`Z1F1033XEL40<6OE`@0
`9iF1034XUX50<RVGP@0aZ5J1031W5D40<>NE`@0aj9K1038Xe`40<FPF@P0`imE1@32WU840<2LD0@0
_i]A1030W5840<>OE@@0`YiD1034WeP40<RSG0T0aIiI1034WEX40<:KF0@0a9eJ1036We`40<NQFP@0
`ieF1034WU<50<BMDP@0aYmD1036W5840<RNE0@0bImE1039We<40<ZPE0/0oooo000:0?ooo`@0]YQ@
102gVE<80;NHE@@0^9M@102gUDd50;NFB@@0^iI8102iU4<40;RB@@P0^I0n102kT4440;bA@P@0_I<o
1@2kTCl40;^B@0@0^Y51202jUDD80;ZEA0P0^9A01@2kUcl40;jJ@P@0_ie41031WdH40;nMAP@0_YY4
102hU3`40;jI@@D0`i]61031VD@80<>IA@@0aYa:1033VDL40<:HAP@0_iA5102hTT450;bEB0@0`9a>
102oVe440<2PE@@0bjYS103C/FX40<ZWH`@0ajEN1032X5T50<6OE`@0aZAL2034XUX40<:PF0@0a:9J
1039Yel40<BRFP@0_YaB1@31WeD80<>QE`@0aZ5J1031W5D80<BOF@@0`iiH1@37XU`40<RQG0@0a9eH
102oV5<40<RQG0@0c:IO1038XU/40<BNE@@0`ieD1@31Ve040<2JC`@0`9a@102nVTh40;nKC`@0`9a@
1031WE<40<BOF0@0aZ1I1@35WUT40<BMFP@0aYmL1037X5l40<FNG@@0bJ5L1036WUT40<VQF@D0aimG
2036WUP80<NOE`@0bJ9G103>Ye`;0?ooo`002P3oool40;JHD0@0]iUC202gV5D40;RGD0@0]iE=1@2g
UTT40;^FB0@0^IA3102hTT480;V@?P@0^i11102lTD840;fC?`D0^i4o102kTT040;ZA@@P0^YE5202j
UD@80;RD@0D0^iLo102nVT840;nMA0@0`Im6102oWDH40;jJA0@0^9@l102nVD450<>KAP@0`IU42033
VDD40<JLBP@0`iU71032V4H40;nDA@@0^9911@2lUDP40<2LCP@0_i]A1030X5D40<^ZH`@0dk5Z103:
Yf<40<NUGP@0`Z1I1@31WeL40<JTG0P0a:9J1032X5P40<BRFP@0bJMO1034XUX40;jLDPD0`ImE2033
XEL40<JQFP@0`IaE2034WeT40<>NF0D0aj9L1038XE`40<BMF0@0_iQC1038XE`40<bVG`@0b:9K1034
WUD40<>ME0D0`I]@1030VTl40<2LD0@0_YY>102oVdl40<2LD0@0`IeC1034WeP40<JPF@D0aIiI1034
WEX40<JOG0@0aj1O1035WUd40<VQG0@0aYiI1039XET50<NOE`P0aYiH2037WeL40<VRE`@0cZML2`3o
ool000X0oooo102fV5040;NID`P0]iQE102hUe040;NEC@D0]iI9102kUTP40;VD@`@0^991202iT3h4
0;^@@@@0_952102mTcl50;^A?`@0^i90102jTD480;ZEA@P0^YE4202hU4050;^G?`@0_YY2102oWD@4
0<6OAP@0_ie6102nVT@40;RD?0@0_YU11@33VdH40<6IA0P0`iU51036W4X40<>IA`@0`YQ6102oU4D4
0;RB@@D0_9E81030W4h40;nKD@@0`:1E103;ZV<40=>aJP@0bZMS1037YEh40<:PF@D0`ImG1036Y5`8
0<BRFP@0`Z1H1034XUX40<VWG`@0a:9J102nW5850<6OE@P0`j5G1036XEX40<6LE@P0a9mI1033WUP5
0<NRG0@0b:5L1034WEP40;nHD`@0b:5L103<YUl40<RRF`@0a9iE1033WE@50<6KD0@0`9Y?1030W504
0;jJCP@0_i]?1030W5040<6MD`@0a9mH1036X5T50<FNF@@0a9eJ1036We`40<NPG`@0aIiM1039XE`4
0<JNF@@0bJ5I1@37WeL80<JNF0P0aimG1039XUL40<jWG0/0oooo000:0?ooo`@0]YQ@102gVE<80;NH
E@@0^9M@102gUDd50;NFB@@0^iI8102iU4<40;RB@@P0^I0n102kT4440;bA@P@0_I<o1@2kTCl40;^B
@0@0^Y51202jUDD80;ZEA0P0^9A01@2kUcl40;jJ@P@0_ie41031WdH40;nMAP@0_YY4102hU3`40;jI
@@D0`i]61031VD@80<>IA@@0aYa:1033VDL40<:HAP@0_iA5102hTT450;bEB0@0`9a>102oVe440<2P
E@@0bjYS103C/FX40<ZWH`@0ajEN1032X5T50<6OE`@0aZAL2034XUX40<:PF0@0a:9J1039Yel40<BR
FP@0_YaB1@31WeD80<>QE`@0aZ5J1031W5D80<BOF@@0`iiH1@37XU`40<RQG0@0a9eH102oV5<40<RQ
G0@0c:IO1038XU/40<BNE@@0`ieD1@31Ve040<2JC`@0`9a@102nVTh40;nKC`@0`9a@1031WE<40<BO
F0@0aZ1I1@35WUT40<BMFP@0aYmL1037X5l40<FNG@@0bJ5L1036WUT40<VQF@D0aimG2036WUP80<NO
E`@0bJ9G103>Ye`;0?ooo`002P3oool40;RFC`@0^IM@102hUe840;bKEP@0]iI?102fUDh50;RFC0@0
^IM=102iUDL40;^GB@@0^YE4102iU4<40;ZF@P@0_i]7102mUdH=0;VC@P@0^YE51032WDd40<2KB`@0
_YU9102mV4L40;bGAPD0^iM3102mVDD40;nKA@@0`9a61031W4@40<>NAP@0_iY2102mV4050;jH@`@0
_iU41031V4H40<:IB@@0`9M71030UdP40;nEB@@0_I=7102jUDL50;fHBP@0^iM;102mVDd40<6PD`@0
cJ]Q1039Yel40;nMEPP0_IYF1@34XEl40<NTHP@0a:=N1032XE`40;nOEP@0_YiE102oWE<40<6OE`@0
`9iF1@33XEX40<6NFPP0`j1N1035XV840<>MG0@0]Y1?1035WUT50<jWHP@0bZ=N1034WEP40;jGE0@0
`iaI2036WeX40<RPF0@0aIeE1@33VDd40<:HC0@0`Ia>1030Vdd40;jIB`@0^iI81030VTl40<FOEP@0
aJ5G1@35X5X40<FNF@@0a9eJ1035WU/40<VRG`@0aZ1I1037XEX90<RPF0@0aimG1038X5P40<NOE`@0
a9aD1039XUL40=B]H0/0oooo000:0?ooo`@0^9I?102iUe040;RGDP@0_9]F102gUTl40;JECPD0^9I<
102iUdd40;VEA`@0^iM9102jUD@40;VD@`@0^YI2102oVdL40;fGAPd0^I=2102jUDD40<:MC@@0`9];
102nVDT40;fHA`@0_9M61@2kUd<40;fIA@@0_i]51030W4H40<6LA0@0`ii6102oVT840;fH@0D0_YQ3
102oVD@40<6HAP@0`YU91030UdL40<2GB0@0_iE9102mTdL40;ZEA`D0_IQ:102kUd/40;fIC@@0`J1C
103=Zf440<VWG`@0_ieF202mVUH50<BQG`@0ajAR1034Xeh40<:QG0@0_imF102nWUD40;nMD`@0`ImG
1030WUH50<>QFP@0`IiJ2033X5h40<FRHP@0`ieL102fT4l40<FNF@D0cZMR103:Xeh40<BMF0@0_YMD
1033W5T80<JOFP@0b:1H1035WED50<>IC@@0`YQ<1031W4h40<2KC@@0_YU;102kUTP40<2JC`@0aImF
1035XEL50<FPFP@0aIiI1034WEX40<FNF`@0bJ9O1036X5T40<NQFPT0b:1H1037WeL40<RPF0@0aimG
1034W5@40<VRE`@0e:eP2`3oool000X0oooo102hUTl40;VGD0@0^9MB102lVeH40;NFC`@0]YE>1@2h
UT`40;VGC@@0^IE7102kUdT40;ZEA0@0^IA3102jUT840;nKA`@0_IM63@2iTd840;ZEA@@0`Ye=1030
Vd/40;jIB@@0_IQ7102lUdH50;^G@`@0_IU5102oVdD40<2LAP@0`Ia41033WTH40;nJ@P@0_IQ01@2n
V4<40;nIA0@0`IQ61032VDT40<2GA`@0`9M8102oUDT40;fCA`@0^YE71@2mV4X40;^GB`@0_IU=1031
X5<40<f[H@@0bJMO102oWEH80;fJEPD0a:5O1037Y6840<BSGP@0`Z5L102oWeH40;jNE@@0_ieC1031
WeL40<2NEPD0`j5J1031WUX80<>PGP@0aJ9R1033WE`40;J@C`@0aIiI1@3>Yf840<ZSGP@0a9eH102n
Ue@40<>LF@P0aYmJ1038X5P40<FME@D0`iU=1032V4`40<6LCP@0`9]=102nVD/40;^FB0@0`9Y?1035
WeH40<FQE`D0aJ1J1035WUT40<BMFP@0aIiK1039XUl40<JPF@@0aj5J2@38X5P40<NOE`@0b:1H1037
WeL40<BLE0@0bJ9G103D[F0;0?ooo`002P3oool40;RFC`@0^IM@102hUe840;bKEP@0]iI?102fUDh5
0;RFC0@0^IM=102iUDL40;^GB@@0^YE4102iU4<40;ZF@P@0_i]7102mUdH=0;VC@P@0^YE51032WDd4
0<2KB`@0_YU9102mV4L40;bGAPD0^iM3102mVDD40;nKA@@0`9a61031W4@40<>NAP@0_iY2102mV405
0;jH@`@0_iU41031V4H40<:IB@@0`9M71030UdP40;nEB@@0_I=7102jUDL50;fHBP@0^iM;102mVDd4
0<6PD`@0cJ]Q1039Yel40;nMEPP0_IYF1@34XEl40<NTHP@0a:=N1032XE`40;nOEP@0_YiE102oWE<4
0<6OE`@0`9iF1@33XEX40<6NFPP0`j1N1035XV840<>MG0@0]Y1?1035WUT50<jWHP@0bZ=N1034WEP4
0;jGE0@0`iaI2036WeX40<RPF0@0aIeE1@33VDd40<:HC0@0`Ia>1030Vdd40;jIB`@0^iI81030VTl4
0<FOEP@0aJ5G1@35X5X40<FNF@@0a9eJ1035WU/40<VRG`@0aZ1I1037XEX90<RPF0@0aimG1038X5P4
0<NOE`@0a9aD1039XUL40=B]H0/0oooo000:0?ooo`@0]YI=102gUdh40;FGC`@0]YQ@102eUdl40;RG
D0D0]iM<102jVD`40;bHBP@0^YM6102iU4<40;bGAP@0^iM31030W4P40<:LB@D0^iE2102kUD@80;ZD
@`@0_9I5102kUTD40;fHA`@0_9M6102nVDP50;nKA`@0_YY6102nVT@40;nKA@@0`9a61031WDL40<6K
AP@0_iU41@2nV4D40;fGA0@0_YE51031V4T40<>JB`@0a9Y>1032Ve040;nHC@T0^997102iUDT40;nK
C`@0`Z5D1035Y5L40<:PEP@0_I]C102]Rd<40;ZHD@D0`j1L1038YF440=2]J@@0a:5M202jV5040;^I
C`@0_I]A1038YUh50<2NE`@0_9YC1036Xf440<n^J`@0aJ=S1031WU`40;bFE@@0_iYF1@39XUl40<^T
H@@0aYmL102oVUH40<2KE`P0aj9N103C[FH40<BNE`D0`Y]@1033W5440<6KD0@0_YQ=102mUd`40;^E
BP@0`I]@1036X5D40<FQE@D0aJ5G1036X5L40<FOF0@0aj5J1036X5T40<ZTG@@0aj5J2@39XET40<JP
E`@0aImF1039XeX40<JPE`@0aImD1037XEH;0?ooo`002P3oool40;JFC@@0]iM>102eUdl40;JHD0@0
]IM?102hUe050;NGC0@0^YU<102lV4X40;ZGAP@0^IA3102lUdH40;^G@`@0`9a81032W4T50;^E@P@0
^iE4202jU4<40;bFA@@0^iI5102mV4L40;bGAP@0_YU81@2oVdL40;jJAP@0_YY4102oVdD40<2LAP@0
`Ie71031VdH40;nIA0D0_YQ5102mUd@40;jEA@@0`IQ91033VT/40<BJCP@0`Y]@102oV4d90;RBA`@0
^IE9102oVdl40<:QE0@0aJAG1032X5H40;fKD`@0[H]3102jV5450<>PG0@0b:EQ103@[FT40<BQG@P0
^YQ@102kVDl40;fKD@@0b:IN1@30WUL40;bJD`@0aZ=Q103?[V/40<FSH`@0`IiL102lUUD40;nJEPD0
bJ9O103;Y6440<JOG0@0_iYF1030VeL80<NRGP@0djeV1034WUL50<:KD0@0`iaA1031Ve040;jHC@@0
_IM<102kUDX40<6KD0@0aZ1E1035XED50<FQE`@0aZ1G1035WeP40<NQFP@0aZ1I103:Y5d40<NQFPT0
bJ5I1036X5L40<FOEP@0bJ=J1036X5L40<FOE0@0aj5F2`3oool000X0oooo102fUTd40;NGCP@0]IM?
102fV5040;FGC`@0^9M@1@2gUd`40;ZIC0@0_9Q:102jUdH40;VD@`@0_9M6102kUd<40<2LB0@0`Ya9
1@2kUD840;^EA0P0^YA3102lUTD40;^FA@@0_IQ7102lUdH40;jIB0D0_i]7102nVTH40;jJA0@0_i]5
1030W4H40<6MA`@0`I]6102oVD@50;jHA@@0_IM4102nUDD40<6HB@@0`iY;1034VTh40<:KD0@0_iQ=
2@2hTTL40;VEB@@0_i]?1032XE@40<FTE`@0`Z1F102mVe<40:f;@`@0^YQA1@33X5`40<RUH@@0d:eY
1034XEd80;ZHD0@0^iU?102mVe440<RVGPD0`9iG102lVU<40<JSH@@0cji[1035Xf<40<6NG0@0_9IE
102oVUH50<VRG`@0bjAQ1036We`40;nJEP@0`9]G2037XUh40=>]IP@0a9iG1@32Ve040<>LD@@0`I]@
102nV4d40;fGC0@0^iE:1031Ve040<JPE@@0aJ5E1@35XEL40<JPE`@0aImH1037XEX40<JPF@@0bZAM
1037XEX90<VQF@@0aZ1G1035WeH40<VSFP@0aZ1G1035We@40<NQEP/0oooo000:0?ooo`@0]YI=102g
Udh40;FGC`@0]YQ@102eUdl40;RGD0D0]iM<102jVD`40;bHBP@0^YM6102iU4<40;bGAP@0^iM31030
W4P40<:LB@D0^iE2102kUD@80;ZD@`@0_9I5102kUTD40;fHA`@0_9M6102nVDP50;nKA`@0_YY6102n
VT@40;nKA@@0`9a61031WDL40<6KAP@0_iU41@2nV4D40;fGA0@0_YE51031V4T40<>JB`@0a9Y>1032
Ve040;nHC@T0^997102iUDT40;nKC`@0`Z5D1035Y5L40<:PEP@0_I]C102]Rd<40;ZHD@D0`j1L1038
YF440=2]J@@0a:5M202jV5040;^IC`@0_I]A1038YUh50<2NE`@0_9YC1036Xf440<n^J`@0aJ=S1031
WU`40;bFE@@0_iYF1@39XUl40<^TH@@0aYmL102oVUH40<2KE`P0aj9N103C[FH40<BNE`D0`Y]@1033
W5440<6KD0@0_YQ=102mUd`40;^EBP@0`I]@1036X5D40<FQE@D0aJ5G1036X5L40<FOF0@0aj5J1036
X5T40<ZTG@@0aj5J2@39XET40<JPE`@0aImF1039XeX40<JPE`@0aImD1037XEH;0?ooo`002P3oool4
0;JFC@@0]iM>102eUdl40;JHD0@0]IM?102hUe050;NGC0@0^YU<102lV4X40;ZGAP@0^IA3102lUdH4
0;^G@`@0`9a81032W4T50;^E@P@0^iE4202jU4<40;bFA@@0^iI5102mV4L40;bGAP@0_YU81@2oVdL4
0;jJAP@0_YY4102oVdD40<2LAP@0`Ie71031VdH40;nIA0D0_YQ5102mUd@40;jEA@@0`IQ91033VT/4
0<BJCP@0`Y]@102oV4d90;RBA`@0^IE9102oVdl40<:QE0@0aJAG1032X5H40;fKD`@0[H]3102jV545
0<>PG0@0b:EQ103@[FT40<BQG@P0^YQ@102kVDl40;fKD@@0b:IN1@30WUL40;bJD`@0aZ=Q103?[V/4
0<FSH`@0`IiL102lUUD40;nJEPD0bJ9O103;Y6440<JOG0@0_iYF1030VeL80<NRGP@0djeV1034WUL5
0<:KD0@0`iaA1031Ve040;jHC@@0_IM<102kUDX40<6KD0@0aZ1E1035XED50<FQE`@0aZ1G1035WeP4
0<NQFP@0aZ1I103:Y5d40<NQFPT0bJ5I1036X5L40<FOEP@0bJ=J1036X5L40<FOE0@0aj5F2`3oool0
00X0oooo102fU4X40;NEB`P0]IM>102dUTd40;NID0D0^YY=102lVdh40;VHA`@0^YM6102jUD@40;bG
AP@0_IU5102nVTH40<2LB0D0^iM3102mUd@40;RB?`P0]Y0m102hTSl40;ZD@@@0_9I3102nV4D50;nK
A`@0`9a81032WTX40<>OB`P0`Ii:2030W4P50<2JB@@0_II7102kU4D40;jGBP@0`iaA1035WU<40<:J
DP@0a9aD102lUTd50;ZDB`@0^iE:1030VTl40<BPDP@0aJ5C102mW4/40;^JB`@0]IA7102gUDd50<6L
EP@0bjIR103:YF440<RSG@@0`YeF102kUdd40;VHB`@0_I]A102mWE850<2OF0@0`J1I1033XUl40<RV
IP@0bZQY1034XF440;bIF@@0_YQG1@35Weh40<ZTH`@0cZQW1036X5l40<6KFP@0`YeI103<Yf<40<jY
H`@0aj9L1@33WEH40<JPF@@0aImF1031Ve840<2JC`@0_iU>1033WU0=0<FPDP@0a9iC1036X5D40<JP
E`@0aImF1036X5L80<RRF@D0cZQO1039XeX40<>ME0@0aj5H1036X5L40<JPE@@0aImD2`3oool000X0
oooo102fU4X40;NEB`P0]IM>102dUTd40;NID0D0^YY=102lVdh40;VHA`@0^YM6102jUD@40;bGAP@0
_IU5102nVTH40<2LB0D0^iM3102mUd@40;RB?`P0]Y0m102hTSl40;ZD@@@0_9I3102nV4D50;nKA`@0
`9a81032WTX40<>OB`P0`Ii:2030W4P50<2JB@@0_II7102kU4D40;jGBP@0`iaA1035WU<40<:JDP@0
a9aD102lUTd50;ZDB`@0^iE:1030VTl40<BPDP@0aJ5C102mW4/40;^JB`@0]IA7102gUDd50<6LEP@0
bjIR103:YF440<RSG@@0`YeF102kUdd40;VHB`@0_I]A102mWE850<2OF0@0`J1I1033XUl40<RVIP@0
bZQY1034XF440;bIF@@0_YQG1@35Weh40<ZTH`@0cZQW1036X5l40<6KFP@0`YeI103<Yf<40<jYH`@0
aj9L1@33WEH40<JPF@@0aImF1031Ve840<2JC`@0_iU>1033WU0=0<FPDP@0a9iC1036X5D40<JPE`@0
aImF1036X5L80<RRF@D0cZQO1039XeX40<>ME0@0aj5H1036X5L40<JPE@@0aImD2`3oool000X0oooo
102fU4X40;NEB`P0]IM>102dUTd40;NID0D0^YY=102lVdh40;VHA`@0^YM6102jUD@40;bGAP@0_IU5
102nVTH40<2LB0D0^iM3102mUd@40;RB?`P0]Y0m102hTSl40;ZD@@@0_9I3102nV4D50;nKA`@0`9a8
1032WTX40<>OB`P0`Ii:2030W4P50<2JB@@0_II7102kU4D40;jGBP@0`iaA1035WU<40<:JDP@0a9aD
102lUTd50;ZDB`@0^iE:1030VTl40<BPDP@0aJ5C102mW4/40;^JB`@0]IA7102gUDd50<6LEP@0bjIR
103:YF440<RSG@@0`YeF102kUdd40;VHB`@0_I]A102mWE850<2OF0@0`J1I1033XUl40<RVIP@0bZQY
1034XF440;bIF@@0_YQG1@35Weh40<ZTH`@0cZQW1036X5l40<6KFP@0`YeI103<Yf<40<jYH`@0aj9L
1@33WEH40<JPF@@0aImF1031Ve840<2JC`@0_iU>1033WU0=0<FPDP@0a9iC1036X5D40<JPE`@0aImF
1036X5L80<RRF@D0cZQO1039XeX40<>ME0@0aj5H1036X5L40<JPE@@0aImD2`3oool000X0oooo102f
U4X40;NEB`P0]IM>102dUTd40;NID0D0^YY=102lVdh40;VHA`@0^YM6102jUD@40;bGAP@0_IU5102n
VTH40<2LB0D0^iM3102mUd@40;RB?`P0]Y0m102hTSl40;ZD@@@0_9I3102nV4D50;nKA`@0`9a81032
WTX40<>OB`P0`Ii:2030W4P50<2JB@@0_II7102kU4D40;jGBP@0`iaA1035WU<40<:JDP@0a9aD102l
UTd50;ZDB`@0^iE:1030VTl40<BPDP@0aJ5C102mW4/40;^JB`@0]IA7102gUDd50<6LEP@0bjIR103:
YF440<RSG@@0`YeF102kUdd40;VHB`@0_I]A102mWE850<2OF0@0`J1I1033XUl40<RVIP@0bZQY1034
XF440;bIF@@0_YQG1@35Weh40<ZTH`@0cZQW1036X5l40<6KFP@0`YeI103<Yf<40<jYH`@0aj9L1@33
WEH40<JPF@@0aImF1031Ve840<2JC`@0_iU>1033WU0=0<FPDP@0a9iC1036X5D40<JPE`@0aImF1036
X5L80<RRF@D0cZQO1039XeX40<>ME0@0aj5H1036X5L40<JPE@@0aImD2`3oool000X0oooo102fTTH4
0;RDB0@0^9Q=102eUDX40;>FBP@0]YU=1@2lW4l40;bKCP@0`J1?102lVDP40;NB@@@0]Y50102eSch4
0;fGAP@0_YY61@2mVDD40;nKA`@0^YI2202hTSd40;VC?P@0^Y@o1033WDP40<6KAPD0_YY6102oVdL4
0;nLBPP0`9e;1032Wdd40<6MB@T0`Ia;102oVTX40;jIB`@0_YQ=1032W5440<>ME0P0aIeE1030VTl5
0;fGC0@0_IQ:1030Vdd40<>NCP@0a9m?1039YU@40;^HA`@0_9Q:102nVU050<>MEP@0aYmJ1039X5h4
0<fUH0@0bjEN1032W5<40;RDB0@0^IE9102hUT`50;nME@@0_YiE1032XE`40<JUHP@0aZAT1032Wel4
0<>MGP@0`YaM1@34W5h40<NPG`@0c:ET103?ZVH40<NRGP@0aJ1J1037XU`40<FPFP@0`iiH1@35WUT4
0<JOFP@0aImH1033WEH40<BNE@@0`YaC2035WeH40<FOE0D0b:9G1035We@40<JPE@@0aZ1G1037XEP4
0<JPE`@0aj5H1032W5<50<RRF@@0cJML103;YEX40<JPE@@0a9iC2036We8;0?ooo`002P3oool40;JB
AP@0^9A8102hV4d40;FEBP@0/iI:102fVDd50;bLC`@0_9]>1031X4l40;bIB0@0]i91102fTD040;F?
?P@0_IM6102nVTH50;fIA@@0_i]7102jUT880;RB?@@0^I<n102jU3l40<>MB0@0`I]61@2nVTH40;nK
A`@0_ia:2030WD/40<:OC@@0`Ie92@31W4/40;nJBP@0_YU;102nV4d40<:LD@@0`ieD2035WED40<2J
C`D0_IM<102mV4X40<2KC@@0`ii>1034Wdl40<VVE0@0^iQ7102lV4X40;jJD0D0`ieF1036WeX40<VP
GP@0cJEP103;YEh40<:LD`@0^9A8102iUDT40;RFC0D0_ieE102nWUD40<:QG0@0aZER1036Y6@40<:O
G`@0`ieN1032W5d50<BLGP@0aj1O103<YF@40<nZIP@0aj9N1035X5X40<NRG0@0aJ1J1033WUP50<FN
F@@0aYmJ1035WeP40<>MEP@0a9iE1032W5<80<FOEP@0aImD1@38XUL40<FOE0@0aZ1E1036X5L40<NQ
F0@0aZ1G1037XEP40<:LD`D0b:9I103=Ye`40<^UFP@0aZ1E1034WU<80<JODP/0oooo000:0?ooo`@0
]Y96102hU4P40;RHC@@0]IE:102cUTX40;JIC@D0_9a?102lVdh40<6PC`@0_9U8102gTT440;JA@0@0
]Hln102mUdH40;jJAPD0_IU5102oVdL40;ZF@PP0^98m102iTch40;ZD?`@0`ie81031VdH50;jJAP@0
_i]7102oW4X80<2MB`@0`Ym=1031WDT90<6LB`@0_iY:102nVD/40;jHC@@0`YaA1033WE@80<FME@@0
`9Y?1@2mUd`40;fHBP@0`9]=1033WTh40<BOC`@0bJID102kV4L40;bHBP@0_YY@1@33WEH40<JOFP@0
bJ1N103=YF040<^UGP@0`YaC102hU4P40;VEB@@0^9I<1@2oWED40;jNE@@0`Z5L1036YF840<JTI0@0
`YmO1033WEh40<:LG@D0a9aN1037X5l40<bUI0@0cjYV1037XUh40<FPFP@0aj9L1035X5X40<>NF0D0
aIiI1036WeX40<FOF0@0`ieF1034WUD40<:LD`P0aImF1035We@50<RRE`@0aImD1036X5D40<JPE`@0
aj5H1036X5L40<NQF0@0`YaC1@38XUT40<fWG0@0bjEJ1036X5D40<BND`P0aYmB2`3oool000X0oooo
102fTTH40;RDB0@0^9Q=102eUDX40;>FBP@0]YU=1@2lW4l40;bKCP@0`J1?102lVDP40;NB@@@0]Y50
102eSch40;fGAP@0_YY61@2mVDD40;nKA`@0^YI2202hTSd40;VC?P@0^Y@o1033WDP40<6KAPD0_YY6
102oVdL40;nLBPP0`9e;1032Wdd40<6MB@T0`Ia;102oVTX40;jIB`@0_YQ=1032W5440<>ME0P0aIeE
1030VTl50;fGC0@0_IQ:1030Vdd40<>NCP@0a9m?1039YU@40;^HA`@0_9Q:102nVU050<>MEP@0aYmJ
1039X5h40<fUH0@0bjEN1032W5<40;RDB0@0^IE9102hUT`50;nME@@0_YiE1032XE`40<JUHP@0aZAT
1032Wel40<>MGP@0`YaM1@34W5h40<NPG`@0c:ET103?ZVH40<NRGP@0aJ1J1037XU`40<FPFP@0`iiH
1@35WUT40<JOFP@0aImH1033WEH40<BNE@@0`YaC2035WeH40<FOE0D0b:9G1035We@40<JPE@@0aZ1G
1037XEP40<JPE`@0aj5H1032W5<50<RRF@@0cJML103;YEX40<JPE@@0a9iC2036We8;0?ooo`002P3o
ool40;ZEA`@0^YA9102hUdX40;NEB`@0^IU>102oWe@50;ZIC0@0_9Q<102kV4L40;^FAP@0^Y=4102i
TT<40;fDA@@0`9M8102nVDP50;fHA`P0_IU5102kUD040;VC?P@0]i8j102hTc/40;ZE?@@0_9Lo1@2n
V4<40<2JA@@0`9a81032WTX40<JSD@@0bjQF1031WDT40<2LB0D0`Ye<2032WDd40<2KC@@0`I]@1032
W5480<FOE0@0aJ1B1@2oVT`40;jGB0@0`IY;1031VdX40<>MC0@0`Ye<1032WDd40<2IC0@0`9Q@1@36
VeH40<FJEP@0bimN103AYF@80<^PF`@0`I]@102gTDH40;fIC`D0`IaE1030WUH40;nLF0@0`j1L1036
Xf440<NQH0@0aZ1O1033Ved50;fEE`@0a9]I103;XV040<jXH@@0bZAM1037XEP40<2JD@@0`ieF1030
VU<50<BMF0P0aYmJ1038XE`40<ZSGPP0aj1K1036WeX40<VRG@D0cJIQ1037X5/40<6JE@P0aImH1039
XeX40<NQF0T0aZ1G1034WE040;jGBP@0aii?103@YeP40<VPD@@0aii?2`3oool000X0oooo102jUDL4
0;ZDB@@0^9M:102gUD/40;VICP@0_imD1@2jVD`40;bHC0@0^iQ7102kUTH40;ZCA0@0^I93102mU4D4
0<2GB0@0_YU81@2mV4L80;fIA@@0^iE0102iTch40;NB>P@0^9<k102jUCd40;bG?`D0_YQ31030VTD4
0<2LB0@0`Yi:1036Xe440<^XEP@0`Ie91030W4P50<:MC0P0`Ye=1030Vdd40<6KD0@0`YaA2035We@4
0<FPDPD0_iY<102nUdP40<6JB`@0`I]:1033WD`40<:MC0@0`Ye=1030VD`40<2HD0D0aY]F1035VUH4
0<^OGP@0dJET203;X5/40<6KD0@0]i56102mVDl50<6LE@@0`9iF102oW5P40<>PG0@0aZ=Q1037XF04
0<JPG`@0`i]M1@2mUEL40<BKF@@0bj9P103>Z6440<ZTG@@0aj5H1030VU440<>MEP@0`9YC1@34WEP8
0<JOFP@0b:5L103:Xeh80<NPF`@0aYmJ1039XUd50<fVH@@0aj1K1031VUD80<FOF0@0bJ=J1037XEP9
0<JPE`@0a9e@102nUdX40<NNC`@0d:MH1039X5440<NNC`/0oooo000:0?ooo`@0^YE7102jU4T40;RG
BP@0]iE;102iVDh40;nOE0D0^YU<102lV4`40;^HA`@0^iI6102jTd@40;VB@`@0_IA51030UdP40;jI
B0D0_IQ7202mVDD40;^E@0@0^I<n102gTSX40;RC>`@0^YDm102lUcl50;jH@`@0`9Y51030W4P40<:N
BP@0aZ=A103;Z5H40<6MB@@0`9a81@32WD`80<:MC@@0`9]=1031Ve040<:LD@P0aImD1035X5850;nJ
C0@0_YM81031VT/40<6KBP@0`ie<1032WD`40<:MC@@0`9U<1030V5050<JKEP@0aIYF103;Weh40=6U
I0P0bj1K1031Ve040;NAAP@0_IU?1@31W5D40<2NEP@0_iaH1033X5`40<JSH@@0aj5P1036X5l40<>K
G@D0_IEG1034VeT40<^RH0@0cZQQ103:Y5d40<NQF0@0`9YA1033WEH40<2JD`D0a9eH2036WeX40<RQ
G0@0bZ=N2037X5/40<JOFP@0bJ9M1@3=YV440<NPF`@0`IYE2035WeP40<VSFP@0aj5H2@36X5L40<BM
D0@0_YM:1037WTl40=2WF0@0bJ1A1037WTl;0?ooo`002P3oool40;ZEA`@0^YA9102hUdX40;NEB`@0
^IU>102oWe@50;ZIC0@0_9Q<102kV4L40;^FAP@0^Y=4102iTT<40;fDA@@0`9M8102nVDP50;fHA`P0
_IU5102kUD040;VC?P@0]i8j102hTc/40;ZE?@@0_9Lo1@2nV4<40<2JA@@0`9a81032WTX40<JSD@@0
bjQF1031WDT40<2LB0D0`Ye<2032WDd40<2KC@@0`I]@1032W5480<FOE0@0aJ1B1@2oVT`40;jGB0@0
`IY;1031VdX40<>MC0@0`Ye<1032WDd40<2IC0@0`9Q@1@36VeH40<FJEP@0bimN103AYF@80<^PF`@0
`I]@102gTDH40;fIC`D0`IaE1030WUH40;nLF0@0`j1L1036Xf440<NQH0@0aZ1O1033Ved50;fEE`@0
a9]I103;XV040<jXH@@0bZAM1037XEP40<2JD@@0`ieF1030VU<50<BMF0P0aYmJ1038XE`40<ZSGPP0
aj1K1036WeX40<VRG@D0cJIQ1037X5/40<6JE@P0aImH1039XeX40<NQF0T0aZ1G1034WE040;jGBP@0
aii?103@YeP40<VPD@@0aii?2`3oool000X0oooo102gTdD40;ZFBP@0^9I<102iUdd40;JFB`@0^IU>
1@2mW4l40;jJCP@0`imA102lUdT40;ZCA0P0_9E6102oV4T40;fHB0D0_YU9202mV4L80;^E@P@0]Y0k
102eScX40;6<=0@0^9<k2@2mV4040;^G@@@0_9Q2102oVdD40<:NB0@0`Ie71030W4H50<FQC@@0`ii=
1032Wdd40<2MC0@0`9a>1031WDl40;nKC@@0aJ5C103=Z5X50<BOD@P0_iU8102nV4L40<>LC@@0aJ1@
1030VTl40;nHC@@0aIeG1@38WEP40<VNFP@0bIeL103;Weh40<bQG0@0b9eH1038X5P40<NOE`@0`ieD
1@32W5<40<6LE@@0`9]E102nW5D40<>PG0@0bJ=R1038XF040<FMG`D0`IQJ1035W5X40<RPF`@0bJ5K
1038X5P40<BND`@0`YaA102oVE040<6KE0D0`ieF1036WeX40<JQF`@0bJAN103=YV<40<ZSHP@0bJ9Q
1038X6840<^SI@D0cjMY103@ZFH40<RQGP@0b:9K1037XEX40<FOEP@0aZ1G1035XED50<FOE0@0_iQ;
102nU4P40<2GB0@0`iY;1039X5040<ROC`/0oooo000:0?ooo`@0]i=5102jUTX40;RFC0@0^IM=102f
UT/40;VICPD0_Ia?102nVTh40<>OD@@0_9M9102jTd@80;bEAP@0_iQ9102mV4P50;jIB@P0_IQ7202k
UD840;J@>`@0]Hlj102aS3@40;RC>`T0_IQ0102kUd440;bH@P@0_i]51032WTP40<6MA`@0`9a61@35
XDd40<>NC@@0`Ym=1030WD`40<2LCP@0`Ie?102oVdd40<FQD`@0cJQJ1@34We480;nIB0@0_YQ71033
W4d40<FPD0@0`9Y?102oV4d40<FME`D0b9eH1039WUX40<VMG0@0bimN103<XE`40<RMF0@0b:1H1037
WeL40<>ME0D0`YaC1031W5D40<2KE@@0_YaE1033X5`40<VSHP@0b:5P1035WEl50<6HFP@0aIaJ1038
X5/40<VQF`@0b:1H1034WU<40<:LD@@0_iU@1031Ve@50<>MEP@0aYmJ1036XE/40<VTGP@0cJIS103:
Xf840<VRH@@0b:1R103;XfD50<nWJ@@0d:UV1038XEh40<RRF`@0aj5J1035WeH40<JPE`@0aJ5E1@35
We@40;nHB`@0_YA81030UdP40<>JB`@0bJ1@1038Wdl;0?ooo`002P3oool40;NCA@@0^YI:102hUT`4
0;VGC@@0]YI;102iVDh50;fLC`@0_YY>1033We440;bGB@@0^Y=4202lUDH40;nHB@@0_IQ81@2nVDT8
0;fHA`P0^iE2102fT3/40;F?>P@0/H`d102hTc/90;fH@0@0^iM1102lV4840;nKA@@0`Yi81031WDL4
0<2LAPD0aJ5=1033WTd40<:OC@@0`9e<1030W4h40<6MC`@0_i]=1035XE<40<fXFPD0a9mA202oVDP4
0;jHA`@0`ia=1035X5040<2JC`@0_iQ=1035WEL50<RMF0@0bIiJ1039WE`40<^OGP@0c:5L1038WEP4
0<RPF0@0aimG1033WE@50<:LD`@0`IaE1030VeD40;jLE@@0`j1L1039Xf840<RQH0@0aIeO1@31V5X4
0<FLFP@0b:1K1039XE/40<RPF0@0a9iC1032W5440;nID0@0`I]D1@33WEH40<JOFP@0aZ5K1039Y5h4
0<fVH`@0bZ=R1039XV440<RPHP@0bj=U1@3?YfT40=2YIP@0b:5N1038XU/40<NQFP@0aImF1036X5L4
0<FQE@D0aImD102oV4/40;jDB0@0`9M81033VT/40<VPD0@0b9m?2`3oool000X0oooo102gTdD40;ZF
BP@0^9I<102iUdd40;JFB`@0^IU>1@2mW4l40;jJCP@0`imA102lUdT40;ZCA0P0_9E6102oV4T40;fH
B0D0_YU9202mV4L80;^E@P@0]Y0k102eScX40;6<=0@0^9<k2@2mV4040;^G@@@0_9Q2102oVdD40<:N
B0@0`Ie71030W4H50<FQC@@0`ii=1032Wdd40<2MC0@0`9a>1031WDl40;nKC@@0aJ5C103=Z5X50<BO
D@P0_iU8102nV4L40<>LC@@0aJ1@1030VTl40;nHC@@0aIeG1@38WEP40<VNFP@0bIeL103;Weh40<bQ
G0@0b9eH1038X5P40<NOE`@0`ieD1@32W5<40<6LE@@0`9]E102nW5D40<>PG0@0bJ=R1038XF040<FM
G`D0`IQJ1035W5X40<RPF`@0bJ5K1038X5P40<BND`@0`YaA102oVE040<6KE0D0`ieF1036WeX40<JQ
F`@0bJAN103=YV<40<ZSHP@0bJ9Q1038X6840<^SI@D0cjMY103@ZFH40<RQGP@0b:9K1037XEX40<FO
EP@0aZ1G1035XED50<FOE0@0_iQ;102nU4P40<2GB0@0`iY;1039X5040<ROC`/0oooo000:0?ooo`@0
]iI9102mW4l40;fMDP@0`:1E102gUd`40;>CB0D0^iY=102nWE040<:ND0@0_i]=202oVT`40<2LCP@0
_9Q:102oVT`50<2KC@@0_iY:102nVDT80;fIA@@0^iM1102iUCl40;^F?P@0_IQ01@2nVD040;fH?`@0
_9Ln102kUSd40;fH?`@0`9]31032WTP40<>OB`D0bZIB1032WD`40;nLBP@0`9e<202nWDh40;^GB@@0
`Yi@103;YeT50<NRE0@0`Ia<102oV4T40;fFA`@0`9U<1036X5L40<VSG0@0`Y]F1035WUT50<RPF`@0
bJ5L203:XEl40<RPF`@0bZ9M2039Xe`40<>NE`D0a9mH102oVU<40;nJE0@0_iiG102oW5X40<VVI0@0
d:Y[1038X6<50<2HF`@0aiiN1039X5h40<VSG0@0aZ1G1034X5840<:NDP@0_YY>102oVU<50<:MEP@0
`iiH1034We/40<JQG@@0bJ=R1038XV480<ZRI0@0bj=U1@3>YVP40<^TH@@0bZ=P103:Y5d40<bVG`@0
a:1F1036XUP40<JREPD0aj5F1037X5D40<NMD`@0`Y]>102oV4/40<>MC0@0aIm>2`3oool000X0oooo
102gUTT40;fLC`@0_IeB1030X5D40;NGC0@0/i=81@2kVTd40;jMD0@0`Yi@102oVdd80;nJC0@0`9a>
102lV4X40;nJC0D0`9]=102oVTX40;jIB@P0_IU5102kUd440;VE?`@0^iHn102mV4050;jI@0@0_IPo
102lUch40;^F?@@0_IPo1030Vd<40<:NB0@0`im;1@3:YU840<:MC0@0_ia:1030WD`80;jMCP@0^iM9
1032WU040<^WF@D0aj9D1031W4`40;nHB@@0_II71030VD`40<JPE`@0bJ=L1032VeH40<FNF@D0b:1K
1039XE`80<ZQG`@0b:1K103:XUd80<VSG0@0`iiG1@34WeP40;nJD`@0_iYD102oWUL40;nLFP@0bJIT
103@ZV/40<RPH`D0`9QK1037WUh40<VPGP@0bJ=L1036X5L40<BPDP@0`YiB102nVTh40;nJD`D0`YeF
1033WUP40<BOF`@0aZ5M1039Xf840<RRH@P0bZ9T103;XfD50<jVJ0@0bjAQ103:Xf040<ZTG@@0c:IO
1034X5H40<JRF0@0aZ9F1@37XEH40<NPE@@0aieC1032Vdh40;nHB`@0`ie<1035Wdh;0?ooo`002P3o
ool40;NFB@@0_Ia?102mWE840<2PE@@0]iM<102cTdP50;^JC@@0_Ye@1032WU040;nKC@P0_iY<1030
W4h40;bHBP@0_iY<1@30Vdd40;nJBP@0_YU9202mVDD40;^G@@@0^IDo102kUSh40;fH@0D0_YU0102m
V3l40;bG?P@0^iHm102mV3l40<2K@`@0`Yi81033Wd/50<ZVDP@0`Ye<102oW4X40<2MC0P0_Ye>102k
UdT40<:ND0@0bjMI1@37XU@40<6LC0@0_iQ9102mUTL40<2IC0@0aZ1G1039Xe`40<:KEP@0aIiI1@38
X5/40<VQG0P0bZ5O1038X5/40<ZRG@P0bJ=L1033WUL50<BOF0@0_iYC102oVU@40;nNE`@0_iaJ1039
YV@40=2ZJ`@0b:1S1@30V5/40<NNGP@0bJ1N1039Xe`40<JPE`@0a:1B1032WU840;jJCP@0_iYC1@32
WEH40<>NF0@0a9mK1036XEd40<VSHP@0b:9Q203:XV@40<^SI@D0cZIX103;Y6440<ZSH0@0bZAM103<
YUl40<BPEP@0aZ9H1036XUH50<NQEP@0aj1E1037WE<40<:KCP@0_iQ;1033WD`40<FOCP/0oooo000:
0?ooo`@0]iI9102mW4l40;fMDP@0`:1E102gUd`40;>CB0D0^iY=102nWE040<:ND0@0_i]=202oVT`4
0<2LCP@0_9Q:102oVT`50<2KC@@0_iY:102nVDT80;fIA@@0^iM1102iUCl40;^F?P@0_IQ01@2nVD04
0;fH?`@0_9Ln102kUSd40;fH?`@0`9]31032WTP40<>OB`D0bZIB1032WD`40;nLBP@0`9e<202nWDh4
0;^GB@@0`Yi@103;YeT50<NRE0@0`Ia<102oV4T40;fFA`@0`9U<1036X5L40<VSG0@0`Y]F1035WUT5
0<RPF`@0bJ5L203:XEl40<RPF`@0bZ9M2039Xe`40<>NE`D0a9mH102oVU<40;nJE0@0_iiG102oW5X4
0<VVI0@0d:Y[1038X6<50<2HF`@0aiiN1039X5h40<VSG0@0aZ1G1034X5840<:NDP@0_YY>102oVU<5
0<:MEP@0`iiH1034We/40<JQG@@0bJ=R1038XV480<ZRI0@0bj=U1@3>YVP40<^TH@@0bZ=P103:Y5d4
0<bVG`@0a:1F1036XUP40<JREPD0aj5F1037X5D40<NMD`@0`Y]>102oV4/40<>MC0@0aIm>2`3oool0
00X0oooo102bTTD40;RHC@@0]YU=102mWeH40;JHC`@0]9I=1@2eUDX40;ZJC`@0`j9E1032XE@40;jM
CP@0^YU:102kVT/40;fIB`@0_i]=3@2nVD/40<2KBP@0_IQ7102nVT@40<2LAP@0`9a4102lV4090;^F
?@@0^YDj102gTSL40;VB=`@0_YHn1034WTT40<RRC`D0cjYI1033WTd40;jKBP@0`9e<102nWDh40;fL
C@@0^iY;1030We040<ZVF0D0b:AF1034We440;bGB@@0_II91032Ve040<FPFP@0`IaH102oVUH40<BO
F`D0cJQR103<Yf440<^TG`@0bJ9M1038Xel40<JQG@@0b:=M1036XE/40<JQFPD0`iiG102nW5840;^I
D@@0`J1K1032X6040<JSH`@0bjEW103>Yf`50<VQI0@0aYiP1037X5d40<FPF@@0aZ9H1034X5840<6M
D@@0`9mB1030WUH50<6OE`@0`j5J2036XEd40<RRH@@0aj5P203:XV@40<VRH@D0bZ=R1039XUd40<RQ
G0@0bZAK1037XEP80<BPE0@0b:AH1@38XUL40<JPE`@0aIeE1033W5440<FND`@0`Ye=1033WTh;0?oo
o`002P3oool40;:BA@@0^9Q=102fVDd40;fOEP@0]YQ?102dUTd50;FEBP@0^YY?1033XUD40<:QE0@0
_Ye>102jVDX40;^JB`@0_IU;102oVdd=0;jIB`@0`9]:102mV4L40;jJA0@0`9a61030W4@40;bH@0T0
^iHm102jUCX40;NB=`@0^I8g102nUSh40<BNB@@0b:9?1@3?ZUT40<>NC@@0_Y]:1030WD`40;jMCP@0
_Ia=102kVT/40<2OD0@0bZIH1@38Y5H40<BOD@@0_9M9102mUTT40<:KD0@0aJ1J1031W5P40;nJEP@0
a9mK1@3=Z6840<bWH@@0bjAO1039XUd40<RSG`@0aZ5M1038Xed40<JQF`@0aZ5J1@33WUL40;jLDP@0
^iUA1031X5/40<:PH0@0aZ=S103;YFL40<jWK0D0bJ5T1036WV040<NPG@@0aJ1I1036XUP40<BPDP@0
`IeA1030We840<2NEPD0`ImG1033XEX80<JQG@@0b:9Q1037XF080<ZRI0@0bJ9Q1@3:Xf840<VRG@@0
b:5L103:Y5/40<NQF0P0a:1D1038Y5P50<RRE`@0aZ1G1035WED40<>LD@@0aIiC1032WDd40<>NCP/0
oooo000:0?ooo`@0/Y95102hV4d40;JIC@@0_ImF102fV4l40;BFC@D0]IE:102jVTl40<>RE@@0`Z5D
102nWDh40;ZIBP@0^iY;102mVD/40;nKC@d0_YU;1030VdX40;fHA`@0_YY41030W4H40<2LA0@0_9Q0
2@2kUSd40;ZE>P@0]i8g102iTSL40;jF?P@0a9i91038XTl50<nZF@@0`ii=102nVdX40<2MC0@0_Ye>
102mW4d40;^JB`@0`9m@103:YUP50<RTEP@0a9mA102lUdT40;fFB@@0`Y]@1035X5X40<6LF0@0_iYF
1034We/50<fXHP@0c:MQ103;Y5l40<VRG@@0b:=O1036XEd40<RSG@@0aZ5K1036XEX50<>NE`@0_YaB
102kVE440<6PF`@0`Z1P1036Xf<40<^UI`@0cZM/1@39XF@40<JNH0@0aj1M1035X5T40<JRF0@0a:1B
1031WE440<2ODP@0`9iF1@31WeL40<>QFPP0aZ5M1038XV440<NQH0P0bZ9T1039XV450<ZSHP@0bJ9M
1038XE`40<ZTF`@0aj5H2034X5@40<RTF0D0b:9G1036X5L40<FME@@0`iaA1035WU<40<:MC@@0`ii>
2`3oool000X0oooo102bTTD40;RHC@@0]YU=102mWeH40;JHC`@0]9I=1@2eUDX40;ZJC`@0`j9E1032
XE@40;jMCP@0^YU:102kVT/40;fIB`@0_i]=3@2nVD/40<2KBP@0_IQ7102nVT@40<2LAP@0`9a4102l
V4090;^F?@@0^YDj102gTSL40;VB=`@0_YHn1034WTT40<RRC`D0cjYI1033WTd40;jKBP@0`9e<102n
WDh40;fLC@@0^iY;1030We040<ZVF0D0b:AF1034We440;bGB@@0_II91032Ve040<FPFP@0`IaH102o
VUH40<BOF`D0cJQR103<Yf440<^TG`@0bJ9M1038Xel40<JQG@@0b:=M1036XE/40<JQFPD0`iiG102n
W5840;^ID@@0`J1K1032X6040<JSH`@0bjEW103>Yf`50<VQI0@0aYiP1037X5d40<FPF@@0aZ9H1034
X5840<6MD@@0`9mB1030WUH50<6OE`@0`j5J2036XEd40<RRH@@0aj5P203:XV@40<VRH@D0bZ=R1039
XUd40<RQG0@0bZAK1037XEP80<BPE0@0b:AH1@38XUL40<JPE`@0aIeE1033W5440<FND`@0`Ye=1033
WTh;0?ooo`002P3oool40;BCA0@0/I11102gUTT40<:QE0P0]iM:1@2fUTT40;NGBP@0^iY;102nWDh4
0<2LCP@0_IU;202mV4X40;jIB`D0_9M9202lUDH40;nIB0@0`9Y9102oVDH40<6KB0P0_iY21@2mV404
0;VD?0@0^Y8j102eSCD40;R>>0@0^Y8k1034WdL40<JRBPD0`Yi81031WDT40;jJAPP0_YU9102nVD/4
0;fGC0@0`I]@1038Y5P50=NcI`@0`imA102jUTP40;jJC0@0`Ie?1033WE840<BNE@@0`iiG1033WUP5
0<:OF`@0a:5M2036Xel40<FPG0@0bJ9O103=YV<40<nVI0@0b:1K1@30V5840<:JDP@0_9I=102kUU04
0<:OF`@0`YmM1039YV@40<VVIPD0`YmO1033X5`40<:PF@@0`ImG1035XeT40<>OD@@0`YiB1032W544
0<BNE`D0aj1K103:Xf040<JOFP@0`iaG1039X5h40<NNG0@0bJ1P103@YfL40<ZQG`D0b9mM2039XE`4
0<VQF`@0aimI1034WUD40<FOEP@0`iiG2@36X5T40<NOF@@0a9eB1032Ve040<6LC0@0a9m?2`3oool0
00X0oooo102dTd@40;6@@@@0]iI91032XE@80;NGBPD0]YI9102gUdX40;^JB`@0_Ye>1030W4h40;fI
B`P0_IQ:102nVD/50;bGB@P0_9E6102oVDP40<2JB@@0_iU61031VdP80;nJ@PD0_IQ0102iU3`40;ZB
>P@0]Hde102hSSP40;ZB>`@0a9m71036XTX50<:NB0@0`Ie9102nVTH80;jIB@@0_YU;102mUd`40<6K
D0@0b:AH1@3G/fL40<>OD@@0^YI8102nVT`40<6MC`@0`ieB1034WUD40<>NE`@0`iiH1@32We/40<BQ
G@P0aZ=O1035X5`40<VRG`@0cJIS103?YV@40<RPF`D0`9QB1032VU840;bFC@@0^iI@1032We/40<:O
G@@0bJIT1039YVH50<:OG`@0`j1L1032X5T40<6OE`@0aJ=I1033We440<:NDP@0`YaA1034WUL50<NP
F`@0bZ=P1036WeX40<>LE`@0bJ1N1037WU`40<VPH0@0d:MW103:XEl50<ROG@P0bJ5L1039XE/40<NO
F@@0a9iE1035WeH40<>NE`T0aZ1I1037WeT40<BMDP@0`Y]@1031W4`40<BOC`/0oooo000:0?ooo`@0
]9=4102aT4440;NFB@@0`Z5D202gUdX50;JFB@@0]iM:102kVT/40;jMCP@0`9a>102mVD/80;fHBP@0
_YU;1@2lUdT80;bEAP@0_iU81030VTT40;nIAP@0`I]8202oVT850;fH@0@0^I@l102jTSX40;F==@@0
^8hh102jTS/40<BOA`@0aZ9:1@32WTP40<6MB@@0_YY6202nVDT40;jIB`@0_IM<1031Ve040<RTF0D0
ek=W1033We440;ZFB0@0_YY<1031WDl40<>MDP@0a9iE1033WUL40<>NF0D0`YmK1034XEd80<JSG`@0
aJ1L1039XUl40<fVH`@0cjIT1038X5/50<2HDP@0`YYB102lUTd40;^FD0@0`YmK1032Wed40<VVI0@0
bJIV1@32Wel40<>PG0@0`Z1I1031WeL40<FSF@@0`imA1032WU840<:LD@@0a9iG1@37X5/40<ZSH0@0
aYmJ1033W5L40<VPGP@0aiiL1039X6040=2WI`@0bZ5O1@38Wed80<VQG0@0bJ5K1037WeT40<BNE@@0
aImF1033WUL90<JPF@@0aimI1034WE840<:KD0@0`Ia<1034Wdl;0?ooo`002P3oool40;BCA0@0/I11
102gUTT40<:QE0P0]iM:1@2fUTT40;NGBP@0^iY;102nWDh40<2LCP@0_IU;202mV4X40;jIB`D0_9M9
202lUDH40;nIB0@0`9Y9102oVDH40<6KB0P0_iY21@2mV4040;VD?0@0^Y8j102eSCD40;R>>0@0^Y8k
1034WdL40<JRBPD0`Yi81031WDT40;jJAPP0_YU9102nVD/40;fGC0@0`I]@1038Y5P50=NcI`@0`imA
102jUTP40;jJC0@0`Ie?1033WE840<BNE@@0`iiG1033WUP50<:OF`@0a:5M2036Xel40<FPG0@0bJ9O
103=YV<40<nVI0@0b:1K1@30V5840<:JDP@0_9I=102kUU040<:OF`@0`YmM1039YV@40<VVIPD0`YmO
1033X5`40<:PF@@0`ImG1035XeT40<>OD@@0`YiB1032W5440<BNE`D0aj1K103:Xf040<JOFP@0`iaG
1039X5h40<NNG0@0bJ1P103@YfL40<ZQG`D0b9mM2039XE`40<VQF`@0aimI1034WUD40<FOEP@0`iiG
2@36X5T40<NOF@@0a9eB1032Ve040<6LC0@0a9m?2`3oool000X0oooo102/Rc`40;>B@`@0]iI7102f
UDH80;VHB@D0^9M8102iV4T40;bHBP@0_IU;202mVTT80;nJBP@0_YQ51@2lUT<40;RB?`@0^I=0102n
UD<40<2GA@@0`YU71033VTP40<2JA`@0_YQ51@2mUd840;bF@@@0^I4l102kTch40;bD?@@0`9Q31031
VdH40<>MBPD0`I]81030VTL40;fHA`@0_IQ81030Vd/40<6LCP@0`9Y?1034WU<40<6MD`D0aJ5G1030
W5040;nKC`@0`9e<102lVDP40<6LCP@0a9iC1034X5H40<BOF@D0`IiJ1032Wed40<>PGP@0a:5O1036
XEd40<NRGPP0cJIS1039XUd50<BNE`@0`YaC102lUTd40:n=A@@0^iQD1033X5`40<NTI0@0bJIV1@34
X6840<>PGP@0a:5M1036XE/40<>NE`@0`9a@1030W5840<>ME0@0aYmJ1@37X5/40<VRG`@0aj9N1035
X5`<0<JOG0@0aj1M2@39XUd40<RRF`@0bZAM103?ZF040<VSFP@0aj5J1036X5T40<NRG0D0a9mI2036
X5L40<BMD0@0`Y]>1031W4`40<:MC@/0oooo000:0?ooo`@0[8/l102cTT<40;NFA`@0]YE6202iV4T5
0;RGB0@0^IQ9102lV4X40;fIB`P0_IY9202oVTX40;jHA@D0_9I3102hTSl40;VC@0@0_YE31030UdD4
0<:IA`@0`iY81030VTL40;jHA@D0_IM2102lUT440;VA?0@0^i<n102lU3d40<2H@`@0`I]61033WDX5
0<6KB0@0`9Y7102mV4L40;fHB0@0`9];1031W4h40<2JC`@0a9iC1031WE<50<FQE`@0`9a@102oVdl4
0<2MC0@0_9U81031W4h40<BND`@0a:1F1034WeT50<6NFP@0`YmM1033X5h40<BQG`@0aZ5M1037XUh8
0<fVH`@0bJ9M1@34WUL40<:LD`@0_9I=102_SDD40;^HE0@0`j1L1037Y6@40<VVIPD0a:1R1033X5h4
0<BQG@@0aZ5K1033WUL40<2LD0@0`9aB1033WE@40<JOFPD0aj1K1039XUl40<NRGP@0aJ1L3036We`4
0<NPG@T0bJ9M1038XU/40<ZTG@@0cjUP1039XeX40<NQFP@0aZ1I1037XU`50<BOF@P0aZ1G1034WE04
0<:KCP@0`Ia<1032WDd;0?ooo`002P3oool40:b;?0@0/i93102gUTL40;JEAPP0^IQ91@2hUdP40;VH
B@@0_9Q:102mVD/80;fJB@P0_iY:102nV4D50;bF@`@0^98o102iTd040;jE@`@0`9M51032VDL40<>J
B0@0`9Y7102nV4D50;fG@P@0_9I1102iTC`40;^C?P@0_9@m1030V4<40<6KAP@0`ie:1@31VdP40<2J
A`@0_IQ7102mV4P40<2KB`@0`Ia>1030VTl40<BND`@0`IeC1@35XEL40<2LD0@0_i]?1030WD`40;bI
B0@0`Ia>1034WU<40<BPEP@0a9mI1@31WUX40<:OG@@0`j1N1034XEl40<JQG@@0aj9N203=YV<40<VR
G@D0a9iG1032W5<40;bFC@@0[he5102kV5@40<>PG0@0ajAT1039YVH50<BPHP@0`j1N1034XEd40<JQ
F`@0`iiG1030W5040<2LDP@0`ieD1036WeX50<NPF`@0bJ9O1037XUh40<FPG0`0aYmL1037X5d90<VR
G@@0b:9K103:Y5d40<nYH0@0bJ=J1037XEX40<JPF@@0aj9L1@34WeT80<JPE`@0a9e@1032Vdh40<6L
C0@0`Ye=2`3oool000X0oooo102/Rc`40;>B@`@0]iI7102fUDH80;VHB@D0^9M8102iV4T40;bHBP@0
_IU;202mVTT80;nJBP@0_YQ51@2lUT<40;RB?`@0^I=0102nUD<40<2GA@@0`YU71033VTP40<2JA`@0
_YQ51@2mUd840;bF@@@0^I4l102kTch40;bD?@@0`9Q31031VdH40<>MBPD0`I]81030VTL40;fHA`@0
_IQ81030Vd/40<6LCP@0`9Y?1034WU<40<6MD`D0aJ5G1030W5040;nKC`@0`9e<102lVDP40<6LCP@0
a9iC1034X5H40<BOF@D0`IiJ1032Wed40<>PGP@0a:5O1036XEd40<NRGPP0cJIS1039XUd50<BNE`@0
`YaC102lUTd40:n=A@@0^iQD1033X5`40<NTI0@0bJIV1@34X6840<>PGP@0a:5M1036XE/40<>NE`@0
`9a@1030W5840<>ME0@0aYmJ1@37X5/40<VRG`@0aj9N1035X5`<0<JOG0@0aj1M2@39XUd40<RRF`@0
bZAM103?ZF040<VSFP@0aj5J1036X5T40<NRG0D0a9mI2036X5L40<BMD0@0`Y]>1031W4`40<:MC@/0
oooo000:0?ooo`@0]YE4102eU4<40;ND@P@0^YM5102kV4H40;fJB0T0_9U8102mV4X40;bGB@@0_IQ8
102oVTX40<6MB@@0`ie:102mV4050;bD?@@0]hlg102hT3P40;bB?0@0_Y@n1031VD@40<BKB@@0`9Y7
102nV4L90;nJB@@0^YA1102lUT<40;fG@P@0_iU61031VdX40<FNC`D0aZ1?1032W4/40;nIB0@0_iQ9
102oVTX40;jHC@@0a9iC103:Y5/40<FPF@D0`IeC1031WE440;fIB`P0^YM5102nVDT40<:MC`@0`YiD
1034WeT50<2MF`@0`IiN1032Wed40<FRH0@0`iiJ1034We/40<jWI0@0cJIS103:Xeh50<RQG0@0`imE
102nVU040;:BB@@0/i9;1030WET40<RUI@@0bZMW1@35XF<40<FOH0@0aj5P1035X5`40<BOF@@0aImH
102nV5440;fGD0@0`IYE1@32VeH40<>LF@@0aJ1L1038Xel40<NRGP@0aJ1L1031WUX40<:OF`@0aZAM
1@34XU/40<JQFPP0b:=L1039Y5d40<jXH@@0c:IO1037X5/50<RQG0@0aimG1036WUH40<BMD0@0`IY=
2030VTT;0?ooo`002P3oool40;JEA0@0]IA3102gU4840;ZGA@@0^iQ6102mVTP90;bIB0@0_IQ:102l
UdT40;fHB0@0_iY:1031WDT40<>MBP@0_IQ01@2lU3d40;N?=`@0^90h102lTS`40;jD?P@0`IU41034
VdT40<2JA`@0_YQ72@2oVTT40;ZD@@@0_9I3102mUd840;nIAP@0`I]:1035WTl50<JPC`@0`Ya;102o
VDP40;nHB@@0_iY:102nV4d40<BND`@0bZAK1035X5T50<6MD`@0`IeA102mVD/80;ZGA@@0_YU91032
WDl40<:NE0@0a9mI1@30WE/40<6NGP@0`YmM1035XV040<>NFP@0a9mK103>Yf@40<fVH`@0bZ=N1@38
XE`40<>OE@@0_YY@102bTTT40;>BB`@0`9eI1038YFD40<ZWI`D0aJ5S1035Wf040<NQH0@0aJ1L1034
WeT40<FOF0@0_YQA102mUe040<6JE@D0`Y]F1033W5T40<FPG0@0b:=O1037XUh40<FPG0@0`IiJ1032
We/40<JTG@D0a:9K1036XEX80<RSG0@0bJAM103>Z6440<bVG`@0aj1K1@38XE`40<NOE`@0aYiF1034
WE040<6JC@P0`9Y92`3oool000X0oooo102fUD@40;FD@`@0]iA2102jUdD40;^HAP@0_IY82@2lVDP4
0;fHBP@0_9M9102mV4P40;nJBP@0`Ie91033WDX40;fH@0D0_9@m102gScL40;R@>0@0_98l102nU3h4
0<6IA0@0a9]91030VTL40;jHA`T0_iY9102jU4440;bF@`@0_IM2102oVDH40<6KBP@0aIi?1@36X4l4
0<:LB`@0_iU8102oV4T40;nJBP@0_YQ=1034WU<40<ZTF`@0aJ1I1@31WE<40<6MD@@0_IU;202jUdD4
0;jIB@@0`Ye?1032WU@40<BOF@D0`9eK1031WUh40<:OG@@0aJ9P1033WUX40<BOF`@0cZMT103=YV<4
0<ZSGPD0b:5L1033WeD40;jJD0@0/Y99102cTT/40<2MF@@0b:EU103:YfL50<FQH`@0aImP1037XF04
0<FPG0@0a9mI1035WeP40;jHD@@0_IM@1031VUD50<:KEP@0`iaI1035X5`40<RSG`@0aj9N1035X5`4
0<6NFP@0`YmK1036Y5d50<BRF`@0aZ5J2038Xe`40<VTG@@0cZQQ103<YUl40<NPF`D0b:5L1037WeL4
0<JNEP@0a9e@1031VTd80<2JB@/0oooo000:0?ooo`@0]YE4102eU4<40;ND@P@0^YM5102kV4H40;fJ
B0T0_9U8102mV4X40;bGB@@0_IQ8102oVTX40<6MB@@0`ie:102mV4050;bD?@@0]hlg102hT3P40;bB
?0@0_Y@n1031VD@40<BKB@@0`9Y7102nV4L90;nJB@@0^YA1102lUT<40;fG@P@0_iU61031VdX40<FN
C`D0aZ1?1032W4/40;nIB0@0_iQ9102oVTX40;jHC@@0a9iC103:Y5/40<FPF@D0`IeC1031WE440;fI
B`P0^YM5102nVDT40<:MC`@0`YiD1034WeT50<2MF`@0`IiN1032Wed40<FRH0@0`iiJ1034We/40<jW
I0@0cJIS103:Xeh50<RQG0@0`imE102nVU040;:BB@@0/i9;1030WET40<RUI@@0bZMW1@35XF<40<FO
H0@0aj5P1035X5`40<BOF@@0aImH102nV5440;fGD0@0`IYE1@32VeH40<>LF@@0aJ1L1038Xel40<NR
GP@0aJ1L1031WUX40<:OF`@0aZAM1@34XU/40<JQFPP0b:=L1039Y5d40<jXH@@0c:IO1037X5/50<RQ
G0@0aimG1036WUH40<BMD0@0`IY=2030VTT;0?ooo`002P3oool40;ZFB0@0^9E4102fTd440;RE@@@0
_9M61031W4`50<:MC@@0`Ia>102oVDh40;fGC0@0_9M7102nVDT40;nKA`@0`I]81032WDD50;nG@0@0
^Y4i102iT3P40;^B>0@0_9<k102mUCd40<2H@`@0_IM2102lUTD50<:MC0@0_iY:102mV4L40;bGAP@0
_IU3102oVdL40<2KB`@0`Ye?1@37XU840<>NCP@0`Ye=1031W4`40<2KC@@0_iU>1030VTl40<:LD`T0
`I]B1037XU@40<:MC`P0_IM6102kUTD40;bGA`@0^YI<102oVU@50<6NG0@0a:5Q1032Wel40<FRHP@0
`YmK1033X5`40<bWH`@0bjIR1037XU/50<JQFP@0`9iD102nW5840;FEBP@0]IE<102mVe<40<2MF@@0
b:EQ1@38YF<40<NQH0@0b:9Q1038XEh40<VRG`@0bjEN1033WEH80;fGD0D0`IYE1033W5L40<>NFP@0
aZ5M1037Y6040<:OF`@0`9eI1035XUh40<JTG@D0a:9K1035Xe`40<BRF`@0aj9L103:YEl40=VbK@@0
cZMR2@38X5/40<RPF0@0aj1E1037WE440<FLC@@0`iY81031V4P;0?ooo`002P3oool40;ZFB0@0^9E4
102fTd440;RE@@@0_9M61031W4`50<:MC@@0`Ia>102oVDh40;fGC0@0_9M7102nVDT40;nKA`@0`I]8
1032WDD50;nG@0@0^Y4i102iT3P40;^B>0@0_9<k102mUCd40<2H@`@0_IM2102lUTD50<:MC0@0_iY:
102mV4L40;bGAP@0_IU3102oVdL40<2KB`@0`Ye?1@37XU840<>NCP@0`Ye=1031W4`40<2KC@@0_iU>
1030VTl40<:LD`T0`I]B1037XU@40<:MC`P0_IM6102kUTD40;bGA`@0^YI<102oVU@50<6NG0@0a:5Q
1032Wel40<FRHP@0`YmK1033X5`40<bWH`@0bjIR1037XU/50<JQFP@0`9iD102nW5840;FEBP@0]IE<
102mVe<40<2MF@@0b:EQ1@38YF<40<NQH0@0b:9Q1038XEh40<VRG`@0bjEN1033WEH80;fGD0D0`IYE
1033W5L40<>NFP@0aZ5M1037Y6040<:OF`@0`9eI1035XUh40<JTG@D0a:9K1035Xe`40<BRF`@0aj9L
103:YEl40=VbK@@0cZMR2@38X5/40<RPF0@0aj1E1037WE440<FLC@@0`iY81031V4P;0?ooo`002P3o
ool40;ZFB0@0^9E4102fTd440;RE@@@0_9M61031W4`50<:MC@@0`Ia>102oVDh40;fGC0@0_9M7102n
VDT40;nKA`@0`I]81032WDD50;nG@0@0^Y4i102iT3P40;^B>0@0_9<k102mUCd40<2H@`@0_IM2102l
UTD50<:MC0@0_iY:102mV4L40;bGAP@0_IU3102oVdL40<2KB`@0`Ye?1@37XU840<>NCP@0`Ye=1031
W4`40<2KC@@0_iU>1030VTl40<:LD`T0`I]B1037XU@40<:MC`P0_IM6102kUTD40;bGA`@0^YI<102o
VU@50<6NG0@0a:5Q1032Wel40<FRHP@0`YmK1033X5`40<bWH`@0bjIR1037XU/50<JQFP@0`9iD102n
W5840;FEBP@0]IE<102mVe<40<2MF@@0b:EQ1@38YF<40<NQH0@0b:9Q1038XEh40<VRG`@0bjEN1033
WEH80;fGD0D0`IYE1033W5L40<>NFP@0aZ5M1037Y6040<:OF`@0`9eI1035XUh40<JTG@D0a:9K1035
Xe`40<BRF`@0aj9L103:YEl40=VbK@@0cZMR2@38X5/40<RPF0@0aj1E1037WE440<FLC@@0`iY81031
V4P;0?ooo`002P3oool40;ZFB0@0^9E4102fTd440;RE@@@0_9M61031W4`50<:MC@@0`Ia>102oVDh4
0;fGC0@0_9M7102nVDT40;nKA`@0`I]81032WDD50;nG@0@0^Y4i102iT3P40;^B>0@0_9<k102mUCd4
0<2H@`@0_IM2102lUTD50<:MC0@0_iY:102mV4L40;bGAP@0_IU3102oVdL40<2KB`@0`Ye?1@37XU84
0<>NCP@0`Ye=1031W4`40<2KC@@0_iU>1030VTl40<:LD`T0`I]B1037XU@40<:MC`P0_IM6102kUTD4
0;bGA`@0^YI<102oVU@50<6NG0@0a:5Q1032Wel40<FRHP@0`YmK1033X5`40<bWH`@0bjIR1037XU/5
0<JQFP@0`9iD102nW5840;FEBP@0]IE<102mVe<40<2MF@@0b:EQ1@38YF<40<NQH0@0b:9Q1038XEh4
0<VRG`@0bjEN1033WEH80;fGD0D0`IYE1033W5L40<>NFP@0aZ5M1037Y6040<:OF`@0`9eI1035XUh4
0<JTG@D0a:9K1035Xe`40<BRF`@0aj9L103:YEl40=VbK@@0cZMR2@38X5/40<RPF0@0aj1E1037WE44
0<FLC@@0`iY81031V4P;0?ooo`002P3oool40;RDB0@0^9A6202gU4840;JA@@@0_YU;1@35X5840<>M
DP@0`9YA102nV4l80;fHBP@0_Y]91030VdX40<BNC@D0`YU9102nU4040;^A?@@0_9<k102nUCd40;^C
>`@0^i<l102jUCd40;bF@`D0`Ie9102nVDP40;fJB0@0_9U7102mVTH40<6NC0@0`Ym=102nVdX50<>P
C`@0`9e<2031WDl40<2JC`P0`I]@102nV4d90;bEB0@0`iY;1037WTl40<BKB`@0`YU9102mV4L40;ZE
A@@0]I57102lUe450<BQG@@0ajAR2033X5h80<BRF`@0bJAN103;YV090<ZUGP@0b:MJ1037YUT40;VH
B@@0]IA7102lVdh40;nME@@0`ImH1@33X5`40<ZTH`@0b:9Q103;YV040<ZUG`@0bjEN1038XU/40<:L
E@@0_9I?1@31Ve@40<>MEP@0aYmJ1035WUT40<BOF`@0`YeI1031WU`40<FRH0@0b:ES1@39YV@80<RU
H`@0aj9N103:YF440<fWH0@0cjUR2@3<Y5`40<^QF@@0bImE1038WU840<JMCP@0aY]<1034VDX;0?oo
o`002P3oool40;RDB0@0^9A6202gU4840;JA@@@0_YU;1@35X5840<>MDP@0`9YA102nV4l80;fHBP@0
_Y]91030VdX40<BNC@D0`YU9102nU4040;^A?@@0_9<k102nUCd40;^C>`@0^i<l102jUCd40;bF@`D0
`Ie9102nVDP40;fJB0@0_9U7102mVTH40<6NC0@0`Ym=102nVdX50<>PC`@0`9e<2031WDl40<2JC`P0
`I]@102nV4d90;bEB0@0`iY;1037WTl40<BKB`@0`YU9102mV4L40;ZEA@@0]I57102lUe450<BQG@@0
ajAR2033X5h80<BRF`@0bJAN103;YV090<ZUGP@0b:MJ1037YUT40;VHB@@0]IA7102lVdh40;nME@@0
`ImH1@33X5`40<ZTH`@0b:9Q103;YV040<ZUG`@0bjEN1038XU/40<:LE@@0_9I?1@31Ve@40<>MEP@0
aYmJ1035WUT40<BOF`@0`YeI1031WU`40<FRH0@0b:ES1@39YV@80<RUH`@0aj9N103:YF440<fWH0@0
cjUR2@3<Y5`40<^QF@@0bImE1038WU840<JMCP@0aY]<1034VDX;0?ooo`002P3oool40;RDB0@0^9A6
202gU4840;JA@@@0_YU;1@35X5840<>MDP@0`9YA102nV4l80;fHBP@0_Y]91030VdX40<BNC@D0`YU9
102nU4040;^A?@@0_9<k102nUCd40;^C>`@0^i<l102jUCd40;bF@`D0`Ie9102nVDP40;fJB0@0_9U7
102mVTH40<6NC0@0`Ym=102nVdX50<>PC`@0`9e<2031WDl40<2JC`P0`I]@102nV4d90;bEB0@0`iY;
1037WTl40<BKB`@0`YU9102mV4L40;ZEA@@0]I57102lUe450<BQG@@0ajAR2033X5h80<BRF`@0bJAN
103;YV090<ZUGP@0b:MJ1037YUT40;VHB@@0]IA7102lVdh40;nME@@0`ImH1@33X5`40<ZTH`@0b:9Q
103;YV040<ZUG`@0bjEN1038XU/40<:LE@@0_9I?1@31Ve@40<>MEP@0aYmJ1035WUT40<BOF`@0`YeI
1031WU`40<FRH0@0b:ES1@39YV@80<RUH`@0aj9N103:YF440<fWH0@0cjUR2@3<Y5`40<^QF@@0bImE
1038WU840<JMCP@0aY]<1034VDX;0?ooo`002P3oool40;RDB0@0^9A6202gU4840;JA@@@0_YU;1@35
X5840<>MDP@0`9YA102nV4l80;fHBP@0_Y]91030VdX40<BNC@D0`YU9102nU4040;^A?@@0_9<k102n
UCd40;^C>`@0^i<l102jUCd40;bF@`D0`Ie9102nVDP40;fJB0@0_9U7102mVTH40<6NC0@0`Ym=102n
VdX50<>PC`@0`9e<2031WDl40<2JC`P0`I]@102nV4d90;bEB0@0`iY;1037WTl40<BKB`@0`YU9102m
V4L40;ZEA@@0]I57102lUe450<BQG@@0ajAR2033X5h80<BRF`@0bJAN103;YV090<ZUGP@0b:MJ1037
YUT40;VHB@@0]IA7102lVdh40;nME@@0`ImH1@33X5`40<ZTH`@0b:9Q103;YV040<ZUG`@0bjEN1038
XU/40<:LE@@0_9I?1@31Ve@40<>MEP@0aYmJ1035WUT40<BOF`@0`YeI1031WU`40<FRH0@0b:ES1@39
YV@80<RUH`@0aj9N103:YF440<fWH0@0cjUR2@3<Y5`40<^QF@@0bImE1038WU840<JMCP@0aY]<1034
VDX;0?ooo`002P3oool40;RDB0@0^9A6202gU4840;JA@@@0_YU;1@35X5840<>MDP@0`9YA102nV4l8
0;fHBP@0_Y]91030VdX40<BNC@D0`YU9102nU4040;^A?@@0_9<k102nUCd40;^C>`@0^i<l102jUCd4
0;bF@`D0`Ie9102nVDP40;fJB0@0_9U7102mVTH40<6NC0@0`Ym=102nVdX50<>PC`@0`9e<2031WDl4
0<2JC`P0`I]@102nV4d90;bEB0@0`iY;1037WTl40<BKB`@0`YU9102mV4L40;ZEA@@0]I57102lUe45
0<BQG@@0ajAR2033X5h80<BRF`@0bJAN103;YV090<ZUGP@0b:MJ1037YUT40;VHB@@0]IA7102lVdh4
0;nME@@0`ImH1@33X5`40<ZTH`@0b:9Q103;YV040<ZUG`@0bjEN1038XU/40<:LE@@0_9I?1@31Ve@4
0<>MEP@0aYmJ1035WUT40<BOF`@0`YeI1031WU`40<FRH0@0b:ES1@39YV@80<RUH`@0aj9N103:YF44
0<fWH0@0cjUR2@3<Y5`40<^QF@@0bImE1038WU840<JMCP@0aY]<1034VDX;0?ooo`002P3oool40;JB
A0@0]i=5102iUT@40;ND@`@0]8lo102lUT/50<JPE`@0aImH1032VeH40<2IE0@0_YY@102oVdl40<6M
C`@0`ii>1032WDl50<FND@@0aIa<1031V4H40;nG@P@0`9Q1102nUSh40;^C>`@0^9<k102lUT450;nK
A@@0`9a8202nVdT40;bGAP@0`Ia;1030WDT40;nLBPD0`j1>102oW4/40;jJC0@0`Yi@1032WU840<>O
D`P0`ii@2@34WDh40<2IBP@0`Y]<1033VT/40<2GB0@0`9Y9102nUdP40;VEB@@0_YUB1@36Y5d40<FR
GP@0`9iG1032X5T40<>QF@@0a:9J1036XEX40<VTG@@0aZ9H1@32WU@40;nNC`@0_Ye>102nVdX40;fI
B`@0_i]=1031WE<40<:PF0D0_ieF1034We/40<RSG`P0bZEQ2038Xed40<BNE`@0_YQA1@31Ve@40<>L
E`@0b:5L1038XEh80<>LF@@0`ieL1036X5l40<ZWI`D0b:EU1033X6040<NTI0@0bjET1039Y6040<fV
H@@0c:IO103<YU/50<RRE`@0bJ5I1037WeL40<ZPE0@0aieA2038WDl;0?ooo`002P3oool40;JBA0@0
]i=5102iUT@40;ND@`@0]8lo102lUT/50<JPE`@0aImH1032VeH40<2IE0@0_YY@102oVdl40<6MC`@0
`ii>1032WDl50<FND@@0aIa<1031V4H40;nG@P@0`9Q1102nUSh40;^C>`@0^9<k102lUT450;nKA@@0
`9a8202nVdT40;bGAP@0`Ia;1030WDT40;nLBPD0`j1>102oW4/40;jJC0@0`Yi@1032WU840<>OD`P0
`ii@2@34WDh40<2IBP@0`Y]<1033VT/40<2GB0@0`9Y9102nUdP40;VEB@@0_YUB1@36Y5d40<FRGP@0
`9iG1032X5T40<>QF@@0a:9J1036XEX40<VTG@@0aZ9H1@32WU@40;nNC`@0_Ye>102nVdX40;fIB`@0
_i]=1031WE<40<:PF0D0_ieF1034We/40<RSG`P0bZEQ2038Xed40<BNE`@0_YQA1@31Ve@40<>LE`@0
b:5L1038XEh80<>LF@@0`ieL1036X5l40<ZWI`D0b:EU1033X6040<NTI0@0bjET1039Y6040<fVH@@0
c:IO103<YU/50<RRE`@0bJ5I1037WeL40<ZPE0@0aieA2038WDl;0?ooo`002P3oool40;JBA0@0]i=5
102iUT@40;ND@`@0]8lo102lUT/50<JPE`@0aImH1032VeH40<2IE0@0_YY@102oVdl40<6MC`@0`ii>
1032WDl50<FND@@0aIa<1031V4H40;nG@P@0`9Q1102nUSh40;^C>`@0^9<k102lUT450;nKA@@0`9a8
202nVdT40;bGAP@0`Ia;1030WDT40;nLBPD0`j1>102oW4/40;jJC0@0`Yi@1032WU840<>OD`P0`ii@
2@34WDh40<2IBP@0`Y]<1033VT/40<2GB0@0`9Y9102nUdP40;VEB@@0_YUB1@36Y5d40<FRGP@0`9iG
1032X5T40<>QF@@0a:9J1036XEX40<VTG@@0aZ9H1@32WU@40;nNC`@0_Ye>102nVdX40;fIB`@0_i]=
1031WE<40<:PF0D0_ieF1034We/40<RSG`P0bZEQ2038Xed40<BNE`@0_YQA1@31Ve@40<>LE`@0b:5L
1038XEh80<>LF@@0`ieL1036X5l40<ZWI`D0b:EU1033X6040<NTI0@0bjET1039Y6040<fVH@@0c:IO
103<YU/50<RRE`@0bJ5I1037WeL40<ZPE0@0aieA2038WDl;0?ooo`002P3oool40;JBA0@0]i=5102i
UT@40;ND@`@0]8lo102lUT/50<JPE`@0aImH1032VeH40<2IE0@0_YY@102oVdl40<6MC`@0`ii>1032
WDl50<FND@@0aIa<1031V4H40;nG@P@0`9Q1102nUSh40;^C>`@0^9<k102lUT450;nKA@@0`9a8202n
VdT40;bGAP@0`Ia;1030WDT40;nLBPD0`j1>102oW4/40;jJC0@0`Yi@1032WU840<>OD`P0`ii@2@34
WDh40<2IBP@0`Y]<1033VT/40<2GB0@0`9Y9102nUdP40;VEB@@0_YUB1@36Y5d40<FRGP@0`9iG1032
X5T40<>QF@@0a:9J1036XEX40<VTG@@0aZ9H1@32WU@40;nNC`@0_Ye>102nVdX40;fIB`@0_i]=1031
WE<40<:PF0D0_ieF1034We/40<RSG`P0bZEQ2038Xed40<BNE`@0_YQA1@31Ve@40<>LE`@0b:5L1038
XEh80<>LF@@0`ieL1036X5l40<ZWI`D0b:EU1033X6040<NTI0@0bjET1039Y6040<fVH@@0c:IO103<
YU/50<RRE`@0bJ5I1037WeL40<ZPE0@0aieA2038WDl;0?ooo`002P3oool40;FB@0@0]Y=1102gU484
0;2=?0@0]Y=2102nVTh50<>OE@@0a9mH1031WeP40;nMEP@0_YaB102oWE<80<2OD0@0a:1B1@37XeD4
0<JQD@@0aj9B1036X4d40;nIAP@0_IM2102jU3l40;RB?@@0^Y@o1@2mVDD40<:NBPP0`Ia;102nVDT4
0<2KB`P0_YY61@2mV4L40;jIB0@0_Y]91034XE040<VVE@@0bJEG1037XeD40<JRE0@0`imA1@32WU08
0<2KB`@0`Ye<1033WTd40;nHB@@0`9U<102oVT`40<6KDPD0b:IL1032X5P40;fKD@@0`ImE1033WeD4
0<FQE`@0aZ9H103:YU`40<JREPD0`YiB1030WD`40;nLB`@0`9]=102oVDh40<6MD@@0`YeF1031W5D5
0<>NF0@0`j1L1032We/40<JSG`@0b:EQ2039Y6040<NPG@T0aIiK1038XF040<VRH@@0bZ9T1034WUl8
0<>MGP@0aZ1Q1039YVH50<FRHP@0ajAT1039YVH80<NTHP@0b:IO1039Yel40<VWG@D0aZEH1038Y5X4
0<NSF@@0bZAI1039XUL40<VRE@@0bj5E2`3oool000X0oooo102eTT040;JC@@@0]iA2102`SC`40;JC
@P@0_YY>1@33WeD40<BOF0@0`ImH102oWEH40;jLDP@0_ieC2030We040<BPDPD0aj=E1036XE440<NR
DP@0aZ1=102oVDH40;fG@P@0^Y@o102hTSd40;ZD?`D0_IU51032WTX80<6LB`@0_YU91030Vd/80;jJ
APD0_IQ7102nVDP40;jKB@@0a:5@1039YUD40<VUE`@0aj=E1036XU@40<>OD@D0`Yi@2030Vd/40<:M
C0@0`ii=102oV4T40<2IC0@0_iY<1031Ve850<RVG0@0`Z1H102mVe440<6OE@@0`imE1035XEL40<JR
F0@0bZIL1036XUH50<:NDP@0`9e<102oW4/40<2KC@@0_iU>1031WE440<:MEP@0`IaE1@33WUP40<>P
G0@0`YmK1036Xel40<RUH@P0bJAP1037X5d90<FNF`@0b:5P1039XV440<ZRI0@0a9iO2033WEh40<JP
H@@0bJIV1@35XV840<NTI0@0bJIV2037Y6840<RVG`@0bJMO1039Yed50<JUF0@0b:AJ1037XeT40<ZT
F@@0bJ9G1039XUD40<^QE@/0oooo000:0?ooo`@0]I90102fTd440;ND@P@0/8dl102fTd840;jJCPD0
`imE1034WeP40<6OF0@0_ieF102nW5840;nMD`P0`9m@1034X5850<NSE@@0aZ5A1037XU840<JPC@@0
_iU6102mUd840;ZD?`@0^98m102jU3l50;fIA@@0`Yi:2031W4/40;jIB@@0`9];202nVTH50;fHA`@0
_YU8102nVdT40<BQD0@0bJIE1039YEL40<NSE@@0aZ9D1033We450<:ND0P0`9];1032WD`40<>NC@@0
_iQ91030VD`40;nJC0@0`I]B1@38YU`40<:PF0@0_I]A1031WeD40<>OE@@0aJ5G1036XUP40<ZVG0@0
aZ9F1@32WU840<2MC0@0_ia;1030Vdd40;nICP@0`IeA1032WEH40<6LE@D0`iiH1033X5`40<:OF`@0
aZ=O1038YF480<VTH0@0aj1M2@35WU/40<RQH0@0bJ9Q103:XV@40<BNG`P0`ieN1036X6440<VVIPD0
aJ9R1037Y6@40<VVIPP0ajAR1038YUl40<VWG`@0bJMM1@36YEP40<RTFP@0aj=I103:Y5T40<VRE`@0
bJ9E103;XED;0?ooo`002P3oool40;FB@0@0]Y=1102gU4840;2=?0@0]Y=2102nVTh50<>OE@@0a9mH
1031WeP40;nMEP@0_YaB102oWE<80<2OD0@0a:1B1@37XeD40<JQD@@0aj9B1036X4d40;nIAP@0_IM2
102jU3l40;RB?@@0^Y@o1@2mVDD40<:NBPP0`Ia;102nVDT40<2KB`P0_YY61@2mV4L40;jIB0@0_Y]9
1034XE040<VVE@@0bJEG1037XeD40<JRE0@0`imA1@32WU080<2KB`@0`Ye<1033WTd40;nHB@@0`9U<
102oVT`40<6KDPD0b:IL1032X5P40;fKD@@0`ImE1033WeD40<FQE`@0aZ9H103:YU`40<JREPD0`YiB
1030WD`40;nLB`@0`9]=102oVDh40<6MD@@0`YeF1031W5D50<>NF0@0`j1L1032We/40<JSG`@0b:EQ
2039Y6040<NPG@T0aIiK1038XF040<VRH@@0bZ9T1034WUl80<>MGP@0aZ1Q1039YVH50<FRHP@0ajAT
1039YVH80<NTHP@0b:IO1039Yel40<VWG@D0aZEH1038Y5X40<NSF@@0bZAI1039XUL40<VRE@@0bj5E
2`3oool000X0oooo1038YE440;ND@0@0/Y8o102cTT440;:A@0@0]YE81@2iUdd40;bJDPP0_YaE102o
WE<40<6OE@@0`J1A1030We040<:QD0D0_ii=102lVDP40<VTE0@0c:MF1030VTT40;jHA`@0^YA3102f
TSh40;FA?@D0^iI51030VdX40<>NCP@0`Ye=1035X5040<FNC`@0bZAA1032VDL50;F?>P@0_IM2102o
VdD40<2LB0@0aZ=?1036Xe840<FQD`@0b:AH1034XeH50<:QE0@0a:5@1032Wdh40<2MB@P0`9]:1031
VTd40<2KC@@0a9iC1@3<ZV040<BRF0@0_Ye@1031X5<40<BPE0@0`imC1032WU@40<JRF0@0aZ9D1@35
XE<40<6NC0@0`Ye=1031W4h40;nHC@@0`9YA1033WEH40<:MEPD0`IaH102mVUH40<>PGP@0ajAR3036
Xf440<JPG`@0a9iM1@32VeX40<NOH@@0bZAU2036X6840<BNH0@0`IiN1034XF440<FRHPD0ajAT1036
Y6@40<>QH@P0ajIS1037YUl40<RWH0@0cK1T1@35Z5`40<FUFP@0aZAJ1038YU`40<VSFP@0bJ=H103;
Y5T;0?ooo`002P3oool40<RUD@@0]iA0102bTSl40;>B@@@0/Y50102fUDP50;VGC@@0_9YB202nW5D4
0;nMD`@0`ImE1031X5440<2OD0@0`Z5@1@2oWTd40;bIB0@0bJAD103<YeH40<2JB@@0_YQ7102jU4<4
0;JB?P@0]I4m1@2kUTD40<2KBP@0`ii>1032WDd40<FPD0@0aIi?103:Y5440<:IA`D0]Hlj102mUd84
0;nKA@@0`9a81036Xdl40<JSDP@0aJ5C1038Y5P40<BSEPD0`Z5D1034XE040<:OCP@0`9e92030VdX4
0<6JC@@0`9]=1034WU<50<bZH0@0a:9H102nWE040<6PD`@0a:1D1033We<40<:NE0@0aZ9H1036XU@5
0<FQD`@0`Ii<1032WDd40<6LCP@0_iQ=1030VU440<>MEP@0`YeF1@31W5P40;fJEP@0`j1N1037Y68<
0<JSH@@0aZ1O1034WUd50<:KFP@0aimQ103:Y6D80<JPHP@0a9iP1031WUh40<BQH@@0aJ9R1@37Y6@4
0<JTI0@0`j5Q2037YV<40<NVG`@0b:MP103=/6@50<FXG0@0aJEJ1036Y5X40<RVG0@0bJ=J1039XeP4
0<^TF@/0oooo000:0?ooo`@0b:EA102gU4040;:B?`@0/i91102bTD040;JEB0D0^IM=102lVU880;jL
E@@0_ieC1031WeD40<6PD@@0`9m@1032XE050;nNC@@0_9U81039Y5@40<bWEP@0`9Y9102nV4L40;ZD
@`@0]Y8n102eTCd50;^FA@@0`9]:1033WTh40<:MC@@0aJ1@1035WTl40<ZTD@@0`YU71@2eScX40;fG
@P@0_i]51030W4P40<JSC`@0aZ=B1035XE<40<RTF0@0a:=F1@32XE@40<BQD0@0`Ym>1030WDT80<2K
BP@0`IY=1030Vdd40<BND`D0c:YP1034XUP40;jMD0@0`J1C1034X5@40<>OD`@0`YiD1036XUP40<JR
E0D0aJ5C1031WT`40<:MC@@0`Ia>102oV4d40<2JD@@0`ieF1032WEH50<6LF0@0_IYF1033X5h40<NT
HP`0aZ=Q1036X5l40<BNG@D0`Y]J1037Wf440<ZTI@P0aZ1R1034WV040<6NGP@0a:5Q1035XV850<NT
I0@0aZAT1033XF480<NVH`@0ajIO1038Yf040<f`I0D0aJQL1035YEX40<JTFP@0b:IL1039XeX40<VS
F0@0bjAI2`3oool000X0oooo1038YE440;ND@0@0/Y8o102cTT440;:A@0@0]YE81@2iUdd40;bJDPP0
_YaE102oWE<40<6OE@@0`J1A1030We040<:QD0D0_ii=102lVDP40<VTE0@0c:MF1030VTT40;jHA`@0
^YA3102fTSh40;FA?@D0^iI51030VdX40<>NCP@0`Ye=1035X5040<FNC`@0bZAA1032VDL50;F?>P@0
_IM2102oVdD40<2LB0@0aZ=?1036Xe840<FQD`@0b:AH1034XeH50<:QE0@0a:5@1032Wdh40<2MB@P0
`9]:1031VTd40<2KC@@0a9iC1@3<ZV040<BRF0@0_Ye@1031X5<40<BPE0@0`imC1032WU@40<JRF0@0
aZ9D1@35XE<40<6NC0@0`Ye=1031W4h40;nHC@@0`9YA1033WEH40<:MEPD0`IaH102mVUH40<>PGP@0
ajAR3036Xf440<JPG`@0a9iM1@32VeX40<NOH@@0bZAU2036X6840<BNH0@0`IiN1034XF440<FRHPD0
ajAT1036Y6@40<>QH@P0ajIS1037YUl40<RWH0@0cK1T1@35Z5`40<FUFP@0aZAJ1038YU`40<VSFP@0
bJ=H103;Y5T;0?ooo`002P3oool40;RD@0@0]Y8n202dTCd40;BA?`@0/Hhl1@2dTd840;VHA`@0^YU:
102kVT/40;jMCP@0_ii?1030We040;nNC`T0_Ia=1030We040<VXF@@0ajAB102oVTT40;ZF@P@0_9=1
102gScP40;F;=@D0^i4m1030UT880<BNB`P0`ii=1034Wdh40<6KBPD0_iU41031VD@40;nE?`@0^Hlk
1031VD@40<BKB`@0b:=C1039XeP40<NVF@D0`j9E1036XU@40<6NC@@0`im;102oVdL40;nLBP@0_ia;
1032Wdh40<JREPD0cZYN103@[6840<JQFPP0`iiG1034WeP40<>OD`@0aZ9F1036XU@50<>OD@@0a:5?
1034Wdh40<:MC@@0_YM:1030VDh40<JNF0@0`IYE1@32VeX40<BNG@@0`ieN1034X6840<JRI0@0aJ9R
1036Xf<40<2NGP@0`Z1P1@31X5d40<BRHP@0a:9S103;ZF`40<NSI`@0`YiR1033Wf440<:NH0@0a:5O
1@33X5h40<BQG@@0`j1L1033XU/40<2OF0@0`Z5J1033XU/40<:QFPD0aJAM1035Xe/40<>QF@@0aZ5J
1037XeT40<bVF`@0b:=C2`3oool000X0oooo102hU4040;JB?PP0]94m102dTCl40;6>?0D0]9=2102i
V4L40;ZIBP@0^iY;102nWDh40;nNC`@0`9m@102oWTl90;fLC@@0`9m@1039Z5T40<NTDP@0_iY9102j
UT840;bC@@@0]hlh102eRcD50;^A?@@0`9I22034WT/80<>NC@@0a9m>1031VdX50;nIA0@0`IU4102o
UCl40;V?>`@0`IU41034Vd/40<RSD`@0bJ=H1037YUT50<>RE@@0aZ9D1031WTd40<>OB`@0_i]7102o
W4X40;nLB`@0`Ym>1036XUH50<jZGP@0d:aR1036XEX80<>NE`@0a9mH1033We<40<JREP@0aZ9D1@33
We440<BQC`@0a9m>1032WDd40;jGBP@0`9U>1036WUP40<6JE@D0`Y]J1034WUd40<>MGP@0a:1R1036
XV@40<FRHP@0aZ=S1030WUh40<:PH0D0`J1M1034XV840<BRH`@0bjU/1037XfL40<:NHP@0`imQ1032
WV040<BQG`D0`j1N1034XEd40<>PG0@0`j9K1030WeP40<:QFP@0`j9K1032XEX50<FTG@@0aJ=K1033
XET40<JQFP@0aj=I103<YU/40<RSD`/0oooo000:0?ooo`@0^9A0102fTSh80;BA?@@0]94o102aSS`5
0;BC@P@0^IQ7102jVDX40;^JB`@0_Ye>102oWTl40<2OD0@0_ii?2@2mW4d40<2OD0@0bJQI1037Y584
0;nJB@@0^YI2102lTd440;N?>0@0]H/e1@2kTCd40<2F@PP0a9i;2033WTd40<BOCP@0`I]:1@2oVD@4
0<6IA0@0_iDo102iSc/40<6IA0@0a9];1038Xe<40<VSF0@0ajII1@33XUD40<JRE0@0`Ii=1033Wd/4
0;nKA`@0_ia:102oW4/40<:OCP@0aZ9F1@3>ZUh40=2/HP@0aZ5J2033WUL40<BOF0@0`imC1036XUH4
0<JRE0D0`imA1034XDl40<BOCP@0`Ye=102nUdX40<2ICP@0aYiH1031VUD50<:KFP@0a9iM1033WEh4
0<BPHP@0aZ9T1035XV840<JSH`@0`9iN1032X6050<6PG@@0a:9R1034XV<40<^YK0@0aj=W1032WV84
0<>OH@@0`YiP1034XEl50<>PGP@0a:5M1033X5`40<>RF`@0`9mH1032XEX40<>RF`@0`Z5J1@35Y5d4
0<FSF`@0`j5I1036XEX40<NSF@@0c:IK1038Xe<;0?ooo`002P3oool40;RD@0@0]Y8n202dTCd40;BA
?`@0/Hhl1@2dTd840;VHA`@0^YU:102kVT/40;jMCP@0_ii?1030We040;nNC`T0_Ia=1030We040<VX
F@@0ajAB102oVTT40;ZF@P@0_9=1102gScP40;F;=@D0^i4m1030UT880<BNB`P0`ii=1034Wdh40<6K
BPD0_iU41031VD@40;nE?`@0^Hlk1031VD@40<BKB`@0b:=C1039XeP40<NVF@D0`j9E1036XU@40<6N
C@@0`im;102oVdL40;nLBP@0_ia;1032Wdh40<JREPD0cZYN103@[6840<JQFPP0`iiG1034WeP40<>O
D`@0aZ9F1036XU@50<>OD@@0a:5?1034Wdh40<:MC@@0_YM:1030VDh40<JNF0@0`IYE1@32VeX40<BN
G@@0`ieN1034X6840<JRI0@0aJ9R1036Xf<40<2NGP@0`Z1P1@31X5d40<BRHP@0a:9S103;ZF`40<NS
I`@0`YiR1033Wf440<:NH0@0a:5O1@33X5h40<BQG@@0`j1L1033XU/40<2OF0@0`Z5J1033XU/40<:Q
FPD0aJAM1035Xe/40<>QF@@0aZ5J1037XeT40<bVF`@0b:=C2`3oool000X0oooo102bS3T40;B>>`@0
]I4m102hU4040;bGAP@0^IA32@2hTd840;VFA0@0_IY8102oW4/40<2MC0P0`Ii=1032WDl50<>ND0@0
a9mA1037XU@40<FPD0@0`Y]<102nV4L40;bC@`@0^i<n102hT3/50;^C?P@0_iM22032WTX40<6NC0@0
_ia:102oVTX40<>LC@D0aIm<102oUT@40;jD@0@0^Y0l102hScd40<:IB@@0`Ye<1038Xe<40<NVE`D0
a:=D1034X5840<:ND0@0a9m>1030VdX80<6NC0@0`Ym>1033We450<VUE`@0c:QL1036XUP40<FQE`@0
`imE1034X5H80<:NDP@0aJ5C1@36XU@40<>PC`@0`9a>102kUTP40<2JC`@0`9YA1030VU<40<:MEPD0
`IaF102oW5P40<:OF`@0a:5O103:YfD40<JUHP@0a:=P1031Wel40<:PH0D0`j5R1035XfH40<JTI`@0
bZM]1038YVT40<FSIP@0a:5Q1032Wel40<:OF`D0`j1L1037YEh40<FSG0@0`j5J1034XU/40<6PF@@0
_IaE1030WeP50<BSG0@0`j5I1032X5P40<FPF@@0aJ5G103:Y5T40<VTE0/0oooo000:0?ooo`@0/X`i
102dSS/40;FA?@@0^9A0102lUdH40;VD@`T0^9=2102iUT@40;fJB0@0_ia;1030WD`80<6NC@@0`Ye?
1@33WU040<BOD@@0aj9D1035X5040<:KC0@0_YQ7102lTd<40;^C?P@0^90k1@2kTch40;nG@PP0`Yi:
1031WT`40;nLBP@0_iY:1033W4d50<FOC0@0_iI4102nU4040;Z@?0@0^8lm1032VDT40<:MC0@0b:=C
1037YUL50<BSE0@0a:1B1032WU040<BOCP@0`9]:2031WT`40<:OCP@0`imA1@39YEL40<bXG0@0aZ9H
1035XEL40<>OE@@0a:1F2032WU840<FQD`D0aZ9D1033X4l40<2LCP@0^iI81030VTl40<2JD@@0`9YC
1032WEH50<6LEP@0_iaH1032We/40<BQG`@0bZMU1036YF840<BSH0@0`ImO1032X6050<>QHP@0aJ=V
1036Y6L40<ZWK@@0b:IY1035XfH40<BQH@@0`YmO1032We/50<>PG0@0ajEN1035Xe`40<>QFP@0a:9K
1031X5T40;fLE@@0`9mH1@34Xe`40<>QF@@0`Z1H1035X5T40<FQE`@0bZAI1039Y5@;0?ooo`002P3o
ool40;:<>@@0]8hk102eTCd40;RD@0@0_9M6102iU4<90;RC@P@0^II4102mVTP40;nLB`@0`9e<2031
WTd40<:MC`D0`ii@1034We440<NRE0@0aJ1@1032Vd`40;jHA`@0_9=3102kTch40;R@>`D0^i<n102o
Ud880<:NBP@0`Ii<102oW4X40;nJBP@0`ia=1@35Wd`40;nFA0@0_YA0102jT3`40;R??@@0`YU91032
WD`40<RSD`@0ajIG1@34Xe@40<BPDP@0`Yi@1034Wdh40<2KBPP0`Ii<1032Wdh40<>OD@D0bJEG103<
Z5`40<JRF0@0aJ5G1033WeD40<BPEPP0`YiB1035XE<50<JRE0@0`j1?1030W4h40;^FB0@0`9Y?1030
VU440<2JD`@0`YeF1@31W5H40;nLF0@0`YmK1034XEl40<ZWI@@0aZER1034Xf040<6OG`@0`Z1P1@33
XF840<FSIP@0aZAW103:Yfd40<RVJ@@0aJ=V1034XF440<:OG`@0`YmK1@33X5`40<NUGP@0aJ=L1033
XEX40<BRF`@0`J1I102mW5D40<2OF0D0a:=L1033XET40<:PF0@0aJ1I1035XEL40<ZTF@@0bJAD2`3o
ool000X0oooo102bS3T40;B>>`@0]I4m102hU4040;bGAP@0^IA32@2hTd840;VFA0@0_IY8102oW4/4
0<2MC0P0`Ii=1032WDl50<>ND0@0a9mA1037XU@40<FPD0@0`Y]<102nV4L40;bC@`@0^i<n102hT3/5
0;^C?P@0_iM22032WTX40<6NC0@0_ia:102oVTX40<>LC@D0aIm<102oUT@40;jD@0@0^Y0l102hScd4
0<:IB@@0`Ye<1038Xe<40<NVE`D0a:=D1034X5840<:ND0@0a9m>1030VdX80<6NC0@0`Ym>1033We45
0<VUE`@0c:QL1036XUP40<FQE`@0`imE1034X5H80<:NDP@0aJ5C1@36XU@40<>PC`@0`9a>102kUTP4
0<2JC`@0`9YA1030VU<40<:MEPD0`IaF102oW5P40<:OF`@0a:5O103:YfD40<JUHP@0a:=P1031Wel4
0<:PH0D0`j5R1035XfH40<JTI`@0bZM]1038YVT40<FSIP@0a:5Q1032Wel40<:OF`D0`j1L1037YEh4
0<FSG0@0`j5J1034XU/40<6PF@@0_IaE1030WeP50<BSG0@0`j5I1032X5P40<FPF@@0aJ5G103:Y5T4
0<VTE0/0oooo000:0?ooo`@0/h/f102gSS`40;NA@0@0^991102mUTL40;^DA@D0_9I5102hTT440;^E
@P@0_YQ5102mUd@40;jHA@@0`9Y91031VT/40<FLC@D0aYa@1034WE080<FND@@0`Y]>1034Vd`40<6H
B@@0_iI4102lTd450;ZD@@@0_IM41030W4P40<:NBP@0_Yi9102lVDL40<6NC0@0cjYJ1@38XU440<>M
C0@0`iY8102kTT040;bF@`@0^iE2102oVTT40<>NC@@0`9m>1@31X4l40<>PC`@0aJ9A1034Wdl40;nJ
BP@0`Ia;1032WD`40<>NC@@0`Ia;1@33WTh40<JQD@@0`ii@1034We440<BND`@0aZ1E1032WU040<6M
C`@0`Yi@1@38Y5H40<>PC`@0_IU;102fTTH40;^GC@@0_i]A102mVDl40;fKD`D0_9YB102nWEH40<2O
F0@0`Z5J1037YV440<FTG`@0a:9R1036Y6@40<BRI@D0`Z1S1032WfD40<FUJP@0ajM/1038YVL40<NU
IP@0ajAR103:YfD40<BOF@D0_9MA3036XUP40<VUF`@0`ImG102hUTh40;jNE@D0a:AK1035Xe`40<BR
F`@0aj9K1036XUP40<ZTF@@0bJAD2`3oool000X0oooo102cRcH40;N>?0@0]i50102hTT440;fFA`@0
^iA51@2lUTD40;RB@@@0^iE2102nV4D40;fGA0@0_YQ51030VTT40<6JB`@0aIa=1@36W5040<BMD0P0
aIiA1032Vdh40<BKC0@0`IQ9102oUT@40;bC@@D0^YA1102mUd@40<2LB0@0`Yi:102nWTT40;bIA`@0
`Ii<103?ZUX50<RRD@@0`ie<1033VTP40;^B@0@0_9I3102kUD840;nJB@@0`ii=1030Wdh50<6PC`@0
`j1?1035XU440<BOC`@0_iY:1031W4/40<:MC0@0`ii=1031W4/50<>NCP@0aZ5A1033WU040<BOD@@0
a9iC1036X5D40<:ND0@0`Ie?1032WU050<RTEP@0`j1?102mVD/40;JBAP@0^iM=102oVe440;fIC`@0
_I]C1@2lVU840;jMEP@0`9mH1032XEX40<NVH@@0aJAO1034XV840<JTI0@0a:9U1@32X6<40<:OI@@0
aJEZ1037Yf`40<RVI`@0ajEV1037Y6840<ZWI@@0a9mI1@2lUe4<0<JRF0@0bJEK1031WeL40;RFCP@0
_YiE1@34Y5/40<FSG0@0a:9K1037XU/40<JRF0@0bZAI1039Y5@;0?ooo`002P3oool40;>;=P@0]hhl
102gTD040;RB@@@0_II7102kU4D50;bFA@@0^991102kUD840;jHA@@0_IM4102nV4D40<2JB@@0`IY;
1035W4d50<JLD0@0a9e@2035WU440<:KCP@0a9]<1031V4T40;nFA0@0_9=11@2jU4440;fGA0@0`9a8
1032WTX40;jNB@@0_9U71031WT`40<nZFPD0b:9A1033WD`40<>JB0@0^i90102lUT<40;^E@P@0_iY9
1033WTd40<2OCPD0`J1?1033X4l40<FRD@@0a9m?102oVTX40<6LB`@0`Ye<1033WTd40<6LB`D0`ii>
1036XE440<>ND0@0a9mA1034WU<40<JPE@@0`Yi@1031WDl40<:ND0D0b:AF1033X4l40;fIB`@0]Y96
102kUdd40;nKD@@0_IU?102mVe<50;bJDP@0_YeF1030WeP40<:QFP@0ajIQ1035Y5l40<BRHP@0aZAT
1034XVD50<:PH`@0`YmU1035YFX40<NWK0@0b:IW1037YFH40<NTHP@0bZMU1034WeT50;bGD@`0aZ9H
1039YE/40<6OE`@0^9I>102nWUD50<BTF`@0aJ=L1034XU/40<NRF`@0aZ9H103:Y5T40<VTE0/0oooo
000:0?ooo`@0/h/f102gSS`40;NA@0@0^991102mUTL40;^DA@D0_9I5102hTT440;^E@P@0_YQ5102m
Ud@40;jHA@@0`9Y91031VT/40<FLC@D0aYa@1034WE080<FND@@0`Y]>1034Vd`40<6HB@@0_iI4102l
Td450;ZD@@@0_IM41030W4P40<:NBP@0_Yi9102lVDL40<6NC0@0cjYJ1@38XU440<>MC0@0`iY8102k
TT040;bF@`@0^iE2102oVTT40<>NC@@0`9m>1@31X4l40<>PC`@0aJ9A1034Wdl40;nJBP@0`Ia;1032
WD`40<>NC@@0`Ia;1@33WTh40<JQD@@0`ii@1034We440<BND`@0aZ1E1032WU040<6MC`@0`Yi@1@38
Y5H40<>PC`@0_IU;102fTTH40;^GC@@0_i]A102mVDl40;fKD`D0_9YB102nWEH40<2OF0@0`Z5J1037
YV440<FTG`@0a:9R1036Y6@40<BRI@D0`Z1S1032WfD40<FUJP@0ajM/1038YVL40<NUIP@0ajAR103:
YfD40<BOF@D0_9MA3036XUP40<VUF`@0`ImG102hUTh40;jNE@D0a:AK1035Xe`40<BRF`@0aj9K1036
XUP40<ZTF@@0bJAD2`3oool000X0oooo102dRcT40;N>?`@0]i11102hTD@40;bEB0@0_YM:1@2lUTD4
0;RB@@@0^YA1102kUD840;fD@P@0_iI41031V4H40<:IB@@0a9];1@36WDh40<RNDP@0aYa@1033W4l4
0;nHB`@0a9]<1033VT/40<6HAP@0`9M51@2nUT440<2H@`@0_i]51030W4H40;nMAP@0_IY61032WTX4
0<RSDPD0cZQG1038XU440<:IB@@0`IQ8102mUdH40;nIB0@0_9U8102oW4/40<6NC@D0a:5@1033X4l4
0<6NC@@0`Ia<1032WDd40<6LB`@0`Ye<1033Wd/40<:NBPT0`ii=102oVTT40;nJBP@0`ii>1037XU@4
0<BOD@@0`Ye?1030W4h50<BPDP@0`Ie?102mVD/40;FAA@@0_9Q<102oWE<80;fKD@D0_YaB2030WUH4
0<:QFP@0a:=L1033XUd40<:QGP@0a:9R1032X6<50<>OH`@0aJ5W2039ZF`40<JTI0@0ajEU1036Xel4
0<RVG`@0aJ1I1@33WeD80<FOE0@0a:1D1035XED40<6OE@@0_YaB102oWED50<2NEP@0aj9L1035X5X4
0<VTG@@0b:AJ103:Y5T40<JQD@/0oooo000:0?ooo`@0]8/i102gSSl40;N@@@@0^954102lUDP40;jG
BPD0_9I5102hTT440;ZD@@@0^iE2102mU4840;nFA0@0`IQ61032VDT40<BKB`D0aYe>1038WU840<JL
D0@0`ia?102oV4/40<BKC0@0`iY;1031V4H40<2GA@D0_YI11030V4<40;nKA@@0`9a6102oWDH40;fJ
AP@0`Yi:1038Xe850<jXE`@0b:9A1032VDT40<6HB0@0_IM6102oVDP40;bIB0@0_ia;1031WTd50<BQ
D0@0`j1?1031WTd40<6LC0@0`Ye=1031W4/40<:MC0@0`im;1032WTX90<>NC@@0_iY9102oVTX40<>N
CP@0aj9D1034We440<:MC`@0`9a>1@34X5840<6MC`@0_IU;102eTDD40;bHC0@0_ieC202mVe450;jL
DPP0`9iF1032XEX40<BSG0@0`j9M1032XEh40<BRHP@0`Z1S1@33Wf<40<FQI`P0bJU/1036Y6@40<NU
I@@0aZ=O1038YUl40<FPF@D0`imE2035We@40<BPE0@0aJ5E1031WeD40;jLDP@0_ieE1@30WUH40<NR
G0@0aJ1J1039Y5d40<RTFP@0bZAI1036XE4;0?ooo`002P3oool40;B;>@@0]hho102gT4440;RAA0@0
_9E8102nUdX50;bFA@@0^991102jU4440;^E@P@0_IA2102oUT@40<6HAP@0`YU91034Vd/50<JMCP@0
b9iB1036W5040<>LC`@0_iQ;1034Vd`40<>JB`@0`IQ61030UdD50;jF@@@0`9Q3102oVdD40<2LAP@0
_ie6102mVTH40<:NBP@0b:=B1@3>Z5L40<RRD@@0`YU91031V4P40;fGAP@0_iU8102lVDP40;nLB`@0
`Ii=1@34XE040<>PC`@0`Ii=1031W4`40<:MC@@0`Ia;1032WD`40<>OB`@0`Yi:2@33WTd40;nJB@@0
_iY:1033WTh40<NRE0@0a9mA1032WDl40<2LCPD0a:1B1031WDl40;fIB`@0]I55102lV4`40;nMD`P0
_I]A1@2nW5880<2NEP@0`Z5J1034Xe`40<>RG@@0`Z5N1034XV840<:PH`D0`imS1035XFL80<VYK0@0
aZAT1037YFD40<JSG`@0b:IO1035X5T50<>OE@P0aImD1034X5@40<FQE@@0`ImE102nW5840;nME@D0
`9iF1037XU`40<FPFP@0bJAM1038Y5X40<ZTF@@0aZ5A2`3oool000X0oooo102dRcT40;N>?`@0]i11
102hTD@40;bEB0@0_YM:1@2lUTD40;RB@@@0^YA1102kUD840;fD@P@0_iI41031V4H40<:IB@@0a9];
1@36WDh40<RNDP@0aYa@1033W4l40;nHB`@0a9]<1033VT/40<6HAP@0`9M51@2nUT440<2H@`@0_i]5
1030W4H40;nMAP@0_IY61032WTX40<RSDPD0cZQG1038XU440<:IB@@0`IQ8102mUdH40;nIB0@0_9U8
102oW4/40<6NC@D0a:5@1033X4l40<6NC@@0`Ia<1032WDd40<6LB`@0`Ye<1033Wd/40<:NBPT0`ii=
102oVTT40;nJBP@0`ii>1037XU@40<BOD@@0`Ye?1030W4h50<BPDP@0`Ie?102mVD/40;FAA@@0_9Q<
102oWE<80;fKD@D0_YaB2030WUH40<:QFP@0a:=L1033XUd40<:QGP@0a:9R1032X6<50<>OH`@0aJ5W
2039ZF`40<JTI0@0ajEU1036Xel40<RVG`@0aJ1I1@33WeD80<FOE0@0a:1D1035XED40<6OE@@0_YaB
102oWED50<2NEP@0aj9L1035X5X40<VTG@@0b:AJ103:Y5T40<JQD@/0oooo000:0?ooo`@0/H/j102a
RSd40;JA@`@0^YA9102kUDX40<6KD0D0_YU9102jUDD80;ZF@PP0^iE2102kUD@40<2JB@@0`I]:1@34
WTd40<JPC`@0`Ya;1030VDX40;nHB@@0`ia=1031VT/40<:IA`@0`iY81@31VD@40<:JA@@0_YU1102m
V4040;nK@`P0_i]51030W4P50<6KBP@0aZ1?1035WTl40<:KC0@0`ii@1030Vdd40<:MC`@0`Ia>1031
WTd50<>PC`@0a:5@1031WTd40<6LC0@0`Ye=1033WTd40<:MC0P0a9i;1@35WdX40<>MB0@0_iU6102m
UdH40<>NC@@0b:=C1035X5840<BOD@T0`Ia>1030WD`40;bIB0@0^iQ7102gTdD40;nKC@@0bJEI1031
WE<50;jJD0@0`YeF1034WeP40<>QFP@0`Z1I1035XUh40<2MF`@0`ieL1034WUl50<BNH0@0`imQ1035
XfH40<f^KP@0bZQX1038YF440<JTG@@0bZEN1038XUL50<FOE0@0aJ1@1033WTh40<FPDP@0`ii@1032
WU840<BPE0@0_YY@1@2oVe440<BOF0@0aZ5J103;YUl40<NRF`@0b:9G1034We4;0?ooo`002P3oool4
0;6;>P@0/HXm102fTD<40;ZDB@@0^iE:1031Ve050;jIB@@0^YE5202jUT880;^E@P@0^iE41030VTT4
0<6KBPD0a9i=1036X4l40<:LB`@0`9U:102oV4T40<>LC@@0`IY;1032VDL40<>JB0D0`IU41032VTD4
0;jI@@@0_IQ0102oVd<80;nKA@@0`9a81@31VdX40<JPC`@0aIi?1032Vd`40<>ND0@0`9]=1032WDl4
0<6LCP@0`Ii=1@33X4l40<BQD0@0`Ii=1031W4`40<:MC@@0`ii=1032WD`80<BNB`D0aIm:1033WDP4
0;nIAP@0_IM61033WTd40<RSD`@0aJ1B1034We490<6LCP@0`9e<102lVDP40;^HA`@0]i=5102oVdd4
0<VUF@@0`IeC1@2nVU040<:MEP@0a9mH1033XEX40<:PF@@0aJ9N1030WE/40<>MG0@0a9iO1@34WV04
0<>OH@@0aJ=V103=[Vh40<ZXJ0@0b:EQ1036Y5d40<ZUGP@0b:9G1@35We@40<FPD0@0`ii>1035X584
0<>ND0@0`YiB1034X5@40;jJD0D0_i]A1034WeP40<JQFP@0bjIO1037XU/40<RRE`@0a9mA2`3oool0
00X0oooo102aRcX40;6:?@@0]Y53102jU4T40;^EBP@0`I]@1@2nVDT40;ZEA@P0^YI2202kUD840;^E
A0@0`9Y91031VdX50<BNC@@0aZ1?1032W4/40<2IBP@0_iQ91033W4d40<6JB`@0`YU71033VTP50<6I
A0@0`YY5102nVD440;fH@0@0_i]3202oVdD40<2LB0D0`I]:1036X4l40<FNC`@0`Y]<1033WU040<2K
C@@0`Ye?1031W4h40<6NC@D0`j1?1034XE040<6NC@@0`Ia<1032WDd40<>NC@@0`Ye<2034WT/50<FO
BP@0`ie8102oVDH40;fGAP@0`ii=1038Xe<40<FPDP@0a9mA2@31W4h40<2MC0@0_9U8102kV4L40;NC
A@@0_i]=1039YET40<6MD`D0_YY@1032WEH40<BOF0@0`j5J1032X5T40<FRGP@0`9eK1033WE`40<BN
G`D0a9iP1033Wf440<FSIP@0cJi^103:Z6P40<RUH@@0aZAM103:YEh40<RRE`D0aImD1035X5040<>N
CP@0aJ1B1033WU040<:NDP@0a:1D102nVU050;nKD@@0a9mH1036XEX40<^VG`@0aj9K1038XUL40<BO
D@/0oooo000:0?ooo`@0/H/j102aRSd40;JA@`@0^YA9102kUDX40<6KD0D0_YU9102jUDD80;ZF@PP0
^iE2102kUD@40<2JB@@0`I]:1@34WTd40<JPC`@0`Ya;1030VDX40;nHB@@0`ia=1031VT/40<:IA`@0
`iY81@31VD@40<:JA@@0_YU1102mV4040;nK@`P0_i]51030W4P50<6KBP@0aZ1?1035WTl40<:KC0@0
`ii@1030Vdd40<:MC`@0`Ia>1031WTd50<>PC`@0a:5@1031WTd40<6LC0@0`Ye=1033WTd40<:MC0P0
a9i;1@35WdX40<>MB0@0_iU6102mUdH40<>NC@@0b:=C1035X5840<BOD@T0`Ia>1030WD`40;bIB0@0
^iQ7102gTdD40;nKC@@0bJEI1031WE<50;jJD0@0`YeF1034WeP40<>QFP@0`Z1I1035XUh40<2MF`@0
`ieL1034WUl50<BNH0@0`imQ1035XfH40<f^KP@0bZQX1038YF440<JTG@@0bZEN1038XUL50<FOE0@0
aJ1@1033WTh40<FPDP@0`ii@1032WU840<BPE0@0_YY@1@2oVe440<BOF0@0aZ5J103;YUl40<NRF`@0
b:9G1034We4;0?ooo`002P3oool40;>>?P@0/Xdo102fTTH40;ZFBP@0^iM;1030W5050<2LCP@0^iM9
102iUT@40;ZGA@@0^iM3102gTcl40;NB@@@0_IQ71030W4P50<6MB@@0`Ye<1031W4/80;nJBPP0`ie<
1035W4X40<BKB@D0aI]71034VTH40<:J@`@0`9Q11031VD840<2H@@@0_YQ31032W4L50<2JA`@0_iU8
1031VT/40<6JC@@0a9iC1035We@80<>MDP@0aJ1B1@33WU080<BOC`@0a9m>1035X4l40<FOCP@0`ie<
1032W4L90<>MB0@0`Ya7102oVDH40;jHA`@0`ie<1037X5440<FPDP@0a9mA1033WU050;nJC0@0_IY9
102jUdH40;RC@PP0_YU9102oVDh40;nKC`D0`YeF1033WUL40<JQF`@0`9]E1036XE/40<jYI@@0a9mK
102mV5@40;jIE@D0`Y]J1034WUd40<NTI0@0cZa/1039YV840<ZXH@@0cJQQ103:YU`40<RSE@D0aj9D
1033WTh40<6LC0@0aj9B1034We440<:MC`@0`ieB2@2lV4h40<>OE@@0b:AJ103?ZF840<JPF@P0aIiC
2`3oool000X0oooo102cSSh40;:=?`@0]Y96102jUTX40;^GB`@0`9a@1@30W4h40;^GB@@0^II4102j
UdD40;^G@`@0]i<o102gTT440;fHA`@0`9a81@31WDT40<:MC0@0`Ia;202oVTX80<>MC0@0aIa:1034
VdT50<FKA`@0a9Y61032VT<40<2H@@@0`IU21030V4440;jH@`@0`Ya71@30VTL40;nIB0@0`IY;1031
VTd40<BND`@0aImD2033WE840<FPDPD0`ii@2034Wdl40<BOCP@0aJ1?1035Wdh40<>MC0@0`Ya72@33
WDP40<:LA`@0_iU6102nV4L40<>MC0@0aj1A1035X5840<BOD@@0`ii@1@2oVT`40;fJB@@0^YM6102h
Td880;jIB@@0_iU>102oVdl50<:MEP@0`iiG1036XE/40<2KE@@0aZ5K103>ZFD40<BOF`@0_IQD102n
VED50<:KFP@0a9iM1037Y6@40<j/K0@0bJIR103:Z6440<fXH@@0bZIL1038XeD50<NRE0@0`ii>1031
W4`40<NRDP@0a9mA1032WDl40<>MDPT0_9Q>1033WeD40<RTFP@0cjUR1036X5T80<FND`/0oooo000:
0?ooo`@0/hhn102bSCl40;JBAP@0^YI:102kUd/40<2LD0D0`9a>102kUdT40;VFA0@0^YM5102kUd<4
0;NC?`@0]i91102mV4L40<2LB0D0`Ie91032WD`40<6LB`P0_iY:2033WD`40<FLBP@0a9]91@35VdL4
0<BJAP@0`YY31030V4440<6I@P@0`9Q1102nV4<40<:LA`D0`9Y7102oVDP40<6JB`@0`IY=1034WU<4
0<FOE0P0`ieB1035X5850<>ND0P0a9m?1034Wdh40<FPC`@0aIm>1033WD`40<:LA`T0`ie81032W4L4
0;nIAP@0_YQ71033WD`40<NPD@@0aJ1B1034We440<>ND0D0_iY<102mVTT40;ZGAP@0^9=2202nVDT4
0;nICP@0_i]?1@32WEH40<>NE`@0aZ5K1030VeD40<JQF`@0cZUU1034We/40;fHE0@0_YUE1@32VeX4
0<BNG@@0ajAT103>[6`40<VVHP@0bZQQ103=Z6440<ZVG0@0b:=E1@37XU@40<>NCP@0`Ia<1037XU84
0<BOD@@0`Ye?1033WE890;bHCP@0`imE1038Y5X40<nYHP@0aZ1I2035WU<;0?ooo`002P3oool40;>>
?P@0/Xdo102fTTH40;ZFBP@0^iM;1030W5050<2LCP@0^iM9102iUT@40;ZGA@@0^iM3102gTcl40;NB
@@@0_IQ71030W4P50<6MB@@0`Ye<1031W4/80;nJBPP0`ie<1035W4X40<BKB@D0aI]71034VTH40<:J
@`@0`9Q11031VD840<2H@@@0_YQ31032W4L50<2JA`@0_iU81031VT/40<6JC@@0a9iC1035We@80<>M
DP@0aJ1B1@33WU080<BOC`@0a9m>1035X4l40<FOCP@0`ie<1032W4L90<>MB0@0`Ya7102oVDH40;jH
A`@0`ie<1037X5440<FPDP@0a9mA1033WU050;nJC0@0_IY9102jUdH40;RC@PP0_YU9102oVDh40;nK
C`D0`YeF1033WUL40<JQF`@0`9]E1036XE/40<jYI@@0a9mK102mV5@40;jIE@D0`Y]J1034WUd40<NT
I0@0cZa/1039YV840<ZXH@@0cJQQ103:YU`40<RSE@D0aj9D1033WTh40<6LC0@0aj9B1034We440<:M
C`@0`ieB2@2lV4h40<>OE@@0b:AJ103?ZF840<JPF@P0aIiC2`3oool000X0oooo102dScl40;F@@0@0
]Y94102jUTP80;fLC@D0^YU8102gUTD40;JF@`@0^IU6102lVDD40;ZG@`@0_9Q4102nVTH40;jIB0D0
_iY9102oW4/40<:OCP@0`9e<102nVdX40<2KB`@0`Ia<1034WT/40<>MBPD0aim:2034W4L40<>KAP@0
`iY81031V4H40<6KB0@0a9i;1@30VTL40;RB@@@0_9M61031W4h40<>ND0@0`ieB1036X5D40<BND`T0
`I]@1035X5840<^VF0@0aj9B1032WDd80<>MBP@0aIm:1036X4/50<NOBP@0aIe81034VdT40<>JBP@0
`I]:1034WDh40<RQE0@0a9e@1033WTh50;nJBP@0^YM5102hUD<40;^G@`P0_IQ7102lUdT40;bHC0D0
`YeF1036XEX80<RSG@@0bZEO1036XE/40;nJE0@0_YUC1030VeD50<6LEP@0`9]G1035X5`40<jXI`P0
d:]U103@[6840<fYG`@0b:AF1@33We440<:MC@@0_iY:1032WDd40<>ND0@0`Ye?1035We@40<FOEPD0
_YQ?1033We<40<RTF0@0cjUP1035WeH40<BLE0@0aIeE2`3oool000X0oooo102dScl40;F@@0@0]Y94
102jUTP80;fLC@D0^YU8102gUTD40;JF@`@0^IU6102lVDD40;ZG@`@0_9Q4102nVTH40;jIB0D0_iY9
102oW4/40<:OCP@0`9e<102nVdX40<2KB`@0`Ia<1034WT/40<>MBPD0aim:2034W4L40<>KAP@0`iY8
1031V4H40<6KB0@0a9i;1@30VTL40;RB@@@0_9M61031W4h40<>ND0@0`ieB1036X5D40<BND`T0`I]@
1035X5840<^VF0@0aj9B1032WDd80<>MBP@0aIm:1036X4/50<NOBP@0aIe81034VdT40<>JBP@0`I]:
1034WDh40<RQE0@0a9e@1033WTh50;nJBP@0^YM5102hUD<40;^G@`P0_IQ7102lUdT40;bHC0D0`YeF
1036XEX80<RSG@@0bZEO1036XE/40;nJE0@0_YUC1030VeD50<6LEP@0`9]G1035X5`40<jXI`P0d:]U
103@[6840<fYG`@0b:AF1@33We440<:MC@@0_iY:1032WDd40<>ND0@0`Ye?1035We@40<FOEPD0_YQ?
1033We<40<RTF0@0cjUP1035WeH40<BLE0@0aIeE2`3oool000X0oooo102dScl40;F@@0@0]Y94102j
UTP80;fLC@D0^YU8102gUTD40;JF@`@0^IU6102lVDD40;ZG@`@0_9Q4102nVTH40;jIB0D0_iY9102o
W4/40<:OCP@0`9e<102nVdX40<2KB`@0`Ia<1034WT/40<>MBPD0aim:2034W4L40<>KAP@0`iY81031
V4H40<6KB0@0a9i;1@30VTL40;RB@@@0_9M61031W4h40<>ND0@0`ieB1036X5D40<BND`T0`I]@1035
X5840<^VF0@0aj9B1032WDd80<>MBP@0aIm:1036X4/50<NOBP@0aIe81034VdT40<>JBP@0`I]:1034
WDh40<RQE0@0a9e@1033WTh50;nJBP@0^YM5102hUD<40;^G@`P0_IQ7102lUdT40;bHC0D0`YeF1036
XEX80<RSG@@0bZEO1036XE/40;nJE0@0_YUC1030VeD50<6LEP@0`9]G1035X5`40<jXI`P0d:]U103@
[6840<fYG`@0b:AF1@33We440<:MC@@0_iY:1032WDd40<>ND0@0`Ye?1035We@40<FOEPD0_YQ?1033
We<40<RTF0@0cjUP1035WeH40<BLE0@0aIeE2`3oool000X0oooo102dScl40;F@@0@0]Y94102jUTP8
0;fLC@D0^YU8102gUTD40;JF@`@0^IU6102lVDD40;ZG@`@0_9Q4102nVTH40;jIB0D0_iY9102oW4/4
0<:OCP@0`9e<102nVdX40<2KB`@0`Ia<1034WT/40<>MBPD0aim:2034W4L40<>KAP@0`iY81031V4H4
0<6KB0@0a9i;1@30VTL40;RB@@@0_9M61031W4h40<>ND0@0`ieB1036X5D40<BND`T0`I]@1035X584
0<^VF0@0aj9B1032WDd80<>MBP@0aIm:1036X4/50<NOBP@0aIe81034VdT40<>JBP@0`I]:1034WDh4
0<RQE0@0a9e@1033WTh50;nJBP@0^YM5102hUD<40;^G@`P0_IQ7102lUdT40;bHC0D0`YeF1036XEX8
0<RSG@@0bZEO1036XE/40;nJE0@0_YUC1030VeD50<6LEP@0`9]G1035X5`40<jXI`P0d:]U103@[684
0<fYG`@0b:AF1@33We440<:MC@@0_iY:1032WDd40<>ND0@0`Ye?1035We@40<FOEPD0_YQ?1033We<4
0<RTF0@0cjUP1035WeH40<BLE0@0aIeE2`3oool000X0oooo102aS3/40;B??P@0]I91102jUdH40<2O
CP@0^IQ71@2hUdH40;NFA@@0]iM4102jVTL40;bIA@@0_IY61031WDL40;fIA@@0]Y8n1@2mV4L40<6L
C0@0a9m?102oVdd40<2LCPP0`Ye=1030VTT40<BNC@D0c:=A1036WD/40<BKB`@0`iY:1035W4`40<BK
B`@0a9]91035W4X50<6KBP@0_IM6102oVTT40;nJBP@0a9m?1034We440<FOE0@0`YaA1030VDh50<6J
C`@0`Y]@1039XUL40<BMD0@0`IY=1030VTT40<>MC0@0b:9=1039Xdh50<VQC0@0aYi91035W4X40<>J
BP@0`I]:1034WDh40<jWFP@0aj1C1034Wdl50<6LC0@0^iQ4102jUd<40;bHA0@0_9M6102mV4L40;bG
B@@0_IU;1@2oVe440<BPEP@0aJ1I1036Y5`40<ZXH0@0`j5I1031WeL40<2NEP@0_9YB1@30VeD40<6L
EP@0b:=O1039Y6080<bWH@@0c:QN103:YU`40<JRE0D0a:1B1030WD`40;nLB`@0_YU91031W4h40;nJ
C0@0aZ1E103BZV850<NOE`@0`imA1037XeL40<nYGP@0b:9I1037WeT40<JNEP/0oooo000:0?ooo`@0
/H`k102dSch40;FB@@@0^YM61030Wdh40;VHA`D0^9M6102gUTD40;NGA0@0^YY7102lVDD40;fJAP@0
`Ie7102mVDD40;JB?PD0_IQ71031W4`40<BOC`@0_i]=1030W4h80<:MC@@0`9Y91034WTd50<bSD@@0
aYe;1034Vd/40<>JBP@0aIa<1034Vd/40<BKB@@0aIa:1@31VdX40;fGAP@0_iY9102oVTX40<BOC`@0
a9mA1035We@40<:LD@@0`9U>1@31VTl40<:KD0@0bJ9G1034WE040<6JC@@0`9Y91033WD`40<RRC@@0
bJ=>1@39XD`40<JNB@@0aIa:1033VTX40<6KBP@0a9e>103>YeX40<NPD`@0a9m?1@31W4`40;^HA0@0
^YM3102lV4@40;bGAP@0_IQ7102lUdT40;fIB`D0_i]A1034X5H40<FPF@@0aZAL103:Z6040<>QF@@0
`ImG1030WUH40;bJDPD0`9]E1031W5H40<RSG`@0bJAP203<Yf440<bXGP@0bZIL1036XU@50<BPDP@0
`9e<102oW4/40;jIB@@0`Ia>102oVT`40<JPE@@0dZYR1@37WeL40<>OD@@0aj=G103?ZEh40<RRF@@0
aimI1036WUH;0?ooo`002P3oool40;6<>`@0]8ln102eTT440;ZGAP@0`9m>102iV4L50;RGAP@0]iI5
102gUd@40;ZJA`@0_9U5102mVTH40<6MA`@0_IU5102fTSh50;fHA`@0`Ia<1034Wdl40;nKC@@0`9a>
2032WDd40<2JB@@0a9i=1@3<Xe440<JMB`@0a9];1033VTX40<FLC0@0a9];1034VdT40<FLBPD0`I]:
102mUdH40;nJB@@0_iY:1034Wdl40<BOD@@0aImD1032W5440<2ICPD0`IY?1032Ve040<VRE`@0a9e@
1031VTd40<2JB@@0`ie<1038XTd40<VSCPD0bJ5<1036WTT40<FLBP@0`iY:1031VdX40<BMCP@0cZMJ
1037X5<40<BOC`D0`Ia<102kV4@40;ZG@`@0_9Q4102lUdH40;fHA`@0_9M9102mVD/50;nKD@@0a:1F
1035X5T40<JTG0@0bZQP1033XET40<6OE`@0`9iF102lVU850<2KE@@0`IaF1038Xel40<VTH0P0c:MQ
103<Z5h40<ZVG0@0aZ9D1@34X5840<2MC0@0_ia;102nVDT40<6LCP@0_iY<1036X5D40=:ZHPD0aimG
1033We440<NSE`@0cjUN1038XUT40<NOF@@0aYiF2`3oool000X0oooo102aS3/40;B??P@0]I91102j
UdH40<2OCP@0^IQ71@2hUdH40;NFA@@0]iM4102jVTL40;bIA@@0_IY61031WDL40;fIA@@0]Y8n1@2m
V4L40<6LC0@0a9m?102oVdd40<2LCPP0`Ye=1030VTT40<BNC@D0c:=A1036WD/40<BKB`@0`iY:1035
W4`40<BKB`@0a9]91035W4X50<6KBP@0_IM6102oVTT40;nJBP@0a9m?1034We440<FOE0@0`YaA1030
VDh50<6JC`@0`Y]@1039XUL40<BMD0@0`IY=1030VTT40<>MC0@0b:9=1039Xdh50<VQC0@0aYi91035
W4X40<>JBP@0`I]:1034WDh40<jWFP@0aj1C1034Wdl50<6LC0@0^iQ4102jUd<40;bHA0@0_9M6102m
V4L40;bGB@@0_IU;1@2oVe440<BPEP@0aJ1I1036Y5`40<ZXH0@0`j5I1031WeL40<2NEP@0_9YB1@30
VeD40<6LEP@0b:=O1039Y6080<bWH@@0c:QN103:YU`40<JRE0D0a:1B1030WD`40;nLB`@0_YU91031
W4h40;nJC0@0aZ1E103BZV850<NOE`@0`imA1037XeL40<nYGP@0b:9I1037WeT40<JNEP/0oooo000:
0?ooo`@0/H`k102dSch40;FB@@@0^YM61030Wdh40;VHA`D0^9M6102gUTD40;NGA0@0^YY7102lVDD4
0;fJAP@0`Ie7102mVDD40;JB?PD0_IQ71031W4`40<BOC`@0_i]=1030W4h80<:MC@@0`9Y91034WTd5
0<bSD@@0aYe;1034Vd/40<>JBP@0aIa<1034Vd/40<BKB@@0aIa:1@31VdX40;fGAP@0_iY9102oVTX4
0<BOC`@0a9mA1035We@40<:LD@@0`9U>1@31VTl40<:KD0@0bJ9G1034WE040<6JC@@0`9Y91033WD`4
0<RRC@@0bJ=>1@39XD`40<JNB@@0aIa:1033VTX40<6KBP@0a9e>103>YeX40<NPD`@0a9m?1@31W4`4
0;^HA0@0^YM3102lV4@40;bGAP@0_IQ7102lUdT40;fIB`D0_i]A1034X5H40<FPF@@0aZAL103:Z604
0<>QF@@0`ImG1030WUH40;bJDPD0`9]E1031W5H40<RSG`@0bJAP203<Yf440<bXGP@0bZIL1036XU@5
0<BPDP@0`9e<102oW4/40;jIB@@0`Ia>102oVT`40<JPE@@0dZYR1@37WeL40<>OD@@0aj=G103?ZEh4
0<RRF@@0aimI1036WUH;0?ooo`002P3oool80;BA?@P0]I<l102fTS`40;RD?PD0^IE1102lV4@40;fJ
B0@0_9U7102nVdT40;fJB0@0`9a8102nVTH90;bH@P@0`9a81035X4l40<6LB`@0a9m?1031W4h40<:M
C`@0`imC1032WU850<:ND0@0`Ie?1034We440<2KC@@0`Y]<1039XU<40<BOCP@0`Ye<1@30VdX40<:M
C0@0_iY91030VdX40<>NC@@0bjIE1035X5040<:MC@T0a9e>1035WU440<NPD`@0`ia?102nUdP40<2J
B@@0`ie:1034WT/40<ZTD@D0aj5>1033WDX40<6LB`@0`Ye<1030WD/40<>PCPP0a:5@1034We450<:M
C`@0`IY=102lUDP40;^DA@@0^I93202kU4L40;fFB`D0`9Q@1034WUD40<BNE`@0aJ1J103?ZV@40<>Q
FP@0`Z1I102nW5D40;nMEPD0_YaE102oWEH40<2NEP@0a:9J1037YEd40<VWG`@0c:MP1038Xe`90<FO
EP@0a9iE1033WE@40<6KDP@0`9YA102jU4T40<VSF0@0dJ]P1@3;YEX40<bVF`@0bZAI103;YEX40<bV
F`@0bZAI1037XEH;0?ooo`002P3oool80;BA?@P0]I<l102fTS`40;RD?PD0^IE1102lV4@40;fJB0@0
_9U7102nVdT40;fJB0@0`9a8102nVTH90;bH@P@0`9a81035X4l40<6LB`@0a9m?1031W4h40<:MC`@0
`imC1032WU850<:ND0@0`Ie?1034We440<2KC@@0`Y]<1039XU<40<BOCP@0`Ye<1@30VdX40<:MC0@0
_iY91030VdX40<>NC@@0bjIE1035X5040<:MC@T0a9e>1035WU440<NPD`@0`ia?102nUdP40<2JB@@0
`ie:1034WT/40<ZTD@D0aj5>1033WDX40<6LB`@0`Ye<1030WD/40<>PCPP0a:5@1034We450<:MC`@0
`IY=102lUDP40;^DA@@0^I93202kU4L40;fFB`D0`9Q@1034WUD40<BNE`@0aJ1J103?ZV@40<>QFP@0
`Z1I102nW5D40;nMEPD0_YaE102oWEH40<2NEP@0a:9J1037YEd40<VWG`@0c:MP1038Xe`90<FOEP@0
a9iE1033WE@40<6KDP@0`9YA102jU4T40<VSF0@0dJ]P1@3;YEX40<bVF`@0bZAI103;YEX40<bVF`@0
bZAI1037XEH;0?ooo`002P3oool80;BA?@P0]I<l102fTS`40;RD?PD0^IE1102lV4@40;fJB0@0_9U7
102nVdT40;fJB0@0`9a8102nVTH90;bH@P@0`9a81035X4l40<6LB`@0a9m?1031W4h40<:MC`@0`imC
1032WU850<:ND0@0`Ie?1034We440<2KC@@0`Y]<1039XU<40<BOCP@0`Ye<1@30VdX40<:MC0@0_iY9
1030VdX40<>NC@@0bjIE1035X5040<:MC@T0a9e>1035WU440<NPD`@0`ia?102nUdP40<2JB@@0`ie:
1034WT/40<ZTD@D0aj5>1033WDX40<6LB`@0`Ye<1030WD/40<>PCPP0a:5@1034We450<:MC`@0`IY=
102lUDP40;^DA@@0^I93202kU4L40;fFB`D0`9Q@1034WUD40<BNE`@0aJ1J103?ZV@40<>QFP@0`Z1I
102nW5D40;nMEPD0_YaE102oWEH40<2NEP@0a:9J1037YEd40<VWG`@0c:MP1038Xe`90<FOEP@0a9iE
1033WE@40<6KDP@0`9YA102jU4T40<VSF0@0dJ]P1@3;YEX40<bVF`@0bZAI103;YEX40<bVF`@0bZAI
1037XEH;0?ooo`002P3oool80;BA?@P0]I<l102fTS`40;RD?PD0^IE1102lV4@40;fJB0@0_9U7102n
VdT40;fJB0@0`9a8102nVTH90;bH@P@0`9a81035X4l40<6LB`@0a9m?1031W4h40<:MC`@0`imC1032
WU850<:ND0@0`Ie?1034We440<2KC@@0`Y]<1039XU<40<BOCP@0`Ye<1@30VdX40<:MC0@0_iY91030
VdX40<>NC@@0bjIE1035X5040<:MC@T0a9e>1035WU440<NPD`@0`ia?102nUdP40<2JB@@0`ie:1034
WT/40<ZTD@D0aj5>1033WDX40<6LB`@0`Ye<1030WD/40<>PCPP0a:5@1034We450<:MC`@0`IY=102l
UDP40;^DA@@0^I93202kU4L40;fFB`D0`9Q@1034WUD40<BNE`@0aJ1J103?ZV@40<>QFP@0`Z1I102n
W5D40;nMEPD0_YaE102oWEH40<2NEP@0a:9J1037YEd40<VWG`@0c:MP1038Xe`90<FOEP@0a9iE1033
WE@40<6KDP@0`9YA102jU4T40<VSF0@0dJ]P1@3;YEX40<bVF`@0bZAI103;YEX40<bVF`@0bZAI1037
XEH;0?ooo`002P3oool40;ND@P@0]Y=1102fU3d40;JB?0@0]90j102fT3/50;RD@0@0_9Q4102kV4H4
0;bIA`@0^IU6102nVdT40<>PCP@0aZ5@1033X4`50;bIA@@0_YU8102oVTT40;jIB@@0_IQ8102oVT`4
0<6LCPP0`YiB2@31WE440<FQE@@0`imC1033WU040<:MC`P0`Ye<1@31W4/40<:MC0@0`Ia;1032WD`4
0<6LB``0`Ye<2@33WTh40<FNC`@0aYm@1033W4l40<:KC0@0`I]:1033WDX40<JMB`@0aIa:1@36WD/4
0<VPCP@0bJ=@1038XTl40<>NC@@0a9m>1032Wdd40<BQC`@0b:=C1@30Vd/40;jGBP@0^I95202gTD04
0;fDA@@0_I=7102lUDP50;nHC@P0a9iE1032X5P40<6OE`@0`J5F102nWU<40;nMD`@0_I]A1@2mW4l4
0<2ODP@0_ieC1033XEL80<NSF@@0b:AJ1037XeT=0<JPE`@0aj5H1032W5<40;jHC`@0]Hm61033WE@4
0<bVG@D0bJ=J103@ZV440<fWGP@0bZIL103;Yed40<bXGP@0bZIL2`3oool000X0oooo102gU4840;JC
@@@0]Y@m102fTS`40;B@>P@0]Y0k1@2hU4040;bHA0@0^iQ6102lVDL40;VIAP@0_Y]91033X4h40<JQ
D0@0`j1<1@2lVDD40;jIB0@0_iY9102nVDT40;fHB0@0_iY<1031W4h80<:NDPT0`IeA1035XED40<>O
D`@0`ii@1032WDl80<:MC0D0`Ia;1032WD`40<6LB`@0`Ye<1031W4/<0<:MC0T0`ii>1035WTl40<JO
D0@0`ia?1032Vd`40<6KBP@0`ie:1036WD/40<FLBPD0aYe;1039X4h40<VSD0@0b:9?1033WTd40<BO
CP@0`Ym=1034XDl40<RSD`D0`9];102nUdX40;VBA@P0]i50102mU4D40;fCA`@0_9E81@2oV4d80<BN
E@@0`Z1H1031WeL40<6QEP@0_YiC102oWE<40;fKD@D0_Ia?1030We840;nMD`@0`j5G2037XeT40<RT
FP@0aj=I3@36X5L40<NQF0@0`YaC102nV4l40;F?AP@0`ieD103<YUd50<VSFP@0d:YQ103=Yeh40<ZV
G0@0bjMM103<Z5h40<ZVG0/0oooo000:0?ooo`@0]iA2102fTd440;JD?@@0]Y8l102dT3X40;J@>`D0
^9A0102lV4@40;^HAP@0_9U7102iVDH40;jKB@@0`j1>1036XE040<>PC0D0_9U5102nVDP40;nJB@@0
_YU9102mV4P40;nJC0@0`Ia>2032WU890<6MD@@0aJ5E1033We<40<>ND0@0`Ye?2032WD`50<6LB`@0
`Ye<1031W4/40<:MC0@0`Ia;3032WD`90<>NCP@0aIi?1036We040<>LC`@0`Y]<1031VdX40<>MBP@0
aYe;1035W4X50<JMB`@0bJ1>1039Xe040<RRC`@0`ii=1034Wdh40<:OC@@0a:5?1038Xe<50<2KB`@0
_YM:102iTTD80;NA@0@0_IA5102mTdL40;bEB0D0_iQ=2034WUD40<:PF0@0`ImG1031XEH40;jND`@0
_ieC102mVe450;fLC`@0`9mB102oWE<40<>QE`P0aj=I1038Y5X40<NSF@d0aZ1G1037XEP40<:LD`@0
_YQ?102eSdH40<>ME0@0c:IM1@39XeX40=2ZH@@0cJMN103:YU`40<^WG@@0c:QN103:YU`;0?ooo`00
2P3oool40;ND@P@0]Y=1102fU3d40;JB?0@0]90j102fT3/50;RD@0@0_9Q4102kV4H40;bIA`@0^IU6
102nVdT40<>PCP@0aZ5@1033X4`50;bIA@@0_YU8102oVTT40;jIB@@0_IQ8102oVT`40<6LCPP0`YiB
2@31WE440<FQE@@0`imC1033WU040<:MC`P0`Ye<1@31W4/40<:MC0@0`Ia;1032WD`40<6LB``0`Ye<
2@33WTh40<FNC`@0aYm@1033W4l40<:KC0@0`I]:1033WDX40<JMB`@0aIa:1@36WD/40<VPCP@0bJ=@
1038XTl40<>NC@@0a9m>1032Wdd40<BQC`@0b:=C1@30Vd/40;jGBP@0^I95202gTD040;fDA@@0_I=7
102lUDP50;nHC@P0a9iE1032X5P40<6OE`@0`J5F102nWU<40;nMD`@0_I]A1@2mW4l40<2ODP@0_ieC
1033XEL80<NSF@@0b:AJ1037XeT=0<JPE`@0aj5H1032W5<40;jHC`@0]Hm61033WE@40<bVG@D0bJ=J
103@ZV440<fWGP@0bZIL103;Yed40<bXGP@0bZIL2`3oool000X0oooo102kUTD40;VD@`@0^9@n102g
Tcd80;F@>0D0]Hlj102iUD440;^HA0@0^i]8102fUdD40;VJB0@0`J1A1035Y5D40<6NC0D0_IY8102n
VdT40;^HAP@0_9M6102jUD@40;jIB@@0`9]=1031WDl40<BPE0D0`imE1032WU@40<:NDP@0`9a@1031
W4h40;fHBPP0`Ia<1@30Vd/40<6LC0@0`Ye<1035X4l40<>NC@@0`Ye<1031W4/40<2KBP@0`9];1@32
WDd40<RSD`@0bJAD1034Wdl40<BMCP@0aIm>1036WDd40<JMB`@0`iY81@37WDT40<RNBP@0aYi91034
W4L40;nIA0@0^98m102oVdL40<>OB`@0aj9A1@2oVTT40;bGA`@0]Xm0102eSc`40;F<>P@0^Y51102o
UTL40<2IBPD0`IY=1032WU840<6MD@@0`9iD1032X5H40;nND@@0`9mB102mW4/40;^JB@D0a:5?1034
XE040;jKBP@0`Ie?1034X5@40<FQE@P0aj=G1035XEL50<BPEP@0aZ1I103<YUl40<>MEP@0_9I?102o
Ue440<BLEP@0aIeG1@39XE/40<VUF`@0b:AJ1039YE/40<bXGP@0c:YP1039Yed;0?ooo`002P3oool4
0;^FA@@0^IA3102hU3h40;NC?@P0]I0h1@2eScX40;VE@@@0^iQ4102kVdP40;JGA@@0^IY81031X544
0<FTE@@0`Ii<1@2mVTP40;jKB@@0^iQ6102lUdH40;ZEA0@0_YU91030Vdd40<6MC`@0a:1D1@33WeD4
0<:NE0@0`YiB1030W5040<6LCP@0_IQ:2031W4`50<2KB`@0`Ia<1032WD`40<FPC`@0`ii=1032WD`4
0<6LB`@0`9]:1030Vd/50<:MC@@0b:=C1039Y5@40<BOC`@0a9e>1035Wdh40<JMC@@0aYe;1033VTP5
0<NMB@@0b9i:1036WTT40<BLA`@0_iU4102hTSd40;nKA`@0`im;1037XU450;nJB@@0_9M7102fSd04
0;F??0@0]H`j102jTD440;nFA`@0`9U:1@31VTd40<:NDP@0`IeA1030WU@40<:PEP@0_iiA1030We84
0;fLB`@0^iY91@34XDl40<BQD0@0_Y]:1031WDl40<BPE0@0aJ5E2037XeL40<FQE`D0a:1F1036X5T4
0<bVG`@0`ieF102lUTl40;nGD@@0a9aF1035WEL50<VQF`@0bJEK1038Y5X40<VUF`@0c:QN103<ZV04
0<VWG@/0oooo000:0?ooo`@0^iI5102iU4<40;RD?P@0]i<m202eT3P50;F?>P@0^IE1102kV4@40;^K
B0@0]YM5102iVTP40<6PD@@0aJAE1031WT`50;fJB0@0_Y]9102kV4H40;bGAP@0^YE4102nVDT40<2K
C@@0`Ie?1034X5@50<>OE@@0`YiD1032WU840<2LD0@0`Ia>102mV4X80<6LC0D0`9];1031W4`40<:M
C0@0aJ1?1033WTd40<:MC0@0`Ia;1030VdX40<2KB`D0`Ye=1038Xe<40<VTE0@0a9m?1034WDh40<FO
CP@0aYe=1036WD/40<>JB0D0aie91038WTX40<JNB@@0a9a7102oVD@40;RB?@@0_i]71033Wd/40<NR
D@D0_iY9102lUdL40;J?@0@0]Hll102eS3X40;ZA@@@0_iI71030VDX50<6JC@@0`YiB1031WE440<2N
E0@0`Z1F102oWU440<2ODP@0_Ia;102kVTT50<BQC`@0a:5@102nVdX40<6MC`@0a:1D1035XED80<NS
E`@0aJ5G1@34X5H40<JPF@@0c:IO1033WEH40;bFC`@0_iMA1034W5H40<FME`D0bJ5K1039YE/40<RT
FP@0bJEK103<Z5h40<bZH0@0bJMM2`3oool000X0oooo102kUTD40;VD@`@0^9@n102gTcd80;F@>0D0
]Hlj102iUD440;^HA0@0^i]8102fUdD40;VJB0@0`J1A1035Y5D40<6NC0D0_IY8102nVdT40;^HAP@0
_9M6102jUD@40;jIB@@0`9]=1031WDl40<BPE0D0`imE1032WU@40<:NDP@0`9a@1031W4h40;fHBPP0
`Ia<1@30Vd/40<6LC0@0`Ye<1035X4l40<>NC@@0`Ye<1031W4/40<2KBP@0`9];1@32WDd40<RSD`@0
bJAD1034Wdl40<BMCP@0aIm>1036WDd40<JMB`@0`iY81@37WDT40<RNBP@0aYi91034W4L40;nIA0@0
^98m102oVdL40<>OB`@0aj9A1@2oVTT40;bGA`@0]Xm0102eSc`40;F<>P@0^Y51102oUTL40<2IBPD0
`IY=1032WU840<6MD@@0`9iD1032X5H40;nND@@0`9mB102mW4/40;^JB@D0a:5?1034XE040;jKBP@0
`Ie?1034X5@40<FQE@P0aj=G1035XEL50<BPEP@0aZ1I103<YUl40<>MEP@0_9I?102oUe440<BLEP@0
aIeG1@39XE/40<VUF`@0b:AJ1039YE/40<bXGP@0c:YP1039Yed;0?ooo`002P3oool40;fHA`@0^YE4
102jU3l40;VC?PP0^90i1@2bSCD40;^G@@@0_ie6102kVdP40;FF@`@0^IY:1031X5440<2OD0@0_9]:
1@2kVdP40;jKA`@0_9U5102kUd<40;bHA0@0_YU8102oVTX40;nLB`@0_i]=1@2oVdl40<:NDP@0a:1D
1032WU840<JQD`@0`ii@1034WDh40<:KC0D0_iY:1031W4`40<>NC@P0a9m>1033WTd40;bIA`@0_IY8
1030WD`50<BQD0P0bZEE1036XE<40<NPD`@0aj5@1038Wdl40<ROC@@0aYe;1@3:X4`40<VOB`@0`iU3
1030UT040;fE?P@0^I4j102hTSd40;nIA0@0aj=?1@2oVdL40;bGAP@0]I0o102eScX40:n9=0@0/X`i
102kUD@40<6LB`D0`Ia>102oVdd40;nKC`@0`J1C1030We840<2OCP@0`Ym>1030WDT40<FQC@D0a9i9
1033WDX40<2KBP@0`9];1030Vdd40<>ND0P0aJ5E2@35XEL40<NQF0@0b:9I1036X5L40<BLE0@0aYmD
1036W5840<RNE0D0aj1E1036X5D40<JREP@0b:AH103;Ye/40<ZXGP@0b:IL2`3oool000X0oooo102m
V4L40;ZEA0@0^Y@o102iTch80;R@>@D0/Xde102kUd440;nMAP@0^i]8102eUT<40;VJBP@0`J1A1030
We040;bKBPD0^i]8102nVdL40;bIA@@0^iM3102lV4@40;jIB0@0_iY:102oW4/40;nKC@D0_i]?1032
WU840<BPE0@0`YiB1036XE<40<>ND0@0a9e>1032Vd`50;nJBP@0`Ia<1033WTd80<BOCP@0`ii=102l
VDL40;fJB0@0`9e<1@34XE080<ZUE@@0aZ5C1037X5<40<NQD0@0b9m?1038Wdd40<JMB`D0bZ1<1039
Wd/40<>I@`@0`9I0102mUCh40;VA>P@0^98m102oVD@40<NSC`D0_i]7102lUdH40;F@?`@0]Hlj102_
RC@40;:<>@@0^iE41031W4/50<6LCP@0_i]=102oVdl40<6PD`@0`9mB1030Wdh40<:OCP@0`9e91035
XDd50<BNB@@0`ie:1030VdX40<2KB`@0`9]=1033WU080<FQE@T0aJ5G1037XEP40<RRF@@0aZ1G1034
W5@40<JOE0@0aYaB1038WU@50<NPE@@0aZ1E1036XUH40<RTF0@0bjMK103:Z5h40<RVG0/0oooo000:
0?ooo`@0_IQ7102jUD@40;ZD?`@0^I<n202hT3T50;:==@@0^iM1102oWDH40;^KB0@0]II3102iVTX4
0<6PD@@0`9m@102lVdX50;^KB0@0_Y]7102lVDD40;^G@`@0_9Q4102nVDP40;nJBP@0_ia;102oVdd5
0;nKC`@0`YiB1034X5@40<:NDP@0aZ5C1033WU040<BMCP@0`Y]<1@2oVTX40<6LC0@0`ii=2034Wdh4
0<>NC@@0_9U7102mVTP40<2MC0D0a:5@203:YED40<JQD`@0aj1C1037XE040<ROC`@0b9m=1036WD/5
0<ZPC0@0bIm;1033VD<40<2F@0@0_IDn102iTCX40;RB?@@0_iU41037Xdl50;nKA`@0_9M6102eT3l4
0;F?>P@0[hTd102bS3T40;^EA0@0`Ia;1@31W4h40;nKC@@0_i]?1031X5<40<2ODP@0`9m>1032Wdh4
0<2MB@@0aJ5=1@34WTT40<>MBP@0`9]:1030Vd/40<2KC@@0`ii@2035XED90<FQE`@0aj5H1038XUT4
0<JPE`@0a9aD1036We@40<JLDP@0b9iD1@37X5D40<JPE@@0aZ9F1038Y5P40<^WF`@0bZQN1038YU`;
0?ooo`002P3oool40;fHA`@0^YE4102jU3l40;VC?PP0^90i1@2bSCD40;^G@@@0_ie6102kVdP40;FF
@`@0^IY:1031X5440<2OD0@0_9]:1@2kVdP40;jKA`@0_9U5102kUd<40;bHA0@0_YU8102oVTX40;nL
B`@0_i]=1@2oVdl40<:NDP@0a:1D1032WU840<JQD`@0`ii@1034WDh40<:KC0D0_iY:1031W4`40<>N
C@P0a9m>1033WTd40;bIA`@0_IY81030WD`50<BQD0P0bZEE1036XE<40<NPD`@0aj5@1038Wdl40<RO
C@@0aYe;1@3:X4`40<VOB`@0`iU31030UT040;fE?P@0^I4j102hTSd40;nIA0@0aj=?1@2oVdL40;bG
AP@0]I0o102eScX40:n9=0@0/X`i102kUD@40<6LB`D0`Ia>102oVdd40;nKC`@0`J1C1030We840<2O
CP@0`Ym>1030WDT40<FQC@D0a9i91033WDX40<2KBP@0`9];1030Vdd40<>ND0P0aJ5E2@35XEL40<NQ
F0@0b:9I1036X5L40<BLE0@0aYmD1036W5840<RNE0D0aj1E1036X5D40<JREP@0b:AH103;Ye/40<ZX
GP@0b:IL2`3oool000X0oooo102mV4L40;bGAP@0_IM2102kUD040;ZB>`@0^I4j1@2iTch40;VE?`@0
_IY6102nWT/40;VJA`@0]YM7102nWDh40<>RD`@0`9e;1@2mVTH40;bHA0@0_IU5102mVD<40;jJA0P0
_i]71030VdX40<6LB`D0`Ym>1034XE040<:MC@@0_YU91034Wdl40<JQD@@0aIi?1033W4d50<:KC0@0
`ia=1033WTd80<:MC0@0`Ia;202lUdH40<:MC@D0aZ5A1038XeD40<VTEP@0aj9D1038XE@40<RQDP@0
bj9C103;XU840<VPD0D0bZ5?103<Xe440<FMB0@0`9Q3102iTCX40:f5;P@0/8Pa102eSCH40;VD?0D0
_IQ0102kUd440;JB?0@0/Xhf102]RC440:n;=@@0]I4m102kUTD50;^FB0@0_IU;102oVdl40<:NDP@0
`9a@1033WTh40<:KC0@0a9i;1036WD/50<NMB@@0aYa:102nUdP40;nHB`@0`9]=1032WDl40<:NDP@0
a:1D1036XUP90<NSF@@0aZ9H2038XUL40<NPD`@0a9e@1038We050<BMCP@0a9mA1035XE<40<NSE`@0
bJEI103;Yed40<ZVG0/0oooo000:0?ooo`@0_IQ7102lUdH40;fG@P@0^iE0102jTS/40;VA>PD0^I<n
102iUCl40;fJAP@0_Yi;102iVTL40;JGA`@0_Ye>1033XU<40<2MB`D0_IY6102lV4@40;fIA@@0_IU3
102nVT@80;nKA`@0`9]:1031W4/50<:OCP@0a:5@1032WDd40;jIB@@0a9m?1036XE440<FNC`@0`ia=
1@32Vd`40<>LC@@0`ii=2032WD`40<6LB`P0_9M61032WDd50<JQD@@0b:=E1039Y5H40<NRE0@0b:5D
1038XE840<^RD`@0bj9B1039X5050<ZQC`@0c:=A1035WDP40<2H@`@0^I4j102]QBh40;28<@@0]Hdf
102iU3`50;fH@0@0^iM1102fTS`40;:>=P@0[HTa102_RcD40;FA?@@0^iI51@2kUTP40;fIB`@0_i]?
1032WU840<2LD0@0`ii>1032Vd`40<BNB`@0aYe;1@37WDT40<JLBP@0_YM8102oV4/40<2KC@@0`Ye?
1032WU840<BPE0@0aZ9H2@37XeT40<JRF0P0b:9G1037X5<40<BMD0@0b9m@1@34WDh40<BOD@@0aJ5C
1037XeL40<VUF@@0bjMM103:YU`;0?ooo`002P3oool40;fHA`@0_9M6102mUd840;^E@0@0^Y8k102i
TCX50;VC?P@0^IDo102mVTH40;jNB`@0^IY7102fUdL40;jMCP@0`j9C1030WD/50;fJAP@0_9Q4102m
VDD40;fI@`@0_YY4202oVdL40<2KBP@0`Ia;1@32Wdh40<BQD0@0`Ye=102nVDT40<BOC`@0aZ5A1035
WTl40<>LC@D0`Y]<1033W4d40<>NC@P0`Ye<1031W4/80;bGAP@0`Ye=1@36XE440<RSE@@0bJAF1037
XU@40<RQE0@0b:5B103;XU<40<^RDP@0bJ1@1@3:XDl40<bSD@@0aIe81030V4<40;VA>P@0[HD^102`
R3440;F==P@0^I@l1@2mV4040;^G@@@0]Y8l102bSSH40:f9<@@0[h/e102eTCd40;^FA@D0^iI8102m
VD/40;nKC`@0`YiB1030W5040<>NCP@0`Y]<1034WT/40<JMB`D0aie91036W4X40;jGB0@0_iQ;1030
Vdd40<:MC`@0`YiB1034X5@40<JRF0T0aj=I1036XUP80<RRE`@0aj1C1034WE040<ROD0D0a9e>1034
We440<FQD`@0aj=G1039YET40<^WG@@0bZIL2`3oool000X0oooo102mV4L40;bGAP@0_IM2102kUD04
0;ZB>`@0^I4j1@2iTch40;VE?`@0_IY6102nWT/40;VJA`@0]YM7102nWDh40<>RD`@0`9e;1@2mVTH4
0;bHA0@0_IU5102mVD<40;jJA0P0_i]71030VdX40<6LB`D0`Ym>1034XE040<:MC@@0_YU91034Wdl4
0<JQD@@0aIi?1033W4d50<:KC0@0`ia=1033WTd80<:MC0@0`Ia;202lUdH40<:MC@D0aZ5A1038XeD4
0<VTEP@0aj9D1038XE@40<RQDP@0bj9C103;XU840<VPD0D0bZ5?103<Xe440<FMB0@0`9Q3102iTCX4
0:f5;P@0/8Pa102eSCH40;VD?0D0_IQ0102kUd440;JB?0@0/Xhf102]RC440:n;=@@0]I4m102kUTD5
0;^FB0@0_IU;102oVdl40<:NDP@0`9a@1033WTh40<:KC0@0a9i;1036WD/50<NMB@@0aYa:102nUdP4
0;nHB`@0`9]=1032WDl40<:NDP@0a:1D1036XUP90<NSF@@0aZ9H2038XUL40<NPD`@0a9e@1038We05
0<BMCP@0a9mA1035XE<40<NSE`@0bJEI103;Yed40<ZVG0/0oooo000:0?ooo`P0_YU8102oVdL40;jH
A@@0^YA1102jTCl50;NA?P@0^YA1102lVDD40;^HAP@0^IU6102iV4L40<:ND0@0`j1?1030WD/50;fJ
AP@0_IU5102kUd<80;nKA`@0`Yi:1031WDT=0;jKA`@0_ia81032WTX40<6MB@@0aZ1?1033WD`40<:L
B`@0`ie<1@34WTd40<6KBP@0`Ya;2033WD`40<6KBP@0`9];102nVDT40<>LC`D0aj1C1038XEH40<ZS
F0@0bZ9J1039XET40<bRF0@0cJ=I103<YEX40<fVF`D0bZ=F1039XUD40<>LC@@0_iQ9102mU4840;ZA
?`P0]8`g102dScL50;F@>0@0]94g102cT3H40:n=<`@0[X`c102`S3@40;:>>P@0]Y8n1@2hTd<40;bG
B@@0_IM<102nVU040<>OE@@0`YaA1035WU<40<FND@@0aieA1@3:We040<BIB`@0^iA71030VDh40<BN
E@@0`ieD1032W5D40<FOF0@0aj9K1@38Xe`40<NRF`@0bJAM2038XUL40<NPD`@0aYmB1032Vd`50;nH
B@@0_YU91032WDl40<JQD`@0bJ=H103;YE`40<VSFP/0oooo000:0?ooo`P0_YU8102oVdL40;jHA@@0
^YA1102jTCl50;NA?P@0^YA1102lVDD40;^HAP@0^IU6102iV4L40<:ND0@0`j1?1030WD/50;fJAP@0
_IU5102kUd<80;nKA`@0`Yi:1031WDT=0;jKA`@0_ia81032WTX40<6MB@@0aZ1?1033WD`40<:LB`@0
`ie<1@34WTd40<6KBP@0`Ya;2033WD`40<6KBP@0`9];102nVDT40<>LC`D0aj1C1038XEH40<ZSF0@0
bZ9J1039XET40<bRF0@0cJ=I103<YEX40<fVF`D0bZ=F1039XUD40<>LC@@0_iQ9102mU4840;ZA?`P0
]8`g102dScL50;F@>0@0]94g102cT3H40:n=<`@0[X`c102`S3@40;:>>P@0]Y8n1@2hTd<40;bGB@@0
_IM<102nVU040<>OE@@0`YaA1035WU<40<FND@@0aieA1@3:We040<BIB`@0^iA71030VDh40<BNE@@0
`ieD1032W5D40<FOF0@0aj9K1@38Xe`40<NRF`@0bJAM2038XUL40<NPD`@0aYmB1032Vd`50;nHB@@0
_YU91032WDl40<JQD`@0bJ=H103;YE`40<VSFP/0oooo000:0?ooo`P0_YU8102oVdL40;jHA@@0^YA1
102jTCl50;NA?P@0^YA1102lVDD40;^HAP@0^IU6102iV4L40<:ND0@0`j1?1030WD/50;fJAP@0_IU5
102kUd<80;nKA`@0`Yi:1031WDT=0;jKA`@0_ia81032WTX40<6MB@@0aZ1?1033WD`40<:LB`@0`ie<
1@34WTd40<6KBP@0`Ya;2033WD`40<6KBP@0`9];102nVDT40<>LC`D0aj1C1038XEH40<ZSF0@0bZ9J
1039XET40<bRF0@0cJ=I103<YEX40<fVF`D0bZ=F1039XUD40<>LC@@0_iQ9102mU4840;ZA?`P0]8`g
102dScL50;F@>0@0]94g102cT3H40:n=<`@0[X`c102`S3@40;:>>P@0]Y8n1@2hTd<40;bGB@@0_IM<
102nVU040<>OE@@0`YaA1035WU<40<FND@@0aieA1@3:We040<BIB`@0^iA71030VDh40<BNE@@0`ieD
1032W5D40<FOF0@0aj9K1@38Xe`40<NRF`@0bJAM2038XUL40<NPD`@0aYmB1032Vd`50;nHB@@0_YU9
1032WDl40<JQD`@0bJ=H103;YE`40<VSFP/0oooo000:0?ooo`P0_YU8102oVdL40;jHA@@0^YA1102j
TCl50;NA?P@0^YA1102lVDD40;^HAP@0^IU6102iV4L40<:ND0@0`j1?1030WD/50;fJAP@0_IU5102k
Ud<80;nKA`@0`Yi:1031WDT=0;jKA`@0_ia81032WTX40<6MB@@0aZ1?1033WD`40<:LB`@0`ie<1@34
WTd40<6KBP@0`Ya;2033WD`40<6KBP@0`9];102nVDT40<>LC`D0aj1C1038XEH40<ZSF0@0bZ9J1039
XET40<bRF0@0cJ=I103<YEX40<fVF`D0bZ=F1039XUD40<>LC@@0_iQ9102mU4840;ZA?`P0]8`g102d
ScL50;F@>0@0]94g102cT3H40:n=<`@0[X`c102`S3@40;:>>P@0]Y8n1@2hTd<40;bGB@@0_IM<102n
VU040<>OE@@0`YaA1035WU<40<FND@@0aieA1@3:We040<BIB`@0^iA71030VDh40<BNE@@0`ieD1032
W5D40<FOF0@0aj9K1@38Xe`40<NRF`@0bJAM2038XUL40<NPD`@0aYmB1032Vd`50;nHB@@0_YU91032
WDl40<JQD`@0bJ=H103;YE`40<VSFP/0oooo000:0?ooo`@0_IU5102nVDP80<2KB`@0_II7102kU4D5
0;NA@0@0^991102fTcl40;RE@@@0^YM5102kV4H40<2KBP@0`Ye<102oVdL50;nJB@@0_YQ7102mUTL4
0<6JC@@0`Y]>2034Wdl40<6NBP@0`9e91@31WDL40<2LAPP0`I]81036WDd40<FLC0@0`iY82@34VdT4
0<:IA`P0`I]81033WD`40<:LB`@0`IY;1033W4d40<NPD`D0b:5F1039WeD40<ZPF0@0c:5L103?Y5l8
0<fUH0@0cjQS103BZfH50<fVH@@0b:5L1035WeP40<6KE0@0_iQ=102iTTD40;ZA@P@0]hhn102`RSD5
0;:<=`@0/H`c102cSSD40;2=<@@0[h`b102`Rc840;6;=P@0]Y0m1@2gT4440;VBA@@0^I59102mUdh4
0;nIDP@0`YaE1034WUL40<JNEP@0cjMO1@3;XET40;nEC@@0_iM?1031VE480<>MEP@0`IYE1034WEP4
0<VRG`D0c:ER1038Xel40<JQG@@0aj9K1039Y5d40<ZTF`@0aImF1032WDl50;^FB0@0_iQ;1032Ve04
0<BMDP@0aYiF2037XEX;0?ooo`002P3oool40;fIA@@0_YU82030Vd/40;fFA`@0^iA51@2gTD040;RB
@@@0]Y<o102hUD440;ZGA@@0^iQ61030VdX40<:MC0@0_i]71@2oVTT40;jHA`@0_II71031VTd40<:K
CPP0a9m?1031WTX40<2MB@D0`Ie71030W4H80<6KB0@0aYe=1035W4`40<>JB0T0a9]91032VDL80<6K
B0@0`ie<1032W4/40<6JB`@0`ia=1037X5<50<RQEP@0bImE103:X5P40<bQG0@0cjAO203=YF040<nX
H`@0dZ]V1@3=YV440<RQG0@0aImH1031Ve@40;nHC@@0^I95102jTD840;N>?P@0/8Xe1@2bS3L40;6<
<`@0/hhe102`SC440:n<<P@0/8/b102aRcH40;J@?@D0]i11102iTTD40;VAB@@0_IM>102oVE840<:L
E@@0a9iG1036WUH40<nWG`D0bj5I102oUDd40;nGC`@0`IUA2033WEH40<6JE@@0a9eH1039XUl50<bU
HP@0b:=O1036XEd40<NRF`@0bJAM103:Y5/40<FOEP@0`Ye?1@2kUTP40;nHB`@0`Y]@1034WE840<JN
EPP0aj5J2`3oool000X0oooo102mVDD40;jIB0P0`9];102mUTL40;^DA@D0]i50102hTT440;JC?`@0
^9E1102jUdD40;^HAP@0`9]:1032WD`40;nKA`D0_iY9102nV4L40;fFA`@0`IY=1032Vdh80<BOC`@0
`Ii:1030WDT50<6MA`@0`9a62031VdP40<JMC@@0aIa<1033VTP90<BKB@@0`YU72031VdP40<>MC0@0
`Ya;1031VT/40<>LC@@0aj1C1@38XEH40<VOE@@0bZ1H103<XE`40<nTG`P0cJEP103?Z6<40=:[IPD0
cJIQ1038XE`40<FOF0@0`I]D102oV4d40;VBA@@0^Y52102gSSh40;2:=@D0/X`g102aS3<40;>>=@@0
/8da102_S3840;2;<P@0/H/f102fT3d50;N@@@@0^I95102iTDT40;fGCP@0_iUB1032W5D40<BNE`@0
aYiF103?Yel50<^QF@@0_iE=102oUdl40<6ID@P0`ieF1031VUD40<BMF0@0bJ9O1@3<YF840<RSG`@0
aZ5M1037XU/40<VTG@@0bZAK1035WeH40<:MC`D0^iI8102oV4/40<:KD0@0a9eB1036WUH80<NQFP/0
oooo000:0?ooo`@0_IU5102nVDP80<2KB`@0_II7102kU4D50;NA@0@0^991102fTcl40;RE@@@0^YM5
102kV4H40<2KBP@0`Ye<102oVdL50;nJB@@0_YQ7102mUTL40<6JC@@0`Y]>2034Wdl40<6NBP@0`9e9
1@31WDL40<2LAPP0`I]81036WDd40<FLC0@0`iY82@34VdT40<:IA`P0`I]81033WD`40<:LB`@0`IY;
1033W4d40<NPD`D0b:5F1039WeD40<ZPF0@0c:5L103?Y5l80<fUH0@0cjQS103BZfH50<fVH@@0b:5L
1035WeP40<6KE0@0_iQ=102iTTD40;ZA@P@0]hhn102`RSD50;:<=`@0/H`c102cSSD40;2=<@@0[h`b
102`Rc840;6;=P@0]Y0m1@2gT4440;VBA@@0^I59102mUdh40;nIDP@0`YaE1034WUL40<JNEP@0cjMO
1@3;XET40;nEC@@0_iM?1031VE480<>MEP@0`IYE1034WEP40<VRG`D0c:ER1038Xel40<JQG@@0aj9K
1039Y5d40<ZTF`@0aImF1032WDl50;^FB0@0_iQ;1032Ve040<BMDP@0aYiF2037XEX;0?ooo`002P3o
ool40;bHA0@0^iI5102mVTP40<2KB`@0_YU;102mUTT50;^DA@@0^I93102dTCd40;RE@@@0^YM3102l
V4@40;jJAP@0`ie:1034WTd50<2IBP@0^I93102oV4d40<2ICP@0`i]C1033WU040<NRE0@0ajAB1033
X4h50<:NB0@0`I]61030VTL40<2GA@@0`iQ91035VT/40<ROCA40aYe;1033VTP40<BKB@@0a9];1032
VDT40<FKC`@0b9iB1@38WUH40<^QF@@0c:5L103=X5d40=2SH0@0cjIT103AZ6H40=B]K0@0dZ]Z1@3;
YFH40<NQHP@0b:9Q1031VeX40<2IE0@0^iE>102fSd@40;:;?0@0/X`k1@2aRcH40:n:<P@0/H`c102b
SC840:j9<0@0[hL_102aRC@40;J=>`D0]H`m102eST440;R@B0@0_IM>102nV5480<6LEP@0aIiK1037
X5d50=6ZI@@0aIiI1033VeD40<2HDP@0`IUD1035W5X40<FNF`@0a9eL1037Wf450<ZRI0@0b:9S1039
Xf@40<VTH0@0b:=O103B[FL40<FPFP@0`YeF1@34WUL40<6KDP@0`i]C1033VeD40<JNF0@0aj1K1036
WeX;0?ooo`002P3oool40;bHA0@0^iI5102mVTP40<2KB`@0_YU;102mUTT50;^DA@@0^I93102dTCd4
0;RE@@@0^YM3102lV4@40;jJAP@0`ie:1034WTd50<2IBP@0^I93102oV4d40<2ICP@0`i]C1033WU04
0<NRE0@0ajAB1033X4h50<:NB0@0`I]61030VTL40<2GA@@0`iQ91035VT/40<ROCA40aYe;1033VTP4
0<BKB@@0a9];1032VDT40<FKC`@0b9iB1@38WUH40<^QF@@0c:5L103=X5d40=2SH0@0cjIT103AZ6H4
0=B]K0@0dZ]Z1@3;YFH40<NQHP@0b:9Q1031VeX40<2IE0@0^iE>102fSd@40;:;?0@0/X`k1@2aRcH4
0:n:<P@0/H`c102bSC840:j9<0@0[hL_102aRC@40;J=>`D0]H`m102eST440;R@B0@0_IM>102nV548
0<6LEP@0aIiK1037X5d50=6ZI@@0aIiI1033VeD40<2HDP@0`IUD1035W5X40<FNF`@0a9eL1037Wf45
0<ZRI0@0b:9S1039Xf@40<VTH0@0b:=O103B[FL40<FPFP@0`YeF1@34WUL40<6KDP@0`i]C1033VeD4
0<JNF0@0aj1K1036WeX;0?ooo`002P3oool40;bHA0@0^iI5102mVTP40<2KB`@0_YU;102mUTT50;^D
A@@0^I93102dTCd40;RE@@@0^YM3102lV4@40;jJAP@0`ie:1034WTd50<2IBP@0^I93102oV4d40<2I
CP@0`i]C1033WU040<NRE0@0ajAB1033X4h50<:NB0@0`I]61030VTL40<2GA@@0`iQ91035VT/40<RO
CA40aYe;1033VTP40<BKB@@0a9];1032VDT40<FKC`@0b9iB1@38WUH40<^QF@@0c:5L103=X5d40=2S
H0@0cjIT103AZ6H40=B]K0@0dZ]Z1@3;YFH40<NQHP@0b:9Q1031VeX40<2IE0@0^iE>102fSd@40;:;
?0@0/X`k1@2aRcH40:n:<P@0/H`c102bSC840:j9<0@0[hL_102aRC@40;J=>`D0]H`m102eST440;R@
B0@0_IM>102nV5480<6LEP@0aIiK1037X5d50=6ZI@@0aIiI1033VeD40<2HDP@0`IUD1035W5X40<FN
F`@0a9eL1037Wf450<ZRI0@0b:9S1039Xf@40<VTH0@0b:=O103B[FL40<FPFP@0`YeF1@34WUL40<6K
DP@0`i]C1033VeD40<JNF0@0aj1K1036WeX;0?ooo`002P3oool40;bHA0@0^iI5102mVTP40<2KB`@0
_YU;102mUTT50;^DA@@0^I93102dTCd40;RE@@@0^YM3102lV4@40;jJAP@0`ie:1034WTd50<2IBP@0
^I93102oV4d40<2ICP@0`i]C1033WU040<NRE0@0ajAB1033X4h50<:NB0@0`I]61030VTL40<2GA@@0
`iQ91035VT/40<ROCA40aYe;1033VTP40<BKB@@0a9];1032VDT40<FKC`@0b9iB1@38WUH40<^QF@@0
c:5L103=X5d40=2SH0@0cjIT103AZ6H40=B]K0@0dZ]Z1@3;YFH40<NQHP@0b:9Q1031VeX40<2IE0@0
^iE>102fSd@40;:;?0@0/X`k1@2aRcH40:n:<P@0/H`c102bSC840:j9<0@0[hL_102aRC@40;J=>`D0
]H`m102eST440;R@B0@0_IM>102nV5480<6LEP@0aIiK1037X5d50=6ZI@@0aIiI1033VeD40<2HDP@0
`IUD1035W5X40<FNF`@0a9eL1037Wf450<ZRI0@0b:9S1039Xf@40<VTH0@0b:=O103B[FL40<FPFP@0
`YeF1@34WUL40<6KDP@0`i]C1033VeD40<JNF0@0aj1K1036WeX;0?ooo`002P3oool40;VC@0@0^Y=4
102kUdT40;jJCP@0_i]=102oW4/50;jKB@@0_IY6102jUSh40;^G?`@0_9Q2102lV4@40;fJAP@0aJ9A
1033XU450<6PD@@0_iiA102mW4l40<2LDP@0_i]A1031WE440<JREP@0aj9D1038XeD50<>NC@@0_iY9
1031VdX40;nIB0@0a9];1035W4`40<BNC@@0b:9A1@35WdX80<BNB@@0`ie:1034X4`40<:MC0P0`ie<
1036X4l50<jWF0@0bImC1038WUH40<fRGP@0cZ9S103BYFX40=R]MP@0d:M_103>Yg050<VVKP@0bJI/
1036XVH40<6MG`@0_IaI102fUE040;>BB`@0[Xa2102[RST50:j:=P@0ZhH]102^QBd40;27;`@0^8/f
102aQc440:j4<0@0/8Le1@2aR3T40;6:?`@0]Xi8102jU4d40;fFD@@0`9YC1031Ve@40<:MEP@0`iiG
1@33XEX40<FSF`@0_Ie@102eU4L40;bKCP@0a9mH1032VeH80<JOGPD0aimQ1038XV<40=B^K`@0b:EU
1036Xf<40<NTH0@0aZ=O1037XU`50<nZI0@0`YeF202mV5440;nJD`@0`YeF1034WeP;0?ooo`002P3o
ool40;VC@0@0^Y=4102kUdT40;jJCP@0_i]=102oW4/50;jKB@@0_IY6102jUSh40;^G?`@0_9Q2102l
V4@40;fJAP@0aJ9A1033XU450<6PD@@0_iiA102mW4l40<2LDP@0_i]A1031WE440<JREP@0aj9D1038
XeD50<>NC@@0_iY91031VdX40;nIB0@0a9];1035W4`40<BNC@@0b:9A1@35WdX80<BNB@@0`ie:1034
X4`40<:MC0P0`ie<1036X4l50<jWF0@0bImC1038WUH40<fRGP@0cZ9S103BYFX40=R]MP@0d:M_103>
Yg050<VVKP@0bJI/1036XVH40<6MG`@0_IaI102fUE040;>BB`@0[Xa2102[RST50:j:=P@0ZhH]102^
QBd40;27;`@0^8/f102aQc440:j4<0@0/8Le1@2aR3T40;6:?`@0]Xi8102jU4d40;fFD@@0`9YC1031
Ve@40<:MEP@0`iiG1@33XEX40<FSF`@0_Ie@102eU4L40;bKCP@0a9mH1032VeH80<JOGPD0aimQ1038
XV<40=B^K`@0b:EU1036Xf<40<NTH0@0aZ=O1037XU`50<nZI0@0`YeF202mV5440;nJD`@0`YeF1034
WeP;0?ooo`002P3oool40;VC@0@0^Y=4102kUdT40;jJCP@0_i]=102oW4/50;jKB@@0_IY6102jUSh4
0;^G?`@0_9Q2102lV4@40;fJAP@0aJ9A1033XU450<6PD@@0_iiA102mW4l40<2LDP@0_i]A1031WE44
0<JREP@0aj9D1038XeD50<>NC@@0_iY91031VdX40;nIB0@0a9];1035W4`40<BNC@@0b:9A1@35WdX8
0<BNB@@0`ie:1034X4`40<:MC0P0`ie<1036X4l50<jWF0@0bImC1038WUH40<fRGP@0cZ9S103BYFX4
0=R]MP@0d:M_103>Yg050<VVKP@0bJI/1036XVH40<6MG`@0_IaI102fUE040;>BB`@0[Xa2102[RST5
0:j:=P@0ZhH]102^QBd40;27;`@0^8/f102aQc440:j4<0@0/8Le1@2aR3T40;6:?`@0]Xi8102jU4d4
0;fFD@@0`9YC1031Ve@40<:MEP@0`iiG1@33XEX40<FSF`@0_Ie@102eU4L40;bKCP@0a9mH1032VeH8
0<JOGPD0aimQ1038XV<40=B^K`@0b:EU1036Xf<40<NTH0@0aZ=O1037XU`50<nZI0@0`YeF202mV544
0;nJD`@0`YeF1034WeP;0?ooo`002P3oool40;VC@0@0^Y=4102kUdT40;jJCP@0_i]=102oW4/50;jK
B@@0_IY6102jUSh40;^G?`@0_9Q2102lV4@40;fJAP@0aJ9A1033XU450<6PD@@0_iiA102mW4l40<2L
DP@0_i]A1031WE440<JREP@0aj9D1038XeD50<>NC@@0_iY91031VdX40;nIB0@0a9];1035W4`40<BN
C@@0b:9A1@35WdX80<BNB@@0`ie:1034X4`40<:MC0P0`ie<1036X4l50<jWF0@0bImC1038WUH40<fR
GP@0cZ9S103BYFX40=R]MP@0d:M_103>Yg050<VVKP@0bJI/1036XVH40<6MG`@0_IaI102fUE040;>B
B`@0[Xa2102[RST50:j:=P@0ZhH]102^QBd40;27;`@0^8/f102aQc440:j4<0@0/8Le1@2aR3T40;6:
?`@0]Xi8102jU4d40;fFD@@0`9YC1031Ve@40<:MEP@0`iiG1@33XEX40<FSF`@0_Ie@102eU4L40;bK
CP@0a9mH1032VeH80<JOGPD0aimQ1038XV<40=B^K`@0b:EU1036Xf<40<NTH0@0aZ=O1037XU`50<nZ
I0@0`YeF202mV5440;nJD`@0`YeF1034WeP;0?ooo`002P3oool40;RB@@@0^iA5102iUDL40;bHBP@0
`9e<102oW4X50<:NBP@0_YY4102lV4040;^G?`@0^iM1102lV4840;bIA@@0_9U7102nWD`50;jMCP@0
`9a@202oVdl40;jJCP@0`Ie?1036XU@40<FPD0@0`ii>1@35Wdh40<6KBP@0`I]8102nV4D40<2GA@@0
aYe;1032VDL40<NNC0D0aIm:1032W4L40<2JA@@0aZ1;103<YU<40<NQCP@0aIm>2037XE050<NPD@@0
`ia?1036WUH40<jSG`@0dJEV103CZg040=:YL`@0c:M`103=Z7<50<RWLP@0aJA_1030X6L40;nOIP@0
_YiQ102fUeL40;>DD@@0[Xe6102YRC`50:f:>@@0ZhLa102]QBh40:j6;P@0[H@/102/Q2`80:b4;@D0
[hHd102aRSd40;::@P@0]Y17102jU4d40;fHD@@0`9]D1031WeL40<>QF@D0`j5J1033XET40;jND`@0
_Ia?102mVe440;nJD`@0_iQC1033W5/40<BMG0D0aIeO1036X6840<bVJ0@0b:EU103:YfL80<RUH`@0
ajAP1@34XEd40<>QF@@0`Z1H2035X5T80<>NE`/0oooo000:0?ooo`@0^991102kU4D40;VEA`@0_9Q:
1030WD`40;nLBPD0`Yi:102nVT@40;bH@0@0^iLo102kUd440;bH@P@0_9U5102lVDL40;jMC0D0_Ye>
1030W5080;nKC`@0_YY>1031WDl40<JRE0@0aJ1@1033WTh50<FOCP@0`I]:1031VdP40;jHA@@0`9M5
1036WD/40<:IA`@0aii<1@35WdX40<:LA`@0`9Y51036X4/40<bVD`@0aj5>1035Wdh80<NQD0D0aj1A
1033W4l40<JNEP@0cZ=O103AYFH40=>[L0@0dZUc103<Yg040<fXL`D0b:Mb1035Y6l40<2PI`@0_imV
102nWV440;JGE`@0/iAA102^SDH40:V9?0D0[HXi102[Qc440:f5;P@0[XH^102]Q2`40:b4;0P0[8@]
1@2_QS@40;6:?@@0/XY2102fT4L40;ZDC@@0_IQA1030Ve@40<6OE`@0`j5I1@33XEX40<>QF@@0_YiC
102mW4l40;fKD@@0_iYC102oV5<40<>LF`@0a9eL1@35WEl40<JPHP@0c:IX1038YFD40<ZWI`P0b:ES
1037Y6050<BQG@@0`j5I1032X5P80<FPF@P0`iiG2`3oool000X0oooo102hTT440;^DA@@0^IE7102l
V4X40<2MC0@0_ia:1@32WTX40;jJA0@0_9Q0102kUcl40;^G@@@0_9Q2102lVDD40;bIA`@0_Ye<1@2n
WDh40<2LD0P0_i]?102nVTh40<6MC`@0aZ9D1035X5040<>NCPD0aIm>1031VdX40<6KB0@0_YQ51030
UdD40<JMB`@0`YU71037WT`50<FOBP@0`Ya71030VTD40<JPB`@0c:IC1037XDh40<FOCPP0aj5@1@37
X5440<>LC`@0aYiF103>Xel40=6UIP@0dj]`103BZG<40<bWL0@0cJQc1@38Yg840<FTK`@0`:1W102o
WfH40;jNH@@0]YMG102cU5440:j=AP@0ZHTl1@2]RST40:^7<@@0[HD^102^QRh40:f4;0@0[8@/202/
Q2d50:n6=0@0/HXm102bRT840;J@A`@0^YA=102mV5440<2KE0@0`ImG1033XET50<>QFP@0`j5I102n
WU<40;fLC`@0_I]A102oVU<40;nHD`@0`iaK1034WE`50<FMG`@0aZ1R103<YVP40<RUI@@0bZMW2038
YF<40<NTH0D0a:5M1033XET40<:PF0P0aJ1I2033WUL;0?ooo`002P3oool40;RB@@@0^iA5102iUDL4
0;bHBP@0`9e<102oW4X50<:NBP@0_YY4102lV4040;^G?`@0^iM1102lV4840;bIA@@0_9U7102nWD`5
0;jMCP@0`9a@202oVdl40;jJCP@0`Ie?1036XU@40<FPD0@0`ii>1@35Wdh40<6KBP@0`I]8102nV4D4
0<2GA@@0aYe;1032VDL40<NNC0D0aIm:1032W4L40<2JA@@0aZ1;103<YU<40<NQCP@0aIm>2037XE05
0<NPD@@0`ia?1036WUH40<jSG`@0dJEV103CZg040=:YL`@0c:M`103=Z7<50<RWLP@0aJA_1030X6L4
0;nOIP@0_YiQ102fUeL40;>DD@@0[Xe6102YRC`50:f:>@@0ZhLa102]QBh40:j6;P@0[H@/102/Q2`8
0:b4;@D0[hHd102aRSd40;::@P@0]Y17102jU4d40;fHD@@0`9]D1031WeL40<>QF@D0`j5J1033XET4
0;jND`@0_Ia?102mVe440;nJD`@0_iQC1033W5/40<BMG0D0aIeO1036X6840<bVJ0@0b:EU103:YfL8
0<RUH`@0ajAP1@34XEd40<>QF@@0`Z1H2035X5T80<>NE`/0oooo000:0?ooo`@0^991102kU4D40;VE
A`@0_9Q:1030WD`40;nLBPD0`Yi:102nVT@40;bH@0@0^iLo102kUd440;bH@P@0_9U5102lVDL40;jM
C0D0_Ye>1030W5080;nKC`@0_YY>1031WDl40<JRE0@0aJ1@1033WTh50<FOCP@0`I]:1031VdP40;jH
A@@0`9M51036WD/40<:IA`@0aii<1@35WdX40<:LA`@0`9Y51036X4/40<bVD`@0aj5>1035Wdh80<NQ
D0D0aj1A1033W4l40<JNEP@0cZ=O103AYFH40=>[L0@0dZUc103<Yg040<fXL`D0b:Mb1035Y6l40<2P
I`@0_imV102nWV440;JGE`@0/iAA102^SDH40:V9?0D0[HXi102[Qc440:f5;P@0[XH^102]Q2`40:b4
;0P0[8@]1@2_QS@40;6:?@@0/XY2102fT4L40;ZDC@@0_IQA1030Ve@40<6OE`@0`j5I1@33XEX40<>Q
F@@0_YiC102mW4l40;fKD@@0_iYC102oV5<40<>LF`@0a9eL1@35WEl40<JPHP@0c:IX1038YFD40<ZW
I`P0b:ES1037Y6050<BQG@@0`j5I1032X5P80<FPF@P0`iiG2`3oool000X0oooo102jTd@40;bEAP@0
^iI6102jUDD40;ZEA0@0_9M61@2oVdD40;fI@`@0_iY2102nVD440;fH@0@0^YDm102iUCl40;NC?`@0
_Y]:2@30W4h<0;nKC@@0`Ii=1033X4l40<>NC@@0^IA31@2nV4<40<2JA@@0`9Q3102nUT440<6IA0@0
`i]61034VdT40<JMB`D0aIe82032VTD40<FMB0@0aIm<1037XDh40<VSDP@0b:9A103:YE@50<ZUE@@0
aj9D103<YUd40<nYHP@0cjQW103;YfT40<^XL0@0cJag103:ZWT50<BVM0@0a:Ef1030XW040;nQK`@0
_9iX102eV6040;>EF@@0[Xm?102WRD450:Z8?P@0[8Th102/R3@40:f8;`@0YX4V102YPRD40:Z3:0@0
Z84V1@2]QBh40;B;>`@0/hTm102bRT840;R@BP@0_9M@1031W5D80<6OE`D0`9mH1032XUT40<BRF0@0
_Ye@1030W5840<2KE0@0a9eH1039XV440<>LF`D0`i]M1035WF040<RPH`@0bZAV103=YfT80<VVIP@0
b:ES1@30WET40<FSG0@0ajEM1039Y5d40<RSG0P0`iiG2`3oool000X0oooo102jTd@40;bEAP@0^iI6
102jUDD40;ZEA0@0_9M61@2oVdD40;fI@`@0_iY2102nVD440;fH@0@0^YDm102iUCl40;NC?`@0_Y]:
2@30W4h<0;nKC@@0`Ii=1033X4l40<>NC@@0^IA31@2nV4<40<2JA@@0`9Q3102nUT440<6IA0@0`i]6
1034VdT40<JMB`D0aIe82032VTD40<FMB0@0aIm<1037XDh40<VSDP@0b:9A103:YE@50<ZUE@@0aj9D
103<YUd40<nYHP@0cjQW103;YfT40<^XL0@0cJag103:ZWT50<BVM0@0a:Ef1030XW040;nQK`@0_9iX
102eV6040;>EF@@0[Xm?102WRD450:Z8?P@0[8Th102/R3@40:f8;`@0YX4V102YPRD40:Z3:0@0Z84V
1@2]QBh40;B;>`@0/hTm102bRT840;R@BP@0_9M@1031W5D80<6OE`D0`9mH1032XUT40<BRF0@0_Ye@
1030W5840<2KE0@0a9eH1039XV440<>LF`D0`i]M1035WF040<RPH`@0bZAV103=YfT80<VVIP@0b:ES
1@30WET40<FSG0@0ajEM1039Y5d40<RSG0P0`iiG2`3oool000X0oooo102jTd@40;bEAP@0^iI6102j
UDD40;ZEA0@0_9M61@2oVdD40;fI@`@0_iY2102nVD440;fH@0@0^YDm102iUCl40;NC?`@0_Y]:2@30
W4h<0;nKC@@0`Ii=1033X4l40<>NC@@0^IA31@2nV4<40<2JA@@0`9Q3102nUT440<6IA0@0`i]61034
VdT40<JMB`D0aIe82032VTD40<FMB0@0aIm<1037XDh40<VSDP@0b:9A103:YE@50<ZUE@@0aj9D103<
YUd40<nYHP@0cjQW103;YfT40<^XL0@0cJag103:ZWT50<BVM0@0a:Ef1030XW040;nQK`@0_9iX102e
V6040;>EF@@0[Xm?102WRD450:Z8?P@0[8Th102/R3@40:f8;`@0YX4V102YPRD40:Z3:0@0Z84V1@2]
QBh40;B;>`@0/hTm102bRT840;R@BP@0_9M@1031W5D80<6OE`D0`9mH1032XUT40<BRF0@0_Ye@1030
W5840<2KE0@0a9eH1039XV440<>LF`D0`i]M1035WF040<RPH`@0bZAV103=YfT80<VVIP@0b:ES1@30
WET40<FSG0@0ajEM1039Y5d40<RSG0P0`iiG2`3oool000X0oooo102jTd@40;bEAP@0^iI6102jUDD4
0;ZEA0@0_9M61@2oVdD40;fI@`@0_iY2102nVD440;fH@0@0^YDm102iUCl40;NC?`@0_Y]:2@30W4h<
0;nKC@@0`Ii=1033X4l40<>NC@@0^IA31@2nV4<40<2JA@@0`9Q3102nUT440<6IA0@0`i]61034VdT4
0<JMB`D0aIe82032VTD40<FMB0@0aIm<1037XDh40<VSDP@0b:9A103:YE@50<ZUE@@0aj9D103<YUd4
0<nYHP@0cjQW103;YfT40<^XL0@0cJag103:ZWT50<BVM0@0a:Ef1030XW040;nQK`@0_9iX102eV604
0;>EF@@0[Xm?102WRD450:Z8?P@0[8Th102/R3@40:f8;`@0YX4V102YPRD40:Z3:0@0Z84V1@2]QBh4
0;B;>`@0/hTm102bRT840;R@BP@0_9M@1031W5D80<6OE`D0`9mH1032XUT40<BRF0@0_Ye@1030W584
0<2KE0@0a9eH1039XV440<>LF`D0`i]M1035WF040<RPH`@0bZAV103=YfT80<VVIP@0b:ES1@30WET4
0<FSG0@0ajEM1039Y5d40<RSG0P0`iiG2`3oool000X0oooo102gTD040;VC@PP0_9I3102lUT440;nI
A0T0_YQ31030VTD80<:LA`@0^iE0102iTch40;bF@`@0_Y]91@30WD`40<2LCP@0_i]=102oW4/40<6N
C@P0`Ia;102nVT@40<2LAPT0`Ia41030V4440;fE?PP0`i]61039Wdd40<JLBPT0aI]71036WTT40<FM
B0@0`iY81039X4h80<VSD0@0bJEA1@3:YE@40<fXF0@0cZQM103;YUl40=2]J`@0fKMh103=[G@40<^]
N@@0bJYk1@31YWT40;fRM`P0^iid102mWW040;NHJ@@0]IMQ102_T5L40:N:B0D0YhI1102XQcX40:Z7
=P@0ZhL_102UPRP80:J290@0Z84V1@2^QRh40;::=@@0/HPh102aRSd40;J?A0@0^YI<102oVe440;nM
D`@0_YaB1@2nWUD40<6OE@@0`J1C1032WU040<>MDP@0aImF1032W5D40<FNF`@0b:5N1@34WE`40<BL
GP@0aimQ1037XF840<RRH`P0bZMW103:YfD50<FRGP@0a:9K1036Y5`80<BRFP@0a9mH1035X5T;0?oo
o`002P3oool40;NA@0@0^I=2202lUT<40;bF@@@0_iU42@2nV4<40<2JA@P0`Ya7102kUD040;VC?P@0
_9I3102nVdT50<2MC0@0`9a>102oVdd40;nLB`@0`Ii=2031W4/40;jJA0@0`9a62@31W4@40<2H@@@0
_IDn2033VdH40<VOC@@0aYa:2@35VdL40<JNB@@0aIe81033VTP40<VPCPP0bJ=@1039YE450<ZUE0@0
cJQH103>Z5d40<^VG`@0d:e[103I]gP40<f]M0@0bjei1039ZW/50<6VN@@0_J9g202kWW@40;fNL0@0
]iQY102eUf440:n@E`@0YhY81@2WQT440:R7>P@0ZXLf102[Qbl40:F2:0P0YX8T102XPBH50:j6;P@0
/XXe102aR3P40;6:?@@0]Xm4102jUT`40;nKD@@0_ieC102nW5850;jNE@@0`ImE1031X5<40<:ND0@0
`ieB1035WeH40<:LE@@0aIiK1038XEh50<BMG0@0a9aN1037Wf440<NQHP@0b:9S203:YfL40<ZWI@D0
aJ9N1034XU/40<JTG0P0a:9J1034WeP40<FPF@/0oooo000:0?ooo`@0]i50102iTd880;bF@`@0_9I1
102oVD@90;jH@`@0`9Y52032W4L40;^E@0@0^I<n102lUT<40;jKB@D0`9e<1030W4h40;nKC@@0_ia;
1031WTd80<6LB`@0_YY41030W4H90<6LA0@0`9Q1102mUCh80<>KAP@0bIm=1036W4X90<FKA`@0aYi9
1035WDP40<>JB0@0bJ1>2039Xe040<VUD@D0bZED103=Z5P40<jXG@@0bjIO103@[F/40=VgN0@0cJed
103;[GT40<VZN`D0`JIi102mXWL80;^NM0@0_Ii`102gV6T40;FGH@@0[i1G102WRTP50:N6@@@0Z8Lj
102ZQcH40:^7;`@0YH8X202VPR@40:R19PD0[XH^102bRSD40;68>0@0/HXm102fSd@40;ZFC0@0_i]A
102oWE<40;jLDPD0_YiE1031WeD40<6PD`@0`Yi@1033WE840<FOEP@0`YaE1035WU/40<RQGPD0a9eL
1034W5h40<NOH@@0aj5R1038XV<80<ZWI`@0bZMU1@35XUh40<BRF`@0aZAL2034XUX40<BOF0@0aJ1I
2`3oool000X0oooo102gTD040;VC@PP0_9I3102lUT440;nIA0T0_YQ31030VTD80<:LA`@0^iE0102i
Tch40;bF@`@0_Y]91@30WD`40<2LCP@0_i]=102oW4/40<6NC@P0`Ia;102nVT@40<2LAPT0`Ia41030
V4440;fE?PP0`i]61039Wdd40<JLBPT0aI]71036WTT40<FMB0@0`iY81039X4h80<VSD0@0bJEA1@3:
YE@40<fXF0@0cZQM103;YUl40=2]J`@0fKMh103=[G@40<^]N@@0bJYk1@31YWT40;fRM`P0^iid102m
WW040;NHJ@@0]IMQ102_T5L40:N:B0D0YhI1102XQcX40:Z7=P@0ZhL_102UPRP80:J290@0Z84V1@2^
QRh40;::=@@0/HPh102aRSd40;J?A0@0^YI<102oVe440;nMD`@0_YaB1@2nWUD40<6OE@@0`J1C1032
WU040<>MDP@0aImF1032W5D40<FNF`@0b:5N1@34WE`40<BLGP@0aimQ1037XF840<RRH`P0bZMW103:
YfD50<FRGP@0a:9K1036Y5`80<BRFP@0a9mH1035X5T;0?ooo`002P3oool40;^C?P@0_IE0102mUCh4
0;jF?`@0_IQ0102kUSh50;nIA0@0_YQ31030VTL40<BNB`@0`I]:102mUdH40;fDA0@0`9M7102mV4P5
0<2KB`@0`Ye=1030Vd/40;nJB@@0`Ia;2032WTX40<>OB@@0_i]51@32WDD40<^VCP@0`i]6102jTSd4
0<6IA0@0`YU71037WD/40<BIBPT0aie91034VTH40<JLB0@0aii<1038Wdd40<VSD0@0aIm<103:YU85
0<fXE`@0bZMF1039YET40<ZVG0@0cjaX103G]GH40<j_N0@0cJmk1038Zgl50;nSN`@0^Ieh102lWWX4
0;nQN`@0^i]d102hVFd40;FGI@@0/I9L102ZRTd50:J3@`@0YH0i102YPcP40:b7=P@0Yh4/102UP2P4
0:=k8`@0Y7/Q1@2]Q2`40;>9<`@0/hTg102bRc`40;B=@0@0]i=5102nVT`40;nNC`@0_Ia=1@2lVdh4
0<2LD0@0`Ym>102mV4X40<>ND0P0b:9I1038XE`40<:KEPD0`Y]H1034WE`40<FNG@P0`ieL103;YF@4
0<fWIP@0bjQT1@36Xel80<>QF@@0`Z1I1033XEX40<FPFP@0aZ5K2`3oool000X0oooo102kTch40;fE
@0@0_IDn102nUSl40;fH@0@0^iHn1@2oVD@40;jH@`@0`9Y71034WT/40<6KBP@0_IM6102mU4@40<2G
A`@0_IQ81@30Vd/40<:MC@@0`9];102oVTT40<6LB`P0`Yi:1033WdT40;nKA@D0`Ye5103;YTh40<>K
AP@0^Y8m1031VD@40<:IA`@0aie;1034VDX90<NMB@@0a9Y61036W4P40<NNC0@0b9m=1039Xe040<FO
C0@0bZIB1@3=Z5L40<ZWEP@0bJEI103:YU`40<n/J0@0ekEf103>[gP40<f_N`@0b:]o1@2oXg/40;VM
N0@0_9ij102oXG/40;^KM0@0^9U]102eUfD40;6BG0@0ZXY=1@2VPd<40:F0>@@0ZH<h102/QcH40:N1
;0@0YH0X102SNb<40:Ak8@D0[H@/102cRC<40;>9=`@0/X/l102dSD040;NCA@@0_YY<102oWTl40;fL
C@D0_9]>1030W5040<:OCP@0_IQ:1033WU080<RRF@@0b:5L1032VeH50<:KF0@0a9eL1035WUd80<>M
G0@0bjET103=YfH40<^XI0D0aZ=O2033XET40<:PF@@0`j5J1035X5X40<JQF`/0oooo000:0?ooo`@0
^i<n102mUD040;fE?P@0_YHo102mV4040;^F?PD0_iU4102nV4<40<2JA`@0a9i;1031VdX40;fGAP@0
_IA41030UdL40;fHB0D0`9];1032WDd40<2KB`@0_iY91031W4/80<:NBP@0`im9102oVdD50<:MA@@0
bjI>1033VdH40;ZB?@@0`IU41032VDL40<NMB`@0a9U:2@37WDT40<BJAP@0aYa81037WT`40<ROC@@0
bJ=@1035Wd`40<ZVDPD0cJQG103:YeH40<VUF@@0bZIL103?[6P40=NeMP@0cZmh103=[g/40<R[O`D0
_j=k102iWGP40;bNNP@0_j5k102kVg@40;RIK@@0]IMU102aTU`40:Z:C@D0YX=3102UP3T40:V3>0@0
[8Lf102WPB`40:F0:0@0Xg/S102TNb450:f4;0@0/hTc102cRCL40;:;?0@0]8e0102gTdD40;jJC0@0
_ii?102mW4d50;bKCP@0`9a@1032Wdh40;fHBP@0`ii@2038XUT40<RQG0@0`Y]F1@32VeP40<BMG0@0
aIiM2033WE`40<^UI0@0cJMV103;Z6@50<JSG`P0`j5I1032X5T40<>QFP@0aJ1J1036XE/;0?ooo`00
2P3oool40;^C?P@0_IE0102mUCh40;jF?`@0_IQ0102kUSh50;nIA0@0_YQ31030VTL40<BNB`@0`I]:
102mUdH40;fDA0@0`9M7102mV4P50<2KB`@0`Ye=1030Vd/40;nJB@@0`Ia;2032WTX40<>OB@@0_i]5
1@32WDD40<^VCP@0`i]6102jTSd40<6IA0@0`YU71037WD/40<BIBPT0aie91034VTH40<JLB0@0aii<
1038Wdd40<VSD0@0aIm<103:YU850<fXE`@0bZMF1039YET40<ZVG0@0cjaX103G]GH40<j_N0@0cJmk
1038Zgl50;nSN`@0^Ieh102lWWX40;nQN`@0^i]d102hVFd40;FGI@@0/I9L102ZRTd50:J3@`@0YH0i
102YPcP40:b7=P@0Yh4/102UP2P40:=k8`@0Y7/Q1@2]Q2`40;>9<`@0/hTg102bRc`40;B=@0@0]i=5
102nVT`40;nNC`@0_Ia=1@2lVdh40<2LD0@0`Ym>102mV4X40<>ND0P0b:9I1038XE`40<:KEPD0`Y]H
1034WE`40<FNG@P0`ieL103;YF@40<fWIP@0bjQT1@36Xel80<>QF@@0`Z1I1033XEX40<FPFP@0aZ5K
2`3oool000X0oooo102oUd040;jF?`P0_iDo102nUT440;nG@PD0`9Y7102lUT<40;jHA`@0`ie<102l
UTD40;^EA0@0_iI6102nUDD40;ZEA0D0_iY91033WTd40;nJB@P0_9M61031WDT40<:NBP@0`Ie73@32
WTP40<6KB0@0`9Y71030VTT40<6KBP@0aIa=1037WTl50<ZQD@@0aYe=1034VTP40<FKB@@0aii>103:
XE440<^RDP@0c:=C103<Z5@50<ZUE0@0bjQG103:YUX40<NUF`@0cZ]W103C]7@40=>dO@@0c[1n1035
Z7h50;bPN`@0^Ial102jVgh40;FFM`@0^9Mf102hV7840;FFJ0@0/Y9O102^SUD50:N3A@@0Y7lk102X
PS/40:b7>@@0YGl^102TOR/40:Ek9`@0XgTS1@2^PB`40;N:=`@0]XTh102eS3X40;N>?P@0^IA31030
VdX40<6NC0@0_Y]:1@2mVTT40;nKC@P0`Ye?102oVDh40<BND`@0b:9I1036X5T40<:LE@D0aIiI1036
We`40<BMFP@0aYmL1037X5d40<RSG@@0bJAN1039Yf050<>QFPP0`ImH1033X5`40<FRGP@0aZ1O1035
Weh;0?ooo`002P3oool40;nG@0@0_YHo202oUCl40;jF@@@0_iM21@30VTL40;bF@`@0_YQ71033WD`4
0;bFA@@0^iE4102oUTH40;jEA@@0^YE41@2oVTT40<>NC@@0_iY9202lUdH40<6MB@@0`Yi:1031WDL=
0<:NB0@0`I]81030VTL40<2JB@@0`I]:1035W4d40<NNC`D0bZ5A1036WDd40<BJB0@0aI]91037WTh4
0<ZQD@@0bj9B103<Xe<40<bXE0D0bZED103;Z5L40<ZVFP@0ajEK103>ZfL40=>dM0@0dkAm103>/7h4
0<FXOPD0_:1k102iW7`40;ZKOP@0]IIg102hUgH40;RHLP@0]IIX102bTUl40:j>E@D0Yh=5102TOc/4
0:R2>`@0[8Li102UObh40:An:`@0YG/W102SNB<50:j1;0@0]hXg102fRCP40;F<>P@0]hhn102iU4<4
0<2KBP@0`Ii<102nVdX50;fJB@@0_i]=2032WDl40;nICP@0a9iC1038XUT40<JPF@@0`YaE1@35WUT4
0<JOG0@0a9eJ1036We`40<NPG@@0b:=M1039Y5h40<VWH0D0`j5J2031WeP40<>PG0@0aJ9N1036X5l4
0<FOGP/0oooo000:0?ooo`@0_iM0102nUSl80;nE?`@0_YI1102oUd850<2JA`@0_9I3102nV4L40<>M
C0@0_9I5102kUD@40;nFAP@0_YE5102jUD@50;nJB@@0`ii=102oVTT80;bGAP@0`Ie91032WTX40<6M
A`d0`Yi81031VdP40<2JA`@0`9Y91031VdX40<FLC@@0aii?1@3:XE440<JMC@@0a9Y81035VdT40<NN
CP@0bZ5A103;XU840<bSD`@0c:QD1@3:YE@40<^XE`@0bZIJ1037YE/40<j[I`@0dkAd103C]7d40<j`
OP@0aJQn1@2lX7/40;VLO0@0^Y]n102eUWL40;RGMP@0^9Qb102eUVP40;:BG`@0[XiE1@2WPdD40:Ao
>`@0Z88k102/QcT40:Eo;P@0Y7h[102UNbL40:=i8`D0[X4/102gRSL40;J9>0@0]H`j102gSSh40;VD
@`@0`9]:1031WT`40;jKBPD0_IY9102oVdd80<:MC`@0_iU>1034WU<40<RRF@@0aZ1I1032W5D50<FN
F@@0aYmL1034WEX40<JOG0@0aj1M1038Xed40<VTGP@0bJMP1@33XEX80<6OF0@0`j1L1035XUh40<JP
G`@0aImN2`3oool000X0oooo102oUd040;jF?`P0_iDo102nUT440;nG@PD0`9Y7102lUT<40;jHA`@0
`ie<102lUTD40;^EA0@0_iI6102nUDD40;ZEA0D0_iY91033WTd40;nJB@P0_9M61031WDT40<:NBP@0
`Ie73@32WTP40<6KB0@0`9Y71030VTT40<6KBP@0aIa=1037WTl50<ZQD@@0aYe=1034VTP40<FKB@@0
aii>103:XE440<^RDP@0c:=C103<Z5@50<ZUE0@0bjQG103:YUX40<NUF`@0cZ]W103C]7@40=>dO@@0
c[1n1035Z7h50;bPN`@0^Ial102jVgh40;FFM`@0^9Mf102hV7840;FFJ0@0/Y9O102^SUD50:N3A@@0
Y7lk102XPS/40:b7>@@0YGl^102TOR/40:Ek9`@0XgTS1@2^PB`40;N:=`@0]XTh102eS3X40;N>?P@0
^IA31030VdX40<6NC0@0_Y]:1@2mVTT40;nKC@P0`Ye?102oVDh40<BND`@0b:9I1036X5T40<:LE@D0
aIiI1036We`40<BMFP@0aYmL1037X5d40<RSG@@0bJAN1039Yf050<>QFPP0`ImH1033X5`40<FRGP@0
aZ1O1035Weh;0?ooo`002P3oool40<6G@@@0_Y@n102oUD440;fC?`@0_9=11031V4H50<6KB0@0^iE2
102kUd<40<6MB@@0`9]:102kUTD40;^EA0@0_9I5102jU4450;nIAP@0aZ1=102oVDH40;^G@`@0^IE1
102oVdDA0<2LAP@0`Yi:1031WDT40<>NC@@0aJ1@1037XU@40<JODP@0bZ=H1@3=Y5D40<ZQDP@0bJ1@
1038Wdl40<VPD@@0cjIG103=Y5@40<^RDP@0cZQG1@3;Y5D40<VTE0@0bjEJ103=ZEl40<fZIP@0d[9g
103F]X<40<faPP@0`ZAn1@2eVgX40;BIO0@0]YQn102gVGd40;NHN@@0]iUe102eV6h40;BEIP@0/95K
1@2ZQdd40:F2@P@0YWll102VP3D40:El;@@0YG`/102ZOB`40:ao;0D0/84_202cQSD40;B;>@@0^8lm
102iUD440;jJAP@0_iY9102mV4P50;jGB0@0`IY=102oVDh40<6KD0@0`I]B102nV4l40<FPF@@0cJQQ
1033W5L50<2IE0@0b:1K1036WUT80<ZRG@P0aYmJ1037XU`50<>NF0P0`IiJ1035XV040<BQG`@0aZ1Q
1035Wf0;0?ooo`002P3oool40<6G@@@0_Y@n102oUD440;fC?`@0_9=11031V4H50<6KB0@0^iE2102k
Ud<40<6MB@@0`9]:102kUTD40;^EA0@0_9I5102jU4450;nIAP@0aZ1=102oVDH40;^G@`@0^IE1102o
VdDA0<2LAP@0`Yi:1031WDT40<>NC@@0aJ1@1037XU@40<JODP@0bZ=H1@3=Y5D40<ZQDP@0bJ1@1038
Wdl40<VPD@@0cjIG103=Y5@40<^RDP@0cZQG1@3;Y5D40<VTE0@0bjEJ103=ZEl40<fZIP@0d[9g103F
]X<40<faPP@0`ZAn1@2eVgX40;BIO0@0]YQn102gVGd40;NHN@@0]iUe102eV6h40;BEIP@0/95K1@2Z
Qdd40:F2@P@0YWll102VP3D40:El;@@0YG`/102ZOB`40:ao;0D0/84_202cQSD40;B;>@@0^8lm102i
UD440;jJAP@0_iY9102mV4P50;jGB0@0`IY=102oVDh40<6KD0@0`I]B102nV4l40<FPF@@0cJQQ1033
W5L50<2IE0@0b:1K1036WUT80<ZRG@P0aYmJ1037XU`50<>NF0P0`IiJ1035XV040<BQG`@0aZ1Q1035
Wf0;0?ooo`002P3oool40<6G@@@0_Y@n102oUD440;fC?`@0_9=11031V4H50<6KB0@0^iE2102kUd<4
0<6MB@@0`9]:102kUTD40;^EA0@0_9I5102jU4450;nIAP@0aZ1=102oVDH40;^G@`@0^IE1102oVdDA
0<2LAP@0`Yi:1031WDT40<>NC@@0aJ1@1037XU@40<JODP@0bZ=H1@3=Y5D40<ZQDP@0bJ1@1038Wdl4
0<VPD@@0cjIG103=Y5@40<^RDP@0cZQG1@3;Y5D40<VTE0@0bjEJ103=ZEl40<fZIP@0d[9g103F]X<4
0<faPP@0`ZAn1@2eVgX40;BIO0@0]YQn102gVGd40;NHN@@0]iUe102eV6h40;BEIP@0/95K1@2ZQdd4
0:F2@P@0YWll102VP3D40:El;@@0YG`/102ZOB`40:ao;0D0/84_202cQSD40;B;>@@0^8lm102iUD44
0;jJAP@0_iY9102mV4P50;jGB0@0`IY=102oVDh40<6KD0@0`I]B102nV4l40<FPF@@0cJQQ1033W5L5
0<2IE0@0b:1K1036WUT80<ZRG@P0aYmJ1037XU`50<>NF0P0`IiJ1035XV040<BQG`@0aZ1Q1035Wf0;
0?ooo`002P3oool40<6G@@@0_Y@n102oUD440;fC?`@0_9=11031V4H50<6KB0@0^iE2102kUd<40<6M
B@@0`9]:102kUTD40;^EA0@0_9I5102jU4450;nIAP@0aZ1=102oVDH40;^G@`@0^IE1102oVdDA0<2L
AP@0`Yi:1031WDT40<>NC@@0aJ1@1037XU@40<JODP@0bZ=H1@3=Y5D40<ZQDP@0bJ1@1038Wdl40<VP
D@@0cjIG103=Y5@40<^RDP@0cZQG1@3;Y5D40<VTE0@0bjEJ103=ZEl40<fZIP@0d[9g103F]X<40<fa
PP@0`ZAn1@2eVgX40;BIO0@0]YQn102gVGd40;NHN@@0]iUe102eV6h40;BEIP@0/95K1@2ZQdd40:F2
@P@0YWll102VP3D40:El;@@0YG`/102ZOB`40:ao;0D0/84_202cQSD40;B;>@@0^8lm102iUD440;jJ
AP@0_iY9102mV4P50;jGB0@0`IY=102oVDh40<6KD0@0`I]B102nV4l40<FPF@@0cJQQ1033W5L50<2I
E0@0b:1K1036WUT80<ZRG@P0aYmJ1037XU`50<>NF0P0`IiJ1035XV040<BQG`@0aZ1Q1035Wf0;0?oo
o`002P3oool40;jD@0@0_iE11032V4H40<>IA`P0`IQ81@31VdP40;ZD@@@0]i<o1030W4P40<ZVDP@0
_i]7102gTCh40;bF@`@0_YQ51@31VdP40<RRC`@0`I]8102oVdL40;^G@`@0`Ie71030W4H40;fKA0@0
_Ya51@2fTcl40;fJB0@0`Ym=1032Wdh40<BOD@@0`ieB1038XEH40<VQF@D0c:EH103;Y5L40<ZQDP@0
bj9C203=XU@40<ROD0@0bZ5B103?ZEP50<nXF@@0cJQH103;YEX40<^WG@@0bjQV103>[W<40=VkR@@0
d;>7102oXgh50;>HNP@0^Ij3102gVh<40;BIOP@0]9Ij102cUWH40;>FKP@0]9EW102_TEd50:Z:D@@0
YhE6102UP3`40:Al=0@0Yg/`102QMRL40:Eg:@@0[Wl]1@2]OR`40:io;`@0/hHe102fS3X40;N>?0@0
]Y8l102iUD440;bF@`@0_9E61@2oUDT40<6GC`@0`I]B102oVE840<:LE@@0a9iG1034WeT40<JQF`@0
`Y]H1@34WEX40<NNG0@0aYeK2037WU`80<JOFP@0aJ1J1@35X5`40<>PG0@0`IiL1035XV840<>PH0@0
a:5Q1035XV8;0?ooo`002P3oool40;jD@0@0_iE11032V4H40<>IA`P0`IQ81@31VdP40;ZD@@@0]i<o
1030W4P40<ZVDP@0_i]7102gTCh40;bF@`@0_YQ51@31VdP40<RRC`@0`I]8102oVdL40;^G@`@0`Ie7
1030W4H40;fKA0@0_Ya51@2fTcl40;fJB0@0`Ym=1032Wdh40<BOD@@0`ieB1038XEH40<VQF@D0c:EH
103;Y5L40<ZQDP@0bj9C203=XU@40<ROD0@0bZ5B103?ZEP50<nXF@@0cJQH103;YEX40<^WG@@0bjQV
103>[W<40=VkR@@0d;>7102oXgh50;>HNP@0^Ij3102gVh<40;BIOP@0]9Ij102cUWH40;>FKP@0]9EW
102_TEd50:Z:D@@0YhE6102UP3`40:Al=0@0Yg/`102QMRL40:Eg:@@0[Wl]1@2]OR`40:io;`@0/hHe
102fS3X40;N>?0@0]Y8l102iUD440;bF@`@0_9E61@2oUDT40<6GC`@0`I]B102oVE840<:LE@@0a9iG
1034WeT40<JQF`@0`Y]H1@34WEX40<NNG0@0aYeK2037WU`80<JOFP@0aJ1J1@35X5`40<>PG0@0`IiL
1035XV840<>PH0@0a:5Q1035XV8;0?ooo`002P3oool40;jD@0@0_iE11032V4H40<>IA`P0`IQ81@31
VdP40;ZD@@@0]i<o1030W4P40<ZVDP@0_i]7102gTCh40;bF@`@0_YQ51@31VdP40<RRC`@0`I]8102o
VdL40;^G@`@0`Ie71030W4H40;fKA0@0_Ya51@2fTcl40;fJB0@0`Ym=1032Wdh40<BOD@@0`ieB1038
XEH40<VQF@D0c:EH103;Y5L40<ZQDP@0bj9C203=XU@40<ROD0@0bZ5B103?ZEP50<nXF@@0cJQH103;
YEX40<^WG@@0bjQV103>[W<40=VkR@@0d;>7102oXgh50;>HNP@0^Ij3102gVh<40;BIOP@0]9Ij102c
UWH40;>FKP@0]9EW102_TEd50:Z:D@@0YhE6102UP3`40:Al=0@0Yg/`102QMRL40:Eg:@@0[Wl]1@2]
OR`40:io;`@0/hHe102fS3X40;N>?0@0]Y8l102iUD440;bF@`@0_9E61@2oUDT40<6GC`@0`I]B102o
VE840<:LE@@0a9iG1034WeT40<JQF`@0`Y]H1@34WEX40<NNG0@0aYeK2037WU`80<JOFP@0aJ1J1@35
X5`40<>PG0@0`IiL1035XV840<>PH0@0a:5Q1035XV8;0?ooo`002P3oool40;jD@0@0_iE11032V4H4
0<>IA`P0`IQ81@31VdP40;ZD@@@0]i<o1030W4P40<ZVDP@0_i]7102gTCh40;bF@`@0_YQ51@31VdP4
0<RRC`@0`I]8102oVdL40;^G@`@0`Ie71030W4H40;fKA0@0_Ya51@2fTcl40;fJB0@0`Ym=1032Wdh4
0<BOD@@0`ieB1038XEH40<VQF@D0c:EH103;Y5L40<ZQDP@0bj9C203=XU@40<ROD0@0bZ5B103?ZEP5
0<nXF@@0cJQH103;YEX40<^WG@@0bjQV103>[W<40=VkR@@0d;>7102oXgh50;>HNP@0^Ij3102gVh<4
0;BIOP@0]9Ij102cUWH40;>FKP@0]9EW102_TEd50:Z:D@@0YhE6102UP3`40:Al=0@0Yg/`102QMRL4
0:Eg:@@0[Wl]1@2]OR`40:io;`@0/hHe102fS3X40;N>?0@0]Y8l102iUD440;bF@`@0_9E61@2oUDT4
0<6GC`@0`I]B102oVE840<:LE@@0a9iG1034WeT40<JQF`@0`Y]H1@34WEX40<NNG0@0aYeK2037WU`8
0<JOFP@0aJ1J1@35X5`40<>PG0@0`IiL1035XV840<>PH0@0a:5Q1035XV8;0?ooo`002P3oool40;nF
A0@0`9M51031V4P40<ROC`@0a9e>2@30VDX40;bEAP@0^9=3102nVDT40<JQD0@0`Ia;102nVTH40;fI
A@@0_IM21@31VdH40<RRC`@0aj5>1032W4/40;fGAP@0_iU61030VTL40<2LB0@0_9Q41@2mVDD40;fH
A`@0^iQ6102nVdX40<2LCP@0`imC1038XUT40<^UGPD0cJML1039XeP80<VTEPP0bjAG103<Xe@40<jU
EP@0cJAE1@3@YUX40<jXH@@0cZMT103<YVP40<fXL@@0fKF3103M_9440<V/Q0@0_J1n1@2`UgT40;VO
Q0@0_::7102cV7d40;6FN@@0]IQj102`TG840;FEK`@0]9AU1@2^ReD40:R6AP@0YH0i102OO2/409ih
9@@0X7HT102RLb<40:Qi:@D0ZW/[102^P3840:n6=P@0/H/j102aS3/40;JA@0@0^991102nV4L40;fD
A0D0_iA51030UDL40;nHB`@0`IY?1033WE@80<JPF@@0aIiI1033WUX50<BOF`@0aJ1J1036XE/40<NQ
FP@0a9iG102oUe840;bDC`@0b:1K1@3;Xeh40<JOG0@0a9eJ1033X5h40<BQG`@0`J9O1033Y64;0?oo
o`002P3oool40;nFA0@0`9M51031V4P40<ROC`@0a9e>2@30VDX40;bEAP@0^9=3102nVDT40<JQD0@0
`Ia;102nVTH40;fIA@@0_IM21@31VdH40<RRC`@0aj5>1032W4/40;fGAP@0_iU61030VTL40<2LB0@0
_9Q41@2mVDD40;fHA`@0^iQ6102nVdX40<2LCP@0`imC1038XUT40<^UGPD0cJML1039XeP80<VTEPP0
bjAG103<Xe@40<jUEP@0cJAE1@3@YUX40<jXH@@0cZMT103<YVP40<fXL@@0fKF3103M_9440<V/Q0@0
_J1n1@2`UgT40;VOQ0@0_::7102cV7d40;6FN@@0]IQj102`TG840;FEK`@0]9AU1@2^ReD40:R6AP@0
YH0i102OO2/409ih9@@0X7HT102RLb<40:Qi:@D0ZW/[102^P3840:n6=P@0/H/j102aS3/40;JA@0@0
^991102nV4L40;fDA0D0_iA51030UDL40;nHB`@0`IY?1033WE@80<JPF@@0aIiI1033WUX50<BOF`@0
aJ1J1036XE/40<NQFP@0a9iG102oUe840;bDC`@0b:1K1@3;Xeh40<JOG0@0a9eJ1033X5h40<BQG`@0
`J9O1033Y64;0?ooo`002P3oool40;nFA0@0`9M51031V4P40<ROC`@0a9e>2@30VDX40;bEAP@0^9=3
102nVDT40<JQD0@0`Ia;102nVTH40;fIA@@0_IM21@31VdH40<RRC`@0aj5>1032W4/40;fGAP@0_iU6
1030VTL40<2LB0@0_9Q41@2mVDD40;fHA`@0^iQ6102nVdX40<2LCP@0`imC1038XUT40<^UGPD0cJML
1039XeP80<VTEPP0bjAG103<Xe@40<jUEP@0cJAE1@3@YUX40<jXH@@0cZMT103<YVP40<fXL@@0fKF3
103M_9440<V/Q0@0_J1n1@2`UgT40;VOQ0@0_::7102cV7d40;6FN@@0]IQj102`TG840;FEK`@0]9AU
1@2^ReD40:R6AP@0YH0i102OO2/409ih9@@0X7HT102RLb<40:Qi:@D0ZW/[102^P3840:n6=P@0/H/j
102aS3/40;JA@0@0^991102nV4L40;fDA0D0_iA51030UDL40;nHB`@0`IY?1033WE@80<JPF@@0aIiI
1033WUX50<BOF`@0aJ1J1036XE/40<NQFP@0a9iG102oUe840;bDC`@0b:1K1@3;Xeh40<JOG0@0a9eJ
1033X5h40<BQG`@0`J9O1033Y64;0?ooo`002P3oool40;nFA0@0`9M51031V4P40<ROC`@0a9e>2@30
VDX40;bEAP@0^9=3102nVDT40<JQD0@0`Ia;102nVTH40;fIA@@0_IM21@31VdH40<RRC`@0aj5>1032
W4/40;fGAP@0_iU61030VTL40<2LB0@0_9Q41@2mVDD40;fHA`@0^iQ6102nVdX40<2LCP@0`imC1038
XUT40<^UGPD0cJML1039XeP80<VTEPP0bjAG103<Xe@40<jUEP@0cJAE1@3@YUX40<jXH@@0cZMT103<
YVP40<fXL@@0fKF3103M_9440<V/Q0@0_J1n1@2`UgT40;VOQ0@0_::7102cV7d40;6FN@@0]IQj102`
TG840;FEK`@0]9AU1@2^ReD40:R6AP@0YH0i102OO2/409ih9@@0X7HT102RLb<40:Qi:@D0ZW/[102^
P3840:n6=P@0/H/j102aS3/40;JA@0@0^991102nV4L40;fDA0D0_iA51030UDL40;nHB`@0`IY?1033
WE@80<JPF@@0aIiI1033WUX50<BOF`@0aJ1J1036XE/40<NQFP@0a9iG102oUe840;bDC`@0b:1K1@3;
Xeh40<JOG0@0a9eJ1033X5h40<BQG`@0`J9O1033Y64;0?ooo`002P3oool40;jE@`@0`YU91033VTX4
0<JMCP@0a9e@1033W4l50;nICP@0^iE:102jUDL40;nJC0@0a9m?1035X5040<BOCP@0_9M6102jUT85
0;fIA@@0a9m>1036XE040<FQC@@0`im;1032WTX40;nKA`@0_IU31030W4H50;^G@`@0^iI5102gU484
0;ZFB0@0_i]=1032WU@40<JPE`@0bJ=L1@3=Ye`40<bVF`@0c:MI103;YUP40<bUF0@0bZ=F103<YEH4
0<^TE@@0bZ=F1@3=YU/40<nXH`@0d:UX103BZg040=F`N`@0gkZ=103M^iD40<V[Q`@0^ij01@2/TWT4
0;NMQP@0_jF>102cUh440:nCN`@0/YAj102dUGT40;NFM@@0/i=Z1@2/RUX40:N7C0@0X7dk102HLbD4
09ac8`@0W74R102PLR@40:Ef:0D0Zgd_102^PcD40:n8>@@0/H`l102eTT440;NB@P@0^952102nUdX4
0<2FBPT0`IE:2032VDX40;nHB`@0`9U>1031Ve040<BNE@@0`iiG1@32WEH80<>NE`@0aImF1033WE@4
0<>KE@@0`IUC1036VeL50<RMF@@0aj1K1035WUT40<>PG0@0aJ9N102oXE/40<BVH0/0oooo000:0?oo
o`@0_YE31032VDT40<>JBP@0aYe>1034WE040<>LC`D0_iU>102kUDX40;ZEA`@0_iY<1034Wdl40<FP
D0@0a9m>102lUdH40;ZF@PD0_IU51034Wdh40<JQD0@0aJ5=1033Wd/40<:NBP@0_i]7102mVD<40<2L
APD0^iM3102kUTD40;ND@P@0^YI8102oVdd40<:NE0@0aZ1G1039Xe`50<fWG0@0c:IK103<YeT40<^V
F0@0c:EH103:XeH40<bUEP@0bjAE103:XeH50<fVF`@0cjQS103@ZFP40=:[L0@0eK1k103O^Xd40=fk
U@@0bJ^7102kWX050:bBN@@0]if6102oYHh40;>GP@@0[i=k102bU7X40;BEN@@0]iIe102cTfX50:b:
FP@0YhM<102POC/409Qc9@@0W7<S102LLB840:1b90@0YGHX1@2[OBl40:j3=@@0[hPi102aS3`40;FB
@@@0]i92102hTD840;jGBP@0`9I:2@31UDX80<:IBP@0_iQ;1030VDh40<6KD0@0a9iE1033WUL50<:M
EPP0`iiG1035WeH40<>ME0@0`i]E1031VE<40<JKE`D0b9eI1037X5/40<FNF@@0`j1L1035XUh40;nQ
F`@0a:IP2`3oool000X0oooo102nUD<40<:IB@@0`iY:1036WDh40<BMD0@0`ia?1@2oVDh40;^EBP@0
^YE7102oVT`40<BOC`@0aJ1@1034Wdh40;bGAP@0^YI21@2mVDD40<BOCP@0aZ5@1035XDd40<>OB`@0
`Yi:102oVdL40;fI@`@0`9a61@2kUd<40;^FA@@0]iA2102jUTP40;nKC@@0`YiD1036X5L40<VSG0D0
cJML103<YU/40<bWF@@0bjIH103<YEP40<ZSEP@0c:EF103;Y5D40<ZSEPD0cJIK103?Z6<40=2YJ0@0
dZ]`103E/7/40=njS@@0gK^E1039ZhL40;^NP0D0[99i102gWHH40;nUSP@0/iN1102_Tg/40;:DNP@0
]9Ei102gUWD40;>CJPD0[8YJ102WQd`40:1m>`@0V7<U102LLb<409aa8P@0X78T102UMRP50:]m;`@0
[X<e102_R3T40;6<?0@0]I91102gTT840;RA@P@0_YM:1030UTX90<6EBPP0`YU:102oV4/40<2ICP@0
`I]@1034WUD40<>NE`D0`YeF2033WUL40<FOEP@0`ieD1033VeD40<6ID`@0aY]G1@38WET40<NPF`@0
aIiI1033X5`40<FRGP@0_j5K1034YV0;0?ooo`002P3oool40;jE@`@0`YU91033VTX40<JMCP@0a9e@
1033W4l50;nICP@0^iE:102jUDL40;nJC0@0a9m?1035X5040<BOCP@0_9M6102jUT850;fIA@@0a9m>
1036XE040<FQC@@0`im;1032WTX40;nKA`@0_IU31030W4H50;^G@`@0^iI5102gU4840;ZFB0@0_i]=
1032WU@40<JPE`@0bJ=L1@3=Ye`40<bVF`@0c:MI103;YUP40<bUF0@0bZ=F103<YEH40<^TE@@0bZ=F
1@3=YU/40<nXH`@0d:UX103BZg040=F`N`@0gkZ=103M^iD40<V[Q`@0^ij01@2/TWT40;NMQP@0_jF>
102cUh440:nCN`@0/YAj102dUGT40;NFM@@0/i=Z1@2/RUX40:N7C0@0X7dk102HLbD409ac8`@0W74R
102PLR@40:Ef:0D0Zgd_102^PcD40:n8>@@0/H`l102eTT440;NB@P@0^952102nUdX40<2FBPT0`IE:
2032VDX40;nHB`@0`9U>1031Ve040<BNE@@0`iiG1@32WEH80<>NE`@0aImF1033WE@40<>KE@@0`IUC
1036VeL50<RMF@@0aj1K1035WUT40<>PG0@0aJ9N102oXE/40<BVH0/0oooo000:0?ooo`@0_9=11034
Vd`40<BMCPP0a9eB1033Ve<50;nID0@0`9YA202oVE040<2KC@P0`Ia>102nVD/40;^FA@D0_9M61034
Wdh40<FPC`@0aZ=?1035XTh40<:PB@@0_I]4102lVT<40<2NA`D0_IY6102lVDL40;^HAP@0^YI8102o
VT`40<BNE@@0aj5H1037XEX50<ZTF`@0c:IM103?ZEh40=2ZG`@0cZQM1038XUL80<ZSEP@0c:EJ1@3>
YUh40<nXI@@0dJU[103B[W@40=FaO@@0gKb?103G^I<40<V/RP@0_J:51@2cVH040;NMQP@0_:2:102a
UGl40:nAN@@0/99j102dUWX40;>FMP@0/YE]1@2/SEh40:R;D`@0WWln102HM2P409I`7`@0VFhO102G
JA/40:Ef:0D0Zgd_102cR3T40:j8=`@0/Xdl102jUdD40;ZEA@@0]Hho102lUDP40<>IC@D0a9Q=1033
V4X40<FJB`@0a9Y81032VDT40<2GB0@0_9M7102mV4X40;nKC`d0`YiB2032W5440<BLE0@0b9iF1037
W5L50<VNF@@0b:1J103<YUl40<:PF0@0_9YB1034Y5/40=JfK@/0oooo000:0?ooo`@0_9=11034Vd`4
0<BMCPP0a9eB1033Ve<50;nID0@0`9YA202oVE040<2KC@P0`Ia>102nVD/40;^FA@D0_9M61034Wdh4
0<FPC`@0aZ=?1035XTh40<:PB@@0_I]4102lVT<40<2NA`D0_IY6102lVDL40;^HAP@0^YI8102oVT`4
0<BNE@@0aj5H1037XEX50<ZTF`@0c:IM103?ZEh40=2ZG`@0cZQM1038XUL80<ZSEP@0c:EJ1@3>YUh4
0<nXI@@0dJU[103B[W@40=FaO@@0gKb?103G^I<40<V/RP@0_J:51@2cVH040;NMQP@0_:2:102aUGl4
0:nAN@@0/99j102dUWX40;>FMP@0/YE]1@2/SEh40:R;D`@0WWln102HM2P409I`7`@0VFhO102GJA/4
0:Ef:0D0Zgd_102cR3T40:j8=`@0/Xdl102jUdD40;ZEA@@0]Hho102lUDP40<>IC@D0a9Q=1033V4X4
0<FJB`@0a9Y81032VDT40<2GB0@0_9M7102mV4X40;nKC`d0`YiB2032W5440<BLE0@0b9iF1037W5L5
0<VNF@@0b:1J103<YUl40<:PF0@0_9YB1034Y5/40=JfK@/0oooo000:0?ooo`@0_9=11034Vd`40<BM
CPP0a9eB1033Ve<50;nID0@0`9YA202oVE040<2KC@P0`Ia>102nVD/40;^FA@D0_9M61034Wdh40<FP
C`@0aZ=?1035XTh40<:PB@@0_I]4102lVT<40<2NA`D0_IY6102lVDL40;^HAP@0^YI8102oVT`40<BN
E@@0aj5H1037XEX50<ZTF`@0c:IM103?ZEh40=2ZG`@0cZQM1038XUL80<ZSEP@0c:EJ1@3>YUh40<nX
I@@0dJU[103B[W@40=FaO@@0gKb?103G^I<40<V/RP@0_J:51@2cVH040;NMQP@0_:2:102aUGl40:nA
N@@0/99j102dUWX40;>FMP@0/YE]1@2/SEh40:R;D`@0WWln102HM2P409I`7`@0VFhO102GJA/40:Ef
:0D0Zgd_102cR3T40:j8=`@0/Xdl102jUdD40;ZEA@@0]Hho102lUDP40<>IC@D0a9Q=1033V4X40<FJ
B`@0a9Y81032VDT40<2GB0@0_9M7102mV4X40;nKC`d0`YiB2032W5440<BLE0@0b9iF1037W5L50<VN
F@@0b:1J103<YUl40<:PF0@0_9YB1034Y5/40=JfK@/0oooo000:0?ooo`@0_9=11034Vd`40<BMCPP0
a9eB1033Ve<50;nID0@0`9YA202oVE040<2KC@P0`Ia>102nVD/40;^FA@D0_9M61034Wdh40<FPC`@0
aZ=?1035XTh40<:PB@@0_I]4102lVT<40<2NA`D0_IY6102lVDL40;^HAP@0^YI8102oVT`40<BNE@@0
aj5H1037XEX50<ZTF`@0c:IM103?ZEh40=2ZG`@0cZQM1038XUL80<ZSEP@0c:EJ1@3>YUh40<nXI@@0
dJU[103B[W@40=FaO@@0gKb?103G^I<40<V/RP@0_J:51@2cVH040;NMQP@0_:2:102aUGl40:nAN@@0
/99j102dUWX40;>FMP@0/YE]1@2/SEh40:R;D`@0WWln102HM2P409I`7`@0VFhO102GJA/40:Ef:0D0
Zgd_102cR3T40:j8=`@0/Xdl102jUdD40;ZEA@@0]Hho102lUDP40<>IC@D0a9Q=1033V4X40<FJB`@0
a9Y81032VDT40<2GB0@0_9M7102mV4X40;nKC`d0`YiB2032W5440<BLE0@0b9iF1037W5L50<VNF@@0
b:1J103<YUl40<:PF0@0_9YB1034Y5/40=JfK@/0oooo000:0?ooo`@0]hlj102oUTH40<>LC@@0aIiC
1032W5440<2JD@D0bJ=L1032W5D40;fGCP@0_9I=102jUDL40;nJC0@0`ia?1031VTd40;jIB0D0_iY9
1034XDl<0<>PCP@0_Yi;102lW4T80;bLA`D0`j1>102nVdT40<6LC0@0_iY<1030Vdd40<BNE@@0aZ1G
1037XEX90<^UG0@0bjMK103=ZEd40=6[HP@0cJMN203;YEX40<^UG0D0bJ=L103<Yf<40=>]KP@0f;Aj
103I]H440=jmT0@0f[bF1039[8X40;^PP`D0^In6102hWXL40;RLQ0@0]9R0102bU7`40;>EN`@0]IMk
102bUG<40;FHL0D0[Y9R102XRe<409f0?P@0TG0O102DL1X409Ua70@0VW0L102SMR<50:]n:`@0/hTe
102eRcL40;>=>P@0^98o102hTT440;ZD@`@0`9M81031V4T50;jGB0@0`iY;1035W4`40<BIBP@0`IQ9
1030UdP80;jGB0@0_iY<2@32WDl40<>ND0@0`ieB1032W5440<BMDP@0aIiC1036W5@50<FKD`@0aZ1G
1037XEP40<JRF0P0`imE1037XeT;0?ooo`002P3oool40;N?>P@0_iI61033W4d40<FND`@0`YaA1030
VU450<VSG0@0`YaE102mUdh40;bFC@@0^YE7102oVT`40<>LC`@0`IY=102nVDP50;nJB@@0a:5?3033
X4h40;jNB`@0_9a9202lW4L50<>PCP@0_Y]91031W4`40;nJC0@0`9]=1034WUD40<JPE`@0aj5J2@3;
YE`40<^WF`@0cJUM103AZf840<fWGPP0bjEJ103;YE`50<VSG0@0c:MS103C[Fh40=RdNP@0fKF1103N
_I040=ZlUP@0bJb:102kX8<50;VOQP@0^9j7102hW8@40;BHP0@0/YAl102cUG/40;FGN`@0/YEc102e
V7050:jBHP@0Z8]C102MP3h4095`7`@0U70J102ILA`409Y`70@0XgHS1@2[OR/40;>9=@@0]H/g102c
SCX40;RB?`@0^991102jU4<40<2GB0@0`IQ91@2nUdP40<>JB`@0aIa<1034VDX40<6HB@@0`9M8202n
UdP40;nJC0T0`Ye?1033WU040<>MDP@0`YaA1034WE840<FND`@0aYaD1@35Ve<40<JPE`@0aj5H1036
XUP80<>OE@@0aj=I2`3oool000X0oooo102gScX40;nFAP@0`ia=1035WU<40<:LD@@0`9YA1@39Xe`4
0<:LE@@0_IM>102lUTd40;ZEA`@0_iY<1033W4l40<6JC@@0_YU81@2oVTT40<BQC``0`j1>102nWT/4
0;bLB@P0_9a71@33X4h40;jKB@@0`Ia<102oVT`40<2KC@@0a9iE1036X5L40<NQFPT0bjEL103;Ye/4
0<fYG@@0dJ]R103=Yeh80<^UFP@0bjEL1@39Xe`40<bWH`@0dje^103H]7X40=VeP@@0g[f@103J_9H4
0<V/RP@0^j231@2iWhH40;RNQ`@0^9b4102dV8040;:DO0@0/iEk102eUg/40;:EL`@0]IQ`1@2^TV84
0:R;D`@0WH0n102AL1l409A`6P@0VG4L102JL1`40:=f8`D0Zgh[102cRCD40;F;=`@0/hdj102hTSl4
0;RB@@@0^YA31030UdP40<6HB@D0_YM81033VT/40<FLC0@0a9U:1031V4T40<2GB0P0_YM8102oVT`9
0<:MC`@0`ii@1033WE840<:LD@@0a9eB1035WU<40<JLE0D0aI]C1036X5L40<NQF0@0aZ9H2033WeD4
0<NSF@/0oooo000:0?ooo`@0]hlj102oUTH40<>LC@@0aIiC1032W5440<2JD@D0bJ=L1032W5D40;fG
CP@0_9I=102jUDL40;nJC0@0`ia?1031VTd40;jIB0D0_iY91034XDl<0<>PCP@0_Yi;102lW4T80;bL
A`D0`j1>102nVdT40<6LC0@0_iY<1030Vdd40<BNE@@0aZ1G1037XEX90<^UG0@0bjMK103=ZEd40=6[
HP@0cJMN203;YEX40<^UG0D0bJ=L103<Yf<40=>]KP@0f;Aj103I]H440=jmT0@0f[bF1039[8X40;^P
P`D0^In6102hWXL40;RLQ0@0]9R0102bU7`40;>EN`@0]IMk102bUG<40;FHL0D0[Y9R102XRe<409f0
?P@0TG0O102DL1X409Ua70@0VW0L102SMR<50:]n:`@0/hTe102eRcL40;>=>P@0^98o102hTT440;ZD
@`@0`9M81031V4T50;jGB0@0`iY;1035W4`40<BIBP@0`IQ91030UdP80;jGB0@0_iY<2@32WDl40<>N
D0@0`ieB1032W5440<BMDP@0aIiC1036W5@50<FKD`@0aZ1G1037XEP40<JRF0P0`imE1037XeT;0?oo
o`002P3oool40;J>=`@0^i901030VDX40<NPD`@0`ieB1032W5450<FOE0@0b:9G1034We440;nJC0@0
`9U:202oV4T40<JOD0T0_iY91035X5040<>NCPP0`Ii=102mW4/40;bKBPP0^iY91@37Y5840<>PCP@0
`ii>1031W4`40<2KB`@0`ii@1037XEH40<JPE`T0aj5F1039YET40<jZGP@0dJ]R103<YUd80<fWG0@0
bjEL1@34WUL40<>PG0@0dZm_103J]gd40=NfP@@0g[fB103N`9X40<f`T0@0^Yn21@2jX8L40;^OR@@0
^9b6102hVH@40;JFO`@0]9Ak102eUg/40;FHMP@0]iYb1@2dV6P40:f@EP@0WH0l102BLb04095_5P@0
UW4I102LLQ`40:Ii9PD0[h0^102dQc@40;J9=P@0]Xdk102kTT080;fDA0@0_9E61030VDX50<2LCP@0
`9]=1031W4h40<>LC`@0a9e@1032Vdh40<2IC0@0_iQ;1030VD`50<:KCP@0a9eB1033W5480<:KD0@0
a9eB1033W5440<VRE`D0aIiC1038X5P40<jVGP@0c:AL1036WUH40<NPE@@0`Y]@2`3oool000X0oooo
102fSSL40;^B@0@0`9U:1037X5<40<>MDP@0`YaA1@35We@40<RRE`@0a9mA102oVT`40<2IBPP0_iQ9
1036We090;nJB@@0aJ1@1033WTh80<6NC@@0_Ia;102lVdX80;^JB@D0ajAB1033X4h40<>NCP@0`Ia<
1030Vd/40<>ND0@0aj5F1036X5L90<NQEP@0bJEI103>ZUh40=6[HP@0c:IM203=Ye`40<^UG0D0a9iG
1033X5`40=:_K`@0f[Mm103G]X440=jmTP@0g/2J103=/9040;ZOPPD0^Z27102kWhT40;RLQP@0^9V4
102fUWl40;BDN`@0]IMk102eV7H40;NJLPD0]9QX102]T5H409f0?0@0TW<P102AKaH409Ia6@@0W78L
102VNBH50:n0;P@0]8Ld102fRCH40;J=>`@0^i90202mU4@40;bEAP@0`9U:1@30W4h40<2KC@@0`Ia>
1033W4l40<BMD0@0`Y]>1030VD`40;nHB`@0`9U<1@32Vdh40<BMDP@0`iaA2032Ve040<BMDP@0`iaA
1039XUL50<FND`@0b:1H103>YUh40<bTG0@0aYiF1037X5D40<:KD0/0oooo000:0?ooo`@0]Xhg102k
TT040<2IBP@0aj1C1033WE840<:LD@D0aImD1038XUL40<BOD@@0_iY<1030VDX80;nHB@@0aYm@2@2o
VTT40<FPD0@0`ii>2031WTd40;fLB`@0_9]:202kVTT50<NTDP@0`j1>1033WTh40<6LC0@0`9];1033
WU040<NQEP@0aZ1G2@37XEH40<VUF@@0cZYN103AZf840<bVG@P0cJML103;YE`50<BNE`@0`j1L103B
[fl40=ZgO@@0ekJ1103N_I840=k0VP@0cK2@102jWh850;ZPQ`@0^in9102hW8H40;RIQ0@0]YIo102d
U7/40;FGN`@0]IQf102gVW850;BHJ0@0[I1F102MP3`4099c80@0TFlF102FLAT409ab70@0YWTV1@2_
P2h40;B7=0@0]XTf102fSC/40;^B@0P0_IA4102lUDH40<2IBPD0`9a>1030Vdd40<6LCP@0`ia?1034
WE040<:KCP@0`9U<102oV4/40<2IC0D0`Y]>1034WE840<>LD@P0`Y]@1034WE840<>LD@@0bJ9G1@35
WU<40<RPF0@0cZIN103<Y5`40<JNEP@0aj1E1032Ve0;0?ooo`002P3oool40;J>=`@0^i901030VDX4
0<NPD`@0`ieB1032W5450<FOE0@0b:9G1034We440;nJC0@0`9U:202oV4T40<JOD0T0_iY91035X504
0<>NCPP0`Ii=102mW4/40;bKBPP0^iY91@37Y5840<>PCP@0`ii>1031W4`40<2KB`@0`ii@1037XEH4
0<JPE`T0aj5F1039YET40<jZGP@0dJ]R103<YUd80<fWG0@0bjEL1@34WUL40<>PG0@0dZm_103J]gd4
0=NfP@@0g[fB103N`9X40<f`T0@0^Yn21@2jX8L40;^OR@@0^9b6102hVH@40;JFO`@0]9Ak102eUg/4
0;FHMP@0]iYb1@2dV6P40:f@EP@0WH0l102BLb04095_5P@0UW4I102LLQ`40:Ii9PD0[h0^102dQc@4
0;J9=P@0]Xdk102kTT080;fDA0@0_9E61030VDX50<2LCP@0`9]=1031W4h40<>LC`@0a9e@1032Vdh4
0<2IC0@0_iQ;1030VD`50<:KCP@0a9eB1033W5480<:KD0@0a9eB1033W5440<VRE`D0aIiC1038X5P4
0<jVGP@0c:AL1036WUH40<NPE@@0`Y]@2`3oool000X0oooo102fSSL40;^B@0@0`9U:1037X5<40<>M
DP@0`YaA1@35We@40<RRE`@0a9mA102oVT`40<2IBPP0_iQ91036We090;nJB@@0aJ1@1033WTh80<6N
C@@0_Ia;102lVdX80;^JB@D0ajAB1033X4h40<>NCP@0`Ia<1030Vd/40<>ND0@0aj5F1036X5L90<NQ
EP@0bJEI103>ZUh40=6[HP@0c:IM203=Ye`40<^UG0D0a9iG1033X5`40=:_K`@0f[Mm103G]X440=jm
TP@0g/2J103=/9040;ZOPPD0^Z27102kWhT40;RLQP@0^9V4102fUWl40;BDN`@0]IMk102eV7H40;NJ
LPD0]9QX102]T5H409f0?0@0TW<P102AKaH409Ia6@@0W78L102VNBH50:n0;P@0]8Ld102fRCH40;J=
>`@0^i90202mU4@40;bEAP@0`9U:1@30W4h40<2KC@@0`Ia>1033W4l40<BMD0@0`Y]>1030VD`40;nH
B`@0`9U<1@32Vdh40<BMDP@0`iaA2032Ve040<BMDP@0`iaA1039XUL50<FND`@0b:1H103>YUh40<bT
G0@0aYiF1037X5D40<:KD0/0oooo000:0?ooo`@0^Y8k102lTd440;nIB0@0aYmB1032WDl40<6KD0D0
`9a>1035XE<40<ZUE0@0a9m>1030VTT<0;jHA`T0`9Y91034Wdl40<>ND0@0`Ye?1031Ve040;jJCP@0
_9Q<102lV4X40;fIB`D0aZ=A103?[5X40<VTD`@0_iY9102nVDP80<>NCP@0aJ1B1@38XeD80<NRE0@0
bZEG103>Z5d40<fWG0@0bjEJ103>Z5d40<fWGPD0a9iG102nVeL40=2]K@@0f[Qk103J^H@40=jmT0@0
gKbI103A]9@40<FWS@D0_j>=102mXH`40;bMR0@0^YZ5102hV8440;>AN0@0]9Ei102hVWP40;VIL0D0
]IMU102aTeL409n1>`@0Tg8Q102AKAL409Qb7`@0W78P102WOB/50:n2<@@0]8Hh102gRC/80;ZA@P@0
_YA81030UTX40;jHC@@0`9Y?2@30WU@40<2LDP@0aZ9H103:Y5T40<BND`@0_iY<1030Vdd40<:KD0D0
`IY?1035WU<40<:KD0@0`9Q@1031VE480<BNE@@0cJMN1@39XeX40<NOF@@0bZ9L103<Y5h40<VQF`P0
a9aD2`3oool000X0oooo102jTS/40;bC@@@0_iU81036We840<:MC`@0`I]@1@30W4h40<FQD`@0bZED
1034Wdh40<2JB@`0_YQ72@30VTT40<BOC`@0`ii@1032WDl40<6KD0@0_YY>102lV4`40;bHBP@0_IU;
1@36Xe440<n/FP@0bJAC102oVTT40;jIB0P0`ii>1035X5850<RSE@P0aj9D103:YEL40<jXG@@0cJML
103;YEX40<jXG@@0cJMN1@34WUL40;jKE`@0d:e]103J^7/40=ZiQ0@0g[f@103M_9T40=6dU0@0aJN=
1@2oXhd40;fQS0@0_9f8102jVXD40;RHP@@0/i5h102dUGT40;RJN0@0^IU`1@2eUfD40;6CE`@0Wh4k
102CLR44095]5`@0V78O102LLR040:Mm:`D0[h8a102dQSP40;N9>`P0^Y52102nU4P40<2FBP@0_YQ=
1030VTl90<2NE0@0`9aB1036XUP40<ZTF@@0a9iC102oVT`40<2KC@@0`Y]@1@31VTl40<FND`@0`Y]@
1030V5040<6ID@P0a9iE103=Yeh50<VSFP@0aimI103:XU`40<bTGP@0bJ5K2034W5@;0?ooo`002P3o
ool40;ZB>`@0_9=1102oVDP40<JODP@0`Ye?1031Ve050<2LCP@0aJ5C103:YE@40<BOCP@0`9Y9302n
V4L90<2JB@@0a9m?1033WU040<:MC`@0`I]@102nVTh40;bHC0@0_9Q:102mVD/50<JSD@@0cjaJ1039
Y5<40;nJB@@0_YU82033WTh40<FPDPD0b:=E2037XU@40<ZUE`@0cZQM103=Ye`40<^UFP@0cZQM103=
Yeh50<BNE`@0_Y]G103@[Fd40=ZhN`@0f[V4103N_I040=flV@@0dKBD1035Yhd50;nSS@@0_J6<102l
WHP40;ZJQ@@0^9R1102cTGP40;BEN@@0^9Yh102iVG050;FGI@@0/I=G102OPC/409=b8@@0TFdG102H
LQl409ab80@0Ygd[1@2_PS440;B6>0@0]hTk202jTD840;jDB0@0`9I:102nV4d40<2JC`T0`9iD1030
W5840<JRF0@0bZAI1034WU<40;nJC0@0`9]=1032Ve050<6JC`@0aIiC1032Ve040<2HD0@0`IUA2034
WUD40<fWGPD0bJ=J1037WeT40<ZRG0@0c:AN1039XE/80<BLE0/0oooo000:0?ooo`@0^Y8k102lTd44
0;nIB0@0aYmB1032WDl40<6KD0D0`9a>1035XE<40<ZUE0@0a9m>1030VTT<0;jHA`T0`9Y91034Wdl4
0<>ND0@0`Ye?1031Ve040;jJCP@0_9Q<102lV4X40;fIB`D0aZ=A103?[5X40<VTD`@0_iY9102nVDP8
0<>NCP@0aJ1B1@38XeD80<NRE0@0bZEG103>Z5d40<fWG0@0bjEJ103>Z5d40<fWGPD0a9iG102nVeL4
0=2]K@@0f[Qk103J^H@40=jmT0@0gKbI103A]9@40<FWS@D0_j>=102mXH`40;bMR0@0^YZ5102hV844
0;>AN0@0]9Ei102hVWP40;VIL0D0]IMU102aTeL409n1>`@0Tg8Q102AKAL409Qb7`@0W78P102WOB/5
0:n2<@@0]8Hh102gRC/80;ZA@P@0_YA81030UTX40;jHC@@0`9Y?2@30WU@40<2LDP@0aZ9H103:Y5T4
0<BND`@0_iY<1030Vdd40<:KD0D0`IY?1035WU<40<:KD0@0`9Q@1031VE480<BNE@@0cJMN1@39XeX4
0<NOF@@0bZ9L103<Y5h40<VQF`P0a9aD2`3oool000X0oooo102iTC`40;bC@`@0_iQ91034WE040;nK
C@@0_IU;1@2lVDP40<FRD@@0c:QD1031WDT40;fGA0@0^98o102mU4@40<:IB@@0`9U:1@31VT/40<JO
DP@0aIiA1033W5440<:KD0@0_iU>102kUDX40;fHB0@0_YU91@35X4l40=6/F`@0bjIE1030VdX40;^F
A@@0`Ia;2034WDh90<FPC`@0b:=C1039Y5@40<^VF0@0bZEG103<YU/80<jXG@D0aj5H102nW5D40=6^
K0@0g;Ym103R_hT40=noT0@0f[RB103C]I440<j_TPD0`jR=102oXHT40;bNQ0@0_9b3102jV7`40;BC
M0@0^9Md102mWG@40;bLJ`D0/91G102YRdD409ak;P@0TVlK102AK1@409Ua70@0XWPV102]P2l50;^=
?`@0/HPi102dRc`40;><?`@0]Xm2102kU4T40;jGC0@0`ieD1035WeH50<6OE@@0_9Y@1031X5<40<BS
EP@0aZ9D1031WDl40<2MC0@0`Ym>1034We450<:LD@@0`ieB1032W5<40<:LE@@0a9iG1036WeX40<FN
F@@0b:9K1@36X5T40<NPF`@0bjAO103@ZF@40<RQG0@0b:9K103;YEh;0?ooo`002P3oool40;VA?0@0
_9=3102oV4T40<BMD0@0_i]=102mVD/50;bIB0@0aJ9A103<Z5@40<6MB@@0_IM4102hTSl40;fDA0@0
`YU91030VDX50<6JB`@0aYmB1035WU440<>LD@@0`Y]@102oVDh40;^EBP@0_IQ8102nVDT50<FPC`@0
dJaK103;YUD40<2KBP@0^iI51031W4/80<BMCPT0aJ1?1038Xe<40<VTE0@0bjIH103:YEL40<bVF`P0
cZQM1@37XEP40;jLE@@0dJi/103L^Wd40>:oR@@0gkn@103J^9840=>eT@@0cZnB1@33Z8d40;nQR@@0
_9j4102lW8<40;ZHO0@0]9=d102hUg@40;fMM0@0_9a[1@2`T5L40:V;A@@0W7/^102BKa/4095/50@0
VG4L102RN2H40:f0;`D0^hdo102aR3T40;B;?0@0/h`o102fSd840;^DB@@0_YM<1033WE@40<FOEPD0
`ImE102lVU040<6PD`@0a:=F1036XU@40<6MC`@0`9e<1032Wdh40<BOD@D0`YaA1033WE840<:LD`@0
`YaE1034WUL40<JOFP@0aIiI1038XU/50<JPF@@0aj1K103;Y5l40=2YI0@0b:5L1038XU/40<^UGP/0
oooo000:0?ooo`@0^I4l102lTd<40;nHB@@0a9e@102oVdd40;fIB`D0_9U81035XU440<bXE0@0`Ie9
102mUd@40;RB?`@0_IA41032VDT40<2IBPD0`IY;1036We840<FND@@0`iaA1032Ve040;nICP@0^iE:
102mV4P40;jIB@D0aJ1?103A[5/40<^VE@@0`9]:102kUTD40<6LB`P0a9e>2@35X4l40<RSD`@0bJAD
103;YUP40<ZUE`@0c:IK203>Z5d50<NQF0@0_YaE103A[V`40=bjO@@0h[n9103O_i040=ZhTP@0dkFA
103>[i850<>XS@@0_j69102lWX@40;bLP`@0^YQl102dTg@40;RGM0@0_Ied102lW6/50;2@E`@0ZH]5
102LNbh4099_6`@0TF`D102ILA`40:9h9P@0[H0_1@2kSCl40;68>@@0]8/l102cS3l40;J?@P@0^iA9
102nUd`40<>ME0@0aImF1@31WeD40;bJD0@0`J1C1034XeH40<JRE0@0`Ie?1030WD`40<:OCP@0a9mA
1@32W5440<>MDP@0`YaC1032W5D40<BNE`@0aYmJ1035WUT40<RRF`D0aZ1I1037X5/40<^TG`@0d:UT
1038XE`40<RRF`@0bjEN2`3oool000X0oooo102iTC`40;bC@`@0_iQ91034WE040;nKC@@0_IU;1@2l
VDP40<FRD@@0c:QD1031WDT40;fGA0@0^98o102mU4@40<:IB@@0`9U:1@31VT/40<JODP@0aIiA1033
W5440<:KD0@0_iU>102kUDX40;fHB0@0_YU91@35X4l40=6/F`@0bjIE1030VdX40;^FA@@0`Ia;2034
WDh90<FPC`@0b:=C1039Y5@40<^VF0@0bZEG103<YU/80<jXG@D0aj5H102nW5D40=6^K0@0g;Ym103R
_hT40=noT0@0f[RB103C]I440<j_TPD0`jR=102oXHT40;bNQ0@0_9b3102jV7`40;BCM0@0^9Md102m
WG@40;bLJ`D0/91G102YRdD409ak;P@0TVlK102AK1@409Ua70@0XWPV102]P2l50;^=?`@0/HPi102d
Rc`40;><?`@0]Xm2102kU4T40;jGC0@0`ieD1035WeH50<6OE@@0_9Y@1031X5<40<BSEP@0aZ9D1031
WDl40<2MC0@0`Ym>1034We450<:LD@@0`ieB1032W5<40<:LE@@0a9iG1036WeX40<FNF@@0b:9K1@36
X5T40<NPF`@0bjAO103@ZF@40<RQG0@0b:9K103;YEh;0?ooo`002P3oool40;J=>`@0^Y52102oV4T4
0<BMD0@0`Yi@102nVT`50;fJB0@0_Y]91038Y5040<6MB@@0`9Y7102lUT<40<6HB0@0`9M81030VD`5
0<BMDP@0b:5F1036We@40<>LD@@0`IY?1031VTd40;fFB@@0_YQ7102mUdH50<FOCP@0aZ1?1035X4l4
0<:MC0@0^IA3102nVDP40<>MC0@0a9i=2@35XDd40<NRD@@0aJ1@1037XU840<VTEP@0cJQJ103;YUP4
0<^UFPD0bJ=J1030WUH40=2]J@@0eK=d103I]Wh40=ZiQ0@0f;N:103G]hh40=:dT0D0b:^;1030XhD4
0;^LO@@0^iYk102eU7440;NEL0@0_9]`1031XG040<FUJPD0[Ha9102QPS8409Qe8@@0SfXA102CJa<4
09ie7@@0X7HP102XORX50;F;>@@0[XPe102cS3d40;F@@0@0/hi0102fTD<40;^FB0@0aZ5C1035X589
0<BPDP@0a:=D1033XU<40<6PC`@0_Ye<102kVdP40;bLB@@0_Ye<1@30We040<6MD@@0`YeF1034WeP4
0<BOF@P0aIiK1035W5X50<ROG@@0aZ5M1038Xel40=VdKP@0bjIP2037XU`;0?ooo`002P3oool40;J=
>`@0^Y52102oV4T40<BMD0@0`Yi@102nVT`50;fJB0@0_Y]91038Y5040<6MB@@0`9Y7102lUT<40<6H
B0@0`9M81030VD`50<BMDP@0b:5F1036We@40<>LD@@0`IY?1031VTd40;fFB@@0_YQ7102mUdH50<FO
CP@0aZ1?1035X4l40<:MC0@0^IA3102nVDP40<>MC0@0a9i=2@35XDd40<NRD@@0aJ1@1037XU840<VT
EP@0cJQJ103;YUP40<^UFPD0bJ=J1030WUH40=2]J@@0eK=d103I]Wh40=ZiQ0@0f;N:103G]hh40=:d
T0D0b:^;1030XhD40;^LO@@0^iYk102eU7440;NEL0@0_9]`1031XG040<FUJPD0[Ha9102QPS8409Qe
8@@0SfXA102CJa<409ie7@@0X7HP102XORX50;F;>@@0[XPe102cS3d40;F@@0@0/hi0102fTD<40;^F
B0@0aZ5C1035X5890<BPDP@0a:=D1033XU<40<6PC`@0_Ye<102kVdP40;bLB@@0_Ye<1@30We040<6M
D@@0`YeF1034WeP40<BOF@P0aIiK1035W5X50<ROG@@0aZ5M1038Xel40=VdKP@0bjIP2037XU`;0?oo
o`002P3oool40;J=>`@0^Y52102oV4T40<BMD0@0`Yi@102nVT`50;fJB0@0_Y]91038Y5040<6MB@@0
`9Y7102lUT<40<6HB0@0`9M81030VD`50<BMDP@0b:5F1036We@40<>LD@@0`IY?1031VTd40;fFB@@0
_YQ7102mUdH50<FOCP@0aZ1?1035X4l40<:MC0@0^IA3102nVDP40<>MC0@0a9i=2@35XDd40<NRD@@0
aJ1@1037XU840<VTEP@0cJQJ103;YUP40<^UFPD0bJ=J1030WUH40=2]J@@0eK=d103I]Wh40=ZiQ0@0
f;N:103G]hh40=:dT0D0b:^;1030XhD40;^LO@@0^iYk102eU7440;NEL0@0_9]`1031XG040<FUJPD0
[Ha9102QPS8409Qe8@@0SfXA102CJa<409ie7@@0X7HP102XORX50;F;>@@0[XPe102cS3d40;F@@0@0
/hi0102fTD<40;^FB0@0aZ5C1035X5890<BPDP@0a:=D1033XU<40<6PC`@0_Ye<102kVdP40;bLB@@0
_Ye<1@30We040<6MD@@0`YeF1034WeP40<BOF@P0aIiK1035W5X50<ROG@@0aZ5M1038Xel40=VdKP@0
bjIP2037XU`;0?ooo`002P3oool40;J=>`@0^Y52102oV4T40<BMD0@0`Yi@102nVT`50;fJB0@0_Y]9
1038Y5040<6MB@@0`9Y7102lUT<40<6HB0@0`9M81030VD`50<BMDP@0b:5F1036We@40<>LD@@0`IY?
1031VTd40;fFB@@0_YQ7102mUdH50<FOCP@0aZ1?1035X4l40<:MC0@0^IA3102nVDP40<>MC0@0a9i=
2@35XDd40<NRD@@0aJ1@1037XU840<VTEP@0cJQJ103;YUP40<^UFPD0bJ=J1030WUH40=2]J@@0eK=d
103I]Wh40=ZiQ0@0f;N:103G]hh40=:dT0D0b:^;1030XhD40;^LO@@0^iYk102eU7440;NEL0@0_9]`
1031XG040<FUJPD0[Ha9102QPS8409Qe8@@0SfXA102CJa<409ie7@@0X7HP102XORX50;F;>@@0[XPe
102cS3d40;F@@0@0/hi0102fTD<40;^FB0@0aZ5C1035X5890<BPDP@0a:=D1033XU<40<6PC`@0_Ye<
102kVdP40;bLB@@0_Ye<1@30We040<6MD@@0`YeF1034WeP40<BOF@P0aIiK1035W5X50<ROG@@0aZ5M
1038Xel40=VdKP@0bjIP2037XU`;0?ooo`002P3oool40;RB@@@0]Y0o102lUdL40<2KB`@0`Ia<1030
Vd/90;nHB@P0`iY:1032VDT40<6HB0@0_YQ71032Vd`40<6MC`D0a9iC1037XEH40<RQEP@0aii?1034
Vd`40<2JB@@0_YQ7202oVDH50<>JB0@0a9]91034WT/40;nIAP@0]I8n102lVDL40<2MB`@0`Ii=1@33
We440<FQD`P0`imA1036XE440<:MC@@0aj9D103;YEX40<ZUGPD0bJAP1036XEd40=2ZJ@@0f[Ac103F
/W@40=ZgO@@0f[V4103N_8h40>2mT`D0cJ^51036Y7l40<BTN`@0_j1d102kW6d40;^KJ0@0^iaS1037
YFH40;NECPD0[HPj102PO2@409M`4`@0VFh@102LKa8409mg60@0Y7/Q102ZPRX90;28<`@0/XTg102d
RCX40;N<?@@0^8do102jT4@40;nHB`@0`IeA1@32X5H40<JVF`@0ajMJ1034Y5L40<2QC`@0^ia:102l
W4T40;ZJA`@0_Y]:1@2oVdd40<6LCP@0`ieD1033WEH40<6JE@@0`Y]H1035WU/40<FOGPD0`ieL1031
WUX40<JSG`@0d:iW1037YEh40<:PF0@0a:9J2`3oool000X0oooo102hTT440;J@?`@0_9M71030Vd/4
0<6LC0@0`9];2@2oV4T80<>JBP@0`YU91031V4P40;jHA`@0`Y]<1031WDl50<BND`@0aj5F1038XEH4
0<NNC`@0a9]<1030VTT40;jHA`P0_iU61@33VTP40<BKB@@0a9i;102oVDH40;FB?P@0_9U71030WD/4
0<6NC@D0`imA1035XE<80<>OD@@0aZ5A1032WDd40<NRE0@0bjEJ103:YEh50<VTH0@0aZ5M103@ZVT4
0=ZdL`@0e[9d103J]gd40=ZiQ0@0g[b>103P_I<50<f[Q@@0aZAo1034Y7/40;nPM0@0^ia]102kVfP4
0;^LH`@0ajEV102gUDh50:f8>P@0X7`T102GL1<409U^40@0W6lB102OMaP40:Ak8@@0ZX8Z2@2`R3<4
0;:9=`@0]8Tj102gS3d40;R=?`@0^Y14102oV4/40<6MD@D0`Z1F1036YU/40<NWFP@0a:AG1030XDl4
0;^LBP@0_9a9102jVTL40;jKBPD0_i]=1031W4h40<>ME0@0`ieF1031VUD40<:KF0@0aIiK1035Weh5
0<>MG0@0`IiJ1036Xel40=2^I`@0ajEN1032X5P40<BRFP/0oooo000:0?ooo`@0^991102fT3l40;bG
A`@0`9];1031W4`40<2KB`T0_iQ92033VTX40<:IB@@0`IQ8102nV4L40<:KC0@0`Ie?1@34WU<40<NQ
EP@0b:5F1037WTl40<BKC0@0`9Y9102nV4L80;nIAPD0`iY81034VdT40<BNB`@0_iU6102eTSh40;bI
A`@0`9e;1031WTd50<>OD@@0aJ5C2033We440<JQD@@0`Ye=1037XU@40<^UFP@0bZEN1@39Y6040<JQ
G@@0d:YY103J]7<40=JbM0@0f[Mm103J^H@40=jlSP@0h;fC1@3=ZhD40<JTO`@0a:Ak102oX7@40;^L
K@@0^i]X102kW6<40<NUIP@0]iE>1@2]R3X40:1l90@0Ug0C102IKQ0409a_4P@0WgLH102TNb440:Z2
:PT0/8Pc102bRCL40;B9>P@0]h`m102hSCl40;Z@A0@0_iQ;1031WE450<:PEP@0aZIK1037YeX40<BT
E`@0`:5?102kW4X40;bLB@@0^YY7102nVdX50;nKC@@0`Ia>1033WE@40<>MEP@0`IYE1032VeP40<FN
F`@0aImN1@33WE`40<6NFP@0aZ=O103@[VL40<NUGP@0`Z1H1034XUX;0?ooo`002P3oool40;RB@@@0
]Y0o102lUdL40<2KB`@0`Ia<1030Vd/90;nHB@P0`iY:1032VDT40<6HB0@0_YQ71032Vd`40<6MC`D0
a9iC1037XEH40<RQEP@0aii?1034Vd`40<2JB@@0_YQ7202oVDH50<>JB0@0a9]91034WT/40;nIAP@0
]I8n102lVDL40<2MB`@0`Ii=1@33We440<FQD`P0`imA1036XE440<:MC@@0aj9D103;YEX40<ZUGPD0
bJAP1036XEd40=2ZJ@@0f[Ac103F/W@40=ZgO@@0f[V4103N_8h40>2mT`D0cJ^51036Y7l40<BTN`@0
_j1d102kW6d40;^KJ0@0^iaS1037YFH40;NECPD0[HPj102PO2@409M`4`@0VFh@102LKa8409mg60@0
Y7/Q102ZPRX90;28<`@0/XTg102dRCX40;N<?@@0^8do102jT4@40;nHB`@0`IeA1@32X5H40<JVF`@0
ajMJ1034Y5L40<2QC`@0^ia:102lW4T40;ZJA`@0_Y]:1@2oVdd40<6LCP@0`ieD1033WEH40<6JE@@0
`Y]H1035WU/40<FOGPD0`ieL1031WUX40<JSG`@0d:iW1037YEh40<:PF0@0a:9J2`3oool000X0oooo
102nV4D40;bF@`@0^iI5102oVTT40<BOC`@0`Ia<1@2nVDT80;fHB0@0_YU91030Vd/40;nJBP@0_IY9
1030WD`40<6MC`D0`ii@1033WTh40<JOD0@0bJ1A1038We080<>MC0P0`iY81@34VTP40<JLBP@0bZ9=
1030V4<40;:>>0@0_YY6102oW4/40<:ND0D0aJ5E1038Y5P40<RRE`@0aZ1E1036XE<40<BOD@@0aj9D
103:Y5T40<ZTF`D0bJ=L103:Y5d40=2ZH`@0fKE[103M^7440=RgLP@0f;If103G]7X40=BaN`D0dK1k
103A/7d40=VhPP@0cJed1038Z6d40<FSI0@0_YaL102mV5840;J@A@D0[hHd102NMQh40:1g6`@0XgPI
102RMaT40:Al7@@0ZH0V102^Qb`50;69<P@0]8`e102hT3/40;R>?0@0]HXk102eS3`40;V?@`@0_9M9
1031Ve050<:PEP@0aJ=I103<[5l40<RXF`@0_Ii>102lWDd40;ZJA`@0^YM5102lVDL90<6LC0@0`YaA
1034W5@40<:JE0@0`IYE1034WEP40<JOG0D0aIiK1032WEL40<JQF`@0cJQR1038Xed40<BOF0@0aZ5J
2`3oool000X0oooo102nV4D40;bF@`@0^iI5102oVTT40<BOC`@0`Ia<1@2nVDT80;fHB0@0_YU91030
Vd/40;nJBP@0_IY91030WD`40<6MC`D0`ii@1033WTh40<JOD0@0bJ1A1038We080<>MC0P0`iY81@34
VTP40<JLBP@0bZ9=1030V4<40;:>>0@0_YY6102oW4/40<:ND0D0aJ5E1038Y5P40<RRE`@0aZ1E1036
XE<40<BOD@@0aj9D103:Y5T40<ZTF`D0bJ=L103:Y5d40=2ZH`@0fKE[103M^7440=RgLP@0f;If103G
]7X40=BaN`D0dK1k103A/7d40=VhPP@0cJed1038Z6d40<FSI0@0_YaL102mV5840;J@A@D0[hHd102N
MQh40:1g6`@0XgPI102RMaT40:Al7@@0ZH0V102^Qb`50;69<P@0]8`e102hT3/40;R>?0@0]HXk102e
S3`40;V?@`@0_9M91031Ve050<:PEP@0aJ=I103<[5l40<RXF`@0_Ii>102lWDd40;ZJA`@0^YM5102l
VDL90<6LC0@0`YaA1034W5@40<:JE0@0`IYE1034WEP40<JOG0D0aIiK1032WEL40<JQF`@0cJQR1038
Xed40<BOF0@0aZ5J2`3oool000X0oooo102nV4D40;bF@`@0^iI5102oVTT40<BOC`@0`Ia<1@2nVDT8
0;fHB0@0_YU91030Vd/40;nJBP@0_IY91030WD`40<6MC`D0`ii@1033WTh40<JOD0@0bJ1A1038We08
0<>MC0P0`iY81@34VTP40<JLBP@0bZ9=1030V4<40;:>>0@0_YY6102oW4/40<:ND0D0aJ5E1038Y5P4
0<RRE`@0aZ1E1036XE<40<BOD@@0aj9D103:Y5T40<ZTF`D0bJ=L103:Y5d40=2ZH`@0fKE[103M^744
0=RgLP@0f;If103G]7X40=BaN`D0dK1k103A/7d40=VhPP@0cJed1038Z6d40<FSI0@0_YaL102mV584
0;J@A@D0[hHd102NMQh40:1g6`@0XgPI102RMaT40:Al7@@0ZH0V102^Qb`50;69<P@0]8`e102hT3/4
0;R>?0@0]HXk102eS3`40;V?@`@0_9M91031Ve050<:PEP@0aJ=I103<[5l40<RXF`@0_Ii>102lWDd4
0;ZJA`@0^YM5102lVDL90<6LC0@0`YaA1034W5@40<:JE0@0`IYE1034WEP40<JOG0D0aIiK1032WEL4
0<JQF`@0cJQR1038Xed40<BOF0@0aZ5J2`3oool000X0oooo102nV4D40;bF@`@0^iI5102oVTT40<BO
C`@0`Ia<1@2nVDT80;fHB0@0_YU91030Vd/40;nJBP@0_IY91030WD`40<6MC`D0`ii@1033WTh40<JO
D0@0bJ1A1038We080<>MC0P0`iY81@34VTP40<JLBP@0bZ9=1030V4<40;:>>0@0_YY6102oW4/40<:N
D0D0aJ5E1038Y5P40<RRE`@0aZ1E1036XE<40<BOD@@0aj9D103:Y5T40<ZTF`D0bJ=L103:Y5d40=2Z
H`@0fKE[103M^7440=RgLP@0f;If103G]7X40=BaN`D0dK1k103A/7d40=VhPP@0cJed1038Z6d40<FS
I0@0_YaL102mV5840;J@A@D0[hHd102NMQh40:1g6`@0XgPI102RMaT40:Al7@@0ZH0V102^Qb`50;69
<P@0]8`e102hT3/40;R>?0@0]HXk102eS3`40;V?@`@0_9M91031Ve050<:PEP@0aJ=I103<[5l40<RX
F`@0_Ii>102lWDd40;ZJA`@0^YM5102lVDL90<6LC0@0`YaA1034W5@40<:JE0@0`IYE1034WEP40<JO
G0D0aIiK1032WEL40<JQF`@0cJQR1038Xed40<BOF0@0aZ5J2`3oool000X0oooo102oUT@40;jE@`@0
_IM41030VTL40<BOCP@0`ii=1@30Vd/40;bGA`@0^IA6102mV4X40<2OD0@0_ii?102kW4`40;bKC0@0
`:1=1@37XU440<BOCP@0`Ya;1033VTP40<JMB`P0aIa:1036WTT40<FKA`D0b9i:103;WT/40<NMB@@0
`iU5102lUT440;nIAP@0`Ie?1034X5H50<JPE`P0b:9K1035WeP40<JOE0@0aj1E1038XE@40<ZSEP@0
bJ9G1@38XEH40<^VF0@0c:MI103E/5l40=bgIP@0dK5N103?[Ud40<j]H0@0cjeU1@3A[fL40=RfK`@0
ekE^103>[6D40<ZXGP@0aZ9H1030W4h40;^DA@@0]Hdh1@2dR3440;66:P@0ZG`O102VNad40:Qm7`@0
ZX4U102]Q2X40;:;<0D0]Hdf102iTCX40;ZB?@@0^Y4o102cRSX40;R??`@0_YE6102mV4X40<2JC`D0
`9mB1032X5H80<VYGP@0`J1A1033XU<40<2MC0@0^9E4102lUdH50<:MC@@0`ia=1034WE840<JOE0@0
aimG103:WeX40<^PF`@0bYmK1@38WET40<>KE@@0aYiH2038XU/40<6LE@@0`iiG2`3oool000X0oooo
102oUT@40;jE@`@0_IM41030VTL40<BOCP@0`ii=1@30Vd/40;bGA`@0^IA6102mV4X40<2OD0@0_ii?
102kW4`40;bKC0@0`:1=1@37XU440<BOCP@0`Ya;1033VTP40<JMB`P0aIa:1036WTT40<FKA`D0b9i:
103;WT/40<NMB@@0`iU5102lUT440;nIAP@0`Ie?1034X5H50<JPE`P0b:9K1035WeP40<JOE0@0aj1E
1038XE@40<ZSEP@0bJ9G1@38XEH40<^VF0@0c:MI103E/5l40=bgIP@0dK5N103?[Ud40<j]H0@0cjeU
1@3A[fL40=RfK`@0ekE^103>[6D40<ZXGP@0aZ9H1030W4h40;^DA@@0]Hdh1@2dR3440;66:P@0ZG`O
102VNad40:Qm7`@0ZX4U102]Q2X40;:;<0D0]Hdf102iTCX40;ZB?@@0^Y4o102cRSX40;R??`@0_YE6
102mV4X40<2JC`D0`9mB1032X5H80<VYGP@0`J1A1033XU<40<2MC0@0^9E4102lUdH50<:MC@@0`ia=
1034WE840<JOE0@0aimG103:WeX40<^PF`@0bYmK1@38WET40<>KE@@0aYiH2038XU/40<6LE@@0`iiG
2`3oool000X0oooo102oUT@40;jE@`@0_IM41030VTL40<BOCP@0`ii=1@30Vd/40;bGA`@0^IA6102m
V4X40<2OD0@0_ii?102kW4`40;bKC0@0`:1=1@37XU440<BOCP@0`Ya;1033VTP40<JMB`P0aIa:1036
WTT40<FKA`D0b9i:103;WT/40<NMB@@0`iU5102lUT440;nIAP@0`Ie?1034X5H50<JPE`P0b:9K1035
WeP40<JOE0@0aj1E1038XE@40<ZSEP@0bJ9G1@38XEH40<^VF0@0c:MI103E/5l40=bgIP@0dK5N103?
[Ud40<j]H0@0cjeU1@3A[fL40=RfK`@0ekE^103>[6D40<ZXGP@0aZ9H1030W4h40;^DA@@0]Hdh1@2d
R3440;66:P@0ZG`O102VNad40:Qm7`@0ZX4U102]Q2X40;:;<0D0]Hdf102iTCX40;ZB?@@0^Y4o102c
RSX40;R??`@0_YE6102mV4X40<2JC`D0`9mB1032X5H80<VYGP@0`J1A1033XU<40<2MC0@0^9E4102l
UdH50<:MC@@0`ia=1034WE840<JOE0@0aimG103:WeX40<^PF`@0bYmK1@38WET40<>KE@@0aYiH2038
XU/40<6LE@@0`iiG2`3oool000X0oooo102oUT@40;jE@`@0_IM41030VTL40<BOCP@0`ii=1@30Vd/4
0;bGA`@0^IA6102mV4X40<2OD0@0_ii?102kW4`40;bKC0@0`:1=1@37XU440<BOCP@0`Ya;1033VTP4
0<JMB`P0aIa:1036WTT40<FKA`D0b9i:103;WT/40<NMB@@0`iU5102lUT440;nIAP@0`Ie?1034X5H5
0<JPE`P0b:9K1035WeP40<JOE0@0aj1E1038XE@40<ZSEP@0bJ9G1@38XEH40<^VF0@0c:MI103E/5l4
0=bgIP@0dK5N103?[Ud40<j]H0@0cjeU1@3A[fL40=RfK`@0ekE^103>[6D40<ZXGP@0aZ9H1030W4h4
0;^DA@@0]Hdh1@2dR3440;66:P@0ZG`O102VNad40:Qm7`@0ZX4U102]Q2X40;:;<0D0]Hdf102iTCX4
0;ZB?@@0^Y4o102cRSX40;R??`@0_YE6102mV4X40<2JC`D0`9mB1032X5H80<VYGP@0`J1A1033XU<4
0<2MC0@0^9E4102lUdH50<:MC@@0`ia=1034WE840<JOE0@0aimG103:WeX40<^PF`@0bYmK1@38WET4
0<>KE@@0aYiH2038XU/40<6LE@@0`iiG2`3oool000X0oooo1035W4X40;jE@`@0]i4n1032W4T40<^U
DP@0`ie:1@32W4/40;nIB0@0^IA4102oVTX80<JRE0@0_imB102nWDh40<2MB`D0aIm<1033WDX40<6H
AP@0_YA01034VTH80<FMB0@0a9a71036WTT50<RNBP@0a9Y61033VDD40<FKA`@0`I]61032W4T40<6M
C`@0`imE1@35WeH40<RRF`@0bJ5K1037WeT40<JNEP@0a9aD1036We840<NPD`@0bJ9E1@3:XeH40<bW
EP@0bZIB103;Ye440<jZDP@0cJQ=103=Z4l40<^VC@@0cJMB1@3@ZUD40<nYF0@0e:mN103>ZET40<NR
D@@0_YU8102lUT440;N?>0@0^Y4i1@2jSSD40;J9;0@0]8LZ102/PBD40;25:@@0/hX`102dRc<40;VA
>@D0_9@m1031VD@40;jE@`@0^i90102iT4440;fFA`@0_9E8102iTdP40<6KD0T0`ImE1032XUL40<6Q
EP@0`9mB1034XeH40<NSE@@0_IU;102mV4P50<2KB`@0`ia=1035WU440<ZPE0@0cJ=I103?YEd40<jS
GP@0bj1K1@37W5P40<NME@@0b9iF1038X5P40<VQF@@0`YaE1031Ve@;0?ooo`002P3oool40<FLBP@0
_YE3102gTCh40<:LB@@0bjEB1033WDX50<:LB`@0_iU8102iU4@40;nJBPP0aZ9D102oWe840;jMCP@0
`9e;1@35Wd`40<>MBP@0`IQ6102nU4040<BJAPP0aIe81034W4L40<JNB@D0b9i:1034VTH40<>IA@@0
aI]71031VdH40<:LB@@0`Ie?1033WeD50<FOEP@0b:9K1039XE/40<NOF@@0aYiF1034W5@40<JODP@0
aj1C1039XUD50<ZSEP@0c:MF103:YU840<^WD@@0cZYB103=Z4d40<fXC`@0bjI=103=Ye850=2ZE@@0
cjUH103D[eh40<jYF@@0aj9A102nVDP40;bF@@@0]hlh102jTCT50;Z>=@@0]XT/102dQbX40:b19@@0
/8DY102cRS040;B;<`@0^I4i1@2lU3d40<6IA0@0_YE3102kTT040;V@@@@0_II7102lUDP40;VCB0@0
`I]@2@31WeD40<:RE`@0`J5F1030We840<BSEP@0aj=E102mVD/40;fHB0D0`9];1033W4d40<FND@@0
bZ1D103=XeT40<nUG@@0cZ=N103;X5/50<NLF0@0aieE1038WUH40<RPF0@0bJ5I1032W5D40<6KE0/0
oooo000:0?ooo`@0aIa:102nUD<40;NA?P@0`Ya9103;YE840<>MBPD0`Ya;102oVDP40;VDA0@0_iY:
2036XU@40;nODP@0_Ye>1030WD/50<FOC0@0`ie:1031V4H40;jD@0@0a9Y62035WDP40<BLA`@0aYi9
1@38WTX40<BJAP@0`iU51035VdL40<6KAP@0`Ya91031WDl40<>OE@D0aImF1038XU/40<VQF`@0aimI
1036WUH40<BLE0@0aYmB1037X5<40<VRE@D0bZ=F103<YeH40<ZVDP@0bjMA103>ZU840<fXC@@0cJQ?
103;YTd40<fWDPD0d:YE103?ZEP40=B_GP@0cZUI1037XU440;jIB0@0_9I1102gScP40;ZA>@D0^Xhe
102fRB`40;B7:P@0[84U102`QBT40;>:<0@0]8/c102iTCT50;bD?@@0`IU4102nUD<40;^B@0@0^I11
102mUTL40;bEB0@0^I=81031Ve090<6OE@@0`Z9G1031XEH40<2ODP@0a:=F1037XeD40;fIB`@0_IQ8
1@30Vd/40<>LC@@0aIiA103:X5@40<fSF@@0cjEM103>Xeh40<^PF`D0aiaH1037WED40<RNEP@0b:1H
1039XET40<:LE@@0`I]D2`3oool000X0oooo1035W4X40;jE@`@0]i4n1032W4T40<^UDP@0`ie:1@32
W4/40;nIB0@0^IA4102oVTX80<JRE0@0_imB102nWDh40<2MB`D0aIm<1033WDX40<6HAP@0_YA01034
VTH80<FMB0@0a9a71036WTT50<RNBP@0a9Y61033VDD40<FKA`@0`I]61032W4T40<6MC`@0`imE1@35
WeH40<RRF`@0bJ5K1037WeT40<JNEP@0a9aD1036We840<NPD`@0bJ9E1@3:XeH40<bWEP@0bZIB103;
Ye440<jZDP@0cJQ=103=Z4l40<^VC@@0cJMB1@3@ZUD40<nYF0@0e:mN103>ZET40<NRD@@0_YU8102l
UT440;N?>0@0^Y4i1@2jSSD40;J9;0@0]8LZ102/PBD40;25:@@0/hX`102dRc<40;VA>@D0_9@m1031
VD@40;jE@`@0^i90102iT4440;fFA`@0_9E8102iTdP40<6KD0T0`ImE1032XUL40<6QEP@0`9mB1034
XeH40<NSE@@0_IU;102mV4P50<2KB`@0`ia=1035WU440<ZPE0@0cJ=I103?YEd40<jSGP@0bj1K1@37
W5P40<NME@@0b9iF1038X5P40<VQF@@0`YaE1031Ve@;0?ooo`002P3oool40<:IB@@0^Y51102oUT@4
0<VPCP@0bZ5?1032VDL50<:HAP@0`IM5102nUDD40<>JBPP0b:5B1036XE<40<JOD0@0aZ1?1@35W4X4
0<BJAP@0`iU51031U3l40<FH@`P0aIe61034W4D40<>KA0D0aie91038WTX40<FLBP@0a9]91032WTX4
0<JQD0@0aZ=B1035XED50<JPE@@0b:9I1038XU/40<ZTG@@0bj=K1037WeL80<RQE0@0bJ9E1@3;Y5L4
0<bVE@@0c:IC1039Xdh40<RPB0@0c:E81038X4440<JM@@@0a9]11@35W4@40<bRCP@0dJQF103F[Ed4
0<JPC`@0`Ya;102iTch40;>;=0@0^i<k1@2kTSP40;bA=@@0^Hdd102aR2h40;:9<@P0/h/c102gScP5
0;N?>P@0_9I1102kUD@40;VC@P@0]Hi1102nUdX40<BMDP@0`IeC1030W5850;jLDP@0`Z1F1030WU@4
0;jLDP@0`9iD1032X5H40<NSE`@0`IeA102oVT`50<2KC@@0`ia?1035WU440<VOE@@0bj5G203;XET4
0<^PF`D0bIiI2039WeL40<VQF@@0bZ9J1033WE@40;jHC`/0oooo000:0?ooo`@0`YU9102jTD440;nF
A0@0bJ1>103:XDl40<:IA`D0`YQ61031UdD40;jEA@@0`iY:2038XE840<JQD`@0aYm@1036X4l50<FL
BP@0a9Y61033VDD40<6D?`@0aIQ32035WDH40<BLA@@0`i]41@37WDT40<RNBP@0aIa:1034VdT40<:N
BP@0aZ5@1036Xe840<FQE@D0aZ1E1038XUT40<RRF`@0bZAM103;Xe/40<NOE`P0b:5D1039XUD50<^T
E`@0c:IE103<YU<40<VSCP@0b:18103<YDP40<RP@@@0aYe11034Vd450<FLA0@0c:9>103AZ5H40=J]
G@@0aZ1?1032W4/40;VC?P@0/h/d102kTc/50;^B>0@0_94e102iSC@40;68;P@0/XTa202cRc<40;N?
>0D0]hlj102lUT440;^EA0@0^I=2102eST440;jGBP@0a9eB1031WE<40<2LDPD0_YaB1032X5H40<2N
E0@0_YaB1030WU@40<:PEP@0aj=G1031WE440;nJC0D0`9]=1033W4l40<FND@@0bImE103;XEL80<^Q
F@@0bj1K1@39WUT80<VOE`@0bJ5I103:XUX40<>ME0@0_YQ?2`3oool000X0oooo1032VDT40;ZA@@@0
_iI41039X4h40<ZQC`@0`YU71@32V4H40<6GA@@0_YE51033VTX80<RQDP@0aZ5C1036We040<JPC`D0
aIa:1034VTH40<>IA@@0`I@o1035V4<80<FMAP@0a9a51033Vd@50<NMB@@0b9i:1035W4X40<BKB@@0
`Yi:1036XE040<JSDP@0aJ5E1@36X5D40<RRF@@0b:9K103:Y5d40<^SF`@0aimG2038XE@40<VRE@D0
bjAG103<YUD40<bVD`@0bJ=>1038X4P40<bUB0@0b:111036WD440<BK@@D0aIa4103<XTh40=6XEP@0
eZeM1036X4l40<:LB`@0^I<n102cRc@40;^C>`D0^i8h102lTCD40;V==0@0/HP^102bRC480;>;<`@0
]hlh1@2gScX40;bF@@@0^iE4102iTd840;F>@@@0_YM:1034WE840<6MD`@0`9aB1@2nW5840<:PEP@0
`9iD102nW5840<2NE0@0`Z1F1037XeL40<6MD@@0_iY<1@30Vdd40<>LC`@0aIiA1039WeD40<^QE`P0
bj5I103;X5/50<VNF@P0bImG1039XET40<ZRFP@0`ieD102nV4l;0?ooo`002P3oool40<:IB@@0^Y51
102oUT@40<VPCP@0bZ5?1032VDL50<:HAP@0`IM5102nUDD40<>JBPP0b:5B1036XE<40<JOD0@0aZ1?
1@35W4X40<BJAP@0`iU51031U3l40<FH@`P0aIe61034W4D40<>KA0D0aie91038WTX40<FLBP@0a9]9
1032WTX40<JQD0@0aZ=B1035XED50<JPE@@0b:9I1038XU/40<ZTG@@0bj=K1037WeL80<RQE0@0bJ9E
1@3;Y5L40<bVE@@0c:IC1039Xdh40<RPB0@0c:E81038X4440<JM@@@0a9]11@35W4@40<bRCP@0dJQF
103F[Ed40<JPC`@0`Ya;102iTch40;>;=0@0^i<k1@2kTSP40;bA=@@0^Hdd102aR2h40;:9<@P0/h/c
102gScP50;N?>P@0_9I1102kUD@40;VC@P@0]Hi1102nUdX40<BMDP@0`IeC1030W5850;jLDP@0`Z1F
1030WU@40;jLDP@0`9iD1032X5H40<NSE`@0`IeA102oVT`50<2KC@@0`ia?1035WU440<VOE@@0bj5G
203;XET40<^PF`D0bIiI2039WeL40<VQF@@0bZ9J1033WE@40;jHC`/0oooo000:0?ooo`@0`9M7102o
UTH40<6HB0@0aIa<1037WT`40<6HAPD0_iE11030UT840<:HAP@0aYa:1037WTh40<NNC`@0aYm@1037
X5<40<^RDPD0b9e>1037WD/40<RKBPP0a9M21033Vd@40<6I@P@0_iY21030Vd<50<FMB0@0bZ5?103:
Y5440<NQD0@0aJ1@103:YED40<bXFP@0bJEI1@36XUH80<JRF0@0bJEK103>Z5d40<VSF0@0bJAF1038
XeD40<RRE`D0bjEJ103;Y5D40<jWF0@0bjEB1039XD`40<NMA`@0a9Q1102mTCP40<FI@PD0aIQ3103;
WTd40<jUE@@0dZUJ1035WTl40<FOCP@0_YQ5102gTC`40;R@>0D0_9@l1037WTH40;fD?0@0^Hli102h
SSP40;R@>@@0]Xhg102gScP50;R@>`@0^iE0102jU4<40;NA@0@0^954102mV4X40<2JC`@0_i]?1031
WE450<>OE@@0a:1F2032X5H40<BPEP@0aJ5G1034X5H40<JRF0d0`YaC1035WeH40<VQF@@0b:1H2035
WEL40<JNF@D0aimJ203:X5P40<ZRFP@0bj=K1034W5@40;fEC@/0oooo000:0?ooo`@0`9M7102oUTH4
0<6HB0@0aIa<1037WT`40<6HAPD0_iE11030UT840<:HAP@0aYa:1037WTh40<NNC`@0aYm@1037X5<4
0<^RDPD0b9e>1037WD/40<RKBPP0a9M21033Vd@40<6I@P@0_iY21030Vd<50<FMB0@0bZ5?103:Y544
0<NQD0@0aJ1@103:YED40<bXFP@0bJEI1@36XUH80<JRF0@0bJEK103>Z5d40<VSF0@0bJAF1038XeD4
0<RRE`D0bjEJ103;Y5D40<jWF0@0bjEB1039XD`40<NMA`@0a9Q1102mTCP40<FI@PD0aIQ3103;WTd4
0<jUE@@0dZUJ1035WTl40<FOCP@0_YQ5102gTC`40;R@>0D0_9@l1037WTH40;fD?0@0^Hli102hSSP4
0;R@>@@0]Xhg102gScP50;R@>`@0^iE0102jU4<40;NA@0@0^954102mV4X40<2JC`@0_i]?1031WE45
0<>OE@@0a:1F2032X5H40<BPEP@0aJ5G1034X5H40<JRF0d0`YaC1035WeH40<VQF@@0b:1H2035WEL4
0<JNF@D0aimJ203:X5P40<ZRFP@0bj=K1034W5@40;fEC@/0oooo000:0?ooo`@0`9M7102oUTH40<6H
B0@0aIa<1037WT`40<6HAPD0_iE11030UT840<:HAP@0aYa:1037WTh40<NNC`@0aYm@1037X5<40<^R
DPD0b9e>1037WD/40<RKBPP0a9M21033Vd@40<6I@P@0_iY21030Vd<50<FMB0@0bZ5?103:Y5440<NQ
D0@0aJ1@103:YED40<bXFP@0bJEI1@36XUH80<JRF0@0bJEK103>Z5d40<VSF0@0bJAF1038XeD40<RR
E`D0bjEJ103;Y5D40<jWF0@0bjEB1039XD`40<NMA`@0a9Q1102mTCP40<FI@PD0aIQ3103;WTd40<jU
E@@0dZUJ1035WTl40<FOCP@0_YQ5102gTC`40;R@>0D0_9@l1037WTH40;fD?0@0^Hli102hSSP40;R@
>@@0]Xhg102gScP50;R@>`@0^iE0102jU4<40;NA@0@0^954102mV4X40<2JC`@0_i]?1031WE450<>O
E@@0a:1F2032X5H40<BPEP@0aJ5G1034X5H40<JRF0d0`YaC1035WeH40<VQF@@0b:1H2035WEL40<JN
F@D0aimJ203:X5P40<ZRFP@0bj=K1034W5@40;fEC@/0oooo000:0?ooo`@0`9M7102oUTH40<6HB0@0
aIa<1037WT`40<6HAPD0_iE11030UT840<:HAP@0aYa:1037WTh40<NNC`@0aYm@1037X5<40<^RDPD0
b9e>1037WD/40<RKBPP0a9M21033Vd@40<6I@P@0_iY21030Vd<50<FMB0@0bZ5?103:Y5440<NQD0@0
aJ1@103:YED40<bXFP@0bJEI1@36XUH80<JRF0@0bJEK103>Z5d40<VSF0@0bJAF1038XeD40<RRE`D0
bjEJ103;Y5D40<jWF0@0bjEB1039XD`40<NMA`@0a9Q1102mTCP40<FI@PD0aIQ3103;WTd40<jUE@@0
dZUJ1035WTl40<FOCP@0_YQ5102gTC`40;R@>0D0_9@l1037WTH40;fD?0@0^Hli102hSSP40;R@>@@0
]Xhg102gScP50;R@>`@0^iE0102jU4<40;NA@0@0^954102mV4X40<2JC`@0_i]?1031WE450<>OE@@0
a:1F2032X5H40<BPEP@0aJ5G1034X5H40<JRF0d0`YaC1035WeH40<VQF@@0b:1H2035WEL40<JNF@D0
aimJ203:X5P40<ZRFP@0bj=K1034W5@40;fEC@/0oooo000:0?ooo`@0_YA0102mTd440<BKB`@0bJ1@
1037WT`40;nFA0D0`9Q3102oUd840<:JA@@0aYe;1037WT`40<NNC`@0aIiA1036We@90<JMCP@0b9e>
1036Vd`40<NMB@@0aI]71034W4@40<6I@@@0_9Lo102hTSd50<2H@`@0b9m?1037WTh40<RNDP@0b:=E
1037XEH40<VUF@@0b:AH2@37XeT80<FSF@@0aZEF1033XU<80<FQD`@0bZIJ2@3=Ye`40<nXG@@0c:EF
1039X5440<NNCP@0`9E61033VDD40<JLB0D0bj5=103>Y5840=:YF@@0eJaM103=YeH40<>MBP@0`I]6
102mV4040;VD>`D0_9Lo1032VT<40<FMB0P0^Y8j102lU3`40;ZB>P@0^I4i1@2kTc/40;ZE?@@0^98m
102fTSh40;B??`@0^II52030W4h40;nKC@D0`9a>1031WDl40<FQE@@0a:1D1032WU@40<BOF0@0aZ5J
103<Yf440<VTGPD0`iiH1034WUL40<JPF@@0bJ=L1038XU/80<JOFP@0aj1M1@36WeX40<ZRG0@0bZ9J
103<Y5`40<jVGP@0aYmD1030VDh;0?ooo`002P3oool40;jD@0@0_I=11034Vd/40<VPD0@0aii<102o
UT@50<2H@`@0_iM21032VTD40<JMB`@0aii<1037WTl40<FND@@0aYmD2@36WDh40<RMCP@0aY]<1037
WDT40<FKA`@0a9a41031VD440;bG?`@0^98m1@30V4<40<ROC`@0aii>1038WU840<RSE@@0aj5F1039
YET40<RTF0T0aj=I2035XeT40<JUEP@0`j9C2035XE<40<ZVFPT0cJML103?Z5d40<bUEP@0bJ1A1037
WTh40<2EAP@0`iU51036W4P50<^QC@@0cZAB103BZET40=F/G@@0cJMF1033WDX40<6KAP@0_IQ0102i
U3/50;bG?`@0`YY31035WDP80;ZB>P@0_9@l102jTSX40;VA>@D0^i<k102jUCd40;RB?@@0]Y8n102d
Scl40;VFA@P0`9a>102oVdd50<2LCP@0`Ie?1035XED40<BPE0@0`YiD1034WeP40<JQFP@0c:MQ1039
Y5h50<>NF0@0a9iG1036X5T40<VSG0@0b:9K2036WeX40<NPG@D0aYmJ103:XU`40<ZRFP@0c:AL103>
YUh40<JOE0@0`9U>2`3oool000X0oooo102nU4040;fC@@@0a9];1039X5040<NNC0@0_iI41@30V4<4
0;nG@P@0`YY51036WD/40<NNC0@0aii?1035WU440<JOE0T0aYe>1038WDh40<JKC0@0aie91035VdL4
0<BLA0@0`IU1102lUcl40;RB?@D0`9Q31038Wdl40<NNCP@0b9iB1038XeD40<NQEP@0bJEI1038Y5P9
0<NSF@P0aJ=I1036YEH40<>RD`P0aJ5C103:YUX90<fWG0@0cjQM103<YEH40<VPD@@0aii>1030UDH4
0<>IA@@0aYa81@3;XDd40<jTDP@0dZUI103E[5d40<fWEP@0`ie:1031VdH40;fH@0@0^I@k1@2lUcl4
0<:J@`@0aIe8202jTSX40;bD?0@0^Y8j102iTCT50;^C>`@0^YDm102hTSd40;JB?P@0]8lo102iUTD8
0<2LCP@0_i]=1@30W4h40<6MC`@0aJ5E1034X5@40<:NE0@0a9mH1036XEX40<bWH@@0bJAN1@33WUP4
0<BNE`@0aZ1I1039Xe`40<RRF`P0aYmJ1037X5d50<JOFP@0bZ9L103:XUX40<bTG0@0cZIN1036We@4
0<2ICP/0oooo000:0?ooo`@0_YA0102mTd440<BKB`@0bJ1@1037WT`40;nFA0D0`9Q3102oUd840<:J
A@@0aYe;1037WT`40<NNC`@0aIiA1036We@90<JMCP@0b9e>1036Vd`40<NMB@@0aI]71034W4@40<6I
@@@0_9Lo102hTSd50<2H@`@0b9m?1037WTh40<RNDP@0b:=E1037XEH40<VUF@@0b:AH2@37XeT80<FS
F@@0aZEF1033XU<80<FQD`@0bZIJ2@3=Ye`40<nXG@@0c:EF1039X5440<NNCP@0`9E61033VDD40<JL
B0D0bj5=103>Y5840=:YF@@0eJaM103=YeH40<>MBP@0`I]6102mV4040;VD>`D0_9Lo1032VT<40<FM
B0P0^Y8j102lU3`40;ZB>P@0^I4i1@2kTc/40;ZE?@@0^98m102fTSh40;B??`@0^II52030W4h40;nK
C@D0`9a>1031WDl40<FQE@@0a:1D1032WU@40<BOF0@0aZ5J103<Yf440<VTGPD0`iiH1034WUL40<JP
F@@0bJ=L1038XU/80<JOFP@0aj1M1@36WeX40<ZRG0@0bZ9J103<Y5`40<jVGP@0aYmD1030VDh;0?oo
o`002P3oool40;jD@0@0_I=11034Vd/40<VPD0@0aii<102oUT@50<2H@`@0_iM21032VTD40<JMB`@0
aii<1037WTl40<FND@@0aYmD2@36WDh40<RMCP@0aY]<1037WDT40<FKA`@0a9a41031VD440;bG?`@0
^98m1@30V4<40<ROC`@0aii>1038WU840<RSE@@0aj5F1039YET40<RTF0T0aj=I2035XeT40<JUEP@0
`j9C2035XE<40<ZVFPT0cJML103?Z5d40<bUEP@0bJ1A1037WTh40<2EAP@0`iU51036W4P50<^QC@@0
cZAB103BZET40=F/G@@0cJMF1033WDX40<6KAP@0_IQ0102iU3/50;bG?`@0`YY31035WDP80;ZB>P@0
_9@l102jTSX40;VA>@D0^i<k102jUCd40;RB?@@0]Y8n102dScl40;VFA@P0`9a>102oVdd50<2LCP@0
`Ie?1035XED40<BPE0@0`YiD1034WeP40<JQFP@0c:MQ1039Y5h50<>NF0@0a9iG1036X5T40<VSG0@0
b:9K2036WeX40<NPG@D0aYmJ103:XU`40<ZRFP@0c:AL103>YUh40<JOE0@0`9U>2`3oool000X0oooo
102mU3`40;jD@0@0_iU61033WD`40<BNC@@0_YQ71@30VTD40;ZD?`@0_9I11032W4T40<FOCP@0aj1C
1035We@40<BNE@@0`Y]>1@31VTd40<BKC0@0aYe=103@YU@40<^QC@@0aJ171033WTD40;VD?0@0^I4l
1@2hT3/40;jCA0@0a9U;1035VE040<>LD@@0aimG1036XUH40<VUF`D0b:AJ1038Xe`40<JTFP@0a:9H
2033Y5@80<BSE0@0bZIJ1@39YET80<bVF`P0c:EH103<YEX40<RQE0@0b9m?1036WD/50<JNB@@0cjID
103H/Ul40=ZdH`@0g[YV103<Z5840<:NAP@0`9e3102jUC`50;fH@0@0a9a71035WDP40;nG@0@0^Y8j
102mUS/40<2I?P@0_YLl1@2mUS/40;VD>`@0^YDm102oVdD40;JA@0@0]iA21030WD`40<:OCP@0`9e<
1@31WTd40<2LCP@0_YY<102oVe440<2LDP@0`IaE1036XE/40<bWH@@0d:]W1@38Xel40<BOF`@0aJ1L
1036XE/40<NRG0@0b:=M103;YV040<ZUH@D0aj9L1038XU/40<RRF@@0bZAK103?ZF040<RQEP@0aIiC
2`3oool000X0oooo102mU3`40;jD@0@0_iU61033WD`40<BNC@@0_YQ71@30VTD40;ZD?`@0_9I11032
W4T40<FOCP@0aj1C1035We@40<BNE@@0`Y]>1@31VTd40<BKC0@0aYe=103@YU@40<^QC@@0aJ171033
WTD40;VD?0@0^I4l1@2hT3/40;jCA0@0a9U;1035VE040<>LD@@0aimG1036XUH40<VUF`D0b:AJ1038
Xe`40<JTFP@0a:9H2033Y5@80<BSE0@0bZIJ1@39YET80<bVF`P0c:EH103<YEX40<RQE0@0b9m?1036
WD/50<JNB@@0cjID103H/Ul40=ZdH`@0g[YV103<Z5840<:NAP@0`9e3102jUC`50;fH@0@0a9a71035
WDP40;nG@0@0^Y8j102mUS/40<2I?P@0_YLl1@2mUS/40;VD>`@0^YDm102oVdD40;JA@0@0]iA21030
WD`40<:OCP@0`9e<1@31WTd40<2LCP@0_YY<102oVe440<2LDP@0`IaE1036XE/40<bWH@@0d:]W1@38
Xel40<BOF`@0aJ1L1036XE/40<NRG0@0b:=M103;YV040<ZUH@D0aj9L1038XU/40<RRF@@0bZAK103?
ZF040<RQEP@0aIiC2`3oool000X0oooo102mU3`40;jD@0@0_iU61033WD`40<BNC@@0_YQ71@30VTD4
0;ZD?`@0_9I11032W4T40<FOCP@0aj1C1035We@40<BNE@@0`Y]>1@31VTd40<BKC0@0aYe=103@YU@4
0<^QC@@0aJ171033WTD40;VD?0@0^I4l1@2hT3/40;jCA0@0a9U;1035VE040<>LD@@0aimG1036XUH4
0<VUF`D0b:AJ1038Xe`40<JTFP@0a:9H2033Y5@80<BSE0@0bZIJ1@39YET80<bVF`P0c:EH103<YEX4
0<RQE0@0b9m?1036WD/50<JNB@@0cjID103H/Ul40=ZdH`@0g[YV103<Z5840<:NAP@0`9e3102jUC`5
0;fH@0@0a9a71035WDP40;nG@0@0^Y8j102mUS/40<2I?P@0_YLl1@2mUS/40;VD>`@0^YDm102oVdD4
0;JA@0@0]iA21030WD`40<:OCP@0`9e<1@31WTd40<2LCP@0_YY<102oVe440<2LDP@0`IaE1036XE/4
0<bWH@@0d:]W1@38Xel40<BOF`@0aJ1L1036XE/40<NRG0@0b:=M103;YV040<ZUH@D0aj9L1038XU/4
0<RRF@@0bZAK103?ZF040<RQEP@0aIiC2`3oool000X0oooo102mU3`40;jD@0@0_iU61033WD`40<BN
C@@0_YQ71@30VTD40;ZD?`@0_9I11032W4T40<FOCP@0aj1C1035We@40<BNE@@0`Y]>1@31VTd40<BK
C0@0aYe=103@YU@40<^QC@@0aJ171033WTD40;VD?0@0^I4l1@2hT3/40;jCA0@0a9U;1035VE040<>L
D@@0aimG1036XUH40<VUF`D0b:AJ1038Xe`40<JTFP@0a:9H2033Y5@80<BSE0@0bZIJ1@39YET80<bV
F`P0c:EH103<YEX40<RQE0@0b9m?1036WD/50<JNB@@0cjID103H/Ul40=ZdH`@0g[YV103<Z5840<:N
AP@0`9e3102jUC`50;fH@0@0a9a71035WDP40;nG@0@0^Y8j102mUS/40<2I?P@0_YLl1@2mUS/40;VD
>`@0^YDm102oVdD40;JA@0@0]iA21030WD`40<:OCP@0`9e<1@31WTd40<2LCP@0_YY<102oVe440<2L
DP@0`IaE1036XE/40<bWH@@0d:]W1@38Xel40<BOF`@0aJ1L1036XE/40<NRG0@0b:=M103;YV040<ZU
H@D0aj9L1038XU/40<RRF@@0bZAK103?ZF040<RQEP@0aIiC2`3oool000X0oooo102nUCd40;jD?P@0
`9I2102oUD480;jF@@D0_9@m102kTc`40;^E@0@0`9Y71036XE040<FPDP@0aJ5C1032WU040;nJB@D0
`I]:1033WD`40<JMCP@0bJ1A103BZEX40<bXE0@0`im9102oVT840;^C>`D0^Y8j102iScT40;fC?`@0
`9E61033VDd40<JLE0@0aImF1036X5T50<ZUG`P0bJAN103;YV040<:PF0@0`j5I1033XUD40<JUF0T0
bZIJ1039YE/40<ZVG0P0c:IO103=Yf040<nYHP@0b:1H1033Ve<50<VRE@@0bZ=F103=YUL40<bUEP@0
cJAD103?YUH40<VSDP@0aZ1?102oVDP50<2JB@@0`ie<1034WTd40<6HAP@0_IE0102lUcl40;jI@0@0
_9Tm2@2jUcd40;^G@@@0^IM0102iUT840;bIA@@0`9e92035XD/50<2LAP@0]Y8l102iUT840;^HAP@0
_9U8102oVdl40<:NE0@0bJAN103<Yf450<RSG`@0`ieL1034WUd80<JQG@@0bJMP103A[fP40<ZXH@D0
aJ=K1037XeT40<JREP@0bjEJ103=Ye`40<^TE`@0aj1C2`3oool000X0oooo102nUCd40;jD?P@0`9I2
102oUD480;jF@@D0_9@m102kTc`40;^E@0@0`9Y71036XE040<FPDP@0aJ5C1032WU040;nJB@D0`I]:
1033WD`40<JMCP@0bJ1A103BZEX40<bXE0@0`im9102oVT840;^C>`D0^Y8j102iScT40;fC?`@0`9E6
1033VDd40<JLE0@0aImF1036X5T50<ZUG`P0bJAN103;YV040<:PF0@0`j5I1033XUD40<JUF0T0bZIJ
1039YE/40<ZVG0P0c:IO103=Yf040<nYHP@0b:1H1033Ve<50<VRE@@0bZ=F103=YUL40<bUEP@0cJAD
103?YUH40<VSDP@0aZ1?102oVDP50<2JB@@0`ie<1034WTd40<6HAP@0_IE0102lUcl40;jI@0@0_9Tm
2@2jUcd40;^G@@@0^IM0102iUT840;bIA@@0`9e92035XD/50<2LAP@0]Y8l102iUT840;^HAP@0_9U8
102oVdl40<:NE0@0bJAN103<Yf450<RSG`@0`ieL1034WUd80<JQG@@0bJMP103A[fP40<ZXH@D0aJ=K
1037XeT40<JREP@0bjEJ103=Ye`40<^TE`@0aj1C2`3oool000X0oooo102nUCd40;jD?P@0`9I2102o
UD480;jF@@D0_9@m102kTc`40;^E@0@0`9Y71036XE040<FPDP@0aJ5C1032WU040;nJB@D0`I]:1033
WD`40<JMCP@0bJ1A103BZEX40<bXE0@0`im9102oVT840;^C>`D0^Y8j102iScT40;fC?`@0`9E61033
VDd40<JLE0@0aImF1036X5T50<ZUG`P0bJAN103;YV040<:PF0@0`j5I1033XUD40<JUF0T0bZIJ1039
YE/40<ZVG0P0c:IO103=Yf040<nYHP@0b:1H1033Ve<50<VRE@@0bZ=F103=YUL40<bUEP@0cJAD103?
YUH40<VSDP@0aZ1?102oVDP50<2JB@@0`ie<1034WTd40<6HAP@0_IE0102lUcl40;jI@0@0_9Tm2@2j
Ucd40;^G@@@0^IM0102iUT840;bIA@@0`9e92035XD/50<2LAP@0]Y8l102iUT840;^HAP@0_9U8102o
Vdl40<:NE0@0bJAN103<Yf450<RSG`@0`ieL1034WUd80<JQG@@0bJMP103A[fP40<ZXH@D0aJ=K1037
XeT40<JREP@0bjEJ103=Ye`40<^TE`@0aj1C2`3oool000X0oooo102nUCd40;jD?P@0`9I2102oUD48
0;jF@@D0_9@m102kTc`40;^E@0@0`9Y71036XE040<FPDP@0aJ5C1032WU040;nJB@D0`I]:1033WD`4
0<JMCP@0bJ1A103BZEX40<bXE0@0`im9102oVT840;^C>`D0^Y8j102iScT40;fC?`@0`9E61033VDd4
0<JLE0@0aImF1036X5T50<ZUG`P0bJAN103;YV040<:PF0@0`j5I1033XUD40<JUF0T0bZIJ1039YE/4
0<ZVG0P0c:IO103=Yf040<nYHP@0b:1H1033Ve<50<VRE@@0bZ=F103=YUL40<bUEP@0cJAD103?YUH4
0<VSDP@0aZ1?102oVDP50<2JB@@0`ie<1034WTd40<6HAP@0_IE0102lUcl40;jI@0@0_9Tm2@2jUcd4
0;^G@@@0^IM0102iUT840;bIA@@0`9e92035XD/50<2LAP@0]Y8l102iUT840;^HAP@0_9U8102oVdl4
0<:NE0@0bJAN103<Yf450<RSG`@0`ieL1034WUd80<JQG@@0bJMP103A[fP40<ZXH@D0aJ=K1037XeT4
0<JREP@0bjEJ103=Ye`40<^TE`@0aj1C2`3oool000X0oooo102oUSh40;jD@0@0_98n102oUD<40;nF
A0@0_9=12@2lU3l40;VC?P@0`9Y71037Xdl40<BOCP@0`Ye=1033WTd40;fIA@D0_i]52035Wd`40<JP
C`@0c:IE103;Ye440<FQB@@0`Ii4102kUS/50;JA>0@0^90i102mTcl40<:GB0@0`iY;1035Ve440<FO
EP@0bJ=L1@3<YF040<fVH@@0bZEO1039Y5h40<BRFP@0aJ=K1035XeT40<JTFP@0bJMM1@3>[6840<bW
H0@0bZEN1038Xe`40<bWH0@0eJmX103>Z6440<NQF0@0aZ1G1@37XU@40<RSE@@0c:EF1035WTl40;ZD
@`@0`Ya;1037XE040<>MC0@0_iQ91@30VDX40<FPD0@0bZ=D102oVDP40;nFA0@0_iM0102nUSh40;ZE
>PD0^iHm102lVCl40;bH@P@0^IDo102jUT840;fIA@@0`Ie91038XTl40<BNB`D0`I]:102nV4L40;ZF
@P@0]Y50102XPc840;bGB@@0`imC1033WUL40=>^I`D0a9mI1034We/40<>NFP@0`9iG1032X5T40<BR
F`@0ajEN1036Y5d50<NUG@@0a:9H1033XUD40<RTF0@0bZIJ1039Y5H40<ZUE`/0oooo000:0?ooo`@0
_iHn102nU4040;bB?P@0_iE3102oUT@40;bC@@T0_9@o102iTch40<2JA`@0aj=?1034Wdh40<:MC@@0
`ii=102mVDD50;nKA@P0aIm<1036X4l40<bVE@@0bjMA1035XDT40<6NA0@0^iHk1@2fTCP40;R@>@@0
_I<o1032UdP40<>JB`@0aI]A1035WeH40<VSG0D0c:EP103=YV440<ZUG`@0bJAN1034XUX40<FSF`@0
aJ=I1036Y5X40<VWG@D0cZaR103<Yf040<ZUGP@0b:=L103<Yf040=F_J0@0cZQQ1037XEP40<JPE`D0
aj9D1038XeD40<bUEP@0aIi?102jU4<40<:LB`@0aj5@1033WD`40;nHB@D0`9U:1035X5040<ZSE0@0
_iU8102oUT@40;nG@0@0_YHn102jUCX50;^F?@@0_9To102lV4840;VE?`@0^YI2102mVDD40<6MB@@0
b:9?1034WT/50<6KBP@0_YQ7102jUT840;JA@0@0Z8<b102lUdT40<>OD`@0`iiG103C[VL50<BOF@@0
a9mK1033WUX40<2NE`@0`Z1I1034XU/40<NUGP@0aZAM1@37YEd40<BRF0@0`j9E1038Y5P40<ZVFP@0
bJAF103:YEL;0?ooo`002P3oool40;nF?P@0_YA0102lTSh40;nE@`@0_iI4102lTd490;bD?`@0^I<n
1030VTL40<NSC`@0a9m>1032WDd40<>NC@@0_IU51@2oVdD80<FOC0@0aZ1?103<YUD40<^WD@@0aJ59
1031WT@40;^F>`D0]Y4h102hT3T40;fC?`@0`YM81033VT/40<FKD@@0aImF1039Xe`50<bUH0@0cJIQ
103:YEl40<VTGP@0a:9J1035Xe/40<FSF@@0aZAJ1039Yed50<j/HP@0c:MP103:YEh40<RSG0@0c:MP
103E[fP40<jXH@@0aj5H1036X5L50<NRE0@0b:=E103<YEH40<FNC`@0^YA31032W4/40<NQD0@0`ie<
102oV4T50<2IBP@0aJ1@103:Xe@40;nIB0@0_iI4102oUd040;jF?P@0^YDj1@2kUSd40;bI?`@0_9Q2
102iUCl40;ZF@P@0_IU51031WDT40<RRC`@0a9i;1@31VdX40;jHA`@0^YI2102fTD040:R3<P@0_9M9
1033We<40<>NE`@0djiW1@34WeT40<BOF`@0`iiJ1030WUL40<:PF@@0a:9K1037YEh40<JTG@D0ajEM
1034XUP40<>RE@@0b:AH103:YUX40<VTEP@0bZEG2`3oool000X0oooo102oUSh40;jD@0@0_98n102o
UD<40;nFA0@0_9=12@2lU3l40;VC?P@0`9Y71037Xdl40<BOCP@0`Ye=1033WTd40;fIA@D0_i]52035
Wd`40<JPC`@0c:IE103;Ye440<FQB@@0`Ii4102kUS/50;JA>0@0^90i102mTcl40<:GB0@0`iY;1035
Ve440<FOEP@0bJ=L1@3<YF040<fVH@@0bZEO1039Y5h40<BRFP@0aJ=K1035XeT40<JTFP@0bJMM1@3>
[6840<bWH0@0bZEN1038Xe`40<bWH0@0eJmX103>Z6440<NQF0@0aZ1G1@37XU@40<RSE@@0c:EF1035
WTl40;ZD@`@0`Ya;1037XE040<>MC0@0_iQ91@30VDX40<FPD0@0bZ=D102oVDP40;nFA0@0_iM0102n
USh40;ZE>PD0^iHm102lVCl40;bH@P@0^IDo102jUT840;fIA@@0`Ie91038XTl40<BNB`D0`I]:102n
V4L40;ZF@P@0]Y50102XPc840;bGB@@0`imC1033WUL40=>^I`D0a9mI1034We/40<>NFP@0`9iG1032
X5T40<BRF`@0ajEN1036Y5d50<NUG@@0a:9H1033XUD40<RTF0@0bZIJ1039Y5H40<ZUE`/0oooo000:
0?ooo`@0`IU1102oUd840<2H@`@0_IA21031V4H40<:IA`D0_iM2102fSST40;VD?0@0aJ181031VdH4
0;nIA0@0aZ1=103:Y4l40<:PA`D0_i]31031WDD40<:LA`@0aIm:1036X4/40<BRB@@0`9i51031WT84
0;fH?@D0]i8g102kTc/40;nG@0@0aIa:1030VTT40<6JC@@0`ieB1038XUT50<^UGP@0d:UT103<Yf44
0<RSG`@0aZ=O1039YV840<NUGP@0`j5J103;ZF850=RfK`@0bZQP1034XUX40<FPF@@0cJQQ103G/V/4
0=F`J@@0cJMN1037XEP50<NRE0@0aJ1B1037XU840<>NCP@0_9M6102kUTD80;jIB0@0_YU91@2mV4P4
0<NRE0@0eJiQ103;XU840<RNC0@0`IU4102mUCh40;fF>`D0^i<k102lUch40<FOBP@0_IM2102lUT<4
0;fGA0@0`I]81039Xe840<BNC@D0`iY;1031V4P40;bF@@@0/X`g102cSCP40;^EA0@0`9];1033WE84
0<:NE0D0a9mH2030WUH40;jLE0@0`Z1H1034XU/40<6OF0@0aJ=L1@37YEd40<BRF0@0a:=F2035Y5D4
0<RTEP@0cJUK2`3oool000X0oooo1031VD440;nG@P@0`9Q3102mU4840<6HAP@0`YU71@2oUd840;J>
>@@0^I@l1035X4P40<6KAP@0_iU41036X4d40<ZTC`@0`Z171@2oVd<40<6MA@@0`Ya71035WdX40<JP
B`@0a:991030WTD40<6N@P@0_IPm1@2gTSL40;^C>`@0_iM01035W4X40<2JB@@0`IY=1033WE840<RR
F@D0bjEN103@ZF@40<bWH@@0b:=O1036Xel40<VVHP@0ajEN1033XEX40<^YHPD0f;I_103:Z6040<BR
FP@0aJ1I103=Z6440=NbJ`@0eK1Y103=Yeh40<NQF0D0aj9D1035X5840<NRDP@0`ii>102lUdH40;^F
A@P0_YU8102nVDT50;fHB0@0aj9D103E[V440<^RDP@0b9i<1031VD@40;fE?P@0_IHk1@2kTc/40;bG
?P@0aIm:102mUd840;bF@`@0_IM41031VdP40<VSDP@0a9i=1@33VT/40<6HB0@0_9I1102bS3L40;>=
>0@0^iE41030Vd/40<>MDP@0`YiD1@34WeP80<2NEP@0_YaD1032X5P40<BRF`@0`ImH1035Xe`50<NU
G@@0a:9H1034XeH80<FTE@@0b:AF103=ZE/;0?ooo`002P3oool40<6I@@@0_iM21030V4<40;fD@P@0
`IQ61032VDL50;nG@P@0]Xhi102iU3`40<FPB0@0`I]6102oVD@40<JPC@@0bZA?1032X4L50;nK@`@0
`Ie51032W4L40<FOBP@0aZ1;1034XTT40<2NA@@0`Ii2102mV3d50;NB=`@0^i<k102oUd040<FLBP@0
`9Y91031VTd40<>MDP@0b:9I1@3;YEh40=2YI0@0c:MQ1038Xel40<JSG`@0bJIR1037YEh40<>QFP@0
bjUR1@3H]Vl40<ZXH0@0a:9J1035X5T40<fXH@@0ek9[103E/6T40<fWGP@0aj5H1@37XU@40<FPDP@0
aj9B1033WTh40;bGAP@0^iI5202nVDP40;jIB@D0_IQ81037XU@40=F^H@@0bj9B1038WT`40<6IA0@0
_IDn102mUS/50;^C>`@0_9Ln1035WdX40;fG@P@0_9I3102mUd@40<6KB0@0bJ=B1034WTd50<>JB`@0
`IQ8102lUT440;:<=`@0/hdh102kUD@40<2KB`@0`ieB1032WU@50<BOF0P0`9iF102nW5@40<:PF0@0
a:9K1031WeP40<FSG0D0ajEM1034XUP40<BSEPP0aJAE1038Y5H40<fYF`/0oooo000:0?ooo`@0`IU1
102oUd840<2H@`@0_IA21031V4H40<:IA`D0_iM2102fSST40;VD?0@0aJ181031VdH40;nIA0@0aZ1=
103:Y4l40<:PA`D0_i]31031WDD40<:LA`@0aIm:1036X4/40<BRB@@0`9i51031WT840;fH?@D0]i8g
102kTc/40;nG@0@0aIa:1030VTT40<6JC@@0`ieB1038XUT50<^UGP@0d:UT103<Yf440<RSG`@0aZ=O
1039YV840<NUGP@0`j5J103;ZF850=RfK`@0bZQP1034XUX40<FPF@@0cJQQ103G/V/40=F`J@@0cJMN
1037XEP50<NRE0@0aJ1B1037XU840<>NCP@0_9M6102kUTD80;jIB0@0_YU91@2mV4P40<NRE0@0eJiQ
103;XU840<RNC0@0`IU4102mUCh40;fF>`D0^i<k102lUch40<FOBP@0_IM2102lUT<40;fGA0@0`I]8
1039Xe840<BNC@D0`iY;1031V4P40;bF@@@0/X`g102cSCP40;^EA0@0`9];1033WE840<:NE0D0a9mH
2030WUH40;jLE0@0`Z1H1034XU/40<6OF0@0aJ=L1@37YEd40<BRF0@0a:=F2035Y5D40<RTEP@0cJUK
2`3oool000X0oooo1037WdL40<:J@`@0`YY51031V4H40<2GA@@0`YU71@30V4<40<6IA0@0_9@m1030
V4440<BLA0@0aYi61033WTD40<FPA`@0ajI91@2nVcl40;fJ@0@0`Ye41036XDT40<BOA`@0`Z161034
XTP40<:QA0@0_ia01@2kV3`40;fH?`@0`i]41037WT`40<2KBP@0`9]=102kUd/40<>OE@D0aZ5J1039
Y5d40<RVG`@0bJIR103:Yf<40<VVI0@0b:ES103:YfD40<nZIPD0djiZ103;YV040<ZUG`@0a9iG1038
XU/40=VcK0@0e:iW103;YE`40<NQF0D0b:=E1036XE<40<RQDP@0`ia=1030VTT40;nIB0@0_iU6102n
V4D40<2JB@D0`ie<1038XU440<nYF0@0fk9P1039X4h40;jF?`@0_IDn102kTc/50;bD?@@0_YU11032
W4T40<2JA`P0_9I51032W4/40<RRD@@0a9i=1@33W4d40;nIB0@0_iM0102lU3d40;jF?`@0`IQ61032
WD`40<6LC0@0_IU;1@30W4h80;jMD0@0_I]A1030WU@40<FSF`@0`j5I1038Xe`50<NRF`P0aj=G1038
Y5H40<NSE@@0bJEG103=ZE/;0?ooo`002P3oool40<NOA`@0`YY31032VTD40<6HAP@0`9M51032VDL5
0<2H@`@0`IU4102lU3d40<2H@@@0a9a41036WTH40<>NA@@0aJ171037YTT50;jK?`@0_IY01032WD@4
0<JQB@@0a9m71032X4H40<BRB0@0`Z54102oW4050;^H?0@0_IPo1033Vd@40<NNC0@0`9]:1030Vdd4
0;^GB`@0`imE1@36XEX40<VTG@@0b:IO1039YV840<ZWH`@0bJIT1038YF<40<ZWI@@0cjYV1@3C[VX4
0<^VH0@0bZEO1034WUL40<RRF`@0fK=/103D[VL40<^UG0@0aj5H1@38XeD40<JQD`@0b:5B1033W4d4
0<2JB@@0_iU8102oVDH40;jHA@@0`9Y91@33WD`40<RRD@@0cjUH103K/V040<VPCP@0_YHo102mUCh4
0;^C>`D0_9@m102nVD440<:LB@@0`9Y7202lUTD40<:LB`@0b:9A1034WTd50<>LC@@0_iU8102oUd04
0;bD?@@0_YHo1031V4H40<:MC0@0`Ia<102mVD/50<2LCPP0_Ye@102mVe440<2NE0@0aJ=K1033XET4
0<RSG0D0aj9K2037XeL40<RTEP@0aj=E1039YEL40<fYF`/0oooo000:0?ooo`@0aim71032VT<40<:J
A@@0`IQ61030UdD40<:IA`D0`9Q31031VD@40;bD?@@0`9Q11034W4@40<JNAP@0`ii51035X4L40<NV
B@D0_Y/o102mVT040<:MA0@0aZ591034WdL40<:PAP@0a:981032XD@40;nL@0D0^iPl102mV3l40<>K
A0@0aii<1030VdX40<2KC@@0^iM;1033WeD50<JQFP@0bJAM1038YUl40<VVHP@0bZMS1039YV@40<RU
H`@0bZMU103?ZVH50=>^JP@0bjIP103:YEl40<BNE`@0b:9K103I/f`40=B^I`@0bjEL1037XEP50<RS
E@@0aZ5C1038XE840<>LC@@0`9Y9102oVDP40;nIAP@0_YQ51030VTT50<>MC0@0b:9A103?ZEP40=^b
H0@0bJ1>102nUSl40;fE?P@0^i<k1@2lU3d40;jI@@@0`Ya91030VTL80;bFA@@0`Ya;1038XU440<BN
C@D0`ia=102oVDP40;nG@0@0_9@m102nUSl40<6HAP@0`Ye<1031W4`40;fIB`D0`9a>202nWE040;fK
D@@0`9iD1035Xe/40<>QF@@0b:=L1@37XU/80<NSE`@0b:AF1037XeD40<VUE`@0cJUK2`3oool000X0
oooo1037WdL40<:J@`@0`YY51031V4H40<2GA@@0`YU71@30V4<40<6IA0@0_9@m1030V4440<BLA0@0
aYi61033WTD40<FPA`@0ajI91@2nVcl40;fJ@0@0`Ye41036XDT40<BOA`@0`Z161034XTP40<:QA0@0
_ia01@2kV3`40;fH?`@0`i]41037WT`40<2KBP@0`9]=102kUd/40<>OE@D0aZ5J1039Y5d40<RVG`@0
bJIR103:Yf<40<VVI0@0b:ES103:YfD40<nZIPD0djiZ103;YV040<ZUG`@0a9iG1038XU/40=VcK0@0
e:iW103;YE`40<NQF0D0b:=E1036XE<40<RQDP@0`ia=1030VTT40;nIB0@0_iU6102nV4D40<2JB@D0
`ie<1038XU440<nYF0@0fk9P1039X4h40;jF?`@0_IDn102kTc/50;bD?@@0_YU11032W4T40<2JA`P0
_9I51032W4/40<RRD@@0a9i=1@33W4d40;nIB0@0_iM0102lU3d40;jF?`@0`IQ61032WD`40<6LC0@0
_IU;1@30W4h80;jMD0@0_I]A1030WU@40<FSF`@0`j5I1038Xe`50<NRF`P0aj=G1038Y5H40<NSE@@0
bJEG103=ZE/;0?ooo`002P3oool40;nH?@@0`YY31033Vd@40<RPB`@0`YU71033VTP50<>KAP@0b:1;
102mUCd40;^C>`@0aIi31039XTL40<>L?`@0a9e01035XT@50;nL?P@0`9]01034Wd@80<>NA@@0`Z16
1037YD/40<>RA@@0`9e11@2oW4840;jI@@@0`9]31031VdP40;nKA`@0_iY:102iV4L40;bKCPD0_iiA
1034XUX40<NUG@@0bjUR103:Yf<40<^XI0@0d:YY103=YfH40=:[J0D0djaY103<Y5h40<VQF`@0a9aD
1035WED40=2XH0@0eZiV103=YEd40<FME@D0c:EH103=YUT40<ZSE0@0aIi?102oVDH40;jHA@P0`9M5
1030V4<50<JNB@@0bJ5<103>YU440<bWC`@0b:=;1032WD@40;fH?`@0^iHn1@2lUT440<2JA`@0aIm>
1035WTl40;fFA`@0`9Y91039Xe840<>MBP@0_iU61@31VdX40<>JB0@0`i]41031V4040<>KA0@0`YY5
1033WDP40<>MBP@0`9]:1@2nVDP40;jKBP@0_IY9102nVT`40;nKC@P0`imC1036X5L50<NQF0P0bJ9G
1039XeP40<ZTF@@0bJEI103;Ye/;0?ooo`002P3oool40;nH?@@0`YY31033Vd@40<RPB`@0`YU71033
VTP50<>KAP@0b:1;102mUCd40;^C>`@0aIi31039XTL40<>L?`@0a9e01035XT@50;nL?P@0`9]01034
Wd@80<>NA@@0`Z161037YD/40<>RA@@0`9e11@2oW4840;jI@@@0`9]31031VdP40;nKA`@0_iY:102i
V4L40;bKCPD0_iiA1034XUX40<NUG@@0bjUR103:Yf<40<^XI0@0d:YY103=YfH40=:[J0D0djaY103<
Y5h40<VQF`@0a9aD1035WED40=2XH0@0eZiV103=YEd40<FME@D0c:EH103=YUT40<ZSE0@0aIi?102o
VDH40;jHA@P0`9M51030V4<50<JNB@@0bJ5<103>YU440<bWC`@0b:=;1032WD@40;fH?`@0^iHn1@2l
UT440<2JA`@0aIm>1035WTl40;fFA`@0`9Y91039Xe840<>MBP@0_iU61@31VdX40<>JB0@0`i]41031
V4040<>KA0@0`YY51033WDP40<>MBP@0`9]:1@2nVDP40;jKBP@0_IY9102nVT`40;nKC@P0`imC1036
X5L50<NQF0P0bJ9G1039XeP40<ZTF@@0bJEI103;Ye/;0?ooo`002P3oool40;nH?@@0`YY31033Vd@4
0<RPB`@0`YU71033VTP50<>KAP@0b:1;102mUCd40;^C>`@0aIi31039XTL40<>L?`@0a9e01035XT@5
0;nL?P@0`9]01034Wd@80<>NA@@0`Z161037YD/40<>RA@@0`9e11@2oW4840;jI@@@0`9]31031VdP4
0;nKA`@0_iY:102iV4L40;bKCPD0_iiA1034XUX40<NUG@@0bjUR103:Yf<40<^XI0@0d:YY103=YfH4
0=:[J0D0djaY103<Y5h40<VQF`@0a9aD1035WED40=2XH0@0eZiV103=YEd40<FME@D0c:EH103=YUT4
0<ZSE0@0aIi?102oVDH40;jHA@P0`9M51030V4<50<JNB@@0bJ5<103>YU440<bWC`@0b:=;1032WD@4
0;fH?`@0^iHn1@2lUT440<2JA`@0aIm>1035WTl40;fFA`@0`9Y91039Xe840<>MBP@0_iU61@31VdX4
0<>JB0@0`i]41031V4040<>KA0@0`YY51033WDP40<>MBP@0`9]:1@2nVDP40;jKBP@0_IY9102nVT`4
0;nKC@P0`imC1036X5L50<NQF0P0bJ9G1039XeP40<ZTF@@0bJEI103;Ye/;0?ooo`002P3oool40;nH
?@@0`YY31033Vd@40<RPB`@0`YU71033VTP50<>KAP@0b:1;102mUCd40;^C>`@0aIi31039XTL40<>L
?`@0a9e01035XT@50;nL?P@0`9]01034Wd@80<>NA@@0`Z161037YD/40<>RA@@0`9e11@2oW4840;jI
@@@0`9]31031VdP40;nKA`@0_iY:102iV4L40;bKCPD0_iiA1034XUX40<NUG@@0bjUR103:Yf<40<^X
I0@0d:YY103=YfH40=:[J0D0djaY103<Y5h40<VQF`@0a9aD1035WED40=2XH0@0eZiV103=YEd40<FM
E@D0c:EH103=YUT40<ZSE0@0aIi?102oVDH40;jHA@P0`9M51030V4<50<JNB@@0bJ5<103>YU440<bW
C`@0b:=;1032WD@40;fH?`@0^iHn1@2lUT440<2JA`@0aIm>1035WTl40;fFA`@0`9Y91039Xe840<>M
BP@0_iU61@31VdX40<>JB0@0`i]41031V4040<>KA0@0`YY51033WDP40<>MBP@0`9]:1@2nVDP40;jK
BP@0_IY9102nVT`40;nKC@P0`imC1036X5L50<NQF0P0bJ9G1039XeP40<ZTF@@0bJEI103;Ye/;0?oo
o`002P3oool40;29;P@0^i<l1031VD840<:JA@@0`iY81036WD/50<NOBP@0a9a72030V4440<2I?P@0
`ia11037X4440<JO@0@0`im11@32WT040<>L@@@0a9e21033Vd<40<FMA@@0`9e32031WT@40;jK@@D0
`Ia4102oVT840;nIA0@0_iU6102oVdL40;nJB@@0_Ia;102kVTT50;jMCP@0`J1C1036YEP40<^YH@@0
b:IN103:Z6440<^VHP@0dZeY103G/6/50=2YI0@0cZIN1038X5P80<BJCP@0bj5G103CZEl40=J/HP@0
d:IL1@3:X5@40<bREP@0d:IJ1036W5040;^B@P@0`IQ81033VTP80<:IA`D0bZ5?103=Xdl40<^QC@@0
bZE=1036XDT40<>NA@@0_YU1102iU3`50;nIAP@0bJ=B103<YEH40<JOD0@0_II71032W4T40<bVD`@0
`I]6102kUD050;jH@`@0aIe81034W4@40<NNAP@0aIe61034W4D40<>MB0@0_iU41032W4L50;nIA0@0
_IU3102lV4840;nKA`@0`9]:1031VdX40<2IBP@0`9U<1@36We840<NPE@@0bJ9G103;Y5T40<bUFPP0
bJEI2`3oool000X0oooo102`RBh40;^C?0@0`IU21032VTD40<>JB0@0aYe;1@37WdX40<BLA`P0`9Q1
1030VCh40<>L@@@0aj111036Wd040<>O@@D0`Yi01033W4440<BM@P@0`i]31035WDD40<2M@`P0`Ii4
102nVd450<6LA0@0_iY2102oVD@40;nIAP@0_i]7102oVTT40;fLB`@0^iY91@2nWDh40<6PD`@0aZEH
103;ZF440<RVGP@0bZQQ103;YV840=:]J@@0ek1[1@3@ZF@40<jVGP@0b:1H2034VTh40<^QE`@0djUO
103F[6840=2VG0D0bZ1D103<XUH40=2VFP@0aYa@102kTT840<6HB0@0`iY82032VDL50<ZQC`@0cJ=?
103;XDd40<ZUC@@0aZ591033WTD40;jI@@@0^I@l1@2oVDH40<VSDP@0c:EF1036We040;fFA`@0`Ya9
103<YU<40<6KAP@0^iE01@2nV4<40<FMB0@0a9a41037WTH40<FMAP@0a9a51033WDP40;nIA0@0`Ya7
1@2oVD@40;fI@`@0_9Q2102oVdL40<2KBP@0`I]:1030VDX40<2IC0D0aYmB1037X5D40<VRE`@0bjAI
103<YEX80<VUF@/0oooo000:0?ooo`@0/8T^102kTc`40<6I@P@0`YY51033VTP40<JMB`D0aim:1034
W4L80<2H@@@0`9Tn1033W4440<NP@@@0aYm01033Wd450<:N@0@0`ia11034WD840<>K@`@0aIe51030
WD<80<6NA0@0_Y]11@31W4@40;nJ@P@0_iU4102oVDH40;nKA`@0_iY9102mW4/40;^JB@D0_Ye>1031
X5<40<JUF0@0bjUQ1038YUh40<ZXH@@0bjIR103B[FT40=N`J`D0d:UT103>YUh40<RPF0P0a9Y>103;
XEL40=>YG`@0eZaR103@YU`50<ZPE0@0c:9F103@YUX40<JLD0@0^i921031V4P40<>JB0P0`YU71@3:
XDl40<fSC`@0bj5=103:YDd40<JQB@@0`ii5102nVD440;VD?0D0_iU61039Xe840<bUEP@0aYm@102m
UTL40<:LB@@0c:IC1031VdH40;^E@0D0_YQ31035WDP40<BLA0@0aii61035WDH40<BLA@@0`ie8102o
VD@40<:LA`D0_iU4102mVD<40;bH@P@0_i]71030VdX40<6KBP@0`9U:1030VD`50<JODP@0aj1E1039
XUL40<^TF@@0c:EJ2039YET;0?ooo`002P3oool40;29;P@0^i<l1031VD840<:JA@@0`iY81036WD/5
0<NOBP@0a9a72030V4440<2I?P@0`ia11037X4440<JO@0@0`im11@32WT040<>L@@@0a9e21033Vd<4
0<FMA@@0`9e32031WT@40;jK@@D0`Ia4102oVT840;nIA0@0_iU6102oVdL40;nJB@@0_Ia;102kVTT5
0;jMCP@0`J1C1036YEP40<^YH@@0b:IN103:Z6440<^VHP@0dZeY103G/6/50=2YI0@0cZIN1038X5P8
0<BJCP@0bj5G103CZEl40=J/HP@0d:IL1@3:X5@40<bREP@0d:IJ1036W5040;^B@P@0`IQ81033VTP8
0<:IA`D0bZ5?103=Xdl40<^QC@@0bZE=1036XDT40<>NA@@0_YU1102iU3`50;nIAP@0bJ=B103<YEH4
0<JOD0@0_II71032W4T40<bVD`@0`I]6102kUD050;jH@`@0aIe81034W4@40<NNAP@0aIe61034W4D4
0<>MB0@0_iU41032W4L50;nIA0@0_IU3102lV4840;nKA`@0`9]:1031VdX40<2IBP@0`9U<1@36We84
0<NPE@@0bJ9G103;Y5T40<bUFPP0bJEI2`3oool000X0oooo102mU3X40;jE?@@0_YHn102oUd040<JN
B@@0bJ5<1@35WDP40<JNB@@0a9a51031VD840<6J?`@0a9e21037WT840<:I?@T0a9/o1036VT440<FI
@0@0a9]31037WTH40<:MA@@0`9]31030W4@40;jJ@PD0`ie81032W4L40<2JA`@0`Ya91031WT`40;nL
BP@0_iY91031W4/50<2MC0@0_Y]:1031WDl40<^WF`@0bJEI1037XeT40<nYHP@0cJMP103AZf850=2Z
H@@0cZMJ103:XeH40<ROC`@0`YU:1038We040<bREP@0c:EH103=YUT50<^TF@@0a9eB2035WU<80<BM
DP@0aieA1039We<40<ROD0D0c:=D103AZ5P40=2WE@@0a9i91035X4P40<>NAP@0`Ia41030VTD50;fG
A0@0_iU81036We040<:LB`@0_9I51031VdH40<NQC0@0`Ia3102nVD050;jI@@@0aJ181036WTL40<NO
B0@0aIe81034W4L40<NOBP@0aIe81038X4T50<:J@`@0_9@l102nUSh40<:J@`@0a9a51032VTD80<2G
A@D0aii?1037X5<40<^TF@@0c:IK103;YEX40<JRF0@0aJ5G2`3oool000X0oooo102mU3X40;jE?@@0
_YHn102oUd040<JNB@@0bJ5<1@35WDP40<JNB@@0a9a51031VD840<6J?`@0a9e21037WT840<:I?@T0
a9/o1036VT440<FI@0@0a9]31037WTH40<:MA@@0`9]31030W4@40;jJ@PD0`ie81032W4L40<2JA`@0
`Ya91031WT`40;nLBP@0_iY91031W4/50<2MC0@0_Y]:1031WDl40<^WF`@0bJEI1037XeT40<nYHP@0
cJMP103AZf850=2ZH@@0cZMJ103:XeH40<ROC`@0`YU:1038We040<bREP@0c:EH103=YUT50<^TF@@0
a9eB2035WU<80<BMDP@0aieA1039We<40<ROD0D0c:=D103AZ5P40=2WE@@0a9i91035X4P40<>NAP@0
`Ia41030VTD50;fGA0@0_iU81036We040<:LB`@0_9I51031VdH40<NQC0@0`Ia3102nVD050;jI@@@0
aJ181036WTL40<NOB0@0aIe81034W4L40<NOBP@0aIe81038X4T50<:J@`@0_9@l102nUSh40<:J@`@0
a9a51032VTD80<2GA@D0aii?1037X5<40<^TF@@0c:IK103;YEX40<JRF0@0aJ5G2`3oool000X0oooo
102mU3X40;jE?@@0_YHn102oUd040<JNB@@0bJ5<1@35WDP40<JNB@@0a9a51031VD840<6J?`@0a9e2
1037WT840<:I?@T0a9/o1036VT440<FI@0@0a9]31037WTH40<:MA@@0`9]31030W4@40;jJ@PD0`ie8
1032W4L40<2JA`@0`Ya91031WT`40;nLBP@0_iY91031W4/50<2MC0@0_Y]:1031WDl40<^WF`@0bJEI
1037XeT40<nYHP@0cJMP103AZf850=2ZH@@0cZMJ103:XeH40<ROC`@0`YU:1038We040<bREP@0c:EH
103=YUT50<^TF@@0a9eB2035WU<80<BMDP@0aieA1039We<40<ROD0D0c:=D103AZ5P40=2WE@@0a9i9
1035X4P40<>NAP@0`Ia41030VTD50;fGA0@0_iU81036We040<:LB`@0_9I51031VdH40<NQC0@0`Ia3
102nVD050;jI@@@0aJ181036WTL40<NOB0@0aIe81034W4L40<NOBP@0aIe81038X4T50<:J@`@0_9@l
102nUSh40<:J@`@0a9a51032VTD80<2GA@D0aii?1037X5<40<^TF@@0c:IK103;YEX40<JRF0@0aJ5G
2`3oool000X0oooo102mU3X40;jE?@@0_YHn102oUd040<JNB@@0bJ5<1@35WDP40<JNB@@0a9a51031
VD840<6J?`@0a9e21037WT840<:I?@T0a9/o1036VT440<FI@0@0a9]31037WTH40<:MA@@0`9]31030
W4@40;jJ@PD0`ie81032W4L40<2JA`@0`Ya91031WT`40;nLBP@0_iY91031W4/50<2MC0@0_Y]:1031
WDl40<^WF`@0bJEI1037XeT40<nYHP@0cJMP103AZf850=2ZH@@0cZMJ103:XeH40<ROC`@0`YU:1038
We040<bREP@0c:EH103=YUT50<^TF@@0a9eB2035WU<80<BMDP@0aieA1039We<40<ROD0D0c:=D103A
Z5P40=2WE@@0a9i91035X4P40<>NAP@0`Ia41030VTD50;fGA0@0_iU81036We040<:LB`@0_9I51031
VdH40<NQC0@0`Ia3102nVD050;jI@@@0aJ181036WTL40<NOB0@0aIe81034W4L40<NOBP@0aIe81038
X4T50<:J@`@0_9@l102nUSh40<:J@`@0a9a51032VTD80<2GA@D0aii?1037X5<40<^TF@@0c:IK103;
YEX40<JRF0@0aJ5G2`3oool000X0oooo1033VT040;fD?0@0]Xde1030UT040<6IA0T0aIe81034W4L4
0<:J@`@0`IU22033Vd<40<NN@P@0aIa01034Vd450<FL@P@0bIe61036VT<40<JIA0@0`iU31033Vd@4
0<BOA`@0`im7102oVd<90<:LA`@0_YQ51032W4T40<6NC0@0`9]:1032WD`40<6KBPD0`9Y91032W4/4
0<>NCP@0aZ5C1037XU@40<^UFP@0cZQO103=Yeh40<bVF`D0bZAI1039Y5@40<^VEP@0bjEB1034WTd4
0;nIB0@0aIi?1035WU440<JOE0D0b:5F1034W5@80<BNE`@0aYiH103;Xed80=6YH@@0cjQM1@3AZUl4
0=J/H0@0cZEF1035W4X40<6IA0@0^i<l102mUCh40<BLA`D0`IQ6102mU4840<2GA`@0`iY81033VdH4
0<FMAPP0`i]31032VT850;nG@0@0aIe6103<Y4l40<JNB@@0aim:1036WTT40<FMAP@0b:19103AZ505
0<>J@P@0^Y4g102nUC/40<2G?`@0`iY22032V4840<>IA@D0aYe=1039XUD40<bVG@@0cJUO1039YE/8
0<>OE@/0oooo000:0?ooo`@0`iY0102mU3`40;J==@@0`9I01031VD@90<FMB0@0a9a71032VT<40<6I
@PP0`i]31037WT840<FL@0@0a9]11@35W4840<VMAP@0aYY31036VD@40<>I@`@0`i]41034WdL40<>O
A`@0_i]32@32W4L40;jHA@@0`Ya91031WT`40<2KBP@0`Ye<1031VdX50<2JB@@0`Ya;1033WTh40<JQ
D`@0aj9D103;YEX40<jXG`@0cJMN103<YU/50<ZTF@@0bJAD103;YUH40<^UDP@0a9i=102oVDP40<FN
C`@0aIiA1036We@50<RQEP@0a9aD2034WUL40<JNF0@0bj=M203AZF440<nXG@D0dJYO103F[6040<jU
EP@0aIa:1031VD@40;^C?0@0_IDn1034W4L50<6HAP@0_IA21030UdL40<>JB0@0`i]61035WDH80<>K
@`@0`YY21@2oUd040<FMAP@0c:A?1036WTT40<NOBP@0aYi91035WDH40<RPB@@0dJQ@1@33VT840;ZA
=`@0_YDk1030Ucl40<>J@PP0`YQ21033VDD50<JMC@@0bJ9E103<YUd40<fYG`@0bJEK2033WeD;0?oo
o`002P3oool40<>J@0@0_I@l102fSCD40<2F@0@0`IU42@35WDP40<BLA`@0`YY31031VD880<>K@`@0
aii21035W4040<BK@@D0aIa21039WDH40<JJ@`@0aYU41033VD<40<>KA0@0a9m71033WdL40;nK@`T0
`Ya7102nV4D40<:LB@@0`Ii<1030VdX40<:MC0@0`I]:1@30VTT40<:LB`@0`ii>1036XE<40<NRE0@0
bjEJ103>Z5l40<fWGP@0c:IK1@3:Y5T40<VTE0@0bjIF103;YE840<BNC@@0_iU81035WTl40<FND@@0
aYmD1@38XEH40<BLE0P0a9iG1036WUP40<^SG@P0dJUQ103?Z5d50=6ZG`@0eZaP103>YEH40<FLBP@0
`IU4102kTc`40;fE?P@0a9a71@31V4H40;fD@P@0`9M71033VTP40<>KAP@0aIe62033Vd<40<:J@PD0
_iM01035WDH40<bTC`@0aYi91037WdX40<JNB@@0aIe61038X4T40=6XD0D0`iY2102jTCL40;jE>`@0
`9Lo1033VT880<:H@P@0`iU51@36WDd40<VRE@@0c:IM103=ZEl40<VUF`P0`imE2`3oool000X0oooo
1033VT040;fD?0@0]Xde1030UT040<6IA0T0aIe81034W4L40<:J@`@0`IU22033Vd<40<NN@P@0aIa0
1034Vd450<FL@P@0bIe61036VT<40<JIA0@0`iU31033Vd@40<BOA`@0`im7102oVd<90<:LA`@0_YQ5
1032W4T40<6NC0@0`9]:1032WD`40<6KBPD0`9Y91032W4/40<>NCP@0aZ5C1037XU@40<^UFP@0cZQO
103=Yeh40<bVF`D0bZAI1039Y5@40<^VEP@0bjEB1034WTd40;nIB0@0aIi?1035WU440<JOE0D0b:5F
1034W5@80<BNE`@0aYiH103;Xed80=6YH@@0cjQM1@3AZUl40=J/H0@0cZEF1035W4X40<6IA0@0^i<l
102mUCh40<BLA`D0`IQ6102mU4840<2GA`@0`iY81033VdH40<FMAPP0`i]31032VT850;nG@0@0aIe6
103<Y4l40<JNB@@0aim:1036WTT40<FMAP@0b:19103AZ5050<>J@P@0^Y4g102nUC/40<2G?`@0`iY2
2032V4840<>IA@D0aYe=1039XUD40<bVG@@0cJUO1039YE/80<>OE@/0oooo000:0?ooo`@0`IXo102o
V3d80;nF?P@0_I@l102oUShA0<6I@@@0`IQ01034V4440<RKAP@0cZ1;1037Vd@50<JJ@`@0aiY51037
VTL40<RKB0@0aYU82038VdX40<FKA`@0a9Y61@32VT<40<BLA@P0`9a61030WDT40<2LB0@0`I]81034
VdT50<>JB0@0`iY:1033W4d40<FND`@0aZ1E103:Y5/40<^WG@@0cJUM1035XU450;bIA@@0`im9103:
YTh40<RSB`@0aZ1;1034X4X40<BPC0@0`ii=2@31W4`80<6KD0@0`ieF1035WeP40<RQG0@0cZIP103?
Yf440<VRE`D0bjAI103>YeP40<fWEP@0b9m=1032VTD40;^B@0@0^Y4o1033VTX50<ROC`@0a9U:1032
UdP40<JLBP@0a9Y81036W4P80<BJAP@0`YQ41@30UdD40<:IA`@0`iY81035W4X40<NOBP@0bZ9=2037
XTX40<^VC@D0a9m61032Vch40;jG>P@0_iPi1030VC`40<BK?`@0`YU11033VDL50<BKC0@0aZ5A103@
[5h40<fYG@@0aZ9F1031WeD40<2NE0/0oooo000:0?ooo`@0`IXo102oV3d80;nF?P@0_I@l102oUShA
0<6I@@@0`IQ01034V4440<RKAP@0cZ1;1037Vd@50<JJ@`@0aiY51037VTL40<RKB0@0aYU82038VdX4
0<FKA`@0a9Y61@32VT<40<BLA@P0`9a61030WDT40<2LB0@0`I]81034VdT50<>JB0@0`iY:1033W4d4
0<FND`@0aZ1E103:Y5/40<^WG@@0cJUM1035XU450;bIA@@0`im9103:YTh40<RSB`@0aZ1;1034X4X4
0<BPC0@0`ii=2@31W4`80<6KD0@0`ieF1035WeP40<RQG0@0cZIP103?Yf440<VRE`D0bjAI103>YeP4
0<fWEP@0b9m=1032VTD40;^B@0@0^Y4o1033VTX50<ROC`@0a9U:1032UdP40<JLBP@0a9Y81036W4P8
0<BJAP@0`YQ41@30UdD40<:IA`@0`iY81035W4X40<NOBP@0bZ9=2037XTX40<^VC@D0a9m61032Vch4
0;jG>P@0_iPi1030VC`40<BK?`@0`YU11033VDL50<BKC0@0aZ5A103@[5h40<fYG@@0aZ9F1031WeD4
0<2NE0/0oooo000:0?ooo`@0`IXo102oV3d80;nF?P@0_I@l102oUShA0<6I@@@0`IQ01034V4440<RK
AP@0cZ1;1037Vd@50<JJ@`@0aiY51037VTL40<RKB0@0aYU82038VdX40<FKA`@0a9Y61@32VT<40<BL
A@P0`9a61030WDT40<2LB0@0`I]81034VdT50<>JB0@0`iY:1033W4d40<FND`@0aZ1E103:Y5/40<^W
G@@0cJUM1035XU450;bIA@@0`im9103:YTh40<RSB`@0aZ1;1034X4X40<BPC0@0`ii=2@31W4`80<6K
D0@0`ieF1035WeP40<RQG0@0cZIP103?Yf440<VRE`D0bjAI103>YeP40<fWEP@0b9m=1032VTD40;^B
@0@0^Y4o1033VTX50<ROC`@0a9U:1032UdP40<JLBP@0a9Y81036W4P80<BJAP@0`YQ41@30UdD40<:I
A`@0`iY81035W4X40<NOBP@0bZ9=2037XTX40<^VC@D0a9m61032Vch40;jG>P@0_iPi1030VC`40<BK
?`@0`YU11033VDL50<BKC0@0aZ5A103@[5h40<fYG@@0aZ9F1031WeD40<2NE0/0oooo000:0?ooo`@0
`IXo102oV3d80;nF?P@0_I@l102oUShA0<6I@@@0`IQ01034V4440<RKAP@0cZ1;1037Vd@50<JJ@`@0
aiY51037VTL40<RKB0@0aYU82038VdX40<FKA`@0a9Y61@32VT<40<BLA@P0`9a61030WDT40<2LB0@0
`I]81034VdT50<>JB0@0`iY:1033W4d40<FND`@0aZ1E103:Y5/40<^WG@@0cJUM1035XU450;bIA@@0
`im9103:YTh40<RSB`@0aZ1;1034X4X40<BPC0@0`ii=2@31W4`80<6KD0@0`ieF1035WeP40<RQG0@0
cZIP103?Yf440<VRE`D0bjAI103>YeP40<fWEP@0b9m=1032VTD40;^B@0@0^Y4o1033VTX50<ROC`@0
a9U:1032UdP40<JLBP@0a9Y81036W4P80<BJAP@0`YQ41@30UdD40<:IA`@0`iY81035W4X40<NOBP@0
bZ9=2037XTX40<^VC@D0a9m61032Vch40;jG>P@0_iPi1030VC`40<BK?`@0`YU11033VDL50<BKC0@0
aZ5A103@[5h40<fYG@@0aZ9F1031WeD40<2NE0/0oooo000:0?ooo`@0`ia11033Vd<40<:J@P@0^i<l
202jTS/50;fE?P@0_YHo2030V4080<:H@P@0aIQ31038VdH40<JLB0D0aI]71034VTP40<FKB@P0aia=
1038WDh40<FJB`@0aI]91034VTP50<FMB0@0aYi91034W4D40<>KA0@0`Ia4102nVD440;nG@P@0`IU4
1@32VTD80<6HAP@0`IQ91032WDd40<NRE0@0bZIH103<ZEP40<RUD`D0_ie6102oVd<40<6NA0@0`Ia4
1036X4/40<^WD`@0aJ1?1031W4/40<2KB`D0_IQ8102iTdP40;^EBP@0`ieD1033WEH40<RRF`@0bJ=J
103:Y5/40<VTEPD0bZEG103:YE@40<bWEP@0cjUF1032W4T40;^E@P@0`9Y73@34Vd/40<>JBP@0aI]9
1033VDL80<>KAP@0aYe;1035W4X50<2JA`@0_YQ51031V4H40<:IA`@0`i]61037WdX40<ZRC@@0c:A?
103>YU450<RPB`@0bZ9:1031VD440;jG?0@0`9Tn1034W4@40<6I@P@0`IU41@34Vd/40<>NCP@0cJQJ
103<YeT40<NQEP@0a:1D1033WeD;0?ooo`002P3oool40<>L@@@0`i]31032VT840;^C?0P0^Y8k1@2m
UCh40;jF?`P0`9Q02032V4840<FH@`@0b9]61036W4P50<FKA`@0a9Y81035VdT80<NLC@@0b9e>1035
VT/40<FKB@@0a9Y81@35WDP40<JNB@@0a9a51033Vd@40<6LA0@0_YU1102oUd840<6IA0D0`YY52031
V4H40<6HB@@0`Ye=1037XU@40<ZVF0@0c:UH1038YE<50;nMAP@0_i]31031WT@40<6LA0@0aZ1;103;
Ye<40<FPC`@0`Ia;1030Vd/50;fHB0@0^I=8102kUDX40<>ME0@0`ieF1038XU/40<VSFP@0bZAK1039
Y5H50<ZUE`@0bZED103<YeH40<nYEP@0`Ya9102kUD840<2JA`d0a9];1033VTX40<FKB@@0`iU72033
VdH40<JMB`@0aIa:1@30VTL40;jHA@@0`IQ61032VDL40<>KAP@0aim:103:XTd40<bTC`@0cZIA1@38
X4/40<ZRBP@0`IU1102nUc`40<2I?P@0a9a41031VD840<6IA0D0a9];1033WTh40<fXFP@0c:MI1037
XEH40<BPE0@0`imE2`3oool000X0oooo1033W4440<>K@`@0`YY2102kTc`80;ZB>`D0_IDn102nUSl8
0<2H@0P0`YQ21035V4<40<RKAP@0aYa81@35VdL40<BJB0@0aI]92037W4d40<RMCP@0aIY;1035VdT4
0<BJB0D0aIe81036WTT40<BLA@@0`i]41031W4@40;jI@@@0_iM21031VD@50<:JA@P0`IQ61031V4T4
0<:MC@@0aj9D103:YUP40<bYF0@0b:EC1@2oWDH40;nK@`@0`Ii41031W4@40<JPB`@0bjMC1035X4l4
0<6LB`@0`9];1@2mV4P40;VCB0@0^iE:1033WE@40<>MEP@0b:9K1039XeX40<ZTF`@0bJAF1@3:YEL4
0<ZUE0@0c:MF103?ZEH40<:LB@@0^iE21030VTL=0<BKB`@0`iY:1035VdT40<>IA`P0`i]61036WD/4
0<FLBPD0`9Y7102nV4D40<6HAP@0`YU71033VdH40<NOBP@0bZ9=103<Y4l40<jVD@D0b:1;103:XTX4
0<6I@@@0_YLl1030VCh40<BLA0@0`IU21031VD@50<BKB`@0`ii>103=Z5X40<bWF@@0aj5F1034X5@4
0<>OE@/0oooo000:0?ooo`@0`ia11033Vd<40<:J@P@0^i<l202jTS/50;fE?P@0_YHo2030V4080<:H
@P@0aIQ31038VdH40<JLB0D0aI]71034VTP40<FKB@P0aia=1038WDh40<FJB`@0aI]91034VTP50<FM
B0@0aYi91034W4D40<>KA0@0`Ia4102nVD440;nG@P@0`IU41@32VTD80<6HAP@0`IQ91032WDd40<NR
E0@0bZIH103<ZEP40<RUD`D0_ie6102oVd<40<6NA0@0`Ia41036X4/40<^WD`@0aJ1?1031W4/40<2K
B`D0_IQ8102iTdP40;^EBP@0`ieD1033WEH40<RRF`@0bJ=J103:Y5/40<VTEPD0bZEG103:YE@40<bW
EP@0cjUF1032W4T40;^E@P@0`9Y73@34Vd/40<>JBP@0aI]91033VDL80<>KAP@0aYe;1035W4X50<2J
A`@0_YQ51031V4H40<:IA`@0`i]61037WdX40<ZRC@@0c:A?103>YU450<RPB`@0bZ9:1031VD440;jG
?0@0`9Tn1034W4@40<6I@P@0`IU41@34Vd/40<>NCP@0cJQJ103<YeT40<NQEP@0a:1D1033WeD;0?oo
o`002P3oool40<>L@@@0`i]31032VT840;^C?0P0^Y8k1@2mUCh40;jF?`P0`9Q02032V4840<FH@`@0
b9]61036W4P50<FKA`@0a9Y81035VdT80<NLC@@0b9e>1035VT/40<FKB@@0a9Y81@35WDP40<JNB@@0
a9a51033Vd@40<6LA0@0_YU1102oUd840<6IA0D0`YY52031V4H40<6HB@@0`Ye=1037XU@40<ZVF0@0
c:UH1038YE<50;nMAP@0_i]31031WT@40<6LA0@0aZ1;103;Ye<40<FPC`@0`Ia;1030Vd/50;fHB0@0
^I=8102kUDX40<>ME0@0`ieF1038XU/40<VSFP@0bZAK1039Y5H50<ZUE`@0bZED103<YeH40<nYEP@0
`Ya9102kUD840<2JA`d0a9];1033VTX40<FKB@@0`iU72033VdH40<JMB`@0aIa:1@30VTL40;jHA@@0
`IQ61032VDL40<>KAP@0aim:103:XTd40<bTC`@0cZIA1@38X4/40<ZRBP@0`IU1102nUc`40<2I?P@0
a9a41031VD840<6IA0D0a9];1033WTh40<fXFP@0c:MI1037XEH40<BPE0@0`imE2`3oool000X0oooo
102nUSh40=6YDP@0`ii61033WDP80<2H@`D0_iM21030V4<40<6G@`P0`YQ41031Ud<40<FKA`@0cJ=A
103:Y5<50<FNC`@0`iY;1034Vd`40<NNC`@0aYe>1037WTl40<FLC@@0bIi@1037W4h50<RNC0@0aYa8
1034VT@40<BK@`@0a9/o1032VCl40<2G?@@0`IQ02@31V3h40<6H@0@0`IM11031VdH40<FOC0@0b:A@
103>ZUH40<RVC@D0`Im6102lVCl40;VF?0@0`9]21031W4@40<BQC@@0a:5?1032Wdd40;nLBPD0_YU9
102oVTX40<2KC@@0`Ia>1030W5040<6MD@@0a:1D1038Y5P40<NSE@D0b:AF1039YUD40<bYF0@0a9m>
102mV4L40;^FA@@0`Ia;1031VdX50;nIB0P0aIa:2035WDP40<JNB@@0aIe82032W4T50<:MC0@0_iY9
202oVDP40<:IA`@0aYe;103:XDl40<fTDP@0cZ=D1@3:We080<NNC0@0a9a51032VT<40<:MA@@0`Ia4
1030VTD50;nIAP@0`ie<103:Xe@40<VTEP@0aj9D1036X5D40<BND`/0oooo000:0?ooo`@0_YHn103A
ZE840<>NAP@0`ie82030V4<50;nG@P@0`9Q31031Ud<80<:HA0@0`IM31035VdL40<fSD@@0bZAC1@35
WTl40<>JB`@0a9]<1037WTl40<JMCP@0aii?1035W4d40<VND0@0aia>1@38WT`40<JLB0@0a9Y41034
Vd<40<BK?`@0`YTo1030Ucd40<6H@0T0`IPn1031V4040<6G@@@0`I]61035Wd`40<RTD0@0cZYF1038
YTd50<6OAP@0_9To102iUS`40<2K@P@0`Ia41034XDd40<BQC`@0`Ym=102oW4X50;jIB@@0_iY:1030
Vdd40<6LCP@0`9a@1031WE440<BPE0@0b:AH1037XeD50<RTEP@0bJIE103<ZEP40<BOCP@0_IQ7102k
UTD40<6LB`@0`I]:1@2oVDP80<FLBPP0aIe81036WTT40<FMB0P0`Ya91@32WD`40;nJB@P0_iU81032
VDL40<JMB`@0bZ5?103=Y5840<jSE0D0bYm@2037WT`40<BLA@@0`YY31032WDD40<6LA0@0`9Y51@2o
VDH40<>MC0@0bZ=D1039Y5H40<NRE0@0aZ1E1034WU<;0?ooo`002P3oool40;jF?P@0dJUB1033WTH4
0<>MB0P0`9Q31@2oUd840<2H@`@0`IM32032V4@40<6G@`@0aI]7103=Xe440<ZTD`D0aIi?1033VT/4
0<BKC0@0aii?1036WDh40<NNC`@0aIa=1039WU040<NLCPD0b9i<1036W4P40<BJA0@0a9]31034Vcl4
0<:I?`@0`9Lm1031V4090<6H?P@0`IQ01031Ud440<6KAP@0aIm<1038Y5040<jZEP@0b:I=1@31WdH4
0;bI?`@0^IHl1030Vd840<6LA0@0a:5=1034XDl40<:OC@@0_ia:1@2nVDT40;nJBP@0`9]=1031W4h4
0<2LD0@0`IeA1034X5@40<RTF0@0aj=E1@38Y5H40<VVE@@0c:UH1034Wdh40;fHA`@0^iI51031W4/4
0<6KBPD0_iU82035W4X80<FMB0@0aYi91035WDP80<:LB@D0`Ye<102oVTT80;nIB0@0`YU71036WD/4
0<ZQC`@0cJAB103>Xe@50<ZOD0P0aii<1034W4D40<:J@`@0`Ye51031W4@40<2JA@D0_iU61033WD`4
0<ZSE0@0bJAF1037XU@40<JPE@@0a9iC2`3oool000X0oooo102nUSh40=6YDP@0`ii61033WDP80<2H
@`D0_iM21030V4<40<6G@`P0`YQ41031Ud<40<FKA`@0cJ=A103:Y5<50<FNC`@0`iY;1034Vd`40<NN
C`@0aYe>1037WTl40<FLC@@0bIi@1037W4h50<RNC0@0aYa81034VT@40<BK@`@0a9/o1032VCl40<2G
?@@0`IQ02@31V3h40<6H@0@0`IM11031VdH40<FOC0@0b:A@103>ZUH40<RVC@D0`Im6102lVCl40;VF
?0@0`9]21031W4@40<BQC@@0a:5?1032Wdd40;nLBPD0_YU9102oVTX40<2KC@@0`Ia>1030W5040<6M
D@@0a:1D1038Y5P40<NSE@D0b:AF1039YUD40<bYF0@0a9m>102mV4L40;^FA@@0`Ia;1031VdX50;nI
B0P0aIa:2035WDP40<JNB@@0aIe82032W4T50<:MC0@0_iY9202oVDP40<:IA`@0aYe;103:XDl40<fT
DP@0cZ=D1@3:We080<NNC0@0a9a51032VT<40<:MA@@0`Ia41030VTD50;nIAP@0`ie<103:Xe@40<VT
EP@0aj9D1036X5D40<BND`/0oooo000:0?ooo`@0_IPo1032WDD40<bVD@@0bZA?103<YU<40<FLBPD0
`YU71033VDL80<>IA@@0`YQ41030UT840<BKB@@0cZEE103<YUD50<BMCP@0_iQ91031VT/40<BMD0@0
`Y]>1034WE040<FND@P0aieA1@3:We040<RNC0@0bIa91036VT<40<>G?PP0`iPl1031USX90<2E=`@0
_YHg102oUSX40<2I?P@0a9a41036XDT40<VTC0@0bJI<1@33X4H40;ZE>P@0^9<h102nUSh40<>KA0@0
_i]7102nVDP40;bHA0@0_IU51@2oVTT40<2KBP@0`Ia<1032WDd80<>ND0@0a9iC1036X5D40<FQE@D0
bJEI203:YUX40<bXFP@0a:1B102mV4P40;nHB@@0`I]:1@33VTX40<BJB0@0`iU72036W4P40<BKB@@0
`YU71031VdX40<FOCPD0bZEE1037XU840;nIB0@0_YQ71032VDL40<BKB@@0b9i:103:X4`90<VOC@@0
b9m=1036WD/40<6KAP@0`Ya71037XTX40<FPB0@0a9i91@33WDX40<BOC`@0aj9D1038XeD<0<FPDP/0
oooo000:0?ooo`@0_IPo1032WDD40<bVD@@0bZA?103<YU<40<FLBPD0`YU71033VDL80<>IA@@0`YQ4
1030UT840<BKB@@0cZEE103<YUD50<BMCP@0_iQ91031VT/40<BMD0@0`Y]>1034WE040<FND@P0aieA
1@3:We040<RNC0@0bIa91036VT<40<>G?PP0`iPl1031USX90<2E=`@0_YHg102oUSX40<2I?P@0a9a4
1036XDT40<VTC0@0bJI<1@33X4H40;ZE>P@0^9<h102nUSh40<>KA0@0_i]7102nVDP40;bHA0@0_IU5
1@2oVTT40<2KBP@0`Ia<1032WDd80<>ND0@0a9iC1036X5D40<FQE@D0bJEI203:YUX40<bXFP@0a:1B
102mV4P40;nHB@@0`I]:1@33VTX40<BJB0@0`iU72036W4P40<BKB@@0`YU71031VdX40<FOCPD0bZEE
1037XU840;nIB0@0_YQ71032VDL40<BKB@@0b9i:103:X4`90<VOC@@0b9m=1036WD/40<6KAP@0`Ya7
1037XTX40<FPB0@0a9i91@33WDX40<BOC`@0aj9D1038XeD<0<FPDP/0oooo000:0?ooo`@0_IPo1032
WDD40<bVD@@0bZA?103<YU<40<FLBPD0`YU71033VDL80<>IA@@0`YQ41030UT840<BKB@@0cZEE103<
YUD50<BMCP@0_iQ91031VT/40<BMD0@0`Y]>1034WE040<FND@P0aieA1@3:We040<RNC0@0bIa91036
VT<40<>G?PP0`iPl1031USX90<2E=`@0_YHg102oUSX40<2I?P@0a9a41036XDT40<VTC0@0bJI<1@33
X4H40;ZE>P@0^9<h102nUSh40<>KA0@0_i]7102nVDP40;bHA0@0_IU51@2oVTT40<2KBP@0`Ia<1032
WDd80<>ND0@0a9iC1036X5D40<FQE@D0bJEI203:YUX40<bXFP@0a:1B102mV4P40;nHB@@0`I]:1@33
VTX40<BJB0@0`iU72036W4P40<BKB@@0`YU71031VdX40<FOCPD0bZEE1037XU840;nIB0@0_YQ71032
VDL40<BKB@@0b9i:103:X4`90<VOC@@0b9m=1036WD/40<6KAP@0`Ya71037XTX40<FPB0@0a9i91@33
WDX40<BOC`@0aj9D1038XeD<0<FPDP/0oooo000:0?ooo`@0_IPo1032WDD40<bVD@@0bZA?103<YU<4
0<FLBPD0`YU71033VDL80<>IA@@0`YQ41030UT840<BKB@@0cZEE103<YUD50<BMCP@0_iQ91031VT/4
0<BMD0@0`Y]>1034WE040<FND@P0aieA1@3:We040<RNC0@0bIa91036VT<40<>G?PP0`iPl1031USX9
0<2E=`@0_YHg102oUSX40<2I?P@0a9a41036XDT40<VTC0@0bJI<1@33X4H40;ZE>P@0^9<h102nUSh4
0<>KA0@0_i]7102nVDP40;bHA0@0_IU51@2oVTT40<2KBP@0`Ia<1032WDd80<>ND0@0a9iC1036X5D4
0<FQE@D0bJEI203:YUX40<bXFP@0a:1B102mV4P40;nHB@@0`I]:1@33VTX40<BJB0@0`iU72036W4P4
0<BKB@@0`YU71031VdX40<FOCPD0bZEE1037XU840;nIB0@0_YQ71032VDL40<BKB@@0b9i:103:X4`9
0<VOC@@0b9m=1036WD/40<6KAP@0`Ya71037XTX40<FPB0@0a9i91@33WDX40<BOC`@0aj9D1038XeD<
0<FPDP/0oooo000:0?ooo`@0^I@l1032W4L40<JPB`@0bJ=@103:Y5440<FLBPD0aYe;1035VdT80<>I
A`@0`YU71031V4H40<:LB@@0b:9A103:XE450<BKC0@0`IQ91033VT/40<>LC`@0`Y]>1034WE840<FN
D`@0aj1E1038XEH50<ZQDP@0aii>1039Wdd40<FKA@@0`iY21035W4840<:G>@@0`9Dg3@2nU3840;jC
=0@0_iLh1032VCl40<FPA@@0b:=:1037XTL50<VTB@@0_YTn102dSc@40<2H@0@0aIe61031W4@40;jH
@`@0_YI11030V4<50<6IA0@0`9M51031V4H40<FLC@@0aIi?1038XEH40<BMDP@0`YYB1034WUL50<VS
G0P0b:9K103@ZUl40<BND`@0`9U:1032Vd`40<FLBPD0`IQ6102oUD440<BJAP@0a9M41036VDH40<JL
BP@0`YM8102nV4L40<>LC@D0cZMJ103@ZE`40<2IBP@0_YQ71031V4H40<>IA@@0aI]51039W4L40<FK
A`D0aYa82038X4/40<JQB@@0`ii61032WTH40<6MA`@0aZ1;1@3;YE@40<RSE@@0b:9G1036XU@40<BP
DPP0`j1>2`3oool000X0oooo102iU3`40<:LA`@0aZ1;1039Xe040<ZTD@@0aIa:1@36WD/40<FKB@P0
`iU71032VDL40<6HAP@0`Ya91038XU440<ZQD@D0a9]<1031V4T40<>JB`@0`ia?1032Vdh40<BMDP@0
aIiC1037X5D40<RQEPD0bZ5B1037WTh40<VOC@@0aI]51033VT840<FL@P@0`YLi1030UCL=0;jD<P@0
_Y<d102oUcP40<:I?`@0aJ151038XdX40<NRA`D0bJA9102nVCh40;B?=0@0`9Q01035WDH40<6LA0@0
_YQ3102nUT440<2H@`D0`IU41030UdD40<6HAP@0aIa=1035WTl40<RQEP@0a9eB1032VU840<BNE`D0
bJ=L2038XU/40=2ZG`@0a9iC1030VDX40<:KC0@0aIa:1@31V4H40;nE@@@0a9Y61034Ud@40<JIAP@0
aYa:1032UdP40;jHA`@0`ia=1@3>YeX40=2YG0@0`9U:102nV4L40<6HAP@0`iU51035VdD40<VLA`@0
aI]71@36W4P80<RPB`@0aZ591033WTH40<:NAP@0`Ie71036X4/50<^UE0@0b:=E1038XUL40<JRE0@0
a:1B2033X4h;0?ooo`002P3oool40;VD?0@0`Ya71036X4/40<VSD0@0bZAA1035W4X50<JMB`@0aI]9
2033VDL40<:IA`@0`IQ61032W4T40<RRD@@0bZ5A1@34Vd`40<6HB@@0`iY;1033W4l40<:KCP@0a9eB
1035WU<40<NPE@@0b:5F1@3:XE840<NNCP@0bIm=1035VdD40<>J@P@0aIa21032UcT40<2E=`d0_Y@b
102nTc@40;nG>0@0`YTo1035X4D40<RSBP@0aj971@39Y4T40;jI?P@0]8ld1030V4040<FMAP@0`Ia4
102nV4<40;jF@@@0`9Q31@31VD@40<2GA@@0`IQ61035W4d40<FNC`@0b:5F1034WE840<:JDP@0a9iG
1@39Xe`80<RRF`@0d:YO1034WU<40<2IBP@0`Y]<1035W4X50<6HAP@0_iE11034VTH40<BGA0@0aYU6
1036W4X40<:GB0@0_YQ71033W4d50<jWFP@0d:UL1030VDX40;jHA`@0`IQ61033VDD40<FKA@@0bIa7
1035VdL50<JLB0P0b:1;1036XDT40<>NAP@0`Yi61031WDL40<JPB`D0bjED1038XeD40<RRE`@0aZ9D
1034X5880<>PCP/0oooo000:0?ooo`@0^I@l1032W4L40<JPB`@0bJ=@103:Y5440<FLBPD0aYe;1035
VdT80<>IA`@0`YU71031V4H40<:LB@@0b:9A103:XE450<BKC0@0`IQ91033VT/40<>LC`@0`Y]>1034
WE840<FND`@0aj1E1038XEH50<ZQDP@0aii>1039Wdd40<FKA@@0`iY21035W4840<:G>@@0`9Dg3@2n
U3840;jC=0@0_iLh1032VCl40<FPA@@0b:=:1037XTL50<VTB@@0_YTn102dSc@40<2H@0@0aIe61031
W4@40;jH@`@0_YI11030V4<50<6IA0@0`9M51031V4H40<FLC@@0aIi?1038XEH40<BMDP@0`YYB1034
WUL50<VSG0P0b:9K103@ZUl40<BND`@0`9U:1032Vd`40<FLBPD0`IQ6102oUD440<BJAP@0a9M41036
VDH40<JLBP@0`YM8102nV4L40<>LC@D0cZMJ103@ZE`40<2IBP@0_YQ71031V4H40<>IA@@0aI]51039
W4L40<FKA`D0aYa82038X4/40<JQB@@0`ii61032WTH40<6MA`@0aZ1;1@3;YE@40<RSE@@0b:9G1036
XU@40<BPDPP0`j1>2`3oool000X0oooo1030V4440;nG@0@0`i]61036WTT80<>KAPT0`IU42030V4<4
0<6HAP@0`iY81034WT/40<NNC0@0b9m=1@36W4X40<>JBP@0`iY;1035W4d40<JLD0@0b:5F1037X5D4
0<BMDP@0aj1E1@3;XU<40<bSD`@0cJAB1036WTT40<BLA0@0`YTo1031V3`40<2E=`T0_Y@b102oUC44
0<2F=0@0_YHf102nUCT40<NPA@@0aim71038XdX50<VTB`@0`YY2102lU3`40<2H@0P0a9a52036WTT4
0<BLA`D0a9Y61033VDL40<:IA`@0`iY;1035W4d40<JLDP@0aIiC1038X5P40<BNE`D0`ieF1034WUL4
0<RRF`@0g;I[1038XUL40<6JB`@0`Y]<2@35W4X40<FKA`@0aYa81038WT`40<JLBP@0`iY:1030UdL4
0<6JB`@0aIi?1@3:Xe@40<RQDP@0aIi?1030VTT40<:IA`@0`iU51035VdD40<VLA`@0aI]51@34VT@4
0<:MA0@0`ii51034XDL40;nL@P@0_YY21032WTP40<JPC`D0aj1C2038Y5P40<NSE@@0a:5@1031WTX4
0<:OB`/0oooo000:0?ooo`@0`9Q1102oUd040<>KAP@0aYi92033VdH90<6IA0P0`9Q31031V4H40<>J
B0@0a9i;1037WT`40<ROC@D0aYa:1033VTX40<>JB`@0aIa=1036W5040<RQEP@0aj1E1034WE840<NP
E@D0bj9C103<Xe<40<fTDP@0aYi91034W4@40<:I?`@0`IPl1030UCL90;jD<P@0_iDa1030US@40;jF
=P@0_YDi1037X4D40<NOA`@0b:=:1@39Y4/40<:J@P@0_9@l1030V4080<BLA@P0aYi91034W4L50<BJ
AP@0`iU71032VDL40<>JB`@0aIa=1036W5840<FND`@0b:1H1034WUL50<>MEP@0a9iG1038XU/40=bf
J`@0b:9G1031VT/40<:KC0T0aIa:1035VdL40<JLB0@0b9i<1036W4X40<>JBP@0`9M71031VT/40<FN
C`D0bZ=D1038XE840<FNC`@0`9Y91032VDL40<>IA@@0aI]51039W4L40<FKA@D0a9Y41032WD@40<>N
A@@0a:57102oW4840;jJ@P@0`Yi81036X4l50<NPD`P0b:AH1037XeD40<BQD0@0`Ii:1032Wd/;0?oo
o`002P3oool40<2H@@@0_iM01033VdH40<JNB@P0`i]62@31VD@80<2H@`@0`IQ61033VTP40<BNB`@0
aii<1038Wdd50<JLBP@0`iY:1033VT/40<FLC@@0aYa@1038XEH40<NPE@@0a9eB1037X5D50<^RD`@0
c:=C103=Y5840<JNB@@0a9a41032VCl40<6H?0@0`9Dg2@2nU3840;nE<@@0`9Hd102nUSH40;jE>@@0
aj151037WdL40<RSBPD0bJA;1032VT840;bD?0@0`9Q02034W4D80<JNB@@0a9a71@34VTH40<>IA`@0
`YU71033VT/40<FLC@@0aYaB1035WU<40<RPF0@0a9iG1@33WEH40<BNE`@0b:9K103L]V/40<RRE`@0
`IY;1032Vd`90<FLBP@0aI]71036W4P40<RNC0@0aYa:1033VTX40<2GA`@0`IY;1035WTl50<ZSE0@0
b:5B1035WTl40<2JB@@0`YU71033VDD40<FKA@@0bIa71035VdD50<BJA0@0`Ye41033WTD40<BQA`@0
_ia2102nVT840<:NB0@0aZ1?1@37X5<80<RTF0@0aj=E1034XE040<6NBP@0`Ym;2`3oool000X0oooo
1030V4440;nG@0@0`i]61036WTT80<>KAPT0`IU42030V4<40<6HAP@0`iY81034WT/40<NNC0@0b9m=
1@36W4X40<>JBP@0`iY;1035W4d40<JLD0@0b:5F1037X5D40<BMDP@0aj1E1@3;XU<40<bSD`@0cJAB
1036WTT40<BLA0@0`YTo1031V3`40<2E=`T0_Y@b102oUC440<2F=0@0_YHf102nUCT40<NPA@@0aim7
1038XdX50<VTB`@0`YY2102lU3`40<2H@0P0a9a52036WTT40<BLA`D0a9Y61033VDL40<:IA`@0`iY;
1035W4d40<JLDP@0aIiC1038X5P40<BNE`D0`ieF1034WUL40<RRF`@0g;I[1038XUL40<6JB`@0`Y]<
2@35W4X40<FKA`@0aYa81038WT`40<JLBP@0`iY:1030UdL40<6JB`@0aIi?1@3:Xe@40<RQDP@0aIi?
1030VTT40<:IA`@0`iU51035VdD40<VLA`@0aI]51@34VT@40<:MA0@0`ii51034XDL40;nL@P@0_YY2
1032WTP40<JPC`D0aj1C2038Y5P40<NSE@@0a:5@1031WTX40<:OB`/0oooo000:0?ooo`@0`9Lo1032
VD440<>I@`P0`YQ21034VT@50;jF?`@0^Y8k102hTc/40;bG?`@0_YQ31030VTL40<:LB@@0`Ya;1037
WT`50<FLC0@0`iY:1034Vd`40<NMD@@0bImC103>Y5X40<fSF@@0aieA1036W5050<ROC`@0bJ1@1039
XD`40<FMB0@0bJ591031VD440;nF>P@0_9@e1@2nTc@40<2F=0@0`ILe1031USL40;jF=`@0^i8h1033
Vd<40<NOB0@0aZ591@37XTX40<BLA0@0`9Q01035VdD40<:HA0@0aYi91037WT`40<NOBP@0aYi91@35
W4X40<BKB@@0a9];1036WDh40<FLC@@0`YQ>1036We@40<jVGP@0aZ1I1@30VU<40<:MEP@0b:=L103?
Zel40<JREPP0`ii>2@33WDX40<BNB@@0`ie81036X4d40<BNB`@0a9i=1032W4/40<>LC@@0aIi?1@35
X5040<BOC`@0aIm>1032W4/40<BKB@@0`iY81034VTH40<RNBP@0b9i81@34VT@40;fH?`@0_9Ln1033
X4@40<2M@`@0_IQ0102mUd@40<>JB`D0bZ1F103;YEX40<bVF`@0bZEG1036XE040<6MB@@0`Yi82`3o
ool000X0oooo1030Ucl40<:I@@@0`iU32032V4840<BJA0D0_YHo102jTS/40;RC>`@0_9Lo102nV4<4
0<2JA`@0`Ya91032W4/40<NNC0D0aIa<1033VTX40<BKC0@0aieA1039We<40<jTFP@0cJ=I1037WE44
0<JLD0D0b9m?1039X5040<VQC0@0aIe81039XDT40<6I@@@0_iHj102lU3D50;jC=0@0`9Hd1031UcD4
0<6F=`@0_YHg102kTSP40<>K@`@0aim81036XDT50<NRBP@0a9a41030V4040<FKA@@0`YQ41036WTT4
0<NNC0@0aim:1036WTT50<FLBP@0a9]91034Vd/40<JMCP@0aIa=1032V4h40<JOE0@0cZIN1036X5T5
0<2JD`@0`YeF1038Xe`40<n[G`@0aZ9F2033WTh90<>MBP@0a9i91033WDP40<JPC@@0a9i;1034WTd4
0<:LB`@0`ia=1035WTl50<FPD0@0a9m?1035Wdh40<:LB`@0a9]91033VTP40<BJAP@0b9i:1038WTP5
0<BJA0@0_IPo102lUch40<>PA0@0`9e3102mV4040;fGA0@0`iY;1@3:X5H40<^UFP@0c:IK103:YEL4
0<JQD0@0`Ie91032WTP;0?ooo`002P3oool40<2G?`@0`YU11033VD<80<:H@P@0a9Y41@2nUSl40;ZB
>`@0^9<k102lUcl40;jH@`@0`9Y71032W4T40<:LB`@0aii<1@35W4`40<>JBP@0a9]<1037WE440<VO
D`@0cZAJ103=XeT40<NMD@@0aYa@1@38Wdl40<VPD0@0bJ5<1035WDP40<VQB@@0`IU1102oUSX40;bD
=@D0_Y<d1030US@40<6G=@@0`IHg102nUSL40;^B>0@0`i]31037WdP40<JQB@D0aj9:1034W4@40<2H
@0@0aI]51032V4@40<JNB@@0aii<1037WdX40<JNB@D0aIa:1034VdT40<BKB`@0aYe>1035W4d40<:H
CP@0aYmD103>YUh40<JPF@D0`9YC1032WEH40<RSG0@0cj]O1036XUH80<>NCPT0`ie:1034WTT40<>M
B0@0aZ1=1034WT/40<BNC@@0`Ya;1033W4d40<FNC`D0aJ1@1034Wdl40<FOCP@0`Ya;1034VdT40<>J
B0@0a9Y61038WTX40<RNB0D0a9Y4102mV3l40;bG?P@0`j141030WD<40;fH@0@0_IM41033VT/50<ZP
EP@0bjEJ103<YU/40<ZUE`@0aZ5@1031WDT40<:NB0/0oooo000:0?ooo`@0`9Lo1032VD440<>I@`P0
`YQ21034VT@50;jF?`@0^Y8k102hTc/40;bG?`@0_YQ31030VTL40<:LB@@0`Ya;1037WT`50<FLC0@0
`iY:1034Vd`40<NMD@@0bImC103>Y5X40<fSF@@0aieA1036W5050<ROC`@0bJ1@1039XD`40<FMB0@0
bJ591031VD440;nF>P@0_9@e1@2nTc@40<2F=0@0`ILe1031USL40;jF=`@0^i8h1033Vd<40<NOB0@0
aZ591@37XTX40<BLA0@0`9Q01035VdD40<:HA0@0aYi91037WT`40<NOBP@0aYi91@35W4X40<BKB@@0
a9];1036WDh40<FLC@@0`YQ>1036We@40<jVGP@0aZ1I1@30VU<40<:MEP@0b:=L103?Zel40<JREPP0
`ii>2@33WDX40<BNB@@0`ie81036X4d40<BNB`@0a9i=1032W4/40<>LC@@0aIi?1@35X5040<BOC`@0
aIm>1032W4/40<BKB@@0`iY81034VTH40<RNBP@0b9i81@34VT@40;fH?`@0_9Ln1033X4@40<2M@`@0
_IQ0102mUd@40<>JB`D0bZ1F103;YEX40<bVF`@0bZEG1036XE040<6MB@@0`Yi82`3oool000X0oooo
2034V4480<NKA0@0aIU21036VT<50<VQB@@0_9@l102eT3L40;ZE?@@0_YU1102oVD@40<:LB@@0a9i;
1037XDh50<:LB`@0`I]:1035WU440<VRE@@0aj1E203;XEL40<ROD0@0aYe>1@38Wdd40<VPCPP0aim8
103>YTh40<6I@@@0^i8f102lU3D50;nG=`@0`ITg1030V3H40;nG=`@0_iHj102lTc/40<6I@P@0aIe8
103:XTd50<^SCP@0aYi71034W4D40<NMA`@0b9i:1035Wd`40<JPC`@0b9m?1039X5050<ZQD@@0bJ1@
1038We040<NNC`@0a9e@1031VTl40<:LD@@0aj5H1033WeD50<2LDP@0_Ye@1032XE@80<^WF`@0a:5@
1033X4l40<JSC`D0`j1<2033WdT40<FQC@@0`im;1034Wdh40<:MC0@0aJ1@1036XE450<>PCP@0`ii=
1032WD`40<>MC0@0aYe;1034VdT40<BJB0@0bIm=103;XU050<NNC0@0`im71030W4@40<FRB0@0_IU1
102hTc/40;jE@`@0`IQ91@36VTl40<jWG0@0d:UL103<YEH40<JPC`@0`9Y51032W4L;0?ooo`002P3o
ool80<BH@@P0ai]41035VD840<JJ@`D0bJ59102lU3`40;F@=`@0^YDm102nVD440;nIA0@0`Ya91034
WT/40<NQCPD0`Ya;1031VdX40<FND@@0bJ9E1037X5D80<^QE`@0b9m@1036WDh50<ROC@@0bJ1>2037
WdP40<jVCP@0`IU1102kTSH40;bD=@D0_iLg1031VCL40<2H=P@0_iLg102oUSX40;bC>`@0`IU21035
WDP40<ZRC@D0bj=>1036WTL40<BLA@@0aie71038WTX40<FOC0@0aZ1?1038Wdl40<VPD0D0bZ5A1039
X5040<ROD0@0aii?1034WE040<6JC`@0`YaA1037XEP40<>OE@D0`9aB102nWE040<:QE0P0bjMK1034
XE040<>PC`@0aZ=?1@33X4`80<>OB@@0aJ5=1033Wd/40<BOCP@0`Ye<1035X5040<JQD@D0`j1>1033
WTd40<:MC0@0`ie<1036WD/40<BKB@@0a9Y81039Wdd40<^RD0D0aii<1033WdL40<2LA0@0aJ98102m
VD440;RC>`@0_YE31031V4T50<JJC`@0cZML103@ZE`40<bUEP@0aZ1?1030VTD40<:LA`/0oooo000:
0?ooo`P0a9Q12037Vd@40<FI@P@0aYY31@39XDT40;bD?0@0]I0g102jUCd40;jI@@@0_iU41032W4T4
0<BNB`@0aj5>1@32W4/40<6KBP@0aIiA1039XUD40<NPE@P0bj5G1038We040<JMCPD0b9m=1039X4h8
0<NOB0@0cZI>1031VD440;^B=P@0_9@e1@2oUcL40<6I=`@0`9Pf102oUcL40;nF>P@0_9<k1031VD84
0<FMB0@0bZ9=1@3;Xdh40<JNA`@0a9a51037WDL40<RNBP@0aIm<1036X4l40<ROC`@0bJ1@1@3:XE44
0<VPD0@0b9m@1037WTl40<BMD0@0`IY?1032W5440<NQF0@0`imE1@30W5840;jMD0@0`Z5D203;Ye/4
0<BQD0@0`j1?1036Xdl50<>PC0P0`im91035XDd40<>OB`@0a9m>1032WD`40<FPD0@0aZ5A1@33X4h4
0<>NC@@0`Ye<1033WD`40<JMB`@0a9]91034VTP40<VOC@@0bj9@1@37WT`40<>OA`@0`9a41035XTP4
0;fI@@@0^9<k102nUD<40<6HB@D0aYY?103>Ye`40=2YG0@0c:EF1036X4l40<2JA@@0`Ya72`3oool0
00X0oooo2034V4480<NKA0@0aIU21036VT<50<VQB@@0_9@l102eT3L40;ZE?@@0_YU1102oVD@40<:L
B@@0a9i;1037XDh50<:LB`@0`I]:1035WU440<VRE@@0aj1E203;XEL40<ROD0@0aYe>1@38Wdd40<VP
CPP0aim8103>YTh40<6I@@@0^i8f102lU3D50;nG=`@0`ITg1030V3H40;nG=`@0_iHj102lTc/40<6I
@P@0aIe8103:XTd50<^SCP@0aYi71034W4D40<NMA`@0b9i:1035Wd`40<JPC`@0b9m?1039X5050<ZQ
D@@0bJ1@1038We040<NNC`@0a9e@1031VTl40<:LD@@0aj5H1033WeD50<2LDP@0_Ye@1032XE@80<^W
F`@0a:5@1033X4l40<JSC`D0`j1<2033WdT40<FQC@@0`im;1034Wdh40<:MC0@0aJ1@1036XE450<>P
CP@0`ii=1032WD`40<>MC0@0aYe;1034VdT40<BJB0@0bIm=103;XU050<NNC0@0`im71030W4@40<FR
B0@0_IU1102hTc/40;jE@`@0`IQ91@36VTl40<jWG0@0d:UL103<YEH40<JPC`@0`9Y51032W4L;0?oo
o`002P3oool40<JMA@@0b9m7203;XD/80<FKA@D0aIe5102oUcl40;ZC=P@0_IHk102nVCh40<2K@`@0
a9i91035W4X40<^RD0D0a9Y81032VDT40<FLC0@0b:9A1039Xe840<ZSE0@0aj1A1037X5<40<>LC`D0
b9m?1038Wdd40<^QC@@0b9i8103>YD/40<FL@P@0^i<d102eS3050;nF>P@0cZE=103;Xd/40<:J@`@0
^Y@o102iTch40;^G@@@0`Yi81037Xd/50<ZUC@@0aZ1;1036WTT40<BKB@@0aii<1034WT/40<NQCP@0
c:=C103=Y5@50<jUEP@0bj9C1037X5<40<FND@@0a9e>1033W4d40<6NC@@0`Ym>102mW4/50;^JB@@0
_Ii>1031X5440<RTF0@0djeR1038Y5P40<:NDP@0ajAC1@3<ZEL40<>PC0@0`Z191032Wd/40<:OC@@0
a:5?102oW4/40<BPDP@0aJ5C1@34XE040<JQD@@0aZ5@1034WTd80<BKB`@0aI]91037WD/40<VOC@D0
bj5?103=Ye840=F_FP@0`ie8102oVD@40;^F?P@0]Y4i102nUSl50<FMB0@0aj=?103=Z5L40<ZTC`@0
b:9=1034XDL40<:OA@/0oooo000:0?ooo`@0aYe51038WdL80<^QB`P0aI]51@35WDD40;nG?`@0^Y<f
102mUS/40;jI?P@0`9]31034WTT40<FLBP@0bj9@1@34VTP40<:IB@@0aIa<1038XU440<VSDP@0bZ=D
1037X5440<NPD`@0`ia?1@38Wdl40<ROC@@0bj5=1038WTP40<jUB`@0aIa2102kTc@40;F<<0D0_iHj
103>YDd40<^SB`@0`YY3102jU3l40;VC?P@0^iM11032WTP40<NSB`D0bZE=1036X4/40<JNB@@0a9]9
1037WT`40<BNB`@0aj5>103<Xe<40<fTE0D0cZEF103;XU<40<NPD`@0aIiA1034WDh40<>LC@@0`Ii=
1032Wdh40;fLB`D0^iY9102mWTh40<6PD@@0b:AH103C[F840<RTF0@0`YiB1037Y5<50<bYE`@0`j1<
1032X4T40<:OB`@0`Ym=1034XDl40;nLB`@0a:1B1035XE<50<BQD0@0aZ5A1036XE040<BNC@P0a9];
1035VdT40<NMB`@0bIm=1@3;XDl40<fWDP@0eJmJ1033WDP40;nIA0@0^iHn102fTCT40;jF?`D0aIe8
1037Xdl40<fXE`@0bZA?1038XTd40<BQA`@0`Ym52`3oool000X0oooo1036WDD40<ROA`P0bj5;2035
VdD50<FMA@@0_iLo102jTcH40;fF>`@0_YTn1030Vd<40<BNB@@0aIa:103;XU050<BJB0@0`YU91035
W4`40<RRD@@0bJ=B103:Xe@40<NPD@@0aj1C1033W4l50<ROC`@0b9m=103;XDd40<RNB0@0cZE;1035
W4840;^C=0@0]H``1@2oUSX40<jUC@@0bj=;1032VT<40;ZD?`@0^I<n102kUd440<:NB0@0aj=;1@3:
YDd40<JPB`@0aYi91034VdT40<NNC0@0a9i;1037XDh40<bSD`@0cJAD1@3>YEH40<^RD`@0aj1C1035
WU440<BMCP@0`ia=1031WTd40<:OCP@0_Ia;1@2kVTT40;fNCP@0`J1A1038Y5P40=>]HP@0b:AH1032
WU840<NTD`D0c:UG1033X4`40<:PB@@0`Ym;1032Wdd40<BQC`@0_ia;1034X5840<FQD`D0a:5@1036
XE440<JQD0@0a9i=2034Vd/40<FKB@@0aie;1039Wdd50<^QC`@0cJMB103E[eX40<>MB0@0_iU4102k
USh40;JA>@@0_YHo1@35WDP40<NSC`@0cJQG103:Y4l40<RRC@@0a:571032WdD;0?ooo`002P3oool4
0<JMA@@0b9m7203;XD/80<FKA@D0aIe5102oUcl40;ZC=P@0_IHk102nVCh40<2K@`@0a9i91035W4X4
0<^RD0D0a9Y81032VDT40<FLC0@0b:9A1039Xe840<ZSE0@0aj1A1037X5<40<>LC`D0b9m?1038Wdd4
0<^QC@@0b9i8103>YD/40<FL@P@0^i<d102eS3050;nF>P@0cZE=103;Xd/40<:J@`@0^Y@o102iTch4
0;^G@@@0`Yi81037Xd/50<ZUC@@0aZ1;1036WTT40<BKB@@0aii<1034WT/40<NQCP@0c:=C103=Y5@5
0<jUEP@0bj9C1037X5<40<FND@@0a9e>1033W4d40<6NC@@0`Ym>102mW4/50;^JB@@0_Ii>1031X544
0<RTF0@0djeR1038Y5P40<:NDP@0ajAC1@3<ZEL40<>PC0@0`Z191032Wd/40<:OC@@0a:5?102oW4/4
0<BPDP@0aJ5C1@34XE040<JQD@@0aZ5@1034WTd80<BKB`@0aI]91037WD/40<VOC@D0bj5?103=Ye84
0=F_FP@0`ie8102oVD@40;^F?P@0]Y4i102nUSl50<FMB0@0aj=?103=Z5L40<ZTC`@0b:9=1034XDL4
0<:OA@/0oooo000:0?ooo`P0aYi62038WdL40<BJA0@0aI]51@33W4440<2I?P@0_9Dh102nUc`40<>N
@`@0`Ye51032W4T40<FOCP@0c:=A1@37WT`40;nIB0@0`Ya;2034Wdh<0<NRDP@0aZ5A1@37XE040<NQ
CP@0aIe81036WTL40<ZQA`@0aIa2102nUSL40;V@=0D0_I@h1033VT840=^cF`@0a9a5102iTch40;ZD
?`@0^YI01031WDL40<>OB@D0aJ5;2034WT/40<JMC@@0aii>1035Wdh40<NQD0@0cZMH103>YeX50=:[
GP@0d:UN1037X5D40<JOE0@0aYmB1032Vdh40<2KB`@0`Ia<102mVD/50;bHBP@0_Ia=1031X5<40<JU
F0@0aZAJ1036XUP40<ZVFP@0b:AF1@38YE@40<>PC0@0`9e91031WTX80<>PCP@0a:5@1034X5840<>O
D@D0aJ9A1034Wdl40<bVE@@0b9m?1035VT/40<:GB0@0bIa;1038VdX40<RNC0D0bIm=103>YU440=6Y
E0@0b:9=1033WDP40<>KAPP0`YY51@37WT`40<JPC@@0bZAC103<Y4l40<VQC0@0aZ591034WdL;0?oo
o`002P3oool80<JNAPP0b9m71034VT@40<FKA@D0`ia11030VCh40;bE>0@0_YLl1033WT<40<:MA@@0
`Ya91035Wdh40<bSD@D0aii<102oVDP40<:LB`P0a9m>3037XU840<JQD@D0aj5@1037XDh40<FMB0@0
aYi7103:XDL40<FL@P@0_YHg102iT3@50;fD>0@0`iY2103K/e/40<BLA@@0^I<n102jU3l40;ZF@0@0
`Ie71033WdT50<FQB`P0a9i;1036WDd40<NNCP@0aIm>1037XE040<jWF0@0cZMJ1@3BZeh40=2YGP@0
aj1E1036We@40<JODP@0`Y]>1030Vd/40<6LC0@0_IU;1@2lV4X40;fLC@@0`J1C1036YEP40<JTFP@0
aZ9H103:YUX40<RTEPD0b:ED1033X4`40<2MB@@0`Ii:2033X4h40<BQD0@0a:1B1033We450<FRD@@0
a9m?103<YUD40<ROC`@0aIY;1032UdP40<VLB`@0b9]:1038WT`50<VOC@@0cZIA103AZE@40<RRC@@0
`ie81033VdH80<:JA@D0aii<1036X4d40<ZTD`@0c:A?1039XD`40<JQB@@0a9m72`3oool000X0oooo
2036WTH80<ROA`@0a9Y41035VdD50<>L@@@0`9Tn102lUCP40;jG?0@0`ii31032WDD40<:LB@@0aIm>
103<Xe450<NNC0@0_iU81032W4/80<BOCP`0aj9B1036XE450<NQD0@0aj5>1035WDP40<JNA`@0bZ57
1035W4840;jF=`@0^I0d1@2mU3P40<>J@P@0fk=K1034W4D40;VC?P@0^Y@o102jUT040<6MA`@0`im9
1@35XD/80<BNB`@0aYe=1037WTh40<FOCP@0aj5@103>YeP40<jWFPD0dZ]N103@ZEh40<NPE@@0aYmD
1036We840<:KCP@0`9];1031W4`40;fIB`D0_9Q:102mW4d40<6PD`@0aZEH1036Y5X40<JRF0@0bZIJ
1038Y5H50<RUE0@0`j1<1030WDT40<6NBPP0`j1>1034XE040<BPDP@0`imA1@35XU440<BOC`@0c:IE
1038Wdl40<FJB`@0`YM81039W4/40<RKBP@0b9i<1@39Wdd40<jVD@@0dJUD1038XTd40<>MB0@0`i]6
2032VTD50<NNC0@0aZ1=103:Y5<40<bTC`@0bJ5<1036XDT40<BOA`/0oooo000:0?ooo`P0aYi62038
WdL40<BJA0@0aI]51@33W4440<2I?P@0_9Dh102nUc`40<>N@`@0`Ye51032W4T40<FOCP@0c:=A1@37
WT`40;nIB0@0`Ya;2034Wdh<0<NRDP@0aZ5A1@37XE040<NQCP@0aIe81036WTL40<ZQA`@0aIa2102n
USL40;V@=0D0_I@h1033VT840=^cF`@0a9a5102iTch40;ZD?`@0^YI01031WDL40<>OB@D0aJ5;2034
WT/40<JMC@@0aii>1035Wdh40<NQD0@0cZMH103>YeX50=:[GP@0d:UN1037X5D40<JOE0@0aYmB1032
Vdh40<2KB`@0`Ia<102mVD/50;bHBP@0_Ia=1031X5<40<JUF0@0aZAJ1036XUP40<ZVFP@0b:AF1@38
YE@40<>PC0@0`9e91031WTX80<>PCP@0a:5@1034X5840<>OD@D0aJ9A1034Wdl40<bVE@@0b9m?1035
VT/40<:GB0@0bIa;1038VdX40<RNC0D0bIm=103>YU440=6YE0@0b:9=1033WDP40<>KAPP0`YY51@37
WT`40<JPC@@0bZAC103<Y4l40<VQC0@0aZ591034WdL;0?ooo`002P3oool40<FMA@P0a9a41033Vd<4
0<BJA0@0aI]51@36WD<40<VPAP@0_iPm102dS3@40;jI@0@0`Ya71032W4/40<BMCP@0bZED1@3=Z5L4
0<6MB@@0`9a81030WD/40<>PCP@0aZ=A1032Wdd40<6LB`@0aJ1?1@3;Ye<40<fYE@@0aj9:1034WdL4
0<FN@`@0`YTo1030V3T40<:G>`D0_YDi1031V4040<VQB@@0aim:1030VTD40;ZD@@@0]i<o102nVTH4
0<6LB`D0aj9A103:Xe@40<VRD`@0aj1A1033W4d40<>NCP@0`ii@103:XeH40<fUG@D0e:aT103H/6X4
0<jVGP@0aimG1037X5<40<bUF0@0aIi?102kU4D40;ZEA`D0_YU;102oVDh40<:NE0@0`j5G1033XeX4
0<NUG@@0cJ]Q103:YUX50<RUE0@0a9m>102kUd<40;nKA`@0`ii=103:YE@40<^VEP@0aJ1B1034We45
0<BQC`@0`ii=1037XDh40<jUD`@0b9i<102mTd480<NJB@@0aiY71@3;WT/40<^QC@@0c:9>103;Xdh4
0=2XD`@0cZEC1036WD/40<ROC@D0bZ5?103;XU040<ZQC`@0bj9@1038Wdd40<^QC`@0bIm=2`3oool0
00X0oooo1035WDD80<BLA0@0`i]31034VT@40<FKA@D0aYe31039X4H40;nH?@@0]8`d102nVD040<:L
A`@0`Ya;1034WDh40<ZUE0D0cJQG1031WDT40<2LB0@0`9e;1033X4h40<JSD@@0`Ym=1031W4/40<FP
C`D0bjMC103=ZED40<NRBP@0a9m71035WT<40<:I?`@0`9Pi1032Uc/50;jE>@@0`IQ01039XDT40<NO
BP@0`9Y5102jU4440;NC?`@0_YY61031W4/50<NRD@@0bZ=D1039XU<40<NPD@@0`ia=1033WTh40<>N
D0@0bZ=F103=YEd50=B/I0@0f;1Z103>YUh40<NOE`@0aj1C103<YEP40<FNC`@0^iA5102jUDL50;jI
B`@0_iU>1032WU@40<>QE`@0`j=J1037YEd40<f[H@@0bZIJ1@38YE@40<BOCP@0^iM3102oVdL40<>N
C@@0bZED103;YUH40<FPDP@0a9mA1@34XDl40<>NC@@0aj5>103>YE<40<RNC0@0_I=12037VTT40<NJ
A`D0bii;103;XDd40<bRCP@0bj=>103@Z5<40<jUD`@0aYe;1038Wdd50<ZQC`@0bj9@103:XDl40<^R
D0@0b9m=103;XDl40<VOC@/0oooo000:0?ooo`@0aIe52034W4@40<>K@`@0a9Y41035VdD50<JM@`@0
bJ16102oV3d40;B<=0@0_YU01032W4L40<:LB`@0a9e>103:YE@50<fXE`@0`Ie91030W4P40<2MB`@0
`j1>1036Xe440<:OC@@0`Ia;1035X4l50<^WD`@0cJUE1037XTX40<BOA`@0aIi31032VCl40<2H>@@0
`YLk1@2nUCT40<6H@0@0bJ591037WdX40<2JA@@0^YA1102gTcl40;jJAP@0`Ia;1@37XU440<ZSE0@0
bJ9C1037X5440<>LC@@0`ii>1033WU040<ZSEP@0cJEM1@3D[6@40=R`JP@0cZIN1037WeL40<NPD`@0
c:EH1035WTl40;^DA@@0^YE71@2nVD/40;nICP@0`YiD1033XEL40<>SFP@0ajEM103=Zf440<ZVFPD0
b:ED1034Wdh40;^G@`@0_i]71033WTd40<ZUE0@0bjIF1035X5840<BOD@D0a:5?1033WTd40<NQCP@0
cZEC1038WT`40;fC@@P0aiY91037VTL50<^NB`@0bj5=103<XTh40<^SCP@0d:QC103>YE<40<JMB`@0
b9m=1@3:XDl40<^RD0@0bZ5?103;XU040<ROC@@0bj5?1039Wdd;0?ooo`002P3oool40<FMA@P0a9a4
1033Vd<40<BJA0@0aI]51@36WD<40<VPAP@0_iPm102dS3@40;jI@0@0`Ya71032W4/40<BMCP@0bZED
1@3=Z5L40<6MB@@0`9a81030WD/40<>PCP@0aZ=A1032Wdd40<6LB`@0aJ1?1@3;Ye<40<fYE@@0aj9:
1034WdL40<FN@`@0`YTo1030V3T40<:G>`D0_YDi1031V4040<VQB@@0aim:1030VTD40;ZD@@@0]i<o
102nVTH40<6LB`D0aj9A103:Xe@40<VRD`@0aj1A1033W4d40<>NCP@0`ii@103:XeH40<fUG@D0e:aT
103H/6X40<jVGP@0aimG1037X5<40<bUF0@0aIi?102kU4D40;ZEA`D0_YU;102oVDh40<:NE0@0`j5G
1033XeX40<NUG@@0cJ]Q103:YUX50<RUE0@0a9m>102kUd<40;nKA`@0`ii=103:YE@40<^VEP@0aJ1B
1034We450<BQC`@0`ii=1037XDh40<jUD`@0b9i<102mTd480<NJB@@0aiY71@3;WT/40<^QC@@0c:9>
103;Xdh40=2XD`@0cZEC1036WD/40<ROC@D0bZ5?103;XU040<ZQC`@0bj9@1038Wdd40<^QC`@0bIm=
2`3oool000X0oooo1033WTH40<6LA0@0`YY21031VD440<BK@`@0aYe51@3<XdT40<>J@0@0_IHi102d
SC840;F@=`@0_iU41036X4d40<JPC`@0bJAC1@38Xe840;nKA`@0`Ie92032WTX40<FQC@P0`im;1034
X4`50<bVD`@0cZQE103;YTh40<BOA`@0`i]31032VD440<2G>`@0`YLk1@2nUC/40<:I@@@0`Ye42033
WDP40;fGA0@0^991102mUdH40<NPD@D0c:EF203=Z5X40<NRE0@0aZ5C1030Vdd40<>MDP@0aj5F103<
YUl50<fWH0@0djaW103F[VP40<fUG@@0bZ=H1037X5<40<FOCP@0`I]:102mUTL50;jGB0@0`9U<102o
VDh40<FSF@@0ajMN1036Y5X40<^WF`@0bZIH1@37XU440<:LB@@0`9Y51030V4<40<>JB0@0aIa:1037
WTh40<BNC@@0aIm>1@39YE440<BNB`@0`ie:1037WT`40<VPCP@0b9m=1037WDT40<FKA`@0aYa81@37
WDT80<VOB`@0bZ5?103BZEL40=2WE@@0aYe;1037WTh50<VPD0@0b:9?1037XDh40<bTC`@0bZ9=103:
X4h40<RNC0/0oooo000:0?ooo`@0`ii61031W4@40<:J@P@0`IU11034Vd<40<JMA@D0c:=91033VT04
0;fF>@@0]8db102eT3L40;nIA0@0aZ1=1036X4l40<VTD`D0b:=B102oVdL40<6MB@P0`Yi:1035XDd8
0<>OB`@0a:1<1@3<YU<40<jXE@@0bjI>1034WdL40<>K@`@0`YU11030Uc/40<:G>`D0_YDk1032VD44
0<:MA0P0`ie8102mUd@40;RB@@@0_IM61037X5450<bUEPP0cJQJ1037XU@40<JQD`@0`9]=1033WE84
0<NQEP@0c:IO1@3=Yf040=>/I`@0eZiX103=YEd40<ZSF0@0aj1C1035Wdh40<6KBP@0_II71@2nUdP4
0<2IC0@0_iU>1035XeT40<NWGP@0aZAJ103;Ye/40<ZVF0D0aj9A1032W4T40<2JA@@0`9Q31033VTP4
0<FLBP@0aii>1034WTd40<FOCPD0bJEA1034WT/40<>MBP@0aii<1039X4h40<ROC@@0aie91035VdL4
0<JLB0D0aie92039Wd/40<ZQC`@0dZUG103@YeD40<JMB`@0aii>1@39X5040<RRC`@0aj5>103<Y4l4
0<ZRC@@0bZ1>1038WT`;0?ooo`002P3oool40<>NAP@0`Ia41032VT840<6I@@@0a9]31036WDD50<bS
B@@0`iY0102mUST40;B=<P@0]I0g102oVD@40<JPC@@0aZ1?1039Y5<50<RSDP@0_i]71031WDT80<:N
BP@0aJ5=2033Wd/40<BPC0D0c:IC103>Z5D40<^VCP@0a9m71033Vd<40<:I@@@0`9Lk1032Uc/50;jE
>`@0`YU11032WD@80<>MB0@0_IM4102hTT440;fGAP@0aj1A1@3<YEH80<fXFP@0aj9D1036XE<40<2K
C@@0`ieB1037XEH40<bVG`D0cJMP103C[6L40=J^J0@0cJEM103:XeP40<NPD`@0aIm>1031VdX40;fF
A`D0_YM81030VD`40;nICP@0aJ=I1037Yeh40<JTFP@0bjMK103:YUP50<NRD@@0`Ya91030VTD40<2H
@`@0`iY81035W4X40<NNCP@0a9i=1035Wdh50<VUD@@0a9i;1033WDX40<NNC0@0bJ1>1038Wdd40<NM
B@@0aI]71036W4P50<NMB@P0bIm;103:XDl40=:YE`@0d:ME1036WD/40<NNCPD0bJ1@1038XTl40<NQ
CP@0c:A?103:XTd40<ZPCP@0b9i<2`3oool000X0oooo1033WTH40<6LA0@0`YY21031VD440<BK@`@0
aYe51@3<XdT40<>J@0@0_IHi102dSC840;F@=`@0_iU41036X4d40<JPC`@0bJAC1@38Xe840;nKA`@0
`Ie92032WTX40<FQC@P0`im;1034X4`50<bVD`@0cZQE103;YTh40<BOA`@0`i]31032VD440<2G>`@0
`YLk1@2nUC/40<:I@@@0`Ye42033WDP40;fGA0@0^991102mUdH40<NPD@D0c:EF203=Z5X40<NRE0@0
aZ5C1030Vdd40<>MDP@0aj5F103<YUl50<fWH0@0djaW103F[VP40<fUG@@0bZ=H1037X5<40<FOCP@0
`I]:102mUTL50;jGB0@0`9U<102oVDh40<FSF@@0ajMN1036Y5X40<^WF`@0bZIH1@37XU440<:LB@@0
`9Y51030V4<40<>JB0@0aIa:1037WTh40<BNC@@0aIm>1@39YE440<BNB`@0`ie:1037WT`40<VPCP@0
b9m=1037WDT40<FKA`@0aYa81@37WDT80<VOB`@0bZ5?103BZEL40=2WE@@0aYe;1037WTh50<VPD0@0
b:9?1037XDh40<bTC`@0bZ9=103:X4h40<RNC0/0oooo000:0?ooo`@0`ie:1032W4T40<>KA0@0`IU2
1035WDD40<RPB0D0aYe31031V3h40;bE>0@0]Xlb102eSS<40;nG?`@0`Ye51038XTd40<ZTD@D0a9i;
1030VTD40<6KAP@0`ie81032W4L40<BNB@@0`ie81033WDX40<:LB@D0b9m=103:XDl40<bTC`@0bJ5<
1037WdP40<FKA@@0`iY21034V4450<2H@0@0_iLo1030Vd<40;bF@@@0aZ1;103:Y5<40;^EA0@0^952
1035WU450<ZSEP@0dJ]P103D[V<40<NSF@@0aZ9H1033WU080<>MDP@0aZ1G1@38XU/40<bVG`@0dZaS
103>Z5l40<fVF@@0bZ=F1037XE040<BNC@@0`YU91@2nUDD40;nFAP@0`IY;1034We440<bXG0@0b:=E
1034WE040<JPC`D0bJ1>1034VTH40<:H@P@0_i8m1030Td040<NMB@@0`iU71035W4`40<ZQD@D0aZ1;
1035Wd`40<BNB`@0a9i=2036X4d40<NQCP@0aIm<1036WTT50<FMB0@0aim:1035WDP80<FOC0@0aZ1?
1038XU440<:MC@D0aj9B103?ZUT40<VTD`P0bJ=>1037WdP40<NOBP/0oooo000:0?ooo`@0`ie:1032
W4T40<>KA0@0`IU21035WDD40<RPB0D0aYe31031V3h40;bE>0@0]Xlb102eSS<40;nG?`@0`Ye51038
XTd40<ZTD@D0a9i;1030VTD40<6KAP@0`ie81032W4L40<BNB@@0`ie81033WDX40<:LB@D0b9m=103:
XDl40<bTC`@0bJ5<1037WdP40<FKA@@0`iY21034V4450<2H@0@0_iLo1030Vd<40;bF@@@0aZ1;103:
Y5<40;^EA0@0^9521035WU450<ZSEP@0dJ]P103D[V<40<NSF@@0aZ9H1033WU080<>MDP@0aZ1G1@38
XU/40<bVG`@0dZaS103>Z5l40<fVF@@0bZ=F1037XE040<BNC@@0`YU91@2nUDD40;nFAP@0`IY;1034
We440<bXG0@0b:=E1034WE040<JPC`D0bJ1>1034VTH40<:H@P@0_i8m1030Td040<NMB@@0`iU71035
W4`40<ZQD@D0aZ1;1035Wd`40<BNB`@0a9i=2036X4d40<NQCP@0aIm<1036WTT50<FMB0@0aim:1035
WDP80<FOC0@0aZ1?1038XU440<:MC@D0aj9B103?ZUT40<VTD`P0bJ=>1037WdP40<NOBP/0oooo000:
0?ooo`@0`ie:1032W4T40<>KA0@0`IU21035WDD40<RPB0D0aYe31031V3h40;bE>0@0]Xlb102eSS<4
0;nG?`@0`Ye51038XTd40<ZTD@D0a9i;1030VTD40<6KAP@0`ie81032W4L40<BNB@@0`ie81033WDX4
0<:LB@D0b9m=103:XDl40<bTC`@0bJ5<1037WdP40<FKA@@0`iY21034V4450<2H@0@0_iLo1030Vd<4
0;bF@@@0aZ1;103:Y5<40;^EA0@0^9521035WU450<ZSEP@0dJ]P103D[V<40<NSF@@0aZ9H1033WU08
0<>MDP@0aZ1G1@38XU/40<bVG`@0dZaS103>Z5l40<fVF@@0bZ=F1037XE040<BNC@@0`YU91@2nUDD4
0;nFAP@0`IY;1034We440<bXG0@0b:=E1034WE040<JPC`D0bJ1>1034VTH40<:H@P@0_i8m1030Td04
0<NMB@@0`iU71035W4`40<ZQD@D0aZ1;1035Wd`40<BNB`@0a9i=2036X4d40<NQCP@0aIm<1036WTT5
0<FMB0@0aim:1035WDP80<FOC0@0aZ1?1038XU440<:MC@D0aj9B103?ZUT40<VTD`P0bJ=>1037WdP4
0<NOBP/0oooo000:0?ooo`@0`ie:1032W4T40<>KA0@0`IU21035WDD40<RPB0D0aYe31031V3h40;bE
>0@0]Xlb102eSS<40;nG?`@0`Ye51038XTd40<ZTD@D0a9i;1030VTD40<6KAP@0`ie81032W4L40<BN
B@@0`ie81033WDX40<:LB@D0b9m=103:XDl40<bTC`@0bJ5<1037WdP40<FKA@@0`iY21034V4450<2H
@0@0_iLo1030Vd<40;bF@@@0aZ1;103:Y5<40;^EA0@0^9521035WU450<ZSEP@0dJ]P103D[V<40<NS
F@@0aZ9H1033WU080<>MDP@0aZ1G1@38XU/40<bVG`@0dZaS103>Z5l40<fVF@@0bZ=F1037XE040<BN
C@@0`YU91@2nUDD40;nFAP@0`IY;1034We440<bXG0@0b:=E1034WE040<JPC`D0bJ1>1034VTH40<:H
@P@0_i8m1030Td040<NMB@@0`iU71035W4`40<ZQD@D0aZ1;1035Wd`40<BNB`@0a9i=2036X4d40<NQ
CP@0aIm<1036WTT50<FMB0@0aim:1035WDP80<FOC0@0aZ1?1038XU440<:MC@D0aj9B103?ZUT40<VT
D`P0bJ=>1037WdP40<NOBP/0oooo000:0?ooo`@0`ie:1032W4T40<>KA0@0`IU21035WDD40<RPB0D0
aYe31031V3h40;bE>0@0]Xlb102eSS<40;nG?`@0`Ye51038XTd40<ZTD@D0a9i;1030VTD40<6KAP@0
`ie81032W4L40<BNB@@0`ie81033WDX40<:LB@D0b9m=103:XDl40<bTC`@0bJ5<1037WdP40<FKA@@0
`iY21034V4450<2H@0@0_iLo1030Vd<40;bF@@@0aZ1;103:Y5<40;^EA0@0^9521035WU450<ZSEP@0
dJ]P103D[V<40<NSF@@0aZ9H1033WU080<>MDP@0aZ1G1@38XU/40<bVG`@0dZaS103>Z5l40<fVF@@0
bZ=F1037XE040<BNC@@0`YU91@2nUDD40;nFAP@0`IY;1034We440<bXG0@0b:=E1034WE040<JPC`D0
bJ1>1034VTH40<:H@P@0_i8m1030Td040<NMB@@0`iU71035W4`40<ZQD@D0aZ1;1035Wd`40<BNB`@0
a9i=2036X4d40<NQCP@0aIm<1036WTT50<FMB0@0aim:1035WDP80<FOC0@0aZ1?1038XU440<:MC@D0
aj9B103?ZUT40<VTD`P0bJ=>1037WdP40<NOBP/0oooo000:0?ooo`P0`ie:1035WDH40<BLA@@0aYi7
1039XDX50<6J?`@0`9Tn102nUcX40;RA=0@0/HX]102kU3T40<>K@`@0bZ9;103>YU450<NOBP@0aYi7
1033Vd@<0<BLA@@0`i]41030V4<40<BLA`D0aYe;1039X4h40<ZQD@@0bj9B103:XE440<ROC`@0aie9
1034VTH50<6IA0@0`YY51031WDD40<:NAP@0aIm:1030VTL40;fGA0@0_II7102hTD850<BMDP@0d:YO
103?ZF040<n]H`@0bZIL1037XeD40<6LCP@0_YQ=102oVDh50<NSF@@0b:AJ103:Y5/40<nYH0@0g;MY
1039Y5H40<BNC@@0aZ1?1032W4T50;nIAP@0`YU71030UdL40<>NC@@0aZ5A1036We040<NNC`@0aYe;
1@34VTP40<:E@0@0`iI1102lSc`40<>FA@@0bj5?1037W4d80<ROC`D0aIm:1033WDX40<2KBP@0`9];
1034Wdh40<^VE@@0f;AP1036XTh40;fG@PD0`ie82034VdT40<6KBP@0`9Y91032WDd40<BOC`@0`Yi@
1@38Y5H40=JcHP@0cJYI1036XTh40<JPC@@0`ii61036WTL;0?ooo`002P3oool80<>MBP@0aIe61034
W4D40<JNA`@0bJ5:1@31VSl40<2I?P@0_YLj102hTC@40;6:;@@0^i@i1033Vd<40<ZRB`@0cZIA1@37
WdX40<JNA`@0`i]43034W4D40<>KA0@0`9Q31034W4L50<JMB`@0bJ1>103:XE440<^RDP@0bZ5A1038
Wdl40<NMB@@0a9Y61@31VD@40<:JA@@0`Ie51032WTH40<FOBP@0`9Y7102mUd@40;fFA`@0^9521@34
WE840=2ZG`@0cjUP103?[F<40<ZVG0@0aj=E1031W4h40;jHC@@0_iU>1@37XeT40<RTFP@0bZAK103?
ZF040=bgJ@@0bJAF1034WTd40<JPC`@0`Ya91@2oVDH40<:IA`@0`9M71033WTd40<JQD@@0aYm@1037
WTl40<JMB`D0a9Y81032UD040<>F@@@0_8ll1033UTD40<^QC`@0aia=2038Wdl50<FOBP@0`ie:1030
VdX40<2KB`@0a9m>103;YUD40=RdH0@0aZ9>102mUd850<>MB0P0a9]91031VdX40<2JB@@0`Ye=1034
Wdl40<:ND0D0b:AF103F/f840<fZF@@0aZ9>1036X4d40<>NAP@0aYi72`3oool000X0oooo2033WDX4
0<FMAP@0a9a51036WTL40<VQBPD0`IXo1030VCh40;jG>P@0^94d102aRRd40;^D>@@0`i]3103:XT/4
0<jVD@D0aim:1036WTL40<>KA0`0a9a51033Vd@40<2H@`@0a9a71@36WD/40<VPCP@0bZ5A103;XU84
0<ZQD@@0b9m?1037WDT40<BJAPD0`IU41032VTD40<6MA@@0`Yi61035WdX40<2JA`@0_IM4102mUTL4
0;RA@PD0a9eB103@ZUl40<nYH0@0cjeS103:YU`40<NSE@@0`Ia>102nV4d40;nICPD0aj=I1038Y5X4
0<ZTF`@0cjUP103L]fT40<VTEP@0a9i=1036X4l40<:LB@D0_iU61032VDL40<2GA`@0`ii=1036XE44
0<JOD0@0aii?1036WD/50<BJB0@0`YE01033UT440;b??0@0`iI5103;XDl40<NLC@P0b9m?1@35WdX4
0<>MBP@0`9]:1030Vd/40<BOCP@0bjIE103H]6040<JRCP@0_IM21@33WDP80<BKB@@0`I]:1030VTT4
0<:MC@@0a9m?1032WU050<RTEP@0e[=R103=ZUT40<JRCP@0aZ1=1033WTH40<JNA`/0oooo000:0?oo
o`P0`ie:1035WDH40<BLA@@0aYi71039XDX50<6J?`@0`9Tn102nUcX40;RA=0@0/HX]102kU3T40<>K
@`@0bZ9;103>YU450<NOBP@0aYi71033Vd@<0<BLA@@0`i]41030V4<40<BLA`D0aYe;1039X4h40<ZQ
D@@0bj9B103:XE440<ROC`@0aie91034VTH50<6IA0@0`YY51031WDD40<:NAP@0aIm:1030VTL40;fG
A0@0_II7102hTD850<BMDP@0d:YO103?ZF040<n]H`@0bZIL1037XeD40<6LCP@0_YQ=102oVDh50<NS
F@@0b:AJ103:Y5/40<nYH0@0g;MY1039Y5H40<BNC@@0aZ1?1032W4T50;nIAP@0`YU71030UdL40<>N
C@@0aZ5A1036We040<NNC`@0aYe;1@34VTP40<:E@0@0`iI1102lSc`40<>FA@@0bj5?1037W4d80<RO
C`D0aIm:1033WDX40<2KBP@0`9];1034Wdh40<^VE@@0f;AP1036XTh40;fG@PD0`ie82034VdT40<6K
BP@0`9Y91032WDd40<BOC`@0`Yi@1@38Y5H40=JcHP@0cJYI1036XTh40<JPC@@0`ii61036WTL;0?oo
o`002P3oool40<BLA`@0aIe81035WDD40<BLA0@0aim7103;Xd/50<NOA`@0`i]3102mUST40;VB=@@0
]hhd102iT3H40;jE?@@0cZA>103=YDh50<JNB@@0aIe51036WTH40<FMA@@0`IU1102oUcl80<:J@`@0
aYe;1@37WT`40<VPD0@0bJ9C1038XE840<VRE@@0bZ1D1039X5440<RMC`D0`ie:1030VTL40<:NAPP0
_i]3202oVD@40;fDA0@0_YE61@2oUD/40<BND`@0bJ=J103;ZF440=>^I`@0bZIL1033WE@40<:LD@@0
`9Y?2@35XEL40<^WG@@0dJeS103>ZUh40<fYG@@0c:MI1038Xe<40<BNC@D0`Ya91032W4L40<6KAP@0
a9i;1035Wd`40<^RDP@0aYe=2@32V4H80<6G@`@0`IM51032UdP40<ROC`@0aIa=1035WTl40<VRD`D0
aJ5=1034Wdh40;jGB0@0_YM:1037XU840<fXF0@0e[5P103;YUD40<JPC@D0`I]81035W4X40<JMB`@0
`iY:1034Vd`40<BMCP@0`9U<1033We<50<JREP@0cjYL103;YUH40<NQD0@0aIm<1032WDD40<2K@`/0
oooo000:0?ooo`@0a9a71035WDP40<FMA@@0a9a41037WdL40<^SB`D0aim71033Vd<40;fF>@@0^I8e
102gSS@40;V@=P@0_YDm103>Y4h40<fUCPD0aYi91035WDD40<JNAP@0aIe51031VD440;nG?`P0`YY3
1036WD/50<NNC0@0bJ1@1039XU<40<RQDP@0bJ9E103:X5@40<VPD@@0b9e?1@33WDX40<2JA`@0`Yi6
202oVd<80;nIA0@0_IA4102nUDH50;nEB`@0a9iC1039XeX40<^YH@@0djiW103:YU`40<>ME0@0`YaA
1030VTl90<FQE`@0bjMM103A[F<40<jZGP@0cJUM103<YeT40<RSD`@0a9i=1@32W4T40<:LA`@0`I]6
1034WT/40<FOC0@0bj9B1036WDd90<:HAPP0`IM31031UdD40<:GB0@0b9m?1035W4d40<FNC`@0bJ9C
1@35XDd40<BOCP@0_YM8102nUdX40<NRDP@0cJQH103F/F040<^VE@@0aZ1=1@31VdP40<FLBP@0aYe;
1033VTX40<BKC0@0a9e>1030VD`40<>OD`D0aZ9F103?ZU`40<^VEP@0aj5@1035Wd`40<:MA@@0`9]3
2`3oool000X0oooo1034W4L40<FMB0@0aIe51034W4@40<NOA`@0bj=;1@37WdL40<>K@`@0_IHi102i
TSD40;N>=0@0^I0f102nUCd40<jTCP@0cJE>1@36WTT40<FMA@@0aYi61035WDD40<6I@@@0_iLo2032
VT<40<JMB`D0aii<1039X5040<VRD`@0b:5B1039XUD40<ZPE0@0bJ1A1038WDl50<>MBP@0`9Y71032
WTH80;nK@`P0_iU4102mU4@40;jEAPD0_iE;1034WU<40<VSFP@0bjUQ103C[VL40<ZVG0@0`ieD1032
W5440<2JC`T0aJ5G103;Yed40=6]H`@0cZYN103=ZEd40<bWF@@0b:=C1034WTd50<:LB@@0`Ya71031
VdH40<BNB`@0aIm<103;XU840<JMC@T0`YQ62031Ud<40<6GA@@0`YM81038Wdl40<FLC@@0aIi?1039
XU<50<FQC@@0a9m>102nUdP40;jGBP@0aj9B103=Z5P40=JaH0@0bjIE1036X4d50<6KB0@0aIa:1036
WD/40<>JBP@0a9]<1034WDh40<2IC0@0`imC1@36XUH40<nZG0@0bjIF1037XE040<FOC0@0`Ye51030
Vd<;0?ooo`002P3oool40<BLA`@0aIe81035WDD40<BLA0@0aim7103;Xd/50<NOA`@0`i]3102mUST4
0;VB=@@0]hhd102iT3H40;jE?@@0cZA>103=YDh50<JNB@@0aIe51036WTH40<FMA@@0`IU1102oUcl8
0<:J@`@0aYe;1@37WT`40<VPD0@0bJ9C1038XE840<VRE@@0bZ1D1039X5440<RMC`D0`ie:1030VTL4
0<:NAPP0_i]3202oVD@40;fDA0@0_YE61@2oUD/40<BND`@0bJ=J103;ZF440=>^I`@0bZIL1033WE@4
0<:LD@@0`9Y?2@35XEL40<^WG@@0dJeS103>ZUh40<fYG@@0c:MI1038Xe<40<BNC@D0`Ya91032W4L4
0<6KAP@0a9i;1035Wd`40<^RDP@0aYe=2@32V4H80<6G@`@0`IM51032UdP40<ROC`@0aIa=1035WTl4
0<VRD`D0aJ5=1034Wdh40;jGB0@0_YM:1037XU840<fXF0@0e[5P103;YUD40<JPC@D0`I]81035W4X4
0<JMB`@0`iY:1034Vd`40<BMCP@0`9U<1033We<50<JREP@0cjYL103;YUH40<NQD0@0aIm<1032WDD4
0<2K@`/0oooo000:0?ooo`@0aI]51033VT840<:K@0@0`ia11038X4P40<jVCPD0c:A<1034W4@40<2I
?P@0^i@i102fSC<40;N>=P@0_Y8k1032V4840<ZRB`D0bJA<1038X4P40<JNAP@0`ia11030VCh40;^C
>`@0_9@m1033Vd@40<>JB0D0`ie<1038XE@40=6ZG@@0bZ=H103:Y5T40<VRE`@0aYmB1037WE450<JP
C`@0aIm<1032WTP40<:NAP@0`9a4102oVD@40;bF@@@0_iI61030UdP50<:HCP@0`ieB1033WE@40<JT
G0@0bjIO103@Zf@40<RRF`@0aImF1033WE@90<:NDP@0dJeS303=ZEl40<nYGP@0cJQJ1038Xe<50<BO
CPP0a9i91033VdH40<FMB0@0cJAB1039X4h40<BKB`D0`iY:1031V4H40<>JBP@0a9];1035Vdl40<FN
D@@0aYmD1035We@40<NQEPD0aZ=B1036XE440;JA@`@0^iA71035WTl40<bUEP@0djeL103?ZEP40<ZQ
C`D0`IQ61037WD/40<FJB`@0aia=1032UdT40<>LC`@0aIiA1036X5D50<NQEP@0b:5D1039XUD40<RR
D@@0aj5@1035WdX40<:LA`/0oooo000:0?ooo`@0aI]51033VT840<:K@0@0`ia11038X4P40<jVCPD0
c:A<1034W4@40<2I?P@0^i@i102fSC<40;N>=P@0_Y8k1032V4840<ZRB`D0bJA<1038X4P40<JNAP@0
`ia11030VCh40;^C>`@0_9@m1033Vd@40<>JB0D0`ie<1038XE@40=6ZG@@0bZ=H103:Y5T40<VRE`@0
aYmB1037WE450<JPC`@0aIm<1032WTP40<:NAP@0`9a4102oVD@40;bF@@@0_iI61030UdP50<:HCP@0
`ieB1033WE@40<JTG0@0bjIO103@Zf@40<RRF`@0aImF1033WE@90<:NDP@0dJeS303=ZEl40<nYGP@0
cJQJ1038Xe<50<BOCPP0a9i91033VdH40<FMB0@0cJAB1039X4h40<BKB`D0`iY:1031V4H40<>JBP@0
a9];1035Vdl40<FND@@0aYmD1035We@40<NQEPD0aZ=B1036XE440;JA@`@0^iA71035WTl40<bUEP@0
djeL103?ZEP40<ZQC`D0`IQ61037WD/40<FJB`@0aia=1032UdT40<>LC`@0aIiA1036X5D50<NQEP@0
b:5D1039XUD40<RRD@@0aj5@1035WdX40<:LA`/0oooo000:0?ooo`@0aI]51033VT840<:K@0@0`ia1
1038X4P40<jVCPD0c:A<1034W4@40<2I?P@0^i@i102fSC<40;N>=P@0_Y8k1032V4840<ZRB`D0bJA<
1038X4P40<JNAP@0`ia11030VCh40;^C>`@0_9@m1033Vd@40<>JB0D0`ie<1038XE@40=6ZG@@0bZ=H
103:Y5T40<VRE`@0aYmB1037WE450<JPC`@0aIm<1032WTP40<:NAP@0`9a4102oVD@40;bF@@@0_iI6
1030UdP50<:HCP@0`ieB1033WE@40<JTG0@0bjIO103@Zf@40<RRF`@0aImF1033WE@90<:NDP@0dJeS
303=ZEl40<nYGP@0cJQJ1038Xe<50<BOCPP0a9i91033VdH40<FMB0@0cJAB1039X4h40<BKB`D0`iY:
1031V4H40<>JBP@0a9];1035Vdl40<FND@@0aYmD1035We@40<NQEPD0aZ=B1036XE440;JA@`@0^iA7
1035WTl40<bUEP@0djeL103?ZEP40<ZQC`D0`IQ61037WD/40<FJB`@0aia=1032UdT40<>LC`@0aIiA
1036X5D50<NQEP@0b:5D1039XUD40<RRD@@0aj5@1035WdX40<:LA`/0oooo000:0?ooo`@0aI]51033
VT840<:K@0@0`ia11038X4P40<jVCPD0c:A<1034W4@40<2I?P@0^i@i102fSC<40;N>=P@0_Y8k1032
V4840<ZRB`D0bJA<1038X4P40<JNAP@0`ia11030VCh40;^C>`@0_9@m1033Vd@40<>JB0D0`ie<1038
XE@40=6ZG@@0bZ=H103:Y5T40<VRE`@0aYmB1037WE450<JPC`@0aIm<1032WTP40<:NAP@0`9a4102o
VD@40;bF@@@0_iI61030UdP50<:HCP@0`ieB1033WE@40<JTG0@0bjIO103@Zf@40<RRF`@0aImF1033
WE@90<:NDP@0dJeS303=ZEl40<nYGP@0cJQJ1038Xe<50<BOCPP0a9i91033VdH40<FMB0@0cJAB1039
X4h40<BKB`D0`iY:1031V4H40<>JBP@0a9];1035Vdl40<FND@@0aYmD1035We@40<NQEPD0aZ=B1036
XE440;JA@`@0^iA71035WTl40<bUEP@0djeL103?ZEP40<ZQC`D0`IQ61037WD/40<FJB`@0aia=1032
UdT40<>LC`@0aIiA1036X5D50<NQEP@0b:5D1039XUD40<RRD@@0aj5@1035WdX40<:LA`/0oooo000:
0?ooo`@0a9e21032Vd040<:K?P@0a9e21034WdH40<bVD@D0aj5<1035Wd`40;nIA0@0^Y@o102kTc/4
0;F==@@0^I0h102nUCd40<NMA`D0dZQB103:XDT40<FL@P@0b9m3103?YdP40;bC=`@0^8lg1031VD@4
0<FLC@D0a9aD1039XE/40<bVG@@0bJ=H103;YeT40<FRD0@0`Yi81038Y4h50<NQC0@0aIm<1036WD/4
0<NNC0@0a9a51032VT<40<2H@`@0^i90102oVDP50<2IC0@0_YQ=1032W5<40<>NE`@0aj9K103:Y5/4
0=2ZH@@0aImD1034WU<50<:LD@@0`I]@1036X5L40<^UG0@0bJEK103;Yed40<fYG@@0cJUK1037Y5<5
0<BQC@@0aZA=1033WdL40;nKA@@0`9Y51037WdX40<^SCP@0b9i:1@34VTP40;nFA0@0`iY;1035WTl4
0<JODP@0aj9D1035X5840<NRE0@0aZ5C1@37XU@40<^VF0@0`Ia;102iU4<40<:OCP@0ajAC103C[f44
0=ZfJ0@0bZEE1@2oVTX40<BNC@@0aj5@1036WDd40<:IBP@0`ia=1035WU<40<RPF0D0aimI1035We@4
0<JPE@@0b:=C1038Xe840<>PC0@0`9i72`3oool000X0oooo1034WD840<:K@0@0`Y/n1034WD840<BO
AP@0c:IA1@37XD`40<FOC0@0_iU4102jU3l40;^C>`@0]Hde102iT3P40;jE?@@0aie71@3BZ5840<ZQ
B@@0aIa21038Wd<40<nWB0@0_9<g102hScL40<6IA0@0aIa=1@34W5@40<VQF`@0c:IM1039XeP40<^W
F@@0aJ9@1032WTP40<RTCPD0aj5<1035Wd`40<JMB`@0aii<1034W4D40<:J@`@0`9Q3102kTT040;nI
B0D0`9U<102nV4d40<:LD`@0`iiG1037XU/40<ZTF`@0d:YQ1035We@40<BND`D0`YaA1031Ve040<JP
E`@0bjEL1039YE/40<^WG@@0cJUM103=ZE/40<NTD`D0a:5=1036Y4d40<>OA`@0_i]51030VTD40<NO
BP@0bj=>1038WTX50<BJB0@0_iI41033VT/40<FNC`@0aYmB1037XU@40<FPDP@0aj9D1036XE<50<NR
E0@0bjIH1031W4/40;VD@`@0`Ym>1037Y5<40=>_H@@0f[IX103:YED50;nJBP@0a9i=1037XE040<JM
C@@0`YU:1033W4d40<FND`@0b:1H1@37WeT40<FOE0@0aZ1E1038Xe<40<RSDP@0`j1<1030WTL;0?oo
o`002P3oool40<BM@P@0`Y]01032Vch40<BM@P@0a9m6103<YU450<NQC0@0aIm<102oVD@40;ZD?`@0
^i<k102eSCD40;V@>0@0_YDm1037WDL50=:XDP@0bZ591035W4840<RO@`@0cjM8102lTcL40;R?=`@0
`IU41035W4d50<BLE0@0bJ5K103<YUd40<VSF0@0bjMI1035XU040<:NB0@0b:A>1@37XD`40<FOC0@0
aYe;1037WT`40<BLA@@0`YY31030V4<40;^B@0@0_iU81@30VD`40;jHC@@0`YaC1033WUL40<NRF`@0
bZAK103@ZV440<FOE0@0a9iC1@32W5440<6KD0@0aZ1G103;YE`40<VUF`@0bjMM103=ZEd40<fYF`@0
ajAC1@34XDd40<JTC@@0`im7102oVdD40<2JA@@0aim:103;Xdh40<RNBPD0a9Y8102oUT@40<>JB`@0
aIi?1036We840<NRE0@0aJ1B1037XU@40<JQD`D0aj9D103;YUP40<6LB`@0^IA31032Wdh40<NTD`@0
djmQ103J]VP40<ZUE@D0_iY:1034WTd40<NQD0@0aYe=1032VDX40<>LC@@0aIiC1038X5P50<NOF@@0
aImD1036X5D40<RSD`@0b:=B1033X4`40<2NA`/0oooo000:0?ooo`@0a9e21032Vd040<:K?P@0a9e2
1034WdH40<bVD@D0aj5<1035Wd`40;nIA0@0^Y@o102kTc/40;F==@@0^I0h102nUCd40<NMA`D0dZQB
103:XDT40<FL@P@0b9m3103?YdP40;bC=`@0^8lg1031VD@40<FLC@D0a9aD1039XE/40<bVG@@0bJ=H
103;YeT40<FRD0@0`Yi81038Y4h50<NQC0@0aIm<1036WD/40<NNC0@0a9a51032VT<40<2H@`@0^i90
102oVDP50<2IC0@0_YQ=1032W5<40<>NE`@0aj9K103:Y5/40=2ZH@@0aImD1034WU<50<:LD@@0`I]@
1036X5L40<^UG0@0bJEK103;Yed40<fYG@@0cJUK1037Y5<50<BQC@@0aZA=1033WdL40;nKA@@0`9Y5
1037WdX40<^SCP@0b9i:1@34VTP40;nFA0@0`iY;1035WTl40<JODP@0aj9D1035X5840<NRE0@0aZ5C
1@37XU@40<^VF0@0`Ia;102iU4<40<:OCP@0ajAC103C[f440=ZfJ0@0bZEE1@2oVTX40<BNC@@0aj5@
1036WDd40<:IBP@0`ia=1035WU<40<RPF0D0aimI1035We@40<JPE@@0b:=C1038Xe840<>PC0@0`9i7
2`3oool000X0oooo1031V3h40;fD>0@0^Y<f1030VCh40<NPA@@0c:A=1@38Xd/40<FOBP@0aJ181033
WTH80;nG?`@0^Y4g102mU3`40<:I@@D0cJ==1038WdL40<FLA0@0a9/o1035W4040<:I?`@0^i8j1030
UdD40<BKC0D0aImF1039Xe`40<VUF`@0bZIJ103;ZU/40<>PCP@0]iDn1035XD/50<^UD0@0bJ=@1036
X4d40<>MBP@0a9a51032VT<40;nG@0@0^i<n102jU3l50;^EA0@0`9U:1034WE040<BOD@@0aZ1E1039
XeP40<fWGP@0dZaQ1036X5D50;fHBP@0_iY<1031WE440<FQE@@0bJEI1038Y5P80<ZVF0@0aJ9@1@3:
YeD40<n[E@@0aJ5;102oVdL40<6MB@@0aIm<1037XDh40<ROC@D0aYe;1030VTT40<BMCP@0bZEE1037
XU@40<RRE`@0aZ1E1037XEH40<FOE0D0aZ5C103;YUP40<FOCP@0_iU8102oVTX40<FPD0@0cZYL103@
[5h40<bYF0D0b:=C1037XU440<RRD@@0aIm>1032Vd`40;fFA`@0`iaA103:XeP50<VQF@@0aImF1038
XUT40<jXG@@0bJ=H2033WTh;0?ooo`002P3oool40<6H?P@0_I@h102jTcH40<2I?P@0aj15103<Y4d5
0<RSB`@0aIm:1035X4P40<>NAPP0_iLo102jTCL40;fD?0@0`YU11@3=Xdd40<ROA`@0aIa41034Vcl4
0<FL@0@0`YTo102kTSX40<2GA@@0a9]<1@35WeH40<VSG0@0bJEK103:YUX40<^ZF`@0`j1>102gUCh4
0<FQB`D0bjE@1039Xe040<JPC@@0`ie:1034W4D40<:J@`@0_iM0102kTch40;ZD?`D0^iE41030VDX4
0<BMD0@0a9mA1036X5D40<VSF0@0cJMN103B[6440<JPE@D0_IQ:102oVT`40<6MD@@0aJ5E1039YET4
0<RTF0P0bZIH1035XU050<ZWE@@0cj]E1035XD/40;nKA`@0`Ie91035Wd`40<NQCP@0b9m=1@36WD/4
0<2JB@@0a9e>103:YED40<NRE0@0b:9G1036X5D40<NQEP@0aImD1@36XE<40<^VF0@0aIm>102oVDP4
0;nJBP@0aJ1@103>ZU`40=2/GP@0c:UH1@38Xe<40<NRD@@0b:9A1035Wdh40<:KC0@0_II71033W544
0<ZSF0D0bJ5I1035WeH40<RRF@@0cZQM1039XeP80<>NCP/0oooo000:0?ooo`@0`IPn102mU3P40;ZC
=P@0`9Tn1037X4D40<bTC@D0b:=;1035WdX40<FPB0@0`ii6202oUcl40;ZA=`@0_I@l1032VD450<fS
C@@0b9m71035W4@40<BK?`@0aIa01032VCl40;^B>P@0`9M51034Vd`50<FOEP@0bJ=L1039YE/40<ZV
FP@0bjYK1033X4h40;NE?P@0aJ5;1@3;YE040<VSD0@0aZ1=1033WDX40<BLA@@0`YY3102oUd040;^C
?P@0^Y@o1@2kUD@40<2IBP@0a9e@1034We440<JPE@@0bJ=H103=Yeh40=:/H@@0aZ1E1@2mV4X40;nJ
C0@0`IeA1035XED40<VUF@@0b:AH203:YUP40<FRD0D0bZME103?ZeD40<FQB`@0_i]71031WDT40<FO
C0@0aj5>1038Wdd50<JMB`@0`9Y91034WDh40<ZUE@@0aj9D1038XUL40<JPE@@0aj5F1035We@50<JQ
D`@0bjIH1035Wdh40;nIB0@0_iY:1035X5040<jZG0@0d:aN103<ZEP50<RSD`@0aj9A1038XU440<FO
CP@0`Y]<102mUTL40<>LD@@0bZ=H1@39XET40<FOEP@0b:9I103>Z5d40<VSF0P0`ii>2`3oool000X0
oooo1031V3h40;fD>0@0^Y<f1030VCh40<NPA@@0c:A=1@38Xd/40<FOBP@0aJ181033WTH80;nG?`@0
^Y4g102mU3`40<:I@@D0cJ==1038WdL40<FLA0@0a9/o1035W4040<:I?`@0^i8j1030UdD40<BKC0D0
aImF1039Xe`40<VUF`@0bZIJ103;ZU/40<>PCP@0]iDn1035XD/50<^UD0@0bJ=@1036X4d40<>MBP@0
a9a51032VT<40;nG@0@0^i<n102jU3l50;^EA0@0`9U:1034WE040<BOD@@0aZ1E1039XeP40<fWGP@0
dZaQ1036X5D50;fHBP@0_iY<1031WE440<FQE@@0bJEI1038Y5P80<ZVF0@0aJ9@1@3:YeD40<n[E@@0
aJ5;102oVdL40<6MB@@0aIm<1037XDh40<ROC@D0aYe;1030VTT40<BMCP@0bZEE1037XU@40<RRE`@0
aZ1E1037XEH40<FOE0D0aZ5C103;YUP40<FOCP@0_iU8102oVTX40<FPD0@0cZYL103@[5h40<bYF0D0
b:=C1037XU440<RRD@@0aIm>1032Vd`40;fFA`@0`iaA103:XeP50<VQF@@0aImF1038XUT40<jXG@@0
bJ=H2033WTh;0?ooo`002P3oool40;bC>@@0_9<g102hSc<40;fD>P@0aIi3103;Xd`50<bWC`@0cZQC
1037XTX40<BOA`@0_iXo102mV3d40;^D>@@0_YHn1032VT850<^SC0@0aIa4102oUSh40<JM@@@0b9m3
1032VCl40;jE?@@0_YI1102iT4050<:LD@@0aJ5G1038YU`40=2`H`@0b:]K102mWT`40;RE@@@0a:1<
1@3:YE@40<NRD@@0aj5>1034WTT40<FMAP@0`IU1102oV3d40;^C>`@0^I4i1@2lU3l40<:JA@@0aYe;
1034WT/40<FOCP@0bImC103CZEl40=J_HP@0bZ=F1@32WDd40<2KB`@0`Ii=2035XU440<JSDPP0ajAC
1039Y5<50<jYF0@0cZYF1035XDd40<:MC0@0`Ia;1032W4T40<FOC0@0aZ1=1@34WT/40<>MC0@0cjQI
103?ZUX40<VTEP`0aj5F1034WU<50<JPE@@0bjAG1036We040<>JBP@0^YE51033WTh40<^WF@@0aj=E
2@39YUD40<VTD`@0b:=B1035Wdh40<>LC@@0^Y=4102nUd`40<JOE0D0bj=M1039Y5d40<NRG0@0bZAM
1039Xe`40<BNE@@0aZ1G2`3oool000X0oooo102lTcT40;bC=`@0^8lc102mU3X40<FN@`@0bj=<1@3<
Ydl40<jXD`@0aj9:1034WdL40;nJ?`@0_IPm102kU3T40;jF?P@0`YY21@3;Xd`40<FLA0@0_iHn1036
WD440<RO@`@0`YTo102nUCd40;jF@@@0^I101@32W5440<FQE`@0b:IL103@/6<40<R[F`@0_Ii<102h
UD440<BPC0D0bZED1037XU440<NQCP@0a9i91035WDH40<6I@@@0_iPm102kTc/40;VA>@D0_9@o1032
VTD40<JMB`@0a9i;1035Wdh40<VOD`@0djUO103F[f840<ZSEPD0`Ye=1030Vd/40<6NC@P0aJ9A1036
Xe880<NTD`@0bJAC1@3>ZEP40<jZEP@0aJ5=1032WD`40<6LB`@0`Ya91035Wd`40<JPC@D0a9i;1033
WD`40<nXF@@0cjYJ1039Y5H<0<NQEP@0a9iC1@36X5D40<^TE`@0aYm@1033VTX40;ZEA@@0`ii>103;
YeT40<NSE@T0bJIE1039Y5<40<RSDP@0aIm>1033W4d40;ZCA0@0_YM<1036We@50<^SG@@0bJAM1037
XU`40<ZTG@@0bJ=L1034WUD40<JPE`/0oooo000:0?ooo`@0_9<i102lTcL40;R?<`@0_I@j1035WT<4
0<^SC0D0c:M?103>Z5<40<NRBP@0a9m7102oVSl40;fH?@@0^i@i102nUSh40<:J@PD0bj=<1035W4@4
0;nF?P@0aYe11038Wd<40<:I?`@0_YDm102nUT440;V@@0D0`YaA1035XEL40<RVG0@0d;1S1038Ze/4
0;fNC0@0^9E11034X4`50<ZUE0@0aj9A1037XDh40<BNB@@0aIe61031VD440;nH?@@0^i<k102iTCT5
0;bD?`@0`YY51036WD/40<BNB`@0aIm>1039We<40=>YG`@0eZmR103:XeH50<:MC@@0`9];1031WTd8
0<FRD@@0aZ=B2037Y5<40<VTD`D0cZUH103>ZUH40<FQC@@0`Ye<1031W4/40<:LB@@0aIm<1036X4d5
0<BNB`@0`ie<103?Z5T40<nZFP@0bJAF3037XEH40<BND`D0aZ1E103;Y5L40<JOD0@0`iY:102jUDD4
0<>NCP@0bjMI1037XeD90<VVE@@0bJAC1038Xe840<FOCP@0`ia=102jTd@40;jGC0@0aYmD1@3;Xed4
0<VTG@@0aj9L103:Y5d40<VSG0@0a9iE1036X5L;0?ooo`002P3oool40;bC>@@0_9<g102hSc<40;fD
>P@0aIi3103;Xd`50<bWC`@0cZQC1037XTX40<BOA`@0_iXo102mV3d40;^D>@@0_YHn1032VT850<^S
C0@0aIa4102oUSh40<JM@@@0b9m31032VCl40;jE?@@0_YI1102iT4050<:LD@@0aJ5G1038YU`40=2`
H`@0b:]K102mWT`40;RE@@@0a:1<1@3:YE@40<NRD@@0aj5>1034WTT40<FMAP@0`IU1102oV3d40;^C
>`@0^I4i1@2lU3l40<:JA@@0aYe;1034WT/40<FOCP@0bImC103CZEl40=J_HP@0bZ=F1@32WDd40<2K
B`@0`Ii=2035XU440<JSDPP0ajAC1039Y5<50<jYF0@0cZYF1035XDd40<:MC0@0`Ia;1032W4T40<FO
C0@0aZ1=1@34WT/40<>MC0@0cjQI103?ZUX40<VTEP`0aj5F1034WU<50<JPE@@0bjAG1036We040<>J
BP@0^YE51033WTh40<^WF@@0aj=E2@39YUD40<VTD`@0b:=B1035Wdh40<>LC@@0^Y=4102nUd`40<JO
E0D0bj=M1039Y5d40<NRG0@0bZAM1039Xe`40<BNE@@0aZ1G2`3oool000X0oooo102nUC/40;F<<P@0
[hH/102dRc<40<>K@`@0cjMB1@3?ZE@40<ZTD@P0`9Y51033WTD40;nJ@@@0_IHk102jTcP40;jF?PD0
`i]32035WDD40<BK@@@0`iY01030Ucd40<2G?`@0]Y0k102iTd850<:ND0@0bJEI1036YU/40<NWFP@0
aZ]J102oXe040;RGB0@0a:1B1@3<YU/40<^UFP@0bjAE1037XE040<NOBP@0`YY31030VCh40;jG?0@0
_9<k1@30Ucl80<:J@P@0a9a41036WTL40<FJB`@0cJ9D103R^f`40<jWF0D0aZ5A1030Vd/40<>PC`@0
`Ym>102nVdX40<BQD0@0b:=C1037XU890<NRD@@0aZ1=1033WDX40<:LB@@0`ie:1034WT/40<>MBP@0
aim:1@38X4/40<JMB`@0bj9@103>Z5L40<RQDP@0aZ5A1035X5840<JODP@0aIiA1@37X5<40<VRE@@0
d:MG1032VDT40;F>?`@0`IY;103<YeT40<FPDP@0aJ5C1@38Y5H40<NTD`@0bZMF1036XE440<6LC0@0
^iA7102mUTT40<>IC`D0bJ5I103;YE`40<JQFP@0`Y]F103:Xeh40<RQG0@0aYmJ2`3oool000X0oooo
102nUC/40;F<<P@0[hH/102dRc<40<>K@`@0cjMB1@3?ZE@40<ZTD@P0`9Y51033WTD40;nJ@@@0_IHk
102jTcP40;jF?PD0`i]32035WDD40<BK@@@0`iY01030Ucd40<2G?`@0]Y0k102iTd850<:ND0@0bJEI
1036YU/40<NWFP@0aZ]J102oXe040;RGB0@0a:1B1@3<YU/40<^UFP@0bjAE1037XE040<NOBP@0`YY3
1030VCh40;jG?0@0_9<k1@30Ucl80<:J@P@0a9a41036WTL40<FJB`@0cJ9D103R^f`40<jWF0D0aZ5A
1030Vd/40<>PC`@0`Ym>102nVdX40<BQD0@0b:=C1037XU890<NRD@@0aZ1=1033WDX40<:LB@@0`ie:
1034WT/40<>MBP@0aim:1@38X4/40<JMB`@0bj9@103>Z5L40<RQDP@0aZ5A1035X5840<JODP@0aIiA
1@37X5<40<VRE@@0d:MG1032VDT40;F>?`@0`IY;103<YeT40<FPDP@0aJ5C1@38Y5H40<NTD`@0bZMF
1036XE440<6LC0@0^iA7102mUTT40<>IC`D0bJ5I103;YE`40<JQFP@0`Y]F103:Xeh40<RQG0@0aYmJ
2`3oool000X0oooo102nUC/40;F<<P@0[hH/102dRc<40<>K@`@0cjMB1@3?ZE@40<ZTD@P0`9Y51033
WTD40;nJ@@@0_IHk102jTcP40;jF?PD0`i]32035WDD40<BK@@@0`iY01030Ucd40<2G?`@0]Y0k102i
Td850<:ND0@0bJEI1036YU/40<NWFP@0aZ]J102oXe040;RGB0@0a:1B1@3<YU/40<^UFP@0bjAE1037
XE040<NOBP@0`YY31030VCh40;jG?0@0_9<k1@30Ucl80<:J@P@0a9a41036WTL40<FJB`@0cJ9D103R
^f`40<jWF0D0aZ5A1030Vd/40<>PC`@0`Ym>102nVdX40<BQD0@0b:=C1037XU890<NRD@@0aZ1=1033
WDX40<:LB@@0`ie:1034WT/40<>MBP@0aim:1@38X4/40<JMB`@0bj9@103>Z5L40<RQDP@0aZ5A1035
X5840<JODP@0aIiA1@37X5<40<VRE@@0d:MG1032VDT40;F>?`@0`IY;103<YeT40<FPDP@0aJ5C1@38
Y5H40<NTD`@0bZMF1036XE440<6LC0@0^iA7102mUTT40<>IC`D0bJ5I103;YE`40<JQFP@0`Y]F103:
Xeh40<RQG0@0aYmJ2`3oool000X0oooo102nUC/40;F<<P@0[hH/102dRc<40<>K@`@0cjMB1@3?ZE@4
0<ZTD@P0`9Y51033WTD40;nJ@@@0_IHk102jTcP40;jF?PD0`i]32035WDD40<BK@@@0`iY01030Ucd4
0<2G?`@0]Y0k102iTd850<:ND0@0bJEI1036YU/40<NWFP@0aZ]J102oXe040;RGB0@0a:1B1@3<YU/4
0<^UFP@0bjAE1037XE040<NOBP@0`YY31030VCh40;jG?0@0_9<k1@30Ucl80<:J@P@0a9a41036WTL4
0<FJB`@0cJ9D103R^f`40<jWF0D0aZ5A1030Vd/40<>PC`@0`Ym>102nVdX40<BQD0@0b:=C1037XU89
0<NRD@@0aZ1=1033WDX40<:LB@@0`ie:1034WT/40<>MBP@0aim:1@38X4/40<JMB`@0bj9@103>Z5L4
0<RQDP@0aZ5A1035X5840<JODP@0aIiA1@37X5<40<VRE@@0d:MG1032VDT40;F>?`@0`IY;103<YeT4
0<FPDP@0aJ5C1@38Y5H40<NTD`@0bZMF1036XE440<6LC0@0^iA7102mUTT40<>IC`D0bJ5I103;YE`4
0<JQFP@0`Y]F103:Xeh40<RQG0@0aYmJ2`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.47552, -1.47552, 0.361779, \
0.361779}}]
}, Open  ]],

Cell[TextData[{
  "What I would like to do is get the size and location of the limestone \
accretion.  There are many ways to approach this.  The idea I show below is \
certainly not the best, but it demonstrates well the ability to explore using \
the mathematics and interactivity of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["Compute the mean color of all the pixels shown in the image.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(meancolor\  = \ Mean[Mean[N[imagedata]]]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({193.49`, 155.7998`, 78.1182`}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
I am interested in highlighting those points with color different \
than the most prevalent dull yellow.  Thinking of the color as a vector in \
3-space, I want to highlight the points with different color directions.  \
This can be done by taking the norm of the cross product with the mean color.\
\
\>", "Text"],

Cell["\<\
Compute the norm of the cross product of the color vector at each \
point with the mean color and normalize it so that the maximum value is \
1.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(orthogonal\  = \ 
        Map[Norm[Cross[meancolor, \ #]] &, \ 
          imagedata, {2}];\)\), "\[IndentingNewLine]", 
    \(\(orthogonal\  /= \ Max[orthogonal];\)\)}], "Input",
  CellLabel->"In[19]:="],

Cell["Show a surface plot of the resulting data.", "MathCaption"],

Cell[BoxData[
    \(<< RealTime3D`\)], "Input",
  CellLabel->"In[40]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[orthogonal, \ PlotRange \[Rule] All, \ 
        Mesh \[Rule] False];\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.14109 .2015 -11.9442 -9 ]
[.14109 .2015 .05581 0 ]
[.26628 .15225 -11.4388 -9 ]
[.26628 .15225 .56124 0 ]
[.39776 .10054 -10.9333 -9 ]
[.39776 .10054 1.06668 0 ]
[.53601 .04619 -10.4279 -9 ]
[.53601 .04619 1.57211 0 ]
[.68156 -0.01098 -14.8837 -9 ]
[.68156 -0.01098 3.11632 0 ]
[.76488 .0931 0 -6.1657 ]
[.76488 .0931 12 2.8343 ]
[.82636 .18723 0 -6.07503 ]
[.82636 .18723 12 2.92497 ]
[.88261 .27338 0 -5.99372 ]
[.88261 .27338 12 3.00628 ]
[.93428 .35251 0 -5.9204 ]
[.93428 .35251 12 3.0796 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.02431 .26385 -6 -2.74126 ]
[.02431 .26385 0 6.25874 ]
[.01584 .31697 -24 -2.78617 ]
[.01584 .31697 0 6.21383 ]
[.00706 .37196 -18 -2.83282 ]
[.00706 .37196 0 6.16718 ]
[-0.00202 .42892 -24 -2.88131 ]
[-0.00202 .42892 0 6.11869 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15032 .21083 m
.15494 .21549 L
s
[(20)] .14109 .2015 .9907 1 Mshowa
.2751 .16197 m
.2795 .16683 L
s
[(40)] .26628 .15225 .90646 1 Mshowa
.4061 .11067 m
.41026 .11574 L
s
[(60)] .39776 .10054 .82222 1 Mshowa
.5438 .05675 m
.5477 .06203 L
s
[(80)] .53601 .04619 .73798 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(100)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06057 .24597 m
.06342 .24868 L
s
.09013 .23439 m
.09296 .23713 L
s
.12005 .22268 m
.12285 .22545 L
s
.18096 .19883 m
.1837 .20166 L
s
.21196 .18669 m
.21467 .18955 L
s
.24334 .17441 m
.24601 .17729 L
s
.30724 .14938 m
.30985 .15233 L
s
.33979 .13664 m
.34236 .13962 L
s
.37274 .12374 m
.37527 .12675 L
s
.43987 .09745 m
.44233 .10052 L
s
.47408 .08405 m
.4765 .08716 L
s
.50872 .07049 m
.5111 .07363 L
s
.57933 .04284 m
.58163 .04604 L
s
.61533 .02874 m
.61758 .03198 L
s
.65179 .01447 m
.654 .01773 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75258 .09765 m
.74642 .09993 L
s
[(20)] .76488 .0931 -1 .37015 Mshowa
.81397 .19156 m
.80778 .19373 L
s
[(40)] .82636 .18723 -1 .35001 Mshowa
.87016 .27751 m
.86393 .27958 L
s
[(60)] .88261 .27338 -1 .33194 Mshowa
.92177 .35646 m
.91551 .35844 L
s
[(80)] .93428 .35251 -1 .31564 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(100)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70266 .0213 m
.69899 .02272 L
s
.71969 .04735 m
.71602 .04876 L
s
.73633 .0728 m
.73264 .07418 L
s
.76845 .12194 m
.76475 .12329 L
s
.78397 .14567 m
.78026 .147 L
s
.79914 .16888 m
.79543 .17019 L
s
.82848 .21376 m
.82476 .21504 L
s
.84267 .23547 m
.83895 .23674 L
s
.85656 .25671 m
.85283 .25797 L
s
.88347 .29787 m
.87973 .2991 L
s
.8965 .31781 m
.89275 .31902 L
s
.90926 .33733 m
.90551 .33853 L
s
.93402 .37521 m
.93027 .37638 L
s
.94603 .39358 m
.94227 .39473 L
s
.95781 .41158 m
.95404 .41273 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03654 .25907 m
.04265 .25669 L
s
[(0)] .02431 .26385 1 -0.39083 Mshowa
.0281 .3123 m
.03423 .30997 L
s
[(0.25)] .01584 .31697 1 -0.38085 Mshowa
.01937 .36741 m
.02552 .36513 L
s
[(0.5)] .00706 .37196 1 -0.37048 Mshowa
.01032 .42448 m
.0165 .42226 L
s
[(0.75)] -0.00202 .42892 1 -0.35971 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03487 .26957 m
.03854 .26815 L
s
.0332 .28015 m
.03687 .27873 L
s
.03151 .29079 m
.03518 .28938 L
s
.02981 .30151 m
.03349 .3001 L
s
.02638 .32317 m
.03006 .32178 L
s
.02464 .33411 m
.02833 .33273 L
s
.0229 .34513 m
.02658 .34375 L
s
.02114 .35623 m
.02483 .35486 L
s
.01759 .37866 m
.02128 .3773 L
s
.01579 .38999 m
.01949 .38864 L
s
.01398 .40141 m
.01768 .40006 L
s
.01216 .4129 m
.01586 .41156 L
s
.00848 .43614 m
.01218 .43481 L
s
.00662 .44788 m
.01032 .44657 L
s
.00474 .45971 m
.00845 .4584 L
s
.00285 .47163 m
.00657 .47033 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.739 .274 .146 r
.40005 .65636 .40331 .65556 .40801 .67038 .4051 .66101 Mtetra
.264 .301 .713 r
.4051 .66101 .40801 .67038 .41294 .67986 .41013 .66676 Mtetra
.788 .598 .644 r
.41013 .66676 .41294 .67986 .41871 .66301 .41591 .64996 Mtetra
.797 .603 .64 r
.41591 .64996 .41871 .66301 .42487 .63144 .4217 .6316 Mtetra
.951 .777 .631 r
.4217 .6316 .42487 .63144 .43096 .59981 .42754 .60984 Mtetra
.273 0 .28 r
.42754 .60984 .43096 .59981 .43617 .59897 .43291 .60403 Mtetra
.736 .873 .458 r
.43291 .60403 .43617 .59897 .44144 .59581 .43837 .59432 Mtetra
.911 .533 .29 r
.43837 .59432 .44144 .59581 .44619 .61584 .44326 .60811 Mtetra
.393 .417 .766 r
.44326 .60811 .44619 .61584 .45148 .61428 .44843 .61141 Mtetra
.933 .562 .271 r
.44843 .61141 .45148 .61428 .45668 .61748 .45337 .62767 Mtetra
.597 .29 .42 r
.45337 .62767 .45668 .61748 .46187 .62275 .45864 .62959 Mtetra
.726 .396 .419 r
.45864 .62959 .46187 .62275 .46695 .63625 .46384 .63696 Mtetra
.963 .852 .685 r
.46384 .63696 .46695 .63625 .47224 .64009 .46941 .62351 Mtetra
.703 .529 .65 r
.46941 .62351 .47224 .64009 .47781 .62484 .47489 .61473 Mtetra
.836 .639 .636 r
.47489 .61473 .47781 .62484 .4833 .61427 .48051 .59408 Mtetra
.19 .153 .584 r
.48051 .59408 .4833 .61427 .48871 .60912 .48568 .60907 Mtetra
.853 .434 .231 r
.48568 .60907 .48871 .60912 .49409 .60753 .49096 .61835 Mtetra
.486 .188 .385 r
.49096 .61835 .49409 .60753 .4994 .61678 .49638 .61645 Mtetra
.861 .936 .871 r
.49638 .61645 .4994 .61678 .50481 .61701 .50183 .61126 Mtetra
.331 .443 .825 r
.50183 .61126 .50481 .61701 .51021 .62087 .50724 .6143 Mtetra
.6 .566 .788 r
.50724 .6143 .51021 .62087 .51568 .61311 .51269 .61381 Mtetra
.968 .856 .675 r
.51269 .61381 .51568 .61311 .52113 .61156 .51818 .6 Mtetra
.676 .537 .688 r
.51818 .6 .52113 .61156 .52659 .59222 .52364 .5957 Mtetra
.994 .822 .565 r
.52364 .5957 .52659 .59222 .53199 .57054 .52907 .56986 Mtetra
.891 .49 .25 r
.52907 .56986 .53199 .57054 .53748 .58656 .53454 .58229 Mtetra
.758 .323 0 r
.53454 .58229 .53748 .58656 .543 .59577 .54006 .59248 Mtetra
.85 .409 0 r
.54006 .59248 .543 .59577 .54846 .59055 .54564 .60346 Mtetra
.036 0 .236 r
.54564 .60346 .54846 .59055 .55402 .59598 .55108 .59102 Mtetra
.903 .708 .628 r
.55108 .59102 .55402 .59598 .55939 .57982 .55641 .56864 Mtetra
0 .036 .576 r
.55641 .56864 .55939 .57982 .56475 .56602 .56206 .58107 Mtetra
0 0 .161 r
.56206 .58107 .56475 .56602 .57022 .56235 .56738 .5623 Mtetra
.867 .962 .861 r
.56738 .5623 .57022 .56235 .57598 .5775 .57285 .55686 Mtetra
.652 .481 .64 r
.57285 .55686 .57598 .5775 .58149 .57406 .5783 .55123 Mtetra
.556 .409 .636 r
.5783 .55123 .58149 .57406 .58677 .55726 .58389 .55297 Mtetra
.672 .238 0 r
.58389 .55297 .58677 .55726 .59217 .54888 .58965 .5625 Mtetra
.685 .391 .47 r
.58965 .5625 .59217 .54888 .59807 .56394 .59542 .57068 Mtetra
.745 .404 .405 r
.59542 .57068 .59807 .56394 .604 .57751 .60125 .5794 Mtetra
.809 .397 .266 r
.60125 .5794 .604 .57751 .60994 .58921 .60713 .58798 Mtetra
.491 .831 .998 r
.60713 .58798 .60994 .58921 .61568 .59119 .61281 .58707 Mtetra
.345 .534 .897 r
.61281 .58707 .61568 .59119 .62135 .58965 .61858 .5891 Mtetra
.965 .816 .646 r
.61858 .5891 .62135 .58965 .62681 .58063 .62383 .57258 Mtetra
.82 .65 .671 r
.62383 .57258 .62681 .58063 .63227 .57235 .62917 .55994 Mtetra
.788 .6 .646 r
.62917 .55994 .63227 .57235 .63794 .57068 .63441 .54512 Mtetra
.622 .45 .628 r
.63441 .54512 .63794 .57068 .6435 .56538 .63998 .54121 Mtetra
.677 .491 .627 r
.63998 .54121 .6435 .56538 .64895 .55695 .64536 .53163 Mtetra
.534 .388 .629 r
.64536 .53163 .64895 .55695 .65422 .54428 .65123 .53526 Mtetra
0 0 .24 r
.65123 .53526 .65422 .54428 .65963 .53594 .65773 .55452 Mtetra
.593 .323 .477 r
.65773 .55452 .65963 .53594 .66706 .5759 .66363 .55685 Mtetra
.791 .578 .614 r
.66363 .55685 .66706 .5759 .67123 .53753 .66844 .5334 Mtetra
.871 .739 .714 r
.66844 .5334 .67123 .53753 .67649 .52578 .67378 .52303 Mtetra
.299 .603 .951 r
.67378 .52303 .67649 .52578 .68237 .5276 .67964 .52444 Mtetra
.675 .746 .904 r
.67964 .52444 .68237 .5276 .68807 .52539 .68537 .52254 Mtetra
.582 .734 .947 r
.68537 .52254 .68807 .52539 .6938 .52363 .69116 .52179 Mtetra
.64 .838 .977 r
.69116 .52179 .6938 .52363 .69973 .52526 .69692 .52007 Mtetra
.603 .615 .836 r
.69692 .52007 .69973 .52526 .70534 .52071 .70275 .51942 Mtetra
.41 .792 .991 r
.70275 .51942 .70534 .52071 .71109 .51852 .70861 .51897 Mtetra
.283 .782 .766 r
.70861 .51897 .71109 .51852 .71678 .51519 .71441 .51724 Mtetra
.628 .899 .588 r
.71441 .51724 .71678 .51519 .72249 .51197 .71997 .51124 Mtetra
.735 .209 0 r
.71997 .51124 .72249 .51197 .72829 .51024 .72629 .51787 Mtetra
.291 0 .254 r
.72629 .51787 .72829 .51024 .73442 .51355 .73194 .51298 Mtetra
.674 .949 .956 r
.73194 .51298 .73442 .51355 .74059 .51696 .73771 .51012 Mtetra
.735 .633 .746 r
.73771 .51012 .74059 .51696 .74657 .51699 .74336 .50519 Mtetra
.586 .483 .703 r
.74336 .50519 .74657 .51699 .75232 .51348 .74934 .50505 Mtetra
.335 .372 .751 r
.74934 .50505 .75232 .51348 .75808 .50997 .7557 .51026 Mtetra
.9 .984 .787 r
.7557 .51026 .75808 .50997 .76409 .50997 .76123 .50324 Mtetra
.699 .619 .764 r
.76123 .50324 .76409 .50997 .77034 .51282 .76702 .49979 Mtetra
.544 .446 .694 r
.76702 .49979 .77034 .51282 .77613 .50924 .77319 .50144 Mtetra
.75 .624 .72 r
.77319 .50144 .77613 .50924 .78188 .50518 .77877 .49511 Mtetra
.34 .347 .722 r
.77877 .49511 .78188 .50518 .78712 .49448 .78535 .5014 Mtetra
.583 .227 .33 r
.78535 .5014 .78712 .49448 .79351 .49831 .79159 .50311 Mtetra
0 0 0 r
.79159 .50311 .79351 .49831 .7988 .48845 .79716 .4962 Mtetra
.552 .211 .344 r
.79716 .4962 .7988 .48845 .80482 .48736 .80335 .49689 Mtetra
.484 .175 .365 r
.80335 .49689 .80482 .48736 .81106 .48866 .80936 .49511 Mtetra
.434 .081 .266 r
.80936 .49511 .81106 .48866 .81697 .48596 .81537 .49331 Mtetra
.146 0 .204 r
.81537 .49331 .81697 .48596 .82283 .48257 .82092 .4861 Mtetra
.566 .122 .154 r
.82092 .4861 .82283 .48257 .82914 .48406 .82728 .4879 Mtetra
.321 0 .069 r
.82728 .4879 .82914 .48406 .8355 .48578 .83333 .48605 Mtetra
.994 .867 .588 r
.83333 .48605 .8355 .48578 .84134 .48183 .83801 .46975 Mtetra
.154 .201 .659 r
.83801 .46975 .84134 .48183 .84809 .4871 .84542 .48197 Mtetra
.438 .535 .859 r
.84542 .48197 .84809 .4871 .85559 .49953 .85188 .48387 Mtetra
.783 .581 .627 r
.85188 .48387 .85559 .49953 .85946 .47556 .85647 .46694 Mtetra
0 0 .509 r
.85647 .46694 .85946 .47556 .86675 .48525 .86444 .48341 Mtetra
.933 .87 .753 r
.86444 .48341 .86675 .48525 .87152 .47059 .86982 .4743 Mtetra
.277 0 .041 r
.86982 .4743 .87152 .47059 .87802 .47227 .87591 .47201 Mtetra
.428 .867 .903 r
.87591 .47201 .87802 .47227 .88474 .47583 .88206 .47018 Mtetra
.839 .709 .72 r
.88206 .47018 .88474 .47583 .89032 .46878 .88742 .46106 Mtetra
.683 .595 .751 r
.88742 .46106 .89032 .46878 .89699 .47149 .89342 .4578 Mtetra
.629 .497 .682 r
.89342 .4578 .89699 .47149 .90187 .45831 .89953 .45538 Mtetra
.637 .765 .94 r
.89953 .45538 .90187 .45831 .90828 .4584 .90575 .45384 Mtetra
.619 .225 0 r
.90575 .45384 .90828 .4584 .91538 .46424 .91391 .46857 Mtetra
.83 .785 .284 r
.91391 .46857 .91538 .46424 .92117 .45879 .91813 .44985 Mtetra
.334 .365 .745 r
.91813 .44985 .92117 .45879 .92742 .45714 .92533 .45598 Mtetra
.887 .466 .072 r
.92533 .45598 .92742 .45714 .9355 .47003 .93437 .4766 Mtetra
.497 .138 .286 r
.93437 .4766 .9355 .47003 .9425 .4739 .94086 .47611 Mtetra
.098 0 0 r
.94086 .47611 .9425 .4739 .94882 .47209 .94712 .47373 Mtetra
0 0 0 r
.94712 .47373 .94882 .47209 .95435 .46422 .95339 .47132 Mtetra
.366 .041 .276 r
.95339 .47132 .95435 .46422 .96257 .47663 .9595 .46759 Mtetra
.867 .668 .631 r
.9595 .46759 .96257 .47663 .96844 .47112 .96377 .4501 Mtetra
.558 .42 .649 r
.96377 .4501 .96844 .47112 .97432 .46564 .97061 .45185 Mtetra
0 .003 .548 r
.39724 .6445 .40005 .65636 .4051 .66101 .40202 .65637 Mtetra
.446 .556 .874 r
.40202 .65637 .4051 .66101 .41013 .66676 .40721 .65765 Mtetra
.832 .643 .647 r
.40721 .65765 .41013 .66676 .41591 .64996 .41305 .63912 Mtetra
.789 .609 .657 r
.41305 .63912 .41591 .64996 .4217 .6316 .41871 .62525 Mtetra
.867 .678 .645 r
.41871 .62525 .4217 .6316 .42754 .60984 .42452 .60522 Mtetra
.415 .538 .873 r
.42452 .60522 .42754 .60984 .43291 .60403 .42969 .60679 Mtetra
0 0 0 r
.42969 .60679 .43291 .60403 .43837 .59432 .43502 .60301 Mtetra
.678 .362 .432 r
.43502 .60301 .43837 .59432 .44326 .60811 .44012 .60843 Mtetra
.471 0 0 r
.44012 .60843 .44326 .60811 .44843 .61141 .44534 .61017 Mtetra
.905 .522 .286 r
.44534 .61017 .44843 .61141 .45337 .62767 .45033 .62352 Mtetra
.658 .674 .853 r
.45033 .62352 .45337 .62767 .45864 .62959 .45568 .62195 Mtetra
.839 .491 0 r
.45568 .62195 .45864 .62959 .46384 .63696 .46069 .6386 Mtetra
.974 .884 .678 r
.46069 .6386 .46384 .63696 .46941 .62351 .46629 .62539 Mtetra
.964 .932 .704 r
.46629 .62539 .46941 .62351 .47489 .61473 .47182 .61473 Mtetra
.956 .771 .613 r
.47182 .61473 .47489 .61473 .48051 .59408 .47752 .59032 Mtetra
.84 .402 0 r
.47752 .59032 .48051 .59408 .48568 .60907 .48273 .60074 Mtetra
.381 .397 .752 r
.48273 .60074 .48568 .60907 .49096 .61835 .48806 .60454 Mtetra
.047 .094 .589 r
.48806 .60454 .49096 .61835 .49638 .61645 .49334 .61713 Mtetra
.653 .97 .872 r
.49334 .61713 .49638 .61645 .50183 .61126 .49879 .61373 Mtetra
.005 0 0 r
.49879 .61373 .50183 .61126 .50724 .6143 .50425 .61135 Mtetra
0 .059 .558 r
.50425 .61135 .50724 .6143 .51269 .61381 .50968 .61634 Mtetra
.983 .796 .573 r
.50968 .61634 .51269 .61381 .51818 .6 .51523 .58752 Mtetra
.797 .605 .642 r
.51523 .58752 .51818 .6 .52364 .5957 .5207 .57074 Mtetra
.467 .339 .622 r
.5207 .57074 .52364 .5957 .52907 .56986 .52614 .57824 Mtetra
.763 .446 .448 r
.52614 .57824 .52907 .56986 .53454 .58229 .53162 .58992 Mtetra
.237 0 .209 r
.53162 .58992 .53454 .58229 .54006 .59248 .5371 .5849 Mtetra
.74 .617 .721 r
.5371 .5849 .54006 .59248 .54564 .60346 .54258 .57912 Mtetra
.553 .403 .631 r
.54258 .57912 .54564 .60346 .55108 .59102 .5481 .58112 Mtetra
.85 .647 .628 r
.5481 .58112 .55108 .59102 .55641 .56864 .55345 .5588 Mtetra
.905 .585 .098 r
.55345 .5588 .55641 .56864 .56206 .58107 .55924 .58686 Mtetra
.989 .86 .499 r
.55924 .58686 .56206 .58107 .56738 .5623 .56454 .56356 Mtetra
.963 .933 .707 r
.56454 .56356 .56738 .5623 .57285 .55686 .56996 .55328 Mtetra
.781 .741 .816 r
.56996 .55328 .57285 .55686 .5783 .55123 .57544 .54877 Mtetra
0 .408 .84 r
.57544 .54877 .5783 .55123 .58389 .55297 .58105 .55151 Mtetra
.422 0 0 r
.58105 .55151 .58389 .55297 .58965 .5625 .5867 .55494 Mtetra
0 0 .296 r
.5867 .55494 .58965 .5625 .59542 .57068 .59259 .56943 Mtetra
0 .404 .741 r
.59259 .56943 .59542 .57068 .60125 .5794 .59828 .5714 Mtetra
.384 .41 .764 r
.59828 .5714 .60125 .5794 .60713 .58798 .60404 .57521 Mtetra
.595 .479 .691 r
.60404 .57521 .60713 .58798 .61281 .58707 .60971 .57467 Mtetra
.693 .543 .679 r
.60971 .57467 .61281 .58707 .61858 .5891 .61526 .56892 Mtetra
.741 .544 .627 r
.61526 .56892 .61858 .5891 .62383 .57258 .62053 .55296 Mtetra
.729 .536 .631 r
.62053 .55296 .62383 .57258 .62917 .55994 .62582 .53925 Mtetra
.682 .501 .636 r
.62582 .53925 .62917 .55994 .63441 .54512 .63124 .53062 Mtetra
.574 .453 .677 r
.63124 .53062 .63441 .54512 .63998 .54121 .63695 .531 Mtetra
.22 .262 .694 r
.63695 .531 .63998 .54121 .64536 .53163 .64295 .5389 Mtetra
.644 .298 .371 r
.64295 .5389 .64536 .53163 .65123 .53526 .64884 .54259 Mtetra
.775 .438 .415 r
.64884 .54259 .65123 .53526 .65773 .55452 .65506 .55441 Mtetra
.246 0 0 r
.65506 .55441 .65773 .55452 .66363 .55685 .66092 .55561 Mtetra
.967 .776 .595 r
.66092 .55561 .66363 .55685 .66844 .5334 .66577 .53208 Mtetra
.935 .847 .732 r
.66577 .53208 .66844 .5334 .67378 .52303 .67113 .52192 Mtetra
.855 .913 .872 r
.67113 .52192 .67378 .52303 .67964 .52444 .6767 .51674 Mtetra
.359 .401 .769 r
.6767 .51674 .67964 .52444 .68537 .52254 .68272 .52092 Mtetra
.602 .054 0 r
.68272 .52092 .68537 .52254 .69116 .52179 .68883 .52643 Mtetra
.708 .319 .309 r
.68883 .52643 .69116 .52179 .69692 .52007 .69498 .532 Mtetra
.449 .166 .39 r
.69498 .532 .69692 .52007 .70275 .51942 .70069 .52845 Mtetra
.385 .081 .321 r
.70069 .52845 .70275 .51942 .70861 .51897 .70639 .52452 Mtetra
.405 .031 .212 r
.70639 .52452 .70861 .51897 .71441 .51724 .71221 .52278 Mtetra
.666 .754 .264 r
.71221 .52278 .71441 .51724 .71997 .51124 .71738 .50958 Mtetra
0 .261 .673 r
.71738 .50958 .71997 .51124 .72629 .51787 .72352 .51297 Mtetra
.752 .692 .794 r
.72352 .51297 .72629 .51787 .73194 .51298 .7292 .50864 Mtetra
.154 .403 .848 r
.7292 .50864 .73194 .51298 .73771 .51012 .73542 .51254 Mtetra
.536 .047 .043 r
.73542 .51254 .73771 .51012 .74336 .50519 .74151 .51414 Mtetra
.335 .039 .305 r
.74151 .51414 .74336 .50519 .74934 .50505 .74719 .50911 Mtetra
0 0 0 r
.74719 .50911 .74934 .50505 .7557 .51026 .75271 .50175 Mtetra
.717 .596 .721 r
.75271 .50175 .7557 .51026 .76123 .50324 .75838 .49667 Mtetra
.475 .503 .807 r
.75838 .49667 .76123 .50324 .76702 .49979 .76455 .49857 Mtetra
0 .469 .801 r
.76455 .49857 .76702 .49979 .77319 .50144 .77075 .50042 Mtetra
.733 .936 .954 r
.77075 .50042 .77319 .50144 .77877 .49511 .77659 .4972 Mtetra
.934 .93 .568 r
.77659 .4972 .77877 .49511 .78535 .5014 .78175 .48516 Mtetra
.463 .373 .668 r
.78175 .48516 .78535 .5014 .79159 .50311 .78829 .49084 Mtetra
.618 .499 .696 r
.78829 .49084 .79159 .50311 .79716 .4962 .79429 .48925 Mtetra
.199 .322 .765 r
.79429 .48925 .79716 .4962 .80335 .49689 .80094 .49541 Mtetra
.858 .909 .867 r
.80094 .49541 .80335 .49689 .80936 .49511 .80665 .48998 Mtetra
.563 .603 .851 r
.80665 .48998 .80936 .49511 .81537 .49331 .81283 .48999 Mtetra
.819 .787 .822 r
.81283 .48999 .81537 .49331 .82092 .4861 .81854 .48457 Mtetra
.88 .904 .842 r
.81854 .48457 .82092 .4861 .82728 .4879 .8242 .47842 Mtetra
.272 .314 .723 r
.8242 .47842 .82728 .4879 .83333 .48605 .83109 .48577 Mtetra
.99 .863 .614 r
.83109 .48577 .83333 .48605 .83801 .46975 .83589 .47036 Mtetra
.801 .318 .06 r
.83589 .47036 .83801 .46975 .84542 .48197 .84298 .47921 Mtetra
.886 .825 .781 r
.84298 .47921 .84542 .48197 .85188 .48387 .84851 .47153 Mtetra
.728 .566 .671 r
.84851 .47153 .85188 .48387 .85647 .46694 .85396 .4633 Mtetra
.87 .472 .008 r
.85396 .4633 .85647 .46694 .86444 .48341 .86253 .48558 Mtetra
.532 .022 0 r
.86253 .48558 .86444 .48341 .86982 .4743 .86907 .48746 Mtetra
.135 0 .331 r
.86907 .48746 .86982 .4743 .87591 .47201 .87398 .47355 Mtetra
.954 .913 .545 r
.87398 .47355 .87591 .47201 .88206 .47018 .8789 .46012 Mtetra
.698 .569 .706 r
.8789 .46012 .88206 .47018 .88742 .46106 .88471 .45514 Mtetra
.727 .658 .782 r
.88471 .45514 .88742 .46106 .89342 .4578 .89064 .4511 Mtetra
.536 .538 .804 r
.89064 .4511 .89342 .4578 .89953 .45538 .89712 .45195 Mtetra
.501 .666 .936 r
.89712 .45195 .89953 .45538 .90575 .45384 .90356 .45222 Mtetra
.597 .07 0 r
.90356 .45222 .90575 .45384 .91391 .46857 .91086 .45957 Mtetra
.793 .633 .683 r
.91086 .45957 .91391 .46857 .91813 .44985 .91611 .44944 Mtetra
.789 .291 0 r
.91611 .44944 .91813 .44985 .92533 .45598 .92382 .45967 Mtetra
.633 .187 .174 r
.92382 .45967 .92533 .45598 .93437 .4766 .93076 .46315 Mtetra
.705 .546 .669 r
.93076 .46315 .93437 .4766 .94086 .47611 .9364 .45597 Mtetra
.528 .403 .653 r
.9364 .45597 .94086 .47611 .94712 .47373 .9434 .45958 Mtetra
.521 .428 .69 r
.9434 .45958 .94712 .47373 .95339 .47132 .95035 .46246 Mtetra
.811 .645 .676 r
.95035 .46246 .95339 .47132 .9595 .46759 .95547 .45125 Mtetra
.799 .586 .614 r
.95547 .45125 .9595 .46759 .96377 .4501 .95948 .43182 Mtetra
.609 .462 .656 r
.95948 .43182 .96377 .4501 .97061 .45185 .9658 .42992 Mtetra
.512 .442 .713 r
.3944 .63383 .39724 .6445 .40202 .65637 .39951 .63581 Mtetra
.493 .367 .637 r
.39951 .63581 .40202 .65637 .40721 .65765 .40456 .6405 Mtetra
.723 .541 .644 r
.40456 .6405 .40721 .65765 .41305 .63912 .41016 .62918 Mtetra
.789 .615 .665 r
.41016 .62918 .41305 .63912 .41871 .62525 .41579 .61653 Mtetra
.856 .656 .632 r
.41579 .61653 .41871 .62525 .42452 .60522 .42173 .59282 Mtetra
.382 .336 .683 r
.42173 .59282 .42452 .60522 .42969 .60679 .42677 .59835 Mtetra
.703 .583 .717 r
.42677 .59835 .42969 .60679 .43502 .60301 .43211 .59396 Mtetra
0 0 .226 r
.43211 .59396 .43502 .60301 .44012 .60843 .43696 .60891 Mtetra
.816 .386 .222 r
.43696 .60891 .44012 .60843 .44534 .61017 .44206 .6162 Mtetra
.788 .462 .436 r
.44206 .6162 .44534 .61017 .45033 .62352 .44709 .62785 Mtetra
.785 .435 .393 r
.44709 .62785 .45033 .62352 .45568 .62195 .45223 .63722 Mtetra
.399 .138 .398 r
.45223 .63722 .45568 .62195 .46069 .6386 .4577 .63135 Mtetra
.806 .65 .688 r
.4577 .63135 .46069 .6386 .46629 .62539 .46326 .62065 Mtetra
.894 .705 .64 r
.46326 .62065 .46629 .62539 .47182 .61473 .46897 .59975 Mtetra
.8 .598 .628 r
.46897 .59975 .47182 .61473 .47752 .59032 .47463 .57843 Mtetra
0 0 .414 r
.47463 .57843 .47752 .59032 .48273 .60074 .47976 .5942 Mtetra
.775 .406 0 r
.47976 .5942 .48273 .60074 .48806 .60454 .48497 .60776 Mtetra
.359 0 .019 r
.48497 .60776 .48806 .60454 .49334 .61713 .49039 .60696 Mtetra
.733 .583 .687 r
.49039 .60696 .49334 .61713 .49879 .61373 .49587 .59968 Mtetra
.717 .466 0 r
.49587 .59968 .49879 .61373 .50425 .61135 .50112 .62561 Mtetra
.357 .097 .375 r
.50112 .62561 .50425 .61135 .50968 .61634 .50664 .6189 Mtetra
.982 .791 .57 r
.50664 .6189 .50968 .61634 .51523 .58752 .51224 .58861 Mtetra
.975 .802 .607 r
.51224 .58861 .51523 .58752 .5207 .57074 .51775 .56615 Mtetra
0 .096 .648 r
.51775 .56615 .5207 .57074 .52614 .57824 .52318 .57224 Mtetra
.743 .362 0 r
.52318 .57224 .52614 .57824 .53162 .58992 .52866 .58497 Mtetra
.597 .618 .843 r
.52866 .58497 .53162 .58992 .5371 .5849 .53416 .58444 Mtetra
.951 .83 .688 r
.53416 .58444 .5371 .5849 .54258 .57912 .53962 .57123 Mtetra
.608 .542 .755 r
.53962 .57123 .54258 .57912 .5481 .58112 .54512 .57047 Mtetra
.802 .618 .652 r
.54512 .57047 .5481 .58112 .55345 .5588 .55054 .55573 Mtetra
.855 .412 0 r
.55054 .55573 .55345 .5588 .55924 .58686 .55616 .56674 Mtetra
.698 .514 .636 r
.55616 .56674 .55924 .58686 .56454 .56356 .5616 .55661 Mtetra
.592 .554 .78 r
.5616 .55661 .56454 .56356 .56996 .55328 .56715 .55627 Mtetra
0 0 0 r
.56715 .55627 .56996 .55328 .57544 .54877 .57265 .55176 Mtetra
.603 .158 .167 r
.57265 .55176 .57544 .54877 .58105 .55151 .57826 .55402 Mtetra
0 0 0 r
.57826 .55402 .58105 .55151 .5867 .55494 .5838 .55056 Mtetra
.892 .493 .059 r
.5838 .55056 .5867 .55494 .59259 .56943 .58971 .56636 Mtetra
.231 .542 .927 r
.58971 .56636 .59259 .56943 .59828 .5714 .59541 .56833 Mtetra
.784 .772 .842 r
.59541 .56833 .59828 .5714 .60404 .57521 .60098 .5641 Mtetra
.536 .456 .713 r
.60098 .5641 .60404 .57521 .60971 .57467 .6067 .56561 Mtetra
.859 .658 .629 r
.6067 .56561 .60971 .57467 .61526 .56892 .61186 .54432 Mtetra
.692 .501 .624 r
.61186 .54432 .61526 .56892 .62053 .55296 .61722 .53257 Mtetra
.637 .471 .642 r
.61722 .53257 .62053 .55296 .62582 .53925 .62277 .52829 Mtetra
.111 .177 .653 r
.62277 .52829 .62582 .53925 .63124 .53062 .62877 .53837 Mtetra
.737 .402 .413 r
.62877 .53837 .63124 .53062 .63695 .531 .63479 .54735 Mtetra
.639 .356 .473 r
.63479 .54735 .63695 .531 .64295 .5389 .64074 .5529 Mtetra
.414 .149 .4 r
.64074 .5529 .64295 .5389 .64884 .54259 .64633 .54752 Mtetra
.774 .406 .359 r
.64633 .54752 .64884 .54259 .65506 .55441 .65248 .55676 Mtetra
.997 .81 .534 r
.65248 .55676 .65506 .55441 .66092 .55561 .6572 .52884 Mtetra
.616 .443 .625 r
.6572 .52884 .66092 .55561 .66577 .53208 .66285 .52535 Mtetra
.742 .637 .743 r
.66285 .52535 .66577 .53208 .67113 .52192 .66844 .52014 Mtetra
.769 .868 .922 r
.66844 .52014 .67113 .52192 .6767 .51674 .6741 .51673 Mtetra
.883 .467 .213 r
.6741 .51673 .6767 .51674 .68272 .52092 .68055 .53003 Mtetra
.7 .371 .416 r
.68055 .53003 .68272 .52092 .68883 .52643 .68677 .53735 Mtetra
.471 .175 .381 r
.68677 .53735 .68883 .52643 .69498 .532 .69255 .53486 Mtetra
.573 .109 .115 r
.69255 .53486 .69498 .532 .70069 .52845 .69857 .53682 Mtetra
.356 .045 .293 r
.69857 .53682 .70069 .52845 .70639 .52452 .70428 .5327 Mtetra
.124 0 .2 r
.70428 .5327 .70639 .52452 .71221 .52278 .70981 .52502 Mtetra
.986 .893 .566 r
.70981 .52502 .71221 .52278 .71738 .50958 .71485 .50905 Mtetra
.412 .845 .946 r
.71485 .50905 .71738 .50958 .72352 .51297 .72072 .50783 Mtetra
.31 .459 .848 r
.72072 .50783 .72352 .51297 .7292 .50864 .72687 .51101 Mtetra
.776 .342 .219 r
.72687 .51101 .7292 .50864 .73542 .51254 .73332 .51853 Mtetra
.442 .075 .246 r
.73332 .51853 .73542 .51254 .74151 .51414 .73925 .51719 Mtetra
.251 0 0 r
.73925 .51719 .74151 .51414 .74719 .50911 .74517 .51544 Mtetra
0 0 .03 r
.74517 .51544 .74719 .50911 .75271 .50175 .75062 .50658 Mtetra
0 0 0 r
.75062 .50658 .75271 .50175 .75838 .49667 .75604 .49754 Mtetra
.768 .281 .074 r
.75604 .49754 .75838 .49667 .76455 .49857 .76259 .50446 Mtetra
.495 .122 .262 r
.76259 .50446 .76455 .49857 .77075 .50042 .76865 .50418 Mtetra
.664 .238 .224 r
.76865 .50418 .77075 .50042 .77659 .4972 .77506 .5082 Mtetra
0 0 .138 r
.77506 .5082 .77659 .4972 .78175 .48516 .77984 .49072 Mtetra
0 0 0 r
.77984 .49072 .78175 .48516 .78829 .49084 .78499 .47841 Mtetra
.503 .426 .702 r
.78499 .47841 .78829 .49084 .79429 .48925 .79134 .4814 Mtetra
.458 .462 .775 r
.79134 .4814 .79429 .48925 .80094 .49541 .79771 .48413 Mtetra
.696 .555 .691 r
.79771 .48413 .80094 .49541 .80665 .48998 .80341 .4787 Mtetra
.531 .455 .715 r
.80341 .4787 .80665 .48998 .81283 .48999 .80974 .48052 Mtetra
.676 .563 .719 r
.80974 .48052 .81283 .48999 .81854 .48457 .81562 .47689 Mtetra
.578 .537 .773 r
.81562 .47689 .81854 .48457 .8242 .47842 .82183 .47689 Mtetra
.524 0 0 r
.82183 .47689 .8242 .47842 .83109 .48577 .82856 .48242 Mtetra
.911 .789 .713 r
.82856 .48242 .83109 .48577 .83589 .47036 .8338 .47155 Mtetra
.853 .414 .172 r
.8338 .47155 .83589 .47036 .84298 .47921 .84125 .48397 Mtetra
.837 .802 .31 r
.84125 .48397 .84298 .47921 .84851 .47153 .84579 .46587 Mtetra
.453 .524 .84 r
.84579 .46587 .84851 .47153 .85396 .4633 .85226 .46779 Mtetra
.889 .519 .334 r
.85226 .46779 .85396 .4633 .86253 .48558 .86098 .4915 Mtetra
.784 .405 .338 r
.86098 .4915 .86253 .48558 .86907 .48746 .86853 .50283 Mtetra
0 0 .027 r
.86853 .50283 .86907 .48746 .87398 .47355 .87065 .46202 Mtetra
.651 .527 .7 r
.87065 .46202 .87398 .47355 .8789 .46012 .87669 .45893 Mtetra
.839 .946 .891 r
.87669 .45893 .8789 .46012 .88471 .45514 .88252 .45393 Mtetra
.887 .939 .843 r
.88252 .45393 .88471 .45514 .89064 .4511 .88821 .44769 Mtetra
0 .248 .757 r
.88821 .44769 .89064 .4511 .89712 .45195 .89525 .45336 Mtetra
.536 0 0 r
.89525 .45336 .89712 .45195 .90356 .45222 .90196 .45586 Mtetra
0 0 0 r
.90196 .45586 .90356 .45222 .91086 .45957 .90716 .44508 Mtetra
.492 .405 .686 r
.90716 .44508 .91086 .45957 .91611 .44944 .9141 .44923 Mtetra
.802 .31 0 r
.9141 .44923 .91611 .44944 .92382 .45967 .92187 .45983 Mtetra
.444 0 0 r
.92187 .45983 .92382 .45967 .93076 .46315 .92874 .46264 Mtetra
.996 .86 .578 r
.92874 .46264 .93076 .46315 .9364 .45597 .93322 .44607 Mtetra
.583 .506 .734 r
.93322 .44607 .9364 .45597 .9434 .45958 .93976 .44601 Mtetra
.739 .565 .657 r
.93976 .44601 .9434 .45958 .95035 .46246 .94504 .43606 Mtetra
.618 .446 .627 r
.94504 .43606 .95035 .46246 .95547 .45125 .95108 .43211 Mtetra
.493 .384 .658 r
.95108 .43211 .95547 .45125 .95948 .43182 .95839 .43757 Mtetra
.762 .366 .303 r
.95839 .43757 .95948 .43182 .9658 .42992 .96631 .44725 Mtetra
.377 .345 .696 r
.39157 .6225 .3944 .63383 .39951 .63581 .39657 .62753 Mtetra
.36 .384 .751 r
.39657 .62753 .39951 .63581 .40456 .6405 .40163 .6314 Mtetra
.675 .56 .717 r
.40163 .6314 .40456 .6405 .41016 .62918 .40697 .62807 Mtetra
.93 .771 .663 r
.40697 .62807 .41016 .62918 .41579 .61653 .41276 .61107 Mtetra
.841 .685 .689 r
.41276 .61107 .41579 .61653 .42173 .59282 .41836 .59904 Mtetra
.599 .245 .341 r
.41836 .59904 .42173 .59282 .42677 .59835 .42352 .60091 Mtetra
.843 .494 .393 r
.42352 .60091 .42677 .59835 .43211 .59396 .42841 .61346 Mtetra
.696 .425 .509 r
.42841 .61346 .43211 .59396 .43696 .60891 .43336 .62557 Mtetra
.664 .387 .49 r
.43336 .62557 .43696 .60891 .44206 .6162 .43848 .63299 Mtetra
.692 .414 .497 r
.43848 .63299 .44206 .6162 .44709 .62785 .44357 .64329 Mtetra
.253 .011 .34 r
.44357 .64329 .44709 .62785 .45223 .63722 .44915 .63368 Mtetra
.842 .738 .749 r
.44915 .63368 .45223 .63722 .4577 .63135 .45467 .62569 Mtetra
.873 .691 .652 r
.45467 .62569 .4577 .63135 .46326 .62065 .46039 .60745 Mtetra
.801 .605 .636 r
.46039 .60745 .46326 .62065 .46897 .59975 .46607 .58858 Mtetra
.663 .532 .694 r
.46607 .58858 .46897 .59975 .47463 .57843 .47146 .58511 Mtetra
.72 .384 .408 r
.47146 .58511 .47463 .57843 .47976 .5942 .47672 .592 Mtetra
.035 .491 .883 r
.47672 .592 .47976 .5942 .48497 .60776 .48207 .59395 Mtetra
.178 .186 .63 r
.48207 .59395 .48497 .60776 .49039 .60696 .48735 .60433 Mtetra
0 .214 .686 r
.48735 .60433 .49039 .60696 .49587 .59968 .49275 .60809 Mtetra
.566 .238 .372 r
.49275 .60809 .49587 .59968 .50112 .62561 .49819 .60902 Mtetra
.679 .513 .654 r
.49819 .60902 .50112 .62561 .50664 .6189 .5037 .60248 Mtetra
.751 .561 .639 r
.5037 .60248 .50664 .6189 .51224 .58861 .50924 .58816 Mtetra
.949 .823 .685 r
.50924 .58816 .51224 .58861 .51775 .56615 .51475 .5745 Mtetra
0 0 0 r
.51475 .5745 .51775 .56615 .52318 .57224 .52023 .56081 Mtetra
.581 .479 .703 r
.52023 .56081 .52318 .57224 .52866 .58497 .52568 .56083 Mtetra
.305 .224 .598 r
.52568 .56083 .52866 .58497 .53416 .58444 .53118 .57518 Mtetra
.752 .602 .691 r
.53118 .57518 .53416 .58444 .53962 .57123 .53667 .56724 Mtetra
.438 .591 .906 r
.53667 .56724 .53962 .57123 .54512 .57047 .54219 .56834 Mtetra
.855 .818 .812 r
.54219 .56834 .54512 .57047 .55054 .55573 .54768 .56218 Mtetra
.702 .791 .316 r
.54768 .56218 .55054 .55573 .55616 .56674 .55311 .54919 Mtetra
.567 .432 .657 r
.55311 .54919 .55616 .56674 .5616 .55661 .55865 .54991 Mtetra
.777 .649 .72 r
.55865 .54991 .5616 .55661 .56715 .55627 .56412 .54268 Mtetra
.401 .343 .677 r
.56412 .54268 .56715 .55627 .57265 .55176 .56976 .54868 Mtetra
.734 .254 0 r
.56976 .54868 .57265 .55176 .57826 .55402 .57546 .55704 Mtetra
.699 .276 .24 r
.57546 .55704 .57826 .55402 .5838 .55056 .58115 .56153 Mtetra
.586 .28 .417 r
.58115 .56153 .5838 .55056 .58971 .56636 .58682 .5632 Mtetra
.789 .767 .834 r
.58682 .5632 .58971 .56636 .59541 .56833 .59239 .55876 Mtetra
.428 .408 .735 r
.59239 .55876 .59541 .56833 .60098 .5641 .59814 .56247 Mtetra
.936 .805 .69 r
.59814 .56247 .60098 .5641 .6067 .56561 .60353 .54941 Mtetra
.676 .512 .656 r
.60353 .54941 .6067 .56561 .61186 .54432 .60906 .54319 Mtetra
.919 .865 .77 r
.60906 .54319 .61186 .54432 .61722 .53257 .61453 .53474 Mtetra
0 0 0 r
.61453 .53474 .61722 .53257 .62277 .52829 .62016 .53242 Mtetra
.689 .29 .286 r
.62016 .53242 .62277 .52829 .62877 .53837 .626 .53697 Mtetra
.924 .542 .254 r
.626 .53697 .62877 .53837 .63479 .54735 .63234 .55577 Mtetra
.575 .243 .369 r
.63234 .55577 .63479 .54735 .64074 .5529 .63817 .55708 Mtetra
.756 .37 .323 r
.63817 .55708 .64074 .5529 .64633 .54752 .64424 .56459 Mtetra
0 0 .267 r
.64424 .56459 .64633 .54752 .65248 .55676 .64936 .54535 Mtetra
.789 .606 .654 r
.64936 .54535 .65248 .55676 .6572 .52884 .65466 .53195 Mtetra
0 0 0 r
.65466 .53195 .6572 .52884 .66285 .52535 .66026 .52669 Mtetra
.848 .992 .735 r
.66026 .52669 .66285 .52535 .66844 .52014 .6658 .5198 Mtetra
.484 .888 .944 r
.6658 .5198 .66844 .52014 .6741 .51673 .67155 .51807 Mtetra
.929 .589 .369 r
.67155 .51807 .6741 .51673 .68055 .53003 .67885 .54994 Mtetra
.39 .156 .435 r
.67885 .54994 .68055 .53003 .68677 .53735 .68433 .54079 Mtetra
.282 0 0 r
.68433 .54079 .68677 .53735 .69255 .53486 .69017 .53906 Mtetra
.338 0 .092 r
.69017 .53906 .69255 .53486 .69857 .53682 .69601 .53733 Mtetra
.907 .981 .779 r
.69601 .53733 .69857 .53682 .70428 .5327 .70158 .53 Mtetra
.917 .793 .707 r
.70158 .53 .70428 .5327 .70981 .52502 .70691 .51848 Mtetra
.876 .693 .651 r
.70691 .51848 .70981 .52502 .71485 .50905 .71194 .50216 Mtetra
.718 .624 .752 r
.71194 .50216 .71485 .50905 .72072 .50783 .71764 .49791 Mtetra
0 .071 .609 r
.71764 .49791 .72072 .50783 .72687 .51101 .72434 .51035 Mtetra
.529 .894 .971 r
.72434 .51035 .72687 .51101 .73332 .51853 .73023 .50858 Mtetra
.358 .361 .726 r
.73023 .50858 .73332 .51853 .73925 .51719 .73659 .5142 Mtetra
.825 .798 .826 r
.73659 .5142 .73925 .51719 .74517 .51544 .74228 .50875 Mtetra
.903 .699 .617 r
.74228 .50875 .74517 .51544 .75062 .50658 .74687 .48704 Mtetra
.496 .38 .65 r
.74687 .48704 .75062 .50658 .75604 .49754 .75324 .49198 Mtetra
.463 .532 .843 r
.75324 .49198 .75604 .49754 .76259 .50446 .75941 .49363 Mtetra
.582 .491 .716 r
.75941 .49363 .76259 .50446 .76865 .50418 .76549 .49361 Mtetra
.285 .305 .707 r
.76549 .49361 .76865 .50418 .77506 .5082 .77216 .50122 Mtetra
.833 .675 .687 r
.77216 .50122 .77506 .5082 .77984 .49072 .77743 .49002 Mtetra
.741 .961 .939 r
.77743 .49002 .77984 .49072 .78499 .47841 .78328 .48645 Mtetra
.258 0 .257 r
.78328 .48645 .78499 .47841 .79134 .4814 .78896 .48057 Mtetra
.878 .95 .853 r
.78896 .48057 .79134 .4814 .79771 .48413 .79462 .47465 Mtetra
.33 .351 .732 r
.79462 .47465 .79771 .48413 .80341 .4787 .80129 .48074 Mtetra
.225 0 0 r
.80129 .48074 .80341 .4787 .80974 .48052 .8074 .47969 Mtetra
0 .426 .724 r
.8074 .47969 .80974 .48052 .81562 .47689 .81376 .4815 Mtetra
0 0 0 r
.81376 .4815 .81562 .47689 .82183 .47689 .81917 .47227 Mtetra
.83 .734 .759 r
.81917 .47227 .82183 .47689 .82856 .48242 .82474 .46496 Mtetra
.274 .241 .639 r
.82474 .46496 .82856 .48242 .8338 .47155 .83224 .47846 Mtetra
.09 0 .166 r
.83224 .47846 .8338 .47155 .84125 .48397 .83781 .4709 Mtetra
.784 .594 .643 r
.83781 .4709 .84125 .48397 .84579 .46587 .84273 .45682 Mtetra
.256 .312 .729 r
.84273 .45682 .84579 .46587 .85226 .46779 .84974 .46415 Mtetra
0 .021 .571 r
.84974 .46415 .85226 .46779 .86098 .4915 .85689 .47238 Mtetra
.693 .513 .639 r
.85689 .47238 .86098 .4915 .86853 .50283 .8623 .46318 Mtetra
.627 .436 .604 r
.8623 .46318 .86853 .50283 .87065 .46202 .86787 .4556 Mtetra
0 0 .464 r
.86787 .4556 .87065 .46202 .87669 .45893 .8758 .47026 Mtetra
.241 .001 .335 r
.8758 .47026 .87669 .45893 .88252 .45393 .88119 .4608 Mtetra
.415 .072 .273 r
.88119 .4608 .88252 .45393 .88821 .44769 .88734 .45841 Mtetra
.396 .115 .364 r
.88734 .45841 .88821 .44769 .89525 .45336 .89322 .45346 Mtetra
.541 0 0 r
.89322 .45346 .89525 .45336 .90196 .45586 .9001 .45729 Mtetra
.983 .865 .494 r
.9001 .45729 .90196 .45586 .90716 .44508 .90446 .43912 Mtetra
.55 .569 .827 r
.90446 .43912 .90716 .44508 .9141 .44923 .91096 .43951 Mtetra
.235 .289 .715 r
.91096 .43951 .9141 .44923 .92187 .45983 .91849 .44819 Mtetra
.582 .486 .71 r
.91849 .44819 .92187 .45983 .92874 .46264 .925 .44814 Mtetra
.723 .55 .656 r
.925 .44814 .92874 .46264 .93322 .44607 .93039 .43893 Mtetra
.58 .554 .79 r
.93039 .43893 .93322 .44607 .93976 .44601 .93692 .43882 Mtetra
.845 .683 .682 r
.93692 .43882 .93976 .44601 .94504 .43606 .942 .4272 Mtetra
.636 .552 .743 r
.942 .4272 .94504 .43606 .95108 .43211 .94832 .42532 Mtetra
0 .007 .582 r
.94832 .42532 .95108 .43211 .95839 .43757 .95669 .43889 Mtetra
.583 .033 0 r
.95669 .43889 .95839 .43757 .96631 .44725 .96379 .44237 Mtetra
.668 .544 .704 r
.38871 .61237 .39157 .6225 .39657 .62753 .39401 .60903 Mtetra
.397 .305 .634 r
.39401 .60903 .39657 .62753 .40163 .6314 .39892 .61663 Mtetra
.576 .45 .672 r
.39892 .61663 .40163 .6314 .40697 .62807 .40412 .61684 Mtetra
.718 .565 .68 r
.40412 .61684 .40697 .62807 .41276 .61107 .40958 .60993 Mtetra
.902 .826 .762 r
.40958 .60993 .41276 .61107 .41836 .59904 .41509 .60131 Mtetra
.747 .337 .272 r
.41509 .60131 .41836 .59904 .42352 .60091 .42015 .60678 Mtetra
.704 .358 .387 r
.42015 .60678 .42352 .60091 .42841 .61346 .42525 .61233 Mtetra
.925 .592 .389 r
.42525 .61233 .42841 .61346 .43336 .62557 .42993 .63433 Mtetra
.681 .363 .429 r
.42993 .63433 .43336 .62557 .43848 .63299 .43511 .64 Mtetra
.447 .098 .28 r
.43511 .64 .43848 .63299 .44357 .64329 .4405 .63855 Mtetra
.773 .69 .771 r
.4405 .63855 .44357 .64329 .44915 .63368 .44598 .6333 Mtetra
.947 .795 .66 r
.44598 .6333 .44915 .63368 .45467 .62569 .45172 .61638 Mtetra
.878 .663 .608 r
.45172 .61638 .45467 .62569 .46039 .60745 .45774 .58285 Mtetra
.609 .441 .629 r
.45774 .58285 .46039 .60745 .46607 .58858 .46311 .58036 Mtetra
.309 .355 .747 r
.46311 .58036 .46607 .58858 .47146 .58511 .46838 .58496 Mtetra
.856 .437 .231 r
.46838 .58496 .47146 .58511 .47672 .592 .4736 .59438 Mtetra
0 0 0 r
.4736 .59438 .47672 .592 .48207 .59395 .47903 .59098 Mtetra
.489 .683 .952 r
.47903 .59098 .48207 .59395 .48735 .60433 .48443 .59115 Mtetra
.4 .344 .68 r
.48443 .59115 .48735 .60433 .49275 .60809 .48979 .59675 Mtetra
.517 .44 .708 r
.48979 .59675 .49275 .60809 .49819 .60902 .49522 .59876 Mtetra
.766 .601 .674 r
.49522 .59876 .49819 .60902 .5037 .60248 .50075 .58859 Mtetra
.615 .483 .678 r
.50075 .58859 .5037 .60248 .50924 .58816 .50623 .58696 Mtetra
.946 .768 .63 r
.50623 .58696 .50924 .58816 .51475 .5745 .51178 .56611 Mtetra
.683 .575 .728 r
.51178 .56611 .51475 .5745 .52023 .56081 .51725 .56268 Mtetra
.95 .955 .704 r
.51725 .56268 .52023 .56081 .52568 .56083 .52272 .55295 Mtetra
.626 .552 .752 r
.52272 .55295 .52568 .56083 .53118 .57518 .52819 .55168 Mtetra
.62 .452 .632 r
.52819 .55168 .53118 .57518 .53667 .56724 .53367 .54828 Mtetra
.452 .346 .644 r
.53367 .54828 .53667 .56724 .54219 .56834 .53919 .55456 Mtetra
.625 .49 .677 r
.53919 .55456 .54219 .56834 .54768 .56218 .5447 .55244 Mtetra
.752 .598 .685 r
.5447 .55244 .54768 .56218 .55311 .54919 .55017 .54409 Mtetra
.126 .347 .811 r
.55017 .54409 .55311 .54919 .55865 .54991 .55575 .54835 Mtetra
0 .363 .736 r
.55575 .54835 .55865 .54991 .56412 .54268 .56133 .5507 Mtetra
.64 .305 .389 r
.56133 .5507 .56412 .54268 .56976 .54868 .56696 .55432 Mtetra
.707 .345 .36 r
.56696 .55432 .56976 .54868 .57546 .55704 .57264 .56012 Mtetra
.655 .222 .209 r
.57264 .56012 .57546 .55704 .58115 .56153 .57833 .56348 Mtetra
.067 0 0 r
.57833 .56348 .58115 .56153 .58682 .5632 .58395 .56181 Mtetra
.874 .871 .831 r
.58395 .56181 .58682 .5632 .59239 .55876 .5895 .55565 Mtetra
.662 .744 .911 r
.5895 .55565 .59239 .55876 .59814 .56247 .59514 .55397 Mtetra
.696 .583 .725 r
.59514 .55397 .59814 .56247 .60353 .54941 .60074 .5499 Mtetra
.884 .984 .82 r
.60074 .5499 .60353 .54941 .60906 .54319 .60629 .5436 Mtetra
.959 .915 .725 r
.60629 .5436 .60906 .54319 .61453 .53474 .61173 .53351 Mtetra
.695 .898 .97 r
.61173 .53351 .61453 .53474 .62016 .53242 .61737 .53102 Mtetra
.895 .476 .169 r
.61737 .53102 .62016 .53242 .626 .53697 .62348 .54453 Mtetra
.818 .489 .433 r
.62348 .54453 .626 .53697 .63234 .55577 .62978 .56187 Mtetra
.72 .361 .367 r
.62978 .56187 .63234 .55577 .63817 .55708 .63581 .56872 Mtetra
0 0 0 r
.63581 .56872 .63817 .55708 .64424 .56459 .6408 .54411 Mtetra
.748 .547 .623 r
.6408 .54411 .64424 .56459 .64936 .54535 .64599 .52696 Mtetra
.702 .522 .64 r
.64599 .52696 .64936 .54535 .65466 .53195 .65142 .51722 Mtetra
.667 .513 .666 r
.65142 .51722 .65466 .53195 .66026 .52669 .65703 .5122 Mtetra
0 .063 .575 r
.65703 .5122 .66026 .52669 .6658 .5198 .66349 .52804 Mtetra
.462 .135 .324 r
.66349 .52804 .6658 .5198 .67155 .51807 .66927 .52631 Mtetra
.736 .399 .411 r
.66927 .52631 .67155 .51807 .67885 .54994 .67556 .53563 Mtetra
.299 .273 .662 r
.67556 .53563 .67885 .54994 .68433 .54079 .68191 .54503 Mtetra
.856 .881 .447 r
.68191 .54503 .68433 .54079 .69017 .53906 .6872 .53161 Mtetra
.695 .602 .749 r
.6872 .53161 .69017 .53906 .69601 .53733 .69295 .52802 Mtetra
.81 .635 .664 r
.69295 .52802 .69601 .53733 .70158 .53 .69823 .51517 Mtetra
.768 .576 .639 r
.69823 .51517 .70158 .53 .70691 .51848 .7034 .50066 Mtetra
.621 .47 .655 r
.7034 .50066 .70691 .51848 .71194 .50216 .70919 .498 Mtetra
0 0 .539 r
.70919 .498 .71194 .50216 .71764 .49791 .7156 .50606 Mtetra
.655 .313 .381 r
.7156 .50606 .71764 .49791 .72434 .51035 .72185 .51063 Mtetra
.077 0 0 r
.72185 .51063 .72434 .51035 .73023 .50858 .72786 .51065 Mtetra
.967 .92 .583 r
.72786 .51065 .73023 .50858 .73659 .5142 .73305 .49721 Mtetra
.636 .483 .658 r
.73305 .49721 .73659 .5142 .74228 .50875 .73884 .49369 Mtetra
.719 .544 .653 r
.73884 .49369 .74228 .50875 .74687 .48704 .74426 .48437 Mtetra
0 .268 .747 r
.74426 .48437 .74687 .48704 .75324 .49198 .75059 .48866 Mtetra
.825 .392 0 r
.75059 .48866 .75324 .49198 .75941 .49363 .75766 .50303 Mtetra
.478 .164 .355 r
.75766 .50303 .75941 .49363 .76549 .49361 .76364 .50124 Mtetra
.686 .334 .372 r
.76364 .50124 .76549 .49361 .77216 .50122 .77021 .50724 Mtetra
.416 .05 .233 r
.77021 .50724 .77216 .50122 .77743 .49002 .77623 .50545 Mtetra
.376 .129 .407 r
.77623 .50545 .77743 .49002 .78328 .48645 .7818 .49769 Mtetra
.262 .008 .327 r
.7818 .49769 .78328 .48645 .78896 .48057 .78732 .4894 Mtetra
0 0 .027 r
.78732 .4894 .78896 .48057 .79462 .47465 .79216 .4728 Mtetra
.284 .676 .972 r
.79216 .4728 .79462 .47465 .80129 .48074 .79839 .47352 Mtetra
.804 .661 .704 r
.79839 .47352 .80129 .48074 .8074 .47969 .80381 .46445 Mtetra
.543 .432 .677 r
.80381 .46445 .8074 .47969 .81376 .4815 .81017 .46631 Mtetra
.501 .405 .678 r
.81017 .46631 .81376 .4815 .81917 .47227 .81672 .47004 Mtetra
.902 .851 .783 r
.81672 .47004 .81917 .47227 .82474 .46496 .82225 .46215 Mtetra
0 0 .498 r
.82225 .46215 .82474 .46496 .83224 .47846 .8292 .46968 Mtetra
.758 .617 .703 r
.8292 .46968 .83224 .47846 .83781 .4709 .83477 .46215 Mtetra
.705 .59 .724 r
.83477 .46215 .83781 .4709 .84273 .45682 .84061 .4575 Mtetra
.793 .306 .05 r
.84061 .4575 .84273 .45682 .84974 .46415 .84777 .46614 Mtetra
.837 .402 .198 r
.84777 .46614 .84974 .46415 .85689 .47238 .85529 .47794 Mtetra
.845 .776 .271 r
.85529 .47794 .85689 .47238 .8623 .46318 .85945 .45618 Mtetra
.666 .602 .774 r
.85945 .45618 .8623 .46318 .86787 .4556 .86555 .4537 Mtetra
.558 .035 0 r
.86555 .4537 .86787 .4556 .8758 .47026 .87267 .46068 Mtetra
.663 .556 .724 r
.87267 .46068 .8758 .47026 .88119 .4608 .87874 .45755 Mtetra
.761 .789 .876 r
.87874 .45755 .88119 .4608 .88734 .45841 .88476 .45383 Mtetra
.671 .685 .855 r
.88476 .45383 .88734 .45841 .89322 .45346 .89097 .45173 Mtetra
.88 .907 .843 r
.89097 .45173 .89322 .45346 .9001 .45729 .89672 .44551 Mtetra
.746 .581 .67 r
.89672 .44551 .9001 .45729 .90446 .43912 .90212 .43635 Mtetra
.487 .712 .97 r
.90212 .43635 .90446 .43912 .91096 .43951 .90859 .43635 Mtetra
0 .217 .729 r
.90859 .43635 .91096 .43951 .91849 .44819 .91579 .44224 Mtetra
.347 .452 .826 r
.91579 .44224 .91849 .44819 .925 .44814 .92276 .44592 Mtetra
0 .173 .657 r
.92276 .44592 .925 .44814 .93039 .43893 .92999 .45144 Mtetra
.079 0 .315 r
.92999 .45144 .93039 .43893 .93692 .43882 .93467 .43622 Mtetra
.955 .831 .681 r
.93467 .43622 .93692 .43882 .942 .4272 .93964 .4237 Mtetra
0 .155 .688 r
.93964 .4237 .942 .4272 .94832 .42532 .94714 .43084 Mtetra
.843 .453 .308 r
.94714 .43084 .94832 .42532 .95669 .43889 .95601 .44795 Mtetra
.577 .241 .363 r
.95601 .44795 .95669 .43889 .96379 .44237 .9629 .44962 Mtetra
.618 .49 .685 r
.38595 .59966 .38871 .61237 .39401 .60903 .39118 .59808 Mtetra
0 0 .474 r
.39118 .59808 .39401 .60903 .39892 .61663 .39589 .61066 Mtetra
.559 .56 .811 r
.39589 .61066 .39892 .61663 .40412 .61684 .40109 .61086 Mtetra
.75 .647 .747 r
.40109 .61086 .40412 .61684 .40958 .60993 .40649 .60572 Mtetra
.812 .71 .753 r
.40649 .60572 .40958 .60993 .41509 .60131 .41195 .59881 Mtetra
.939 .605 .369 r
.41195 .59881 .41509 .60131 .42015 .60678 .41649 .62112 Mtetra
.556 .274 .443 r
.41649 .62112 .42015 .60678 .42525 .61233 .42177 .62133 Mtetra
.719 .406 .448 r
.42177 .62133 .42525 .61233 .42993 .63433 .42684 .62962 Mtetra
.734 .304 0 r
.42684 .62962 .42993 .63433 .43511 .64 .43192 .63892 Mtetra
.888 .483 .243 r
.43192 .63892 .43511 .64 .4405 .63855 .437 .65019 Mtetra
.908 .832 .371 r
.437 .65019 .4405 .63855 .44598 .6333 .44301 .624 Mtetra
.85 .651 .633 r
.44301 .624 .44598 .6333 .45172 .61638 .44888 .60143 Mtetra
.779 .585 .637 r
.44888 .60143 .45172 .61638 .45774 .58285 .45459 .58424 Mtetra
.974 .858 .664 r
.45459 .58424 .45774 .58285 .46311 .58036 .46021 .56949 Mtetra
0 .063 .592 r
.46021 .56949 .46311 .58036 .46838 .58496 .46535 .58019 Mtetra
0 .048 .609 r
.46535 .58019 .46838 .58496 .4736 .59438 .47062 .58651 Mtetra
.36 .396 .763 r
.47062 .58651 .4736 .59438 .47903 .59098 .47595 .59028 Mtetra
.77 .93 .938 r
.47595 .59028 .47903 .59098 .48443 .59115 .48141 .58686 Mtetra
.659 .672 .851 r
.48141 .58686 .48443 .59115 .48979 .59675 .48685 .58523 Mtetra
.622 .504 .698 r
.48685 .58523 .48979 .59675 .49522 .59876 .4923 .5836 Mtetra
.576 .45 .671 r
.4923 .5836 .49522 .59876 .50075 .58859 .49774 .58378 Mtetra
.688 .662 .819 r
.49774 .58378 .50075 .58859 .50623 .58696 .50322 .58141 Mtetra
.817 .684 .717 r
.50322 .58141 .50623 .58696 .51178 .56611 .50874 .57252 Mtetra
0 0 0 r
.50874 .57252 .51178 .56611 .51725 .56268 .51426 .56142 Mtetra
.889 .857 .804 r
.51426 .56142 .51725 .56268 .52272 .55295 .51975 .55444 Mtetra
.894 .989 .76 r
.51975 .55444 .52272 .55295 .52819 .55168 .52523 .5472 Mtetra
.679 .672 .836 r
.52523 .5472 .52819 .55168 .53367 .54828 .53071 .54513 Mtetra
.634 .727 .915 r
.53071 .54513 .53367 .54828 .53919 .55456 .53621 .54387 Mtetra
.558 .473 .715 r
.53621 .54387 .53919 .55456 .5447 .55244 .54173 .54459 Mtetra
0 0 .297 r
.54173 .54459 .5447 .55244 .55017 .54409 .54735 .55872 Mtetra
.62 .333 .46 r
.54735 .55872 .55017 .54409 .55575 .54835 .55296 .56249 Mtetra
.562 .277 .44 r
.55296 .56249 .55575 .54835 .56133 .5507 .55856 .56305 Mtetra
.445 .161 .386 r
.55856 .56305 .56133 .5507 .56696 .55432 .56413 .55955 Mtetra
.443 .055 .207 r
.56413 .55955 .56696 .55432 .57264 .56012 .56974 .55869 Mtetra
.767 .886 .93 r
.56974 .55869 .57264 .56012 .57833 .56348 .57533 .55534 Mtetra
.81 .644 .677 r
.57533 .55534 .57833 .56348 .58395 .56181 .58079 .54366 Mtetra
.565 .429 .655 r
.58079 .54366 .58395 .56181 .5895 .55565 .58645 .54448 Mtetra
.454 .403 .711 r
.58645 .54448 .5895 .55565 .59514 .55397 .5922 .54817 Mtetra
.84 .69 .697 r
.5922 .54817 .59514 .55397 .60074 .5499 .59765 .53723 Mtetra
.323 .301 .679 r
.59765 .53723 .60074 .5499 .60629 .5436 .60351 .54464 Mtetra
.986 .849 .62 r
.60351 .54464 .60629 .5436 .61173 .53351 .6088 .52728 Mtetra
.909 .547 .094 r
.6088 .52728 .61173 .53351 .61737 .53102 .6151 .54959 Mtetra
.597 .324 .474 r
.6151 .54959 .61737 .53102 .62348 .54453 .62094 .55231 Mtetra
.719 .38 .404 r
.62094 .55231 .62348 .54453 .62978 .56187 .62696 .5601 Mtetra
.95 .786 .644 r
.62696 .5601 .62978 .56187 .63581 .56872 .63222 .54266 Mtetra
.732 .526 .613 r
.63222 .54266 .63581 .56872 .6408 .54411 .63739 .52366 Mtetra
.733 .537 .626 r
.63739 .52366 .6408 .54411 .64599 .52696 .64265 .50876 Mtetra
.585 .443 .654 r
.64265 .50876 .64599 .52696 .65142 .51722 .64842 .50845 Mtetra
.607 .53 .742 r
.64842 .50845 .65142 .51722 .65703 .5122 .65418 .5076 Mtetra
.914 .533 .111 r
.65418 .5076 .65703 .5122 .66349 .52804 .66085 .52851 Mtetra
.14 0 0 r
.66085 .52851 .66349 .52804 .66927 .52631 .66672 .52862 Mtetra
.259 0 0 r
.66672 .52862 .66927 .52631 .67556 .53563 .67257 .52766 Mtetra
.118 .243 .718 r
.67257 .52766 .67556 .53563 .68191 .54503 .67881 .53509 Mtetra
.074 .173 .664 r
.67881 .53509 .68191 .54503 .6872 .53161 .68522 .54506 Mtetra
.835 .726 .199 r
.68522 .54506 .6872 .53161 .69295 .52802 .68937 .5082 Mtetra
.697 .513 .636 r
.68937 .5082 .69295 .52802 .69823 .51517 .69479 .49827 Mtetra
.656 .496 .655 r
.69479 .49827 .69823 .51517 .7034 .50066 .70045 .49329 Mtetra
0 0 .564 r
.70045 .49329 .7034 .50066 .70919 .498 .70701 .50456 Mtetra
.641 .277 .338 r
.70701 .50456 .70919 .498 .7156 .50606 .71319 .50819 Mtetra
.214 0 0 r
.71319 .50819 .7156 .50606 .72185 .51063 .71912 .50705 Mtetra
.764 .756 .845 r
.71912 .50705 .72185 .51063 .72786 .51065 .7249 .50312 Mtetra
.86 .676 .652 r
.7249 .50312 .72786 .51065 .73305 .49721 .72995 .48732 Mtetra
.674 .556 .713 r
.72995 .48732 .73305 .49721 .73884 .49369 .73573 .48365 Mtetra
.704 .571 .702 r
.73573 .48365 .73884 .49369 .74426 .48437 .74142 .47837 Mtetra
.342 .445 .822 r
.74142 .47837 .74426 .48437 .75059 .48866 .74769 .48179 Mtetra
.077 .246 .735 r
.74769 .48179 .75059 .48866 .75766 .50303 .75425 .489 Mtetra
.447 .376 .685 r
.75425 .489 .75766 .50303 .76364 .50124 .76073 .49427 Mtetra
.755 .402 0 r
.76073 .49427 .76364 .50124 .77021 .50724 .76838 .51524 Mtetra
.372 .052 .287 r
.76838 .51524 .77021 .50724 .77623 .50545 .7743 .51159 Mtetra
.682 .307 .329 r
.7743 .51159 .77623 .50545 .7818 .49769 .7809 .51692 Mtetra
.094 0 .352 r
.7809 .51692 .7818 .49769 .78732 .4894 .78555 .49673 Mtetra
.829 .759 .245 r
.78555 .49673 .78732 .4894 .79216 .4728 .78983 .47274 Mtetra
.295 0 0 r
.78983 .47274 .79216 .4728 .79839 .47352 .79615 .47437 Mtetra
.912 .977 .701 r
.79615 .47437 .79839 .47352 .80381 .46445 .80163 .46577 Mtetra
0 0 0 r
.80163 .46577 .80381 .46445 .81017 .46631 .80769 .46393 Mtetra
.683 .191 0 r
.80769 .46393 .81017 .46631 .81672 .47004 .81473 .47317 Mtetra
0 0 0 r
.81473 .47317 .81672 .47004 .82225 .46215 .82057 .46848 Mtetra
.198 0 .173 r
.82057 .46848 .82225 .46215 .8292 .46968 .82636 .46308 Mtetra
.742 .648 .756 r
.82636 .46308 .8292 .46968 .83477 .46215 .83217 .45806 Mtetra
.785 .746 .817 r
.83217 .45806 .83477 .46215 .84061 .4575 .83801 .45319 Mtetra
.25 .468 .875 r
.83801 .45319 .84061 .4575 .84777 .46614 .84463 .45647 Mtetra
0 0 .533 r
.84463 .45647 .84777 .46614 .85529 .47794 .85263 .4732 Mtetra
.941 .743 .607 r
.85263 .4732 .85529 .47794 .85945 .45618 .85693 .45255 Mtetra
.845 .438 0 r
.85693 .45255 .85945 .45618 .86555 .4537 .8654 .47286 Mtetra
.319 .107 .426 r
.8654 .47286 .86555 .4537 .87267 .46068 .87048 .46004 Mtetra
.759 .977 .918 r
.87048 .46004 .87267 .46068 .87874 .45755 .87647 .45594 Mtetra
.614 .87 .99 r
.87647 .45594 .87874 .45755 .88476 .45383 .8827 .45407 Mtetra
.931 .971 .711 r
.8827 .45407 .88476 .45383 .89097 .45173 .88817 .44519 Mtetra
.575 .567 .807 r
.88817 .44519 .89097 .45173 .89672 .44551 .89463 .44513 Mtetra
.971 .925 .683 r
.89463 .44513 .89672 .44551 .90212 .43635 .89985 .43424 Mtetra
.775 .877 .921 r
.89985 .43424 .90212 .43635 .90859 .43635 .90589 .43047 Mtetra
.508 .55 .834 r
.90589 .43047 .90859 .43635 .91579 .44224 .91252 .43157 Mtetra
.273 .301 .708 r
.91252 .43157 .91579 .44224 .92276 .44592 .92009 .44022 Mtetra
0 0 .305 r
.92009 .44022 .92276 .44592 .92999 .45144 .92896 .45902 Mtetra
0 0 .018 r
.92896 .45902 .92999 .45144 .93467 .43622 .9333 .44082 Mtetra
0 0 0 r
.9333 .44082 .93467 .43622 .93964 .4237 .93826 .42793 Mtetra
.311 0 .096 r
.93826 .42793 .93964 .4237 .94714 .43084 .94456 .42558 Mtetra
0 0 .356 r
.94456 .42558 .94714 .43084 .95601 .44795 .95341 .44264 Mtetra
.686 .668 .826 r
.95341 .44264 .95601 .44795 .9629 .44962 .95973 .44 Mtetra
.49 .685 .953 r
.3828 .59674 .38595 .59966 .39118 .59808 .38796 .59689 Mtetra
.909 .543 .327 r
.38796 .59689 .39118 .59808 .39589 .61066 .39259 .61132 Mtetra
.54 0 0 r
.39259 .61132 .39589 .61066 .40109 .61086 .39774 .61333 Mtetra
.722 .963 .697 r
.39774 .61333 .40109 .61086 .40649 .60572 .40318 .60766 Mtetra
.88 .992 .765 r
.40318 .60766 .40649 .60572 .41195 .59881 .40866 .60073 Mtetra
.84 .475 .362 r
.40866 .60073 .41195 .59881 .41649 .62112 .41355 .61171 Mtetra
.106 .196 .675 r
.41355 .61171 .41649 .62112 .42177 .62133 .4186 .61917 Mtetra
.896 .48 .183 r
.4186 .61917 .42177 .62133 .42684 .62962 .42359 .63032 Mtetra
.843 .442 .286 r
.42359 .63032 .42684 .62962 .43192 .63892 .42867 .63966 Mtetra
.883 .975 .835 r
.42867 .63966 .43192 .63892 .437 .65019 .4342 .63359 Mtetra
.81 .601 .62 r
.4342 .63359 .437 .65019 .44301 .624 .44023 .6073 Mtetra
.753 .562 .638 r
.44023 .6073 .44301 .624 .44888 .60143 .44593 .59238 Mtetra
.837 .646 .644 r
.44593 .59238 .44888 .60143 .45459 .58424 .45167 .57372 Mtetra
.759 .594 .673 r
.45167 .57372 .45459 .58424 .46021 .56949 .4572 .56395 Mtetra
0 .031 .601 r
.4572 .56395 .46021 .56949 .46535 .58019 .46241 .57095 Mtetra
0 0 .496 r
.46241 .57095 .46535 .58019 .47062 .58651 .46757 .58251 Mtetra
.738 .709 .824 r
.46757 .58251 .47062 .58651 .47595 .59028 .47301 .57912 Mtetra
.693 .551 .689 r
.47301 .57912 .47595 .59028 .48141 .58686 .47849 .57398 Mtetra
.577 .464 .689 r
.47849 .57398 .48141 .58686 .48685 .58523 .4839 .57409 Mtetra
.692 .551 .689 r
.4839 .57409 .48685 .58523 .4923 .5836 .48938 .56897 Mtetra
.578 .453 .674 r
.48938 .56897 .4923 .5836 .49774 .58378 .49482 .56906 Mtetra
.705 .537 .658 r
.49482 .56906 .49774 .58378 .50322 .58141 .50032 .56119 Mtetra
.577 .429 .644 r
.50032 .56119 .50322 .58141 .50874 .57252 .50578 .56128 Mtetra
.712 .562 .683 r
.50578 .56128 .50874 .57252 .51426 .56142 .51128 .5548 Mtetra
.742 .635 .741 r
.51128 .5548 .51426 .56142 .51975 .55444 .51677 .54963 Mtetra
.519 .588 .864 r
.51677 .54963 .51975 .55444 .52523 .5472 .52225 .55017 Mtetra
.671 .243 .221 r
.52225 .55017 .52523 .5472 .53071 .54513 .52776 .55384 Mtetra
.718 .395 .43 r
.52776 .55384 .53071 .54513 .53621 .54387 .5333 .56197 Mtetra
.627 .351 .481 r
.5333 .56197 .53621 .54387 .54173 .54459 .53888 .56689 Mtetra
.62 .355 .494 r
.53888 .56689 .54173 .54459 .54735 .55872 .54449 .57194 Mtetra
.608 .314 .444 r
.54449 .57194 .54735 .55872 .55296 .56249 .55012 .57486 Mtetra
.435 .151 .381 r
.55012 .57486 .55296 .56249 .55856 .56305 .55571 .57112 Mtetra
.534 .198 .345 r
.55571 .57112 .55856 .56305 .56413 .55955 .56135 .57128 Mtetra
.009 0 .203 r
.56135 .57128 .56413 .55955 .56974 .55869 .56686 .55961 Mtetra
0 0 0 r
.56686 .55961 .56974 .55869 .57533 .55534 .57249 .5582 Mtetra
.995 .863 .579 r
.57249 .5582 .57533 .55534 .58079 .54366 .57785 .53882 Mtetra
.869 .715 .688 r
.57785 .53882 .58079 .54366 .58645 .54448 .58329 .52632 Mtetra
.111 .113 .579 r
.58329 .52632 .58645 .54448 .5922 .54817 .58924 .54243 Mtetra
.521 .555 .831 r
.58924 .54243 .5922 .54817 .59765 .53723 .59495 .5432 Mtetra
.967 .862 .462 r
.59495 .5432 .59765 .53723 .60351 .54464 .60017 .52135 Mtetra
.471 .347 .63 r
.60017 .52135 .60351 .54464 .6088 .52728 .60603 .52814 Mtetra
.908 .546 .34 r
.60603 .52814 .6088 .52728 .6151 .54959 .61227 .54827 Mtetra
.485 0 0 r
.61227 .54827 .6151 .54959 .62094 .55231 .61815 .55209 Mtetra
.972 .829 .643 r
.61815 .55209 .62094 .55231 .62696 .5601 .62346 .53569 Mtetra
.619 .449 .63 r
.62346 .53569 .62696 .5601 .63222 .54266 .62914 .53213 Mtetra
.851 .645 .623 r
.62914 .53213 .63222 .54266 .63739 .52366 .63421 .50997 Mtetra
.464 .387 .685 r
.63421 .50997 .63739 .52366 .64265 .50876 .64014 .51428 Mtetra
.394 .015 .197 r
.64014 .51428 .64265 .50876 .64842 .50845 .64588 .51254 Mtetra
.794 .414 .337 r
.64588 .51254 .64842 .50845 .65418 .5076 .65207 .52243 Mtetra
.676 .38 .465 r
.65207 .52243 .65418 .5076 .66085 .52851 .65825 .53063 Mtetra
.731 .277 .174 r
.65825 .53063 .66085 .52851 .66672 .52862 .66437 .53618 Mtetra
.62 .272 .359 r
.66437 .53618 .66672 .52862 .67257 .52766 .67041 .53916 Mtetra
.197 0 .293 r
.67041 .53916 .67257 .52766 .67881 .53509 .67594 .53002 Mtetra
.909 .721 .635 r
.67594 .53002 .67881 .53509 .68522 .54506 .68098 .51094 Mtetra
.633 .445 .611 r
.68098 .51094 .68522 .54506 .68937 .5082 .68656 .50376 Mtetra
.891 .736 .683 r
.68656 .50376 .68937 .5082 .69479 .49827 .69183 .49067 Mtetra
.452 .464 .78 r
.69183 .49067 .69479 .49827 .70045 .49329 .69789 .49323 Mtetra
.807 .326 .058 r
.69789 .49323 .70045 .49329 .70701 .50456 .70429 .50157 Mtetra
0 .133 .643 r
.70429 .50157 .70701 .50456 .71319 .50819 .71057 .50703 Mtetra
.768 .926 .938 r
.71057 .50703 .71319 .50819 .71912 .50705 .71638 .50343 Mtetra
.922 .759 .663 r
.71638 .50343 .71912 .50705 .7249 .50312 .7215 .48833 Mtetra
.665 .511 .667 r
.7215 .48833 .7249 .50312 .72995 .48732 .72722 .48343 Mtetra
.91 .522 .103 r
.72722 .48343 .72995 .48732 .73573 .48365 .73464 .50552 Mtetra
.197 .015 .393 r
.73464 .50552 .73573 .48365 .74142 .47837 .73952 .48707 Mtetra
0 0 .14 r
.73952 .48707 .74142 .47837 .74769 .48179 .74485 .47591 Mtetra
.662 .626 .803 r
.74485 .47591 .74769 .48179 .75425 .489 .75078 .47385 Mtetra
.476 .387 .676 r
.75078 .47385 .75425 .489 .76073 .49427 .75718 .47842 Mtetra
.086 .12 .6 r
.75718 .47842 .76073 .49427 .76838 .51524 .7645 .49502 Mtetra
.437 .338 .645 r
.7645 .49502 .76838 .51524 .7743 .51159 .77125 .50305 Mtetra
0 .117 .649 r
.77125 .50305 .7743 .51159 .7809 .51692 .77828 .51392 Mtetra
.901 .803 .742 r
.77828 .51392 .7809 .51692 .78555 .49673 .78377 .50438 Mtetra
.762 .728 .2 r
.78377 .50438 .78555 .49673 .78983 .47274 .78824 .4822 Mtetra
.524 .203 .365 r
.78824 .4822 .78983 .47274 .79615 .47437 .79443 .48186 Mtetra
0 0 0 r
.79443 .48186 .79615 .47437 .80163 .46577 .79946 .46734 Mtetra
.88 .961 .625 r
.79946 .46734 .80163 .46577 .80769 .46393 .8049 .45808 Mtetra
0 .042 .611 r
.8049 .45808 .80769 .46393 .81473 .47317 .812 .46803 Mtetra
.802 .711 .764 r
.812 .46803 .81473 .47317 .82057 .46848 .81769 .46155 Mtetra
.578 .556 .794 r
.81769 .46155 .82057 .46848 .82636 .46308 .82396 .46145 Mtetra
.923 .887 .779 r
.82396 .46145 .82636 .46308 .83217 .45806 .8295 .45322 Mtetra
.484 .578 .874 r
.8295 .45322 .83217 .45806 .83801 .45319 .8359 .45427 Mtetra
0 0 0 r
.8359 .45427 .83801 .45319 .84463 .45647 .84205 .45241 Mtetra
.739 .735 .848 r
.84205 .45241 .84463 .45647 .85263 .4732 .84804 .44889 Mtetra
.56 .41 .635 r
.84804 .44889 .85263 .4732 .85693 .45255 .85455 .45038 Mtetra
.611 .106 0 r
.85455 .45038 .85693 .45255 .8654 .47286 .86177 .45857 Mtetra
.58 .463 .684 r
.86177 .45857 .8654 .47286 .87048 .46004 .86819 .45855 Mtetra
.862 .925 .868 r
.86819 .45855 .87048 .46004 .87647 .45594 .87403 .45296 Mtetra
.283 .58 .941 r
.87403 .45296 .87647 .45594 .8827 .45407 .88068 .45479 Mtetra
.979 .908 .584 r
.88068 .45479 .8827 .45407 .88817 .44519 .88563 .44095 Mtetra
.662 .699 .874 r
.88563 .44095 .88817 .44519 .89463 .44513 .89188 .43906 Mtetra
.842 .704 .71 r
.89188 .43906 .89463 .44513 .89985 .43424 .89724 .42924 Mtetra
.708 .685 .826 r
.89724 .42924 .89985 .43424 .90589 .43047 .90337 .42617 Mtetra
.491 .612 .899 r
.90337 .42617 .90589 .43047 .91252 .43157 .90996 .42691 Mtetra
.605 .652 .87 r
.90996 .42691 .91252 .43157 .92009 .44022 .91639 .42605 Mtetra
.338 .308 .679 r
.91639 .42605 .92009 .44022 .92896 .45902 .9241 .43553 Mtetra
.7 .505 .621 r
.9241 .43553 .92896 .45902 .9333 .44082 .92915 .42323 Mtetra
.544 .423 .665 r
.92915 .42323 .9333 .44082 .93826 .42793 .936 .4253 Mtetra
.654 .804 .955 r
.936 .4253 .93826 .42793 .94456 .42558 .94236 .42337 Mtetra
.741 .275 0 r
.94236 .42337 .94456 .42558 .95341 .44264 .9507 .4365 Mtetra
.822 .7 .73 r
.9507 .4365 .95341 .44264 .95973 .44 .95627 .42814 Mtetra
.592 .282 .413 r
.37907 .6069 .3828 .59674 .38796 .59689 .38419 .6087 Mtetra
.645 .348 .452 r
.38419 .6087 .38796 .59689 .39259 .61132 .38922 .61327 Mtetra
.389 0 0 r
.38922 .61327 .39259 .61132 .39774 .61333 .39445 .61349 Mtetra
.798 .971 .909 r
.39445 .61349 .39774 .61333 .40318 .60766 .39985 .60941 Mtetra
.766 .992 .784 r
.39985 .60941 .40318 .60766 .40866 .60073 .40529 .60421 Mtetra
.602 .871 .538 r
.40529 .60421 .40866 .60073 .41355 .61171 .41076 .59802 Mtetra
0 0 .493 r
.41076 .59802 .41355 .61171 .4186 .61917 .41556 .61261 Mtetra
.793 .42 0 r
.41556 .61261 .4186 .61917 .42359 .63032 .42048 .62558 Mtetra
.666 .236 0 r
.42048 .62558 .42359 .63032 .42867 .63966 .42558 .63408 Mtetra
.862 .69 .668 r
.42558 .63408 .42867 .63966 .4342 .63359 .43137 .61868 Mtetra
.83 .618 .616 r
.43137 .61868 .4342 .63359 .44023 .6073 .43749 .58939 Mtetra
.775 .573 .627 r
.43749 .58939 .44023 .6073 .44593 .59238 .4433 .56948 Mtetra
.664 .484 .631 r
.4433 .56948 .44593 .59238 .45167 .57372 .44879 .56188 Mtetra
.524 .438 .7 r
.44879 .56188 .45167 .57372 .4572 .56395 .45408 .56368 Mtetra
.717 .954 .95 r
.45408 .56368 .4572 .56395 .46241 .57095 .45948 .56067 Mtetra
0 0 .483 r
.45948 .56067 .46241 .57095 .46757 .58251 .46461 .57331 Mtetra
.705 .577 .709 r
.46461 .57331 .46757 .58251 .47301 .57912 .47007 .56846 Mtetra
.66 .535 .701 r
.47007 .56846 .47301 .57912 .47849 .57398 .47552 .56528 Mtetra
.633 .543 .735 r
.47552 .56528 .47849 .57398 .4839 .57409 .48095 .56363 Mtetra
.709 .566 .692 r
.48095 .56363 .4839 .57409 .48938 .56897 .48643 .55787 Mtetra
.549 .462 .709 r
.48643 .55787 .48938 .56897 .49482 .56906 .49185 .55886 Mtetra
.627 .52 .713 r
.49185 .55886 .49482 .56906 .50032 .56119 .49731 .5572 Mtetra
.725 .709 .835 r
.49731 .5572 .50032 .56119 .50578 .56128 .50279 .55416 Mtetra
.8 .651 .697 r
.50279 .55416 .50578 .56128 .51128 .5548 .50831 .54463 Mtetra
.553 .476 .722 r
.50831 .54463 .51128 .5548 .51677 .54963 .51378 .54541 Mtetra
0 0 .535 r
.51378 .54541 .51677 .54963 .52225 .55017 .51926 .55208 Mtetra
.821 .424 .298 r
.51926 .55208 .52225 .55017 .52776 .55384 .52477 .56137 Mtetra
.725 .391 .413 r
.52477 .56137 .52776 .55384 .5333 .56197 .53033 .56925 Mtetra
.629 .284 .367 r
.53033 .56925 .5333 .56197 .53888 .56689 .53592 .57236 Mtetra
.82 .482 .416 r
.53592 .57236 .53888 .56689 .54449 .57194 .54159 .58691 Mtetra
.564 .281 .445 r
.54159 .58691 .54449 .57194 .55012 .57486 .54724 .58761 Mtetra
.328 .059 .345 r
.54724 .58761 .55012 .57486 .55571 .57112 .55284 .58097 Mtetra
0 0 0 r
.55284 .58097 .55571 .57112 .56135 .57128 .55836 .56566 Mtetra
.827 .69 .712 r
.55836 .56566 .56135 .57128 .56686 .55961 .5639 .55618 Mtetra
.901 .749 .684 r
.5639 .55618 .56686 .55961 .57249 .5582 .56938 .54257 Mtetra
.611 .471 .667 r
.56938 .54257 .57249 .5582 .57785 .53882 .57501 .54087 Mtetra
.615 .132 .084 r
.57501 .54087 .57785 .53882 .58329 .52632 .58072 .5436 Mtetra
.573 .298 .462 r
.58072 .5436 .58329 .52632 .58924 .54243 .58643 .54475 Mtetra
.945 .953 .648 r
.58643 .54475 .58924 .54243 .59495 .5432 .59193 .53394 Mtetra
.846 .651 .639 r
.59193 .53394 .59495 .5432 .60017 .52135 .59723 .51524 Mtetra
0 .154 .692 r
.59723 .51524 .60017 .52135 .60603 .52814 .60309 .52232 Mtetra
0 0 .514 r
.60309 .52232 .60603 .52814 .61227 .54827 .60904 .5317 Mtetra
.609 .466 .662 r
.60904 .5317 .61227 .54827 .61815 .55209 .61475 .52998 Mtetra
.709 .516 .627 r
.61475 .52998 .61815 .55209 .62346 .53569 .62016 .51733 Mtetra
.632 .474 .65 r
.62016 .51733 .62346 .53569 .62914 .53213 .62582 .51379 Mtetra
.697 .518 .641 r
.62582 .51379 .62914 .53213 .63421 .50997 .63131 .50467 Mtetra
0 .184 .717 r
.63131 .50467 .63421 .50997 .64014 .51428 .63731 .51106 Mtetra
0 .123 .64 r
.63731 .51106 .64014 .51428 .64588 .51254 .64331 .51646 Mtetra
.874 .523 .383 r
.64331 .51646 .64588 .51254 .65207 .52243 .64989 .53645 Mtetra
.55 .263 .431 r
.64989 .53645 .65207 .52243 .65825 .53063 .65578 .53654 Mtetra
.802 .448 .387 r
.65578 .53654 .65825 .53063 .66437 .53618 .66222 .5494 Mtetra
.492 .206 .408 r
.66222 .5494 .66437 .53618 .67041 .53916 .66807 .54715 Mtetra
.89 .806 .325 r
.66807 .54715 .67041 .53916 .67594 .53002 .67295 .52265 Mtetra
.847 .672 .665 r
.67295 .52265 .67594 .53002 .68098 .51094 .67824 .50858 Mtetra
.935 .796 .683 r
.67824 .50858 .68098 .51094 .68656 .50376 .68354 .4952 Mtetra
.718 .596 .72 r
.68354 .4952 .68656 .50376 .69183 .49067 .68921 .49004 Mtetra
.663 .109 0 r
.68921 .49004 .69183 .49067 .69789 .49323 .69541 .49525 Mtetra
.582 .081 .03 r
.69541 .49525 .69789 .49323 .70429 .50157 .70151 .4977 Mtetra
.747 .737 .842 r
.70151 .4977 .70429 .50157 .71057 .50703 .7073 .49408 Mtetra
.751 .575 .657 r
.7073 .49408 .71057 .50703 .71638 .50343 .71269 .48332 Mtetra
.626 .465 .644 r
.71269 .48332 .71638 .50343 .7215 .48833 .71848 .4798 Mtetra
.766 .437 0 r
.71848 .4798 .7215 .48833 .72722 .48343 .72594 .5037 Mtetra
.684 .4 .485 r
.72594 .5037 .72722 .48343 .73464 .50552 .73275 .51539 Mtetra
0 0 .14 r
.73275 .51539 .73464 .50552 .73952 .48707 .738 .50196 Mtetra
.432 .168 .411 r
.738 .50196 .73952 .48707 .74485 .47591 .74377 .49676 Mtetra
.393 .162 .441 r
.74377 .49676 .74485 .47591 .75078 .47385 .74924 .48717 Mtetra
0 0 .224 r
.74924 .48717 .75078 .47385 .75718 .47842 .75415 .4697 Mtetra
0 .145 .662 r
.75415 .4697 .75718 .47842 .7645 .49502 .76099 .47999 Mtetra
.37 .318 .67 r
.76099 .47999 .7645 .49502 .77125 .50305 .76774 .48817 Mtetra
.488 .398 .68 r
.76774 .48817 .77125 .50305 .77828 .51392 .77423 .49218 Mtetra
.717 .521 .624 r
.77423 .49218 .77828 .51392 .78377 .50438 .7794 .47874 Mtetra
.635 .458 .626 r
.7794 .47874 .78377 .50438 .78824 .4822 .78517 .47322 Mtetra
.799 .635 .678 r
.78517 .47322 .78824 .4822 .79443 .48186 .79051 .46239 Mtetra
.625 .466 .647 r
.79051 .46239 .79443 .48186 .79946 .46734 .79645 .45907 Mtetra
.685 .586 .739 r
.79645 .45907 .79946 .46734 .8049 .45808 .80238 .45552 Mtetra
.266 .606 .954 r
.80238 .45552 .8049 .45808 .812 .46803 .80875 .457 Mtetra
.492 .435 .721 r
.80875 .457 .812 .46803 .81769 .46155 .81527 .45988 Mtetra
.385 .754 .992 r
.81527 .45988 .81769 .46155 .82396 .46145 .82156 .45979 Mtetra
.739 .899 .95 r
.82156 .45979 .82396 .46145 .8295 .45322 .82757 .4566 Mtetra
0 0 0 r
.82757 .4566 .8295 .45322 .8359 .45427 .83338 .45108 Mtetra
.514 .694 .95 r
.83338 .45108 .8359 .45427 .84205 .45241 .83971 .45103 Mtetra
.743 .236 0 r
.83971 .45103 .84205 .45241 .84804 .44889 .84698 .4603 Mtetra
.583 .269 .404 r
.84698 .4603 .84804 .44889 .85455 .45038 .85356 .46215 Mtetra
.444 .158 .383 r
.85356 .46215 .85455 .45038 .86177 .45857 .8596 .45841 Mtetra
.676 .975 .893 r
.8596 .45841 .86177 .45857 .86819 .45855 .86564 .45467 Mtetra
.812 .769 .812 r
.86564 .45467 .86819 .45855 .87403 .45296 .87149 .44906 Mtetra
.662 .718 .89 r
.87149 .44906 .87403 .45296 .88068 .45479 .87775 .44717 Mtetra
.849 .677 .669 r
.87775 .44717 .88068 .45479 .88563 .44095 .8828 .43419 Mtetra
.687 .621 .777 r
.8828 .43419 .88563 .44095 .89188 .43906 .88892 .4311 Mtetra
.728 .617 .734 r
.88892 .4311 .89188 .43906 .89724 .42924 .89481 .42583 Mtetra
0 0 .466 r
.89481 .42583 .89724 .42924 .90337 .42617 .90246 .43578 Mtetra
.187 0 .287 r
.90246 .43578 .90337 .42617 .90996 .42691 .90792 .42664 Mtetra
.781 .996 .864 r
.90792 .42664 .90996 .42691 .91639 .42605 .91387 .42172 Mtetra
.591 .663 .889 r
.91387 .42172 .91639 .42605 .9241 .43553 .92035 .42103 Mtetra
.587 .466 .683 r
.92035 .42103 .9241 .43553 .92915 .42323 .92687 .42065 Mtetra
.413 .692 .977 r
.92687 .42065 .92915 .42323 .936 .4253 .93353 .42112 Mtetra
.401 .57 .904 r
.93353 .42112 .936 .4253 .94236 .42337 .94037 .42286 Mtetra
.746 .987 .898 r
.94037 .42286 .94236 .42337 .9507 .4365 .94646 .41856 Mtetra
.552 .427 .663 r
.94646 .41856 .9507 .4365 .95627 .42814 .95333 .4202 Mtetra
.31 0 0 r
.3757 .60814 .37907 .6069 .38419 .6087 .3809 .60835 Mtetra
.523 .894 .968 r
.3809 .60835 .38419 .6087 .38922 .61327 .38618 .60676 Mtetra
.562 .547 .796 r
.38618 .60676 .38922 .61327 .39445 .61349 .3914 .60696 Mtetra
.704 .617 .757 r
.3914 .60696 .39445 .61349 .39985 .60941 .39678 .60346 Mtetra
.709 .633 .77 r
.39678 .60346 .39985 .60941 .40529 .60421 .40216 .60005 Mtetra
0 .014 .56 r
.40216 .60005 .40529 .60421 .41076 .59802 .40723 .60583 Mtetra
0 0 .067 r
.40723 .60583 .41076 .59802 .41556 .61261 .41276 .59882 Mtetra
0 0 .521 r
.41276 .59882 .41556 .61261 .42048 .62558 .41762 .61273 Mtetra
0 .048 .57 r
.41762 .61273 .42048 .62558 .42558 .63408 .4226 .62469 Mtetra
.857 .654 .627 r
.4226 .62469 .42558 .63408 .43137 .61868 .42867 .5997 Mtetra
.762 .562 .628 r
.42867 .5997 .43137 .61868 .43749 .58939 .43451 .58112 Mtetra
.82 .645 .665 r
.43451 .58112 .43749 .58939 .4433 .56948 .44019 .56709 Mtetra
.872 .783 .76 r
.44019 .56709 .4433 .56948 .44879 .56188 .44571 .55895 Mtetra
0 .321 .789 r
.44571 .55895 .44879 .56188 .45408 .56368 .45096 .56218 Mtetra
.473 0 0 r
.45096 .56218 .45408 .56368 .45948 .56067 .45625 .56553 Mtetra
.578 .188 .267 r
.45625 .56553 .45948 .56067 .46461 .57331 .46159 .56707 Mtetra
.574 .563 .804 r
.46159 .56707 .46461 .57331 .47007 .56846 .46698 .56701 Mtetra
.904 .823 .757 r
.46698 .56701 .47007 .56846 .47552 .56528 .47252 .55812 Mtetra
.712 .61 .741 r
.47252 .55812 .47552 .56528 .48095 .56363 .47798 .55397 Mtetra
.614 .519 .723 r
.47798 .55397 .48095 .56363 .48643 .55787 .48341 .55283 Mtetra
.653 .64 .824 r
.48341 .55283 .48643 .55787 .49185 .55886 .48886 .55121 Mtetra
.625 .557 .758 r
.48886 .55121 .49185 .55886 .49731 .5572 .49432 .54994 Mtetra
.764 .633 .716 r
.49432 .54994 .49731 .5572 .50279 .55416 .49983 .54301 Mtetra
.472 .413 .71 r
.49983 .54301 .50279 .55416 .50831 .54463 .50527 .54609 Mtetra
.335 0 0 r
.50527 .54609 .50831 .54463 .51378 .54541 .51076 .54632 Mtetra
.828 .407 .243 r
.51076 .54632 .51378 .54541 .51926 .55208 .51624 .55501 Mtetra
.653 .217 .201 r
.51624 .55501 .51926 .55208 .52477 .56137 .52176 .55828 Mtetra
.858 .414 .009 r
.52176 .55828 .52477 .56137 .53033 .56925 .52733 .56925 Mtetra
.777 .291 .072 r
.52733 .56925 .53033 .56925 .53592 .57236 .53293 .57552 Mtetra
.853 .498 .38 r
.53293 .57552 .53592 .57236 .54159 .58691 .53861 .59049 Mtetra
0 0 0 r
.53861 .59049 .54159 .58691 .54724 .58761 .54423 .58453 Mtetra
.545 .707 .946 r
.54423 .58453 .54724 .58761 .55284 .58097 .5499 .5842 Mtetra
.996 .864 .577 r
.5499 .5842 .55284 .58097 .55836 .56566 .5554 .56439 Mtetra
.952 .782 .635 r
.5554 .56439 .55836 .56566 .5639 .55618 .56086 .54519 Mtetra
.729 .575 .682 r
.56086 .54519 .5639 .55618 .56938 .54257 .56642 .53772 Mtetra
0 .234 .752 r
.56642 .53772 .56938 .54257 .57501 .54087 .57215 .54305 Mtetra
.623 .147 .102 r
.57215 .54305 .57501 .54087 .58072 .5436 .57788 .5459 Mtetra
.519 .027 .027 r
.57788 .5459 .58072 .5436 .58643 .54475 .58361 .54725 Mtetra
.98 .915 .617 r
.58361 .54725 .58643 .54475 .59193 .53394 .58906 .53332 Mtetra
.959 .833 .676 r
.58906 .53332 .59193 .53394 .59723 .51524 .59449 .51939 Mtetra
0 0 0 r
.59449 .51939 .59723 .51524 .60309 .52232 .60005 .51264 Mtetra
.538 .476 .734 r
.60005 .51264 .60309 .52232 .60904 .5317 .6058 .51379 Mtetra
.633 .476 .652 r
.6058 .51379 .60904 .5317 .61475 .52998 .61144 .51026 Mtetra
.648 .48 .643 r
.61144 .51026 .61475 .52998 .62016 .51733 .61705 .5051 Mtetra
.541 .449 .7 r
.61705 .5051 .62016 .51733 .62582 .51379 .62285 .50651 Mtetra
.691 .602 .752 r
.62285 .50651 .62582 .51379 .63131 .50467 .62852 .50314 Mtetra
.58 .847 .995 r
.62852 .50314 .63131 .50467 .63731 .51106 .63427 .50177 Mtetra
.162 .242 .7 r
.63427 .50177 .63731 .51106 .64331 .51646 .64034 .50958 Mtetra
.742 .384 0 r
.64034 .50958 .64331 .51646 .64989 .53645 .64679 .52643 Mtetra
0 .113 .633 r
.64679 .52643 .64989 .53645 .65578 .53654 .6531 .53732 Mtetra
.862 .445 .23 r
.6531 .53732 .65578 .53654 .66222 .5494 .6595 .54937 Mtetra
.982 .789 .568 r
.6595 .54937 .66222 .5494 .66807 .54715 .66436 .52295 Mtetra
.709 .512 .62 r
.66436 .52295 .66807 .54715 .67295 .52265 .66969 .50897 Mtetra
.784 .591 .64 r
.66969 .50897 .67295 .52265 .67824 .50858 .67493 .49369 Mtetra
.389 .33 .67 r
.67493 .49369 .67824 .50858 .68354 .4952 .68118 .50082 Mtetra
.86 .84 .373 r
.68118 .50082 .68354 .4952 .68921 .49004 .68629 .48366 Mtetra
.715 .35 0 r
.68629 .48366 .68921 .49004 .69541 .49525 .69305 .49987 Mtetra
0 0 0 r
.69305 .49987 .69541 .49525 .70151 .4977 .69856 .4906 Mtetra
.802 .66 .705 r
.69856 .4906 .70151 .4977 .7073 .49408 .70406 .4816 Mtetra
.65 .517 .688 r
.70406 .4816 .7073 .49408 .71269 .48332 .70986 .47827 Mtetra
0 0 .356 r
.70986 .47827 .71269 .48332 .71848 .4798 .71655 .49006 Mtetra
.678 .352 .415 r
.71655 .49006 .71848 .4798 .72594 .5037 .72299 .4967 Mtetra
0 .192 .706 r
.72299 .4967 .72594 .5037 .73275 .51539 .72956 .50468 Mtetra
.521 .456 .724 r
.72956 .50468 .73275 .51539 .738 .50196 .73579 .50654 Mtetra
.635 .225 .249 r
.73579 .50654 .738 .50196 .74377 .49676 .74214 .50987 Mtetra
0 0 .152 r
.74214 .50987 .74377 .49676 .74924 .48717 .74695 .48975 Mtetra
.963 .902 .533 r
.74695 .48975 .74924 .48717 .75415 .4697 .75205 .47457 Mtetra
0 0 0 r
.75205 .47457 .75415 .4697 .76099 .47999 .75751 .46512 Mtetra
0 0 .531 r
.75751 .46512 .76099 .47999 .76774 .48817 .76512 .48537 Mtetra
.897 .814 .758 r
.76512 .48537 .76774 .48817 .77423 .49218 .77066 .4766 Mtetra
.774 .576 .632 r
.77066 .4766 .77423 .49218 .7794 .47874 .77565 .46092 Mtetra
.573 .438 .659 r
.77565 .46092 .7794 .47874 .78517 .47322 .78187 .46122 Mtetra
.512 .437 .708 r
.78187 .46122 .78517 .47322 .79051 .46239 .78827 .46366 Mtetra
.804 .977 .687 r
.78827 .46366 .79051 .46239 .79645 .45907 .79392 .45658 Mtetra
.77 .836 .903 r
.79392 .45658 .79645 .45907 .80238 .45552 .79985 .45292 Mtetra
.382 .671 .973 r
.79985 .45292 .80238 .45552 .80875 .457 .80617 .45363 Mtetra
.764 .778 .864 r
.80617 .45363 .80875 .457 .81527 .45988 .8121 .44978 Mtetra
.588 .505 .729 r
.8121 .44978 .81527 .45988 .82156 .45979 .81836 .44946 Mtetra
.743 .592 .688 r
.81836 .44946 .82156 .45979 .82757 .4566 .82395 .44167 Mtetra
.275 .258 .658 r
.82395 .44167 .82757 .4566 .83338 .45108 .83132 .45296 Mtetra
.889 .486 .245 r
.83132 .45296 .83338 .45108 .83971 .45103 .83944 .47138 Mtetra
.344 .126 .432 r
.83944 .47138 .83971 .45103 .84698 .4603 .84467 .45926 Mtetra
.562 .893 .985 r
.84467 .45926 .84698 .4603 .85356 .46215 .85089 .45738 Mtetra
.28 .465 .863 r
.85089 .45738 .85356 .46215 .8596 .45841 .85766 .46075 Mtetra
.729 .885 .487 r
.85766 .46075 .8596 .45841 .86564 .45467 .86318 .45174 Mtetra
.917 .821 .736 r
.86318 .45174 .86564 .45467 .87149 .44906 .8686 .44186 Mtetra
.701 .618 .761 r
.8686 .44186 .87149 .44906 .87775 .44717 .87466 .43811 Mtetra
.672 .569 .732 r
.87466 .43811 .87775 .44717 .8828 .43419 .88077 .43478 Mtetra
.949 .95 .646 r
.88077 .43478 .8828 .43419 .88892 .4311 .88607 .42412 Mtetra
.692 .619 .77 r
.88607 .42412 .88892 .4311 .89481 .42583 .89218 .42078 Mtetra
0 0 .535 r
.89218 .42078 .89481 .42583 .90246 .43578 .90001 .43224 Mtetra
.822 .794 .825 r
.90001 .43224 .90246 .43578 .90792 .42664 .9059 .42663 Mtetra
.802 1 .823 r
.9059 .42663 .90792 .42664 .91387 .42172 .91179 .42106 Mtetra
.714 .973 .928 r
.91179 .42106 .91387 .42172 .92035 .42103 .91791 .41735 Mtetra
.539 .676 .927 r
.91791 .41735 .92035 .42103 .92687 .42065 .92448 .41719 Mtetra
.757 .783 .875 r
.92448 .41719 .92687 .42065 .93353 .42112 .93062 .41347 Mtetra
.419 .449 .785 r
.93062 .41347 .93353 .42112 .94037 .42286 .93768 .41695 Mtetra
.717 .662 .794 r
.93768 .41695 .94037 .42286 .94646 .41856 .94385 .41322 Mtetra
.464 .55 .859 r
.94385 .41322 .94646 .41856 .95333 .4202 .95072 .41479 Mtetra
.655 .65 .833 r
.37257 .60343 .3757 .60814 .3809 .60835 .37784 .60184 Mtetra
.67 .602 .77 r
.37784 .60184 .3809 .60835 .38618 .60676 .38316 .59951 Mtetra
.64 .571 .761 r
.38316 .59951 .38618 .60676 .3914 .60696 .38845 .59791 Mtetra
.458 .432 .742 r
.38845 .59791 .3914 .60696 .39678 .60346 .3936 .6005 Mtetra
.757 .762 .857 r
.3936 .6005 .39678 .60346 .40216 .60005 .39899 .59709 Mtetra
.841 .381 0 r
.39899 .59709 .40216 .60005 .40723 .60583 .40395 .60581 Mtetra
.673 .141 0 r
.40395 .60581 .40723 .60583 .41276 .59882 .40913 .60957 Mtetra
.744 .443 .472 r
.40913 .60957 .41276 .59882 .41762 .61273 .41407 .6215 Mtetra
0 0 0 r
.41407 .6215 .41762 .61273 .4226 .62469 .41978 .60996 Mtetra
.771 .581 .641 r
.41978 .60996 .4226 .62469 .42867 .5997 .42559 .59433 Mtetra
.822 .686 .714 r
.42559 .59433 .42867 .5997 .43451 .58112 .43119 .58503 Mtetra
.98 .914 .614 r
.43119 .58503 .43451 .58112 .44019 .56709 .43692 .57026 Mtetra
.974 .926 .645 r
.43692 .57026 .44019 .56709 .44571 .55895 .44258 .55733 Mtetra
.678 .851 .965 r
.44258 .55733 .44571 .55895 .45096 .56218 .44796 .55531 Mtetra
0 .128 .669 r
.44796 .55531 .45096 .56218 .45625 .56553 .45316 .5623 Mtetra
.457 .653 .944 r
.45316 .5623 .45625 .56553 .46159 .56707 .45852 .5628 Mtetra
.815 .715 .755 r
.45852 .5628 .46159 .56707 .46698 .56701 .46404 .55583 Mtetra
.716 .565 .682 r
.46404 .55583 .46698 .56701 .47252 .55812 .46955 .54916 Mtetra
.632 .539 .731 r
.46955 .54916 .47252 .55812 .47798 .55397 .47498 .5475 Mtetra
.611 .576 .79 r
.47498 .5475 .47798 .55397 .48341 .55283 .4804 .54669 Mtetra
.648 .603 .79 r
.4804 .54669 .48341 .55283 .48886 .55121 .48585 .54502 Mtetra
.648 .602 .789 r
.48585 .54502 .48886 .55121 .49432 .54994 .49131 .54335 Mtetra
.692 .613 .763 r
.49131 .54335 .49432 .54994 .49983 .54301 .4968 .54024 Mtetra
.775 .783 .859 r
.4968 .54024 .49983 .54301 .50527 .54609 .50229 .53642 Mtetra
.41 .394 .73 r
.50229 .53642 .50527 .54609 .51076 .54632 .50775 .54025 Mtetra
.77 .387 0 r
.50775 .54025 .51076 .54632 .51624 .55501 .51321 .55346 Mtetra
0 .274 .651 r
.51321 .55346 .51624 .55501 .52176 .55828 .51874 .55618 Mtetra
0 .245 .676 r
.51874 .55618 .52176 .55828 .52733 .56925 .52431 .55949 Mtetra
.175 .24 .692 r
.52431 .55949 .52733 .56925 .53293 .57552 .5299 .56692 Mtetra
.901 .565 .082 r
.5299 .56692 .53293 .57552 .53861 .59049 .53559 .59109 Mtetra
.347 0 0 r
.53559 .59109 .53861 .59049 .54423 .58453 .54127 .5921 Mtetra
0 0 0 r
.54127 .5921 .54423 .58453 .5499 .5842 .5469 .58296 Mtetra
.956 .763 .603 r
.5469 .58296 .5499 .5842 .5554 .56439 .55238 .55759 Mtetra
.907 .691 .599 r
.55238 .55759 .5554 .56439 .56086 .54519 .55774 .52627 Mtetra
0 0 .515 r
.55774 .52627 .56086 .54519 .56642 .53772 .5636 .54626 Mtetra
.689 .357 .409 r
.5636 .54626 .56642 .53772 .57215 .54305 .56937 .55257 Mtetra
.393 .084 .317 r
.56937 .55257 .57215 .54305 .57788 .5459 .57502 .54904 Mtetra
0 0 0 r
.57502 .54904 .57788 .5459 .58361 .54725 .58068 .54512 Mtetra
.929 .788 .684 r
.58068 .54512 .58361 .54725 .58906 .53332 .58616 .53138 Mtetra
.831 .85 .861 r
.58616 .53138 .58906 .53332 .59449 .51939 .59179 .52643 Mtetra
.225 0 .178 r
.59179 .52643 .59449 .51939 .60005 .51264 .59742 .52166 Mtetra
.274 0 .262 r
.59742 .52166 .60005 .51264 .6058 .51379 .60304 .51615 Mtetra
.129 0 0 r
.60304 .51615 .6058 .51379 .61144 .51026 .60875 .51441 Mtetra
0 0 0 r
.60875 .51441 .61144 .51026 .61705 .5051 .61438 .50949 Mtetra
.156 0 0 r
.61438 .50949 .61705 .5051 .62285 .50651 .62007 .50609 Mtetra
.838 .962 .888 r
.62007 .50609 .62285 .50651 .62852 .50314 .62571 .5012 Mtetra
.813 .857 .882 r
.62571 .5012 .62852 .50314 .63427 .50177 .63137 .4968 Mtetra
0 0 .36 r
.63137 .4968 .63427 .50177 .64034 .50958 .63753 .50732 Mtetra
0 .138 .599 r
.63753 .50732 .64034 .50958 .64679 .52643 .64354 .51181 Mtetra
.432 .36 .676 r
.64354 .51181 .64679 .52643 .6531 .53732 .64962 .51737 Mtetra
.563 .422 .648 r
.64962 .51737 .6531 .53732 .6595 .54937 .65555 .51825 Mtetra
.708 .502 .607 r
.65555 .51825 .6595 .54937 .66436 .52295 .66074 .50028 Mtetra
.62 .454 .635 r
.66074 .50028 .66436 .52295 .66969 .50897 .6665 .49677 Mtetra
.726 .565 .672 r
.6665 .49677 .66969 .50897 .67493 .49369 .67206 .48871 Mtetra
.781 .701 .775 r
.67206 .48871 .67493 .49369 .68118 .50082 .67773 .4832 Mtetra
.514 .398 .659 r
.67773 .4832 .68118 .50082 .68629 .48366 .68382 .48652 Mtetra
0 0 0 r
.68382 .48652 .68629 .48366 .69305 .49987 .68961 .48308 Mtetra
.633 .481 .659 r
.68961 .48308 .69305 .49987 .69856 .4906 .6954 .47975 Mtetra
.587 .493 .715 r
.6954 .47975 .69856 .4906 .70406 .4816 .70137 .47945 Mtetra
.185 .593 .942 r
.70137 .47945 .70406 .4816 .70986 .47827 .70745 .4809 Mtetra
.737 .294 .199 r
.70745 .4809 .70986 .47827 .71655 .49006 .71382 .48703 Mtetra
0 0 .512 r
.71382 .48703 .71655 .49006 .72299 .4967 .72028 .49386 Mtetra
0 .408 .853 r
.72028 .49386 .72299 .4967 .72956 .50468 .72656 .4971 Mtetra
.787 .648 .708 r
.72656 .4971 .72956 .50468 .73579 .50654 .73215 .48871 Mtetra
.586 .447 .658 r
.73215 .48871 .73579 .50654 .74214 .50987 .73823 .48821 Mtetra
.701 .511 .628 r
.73823 .48821 .74214 .50987 .74695 .48975 .74361 .47681 Mtetra
.686 .537 .677 r
.74361 .47681 .74695 .48975 .75205 .47457 .74936 .47119 Mtetra
.653 .739 .912 r
.74936 .47119 .75205 .47457 .75751 .46512 .75538 .4695 Mtetra
.586 .166 .212 r
.75538 .4695 .75751 .46512 .76512 .48537 .76169 .47164 Mtetra
.643 .505 .68 r
.76169 .47164 .76512 .48537 .77066 .4766 .76763 .46837 Mtetra
.783 .637 .7 r
.76763 .46837 .77066 .4766 .77565 .46092 .77317 .45969 Mtetra
.592 .887 .991 r
.77317 .45969 .77565 .46092 .78187 .46122 .77923 .45784 Mtetra
.694 .755 .899 r
.77923 .45784 .78187 .46122 .78827 .46366 .78526 .45546 Mtetra
.595 .539 .761 r
.78526 .45546 .78827 .46366 .79392 .45658 .79144 .45491 Mtetra
.766 .9 .936 r
.79144 .45491 .79392 .45658 .79985 .45292 .7974 .45134 Mtetra
.457 .8 .999 r
.7974 .45134 .79985 .45292 .80617 .45363 .80361 .4507 Mtetra
.882 .817 .78 r
.80361 .4507 .80617 .45363 .8121 .44978 .80922 .44297 Mtetra
.381 .446 .803 r
.80922 .44297 .8121 .44978 .81836 .44946 .81581 .44641 Mtetra
.762 .8 .884 r
.81581 .44641 .81836 .44946 .82395 .44167 .8218 .44275 Mtetra
.779 .294 .071 r
.8218 .44275 .82395 .44167 .83132 .45296 .82887 .45078 Mtetra
0 .405 .83 r
.82887 .45078 .83132 .45296 .83944 .47138 .83554 .45391 Mtetra
.602 .46 .66 r
.83554 .45391 .83944 .47138 .84467 .45926 .84178 .45241 Mtetra
.581 .563 .799 r
.84178 .45241 .84467 .45926 .85089 .45738 .84818 .45219 Mtetra
.866 .732 .713 r
.84818 .45219 .85089 .45738 .85766 .46075 .85357 .44193 Mtetra
.63 .473 .65 r
.85357 .44193 .85766 .46075 .86318 .45174 .85963 .43823 Mtetra
.723 .556 .664 r
.85963 .43823 .86318 .45174 .8686 .44186 .86518 .42965 Mtetra
.704 .554 .681 r
.86518 .42965 .8686 .44186 .87466 .43811 .87094 .42321 Mtetra
.372 .324 .675 r
.87094 .42321 .87466 .43811 .88077 .43478 .87832 .43166 Mtetra
0 .114 .64 r
.87832 .43166 .88077 .43478 .88607 .42412 .88558 .43849 Mtetra
.612 .31 .434 r
.88558 .43849 .88607 .42412 .89218 .42078 .89254 .44231 Mtetra
.555 .291 .47 r
.89254 .44231 .89218 .42078 .90001 .43224 .8991 .44227 Mtetra
.478 .167 .36 r
.8991 .44227 .90001 .43224 .9059 .42663 .90546 .44034 Mtetra
.034 0 .306 r
.90546 .44034 .9059 .42663 .91179 .42106 .91 .42298 Mtetra
0 0 0 r
.91 .42298 .91179 .42106 .91791 .41735 .91589 .4171 Mtetra
.875 .993 .801 r
.91589 .4171 .91791 .41735 .92448 .41719 .92167 .41041 Mtetra
.387 .453 .807 r
.92167 .41041 .92448 .41719 .93062 .41347 .92872 .41395 Mtetra
.535 0 0 r
.92872 .41395 .93062 .41347 .93768 .41695 .93581 .41754 Mtetra
.661 .109 0 r
.93581 .41754 .93768 .41695 .94385 .41322 .9432 .42315 Mtetra
.57 .241 .371 r
.9432 .42315 .94385 .41322 .95072 .41479 .9501 .42464 Mtetra
.861 .937 .87 r
.36922 .60335 .37257 .60343 .37784 .60184 .37466 .59815 Mtetra
.857 .728 .72 r
.37466 .59815 .37784 .60184 .38316 .59951 .38031 .58812 Mtetra
.621 .504 .698 r
.38031 .58812 .38316 .59951 .38845 .59791 .3856 .58651 Mtetra
.069 .135 .625 r
.3856 .58651 .38845 .59791 .3936 .6005 .39047 .59573 Mtetra
.655 .649 .832 r
.39047 .59573 .3936 .6005 .39899 .59709 .3958 .59412 Mtetra
.651 .742 .916 r
.3958 .59412 .39899 .59709 .40395 .60581 .40113 .59264 Mtetra
.178 .191 .635 r
.40113 .59264 .40395 .60581 .40913 .60957 .4061 .60186 Mtetra
.93 .587 .146 r
.4061 .60186 .40913 .60957 .41407 .6215 .41075 .62219 Mtetra
.959 .85 .692 r
.41075 .62219 .41407 .6215 .41978 .60996 .41654 .6088 Mtetra
.905 .831 .764 r
.41654 .6088 .41978 .60996 .42559 .59433 .42217 .60004 Mtetra
.926 .916 .53 r
.42217 .60004 .42559 .59433 .43119 .58503 .42795 .58547 Mtetra
.959 .825 .669 r
.42795 .58547 .43119 .58503 .43692 .57026 .43372 .56998 Mtetra
.792 .953 .922 r
.43372 .56998 .43692 .57026 .44258 .55733 .43917 .56612 Mtetra
0 0 0 r
.43917 .56612 .44258 .55733 .44796 .55531 .44482 .55391 Mtetra
.909 .525 .278 r
.44482 .55391 .44796 .55531 .45316 .5623 .44986 .56795 Mtetra
0 0 0 r
.44986 .56795 .45316 .5623 .45852 .5628 .4554 .56092 Mtetra
.869 .819 .797 r
.4554 .56092 .45852 .5628 .46404 .55583 .46093 .55406 Mtetra
.909 .797 .725 r
.46093 .55406 .46404 .55583 .46955 .54916 .46652 .54335 Mtetra
.601 .59 .813 r
.46652 .54335 .46955 .54916 .47498 .5475 .47193 .54274 Mtetra
.335 .496 .87 r
.47193 .54274 .47498 .5475 .4804 .54669 .47732 .54499 Mtetra
.875 .833 .801 r
.47732 .54499 .4804 .54669 .48585 .54502 .48285 .53816 Mtetra
.237 .349 .776 r
.48285 .53816 .48585 .54502 .49131 .54335 .48824 .54262 Mtetra
.902 .886 .806 r
.48824 .54262 .49131 .54335 .4968 .54024 .49377 .53549 Mtetra
.368 .515 .873 r
.49377 .53549 .4968 .54024 .50229 .53642 .49923 .53749 Mtetra
.645 .136 .02 r
.49923 .53749 .50229 .53642 .50775 .54025 .5047 .54077 Mtetra
.492 0 0 r
.5047 .54077 .50775 .54025 .51321 .55346 .51021 .54272 Mtetra
.054 .14 .637 r
.51021 .54272 .51321 .55346 .51874 .55618 .51572 .55238 Mtetra
.734 .725 .842 r
.51572 .55238 .51874 .55618 .52431 .55949 .52129 .54915 Mtetra
0 0 .424 r
.52129 .54915 .52431 .55949 .5299 .56692 .52687 .56381 Mtetra
.952 .617 .342 r
.52687 .56381 .5299 .56692 .53559 .59109 .53256 .59357 Mtetra
.63 .168 .137 r
.53256 .59357 .53559 .59109 .54127 .5921 .53826 .59651 Mtetra
.992 .874 .548 r
.53826 .59651 .54127 .5921 .5469 .58296 .54385 .57614 Mtetra
.92 .692 .578 r
.54385 .57614 .5469 .58296 .55238 .55759 .54924 .53438 Mtetra
.563 .411 .633 r
.54924 .53438 .55238 .55759 .55774 .52627 .55489 .53531 Mtetra
.754 .431 .437 r
.55489 .53531 .55774 .52627 .5636 .54626 .56067 .54677 Mtetra
.295 0 0 r
.56067 .54677 .5636 .54626 .56937 .55257 .56637 .54759 Mtetra
.55 .603 .859 r
.56637 .54759 .56937 .55257 .57502 .54904 .57209 .5477 Mtetra
.9 .865 .796 r
.57209 .5477 .57502 .54904 .58068 .54512 .5777 .54019 Mtetra
.877 .716 .679 r
.5777 .54019 .58068 .54512 .58616 .53138 .5832 .52656 Mtetra
.724 .683 .81 r
.5832 .52656 .58616 .53138 .59179 .52643 .58886 .52315 Mtetra
.794 .768 .83 r
.58886 .52315 .59179 .52643 .59742 .52166 .59451 .51847 Mtetra
.717 .759 .885 r
.59451 .51847 .59742 .52166 .60304 .51615 .6002 .51578 Mtetra
.575 0 0 r
.6002 .51578 .60304 .51615 .60875 .51441 .60605 .51936 Mtetra
.133 0 .026 r
.60605 .51936 .60875 .51441 .61438 .50949 .61173 .51532 Mtetra
0 0 0 r
.61173 .51532 .61438 .50949 .62007 .50609 .61733 .50812 Mtetra
.61733 .50812 .62007 .50609 .62571 .5012 .62308 .50592 Mtetra
.62308 .50592 .62571 .5012 .63137 .4968 .62868 .49912 Mtetra
.569 .873 .574 r
.62868 .49912 .63137 .4968 .63753 .50732 .63433 .49354 Mtetra
.594 .472 .683 r
.63433 .49354 .63753 .50732 .64354 .51181 .64013 .4928 Mtetra
.53 .403 .651 r
.64013 .4928 .64354 .51181 .64962 .51737 .64608 .49543 Mtetra
.648 .474 .635 r
.64608 .49543 .64962 .51737 .65555 .51825 .65173 .48954 Mtetra
.562 .401 .62 r
.65173 .48954 .65555 .51825 .66074 .50028 .65766 .49068 Mtetra
.705 .576 .708 r
.65766 .49068 .66074 .50028 .6665 .49677 .66335 .4856 Mtetra
.658 .533 .7 r
.66335 .4856 .6665 .49677 .67206 .48871 .66912 .48227 Mtetra
.571 .563 .806 r
.66912 .48227 .67206 .48871 .67773 .4832 .67504 .48223 Mtetra
.061 .597 .856 r
.67504 .48223 .67773 .4832 .68382 .48652 .68102 .48302 Mtetra
.685 .738 .891 r
.68102 .48302 .68382 .48652 .68961 .48308 .68688 .48085 Mtetra
.034 .485 .882 r
.68688 .48085 .68961 .48308 .6954 .47975 .69298 .48314 Mtetra
.419 0 .056 r
.69298 .48314 .6954 .47975 .70137 .47945 .69897 .48291 Mtetra
.436 0 .071 r
.69897 .48291 .70137 .47945 .70745 .4809 .70499 .48285 Mtetra
0 0 0 r
.70499 .48285 .70745 .4809 .71382 .48703 .71084 .47962 Mtetra
.12 .262 .736 r
.71084 .47962 .71382 .48703 .72028 .49386 .7173 .4866 Mtetra
0 0 .357 r
.7173 .4866 .72028 .49386 .72656 .4971 .72432 .50205 Mtetra
.917 .851 .405 r
.72432 .50205 .72656 .4971 .73215 .48871 .72927 .48296 Mtetra
.871 .71 .68 r
.72927 .48296 .73215 .48871 .73823 .48821 .73457 .47008 Mtetra
.607 .459 .655 r
.73457 .47008 .73823 .48821 .74361 .47681 .74056 .46821 Mtetra
.413 .422 .76 r
.74056 .46821 .74361 .47681 .74936 .47119 .74694 .47191 Mtetra
.795 .997 .786 r
.74694 .47191 .74936 .47119 .75538 .4695 .75269 .46611 Mtetra
0 .062 .595 r
.75269 .46611 .75538 .4695 .76169 .47164 .75934 .4729 Mtetra
.914 .97 .671 r
.75934 .4729 .76169 .47164 .76763 .46837 .76487 .46362 Mtetra
.816 .727 .766 r
.76487 .46362 .76763 .46837 .77317 .45969 .77056 .45684 Mtetra
.711 .796 .917 r
.77056 .45684 .77317 .45969 .77923 .45784 .77656 .4542 Mtetra
.571 .69 .922 r
.77656 .4542 .77923 .45784 .78526 .45546 .78275 .45366 Mtetra
.662 .865 .976 r
.78275 .45366 .78526 .45546 .79144 .45491 .78881 .45147 Mtetra
.529 .684 .937 r
.78881 .45147 .79144 .45491 .7974 .45134 .79506 .45136 Mtetra
.786 .997 .859 r
.79506 .45136 .7974 .45134 .80361 .4507 .80092 .44641 Mtetra
.798 .742 .802 r
.80092 .44641 .80361 .4507 .80922 .44297 .80674 .44095 Mtetra
.69 .858 .962 r
.80674 .44095 .80922 .44297 .81581 .44641 .81283 .43849 Mtetra
.539 .513 .775 r
.81283 .43849 .81581 .44641 .8218 .44275 .81922 .43937 Mtetra
0 .304 .794 r
.81922 .43937 .8218 .44275 .82887 .45078 .826 .44414 Mtetra
.648 .604 .791 r
.826 .44414 .82887 .45078 .83554 .45391 .83219 .44225 Mtetra
.409 .377 .711 r
.83219 .44225 .83554 .45391 .84178 .45241 .8391 .44768 Mtetra
.791 .728 .793 r
.8391 .44768 .84178 .45241 .84818 .45219 .84498 .44213 Mtetra
.708 .577 .705 r
.84498 .44213 .84818 .45219 .85357 .44193 .85085 .43662 Mtetra
.776 .702 .782 r
.85085 .43662 .85357 .44193 .85963 .43823 .85674 .4312 Mtetra
.755 .648 .743 r
.85674 .4312 .85963 .43823 .86518 .42965 .86258 .42533 Mtetra
0 .277 .78 r
.86258 .42533 .86518 .42965 .87094 .42321 .86966 .43119 Mtetra
.671 .31 .353 r
.86966 .43119 .87094 .42321 .87832 .43166 .87677 .43687 Mtetra
.683 .276 .268 r
.87677 .43687 .87832 .43166 .88558 .43849 .88389 .44227 Mtetra
.822 .405 .254 r
.88389 .44227 .88558 .43849 .89254 .44231 .89184 .45478 Mtetra
.671 .347 .418 r
.89184 .45478 .89254 .44231 .8991 .44227 .89929 .46219 Mtetra
.359 .137 .435 r
.89929 .46219 .8991 .44227 .90546 .44034 .90461 .45078 Mtetra
0 0 .111 r
.90461 .45078 .90546 .44034 .91 .42298 .90871 .4292 Mtetra
0 0 0 r
.90871 .4292 .91 .42298 .91589 .4171 .91339 .41304 Mtetra
.299 .517 .898 r
.91339 .41304 .91589 .4171 .92167 .41041 .92032 .4157 Mtetra
.07 0 .084 r
.92032 .4157 .92167 .41041 .92872 .41395 .92618 .4094 Mtetra
.458 .585 .893 r
.92618 .4094 .92872 .41395 .93581 .41754 .93298 .41063 Mtetra
0 0 .539 r
.93298 .41063 .93581 .41754 .9432 .42315 .94154 .42533 Mtetra
.467 0 0 r
.94154 .42533 .9432 .42315 .9501 .42464 .94844 .42664 Mtetra
.427 .074 .26 r
.36553 .61036 .36922 .60335 .37466 .59815 .37083 .60876 Mtetra
.179 0 .226 r
.37083 .60876 .37466 .59815 .38031 .58812 .37639 .60172 Mtetra
.503 .217 .412 r
.37639 .60172 .38031 .58812 .3856 .58651 .38171 .60011 Mtetra
.591 .3 .444 r
.38171 .60011 .3856 .58651 .39047 .59573 .38689 .60213 Mtetra
.257 0 .144 r
.38689 .60213 .39047 .59573 .3958 .59412 .39231 .5987 Mtetra
.984 .905 .603 r
.39231 .5987 .3958 .59412 .40113 .59264 .3982 .58251 Mtetra
.886 .571 .066 r
.3982 .58251 .40113 .59264 .4061 .60186 .40271 .60434 Mtetra
.747 .338 .276 r
.40271 .60434 .4061 .60186 .41075 .62219 .40785 .61004 Mtetra
.779 .597 .654 r
.40785 .61004 .41075 .62219 .41654 .6088 .41366 .59628 Mtetra
.73 .565 .667 r
.41366 .59628 .41654 .6088 .42217 .60004 .41928 .58758 Mtetra
.746 .575 .663 r
.41928 .58758 .42217 .60004 .42795 .58547 .42494 .57737 Mtetra
.817 .646 .67 r
.42494 .57737 .42795 .58547 .43372 .56998 .43066 .5642 Mtetra
.753 .657 .754 r
.43066 .5642 .43372 .56998 .43917 .56612 .43614 .55908 Mtetra
.761 .635 .721 r
.43614 .55908 .43917 .56612 .44482 .55391 .44166 .55246 Mtetra
.207 .667 .945 r
.44166 .55246 .44482 .55391 .44986 .56795 .44702 .55302 Mtetra
.575 .449 .671 r
.44702 .55302 .44986 .56795 .4554 .56092 .45239 .55312 Mtetra
.777 .632 .7 r
.45239 .55312 .4554 .56092 .46093 .55406 .45796 .54467 Mtetra
.317 .339 .725 r
.45796 .54467 .46093 .55406 .46652 .54335 .46327 .54969 Mtetra
.561 .197 .309 r
.46327 .54969 .46652 .54335 .47193 .54274 .46867 .55078 Mtetra
.595 .258 .369 r
.46867 .55078 .47193 .54274 .47732 .54499 .47408 .55276 Mtetra
.444 .104 .293 r
.47408 .55276 .47732 .54499 .48285 .53816 .47957 .55109 Mtetra
0 0 .11 r
.47957 .55109 .48285 .53816 .48824 .54262 .48522 .53638 Mtetra
.529 .542 .812 r
.48522 .53638 .48824 .54262 .49377 .53549 .49068 .53706 Mtetra
.582 .075 .013 r
.49068 .53706 .49377 .53549 .49923 .53749 .49614 .53934 Mtetra
.397 .814 .622 r
.49614 .53934 .49923 .53749 .5047 .54077 .50167 .53587 Mtetra
.869 .467 .008 r
.50167 .53587 .5047 .54077 .51021 .54272 .50712 .54983 Mtetra
.43 .079 .267 r
.50712 .54983 .51021 .54272 .51572 .55238 .51268 .54814 Mtetra
.866 .727 .707 r
.51268 .54814 .51572 .55238 .52129 .54915 .51827 .53712 Mtetra
0 0 .192 r
.51827 .53712 .52129 .54915 .52687 .56381 .52383 .55881 Mtetra
.952 .602 .254 r
.52383 .55881 .52687 .56381 .53256 .59357 .52949 .58384 Mtetra
.45 .422 .736 r
.52949 .58384 .53256 .59357 .53826 .59651 .53518 .58693 Mtetra
.685 .565 .714 r
.53518 .58693 .53826 .59651 .54385 .57614 .54087 .5829 Mtetra
.558 .197 .312 r
.54087 .5829 .54385 .57614 .54924 .53438 .54659 .58397 Mtetra
.564 .331 .521 r
.54659 .58397 .54924 .53438 .55489 .53531 .55232 .58413 Mtetra
.52 .294 .513 r
.55232 .58413 .55489 .53531 .56067 .54677 .55801 .57782 Mtetra
.414 .192 .466 r
.55801 .57782 .56067 .54677 .56637 .54759 .56364 .56621 Mtetra
.359 .117 .405 r
.56364 .56621 .56637 .54759 .57209 .5477 .56928 .55743 Mtetra
0 0 0 r
.56928 .55743 .57209 .5477 .5777 .54019 .57478 .54027 Mtetra
.972 .842 .656 r
.57478 .54027 .5777 .54019 .5832 .52656 .58028 .52494 Mtetra
.927 .824 .724 r
.58028 .52494 .5832 .52656 .58886 .52315 .58582 .51411 Mtetra
.678 .568 .723 r
.58582 .51411 .58886 .52315 .59451 .51847 .59149 .51056 Mtetra
0 0 .386 r
.59149 .51056 .59451 .51847 .6002 .51578 .59753 .52416 Mtetra
.588 .25 .364 r
.59753 .52416 .6002 .51578 .60605 .51936 .60337 .52607 Mtetra
.246 0 .172 r
.60337 .52607 .60605 .51936 .61173 .51532 .60908 .52181 Mtetra
0 0 0 r
.60908 .52181 .61173 .51532 .61733 .50812 .61464 .51221 Mtetra
.814 .895 .477 r
.61464 .51221 .61733 .50812 .62308 .50592 .62014 .50093 Mtetra
.845 .714 .719 r
.62014 .50093 .62308 .50592 .62868 .49912 .62568 .49138 Mtetra
.512 .497 .776 r
.62568 .49138 .62868 .49912 .63433 .49354 .63154 .49272 Mtetra
.729 .94 .954 r
.63154 .49272 .63433 .49354 .64013 .4928 .63728 .48955 Mtetra
.723 .762 .883 r
.63728 .48955 .64013 .4928 .64608 .49543 .64304 .48672 Mtetra
.602 .53 .747 r
.64304 .48672 .64608 .49543 .65173 .48954 .64888 .48598 Mtetra
.663 .725 .896 r
.64888 .48598 .65173 .48954 .65766 .49068 .6547 .48419 Mtetra
.604 .58 .799 r
.6547 .48419 .65766 .49068 .66335 .4856 .66058 .48345 Mtetra
.806 .849 .882 r
.66058 .48345 .66335 .4856 .66912 .48227 .66631 .47911 Mtetra
.516 .693 .949 r
.66631 .47911 .66912 .48227 .67504 .48223 .67224 .47903 Mtetra
.366 .615 .947 r
.67224 .47903 .67504 .48223 .68102 .48302 .67825 .48022 Mtetra
.856 .417 0 r
.67825 .48022 .68102 .48302 .68688 .48085 .68487 .49371 Mtetra
.355 .087 .362 r
.68487 .49371 .68688 .48085 .69298 .48314 .69057 .48733 Mtetra
0 0 0 r
.69057 .48733 .69298 .48314 .69897 .48291 .69621 .47998 Mtetra
.71 .784 .91 r
.69621 .47998 .69897 .48291 .70499 .48285 .7021 .47739 Mtetra
.168 .363 .813 r
.7021 .47739 .70499 .48285 .71084 .47962 .7084 .48201 Mtetra
.756 .31 .193 r
.7084 .48201 .71084 .47962 .7173 .4866 .71487 .48881 Mtetra
.112 0 0 r
.71487 .48881 .7173 .4866 .72432 .50205 .72086 .48699 Mtetra
.816 .604 .616 r
.72086 .48699 .72432 .50205 .72927 .48296 .72566 .46527 Mtetra
.614 .465 .656 r
.72566 .46527 .72927 .48296 .73457 .47008 .73161 .46295 Mtetra
.525 .522 .795 r
.73161 .46295 .73457 .47008 .74056 .46821 .73779 .46394 Mtetra
.494 .615 .9 r
.73779 .46394 .74056 .46821 .74694 .47191 .74397 .46455 Mtetra
.267 .36 .773 r
.74397 .46455 .74694 .47191 .75269 .46611 .75048 .46978 Mtetra
.285 0 .011 r
.75048 .46978 .75269 .46611 .75934 .4729 .75654 .46793 Mtetra
.868 .731 .709 r
.75654 .46793 .75934 .4729 .76487 .46362 .76197 .45726 Mtetra
.523 .543 .818 r
.76197 .45726 .76487 .46362 .77056 .45684 .76824 .45812 Mtetra
.943 .953 .643 r
.76824 .45812 .77056 .45684 .77656 .4542 .77365 .44746 Mtetra
.522 .532 .807 r
.77365 .44746 .77656 .4542 .78275 .45366 .77996 .44843 Mtetra
.799 .708 .765 r
.77996 .44843 .78275 .45366 .78881 .45147 .78569 .44202 Mtetra
.601 .522 .738 r
.78569 .44202 .78881 .45147 .79506 .45136 .79188 .44124 Mtetra
.503 .454 .735 r
.79188 .44124 .79506 .45136 .80092 .44641 .79835 .44346 Mtetra
.781 .81 .876 r
.79835 .44346 .80092 .44641 .80674 .44095 .8043 .43938 Mtetra
.41 .778 .994 r
.8043 .43938 .80674 .44095 .81283 .43849 .81058 .43902 Mtetra
0 0 0 r
.81058 .43902 .81283 .43849 .81922 .43937 .81679 .43764 Mtetra
.433 0 0 r
.81679 .43764 .81922 .43937 .826 .44414 .8236 .44267 Mtetra
.003 .517 .859 r
.8236 .44267 .826 .44414 .83219 .44225 .83015 .44447 Mtetra
.5 0 0 r
.83015 .44447 .83219 .44225 .8391 .44768 .8367 .44602 Mtetra
.955 .868 .712 r
.8367 .44602 .8391 .44768 .84498 .44213 .84206 .43501 Mtetra
.81 .67 .709 r
.84206 .43501 .84498 .44213 .85085 .43662 .84759 .42595 Mtetra
.395 .38 .724 r
.84759 .42595 .85085 .43662 .85674 .4312 .85457 .43128 Mtetra
.82 .341 .026 r
.85457 .43128 .85674 .4312 .86258 .42533 .86216 .44221 Mtetra
.598 .309 .449 r
.86216 .44221 .86258 .42533 .86966 .43119 .86901 .44543 Mtetra
.412 .148 .401 r
.86901 .44543 .86966 .43119 .87677 .43687 .87492 .43957 Mtetra
.749 .288 .153 r
.87492 .43957 .87677 .43687 .88389 .44227 .88227 .4469 Mtetra
.777 .366 .27 r
.88227 .4469 .88389 .44227 .89184 .45478 .88996 .45681 Mtetra
.975 .851 .455 r
.88996 .45681 .89184 .45478 .89929 .46219 .89429 .43655 Mtetra
.719 .513 .61 r
.89429 .43655 .89929 .46219 .90461 .45078 .89901 .42024 Mtetra
.61 .433 .617 r
.89901 .42024 .90461 .45078 .90871 .4292 .90514 .41621 Mtetra
.218 .24 .67 r
.90514 .41621 .90871 .4292 .91339 .41304 .91315 .42798 Mtetra
.451 .184 .416 r
.91315 .42798 .91339 .41304 .92032 .4157 .91924 .4233 Mtetra
0 0 .054 r
.91924 .4233 .92032 .4157 .92618 .4094 .92396 .40745 Mtetra
.945 .883 .741 r
.92396 .40745 .92618 .4094 .93298 .41063 .9294 .39776 Mtetra
0 0 .546 r
.9294 .39776 .93298 .41063 .94154 .42533 .93882 .41934 Mtetra
.77 .686 .771 r
.93882 .41934 .94154 .42533 .94844 .42664 .94482 .41369 Mtetra
.83 .811 .832 r
.36223 .60832 .36553 .61036 .37083 .60876 .36771 .60308 Mtetra
.778 .666 .739 r
.36771 .60308 .37083 .60876 .37639 .60172 .37324 .59663 Mtetra
.545 .59 .85 r
.37324 .59663 .37639 .60172 .38171 .60011 .37849 .59684 Mtetra
.661 .726 .898 r
.37849 .59684 .38171 .60011 .38689 .60213 .38382 .59522 Mtetra
.739 .627 .735 r
.38382 .59522 .38689 .60213 .39231 .5987 .38932 .58996 Mtetra
.153 .244 .705 r
.38932 .58996 .39231 .5987 .3982 .58251 .39437 .59622 Mtetra
.652 .36 .464 r
.39437 .59622 .3982 .58251 .40271 .60434 .39948 .6019 Mtetra
.764 .798 .88 r
.39948 .6019 .40271 .60434 .40785 .61004 .40494 .59848 Mtetra
.739 .576 .673 r
.40494 .59848 .40785 .61004 .41366 .59628 .41058 .58972 Mtetra
.828 .668 .685 r
.41058 .58972 .41366 .59628 .41928 .58758 .41632 .57777 Mtetra
.783 .614 .671 r
.41632 .57777 .41928 .58758 .42494 .57737 .42201 .56633 Mtetra
.694 .553 .69 r
.42201 .56633 .42494 .57737 .43066 .5642 .42751 .56115 Mtetra
.854 .76 .758 r
.42751 .56115 .43066 .5642 .43614 .55908 .43308 .55328 Mtetra
.458 .518 .832 r
.43308 .55328 .43614 .55908 .44166 .55246 .4384 .55479 Mtetra
0 0 0 r
.4384 .55479 .44166 .55246 .44702 .55302 .44386 .55124 Mtetra
0 .473 .837 r
.44386 .55124 .44702 .55302 .45239 .55312 .44921 .55303 Mtetra
.882 .938 .848 r
.44921 .55303 .45239 .55312 .45796 .54467 .45474 .54713 Mtetra
0 0 0 r
.45474 .54713 .45796 .54467 .46327 .54969 .46022 .54386 Mtetra
.59 .586 .816 r
.46022 .54386 .46327 .54969 .46867 .55078 .46565 .54345 Mtetra
0 0 .413 r
.46565 .54345 .46867 .55078 .47408 .55276 .47092 .55431 Mtetra
.444 .857 .696 r
.47092 .55431 .47408 .55276 .47957 .55109 .47644 .55104 Mtetra
.956 .834 .682 r
.47644 .55104 .47957 .55109 .48522 .53638 .4821 .53712 Mtetra
.304 .793 .758 r
.4821 .53712 .48522 .53638 .49068 .53706 .4876 .53529 Mtetra
.801 .852 .888 r
.4876 .53529 .49068 .53706 .49614 .53934 .49313 .53123 Mtetra
.676 .578 .738 r
.49313 .53123 .49614 .53934 .50167 .53587 .49866 .52816 Mtetra
0 .055 .614 r
.49866 .52816 .50167 .53587 .50712 .54983 .50412 .53686 Mtetra
.391 .342 .683 r
.50412 .53686 .50712 .54983 .51268 .54814 .50964 .5424 Mtetra
.538 .566 .831 r
.50964 .5424 .51268 .54814 .51827 .53712 .51521 .54284 Mtetra
.803 .462 .41 r
.51521 .54284 .51827 .53712 .52383 .55881 .52078 .55567 Mtetra
.929 .546 .215 r
.52078 .55567 .52383 .55881 .52949 .58384 .52642 .57328 Mtetra
0 .092 .615 r
.52642 .57328 .52949 .58384 .53518 .58693 .53212 .58382 Mtetra
0 .32 .793 r
.53212 .58382 .53518 .58693 .54087 .5829 .53784 .58742 Mtetra
.544 .132 .211 r
.53784 .58742 .54087 .5829 .54659 .58397 .54358 .58854 Mtetra
.125 0 0 r
.54358 .58854 .54659 .58397 .55232 .58413 .54931 .58497 Mtetra
.931 .961 .766 r
.54931 .58497 .55232 .58413 .55801 .57782 .555 .57667 Mtetra
.845 .903 .877 r
.555 .57667 .55801 .57782 .56364 .56621 .56071 .5716 Mtetra
0 0 0 r
.56071 .5716 .56364 .56621 .56928 .55743 .56638 .56245 Mtetra
.998 .844 .514 r
.56638 .56245 .56928 .55743 .57478 .54027 .5718 .53655 Mtetra
.89 .748 .698 r
.5718 .53655 .57478 .54027 .58028 .52494 .57736 .52435 Mtetra
.808 .951 .913 r
.57736 .52435 .58028 .52494 .58582 .51411 .58304 .52006 Mtetra
.27 0 .145 r
.58304 .52006 .58582 .51411 .59149 .51056 .58873 .51667 Mtetra
.781 .43 .391 r
.58873 .51667 .59149 .51056 .59753 .52416 .59474 .52775 Mtetra
.72 .309 .268 r
.59474 .52775 .59753 .52416 .60337 .52607 .60067 .53338 Mtetra
0 0 0 r
.60067 .53338 .60337 .52607 .60908 .52181 .60624 .52227 Mtetra
.422 .867 .829 r
.60624 .52227 .60908 .52181 .61464 .51221 .61202 .52 Mtetra
0 0 0 r
.61202 .52 .61464 .51221 .62014 .50093 .61753 .5076 Mtetra
.61753 .5076 .62014 .50093 .62568 .49138 .62309 .49805 Mtetra
.654 .292 .345 r
.62309 .49805 .62568 .49138 .63154 .49272 .62907 .50222 Mtetra
.532 .208 .364 r
.62907 .50222 .63154 .49272 .63728 .48955 .63495 .50227 Mtetra
.362 .089 .358 r
.63495 .50227 .63728 .48955 .64304 .48672 .64064 .49635 Mtetra
.533 .21 .366 r
.64064 .49635 .64304 .48672 .64888 .48598 .64654 .49639 Mtetra
.226 0 .275 r
.64654 .49639 .64888 .48598 .6547 .48419 .65217 .48894 Mtetra
0 0 0 r
.65217 .48894 .6547 .48419 .66058 .48345 .6578 .48148 Mtetra
.456 .763 .995 r
.6578 .48148 .66058 .48345 .66631 .47911 .66372 .48119 Mtetra
.338 0 0 r
.66372 .48119 .66631 .47911 .67224 .47903 .66966 .48107 Mtetra
.393 0 0 r
.66966 .48107 .67224 .47903 .67825 .48022 .67565 .48144 Mtetra
.902 .524 .302 r
.67565 .48144 .67825 .48022 .68487 .49371 .68256 .50088 Mtetra
.01 0 .098 r
.68256 .50088 .68487 .49371 .69057 .48733 .68822 .49314 Mtetra
0 0 0 r
.68822 .49314 .69057 .48733 .69621 .47998 .69363 .48064 Mtetra
.659 .123 0 r
.69363 .48064 .69621 .47998 .7021 .47739 .6999 .48498 Mtetra
.739 .387 .384 r
.6999 .48498 .7021 .47739 .7084 .48201 .70648 .49421 Mtetra
.507 .209 .395 r
.70648 .49421 .7084 .48201 .71487 .48881 .71252 .49291 Mtetra
.952 .871 .462 r
.71252 .49291 .71487 .48881 .72086 .48699 .71756 .47433 Mtetra
.808 .61 .635 r
.71756 .47433 .72086 .48699 .72566 .46527 .72265 .45748 Mtetra
.64 .571 .761 r
.72265 .45748 .72566 .46527 .73161 .46295 .72863 .45563 Mtetra
0 .124 .663 r
.72863 .45563 .73161 .46295 .73779 .46394 .73535 .46493 Mtetra
0 0 0 r
.73535 .46493 .73779 .46394 .74397 .46455 .74138 .46308 Mtetra
0 .348 .727 r
.74138 .46308 .74397 .46455 .75048 .46978 .74773 .46585 Mtetra
.539 .659 .913 r
.74773 .46585 .75048 .46978 .75654 .46793 .75392 .46578 Mtetra
.951 .818 .676 r
.75392 .46578 .75654 .46793 .76197 .45726 .75917 .45226 Mtetra
.438 .549 .871 r
.75917 .45226 .76197 .45726 .76824 .45812 .7655 .45386 Mtetra
.854 .753 .751 r
.7655 .45386 .76824 .45812 .77365 .44746 .77111 .4456 Mtetra
.095 .557 .909 r
.77111 .4456 .77365 .44746 .77996 .44843 .77748 .44728 Mtetra
.901 .926 .825 r
.77748 .44728 .77996 .44843 .78569 .44202 .7832 .44045 Mtetra
.851 .911 .874 r
.7832 .44045 .78569 .44202 .79188 .44124 .78903 .43512 Mtetra
.584 .585 .819 r
.78903 .43512 .79188 .44124 .79835 .44346 .79528 .43476 Mtetra
.646 .56 .743 r
.79528 .43476 .79835 .44346 .8043 .43938 .80139 .43252 Mtetra
.568 .555 .8 r
.80139 .43252 .8043 .43938 .81058 .43902 .80771 .43256 Mtetra
.367 .451 .815 r
.80771 .43256 .81058 .43902 .81679 .43764 .81434 .43594 Mtetra
.606 .073 0 r
.81434 .43594 .81679 .43764 .8236 .44267 .82134 .44287 Mtetra
.039 0 0 r
.82134 .44287 .8236 .44267 .83015 .44447 .82773 .44282 Mtetra
.5 0 0 r
.82773 .44282 .83015 .44447 .8367 .44602 .83468 .44847 Mtetra
.75 .891 .491 r
.83468 .44847 .8367 .44602 .84206 .43501 .84023 .43907 Mtetra
.656 .221 .203 r
.84023 .43907 .84206 .43501 .84759 .42595 .8471 .44327 Mtetra
.629 .336 .454 r
.8471 .44327 .84759 .42595 .85457 .43128 .85415 .44891 Mtetra
.633 .34 .455 r
.85415 .44891 .85457 .43128 .86216 .44221 .86129 .45496 Mtetra
.539 .238 .405 r
.86129 .45496 .86216 .44221 .86901 .44543 .86783 .45489 Mtetra
.15 0 .257 r
.86783 .45489 .86901 .44543 .87492 .43957 .87341 .44557 Mtetra
.323 0 .19 r
.87341 .44557 .87492 .43957 .88227 .4469 .87963 .44229 Mtetra
.418 .561 .891 r
.87963 .44229 .88227 .4469 .88996 .45681 .88641 .44398 Mtetra
.803 .607 .637 r
.88641 .44398 .88996 .45681 .89429 .43655 .89128 .4285 Mtetra
.867 .681 .649 r
.89128 .4285 .89429 .43655 .89901 .42024 .89612 .4131 Mtetra
.44 .477 .801 r
.89612 .4131 .89901 .42024 .90514 .41621 .90304 .41579 Mtetra
.62 .057 0 r
.90304 .41579 .90514 .41621 .91315 .42798 .91037 .4217 Mtetra
.569 .578 .822 r
.91037 .4217 .91315 .42798 .91924 .4233 .91702 .42162 Mtetra
.97 .875 .686 r
.91702 .42162 .91924 .4233 .92396 .40745 .92223 .40963 Mtetra
.91 .876 .446 r
.92223 .40963 .92396 .40745 .9294 .39776 .92704 .39461 Mtetra
.593 .143 0 r
.92704 .39461 .9294 .39776 .93882 .41934 .93514 .40586 Mtetra
.514 .429 .697 r
.93514 .40586 .93882 .41934 .94482 .41369 .94221 .40857 Mtetra
.568 .5 .739 r
.35925 .59931 .36223 .60832 .36771 .60308 .36448 .59951 Mtetra
.886 .726 .677 r
.36448 .59951 .36771 .60308 .37324 .59663 .37041 .5845 Mtetra
.713 .556 .675 r
.37041 .5845 .37324 .59663 .37849 .59684 .37596 .57748 Mtetra
.499 .374 .641 r
.37596 .57748 .37849 .59684 .38382 .59522 .38105 .58125 Mtetra
.613 .48 .676 r
.38105 .58125 .38382 .59522 .38932 .58996 .38639 .57962 Mtetra
.501 .44 .721 r
.38639 .57962 .38932 .58996 .39437 .59622 .3916 .58161 Mtetra
.611 .475 .672 r
.3916 .58161 .39437 .59622 .39948 .6019 .39696 .57997 Mtetra
.572 .419 .636 r
.39696 .57997 .39948 .6019 .40494 .59848 .40227 .58015 Mtetra
.604 .453 .65 r
.40227 .58015 .40494 .59848 .41058 .58972 .40766 .57851 Mtetra
.749 .584 .672 r
.40766 .57851 .41058 .58972 .41632 .57777 .41331 .56914 Mtetra
.718 .592 .713 r
.41331 .56914 .41632 .57777 .42201 .56633 .41882 .56388 Mtetra
.881 .777 .743 r
.41882 .56388 .42201 .56633 .42751 .56115 .42445 .55462 Mtetra
.628 .583 .785 r
.42445 .55462 .42751 .56115 .43308 .55328 .42984 .55338 Mtetra
.733 .973 .928 r
.42984 .55338 .43308 .55328 .4384 .55479 .4353 .54994 Mtetra
0 .174 .71 r
.4353 .54994 .4384 .55479 .44386 .55124 .44055 .55521 Mtetra
0 0 0 r
.44055 .55521 .44386 .55124 .44921 .55303 .44608 .54994 Mtetra
.783 .764 .836 r
.44608 .54994 .44921 .55303 .45474 .54713 .45158 .54569 Mtetra
.837 .865 .864 r
.45158 .54569 .45474 .54713 .46022 .54386 .4571 .54076 Mtetra
.673 .745 .905 r
.4571 .54076 .46022 .54386 .46565 .54345 .46257 .53893 Mtetra
0 .104 .652 r
.46257 .53893 .46565 .54345 .47092 .55431 .46792 .54463 Mtetra
.671 .553 .713 r
.46792 .54463 .47092 .55431 .47644 .55104 .47344 .5412 Mtetra
.729 .585 .694 r
.47344 .5412 .47644 .55104 .4821 .53712 .47901 .5345 Mtetra
0 .29 .748 r
.47901 .5345 .4821 .53712 .4876 .53529 .48445 .53781 Mtetra
.954 .951 .671 r
.48445 .53781 .4876 .53529 .49313 .53123 .49008 .52698 Mtetra
.72 .699 .83 r
.49008 .52698 .49313 .53123 .49866 .52816 .49561 .52395 Mtetra
.709 .698 .838 r
.49561 .52395 .49866 .52816 .50412 .53686 .50115 .52122 Mtetra
0 0 .523 r
.50115 .52122 .50412 .53686 .50964 .5424 .50659 .53744 Mtetra
.766 .35 0 r
.50659 .53744 .50964 .5424 .51521 .54284 .51212 .54875 Mtetra
.785 .44 .403 r
.51212 .54875 .51521 .54284 .52078 .55567 .51771 .55995 Mtetra
.735 .351 .324 r
.51771 .55995 .52078 .55567 .52642 .57328 .52335 .56643 Mtetra
0 0 .296 r
.52335 .56643 .52642 .57328 .53212 .58382 .52904 .57903 Mtetra
.787 .365 0 r
.52904 .57903 .53212 .58382 .53784 .58742 .53479 .59088 Mtetra
.252 0 0 r
.53479 .59088 .53784 .58742 .54358 .58854 .54053 .58918 Mtetra
.584 .034 0 r
.54053 .58918 .54358 .58854 .54931 .58497 .54632 .59208 Mtetra
0 0 0 r
.54632 .59208 .54931 .58497 .555 .57667 .55202 .582 Mtetra
.63 .792 .351 r
.55202 .582 .555 .57667 .56071 .5716 .55771 .57167 Mtetra
.96 .88 .709 r
.55771 .57167 .56071 .5716 .56638 .56245 .56337 .56003 Mtetra
.948 .746 .598 r
.56337 .56003 .56638 .56245 .5718 .53655 .5688 .53286 Mtetra
.858 .754 .746 r
.5688 .53286 .5718 .53655 .57736 .52435 .57444 .52428 Mtetra
.922 .936 .796 r
.57444 .52428 .57736 .52435 .58304 .52006 .58007 .51667 Mtetra
.745 .756 .861 r
.58007 .51667 .58304 .52006 .58873 .51667 .58578 .51331 Mtetra
.893 .479 .081 r
.58578 .51331 .58873 .51667 .59474 .52775 .59185 .5282 Mtetra
.835 .393 .179 r
.59185 .5282 .59474 .52775 .60067 .53338 .59788 .53757 Mtetra
.659 .836 .421 r
.59788 .53757 .60067 .53338 .60624 .52227 .60352 .52838 Mtetra
0 0 0 r
.60352 .52838 .60624 .52227 .61202 .52 .60907 .51607 Mtetra
.661 .705 .879 r
.60907 .51607 .61202 .52 .61753 .5076 .61488 .5143 Mtetra
0 0 0 r
.61488 .5143 .61753 .5076 .62309 .49805 .62042 .50254 Mtetra
.331 0 .091 r
.62042 .50254 .62309 .49805 .62907 .50222 .62623 .50076 Mtetra
0 .458 .803 r
.62623 .50076 .62907 .50222 .63495 .50227 .63218 .50266 Mtetra
.374 0 0 r
.63218 .50266 .63495 .50227 .64064 .49635 .63814 .50415 Mtetra
.194 0 .191 r
.63814 .50415 .64064 .49635 .64654 .49639 .64386 .49831 Mtetra
0 0 0 r
.64386 .49831 .64654 .49639 .65217 .48894 .64967 .49496 Mtetra
.64967 .49496 .65217 .48894 .6578 .48148 .65514 .48296 Mtetra
.653 .947 .709 r
.65514 .48296 .6578 .48148 .66372 .48119 .66088 .47785 Mtetra
.363 .605 .941 r
.66088 .47785 .66372 .48119 .66966 .48107 .66689 .47913 Mtetra
.719 .859 .948 r
.66689 .47913 .66966 .48107 .67565 .48144 .67275 .47638 Mtetra
0 0 .409 r
.67275 .47638 .67565 .48144 .68256 .50088 .67923 .48695 Mtetra
.593 .472 .683 r
.67923 .48695 .68256 .50088 .68822 .49314 .68523 .48617 Mtetra
.7 .619 .762 r
.68523 .48617 .68822 .49314 .69363 .48064 .69109 .48256 Mtetra
.33 0 0 r
.69109 .48256 .69363 .48064 .6999 .48498 .69715 .48253 Mtetra
0 .076 .557 r
.69715 .48253 .6999 .48498 .70648 .49421 .70353 .48797 Mtetra
.861 .492 0 r
.70353 .48797 .70648 .49421 .71252 .49291 .71091 .51077 Mtetra
0 0 0 r
.71091 .51077 .71252 .49291 .71756 .47433 .71482 .47151 Mtetra
.925 .796 .699 r
.71482 .47151 .71756 .47433 .72265 .45748 .72022 .45933 Mtetra
0 0 0 r
.72022 .45933 .72265 .45748 .72863 .45563 .72611 .45565 Mtetra
.792 .299 .024 r
.72611 .45565 .72863 .45563 .73535 .46493 .73276 .46385 Mtetra
.577 .892 .988 r
.73276 .46385 .73535 .46493 .74138 .46308 .7388 .46199 Mtetra
.73 .205 0 r
.7388 .46199 .74138 .46308 .74773 .46585 .74548 .46948 Mtetra
.059 0 0 r
.74548 .46948 .74773 .46585 .75392 .46578 .75144 .46575 Mtetra
.971 .914 .69 r
.75144 .46575 .75392 .46578 .75917 .45226 .75687 .4544 Mtetra
.518 .005 0 r
.75687 .4544 .75917 .45226 .7655 .45386 .76322 .45615 Mtetra
0 0 0 r
.76322 .45615 .7655 .45386 .77111 .4456 .76906 .45058 Mtetra
.637 .23 .255 r
.76906 .45058 .77111 .4456 .77748 .44728 .77559 .45415 Mtetra
0 0 0 r
.77559 .45415 .77748 .44728 .7832 .44045 .78082 .44062 Mtetra
.943 .96 .732 r
.78082 .44062 .7832 .44045 .78903 .43512 .78638 .43162 Mtetra
.074 .412 .862 r
.78638 .43162 .78903 .43512 .79528 .43476 .79297 .43527 Mtetra
.775 .996 .798 r
.79297 .43527 .79528 .43476 .80139 .43252 .79882 .42975 Mtetra
.773 .823 .892 r
.79882 .42975 .80139 .43252 .80771 .43256 .80481 .42591 Mtetra
0 .077 .636 r
.80481 .42591 .80771 .43256 .81434 .43594 .81205 .43608 Mtetra
.734 .21 0 r
.81205 .43608 .81434 .43594 .82134 .44287 .81906 .44308 Mtetra
.677 .131 0 r
.81906 .44308 .82134 .44287 .82773 .44282 .82599 .44874 Mtetra
.518 .132 .247 r
.82599 .44874 .82773 .44282 .83468 .44847 .83249 .44923 Mtetra
0 0 0 r
.83249 .44923 .83468 .44847 .84023 .43907 .83875 .44708 Mtetra
.456 .117 .302 r
.83875 .44708 .84023 .43907 .8471 .44327 .84507 .4454 Mtetra
.345 0 0 r
.84507 .4454 .8471 .44327 .85415 .44891 .85158 .44537 Mtetra
.722 .767 .888 r
.85158 .44537 .85415 .44891 .86129 .45496 .85779 .44234 Mtetra
.655 .522 .69 r
.85779 .44234 .86129 .45496 .86783 .45489 .86395 .43863 Mtetra
.651 .497 .662 r
.86395 .43863 .86783 .45489 .87341 .44557 .87002 .43402 Mtetra
.371 .356 .712 r
.87002 .43402 .87341 .44557 .87963 .44229 .87728 .44043 Mtetra
.803 .907 .913 r
.87728 .44043 .87963 .44229 .88641 .44398 .8834 .43604 Mtetra
.868 .683 .65 r
.8834 .43604 .88641 .44398 .89128 .4285 .8883 .42069 Mtetra
.903 .696 .613 r
.8883 .42069 .89128 .4285 .89612 .4131 .89259 .40033 Mtetra
.499 .424 .704 r
.89259 .40033 .89612 .4131 .90304 .41579 .89954 .4034 Mtetra
.171 .215 .666 r
.89954 .4034 .90304 .41579 .91037 .4217 .9076 .41564 Mtetra
.652 .629 .814 r
.9076 .41564 .91037 .4217 .91702 .42162 .91403 .41367 Mtetra
.81 .66 .697 r
.91403 .41367 .91702 .42162 .92223 .40963 .91952 .40388 Mtetra
.838 .717 .731 r
.91952 .40388 .92223 .40963 .92704 .39461 .92512 .39515 Mtetra
.65 .095 0 r
.92512 .39515 .92704 .39461 .93514 .40586 .93251 .40063 Mtetra
.713 .688 .824 r
.93251 .40063 .93514 .40586 .94221 .40857 .93881 .39728 Mtetra
.988 .831 .598 r
.35561 .60367 .35925 .59931 .36448 .59951 .36203 .57937 Mtetra
.683 .504 .638 r
.36203 .57937 .36448 .59951 .37041 .5845 .36766 .57086 Mtetra
.754 .574 .652 r
.36766 .57086 .37041 .5845 .37596 .57748 .37343 .55869 Mtetra
.617 .46 .647 r
.37343 .55869 .37596 .57748 .38105 .58125 .37877 .55613 Mtetra
.365 .258 .598 r
.37877 .55613 .38105 .58125 .38639 .57962 .38356 .56714 Mtetra
.654 .516 .684 r
.38356 .56714 .38639 .57962 .3916 .58161 .38897 .5637 Mtetra
.499 .381 .649 r
.38897 .5637 .3916 .58161 .39696 .57997 .39412 .56719 Mtetra
.519 .426 .69 r
.39412 .56719 .39696 .57997 .40227 .58015 .39935 .56911 Mtetra
.622 .509 .704 r
.39935 .56911 .40227 .58015 .40766 .57851 .40473 .56745 Mtetra
.657 .53 .698 r
.40473 .56745 .40766 .57851 .41331 .56914 .41018 .56428 Mtetra
.544 .602 .862 r
.41018 .56428 .41331 .56914 .41882 .56388 .41552 .56443 Mtetra
.944 .902 .753 r
.41552 .56443 .41882 .56388 .42445 .55462 .42118 .55502 Mtetra
.959 .824 .667 r
.42118 .55502 .42445 .55462 .42984 .55338 .427 .53936 Mtetra
.573 .453 .678 r
.427 .53936 .42984 .55338 .4353 .54994 .43235 .53949 Mtetra
.359 .348 .711 r
.43235 .53949 .4353 .54994 .44055 .55521 .4376 .54429 Mtetra
.446 .399 .712 r
.4376 .54429 .44055 .55521 .44608 .54994 .44292 .54768 Mtetra
.825 .811 .837 r
.44292 .54768 .44608 .54994 .45158 .54569 .44845 .54258 Mtetra
.884 .754 .713 r
.44845 .54258 .45158 .54569 .4571 .54076 .45411 .53146 Mtetra
.627 .532 .728 r
.45411 .53146 .4571 .54076 .46257 .53893 .45957 .52988 Mtetra
.31 .341 .732 r
.45957 .52988 .46257 .53893 .46792 .54463 .46492 .53476 Mtetra
.578 .496 .726 r
.46492 .53476 .46792 .54463 .47344 .5412 .47038 .53468 Mtetra
.463 .499 .81 r
.47038 .53468 .47344 .5412 .47901 .5345 .47584 .53637 Mtetra
.341 0 0 r
.47584 .53637 .47901 .5345 .48445 .53781 .48134 .53641 Mtetra
.932 .8 .692 r
.48134 .53641 .48445 .53781 .49008 .52698 .48701 .5231 Mtetra
.339 .554 .913 r
.48701 .5231 .49008 .52698 .49561 .52395 .4925 .52477 Mtetra
.646 .126 0 r
.4925 .52477 .49561 .52395 .50115 .52122 .498 .52818 Mtetra
.821 .497 .441 r
.498 .52818 .50115 .52122 .50659 .53744 .50345 .54534 Mtetra
.67 .33 .39 r
.50345 .54534 .50659 .53744 .51212 .54875 .50902 .55038 Mtetra
.434 0 0 r
.50902 .55038 .51212 .54875 .51771 .55995 .51465 .55127 Mtetra
.88 .543 .043 r
.51465 .55127 .51771 .55995 .52335 .56643 .52026 .57384 Mtetra
.592 .241 .343 r
.52026 .57384 .52335 .56643 .52904 .57903 .52596 .57589 Mtetra
.867 .429 .029 r
.52596 .57589 .52904 .57903 .53479 .59088 .5317 .58774 Mtetra
.657 .749 .918 r
.5317 .58774 .53479 .59088 .54053 .58918 .53745 .58604 Mtetra
.53745 .58604 .54053 .58918 .54632 .59208 .54321 .58433 Mtetra
.779 .639 .706 r
.54321 .58433 .54632 .59208 .55202 .582 .54894 .57602 Mtetra
.852 .693 .685 r
.54894 .57602 .55202 .582 .55771 .57167 .55462 .5634 Mtetra
.865 .668 .635 r
.55462 .5634 .55771 .57167 .56337 .56003 .5602 .54301 Mtetra
.753 .56 .635 r
.5602 .54301 .56337 .56003 .5688 .53286 .56579 .52826 Mtetra
.88 .725 .686 r
.56579 .52826 .5688 .53286 .57444 .52428 .57137 .51518 Mtetra
.243 .301 .724 r
.57137 .51518 .57444 .52428 .58007 .51667 .57722 .52134 Mtetra
0 0 0 r
.57722 .52134 .58007 .51667 .58578 .51331 .58292 .51626 Mtetra
.871 .511 .364 r
.58292 .51626 .58578 .51331 .59185 .5282 .58905 .5336 Mtetra
.836 .49 .399 r
.58905 .5336 .59185 .5282 .59788 .53757 .59524 .55014 Mtetra
0 0 0 r
.59524 .55014 .59788 .53757 .60352 .52838 .60057 .52513 Mtetra
.915 .763 .678 r
.60057 .52513 .60352 .52838 .60907 .51607 .60609 .51095 Mtetra
.515 .584 .862 r
.60609 .51095 .60907 .51607 .61488 .5143 .61196 .51154 Mtetra
.755 .801 .89 r
.61196 .51154 .61488 .5143 .62042 .50254 .61775 .50816 Mtetra
.658 .276 .311 r
.61775 .50816 .62042 .50254 .62623 .50076 .62376 .51227 Mtetra
.349 .064 .333 r
.62376 .51227 .62623 .50076 .63218 .50266 .62951 .50676 Mtetra
.087 0 0 r
.62951 .50676 .63218 .50266 .63814 .50415 .63532 .50311 Mtetra
.876 .916 .851 r
.63532 .50311 .63814 .50415 .64386 .49831 .64105 .49713 Mtetra
.772 .922 .936 r
.64105 .49713 .64386 .49831 .64967 .49496 .64686 .49348 Mtetra
.961 .803 .64 r
.64686 .49348 .64967 .49496 .65514 .48296 .65216 .47632 Mtetra
.811 .672 .71 r
.65216 .47632 .65514 .48296 .66088 .47785 .65774 .46726 Mtetra
0 .041 .587 r
.65774 .46726 .66088 .47785 .66689 .47913 .66423 .48005 Mtetra
.93 .972 .731 r
.66423 .48005 .66689 .47913 .67275 .47638 .66984 .47136 Mtetra
.338 .491 .864 r
.66984 .47136 .67275 .47638 .67923 .48695 .67596 .47394 Mtetra
.27 .267 .672 r
.67596 .47394 .67923 .48695 .68523 .48617 .6824 .48281 Mtetra
0 0 .492 r
.6824 .48281 .68523 .48617 .69109 .48256 .68882 .49009 Mtetra
.336 .001 .241 r
.68882 .49009 .69109 .48256 .69715 .48253 .69472 .48642 Mtetra
.292 0 .025 r
.69472 .48642 .69715 .48253 .70353 .48797 .70072 .48459 Mtetra
.492 .673 .945 r
.70072 .48459 .70353 .48797 .71091 .51077 .70685 .48479 Mtetra
.76 .543 .602 r
.70685 .48479 .71091 .51077 .71482 .47151 .71163 .46081 Mtetra
.654 .537 .709 r
.71163 .46081 .71482 .47151 .72022 .45933 .71756 .45774 Mtetra
.857 .898 .864 r
.71756 .45774 .72022 .45933 .72611 .45565 .72335 .45222 Mtetra
0 0 .451 r
.72335 .45222 .72611 .45565 .73276 .46385 .73 .46042 Mtetra
0 .183 .701 r
.73 .46042 .73276 .46385 .7388 .46199 .73654 .46597 Mtetra
.809 .412 .3 r
.73654 .46597 .7388 .46199 .74548 .46948 .74349 .47728 Mtetra
0 0 .057 r
.74349 .47728 .74548 .46948 .75144 .46575 .74897 .46604 Mtetra
.699 .165 0 r
.74897 .46604 .75144 .46575 .75687 .4544 .75561 .47169 Mtetra
.44 .182 .424 r
.75561 .47169 .75687 .4544 .76322 .45615 .76149 .46617 Mtetra
0 0 .107 r
.76149 .46617 .76322 .45615 .76906 .45058 .76664 .4508 Mtetra
.202 0 0 r
.76664 .4508 .76906 .45058 .77559 .45415 .77297 .45159 Mtetra
.848 .842 .839 r
.77297 .45159 .77559 .45415 .78082 .44062 .77882 .44577 Mtetra
.7 .766 .273 r
.77882 .44577 .78082 .44062 .78638 .43162 .784 .43156 Mtetra
.87 .428 .123 r
.784 .43156 .78638 .43162 .79297 .43527 .79144 .44552 Mtetra
.578 .251 .379 r
.79144 .44552 .79297 .43527 .79882 .42975 .79794 .44734 Mtetra
.169 0 .36 r
.79794 .44734 .79882 .42975 .80481 .42591 .80295 .43134 Mtetra
.671 .272 .28 r
.80295 .43134 .80481 .42591 .81205 .43608 .80974 .43624 Mtetra
.652 .096 0 r
.80974 .43624 .81205 .43608 .81906 .44308 .8166 .44142 Mtetra
0 .26 .677 r
.8166 .44142 .81906 .44308 .82599 .44874 .82337 .4452 Mtetra
.469 .655 .941 r
.82337 .4452 .82599 .44874 .83249 .44923 .82988 .44569 Mtetra
.676 .75 .907 r
.82988 .44569 .83249 .44923 .83875 .44708 .83615 .44354 Mtetra
.872 .797 .774 r
.83615 .44354 .83875 .44708 .84507 .4454 .84188 .43567 Mtetra
.676 .565 .721 r
.84188 .43567 .84507 .4454 .85158 .44537 .848 .43185 Mtetra
.729 .56 .663 r
.848 .43185 .85158 .44537 .85779 .44234 .85361 .42285 Mtetra
.603 .453 .65 r
.85361 .42285 .85779 .44234 .86395 .43863 .85993 .4209 Mtetra
.507 .397 .664 r
.85993 .4209 .86395 .43863 .87002 .43402 .86686 .42465 Mtetra
.454 .439 .752 r
.86686 .42465 .87002 .43402 .87728 .44043 .87378 .4279 Mtetra
.631 .509 .696 r
.87378 .4279 .87728 .44043 .8834 .43604 .8801 .42543 Mtetra
.724 .581 .695 r
.8801 .42543 .8834 .43604 .8883 .42069 .88597 .41875 Mtetra
.938 .882 .752 r
.88597 .41875 .8883 .42069 .89259 .40033 .89153 .40937 Mtetra
.019 0 .211 r
.89153 .40937 .89259 .40033 .89954 .4034 .89684 .39793 Mtetra
.225 .401 .828 r
.89684 .39793 .89954 .4034 .9076 .41564 .904 .40254 Mtetra
.466 .402 .701 r
.904 .40254 .9076 .41564 .91403 .41367 .91118 .40683 Mtetra
.81 .681 .722 r
.91118 .40683 .91403 .41367 .91952 .40388 .91684 .39839 Mtetra
.778 .705 .782 r
.91684 .39839 .91952 .40388 .92512 .39515 .92284 .3928 Mtetra
.708 .854 .952 r
.92284 .3928 .92512 .39515 .93251 .40063 .92919 .39 Mtetra
.628 .526 .72 r
.92919 .39 .93251 .40063 .93881 .39728 .93566 .388 Mtetra
.831 .663 .675 r
.35252 .59674 .35561 .60367 .36203 .57937 .35843 .58328 Mtetra
.985 .824 .601 r
.35843 .58328 .36203 .57937 .36766 .57086 .36482 .55899 Mtetra
.549 .454 .699 r
.36482 .55899 .36766 .57086 .37343 .55869 .37001 .55985 Mtetra
.894 .978 .814 r
.37001 .55985 .37343 .55869 .37877 .55613 .37554 .55332 Mtetra
.894 .472 .139 r
.37554 .55332 .37877 .55613 .38356 .56714 .38032 .5641 Mtetra
0 .21 .696 r
.38032 .5641 .38356 .56714 .38897 .5637 .38545 .56784 Mtetra
.454 .028 .139 r
.38545 .56784 .38897 .5637 .39412 .56719 .39075 .56771 Mtetra
.704 .204 .051 r
.39075 .56771 .39412 .56719 .39935 .56911 .39591 .57185 Mtetra
.15 0 0 r
.39591 .57185 .39935 .56911 .40473 .56745 .40131 .57019 Mtetra
.424 0 .002 r
.40131 .57019 .40473 .56745 .41018 .56428 .40666 .57035 Mtetra
.595 .228 .316 r
.40666 .57035 .41018 .56428 .41552 .56443 .41196 .57234 Mtetra
.907 .879 .45 r
.41196 .57234 .41552 .56443 .42118 .55502 .41792 .55427 Mtetra
.938 .806 .689 r
.41792 .55427 .42118 .55502 .427 .53936 .42371 .54042 Mtetra
.249 0 0 r
.42371 .54042 .427 .53936 .43235 .53949 .42908 .54052 Mtetra
.886 .984 .815 r
.42908 .54052 .43235 .53949 .4376 .54429 .43463 .53411 Mtetra
.175 .231 .681 r
.43463 .53411 .4376 .54429 .44292 .54768 .43984 .54131 Mtetra
.748 .644 .745 r
.43984 .54131 .44292 .54768 .44845 .54258 .44539 .53602 Mtetra
.773 .65 .726 r
.44539 .53602 .44845 .54258 .45411 .53146 .45096 .52918 Mtetra
.713 .811 .926 r
.45096 .52918 .45411 .53146 .45957 .52988 .45644 .52674 Mtetra
.607 .724 .928 r
.45644 .52674 .45957 .52988 .46492 .53476 .46191 .52577 Mtetra
.587 .514 .74 r
.46191 .52577 .46492 .53476 .47038 .53468 .46737 .52543 Mtetra
.477 .444 .742 r
.46737 .52543 .47038 .53468 .47584 .53637 .47281 .5277 Mtetra
.633 .546 .738 r
.47281 .5277 .47584 .53637 .48134 .53641 .47833 .52599 Mtetra
.612 .511 .715 r
.47833 .52599 .48134 .53641 .48701 .5231 .48386 .52475 Mtetra
.673 .196 .109 r
.48386 .52475 .48701 .5231 .4925 .52477 .48934 .52848 Mtetra
.798 .427 .354 r
.48934 .52848 .4925 .52477 .498 .52818 .4948 .53823 Mtetra
.746 .431 .449 r
.4948 .53823 .498 .52818 .50345 .54534 .5003 .54986 Mtetra
.788 .425 .369 r
.5003 .54986 .50345 .54534 .50902 .55038 .50586 .55977 Mtetra
.647 .32 .404 r
.50586 .55977 .50902 .55038 .51465 .55127 .5115 .5642 Mtetra
.495 .201 .396 r
.5115 .5642 .51465 .55127 .52026 .57384 .51718 .56249 Mtetra
.509 .438 .713 r
.51718 .56249 .52026 .57384 .52596 .57589 .52287 .56452 Mtetra
.302 .304 .695 r
.52287 .56452 .52596 .57589 .5317 .58774 .52858 .57103 Mtetra
.606 .464 .662 r
.52858 .57103 .5317 .58774 .53745 .58604 .53432 .56931 Mtetra
.64 .486 .659 r
.53432 .56931 .53745 .58604 .54321 .58433 .54006 .56552 Mtetra
.705 .523 .639 r
.54006 .56552 .54321 .58433 .54894 .57602 .54576 .55523 Mtetra
.715 .524 .63 r
.54576 .55523 .54894 .57602 .55462 .5634 .55143 .54262 Mtetra
.738 .54 .625 r
.55143 .54262 .55462 .5634 .5602 .54301 .55704 .52681 Mtetra
.745 .557 .641 r
.55704 .52681 .5602 .54301 .56579 .52826 .56265 .51386 Mtetra
.69 .53 .664 r
.56265 .51386 .56579 .52826 .57137 .51518 .56832 .50729 Mtetra
.503 .489 .774 r
.56832 .50729 .57137 .51518 .57722 .52134 .57409 .50875 Mtetra
.321 .302 .682 r
.57409 .50875 .57722 .52134 .58292 .51626 .57999 .51579 Mtetra
.924 .56 .315 r
.57999 .51579 .58292 .51626 .58905 .5336 .58619 .53761 Mtetra
.576 .148 .192 r
.58619 .53761 .58905 .5336 .59524 .55014 .5921 .53951 Mtetra
.803 .621 .656 r
.5921 .53951 .59524 .55014 .60057 .52513 .59768 .52558 Mtetra
.978 .87 .661 r
.59768 .52558 .60057 .52513 .60609 .51095 .60322 .51136 Mtetra
.979 .864 .655 r
.60322 .51136 .60609 .51095 .61196 .51154 .60873 .49668 Mtetra
.696 .531 .66 r
.60873 .49668 .61196 .51154 .61775 .50816 .6144 .48943 Mtetra
.378 .299 .64 r
.6144 .48943 .61775 .50816 .62376 .51227 .62052 .49824 Mtetra
.646 .504 .676 r
.62052 .49824 .62376 .51227 .62951 .50676 .62632 .4947 Mtetra
.776 .596 .656 r
.62632 .4947 .62951 .50676 .63532 .50311 .63184 .48226 Mtetra
.623 .46 .64 r
.63184 .48226 .63532 .50311 .64105 .49713 .63763 .47871 Mtetra
.669 .498 .645 r
.63763 .47871 .64105 .49713 .64686 .49348 .64332 .47209 Mtetra
.619 .455 .638 r
.64332 .47209 .64686 .49348 .65216 .47632 .64913 .46874 Mtetra
.668 .589 .758 r
.64913 .46874 .65216 .47632 .65774 .46726 .65497 .46606 Mtetra
.598 .886 .991 r
.65497 .46606 .65774 .46726 .66423 .48005 .66086 .46423 Mtetra
.426 .348 .666 r
.66086 .46423 .66423 .48005 .66984 .47136 .6671 .47031 Mtetra
0 .432 .741 r
.6671 .47031 .66984 .47136 .67596 .47394 .67319 .47209 Mtetra
.483 .789 .998 r
.67319 .47209 .67596 .47394 .6824 .48281 .67919 .4715 Mtetra
.373 .355 .709 r
.67919 .4715 .6824 .48281 .68882 .49009 .68551 .47707 Mtetra
.575 .467 .694 r
.68551 .47707 .68882 .49009 .69472 .48642 .69159 .47709 Mtetra
.631 .541 .734 r
.69159 .47709 .69472 .48642 .70072 .48459 .69759 .47525 Mtetra
.687 .573 .721 r
.69759 .47525 .70072 .48459 .70685 .48479 .70349 .47113 Mtetra
.795 .598 .635 r
.70349 .47113 .70685 .48479 .71163 .46081 .7087 .45477 Mtetra
.428 .502 .833 r
.7087 .45477 .71163 .46081 .71756 .45774 .71494 .45691 Mtetra
.651 .932 .97 r
.71494 .45691 .71756 .45774 .72335 .45222 .72092 .45429 Mtetra
0 0 0 r
.72092 .45429 .72335 .45222 .73 .46042 .72693 .45184 Mtetra
.526 .493 .762 r
.72693 .45184 .73 .46042 .73654 .46597 .73317 .45303 Mtetra
.414 .365 .695 r
.73317 .45303 .73654 .46597 .74349 .47728 .73973 .45852 Mtetra
.575 .436 .654 r
.73973 .45852 .74349 .47728 .74897 .46604 .74595 .45848 Mtetra
.629 .573 .772 r
.74595 .45848 .74897 .46604 .75561 .47169 .75209 .45696 Mtetra
.613 .48 .676 r
.75209 .45696 .75561 .47169 .76149 .46617 .75822 .45508 Mtetra
.731 .579 .684 r
.75822 .45508 .76149 .46617 .76664 .4508 .76395 .44754 Mtetra
.287 .571 .936 r
.76395 .44754 .76664 .4508 .77297 .45159 .77037 .44937 Mtetra
.949 .826 .69 r
.77037 .44937 .77297 .45159 .77882 .44577 .77571 .43673 Mtetra
.778 .626 .692 r
.77571 .43673 .77882 .44577 .784 .43156 .7813 .42772 Mtetra
.046 .371 .839 r
.7813 .42772 .784 .43156 .79144 .44552 .78795 .43192 Mtetra
.702 .543 .669 r
.78795 .43192 .79144 .44552 .79794 .44734 .79371 .42487 Mtetra
.449 .339 .636 r
.79371 .42487 .79794 .44734 .80295 .43134 .80072 .43277 Mtetra
.261 0 0 r
.80072 .43277 .80295 .43134 .80974 .43624 .8071 .4327 Mtetra
.133 .451 .883 r
.8071 .4327 .80974 .43624 .8166 .44142 .8138 .436 Mtetra
.78 .702 .778 r
.8138 .436 .8166 .44142 .82337 .4452 .81972 .43033 Mtetra
.575 .456 .68 r
.81972 .43033 .82337 .4452 .82988 .44569 .82616 .43034 Mtetra
.671 .514 .664 r
.82616 .43034 .82988 .44569 .83615 .44354 .83209 .42467 Mtetra
.656 .489 .646 r
.83209 .42467 .83615 .44354 .84188 .43567 .838 .41884 Mtetra
.608 .467 .663 r
.838 .41884 .84188 .43567 .848 .43185 .84429 .41689 Mtetra
.642 .498 .671 r
.84429 .41689 .848 .43185 .85361 .42285 .85042 .4132 Mtetra
.515 .471 .746 r
.85042 .4132 .85361 .42285 .85993 .4209 .85712 .41495 Mtetra
0 .22 .735 r
.85712 .41495 .85993 .4209 .86686 .42465 .86447 .42263 Mtetra
.771 .89 .929 r
.86447 .42263 .86686 .42465 .87378 .4279 .87064 .41883 Mtetra
.672 .572 .735 r
.87064 .41883 .87378 .4279 .8801 .42543 .87687 .41543 Mtetra
.529 .475 .741 r
.87687 .41543 .8801 .42543 .88597 .41875 .88364 .41687 Mtetra
.91 .9 .804 r
.88364 .41687 .88597 .41875 .89153 .40937 .88942 .40929 Mtetra
.863 .996 .796 r
.88942 .40929 .89153 .40937 .89684 .39793 .8953 .40262 Mtetra
0 0 0 r
.8953 .40262 .89684 .39793 .904 .40254 .90032 .38867 Mtetra
.415 .362 .69 r
.90032 .38867 .904 .40254 .91118 .40683 .90772 .39502 Mtetra
.579 .484 .711 r
.90772 .39502 .91118 .40683 .91684 .39839 .91439 .3949 Mtetra
.874 .812 .786 r
.91439 .3949 .91684 .39839 .92284 .3928 .92016 .38731 Mtetra
.656 .652 .834 r
.92016 .38731 .92284 .3928 .92919 .39 .92662 .38531 Mtetra
.661 .688 .864 r
.92662 .38531 .92919 .39 .93566 .388 .9331 .3833 Mtetra
.946 .739 .591 r
.34905 .59708 .35252 .59674 .35843 .58328 .35622 .55874 Mtetra
.109 .071 .529 r
.35622 .55874 .35843 .58328 .36482 .55899 .36056 .57693 Mtetra
.315 .066 .368 r
.36056 .57693 .36482 .55899 .37001 .55985 .36622 .5683 Mtetra
.737 .419 .444 r
.36622 .5683 .37001 .55985 .37554 .55332 .37106 .57762 Mtetra
.53 .275 .473 r
.37106 .57762 .37554 .55332 .38032 .5641 .37643 .57597 Mtetra
.543 .24 .404 r
.37643 .57597 .38032 .5641 .38545 .56784 .38173 .57615 Mtetra
.334 .002 .244 r
.38173 .57615 .38545 .56784 .39075 .56771 .38719 .57267 Mtetra
.466 .064 .192 r
.38719 .57267 .39075 .56771 .39591 .57185 .39253 .57243 Mtetra
.693 .979 .899 r
.39253 .57243 .39591 .57185 .40131 .57019 .39801 .56895 Mtetra
.616 .87 .99 r
.39801 .56895 .40131 .57019 .40666 .57035 .40343 .56729 Mtetra
.483 .682 .954 r
.40343 .56729 .40666 .57035 .41196 .57234 .4088 .56745 Mtetra
.828 .701 .724 r
.4088 .56745 .41196 .57234 .41792 .55427 .41448 .55849 Mtetra
.994 .858 .591 r
.41448 .55849 .41792 .55427 .42371 .54042 .42053 .53744 Mtetra
.755 .767 .863 r
.42053 .53744 .42371 .54042 .42908 .54052 .426 .53403 Mtetra
.733 .635 .749 r
.426 .53403 .42908 .54052 .43463 .53411 .43152 .52936 Mtetra
.67 .24 0 r
.43152 .52936 .43463 .53411 .43984 .54131 .43668 .53803 Mtetra
.748 .752 .855 r
.43668 .53803 .43984 .54131 .44539 .53602 .44219 .53468 Mtetra
.869 .86 .829 r
.44219 .53468 .44539 .53602 .45096 .52918 .44776 .52855 Mtetra
.263 .752 .918 r
.44776 .52855 .45096 .52918 .45644 .52674 .45321 .52818 Mtetra
.428 .853 .711 r
.45321 .52818 .45644 .52674 .46191 .52577 .45873 .52514 Mtetra
.146 0 0 r
.45873 .52514 .46191 .52577 .46737 .52543 .46418 .52626 Mtetra
0 0 0 r
.46418 .52626 .46737 .52543 .47281 .5277 .46968 .52523 Mtetra
.434 .708 .98 r
.46968 .52523 .47281 .5277 .47833 .52599 .47518 .52542 Mtetra
.275 0 0 r
.47518 .52542 .47833 .52599 .48386 .52475 .48068 .52703 Mtetra
.786 .378 .278 r
.48068 .52703 .48386 .52475 .48934 .52848 .48613 .53461 Mtetra
.74 .388 .385 r
.48613 .53461 .48934 .52848 .4948 .53823 .49162 .54257 Mtetra
.555 .139 .208 r
.49162 .54257 .4948 .53823 .5003 .54986 .49721 .54392 Mtetra
.646 .263 0 r
.49721 .54392 .5003 .54986 .50586 .55977 .50276 .55483 Mtetra
.75 .688 .792 r
.50276 .55483 .50586 .55977 .5115 .5642 .50843 .55047 Mtetra
.522 .425 .685 r
.50843 .55047 .5115 .5642 .51718 .56249 .51409 .55246 Mtetra
.769 .607 .678 r
.51409 .55246 .51718 .56249 .52287 .56452 .51979 .54257 Mtetra
.495 .366 .634 r
.51979 .54257 .52287 .56452 .52858 .57103 .52548 .54714 Mtetra
.595 .432 .631 r
.52548 .54714 .52858 .57103 .53432 .56931 .53119 .54541 Mtetra
.663 .481 .628 r
.53119 .54541 .53432 .56931 .54006 .56552 .53689 .53736 Mtetra
.622 .444 .62 r
.53689 .53736 .54006 .56552 .54576 .55523 .54259 .53253 Mtetra
.735 .533 .62 r
.54259 .53253 .54576 .55523 .55143 .54262 .54822 .51567 Mtetra
.706 .506 .615 r
.54822 .51567 .55143 .54262 .55704 .52681 .55381 .50053 Mtetra
.622 .447 .623 r
.55381 .50053 .55704 .52681 .56265 .51386 .55949 .49603 Mtetra
.537 .41 .656 r
.55949 .49603 .56265 .51386 .56832 .50729 .56524 .49794 Mtetra
.297 .332 .729 r
.56524 .49794 .56832 .50729 .57409 .50875 .57107 .50344 Mtetra
0 .046 .612 r
.57107 .50344 .57409 .50875 .57999 .51579 .57697 .51088 Mtetra
.728 .311 0 r
.57697 .51088 .57999 .51579 .58619 .53761 .58298 .52249 Mtetra
.489 .394 .675 r
.58298 .52249 .58619 .53761 .5921 .53951 .5889 .52599 Mtetra
.762 .58 .651 r
.5889 .52599 .5921 .53951 .59768 .52558 .59451 .51351 Mtetra
.71 .557 .679 r
.59451 .51351 .59768 .52558 .60322 .51136 .60023 .50674 Mtetra
.92 .725 .623 r
.60023 .50674 .60322 .51136 .60873 .49668 .60558 .48498 Mtetra
.689 .547 .688 r
.60558 .48498 .60873 .49668 .6144 .48943 .6113 .47974 Mtetra
.607 .52 .73 r
.6113 .47974 .6144 .48943 .62052 .49824 .61714 .47871 Mtetra
.549 .413 .648 r
.61714 .47871 .62052 .49824 .62632 .4947 .62307 .48016 Mtetra
.628 .489 .674 r
.62307 .48016 .62632 .4947 .63184 .48226 .62889 .47749 Mtetra
.73 .694 .816 r
.62889 .47749 .63184 .48226 .63763 .47871 .63469 .47392 Mtetra
.854 .726 .721 r
.63469 .47392 .63763 .47871 .64332 .47209 .64028 .46424 Mtetra
.658 .578 .754 r
.64028 .46424 .64332 .47209 .64913 .46874 .64612 .4618 Mtetra
.272 .376 .787 r
.64612 .4618 .64913 .46874 .65497 .46606 .65225 .4663 Mtetra
.051 0 0 r
.65225 .4663 .65497 .46606 .66086 .46423 .65822 .46627 Mtetra
.647 .159 .077 r
.65822 .46627 .66086 .46423 .6671 .47031 .66437 .46993 Mtetra
.694 .152 0 r
.66437 .46993 .6671 .47031 .67319 .47209 .67064 .4755 Mtetra
.745 .887 .484 r
.67064 .4755 .67319 .47209 .67919 .4715 .67625 .46596 Mtetra
.561 .593 .843 r
.67625 .46596 .67919 .4715 .68551 .47707 .6823 .46592 Mtetra
.673 .544 .699 r
.6823 .46592 .68551 .47707 .69159 .47709 .68817 .4618 Mtetra
.504 .405 .676 r
.68817 .4618 .69159 .47709 .69759 .47525 .69441 .46488 Mtetra
.827 .636 .645 r
.69441 .46488 .69759 .47525 .70349 .47113 .69967 .4489 Mtetra
.405 .306 .629 r
.69967 .4489 .70349 .47113 .7087 .45477 .7063 .45853 Mtetra
.558 .113 .15 r
.7063 .45853 .7087 .45477 .71494 .45691 .71254 .4603 Mtetra
.869 .904 .491 r
.71254 .4603 .71494 .45691 .72092 .45429 .71796 .44777 Mtetra
.534 .547 .814 r
.71796 .44777 .72092 .45429 .72693 .45184 .72416 .44838 Mtetra
.308 .569 .931 r
.72416 .44838 .72693 .45184 .73317 .45303 .73045 .45016 Mtetra
.528 .73 .966 r
.73045 .45016 .73317 .45303 .73973 .45852 .73663 .44975 Mtetra
.635 .553 .745 r
.73663 .44975 .73973 .45852 .74595 .45848 .74272 .44786 Mtetra
.426 .4 .727 r
.74272 .44786 .74595 .45848 .75209 .45696 .74925 .45203 Mtetra
.658 .667 .848 r
.74925 .45203 .75209 .45696 .75822 .45508 .75538 .45014 Mtetra
.733 .698 .817 r
.75538 .45014 .75822 .45508 .76395 .44754 .7614 .44638 Mtetra
.275 .734 .952 r
.7614 .44638 .76395 .44754 .77037 .44937 .76769 .44634 Mtetra
.891 .813 .765 r
.76769 .44634 .77037 .44937 .77571 .43673 .77336 .43782 Mtetra
0 0 0 r
.77336 .43782 .77571 .43673 .7813 .42772 .77954 .4359 Mtetra
0 0 .122 r
.77954 .4359 .7813 .42772 .78795 .43192 .78502 .42522 Mtetra
.381 .454 .811 r
.78502 .42522 .78795 .43192 .79371 .42487 .79163 .42843 Mtetra
.49 .031 .089 r
.79163 .42843 .79371 .42487 .80072 .43277 .79806 .42922 Mtetra
.663 .743 .91 r
.79806 .42922 .80072 .43277 .8071 .4327 .80429 .42729 Mtetra
.137 .348 .809 r
.80429 .42729 .8071 .4327 .8138 .436 .81115 .43244 Mtetra
.893 .794 .743 r
.81115 .43244 .8138 .436 .81972 .43033 .81675 .42304 Mtetra
.811 .669 .706 r
.81675 .42304 .81972 .43033 .82616 .43034 .82234 .41375 Mtetra
.681 .514 .653 r
.82234 .41375 .82616 .43034 .83209 .42467 .82813 .40675 Mtetra
.51 .397 .661 r
.82813 .40675 .83209 .42467 .838 .41884 .83492 .41025 Mtetra
.599 .538 .758 r
.83492 .41025 .838 .41884 .84429 .41689 .84133 .40948 Mtetra
.478 .493 .795 r
.84133 .40948 .84429 .41689 .85042 .4132 .84803 .41143 Mtetra
.622 .866 .989 r
.84803 .41143 .85042 .4132 .85712 .41495 .85436 .40947 Mtetra
0 0 .325 r
.85436 .40947 .85712 .41495 .86447 .42263 .86259 .42567 Mtetra
.534 .051 .055 r
.86259 .42567 .86447 .42263 .87064 .41883 .86939 .42749 Mtetra
.226 0 .254 r
.86939 .42749 .87064 .41883 .87687 .41543 .87526 .42048 Mtetra
.467 .057 .178 r
.87526 .42048 .87687 .41543 .88364 .41687 .88188 .42031 Mtetra
0 0 0 r
.88188 .42031 .88364 .41687 .88942 .40929 .88772 .41296 Mtetra
.88772 .41296 .88942 .40929 .8953 .40262 .89363 .40632 Mtetra
.817 .816 .333 r
.89363 .40632 .8953 .40262 .90032 .38867 .89846 .39047 Mtetra
0 0 0 r
.89846 .39047 .90032 .38867 .90772 .39502 .90477 .3874 Mtetra
.281 .367 .774 r
.90477 .3874 .90772 .39502 .91439 .3949 .91213 .39308 Mtetra
.861 .92 .868 r
.91213 .39308 .91439 .3949 .92016 .38731 .91815 .38732 Mtetra
.36 0 0 r
.91815 .38732 .92016 .38731 .92662 .38531 .92518 .38974 Mtetra
.021 0 0 r
.92518 .38974 .92662 .38531 .9331 .3833 .93121 .38403 Mtetra
.808 .681 .724 r
.34586 .59163 .34905 .59708 .35622 .55874 .35154 .58336 Mtetra
.556 .298 .481 r
.35154 .58336 .35622 .55874 .36056 .57693 .3568 .58353 Mtetra
.738 .402 .414 r
.3568 .58353 .36056 .57693 .36622 .5683 .36169 .59155 Mtetra
.555 .295 .476 r
.36169 .59155 .36622 .5683 .37106 .57762 .36699 .59174 Mtetra
.499 .212 .408 r
.36699 .59174 .37106 .57762 .37643 .57597 .37239 .5901 Mtetra
.294 .025 .324 r
.37239 .5901 .37643 .57597 .38173 .57615 .37804 .58295 Mtetra
.264 0 .154 r
.37804 .58295 .38173 .57615 .38719 .57267 .38353 .57946 Mtetra
.373 .011 .214 r
.38353 .57946 .38719 .57267 .39253 .57243 .38897 .57727 Mtetra
.336 0 .101 r
.38897 .57727 .39253 .57243 .39801 .56895 .3944 .57561 Mtetra
.05 0 .033 r
.3944 .57561 .39801 .56895 .40343 .56729 .39998 .57021 Mtetra
.171 0 0 r
.39998 .57021 .40343 .56729 .4088 .56745 .40542 .56854 Mtetra
.189 0 0 r
.40542 .56854 .4088 .56745 .41448 .55849 .41083 .56835 Mtetra
.138 0 .187 r
.41083 .56835 .41448 .55849 .42053 .53744 .41647 .56125 Mtetra
.338 .107 .41 r
.41647 .56125 .42053 .53744 .426 .53403 .42223 .5502 Mtetra
.548 .268 .441 r
.42223 .5502 .426 .53403 .43152 .52936 .42765 .55033 Mtetra
.443 .19 .434 r
.42765 .55033 .43152 .52936 .43668 .53803 .43324 .54467 Mtetra
.265 0 .154 r
.43324 .54467 .43668 .53803 .44219 .53468 .43877 .54118 Mtetra
0 0 0 r
.43877 .54118 .44219 .53468 .44776 .52855 .44444 .53239 Mtetra
.269 0 0 r
.44444 .53239 .44776 .52855 .45321 .52818 .44994 .53068 Mtetra
0 0 0 r
.44994 .53068 .45321 .52818 .45873 .52514 .45547 .52759 Mtetra
.62 .157 .132 r
.45547 .52759 .45873 .52514 .46418 .52626 .4609 .53027 Mtetra
.607 .191 .228 r
.4609 .53027 .46418 .52626 .46968 .52523 .46637 .53263 Mtetra
.518 .165 .309 r
.46637 .53263 .46968 .52523 .47518 .52542 .47189 .53271 Mtetra
.465 .111 .281 r
.47189 .53271 .47518 .52542 .48068 .52703 .47745 .53173 Mtetra
.115 0 0 r
.47745 .53173 .48068 .52703 .48613 .53461 .48305 .52818 Mtetra
0 0 .577 r
.48305 .52818 .48613 .53461 .49162 .54257 .48853 .53636 Mtetra
.559 .564 .815 r
.48853 .53636 .49162 .54257 .49721 .54392 .49413 .53646 Mtetra
.68 .594 .753 r
.49413 .53646 .49721 .54392 .50276 .55483 .49977 .53342 Mtetra
.511 .379 .637 r
.49977 .53342 .50276 .55483 .50843 .55047 .50538 .53699 Mtetra
.668 .521 .676 r
.50538 .53699 .50843 .55047 .51409 .55246 .51105 .53236 Mtetra
.649 .48 .641 r
.51105 .53236 .51409 .55246 .51979 .54257 .51673 .52693 Mtetra
.64 .491 .664 r
.51673 .52693 .51979 .54257 .52548 .54714 .5224 .52334 Mtetra
.643 .466 .629 r
.5224 .52334 .52548 .54714 .53119 .54541 .52808 .51744 Mtetra
.591 .421 .62 r
.52808 .51744 .53119 .54541 .53689 .53736 .53377 .51568 Mtetra
.691 .505 .63 r
.53377 .51568 .53689 .53736 .54259 .53253 .53943 .5054 Mtetra
.689 .493 .617 r
.53943 .5054 .54259 .53253 .54822 .51567 .54506 .4927 Mtetra
.5 .366 .63 r
.54506 .4927 .54822 .51567 .55381 .50053 .55079 .49721 Mtetra
.602 .116 0 r
.55079 .49721 .55381 .50053 .55949 .49603 .55659 .50427 Mtetra
.392 .059 .276 r
.55659 .50427 .55949 .49603 .56524 .49794 .56231 .50152 Mtetra
.82 .928 .549 r
.56231 .50152 .56524 .49794 .57107 .50344 .56796 .49169 Mtetra
0 .029 .571 r
.56796 .49169 .57107 .50344 .57697 .51088 .57392 .50459 Mtetra
.111 .296 .772 r
.57392 .50459 .57697 .51088 .58298 .52249 .57982 .50992 Mtetra
.599 .485 .694 r
.57982 .50992 .58298 .52249 .5889 .52599 .58564 .50893 Mtetra
.636 .482 .657 r
.58564 .50893 .5889 .52599 .59451 .51351 .59143 .50523 Mtetra
.856 .666 .644 r
.59143 .50523 .59451 .51351 .60023 .50674 .59691 .48753 Mtetra
.687 .508 .639 r
.59691 .48753 .60023 .50674 .60558 .48498 .60256 .47887 Mtetra
.782 .671 .741 r
.60256 .47887 .60558 .48498 .6113 .47974 .60825 .47221 Mtetra
.367 .418 .782 r
.60825 .47221 .6113 .47974 .61714 .47871 .61422 .47576 Mtetra
.747 .79 .887 r
.61422 .47576 .61714 .47871 .62307 .48016 .62001 .47248 Mtetra
.381 .423 .78 r
.62001 .47248 .62307 .48016 .62889 .47749 .62603 .47592 Mtetra
.88 .878 .828 r
.62603 .47592 .62889 .47749 .63469 .47392 .63174 .46943 Mtetra
.783 .722 .795 r
.63174 .46943 .63469 .47392 .64028 .46424 .6375 .46425 Mtetra
.831 .369 .113 r
.6375 .46425 .64028 .46424 .64612 .4618 .64379 .47363 Mtetra
.634 .318 .419 r
.64379 .47363 .64612 .4618 .65225 .4663 .64995 .4782 Mtetra
.676 .358 .428 r
.64995 .4782 .65225 .4663 .65822 .46627 .65624 .48543 Mtetra
.426 .174 .426 r
.65624 .48543 .65822 .46627 .66437 .46993 .66202 .47902 Mtetra
.524 .19 .344 r
.66202 .47902 .66437 .46993 .67064 .4755 .66807 .47902 Mtetra
.958 .897 .517 r
.66807 .47902 .67064 .4755 .67625 .46596 .67341 .46277 Mtetra
.502 .692 .953 r
.67341 .46277 .67625 .46596 .6823 .46592 .67947 .46276 Mtetra
.899 .789 .731 r
.67947 .46276 .6823 .46592 .68817 .4618 .68506 .45265 Mtetra
.514 .475 .751 r
.68506 .45265 .68817 .4618 .69441 .46488 .69121 .45418 Mtetra
.699 .564 .698 r
.69121 .45418 .69441 .46488 .69967 .4489 .69704 .44883 Mtetra
.73 .205 0 r
.69704 .44883 .69967 .4489 .7063 .45853 .70349 .45513 Mtetra
.732 .274 0 r
.70349 .45513 .7063 .45853 .71254 .4603 .71026 .46612 Mtetra
0 0 0 r
.71026 .46612 .71254 .4603 .71796 .44777 .7158 .45502 Mtetra
0 0 .073 r
.7158 .45502 .71796 .44777 .72416 .44838 .72145 .44618 Mtetra
.647 .829 .97 r
.72145 .44618 .72416 .44838 .73045 .45016 .72753 .44429 Mtetra
.652 .629 .814 r
.72753 .44429 .73045 .45016 .73663 .44975 .73361 .4424 Mtetra
.573 .547 .787 r
.73361 .4424 .73663 .44975 .74272 .44786 .73983 .44229 Mtetra
.278 .433 .837 r
.73983 .44229 .74272 .44786 .74925 .45203 .74632 .44593 Mtetra
.454 .518 .834 r
.74632 .44593 .74925 .45203 .75538 .45014 .75272 .44773 Mtetra
.337 .67 .976 r
.75272 .44773 .75538 .45014 .7614 .44638 .75907 .44848 Mtetra
.083 0 0 r
.75907 .44848 .7614 .44638 .76769 .44634 .76524 .44657 Mtetra
.984 .897 .64 r
.76524 .44657 .76769 .44634 .77336 .43782 .77055 .43298 Mtetra
.552 .623 .876 r
.77055 .43298 .77336 .43782 .77954 .4359 .77688 .43292 Mtetra
.343 .626 .957 r
.77688 .43292 .77954 .4359 .78502 .42522 .78332 .4341 Mtetra
.574 .231 .349 r
.78332 .4341 .78502 .42522 .79163 .42843 .78984 .43587 Mtetra
.459 .107 .28 r
.78984 .43587 .79163 .42843 .79806 .42922 .79614 .43461 Mtetra
.233 0 .111 r
.79614 .43461 .79806 .42922 .80429 .42729 .80223 .4308 Mtetra
.574 .114 .124 r
.80223 .4308 .80429 .42729 .81115 .43244 .80886 .43311 Mtetra
.929 .969 .691 r
.80886 .43311 .81115 .43244 .81675 .42304 .81448 .42366 Mtetra
.87 .991 .736 r
.81448 .42366 .81675 .42304 .82234 .41375 .82026 .41613 Mtetra
0 0 0 r
.82026 .41613 .82234 .41375 .82813 .40675 .8262 .41049 Mtetra
.8262 .41049 .82813 .40675 .83492 .41025 .83215 .40492 Mtetra
0 .084 .644 r
.83215 .40492 .83492 .41025 .84133 .40948 .83952 .41398 Mtetra
.645 .216 .214 r
.83952 .41398 .84133 .40948 .84803 .41143 .84645 .418 Mtetra
.812 .434 .338 r
.84645 .418 .84803 .41143 .85436 .40947 .85452 .43293 Mtetra
.659 .373 .475 r
.85452 .43293 .85436 .40947 .86259 .42567 .86223 .44354 Mtetra
.443 .186 .428 r
.86223 .44354 .86259 .42567 .86939 .42749 .86828 .43779 Mtetra
0 0 .162 r
.86828 .43779 .86939 .42749 .87526 .42048 .87318 .42135 Mtetra
.244 0 0 r
.87318 .42135 .87526 .42048 .88188 .42031 .87989 .4218 Mtetra
.792 .944 .596 r
.87989 .4218 .88188 .42031 .88772 .41296 .88563 .41335 Mtetra
.997 .851 .523 r
.88563 .41335 .88772 .41296 .89363 .40632 .89009 .39373 Mtetra
.772 .591 .654 r
.89009 .39373 .89363 .40632 .89846 .39047 .89539 .38191 Mtetra
0 0 .513 r
.89539 .38191 .89846 .39047 .90477 .3874 .90406 .39893 Mtetra
.428 .136 .364 r
.90406 .39893 .90477 .3874 .91213 .39308 .91032 .39503 Mtetra
0 0 0 r
.91032 .39503 .91213 .39308 .91815 .38732 .91644 .3899 Mtetra
.91644 .3899 .91815 .38732 .92518 .38974 .92263 .3854 Mtetra
.348 .538 .899 r
.92263 .3854 .92518 .38974 .93121 .38403 .92969 .38769 Mtetra
.521 0 0 r
.34234 .5922 .34586 .59163 .35154 .58336 .34751 .59417 Mtetra
.295 0 .275 r
.34751 .59417 .35154 .58336 .3568 .58353 .35306 .58894 Mtetra
.361 0 .145 r
.35306 .58894 .3568 .58353 .36169 .59155 .35844 .5873 Mtetra
.293 .51 .895 r
.35844 .5873 .36169 .59155 .36699 .59174 .36366 .58933 Mtetra
.824 .796 .826 r
.36366 .58933 .36699 .59174 .37239 .5901 .36923 .584 Mtetra
.799 .667 .718 r
.36923 .584 .37239 .5901 .37804 .58295 .37493 .5757 Mtetra
.639 .575 .766 r
.37493 .5757 .37804 .58295 .38353 .57946 .38035 .57404 Mtetra
.651 .63 .816 r
.38035 .57404 .38353 .57946 .38897 .57727 .38577 .57238 Mtetra
.654 .65 .834 r
.38577 .57238 .38897 .57727 .3944 .57561 .3912 .57071 Mtetra
.435 .55 .873 r
.3912 .57071 .3944 .57561 .39998 .57021 .39654 .57201 Mtetra
.183 0 0 r
.39654 .57201 .39998 .57021 .40542 .56854 .40196 .57126 Mtetra
.964 .941 .682 r
.40196 .57126 .40542 .56854 .41083 .56835 .40777 .55983 Mtetra
.773 .622 .693 r
.40777 .55983 .41083 .56835 .41647 .56125 .41348 .55101 Mtetra
0 .064 .6 r
.41348 .55101 .41647 .56125 .42223 .5502 .41859 .5607 Mtetra
.536 .22 .379 r
.41859 .5607 .42223 .5502 .42765 .55033 .42403 .56085 Mtetra
.254 0 .256 r
.42403 .56085 .42765 .55033 .43324 .54467 .42967 .55488 Mtetra
.153 0 .204 r
.42967 .55488 .43324 .54467 .43877 .54118 .43533 .54765 Mtetra
.257 0 .141 r
.43533 .54765 .43877 .54118 .44444 .53239 .44089 .54419 Mtetra
.42 .123 .351 r
.44089 .54419 .44444 .53239 .44994 .53068 .44646 .54079 Mtetra
.3 0 .272 r
.44646 .54079 .44994 .53068 .45547 .52759 .45207 .53573 Mtetra
.439 .099 .29 r
.45207 .53573 .45547 .52759 .4609 .53027 .45761 .53401 Mtetra
.541 .106 .163 r
.45761 .53401 .4609 .53027 .46637 .53263 .46311 .53524 Mtetra
.404 0 0 r
.46311 .53524 .46637 .53263 .47189 .53271 .46865 .53535 Mtetra
.715 .286 .228 r
.46865 .53535 .47189 .53271 .47745 .53173 .47413 .54029 Mtetra
.218 0 .198 r
.47413 .54029 .47745 .53173 .48305 .52818 .47979 .5349 Mtetra
0 0 0 r
.47979 .5349 .48305 .52818 .48853 .53636 .48547 .52679 Mtetra
.628 .532 .726 r
.48547 .52679 .48853 .53636 .49413 .53646 .49109 .52505 Mtetra
.753 .586 .67 r
.49109 .52505 .49413 .53646 .49977 .53342 .49678 .51535 Mtetra
.573 .434 .653 r
.49678 .51535 .49977 .53342 .50538 .53699 .50239 .51532 Mtetra
.6 .44 .637 r
.50239 .51532 .50538 .53699 .51105 .53236 .50803 .51339 Mtetra
.593 .444 .649 r
.50803 .51339 .51105 .53236 .51673 .52693 .51367 .51221 Mtetra
.572 .45 .675 r
.51367 .51221 .51673 .52693 .5224 .52334 .51933 .51228 Mtetra
.729 .575 .682 r
.51933 .51228 .5224 .52334 .52808 .51744 .52501 .50483 Mtetra
.76 .583 .657 r
.52501 .50483 .52808 .51744 .53377 .51568 .53067 .49336 Mtetra
.503 .37 .632 r
.53067 .49336 .53377 .51568 .53943 .5054 .53636 .49753 Mtetra
.441 .453 .776 r
.53636 .49753 .53943 .5054 .54506 .4927 .54208 .50002 Mtetra
.775 .436 .412 r
.54208 .50002 .54506 .4927 .55079 .49721 .54788 .51184 Mtetra
.601 .305 .44 r
.54788 .51184 .55079 .49721 .55659 .50427 .55367 .51485 Mtetra
.373 .071 .317 r
.55367 .51485 .55659 .50427 .56231 .50152 .55942 .51067 Mtetra
.898 .823 .353 r
.55942 .51067 .56231 .50152 .56796 .49169 .56492 .48622 Mtetra
.728 .328 0 r
.56492 .48622 .56796 .49169 .57392 .50459 .57087 .49863 Mtetra
.751 .663 .764 r
.57087 .49863 .57392 .50459 .57982 .50992 .57661 .49361 Mtetra
.671 .508 .656 r
.57661 .49361 .57982 .50992 .58564 .50893 .58233 .48765 Mtetra
.533 .396 .64 r
.58233 .48765 .58564 .50893 .59143 .50523 .5882 .49003 Mtetra
.675 .516 .662 r
.5882 .49003 .59143 .50523 .59691 .48753 .59394 .4842 Mtetra
.436 .648 .948 r
.59394 .4842 .59691 .48753 .60256 .47887 .59982 .48483 Mtetra
0 0 0 r
.59982 .48483 .60256 .47887 .60825 .47221 .60551 .47709 Mtetra
.60551 .47709 .60825 .47221 .61422 .47576 .61119 .46925 Mtetra
.646 .602 .791 r
.61119 .46925 .61422 .47576 .62001 .47248 .61704 .46745 Mtetra
.657 .656 .838 r
.61704 .46745 .62001 .47248 .62603 .47592 .62289 .46562 Mtetra
.619 .52 .72 r
.62289 .46562 .62603 .47592 .63174 .46943 .62876 .46407 Mtetra
.655 .644 .827 r
.62876 .46407 .63174 .46943 .6375 .46425 .63464 .46223 Mtetra
.89 .463 .11 r
.63464 .46223 .6375 .46425 .64379 .47363 .64111 .47664 Mtetra
.549 .079 .091 r
.64111 .47664 .64379 .47363 .64995 .4782 .64718 .47841 Mtetra
.782 .292 .05 r
.64718 .47841 .64995 .4782 .65624 .48543 .65349 .48582 Mtetra
.56 0 0 r
.65349 .48582 .65624 .48543 .66202 .47902 .65968 .48899 Mtetra
.527 .202 .36 r
.65968 .48899 .66202 .47902 .66807 .47902 .66576 .48896 Mtetra
.815 .754 .237 r
.66576 .48896 .66807 .47902 .67341 .46277 .6707 .46273 Mtetra
.338 0 0 r
.6707 .46273 .67341 .46277 .67947 .46276 .67685 .4645 Mtetra
.895 .972 .667 r
.67685 .4645 .67947 .46276 .68506 .45265 .68251 .45541 Mtetra
.545 .829 .488 r
.68251 .45541 .68506 .45265 .69121 .45418 .68829 .44893 Mtetra
.576 .614 .853 r
.68829 .44893 .69121 .45418 .69704 .44883 .69438 .44858 Mtetra
.89 .471 .185 r
.69438 .44858 .69704 .44883 .70349 .45513 .70133 .46387 Mtetra
.658 .31 .373 r
.70133 .46387 .70349 .45513 .71026 .46612 .70779 .46902 Mtetra
.401 0 0 r
.70779 .46902 .71026 .46612 .7158 .45502 .714 .46903 Mtetra
0 0 .066 r
.714 .46903 .7158 .45502 .72145 .44618 .71877 .44448 Mtetra
.94 .855 .73 r
.71877 .44448 .72145 .44618 .72753 .44429 .72433 .43402 Mtetra
.117 .202 .677 r
.72433 .43402 .72753 .44429 .73361 .4424 .73114 .44368 Mtetra
.442 0 0 r
.73114 .44368 .73361 .4424 .73983 .44229 .73748 .44518 Mtetra
0 0 0 r
.73748 .44518 .73983 .44229 .74632 .44593 .74344 .44059 Mtetra
.429 .534 .862 r
.74344 .44059 .74632 .44593 .75272 .44773 .74983 .44236 Mtetra
.536 .591 .857 r
.74983 .44236 .75272 .44773 .75907 .44848 .75616 .44266 Mtetra
.441 .522 .845 r
.75616 .44266 .75907 .44848 .76524 .44657 .76261 .4445 Mtetra
.639 .842 .978 r
.76261 .4445 .76524 .44657 .77055 .43298 .76882 .44258 Mtetra
.576 .24 .362 r
.76882 .44258 .77055 .43298 .77688 .43292 .77532 .44443 Mtetra
.277 .011 .317 r
.77532 .44443 .77688 .43292 .78332 .4341 .78111 .43679 Mtetra
0 0 0 r
.78111 .43679 .78332 .4341 .78984 .43587 .78705 .4311 Mtetra
.737 .71 .826 r
.78705 .4311 .78984 .43587 .79614 .43461 .79314 .42729 Mtetra
.746 .64 .743 r
.79314 .42729 .79614 .43461 .80223 .4308 .79908 .42161 Mtetra
.558 .504 .751 r
.79908 .42161 .80223 .4308 .80886 .43311 .80554 .42202 Mtetra
.732 .581 .686 r
.80554 .42202 .80886 .43311 .81448 .42366 .81133 .41448 Mtetra
.318 .356 .744 r
.81133 .41448 .81448 .42366 .82026 .41613 .81831 .42026 Mtetra
.304 0 .05 r
.81831 .42026 .82026 .41613 .8262 .41049 .82463 .4183 Mtetra
.272 0 .235 r
.82463 .4183 .8262 .41049 .83215 .40492 .83064 .41308 Mtetra
.735 .37 .36 r
.83064 .41308 .83215 .40492 .83952 .41398 .8381 .42277 Mtetra
.828 .47 .379 r
.8381 .42277 .83952 .41398 .84645 .418 .84665 .4429 Mtetra
.61 .336 .477 r
.84665 .4429 .84645 .418 .85452 .43293 .85384 .44851 Mtetra
.59 .291 .43 r
.85384 .44851 .85452 .43293 .86223 .44354 .86079 .45131 Mtetra
0 0 .13 r
.86079 .45131 .86223 .44354 .86828 .43779 .86638 .44079 Mtetra
0 0 0 r
.86638 .44079 .86828 .43779 .87318 .42135 .87233 .4338 Mtetra
.188 0 .317 r
.87233 .4338 .87318 .42135 .87989 .4218 .87781 .42258 Mtetra
.994 .858 .516 r
.87781 .42258 .87989 .4218 .88563 .41335 .88236 .40319 Mtetra
.84 .647 .642 r
.88236 .40319 .88563 .41335 .89009 .39373 .88726 .38744 Mtetra
.821 .699 .73 r
.88726 .38744 .89009 .39373 .89539 .38191 .89297 .37904 Mtetra
.878 .476 .026 r
.89297 .37904 .89539 .38191 .90406 .39893 .90261 .40433 Mtetra
.398 .005 .172 r
.90261 .40433 .90406 .39893 .91032 .39503 .90918 .40278 Mtetra
0 0 .059 r
.90918 .40278 .91032 .39503 .91644 .3899 .9141 .38746 Mtetra
.242 .611 .955 r
.9141 .38746 .91644 .3899 .92263 .3854 .92105 .38897 Mtetra
.087 0 0 r
.92105 .38897 .92263 .3854 .92969 .38769 .92736 .38506 Mtetra
.061 .38 .844 r
.33905 .58809 .34234 .5922 .34751 .59417 .34416 .59123 Mtetra
.901 .486 .162 r
.34416 .59123 .34751 .59417 .35306 .58894 .34888 .60253 Mtetra
.789 .786 .286 r
.34888 .60253 .35306 .58894 .35844 .5873 .35536 .57938 Mtetra
.815 .647 .675 r
.35536 .57938 .35844 .5873 .36366 .58933 .36128 .56664 Mtetra
.676 .493 .63 r
.36128 .56664 .36366 .58933 .36923 .584 .367 .55771 Mtetra
.592 .423 .622 r
.367 .55771 .36923 .584 .37493 .5757 .37239 .55604 Mtetra
.569 .424 .643 r
.37239 .55604 .37493 .5757 .38035 .57404 .3777 .55617 Mtetra
.347 .273 .63 r
.3777 .55617 .38035 .57404 .38577 .57238 .38269 .56434 Mtetra
.564 .519 .763 r
.38269 .56434 .38577 .57238 .3912 .57071 .38805 .56449 Mtetra
.666 .613 .786 r
.38805 .56449 .3912 .57071 .39654 .57201 .39352 .56229 Mtetra
.627 .528 .723 r
.39352 .56229 .39654 .57201 .40196 .57126 .39898 .56061 Mtetra
.237 .267 .69 r
.39898 .56061 .40196 .57126 .40777 .55983 .40415 .5671 Mtetra
.591 .239 .341 r
.40415 .5671 .40777 .55983 .41348 .55101 .40952 .56908 Mtetra
.401 .141 .4 r
.40952 .56908 .41348 .55101 .41859 .5607 .41518 .56292 Mtetra
0 0 0 r
.41518 .56292 .41859 .5607 .42403 .56085 .42075 .55939 Mtetra
.902 .826 .762 r
.42075 .55939 .42403 .56085 .42967 .55488 .42648 .55051 Mtetra
.011 .329 .814 r
.42648 .55051 .42967 .55488 .43533 .54765 .43185 .55432 Mtetra
.197 0 .115 r
.43185 .55432 .43533 .54765 .44089 .54419 .43745 .55015 Mtetra
.247 0 .109 r
.43745 .55015 .44089 .54419 .44646 .54079 .44304 .54692 Mtetra
.092 0 .034 r
.44304 .54692 .44646 .54079 .45207 .53573 .44867 .54216 Mtetra
0 0 0 r
.44867 .54216 .45207 .53573 .45761 .53401 .45437 .53397 Mtetra
.548 .92 .938 r
.45437 .53397 .45761 .53401 .46311 .53524 .45994 .5318 Mtetra
0 .097 .611 r
.45994 .5318 .46311 .53524 .46865 .53535 .4654 .5368 Mtetra
.968 .913 .7 r
.4654 .5368 .46865 .53535 .47413 .54029 .47116 .52518 Mtetra
.609 .472 .67 r
.47116 .52518 .47413 .54029 .47979 .5349 .47675 .52344 Mtetra
.598 .492 .705 r
.47675 .52344 .47979 .5349 .48547 .52679 .48235 .52257 Mtetra
.847 .73 .734 r
.48235 .52257 .48547 .52679 .49109 .52505 .48804 .51363 Mtetra
.736 .576 .676 r
.48804 .51363 .49109 .52505 .49678 .51535 .49372 .50538 Mtetra
.591 .505 .726 r
.49372 .50538 .49678 .51535 .50239 .51532 .49933 .50483 Mtetra
.696 .561 .698 r
.49933 .50483 .50239 .51532 .50803 .51339 .50498 .49977 Mtetra
.51 .416 .685 r
.50498 .49977 .50803 .51339 .51367 .51221 .5106 .50208 Mtetra
.572 .491 .726 r
.5106 .50208 .51367 .51221 .51933 .51228 .51626 .50211 Mtetra
.705 .57 .7 r
.51626 .50211 .51933 .51228 .52501 .50483 .52193 .49674 Mtetra
.775 .631 .702 r
.52193 .49674 .52501 .50483 .53067 .49336 .5276 .48846 Mtetra
.116 .363 .826 r
.5276 .48846 .53067 .49336 .53636 .49753 .5333 .49239 Mtetra
.552 .601 .856 r
.5333 .49239 .53636 .49753 .54208 .50002 .539 .49242 Mtetra
0 0 .441 r
.539 .49242 .54208 .50002 .54788 .51184 .5448 .50407 Mtetra
0 0 .559 r
.5448 .50407 .54788 .51184 .55367 .51485 .55064 .51415 Mtetra
.763 .946 .939 r
.55064 .51415 .55367 .51485 .55942 .51067 .5564 .51052 Mtetra
.949 .897 .742 r
.5564 .51052 .55942 .51067 .56492 .48622 .5621 .50055 Mtetra
.389 .115 .373 r
.5621 .50055 .56492 .48622 .57087 .49863 .56784 .49507 Mtetra
.913 .751 .667 r
.56784 .49507 .57087 .49863 .57661 .49361 .57344 .47969 Mtetra
.53 .429 .684 r
.57344 .47969 .57661 .49361 .58233 .48765 .57928 .4814 Mtetra
.835 .686 .698 r
.57928 .4814 .58233 .48765 .5882 .49003 .58492 .47065 Mtetra
.555 .417 .648 r
.58492 .47065 .5882 .49003 .59394 .4842 .59077 .47163 Mtetra
.312 .297 .682 r
.59077 .47163 .59394 .4842 .59982 .48483 .59678 .47879 Mtetra
.877 .701 .66 r
.59678 .47879 .59982 .48483 .60551 .47709 .6023 .46318 Mtetra
.539 .436 .685 r
.6023 .46318 .60551 .47709 .61119 .46925 .60821 .46455 Mtetra
0 .16 .699 r
.60821 .46455 .61119 .46925 .61704 .46745 .61427 .47064 Mtetra
.548 .086 .108 r
.61427 .47064 .61704 .46745 .62289 .46562 .62025 .47232 Mtetra
.438 .072 .244 r
.62025 .47232 .62289 .46562 .62876 .46407 .62616 .47103 Mtetra
.687 .325 .354 r
.62616 .47103 .62876 .46407 .63464 .46223 .63231 .47688 Mtetra
.499 .213 .41 r
.63231 .47688 .63464 .46223 .64111 .47664 .63825 .47504 Mtetra
.337 .737 .982 r
.63825 .47504 .64111 .47664 .64718 .47841 .64426 .47509 Mtetra
0 0 .493 r
.64426 .47509 .64718 .47841 .65349 .48582 .65056 .48202 Mtetra
.221 .498 .902 r
.65056 .48202 .65349 .48582 .65968 .48899 .65672 .48456 Mtetra
.659 .689 .867 r
.65672 .48456 .65968 .48899 .66576 .48896 .66273 .48271 Mtetra
.857 .698 .684 r
.66273 .48271 .66576 .48896 .6707 .46273 .6683 .47028 Mtetra
.578 .218 .323 r
.6683 .47028 .6707 .46273 .67685 .4645 .67448 .47213 Mtetra
.3 0 .222 r
.67448 .47213 .67685 .4645 .68251 .45541 .68041 .46796 Mtetra
0 0 0 r
.68041 .46796 .68251 .45541 .68829 .44893 .68542 .44491 Mtetra
0 .191 .717 r
.68542 .44491 .68829 .44893 .69438 .44858 .69183 .45062 Mtetra
.838 .419 .241 r
.69183 .45062 .69438 .44858 .70133 .46387 .69859 .46227 Mtetra
.891 .465 .115 r
.69859 .46227 .70133 .46387 .70779 .46902 .70564 .47811 Mtetra
.274 0 .257 r
.70564 .47811 .70779 .46902 .714 .46903 .71156 .47244 Mtetra
.985 .859 .489 r
.71156 .47244 .714 .46903 .71877 .44448 .71655 .45099 Mtetra
.374 .01 .211 r
.71655 .45099 .71877 .44448 .72433 .43402 .72264 .44861 Mtetra
.637 .331 .436 r
.72264 .44861 .72433 .43402 .73114 .44368 .72923 .45422 Mtetra
0 0 .155 r
.72923 .45422 .73114 .44368 .73748 .44518 .73464 .44074 Mtetra
.643 .685 .874 r
.73464 .44074 .73748 .44518 .74344 .44059 .74081 .43915 Mtetra
.424 0 0 r
.74081 .43915 .74344 .44059 .74983 .44236 .74738 .44334 Mtetra
.313 0 0 r
.74738 .44334 .74983 .44236 .75616 .44266 .75375 .44408 Mtetra
.687 .176 .018 r
.75375 .44408 .75616 .44266 .76261 .4445 .76045 .44915 Mtetra
.331 0 .094 r
.76045 .44915 .76261 .4445 .76882 .44258 .76668 .44722 Mtetra
.463 .039 .15 r
.76668 .44722 .76882 .44258 .77532 .44443 .77307 .44718 Mtetra
.433 0 0 r
.77307 .44718 .77532 .44443 .78111 .43679 .77952 .44769 Mtetra
0 0 .203 r
.77952 .44769 .78111 .43679 .78705 .4311 .78489 .43444 Mtetra
.97 .851 .448 r
.78489 .43444 .78705 .4311 .79314 .42729 .78957 .41305 Mtetra
.309 .287 .671 r
.78957 .41305 .79314 .42729 .79908 .42161 .79675 .42224 Mtetra
.555 .926 .783 r
.79675 .42224 .79908 .42161 .80554 .42202 .80287 .41841 Mtetra
.521 .68 .938 r
.80287 .41841 .80554 .42202 .81133 .41448 .80932 .41833 Mtetra
.717 .281 .213 r
.80932 .41833 .81133 .41448 .81831 .42026 .81638 .42469 Mtetra
0 0 0 r
.81638 .42469 .81831 .42026 .82463 .4183 .8222 .41711 Mtetra
.973 .876 .678 r
.8222 .41711 .82463 .4183 .83064 .41308 .82755 .40453 Mtetra
0 0 .244 r
.82755 .40453 .83064 .41308 .8381 .42277 .8364 .42888 Mtetra
.864 .49 .338 r
.8364 .42888 .8381 .42277 .84665 .4429 .84513 .45072 Mtetra
0 0 .143 r
.84513 .45072 .84665 .4429 .85384 .44851 .85082 .44103 Mtetra
.848 .685 .679 r
.85082 .44103 .85384 .44851 .86079 .45131 .85623 .4287 Mtetra
.662 .481 .63 r
.85623 .4287 .86079 .45131 .86638 .44079 .86209 .42098 Mtetra
.619 .462 .647 r
.86209 .42098 .86638 .44079 .87233 .4338 .86841 .41772 Mtetra
.609 .472 .67 r
.86841 .41772 .87233 .4338 .87781 .42258 .87488 .41573 Mtetra
.836 .692 .705 r
.87488 .41573 .87781 .42258 .88236 .40319 .88047 .40556 Mtetra
.974 .834 .426 r
.88047 .40556 .88236 .40319 .88726 .38744 .88461 .38277 Mtetra
.533 .627 .89 r
.88461 .38277 .88726 .38744 .89297 .37904 .89131 .3829 Mtetra
.874 .47 .261 r
.89131 .3829 .89297 .37904 .90261 .40433 .90029 .40241 Mtetra
0 .425 .828 r
.90029 .40241 .90261 .40433 .90918 .40278 .90741 .40538 Mtetra
.676 .837 .414 r
.90741 .40538 .90918 .40278 .9141 .38746 .91304 .39569 Mtetra
0 0 .129 r
.91304 .39569 .9141 .38746 .92105 .38897 .91819 .38222 Mtetra
.648 .611 .798 r
.91819 .38222 .92105 .38897 .92736 .38506 .92473 .38018 Mtetra
0 0 0 r
.33509 .59607 .33905 .58809 .34416 .59123 .34091 .58635 Mtetra
.758 .685 .781 r
.34091 .58635 .34416 .59123 .34888 .60253 .34645 .58169 Mtetra
.66 .486 .637 r
.34645 .58169 .34888 .60253 .35536 .57938 .35209 .57508 Mtetra
.895 .711 .646 r
.35209 .57508 .35536 .57938 .36128 .56664 .35842 .55448 Mtetra
.713 .557 .675 r
.35842 .55448 .36128 .56664 .367 .55771 .36405 .5474 Mtetra
.283 .301 .703 r
.36405 .5474 .367 .55771 .37239 .55604 .3691 .55294 Mtetra
.756 .761 .856 r
.3691 .55294 .37239 .55604 .3777 .55617 .37458 .54945 Mtetra
0 0 .529 r
.37458 .54945 .3777 .55617 .38269 .56434 .37956 .5576 Mtetra
.26 .374 .79 r
.37956 .5576 .38269 .56434 .38805 .56449 .38477 .56139 Mtetra
.803 .327 0 r
.38477 .56139 .38805 .56449 .39352 .56229 .38983 .56949 Mtetra
0 0 0 r
.38983 .56949 .39352 .56229 .39898 .56061 .39552 .56238 Mtetra
.527 .015 0 r
.39552 .56238 .39898 .56061 .40415 .5671 .40088 .56399 Mtetra
.759 .271 0 r
.40088 .56399 .40415 .5671 .40952 .56908 .40606 .57149 Mtetra
.666 .945 .688 r
.40606 .57149 .40952 .56908 .41518 .56292 .41171 .56611 Mtetra
.196 0 0 r
.41171 .56611 .41518 .56292 .42075 .55939 .41724 .56441 Mtetra
0 0 0 r
.41724 .56441 .42075 .55939 .42648 .55051 .4229 .55892 Mtetra
.525 .185 .333 r
.4229 .55892 .42648 .55051 .43185 .55432 .42839 .55907 Mtetra
.906 .935 .564 r
.42839 .55907 .43185 .55432 .43745 .55015 .43424 .5467 Mtetra
.839 .754 .769 r
.43424 .5467 .43745 .55015 .44304 .54692 .43994 .53946 Mtetra
.693 .601 .748 r
.43994 .53946 .44304 .54692 .44867 .54216 .44554 .53594 Mtetra
.441 .5 .825 r
.44554 .53594 .44867 .54216 .45437 .53397 .45103 .53771 Mtetra
0 0 0 r
.45103 .53771 .45437 .53397 .45994 .5318 .45666 .53362 Mtetra
.531 .019 0 r
.45666 .53362 .45994 .5318 .4654 .5368 .46219 .53533 Mtetra
.936 .791 .675 r
.46219 .53533 .4654 .5368 .47116 .52518 .46802 .5202 Mtetra
.549 .606 .862 r
.46802 .5202 .47116 .52518 .47675 .52344 .47359 .52023 Mtetra
.788 .768 .835 r
.47359 .52023 .47675 .52344 .48235 .52257 .47924 .51573 Mtetra
.743 .637 .742 r
.47924 .51573 .48235 .52257 .48804 .51363 .48491 .51039 Mtetra
.861 .766 .756 r
.48491 .51039 .48804 .51363 .49372 .50538 .4906 .50213 Mtetra
.429 .649 .951 r
.4906 .50213 .49372 .50538 .49933 .50483 .49621 .50274 Mtetra
.591 .805 .981 r
.49621 .50274 .49933 .50483 .50498 .49977 .50184 .50153 Mtetra
.695 .966 .737 r
.50184 .50153 .50498 .49977 .5106 .50208 .50752 .49635 Mtetra
.686 .641 .798 r
.50752 .49635 .5106 .50208 .51626 .50211 .51318 .49368 Mtetra
.55 .506 .759 r
.51318 .49368 .51626 .50211 .52193 .49674 .51885 .49417 Mtetra
.877 .799 .769 r
.51885 .49417 .52193 .49674 .5276 .48846 .52453 .48607 Mtetra
.937 .572 .282 r
.52453 .48607 .5276 .48846 .5333 .49239 .53026 .50751 Mtetra
.395 .124 .38 r
.53026 .50751 .5333 .49239 .539 .49242 .53598 .50203 Mtetra
.544 .216 .362 r
.53598 .50203 .539 .49242 .5448 .50407 .54174 .50263 Mtetra
.914 .522 .24 r
.54174 .50263 .5448 .50407 .55064 .51415 .54762 .51909 Mtetra
0 0 0 r
.54762 .51909 .55064 .51415 .5564 .51052 .5534 .5136 Mtetra
.33 0 0 r
.5534 .5136 .5564 .51052 .5621 .50055 .55922 .51284 Mtetra
.422 .128 .358 r
.55922 .51284 .5621 .50055 .56784 .49507 .56502 .50919 Mtetra
0 0 .02 r
.56502 .50919 .56784 .49507 .57344 .47969 .57059 .48804 Mtetra
0 0 .068 r
.57059 .48804 .57344 .47969 .57928 .4814 .57628 .47894 Mtetra
.895 .809 .756 r
.57628 .47894 .57928 .4814 .58492 .47065 .58197 .46999 Mtetra
.717 .183 0 r
.58197 .46999 .58492 .47065 .59077 .47163 .58792 .47575 Mtetra
.797 .897 .486 r
.58792 .47575 .59077 .47163 .59678 .47879 .59357 .46494 Mtetra
.349 .31 .673 r
.59357 .46494 .59678 .47879 .6023 .46318 .5996 .47195 Mtetra
.569 .229 .352 r
.5996 .47195 .6023 .46318 .60821 .46455 .60555 .47344 Mtetra
.52 .183 .337 r
.60555 .47344 .60821 .46455 .61427 .47064 .61147 .47344 Mtetra
.478 0 .024 r
.61147 .47344 .61427 .47064 .62025 .47232 .61744 .47432 Mtetra
.981 .912 .618 r
.61744 .47432 .62025 .47232 .62616 .47103 .62299 .46018 Mtetra
.578 .49 .718 r
.62299 .46018 .62616 .47103 .63231 .47688 .62894 .45999 Mtetra
.606 .462 .66 r
.62894 .45999 .63231 .47688 .63825 .47504 .63486 .45813 Mtetra
.633 .48 .658 r
.63486 .45813 .63825 .47504 .64426 .47509 .64073 .45461 Mtetra
.599 .444 .643 r
.64073 .45461 .64426 .47509 .65056 .48202 .64667 .45275 Mtetra
.595 .421 .617 r
.64667 .45275 .65056 .48202 .65672 .48456 .6526 .45037 Mtetra
.574 .4 .608 r
.6526 .45037 .65672 .48456 .66273 .48271 .65862 .44979 Mtetra
.631 .442 .609 r
.65862 .44979 .66273 .48271 .6683 .47028 .66437 .44266 Mtetra
.575 .41 .621 r
.66437 .44266 .6683 .47028 .67448 .47213 .67041 .44221 Mtetra
.536 .379 .615 r
.67041 .44221 .67448 .47213 .68041 .46796 .67664 .44522 Mtetra
.682 .495 .626 r
.67664 .44522 .68041 .46796 .68542 .44491 .68227 .43535 Mtetra
0 0 .522 r
.68227 .43535 .68542 .44491 .69183 .45062 .68909 .44943 Mtetra
.423 0 0 r
.68909 .44943 .69183 .45062 .69859 .46227 .69544 .45309 Mtetra
.51 .474 .753 r
.69544 .45309 .69859 .46227 .70564 .47811 .70171 .45467 Mtetra
.548 .401 .634 r
.70171 .45467 .70564 .47811 .71156 .47244 .70801 .45632 Mtetra
.687 .52 .655 r
.70801 .45632 .71156 .47244 .71655 .45099 .71382 .4491 Mtetra
.713 .875 .957 r
.71382 .4491 .71655 .45099 .72264 .44861 .71989 .44628 Mtetra
.939 .822 .703 r
.71989 .44628 .72264 .44861 .72923 .45422 .72541 .43424 Mtetra
.752 .548 .619 r
.72541 .43424 .72923 .45422 .73464 .44074 .7306 .4175 Mtetra
.454 .338 .631 r
.7306 .4175 .73464 .44074 .74081 .43915 .73732 .42489 Mtetra
.298 .278 .667 r
.73732 .42489 .74081 .43915 .74738 .44334 .74421 .43406 Mtetra
.507 .472 .753 r
.74421 .43406 .74738 .44334 .75375 .44408 .75065 .43578 Mtetra
.832 .661 .671 r
.75065 .43578 .75375 .44408 .76045 .44915 .75609 .42312 Mtetra
.249 .19 .592 r
.75609 .42312 .76045 .44915 .76668 .44722 .76383 .44235 Mtetra
.235 .443 .86 r
.76383 .44235 .76668 .44722 .77307 .44718 .77049 .44588 Mtetra
.842 .936 .888 r
.77049 .44588 .77307 .44718 .77952 .44769 .77651 .44066 Mtetra
.87 .695 .663 r
.77651 .44066 .77952 .44769 .78489 .43444 .7818 .42621 Mtetra
.536 .51 .774 r
.7818 .42621 .78489 .43444 .78957 .41305 .7883 .42703 Mtetra
.448 .166 .392 r
.7883 .42703 .78957 .41305 .79675 .42224 .79443 .4232 Mtetra
.599 .933 .731 r
.79443 .4232 .79675 .42224 .80287 .41841 .8005 .41855 Mtetra
.015 0 0 r
.8005 .41855 .80287 .41841 .80932 .41833 .80697 .41847 Mtetra
.899 .986 .77 r
.80697 .41847 .80932 .41833 .81638 .42469 .81279 .41086 Mtetra
.531 .436 .692 r
.81279 .41086 .81638 .42469 .8222 .41711 .81946 .41264 Mtetra
.614 .677 .886 r
.81946 .41264 .8222 .41711 .82755 .40453 .82589 .41149 Mtetra
.741 .361 .332 r
.82589 .41149 .82755 .40453 .8364 .42888 .83333 .42081 Mtetra
0 .033 .599 r
.83333 .42081 .8364 .42888 .84513 .45072 .84116 .43354 Mtetra
.662 .5 .655 r
.84116 .43354 .84513 .45072 .85082 .44103 .84723 .42773 Mtetra
.775 .589 .648 r
.84723 .42773 .85082 .44103 .85623 .4287 .85258 .41486 Mtetra
.681 .53 .674 r
.85258 .41486 .85623 .4287 .86209 .42098 .85863 .40907 Mtetra
.676 .543 .695 r
.85863 .40907 .86209 .42098 .86841 .41772 .8648 .40439 Mtetra
.661 .522 .683 r
.8648 .40439 .86841 .41772 .87488 .41573 .871 .39999 Mtetra
.61 .474 .672 r
.871 .39999 .87488 .41573 .88047 .40556 .87747 .39798 Mtetra
.919 .705 .597 r
.87747 .39798 .88047 .40556 .88461 .38277 .88166 .37538 Mtetra
.56 .545 .795 r
.88166 .37538 .88461 .38277 .89131 .3829 .88836 .37554 Mtetra
0 .075 .632 r
.88836 .37554 .89131 .3829 .90029 .40241 .89643 .38735 Mtetra
.513 .417 .684 r
.89643 .38735 .90029 .40241 .90741 .40538 .90352 .39014 Mtetra
.643 .498 .671 r
.90352 .39014 .90741 .40538 .91304 .39569 .90983 .38621 Mtetra
.632 .547 .74 r
.90983 .38621 .91304 .39569 .91819 .38222 .91638 .38417 Mtetra
0 0 0 r
.91638 .38417 .91819 .38222 .92473 .38018 .92271 .38022 Mtetra
.829 .782 .279 r
.3305 .61432 .33509 .59607 .34091 .58635 .33758 .58267 Mtetra
.875 .729 .697 r
.33758 .58267 .34091 .58635 .34645 .58169 .34355 .57002 Mtetra
.748 .582 .669 r
.34355 .57002 .34645 .58169 .35209 .57508 .34935 .56033 Mtetra
.721 .548 .655 r
.34935 .56033 .35209 .57508 .35842 .55448 .35513 .55092 Mtetra
.83 .74 .765 r
.35513 .55092 .35842 .55448 .36405 .5474 .36077 .54382 Mtetra
.138 .465 .891 r
.36077 .54382 .36405 .5474 .3691 .55294 .36596 .54621 Mtetra
.258 .373 .79 r
.36596 .54621 .3691 .55294 .37458 .54945 .37112 .54996 Mtetra
.868 .488 .322 r
.37112 .54996 .37458 .54945 .37956 .5576 .37594 .56179 Mtetra
.284 0 .017 r
.37594 .56179 .37956 .5576 .38477 .56139 .38139 .56011 Mtetra
.841 .383 .11 r
.38139 .56011 .38477 .56139 .38983 .56949 .38646 .56819 Mtetra
.884 .848 .803 r
.38646 .56819 .38983 .56949 .39552 .56238 .39216 .56106 Mtetra
.588 .015 0 r
.39216 .56106 .39552 .56238 .40088 .56399 .39744 .56494 Mtetra
.224 0 0 r
.39744 .56494 .40088 .56399 .40606 .57149 .40289 .56504 Mtetra
.777 .656 .729 r
.40289 .56504 .40606 .57149 .41171 .56611 .4086 .55807 Mtetra
.569 .523 .765 r
.4086 .55807 .41171 .56611 .41724 .56441 .41407 .55809 Mtetra
.754 .65 .747 r
.41407 .55809 .41724 .56441 .4229 .55892 .41974 .55255 Mtetra
.706 .63 .769 r
.41974 .55255 .4229 .55892 .42839 .55907 .42534 .54903 Mtetra
.726 .583 .694 r
.42534 .54903 .42839 .55907 .43424 .5467 .43104 .5424 Mtetra
.787 .718 .787 r
.43104 .5424 .43424 .5467 .43994 .53946 .43669 .53702 Mtetra
.266 .629 .962 r
.43669 .53702 .43994 .53946 .44554 .53594 .44219 .53804 Mtetra
0 0 0 r
.44219 .53804 .44554 .53594 .45103 .53771 .44781 .53466 Mtetra
.661 .753 .919 r
.44781 .53466 .45103 .53771 .45666 .53362 .45341 .53292 Mtetra
.548 0 0 r
.45341 .53292 .45666 .53362 .46219 .53533 .45891 .5362 Mtetra
.938 .944 .765 r
.45891 .5362 .46219 .53533 .46802 .5202 .46466 .52754 Mtetra
.581 .225 .331 r
.46466 .52754 .46802 .5202 .47359 .52023 .47022 .52932 Mtetra
0 0 .086 r
.47022 .52932 .47359 .52023 .47924 .51573 .47597 .52063 Mtetra
0 0 0 r
.47597 .52063 .47924 .51573 .48491 .51039 .48169 .51253 Mtetra
.48169 .51253 .48491 .51039 .4906 .50213 .48735 .50899 Mtetra
.48735 .50899 .4906 .50213 .49621 .50274 .49307 .50004 Mtetra
.743 .796 .895 r
.49307 .50004 .49621 .50274 .50184 .50153 .49873 .49692 Mtetra
.561 .63 .877 r
.49873 .49692 .50184 .50153 .50752 .49635 .50438 .49671 Mtetra
.799 .991 .88 r
.50438 .49671 .50752 .49635 .51318 .49368 .51007 .49203 Mtetra
.669 .125 0 r
.51007 .49203 .51318 .49368 .51885 .49417 .51573 .49753 Mtetra
.752 .347 .284 r
.51573 .49753 .51885 .49417 .52453 .48607 .52143 .50435 Mtetra
.744 .453 .489 r
.52143 .50435 .52453 .48607 .53026 .50751 .52717 .52298 Mtetra
.333 .072 .36 r
.52717 .52298 .53026 .50751 .53598 .50203 .53294 .51558 Mtetra
.636 .332 .438 r
.53294 .51558 .53598 .50203 .54174 .50263 .53875 .52063 Mtetra
.55 .271 .445 r
.53875 .52063 .54174 .50263 .54762 .51909 .54456 .52092 Mtetra
.841 .441 .286 r
.54456 .52092 .54762 .51909 .5534 .5136 .55049 .53226 Mtetra
.516 .244 .44 r
.55049 .53226 .5534 .5136 .55922 .51284 .55634 .53068 Mtetra
.11 0 .299 r
.55634 .53068 .55922 .51284 .56502 .50919 .56207 .51585 Mtetra
.881 .859 .407 r
.56207 .51585 .56502 .50919 .57059 .48804 .56772 .49796 Mtetra
0 0 .047 r
.56772 .49796 .57059 .48804 .57628 .47894 .57341 .48555 Mtetra
.804 .832 .362 r
.57341 .48555 .57628 .47894 .58197 .46999 .57901 .46979 Mtetra
.469 .885 .927 r
.57901 .46979 .58197 .46999 .58792 .47575 .58484 .46796 Mtetra
.084 .231 .719 r
.58484 .46796 .58792 .47575 .59357 .46494 .59085 .47486 Mtetra
.744 .415 .425 r
.59085 .47486 .59357 .46494 .5996 .47195 .597 .48631 Mtetra
.607 .306 .433 r
.597 .48631 .5996 .47195 .60555 .47344 .60303 .48981 Mtetra
.181 0 .321 r
.60303 .48981 .60555 .47344 .61147 .47344 .60868 .47744 Mtetra
.965 .896 .523 r
.60868 .47744 .61147 .47344 .61744 .47432 .61419 .46044 Mtetra
.555 .446 .686 r
.61419 .46044 .61744 .47432 .62299 .46018 .62016 .46116 Mtetra
.673 .155 0 r
.62016 .46116 .62299 .46018 .62894 .45999 .62627 .46555 Mtetra
.736 .817 .35 r
.62627 .46555 .62894 .45999 .63486 .45813 .63185 .45238 Mtetra
.856 .473 0 r
.63185 .45238 .63486 .45813 .64073 .45461 .6385 .47131 Mtetra
.181 0 .329 r
.6385 .47131 .64073 .45461 .64667 .45275 .64408 .45838 Mtetra
.501 .106 .224 r
.64408 .45838 .64667 .45275 .6526 .45037 .65014 .45866 Mtetra
.515 .168 .318 r
.65014 .45866 .6526 .45037 .65862 .44979 .65621 .45865 Mtetra
.447 .114 .307 r
.65621 .45865 .65862 .44979 .66437 .44266 .66222 .45677 Mtetra
0 0 .204 r
.66222 .45677 .66437 .44266 .67041 .44221 .6676 .44017 Mtetra
.071 .535 .899 r
.6676 .44017 .67041 .44221 .67664 .44522 .67377 .44197 Mtetra
.27 .567 .936 r
.67377 .44197 .67664 .44522 .68227 .43535 .67997 .44375 Mtetra
.501 .157 .315 r
.67997 .44375 .68227 .43535 .68909 .44943 .6861 .44336 Mtetra
.211 .373 .808 r
.6861 .44336 .68909 .44943 .69544 .45309 .69249 .44789 Mtetra
0 .196 .726 r
.69249 .44789 .69544 .45309 .70171 .45467 .69902 .4544 Mtetra
.551 0 0 r
.69902 .4544 .70171 .45467 .70801 .45632 .70546 .45823 Mtetra
.764 .301 .148 r
.70546 .45823 .70801 .45632 .71382 .4491 .71212 .46553 Mtetra
0 0 .125 r
.71212 .46553 .71382 .4491 .71989 .44628 .71685 .43904 Mtetra
.898 .697 .621 r
.71685 .43904 .71989 .44628 .72541 .43424 .72184 .41826 Mtetra
.433 .355 .668 r
.72184 .41826 .72541 .43424 .7306 .4175 .72845 .42409 Mtetra
0 0 0 r
.72845 .42409 .7306 .4175 .73732 .42489 .73393 .412 Mtetra
.048 .12 .618 r
.73393 .412 .73732 .42489 .74421 .43406 .7411 .42553 Mtetra
.626 .555 .754 r
.7411 .42553 .74421 .43406 .75065 .43578 .7473 .4239 Mtetra
.801 .612 .647 r
.7473 .4239 .75065 .43578 .75609 .42312 .75262 .40959 Mtetra
0 0 .53 r
.75262 .40959 .75609 .42312 .76383 .44235 .76031 .42833 Mtetra
.294 .278 .671 r
.76031 .42833 .76383 .44235 .77049 .44588 .76737 .43754 Mtetra
.767 .633 .713 r
.76737 .43754 .77049 .44588 .77651 .44066 .77322 .42998 Mtetra
.76 .601 .68 r
.77322 .42998 .77651 .44066 .7818 .42621 .77893 .42081 Mtetra
0 .017 .588 r
.77893 .42081 .7818 .42621 .7883 .42703 .78614 .43042 Mtetra
0 0 0 r
.78614 .43042 .7883 .42703 .79443 .4232 .79223 .42582 Mtetra
.79223 .42582 .79443 .4232 .8005 .41855 .79834 .42137 Mtetra
.381 0 0 r
.79834 .42137 .8005 .41855 .80697 .41847 .80484 .42128 Mtetra
.852 .898 .479 r
.80484 .42128 .80697 .41847 .81279 .41086 .81027 .40897 Mtetra
.441 0 0 r
.81027 .40897 .81279 .41086 .81946 .41264 .81728 .41436 Mtetra
.733 .934 .602 r
.81728 .41436 .81946 .41264 .82589 .41149 .82314 .40683 Mtetra
.224 .448 .866 r
.82314 .40683 .82589 .41149 .83333 .42081 .83003 .41039 Mtetra
.581 .502 .731 r
.83003 .41039 .83333 .42081 .84116 .43354 .83659 .41008 Mtetra
.573 .42 .636 r
.83659 .41008 .84116 .43354 .84723 .42773 .84319 .40988 Mtetra
.745 .549 .629 r
.84319 .40988 .84723 .42773 .85258 .41486 .84843 .39604 Mtetra
.714 .526 .634 r
.84843 .39604 .85258 .41486 .85863 .40907 .85391 .38485 Mtetra
.585 .426 .632 r
.85391 .38485 .85863 .40907 .8648 .40439 .86041 .38363 Mtetra
.617 .456 .642 r
.86041 .38363 .8648 .40439 .871 .39999 .86671 .38031 Mtetra
.671 .495 .639 r
.86671 .38031 .871 .39999 .87747 .39798 .87256 .37282 Mtetra
.579 .42 .63 r
.87256 .37282 .87747 .39798 .88166 .37538 .87915 .37208 Mtetra
0 .19 .706 r
.87915 .37208 .88166 .37538 .88836 .37554 .88654 .37829 Mtetra
.504 .002 0 r
.88654 .37829 .88836 .37554 .89643 .38735 .89346 .3799 Mtetra
.491 .505 .799 r
.89346 .3799 .89643 .38735 .90352 .39014 .90041 .38156 Mtetra
.575 .53 .767 r
.90041 .38156 .90352 .39014 .90983 .38621 .90718 .38138 Mtetra
.633 .674 .871 r
.90718 .38138 .90983 .38621 .91638 .38417 .9138 .37984 Mtetra
.661 .712 .886 r
.9138 .37984 .91638 .38417 .92271 .38022 .92037 .37779 Mtetra
.704 .502 .612 r
.32868 .58365 .3305 .61432 .33758 .58267 .33492 .56679 Mtetra
.638 .487 .661 r
.33492 .56679 .33758 .58267 .34355 .57002 .3404 .5633 Mtetra
.854 .674 .659 r
.3404 .5633 .34355 .57002 .34935 .56033 .34659 .54635 Mtetra
.472 .385 .676 r
.34659 .54635 .34935 .56033 .35513 .55092 .35171 .54962 Mtetra
.779 .881 .921 r
.35171 .54962 .35513 .55092 .36077 .54382 .35719 .54612 Mtetra
.7 .263 .209 r
.35719 .54612 .36077 .54382 .36596 .54621 .3623 .55035 Mtetra
.912 .957 .626 r
.3623 .55035 .36596 .54621 .37112 .54996 .36814 .53958 Mtetra
.954 .641 .218 r
.36814 .53958 .37112 .54996 .37594 .56179 .37223 .56733 Mtetra
.592 .209 .287 r
.37223 .56733 .37594 .56179 .38139 .56011 .37754 .56933 Mtetra
0 0 0 r
.37754 .56933 .38139 .56011 .38646 .56819 .38352 .55602 Mtetra
.735 .571 .67 r
.38352 .55602 .38646 .56819 .39216 .56106 .38929 .5472 Mtetra
0 0 .444 r
.38929 .5472 .39216 .56106 .39744 .56494 .39411 .56261 Mtetra
.768 .815 .89 r
.39411 .56261 .39744 .56494 .40289 .56504 .3997 .5591 Mtetra
.819 .68 .71 r
.3997 .5591 .40289 .56504 .4086 .55807 .40551 .54947 Mtetra
0 .077 .624 r
.40551 .54947 .4086 .55807 .41407 .55809 .4107 .55782 Mtetra
.921 .89 .784 r
.4107 .55782 .41407 .55809 .41974 .55255 .41647 .54953 Mtetra
.866 .767 .75 r
.41647 .54953 .41974 .55255 .42534 .54903 .42224 .5408 Mtetra
.743 .613 .714 r
.42224 .5408 .42534 .54903 .43104 .5424 .42793 .53446 Mtetra
.636 .562 .755 r
.42793 .53446 .43104 .5424 .43669 .53702 .43349 .53272 Mtetra
.714 .701 .837 r
.43349 .53272 .43669 .53702 .44219 .53804 .43909 .52981 Mtetra
.777 .63 .698 r
.43909 .52981 .44219 .53804 .44781 .53466 .44484 .52109 Mtetra
.062 .11 .6 r
.44484 .52109 .44781 .53466 .45341 .53292 .45013 .5323 Mtetra
.597 .025 0 r
.45013 .5323 .45341 .53292 .45891 .5362 .45564 .53594 Mtetra
.891 .931 .838 r
.45564 .53594 .45891 .5362 .46466 .52754 .46136 .52954 Mtetra
.03 0 0 r
.46136 .52954 .46466 .52754 .47022 .52932 .467 .52787 Mtetra
.847 .874 .861 r
.467 .52787 .47022 .52932 .47597 .52063 .47271 .52256 Mtetra
.985 .864 .634 r
.47271 .52256 .47597 .52063 .48169 .51253 .47857 .50567 Mtetra
.562 .548 .797 r
.47857 .50567 .48169 .51253 .48735 .50899 .4842 .50573 Mtetra
.894 .758 .703 r
.4842 .50573 .48735 .50899 .49307 .50004 .48996 .4936 Mtetra
.249 .381 .801 r
.48996 .4936 .49307 .50004 .49873 .49692 .49556 .4975 Mtetra
.908 .967 .805 r
.49556 .4975 .49873 .49692 .50438 .49671 .50128 .49036 Mtetra
.391 .469 .821 r
.50128 .49036 .50438 .49671 .51007 .49203 .50693 .4928 Mtetra
.896 .529 .334 r
.50693 .4928 .51007 .49203 .51573 .49753 .51255 .51018 Mtetra
.618 .31 .425 r
.51255 .51018 .51573 .49753 .52143 .50435 .51828 .51399 Mtetra
.716 .387 .421 r
.51828 .51399 .52143 .50435 .52717 .52298 .52404 .52279 Mtetra
.478 0 0 r
.52404 .52279 .52717 .52298 .53294 .51558 .52984 .52537 Mtetra
.527 .199 .354 r
.52984 .52537 .53294 .51558 .53875 .52063 .53566 .52547 Mtetra
.758 .38 .339 r
.53566 .52547 .53875 .52063 .54456 .52092 .54154 .53378 Mtetra
.274 .002 .307 r
.54154 .53378 .54456 .52092 .55049 .53226 .54736 .52638 Mtetra
.651 .627 .812 r
.54736 .52638 .55049 .53226 .55634 .53068 .55322 .52454 Mtetra
.556 .572 .825 r
.55322 .52454 .55634 .53068 .56207 .51585 .55911 .52461 Mtetra
.945 .836 .397 r
.55911 .52461 .56207 .51585 .56772 .49796 .56469 .49747 Mtetra
.907 .927 .817 r
.56469 .49747 .56772 .49796 .57341 .48555 .57048 .49032 Mtetra
.945 .897 .504 r
.57048 .49032 .57341 .48555 .57901 .46979 .57611 .47372 Mtetra
.426 0 .085 r
.57611 .47372 .57901 .46979 .58484 .46796 .58198 .47348 Mtetra
.841 .493 .394 r
.58198 .47348 .58484 .46796 .59085 .47486 .58821 .49094 Mtetra
.678 .379 .46 r
.58821 .49094 .59085 .47486 .597 .48631 .59435 .50017 Mtetra
0 0 .105 r
.59435 .50017 .597 .48631 .60303 .48981 .59991 .48183 Mtetra
.852 .669 .655 r
.59991 .48183 .60303 .48981 .60868 .47744 .60549 .4661 Mtetra
.651 .529 .702 r
.60549 .4661 .60868 .47744 .61419 .46044 .61137 .46293 Mtetra
.369 0 0 r
.61137 .46293 .61419 .46044 .62016 .46116 .61734 .46291 Mtetra
.981 .914 .63 r
.61734 .46291 .62016 .46116 .62627 .46555 .62292 .44919 Mtetra
.688 .519 .652 r
.62292 .44919 .62627 .46555 .63185 .45238 .62867 .44178 Mtetra
0 0 .357 r
.62867 .44178 .63185 .45238 .6385 .47131 .63528 .46017 Mtetra
.573 .484 .716 r
.63528 .46017 .6385 .47131 .64408 .45838 .64133 .46013 Mtetra
.389 0 0 r
.64133 .46013 .64408 .45838 .65014 .45866 .64742 .46079 Mtetra
.06 0 0 r
.64742 .46079 .65014 .45866 .65621 .45865 .65343 .45891 Mtetra
.633 .078 0 r
.65343 .45891 .65621 .45865 .66222 .45677 .65971 .46314 Mtetra
0 0 0 r
.65971 .46314 .66222 .45677 .6676 .44017 .66527 .45003 Mtetra
.19 0 .238 r
.66527 .45003 .6676 .44017 .67377 .44197 .67107 .44256 Mtetra
.966 .932 .694 r
.67107 .44256 .67377 .44197 .67997 .44375 .67669 .43156 Mtetra
.387 .355 .701 r
.67669 .43156 .67997 .44375 .6861 .44336 .68308 .43704 Mtetra
.274 .403 .812 r
.68308 .43704 .6861 .44336 .69249 .44789 .68945 .44107 Mtetra
0 0 .508 r
.68945 .44107 .69249 .44789 .69902 .4544 .69625 .45266 Mtetra
.675 .145 0 r
.69625 .45266 .69902 .4544 .70546 .45823 .70287 .45982 Mtetra
.041 0 0 r
.70287 .45982 .70546 .45823 .71212 .46553 .70906 .45831 Mtetra
.828 .676 .694 r
.70906 .45831 .71212 .46553 .71685 .43904 .71472 .44755 Mtetra
0 0 0 r
.71472 .44755 .71685 .43904 .72184 .41826 .72005 .43173 Mtetra
0 0 .193 r
.72005 .43173 .72184 .41826 .72845 .42409 .72526 .41438 Mtetra
.704 .579 .713 r
.72526 .41438 .72845 .42409 .73393 .412 .7312 .40929 Mtetra
.807 .349 0 r
.7312 .40929 .73393 .412 .7411 .42553 .73831 .42195 Mtetra
.781 .779 .851 r
.73831 .42195 .7411 .42553 .7473 .4239 .74433 .41753 Mtetra
.864 .704 .682 r
.74433 .41753 .7473 .4239 .75262 .40959 .74979 .40495 Mtetra
0 0 .504 r
.74979 .40495 .75262 .40959 .76031 .42833 .75681 .41459 Mtetra
.423 .366 .689 r
.75681 .41459 .76031 .42833 .76737 .43754 .76358 .41997 Mtetra
.731 .542 .636 r
.76358 .41997 .76737 .43754 .77322 .42998 .76907 .40785 Mtetra
.456 .344 .637 r
.76907 .40785 .77322 .42998 .77893 .42081 .77601 .41482 Mtetra
0 0 .567 r
.77601 .41482 .77893 .42081 .78614 .43042 .78329 .42544 Mtetra
0 .096 .651 r
.78329 .42544 .78614 .43042 .79223 .42582 .79044 .43361 Mtetra
0 0 .046 r
.79044 .43361 .79223 .42582 .79834 .42137 .79594 .4215 Mtetra
.856 .997 .804 r
.79594 .4215 .79834 .42137 .80484 .42128 .8019 .41496 Mtetra
.836 .701 .715 r
.8019 .41496 .80484 .42128 .81027 .40897 .80758 .40531 Mtetra
.88 .796 .762 r
.80758 .40531 .81027 .40897 .81728 .41436 .81335 .3968 Mtetra
.658 .495 .652 r
.81335 .3968 .81728 .41436 .82314 .40683 .81937 .39118 Mtetra
.539 .428 .676 r
.81937 .39118 .82314 .40683 .83003 .41039 .82606 .39276 Mtetra
.661 .497 .651 r
.82606 .39276 .83003 .41039 .83659 .41008 .83207 .38685 Mtetra
.578 .423 .635 r
.83207 .38685 .83659 .41008 .84319 .40988 .83859 .38627 Mtetra
.686 .494 .621 r
.83859 .38627 .84319 .40988 .84843 .39604 .84411 .37541 Mtetra
.607 .451 .643 r
.84411 .37541 .84843 .39604 .85391 .38485 .85045 .37279 Mtetra
.297 .303 .697 r
.85045 .37279 .85391 .38485 .86041 .38363 .85793 .38103 Mtetra
.652 .818 .963 r
.85793 .38103 .86041 .38363 .86671 .38031 .86437 .379 Mtetra
.607 .063 0 r
.86437 .379 .86671 .38031 .87256 .37282 .87181 .38599 Mtetra
.53 .225 .395 r
.87181 .38599 .87256 .37282 .87915 .37208 .87851 .38582 Mtetra
.341 .082 .368 r
.87851 .38582 .87915 .37208 .88654 .37829 .88439 .37817 Mtetra
.393 .851 .863 r
.88439 .37817 .88654 .37829 .89346 .3799 .8909 .37612 Mtetra
.442 .634 .936 r
.8909 .37612 .89346 .3799 .90041 .38156 .89777 .37692 Mtetra
.549 .641 .894 r
.89777 .37692 .90041 .38156 .90718 .38138 .90454 .37676 Mtetra
.584 .661 .891 r
.90454 .37676 .90718 .38138 .9138 .37984 .91127 .37605 Mtetra
.35 .579 .928 r
.91127 .37605 .9138 .37984 .92037 .37779 .91833 .37781 Mtetra
.497 .356 .62 r
.32652 .55944 .32868 .58365 .33492 .56679 .33154 .5637 Mtetra
.85 .756 .759 r
.33154 .5637 .33492 .56679 .3404 .5633 .33727 .55581 Mtetra
.742 .621 .725 r
.33727 .55581 .3404 .5633 .34659 .54635 .34288 .55001 Mtetra
.452 .003 .093 r
.34288 .55001 .34659 .54635 .35171 .54962 .34817 .55014 Mtetra
.855 .974 .866 r
.34817 .55014 .35171 .54962 .35719 .54612 .35376 .54481 Mtetra
.841 .383 .113 r
.35376 .54481 .35719 .54612 .3623 .55035 .3587 .55271 Mtetra
0 0 0 r
.3587 .55271 .3623 .55035 .36814 .53958 .36422 .54918 Mtetra
.769 .459 .462 r
.36422 .54918 .36814 .53958 .37223 .56733 .36895 .56291 Mtetra
.838 .717 .729 r
.36895 .56291 .37223 .56733 .37754 .56933 .37476 .55385 Mtetra
.675 .514 .66 r
.37476 .55385 .37754 .56933 .38352 .55602 .38041 .54796 Mtetra
.727 .606 .723 r
.38041 .54796 .38352 .55602 .38929 .5472 .38605 .54261 Mtetra
.616 .651 .862 r
.38605 .54261 .38929 .5472 .39411 .56261 .3915 .54161 Mtetra
.642 .471 .637 r
.3915 .54161 .39411 .56261 .3997 .5591 .39713 .53648 Mtetra
.555 .404 .631 r
.39713 .53648 .3997 .5591 .40551 .54947 .40255 .53736 Mtetra
0 0 .514 r
.40255 .53736 .40551 .54947 .4107 .55782 .40757 .55 Mtetra
.748 .622 .719 r
.40757 .55 .4107 .55782 .41647 .54953 .41328 .54364 Mtetra
.813 .68 .717 r
.41328 .54364 .41647 .54953 .42224 .5408 .41906 .53473 Mtetra
.838 .683 .691 r
.41906 .53473 .42224 .5408 .42793 .53446 .42492 .52302 Mtetra
.517 .441 .709 r
.42492 .52302 .42793 .53446 .43349 .53272 .43038 .52463 Mtetra
.466 .464 .771 r
.43038 .52463 .43349 .53272 .43909 .52981 .43585 .52659 Mtetra
.793 .768 .83 r
.43585 .52659 .43909 .52981 .44484 .52109 .44152 .52189 Mtetra
.826 .403 .235 r
.44152 .52189 .44484 .52109 .45013 .5323 .44687 .53058 Mtetra
.498 0 0 r
.44687 .53058 .45013 .5323 .45564 .53594 .45237 .53441 Mtetra
.675 .129 0 r
.45237 .53441 .45564 .53594 .46136 .52954 .45788 .53961 Mtetra
0 0 .085 r
.45788 .53961 .46136 .52954 .467 .52787 .4637 .52963 Mtetra
.961 .939 .705 r
.4637 .52963 .467 .52787 .47271 .52256 .46952 .51886 Mtetra
.918 .732 .634 r
.46952 .51886 .47271 .52256 .47857 .50567 .47547 .49751 Mtetra
.697 .592 .735 r
.47547 .49751 .47857 .50567 .4842 .50573 .48114 .49352 Mtetra
.76 .585 .661 r
.48114 .49352 .4842 .50573 .48996 .4936 .4869 .48249 Mtetra
.622 .511 .706 r
.4869 .48249 .48996 .4936 .49556 .4975 .49255 .48069 Mtetra
.007 .044 .55 r
.49255 .48069 .49556 .4975 .50128 .49036 .49807 .49605 Mtetra
.774 .418 .381 r
.49807 .49605 .50128 .49036 .50693 .4928 .50369 .50619 Mtetra
.615 .31 .43 r
.50369 .50619 .50693 .4928 .51255 .51018 .5094 .50994 Mtetra
.74 .225 0 r
.5094 .50994 .51255 .51018 .51828 .51399 .51513 .51564 Mtetra
.759 .309 .181 r
.51513 .51564 .51828 .51399 .52404 .52279 .5209 .52198 Mtetra
.168 .685 .889 r
.5209 .52198 .52404 .52279 .52984 .52537 .5267 .52207 Mtetra
.078 .45 .882 r
.5267 .52207 .52984 .52537 .53566 .52547 .53253 .52479 Mtetra
.762 .948 .939 r
.53253 .52479 .53566 .52547 .54154 .53378 .53837 .5211 Mtetra
.513 .43 .699 r
.53837 .5211 .54154 .53378 .54736 .52638 .54424 .52308 Mtetra
.798 .777 .834 r
.54424 .52308 .54736 .52638 .55322 .52454 .55008 .51818 Mtetra
.046 .257 .754 r
.55008 .51818 .55322 .52454 .55911 .52461 .55603 .52393 Mtetra
.969 .787 .603 r
.55603 .52393 .55911 .52461 .56469 .49747 .56169 .50061 Mtetra
0 0 0 r
.56169 .50061 .56469 .49747 .57048 .49032 .56754 .49692 Mtetra
.903 .862 .418 r
.56754 .49692 .57048 .49032 .57611 .47372 .57318 .47801 Mtetra
.703 .297 .276 r
.57318 .47801 .57611 .47372 .58198 .47348 .57917 .48346 Mtetra
.854 .537 .451 r
.57917 .48346 .58198 .47348 .58821 .49094 .58564 .51346 Mtetra
.333 .102 .406 r
.58564 .51346 .58821 .49094 .59435 .50017 .59141 .50216 Mtetra
.995 .822 .558 r
.59141 .50216 .59435 .50017 .59991 .48183 .59686 .47703 Mtetra
.848 .727 .73 r
.59686 .47703 .59991 .48183 .60549 .4661 .60262 .4678 Mtetra
.973 .927 .649 r
.60262 .4678 .60549 .4661 .61137 .46293 .60827 .4552 Mtetra
.736 .623 .732 r
.60827 .4552 .61137 .46293 .61734 .46291 .61409 .44965 Mtetra
.711 .55 .669 r
.61409 .44965 .61734 .46291 .62292 .44919 .61985 .44212 Mtetra
.582 .558 .793 r
.61985 .44212 .62292 .44919 .62867 .44178 .62583 .44176 Mtetra
.758 .251 0 r
.62583 .44176 .62867 .44178 .63528 .46017 .63205 .44847 Mtetra
.572 .478 .709 r
.63205 .44847 .63528 .46017 .64133 .46013 .63809 .44843 Mtetra
.414 .377 .709 r
.63809 .44843 .64133 .46013 .64742 .46079 .64431 .45294 Mtetra
.569 .534 .777 r
.64431 .45294 .64742 .46079 .65343 .45891 .65039 .4529 Mtetra
.858 .704 .69 r
.65039 .4529 .65343 .45891 .65971 .46314 .65602 .44091 Mtetra
.66 .481 .631 r
.65602 .44091 .65971 .46314 .66527 .45003 .66181 .43355 Mtetra
.696 .523 .65 r
.66181 .43355 .66527 .45003 .67107 .44256 .66757 .42543 Mtetra
.324 .272 .644 r
.66757 .42543 .67107 .44256 .67669 .43156 .67412 .43511 Mtetra
.758 .338 .252 r
.67412 .43511 .67669 .43156 .68308 .43704 .68065 .44282 Mtetra
.776 .811 .33 r
.68065 .44282 .68308 .43704 .68945 .44107 .68606 .42732 Mtetra
0 0 .182 r
.68606 .42732 .68945 .44107 .69625 .45266 .69385 .45845 Mtetra
.484 .089 .215 r
.69385 .45845 .69625 .45266 .70287 .45982 .70011 .45843 Mtetra
.553 0 0 r
.70011 .45843 .70287 .45982 .70906 .45831 .70667 .46356 Mtetra
0 0 0 r
.70667 .46356 .70906 .45831 .71472 .44755 .71258 .4565 Mtetra
0 0 .109 r
.71258 .4565 .71472 .44755 .72005 .43173 .71824 .44542 Mtetra
0 0 .084 r
.71824 .44542 .72005 .43173 .72526 .41438 .72316 .42255 Mtetra
.569 .214 .326 r
.72316 .42255 .72526 .41438 .7312 .40929 .72957 .42428 Mtetra
.518 .227 .412 r
.72957 .42428 .7312 .40929 .73831 .42195 .73583 .42333 Mtetra
0 0 0 r
.73583 .42333 .73831 .42195 .74433 .41753 .74204 .42138 Mtetra
.82 .869 .425 r
.74204 .42138 .74433 .41753 .74979 .40495 .74749 .40828 Mtetra
.718 .86 .44 r
.74749 .40828 .74979 .40495 .75681 .41459 .75313 .39825 Mtetra
.519 .41 .67 r
.75313 .39825 .75681 .41459 .76358 .41997 .75967 .40075 Mtetra
.621 .464 .648 r
.75967 .40075 .76358 .41997 .76907 .40785 .7658 .39737 Mtetra
.2 .258 .698 r
.7658 .39737 .76907 .40785 .77601 .41482 .77286 .40594 Mtetra
.671 .355 0 r
.77286 .40594 .77601 .41482 .78329 .42544 .78114 .4294 Mtetra
.635 .189 .175 r
.78114 .4294 .78329 .42544 .79044 .43361 .78795 .43316 Mtetra
.848 .986 .859 r
.78795 .43316 .79044 .43361 .79594 .4215 .794 .42736 Mtetra
.828 .788 .288 r
.794 .42736 .79594 .4215 .8019 .41496 .79882 .40702 Mtetra
.889 .69 .627 r
.79882 .40702 .8019 .41496 .80758 .40531 .80371 .38809 Mtetra
.629 .478 .658 r
.80371 .38809 .80758 .40531 .81335 .3968 .8099 .38457 Mtetra
.653 .525 .695 r
.8099 .38457 .81335 .3968 .81937 .39118 .8161 .381 Mtetra
.664 .553 .719 r
.8161 .381 .81937 .39118 .82606 .39276 .82232 .37753 Mtetra
.381 .328 .674 r
.82232 .37753 .82606 .39276 .83207 .38685 .8296 .38511 Mtetra
.619 .872 .99 r
.8296 .38511 .83207 .38685 .83859 .38627 .836 .38309 Mtetra
.49 .7 .962 r
.836 .38309 .83859 .38627 .84411 .37541 .84261 .38307 Mtetra
.617 .245 .314 r
.84261 .38307 .84411 .37541 .85045 .37279 .84961 .38662 Mtetra
.731 .4 .419 r
.84961 .38662 .85045 .37279 .85793 .38103 .85768 .40022 Mtetra
.443 .187 .429 r
.85768 .40022 .85793 .38103 .86437 .379 .86378 .39436 Mtetra
.558 .26 .418 r
.86378 .39436 .86437 .379 .87181 .38599 .87063 .39549 Mtetra
.383 .07 .305 r
.87063 .39549 .87181 .38599 .87851 .38582 .87696 .39155 Mtetra
0 0 0 r
.87696 .39155 .87851 .38582 .88439 .37817 .88207 .37667 Mtetra
.596 .886 .991 r
.88207 .37667 .88439 .37817 .8909 .37612 .8886 .37462 Mtetra
.874 .942 .857 r
.8886 .37462 .8909 .37612 .89777 .37692 .89466 .36843 Mtetra
.689 .595 .745 r
.89466 .36843 .89777 .37692 .90454 .37676 .90099 .36451 Mtetra
.527 .45 .712 r
.90099 .36451 .90454 .37676 .91127 .37605 .908 .36617 Mtetra
.362 .377 .742 r
.908 .36617 .91127 .37605 .91833 .37781 .91551 .37165 Mtetra
0 0 0 r
.32248 .56723 .32652 .55944 .33154 .5637 .3282 .55987 Mtetra
.744 .723 .832 r
.3282 .55987 .33154 .5637 .33727 .55581 .33369 .55635 Mtetra
.472 .894 .872 r
.33369 .55635 .33727 .55581 .34288 .55001 .33912 .55419 Mtetra
.83 .954 .61 r
.33912 .55419 .34288 .55001 .34817 .55014 .34491 .54519 Mtetra
.726 .675 .8 r
.34491 .54519 .34817 .55014 .35376 .54481 .35041 .54167 Mtetra
.869 .426 .056 r
.35041 .54167 .35376 .54481 .3587 .55271 .35525 .55141 Mtetra
.91 .539 .315 r
.35525 .55141 .3587 .55271 .36422 .54918 .35989 .56634 Mtetra
.367 .102 .374 r
.35989 .56634 .36422 .54918 .36895 .56291 .3656 .55985 Mtetra
.916 .73 .635 r
.3656 .55985 .36895 .56291 .37476 .55385 .37204 .53704 Mtetra
.606 .46 .658 r
.37204 .53704 .37476 .55385 .38041 .54796 .37751 .5352 Mtetra
.513 .424 .692 r
.37751 .5352 .38041 .54796 .38605 .54261 .38283 .53707 Mtetra
.885 .697 .644 r
.38283 .53707 .38605 .54261 .3915 .54161 .38908 .51676 Mtetra
.594 .427 .625 r
.38908 .51676 .3915 .54161 .39713 .53648 .39456 .51484 Mtetra
.115 .089 .548 r
.39456 .51484 .39713 .53648 .40255 .53736 .39938 .53083 Mtetra
.237 .37 .796 r
.39938 .53083 .40255 .53736 .40757 .55 .4047 .53467 Mtetra
.665 .508 .662 r
.4047 .53467 .40757 .55 .41328 .54364 .41036 .52952 Mtetra
.713 .546 .661 r
.41036 .52952 .41328 .54364 .41906 .53473 .41612 .5213 Mtetra
.703 .543 .668 r
.41612 .5213 .41906 .53473 .42492 .52302 .42183 .51427 Mtetra
.679 .573 .729 r
.42183 .51427 .42492 .52302 .43038 .52463 .42744 .5108 Mtetra
.329 .291 .664 r
.42744 .5108 .43038 .52463 .43585 .52659 .43277 .51752 Mtetra
.346 .369 .742 r
.43277 .51752 .43585 .52659 .44152 .52189 .4382 .52165 Mtetra
.823 .367 .143 r
.4382 .52165 .44152 .52189 .44687 .53058 .44357 .52954 Mtetra
.789 .292 .004 r
.44357 .52954 .44687 .53058 .45237 .53441 .44902 .53635 Mtetra
.815 .413 .287 r
.44902 .53635 .45237 .53441 .45788 .53961 .45445 .54554 Mtetra
.616 .791 .356 r
.45445 .54554 .45788 .53961 .4637 .52963 .4603 .53539 Mtetra
.804 .883 .456 r
.4603 .53539 .4637 .52963 .46952 .51886 .46618 .523 Mtetra
.997 .838 .563 r
.46618 .523 .46952 .51886 .47547 .49751 .47223 .49786 Mtetra
.828 .987 .874 r
.47223 .49786 .47547 .49751 .48114 .49352 .47794 .4928 Mtetra
.942 .843 .716 r
.47794 .4928 .48114 .49352 .4869 .48249 .48372 .48118 Mtetra
.604 .037 0 r
.48372 .48118 .4869 .48249 .49255 .48069 .48931 .48557 Mtetra
.82 .468 .39 r
.48931 .48557 .49255 .48069 .49807 .49605 .49485 .49913 Mtetra
.809 .423 .323 r
.49485 .49913 .49807 .49605 .50369 .50619 .50048 .50922 Mtetra
.821 .439 .329 r
.50048 .50922 .50369 .50619 .5094 .50994 .50616 .52026 Mtetra
.212 0 .233 r
.50616 .52026 .5094 .50994 .51513 .51564 .51197 .51361 Mtetra
.726 .848 .939 r
.51197 .51361 .51513 .51564 .5209 .52198 .51776 .51079 Mtetra
.557 .472 .715 r
.51776 .51079 .5209 .52198 .5267 .52207 .52356 .51123 Mtetra
.418 .389 .72 r
.52356 .51123 .5267 .52207 .53253 .52479 .52938 .51507 Mtetra
.795 .626 .671 r
.52938 .51507 .53253 .52479 .53837 .5211 .53518 .50323 Mtetra
.701 .522 .643 r
.53518 .50323 .53837 .5211 .54424 .52308 .54098 .49391 Mtetra
.365 .255 .594 r
.54098 .49391 .54424 .52308 .55008 .51818 .54691 .50714 Mtetra
.744 .448 0 r
.54691 .50714 .55008 .51818 .55603 .52393 .55299 .53009 Mtetra
.998 .828 .488 r
.55299 .53009 .55603 .52393 .56169 .50061 .55861 .4985 Mtetra
.931 .801 .695 r
.55861 .4985 .56169 .50061 .56754 .49692 .56436 .4854 Mtetra
.706 .56 .687 r
.56436 .4854 .56754 .49692 .57318 .47801 .57018 .47921 Mtetra
.865 .463 .27 r
.57018 .47921 .57318 .47801 .57917 .48346 .5763 .49229 Mtetra
.803 .471 .427 r
.5763 .49229 .57917 .48346 .58564 .51346 .58255 .50938 Mtetra
.802 .747 .801 r
.58255 .50938 .58564 .51346 .59141 .50216 .58845 .50373 Mtetra
.992 .811 .559 r
.58845 .50373 .59141 .50216 .59686 .47703 .59391 .47733 Mtetra
.974 .885 .68 r
.59391 .47733 .59686 .47703 .60262 .4678 .5996 .46437 Mtetra
.918 .764 .675 r
.5996 .46437 .60262 .4678 .60827 .4552 .60523 .4499 Mtetra
.776 .696 .775 r
.60523 .4499 .60827 .4552 .61409 .44965 .61105 .44436 Mtetra
.72 .677 .807 r
.61105 .44436 .61409 .44965 .61985 .44212 .61694 .44083 Mtetra
.801 .918 .917 r
.61694 .44083 .61985 .44212 .62583 .44176 .62281 .43663 Mtetra
.727 .318 0 r
.62281 .43663 .62583 .44176 .63205 .44847 .62923 .44952 Mtetra
.197 0 0 r
.62923 .44952 .63205 .44847 .63809 .44843 .63528 .44946 Mtetra
.877 .993 .759 r
.63528 .44946 .63809 .44843 .64431 .45294 .64109 .44212 Mtetra
.624 .519 .715 r
.64109 .44212 .64431 .45294 .65039 .4529 .6471 .44022 Mtetra
.679 .535 .683 r
.6471 .44022 .65039 .4529 .65602 .44091 .653 .4351 Mtetra
.562 .589 .838 r
.653 .4351 .65602 .44091 .66181 .43355 .6591 .43499 Mtetra
.485 .871 .676 r
.6591 .43499 .66181 .43355 .66757 .42543 .66505 .43095 Mtetra
.863 .508 .377 r
.66505 .43095 .66757 .42543 .67412 .43511 .67214 .45203 Mtetra
0 0 0 r
.67214 .45203 .67412 .43511 .68065 .44282 .67681 .41949 Mtetra
.403 .3 .623 r
.67681 .41949 .68065 .44282 .68606 .42732 .68344 .42913 Mtetra
.86 .447 .247 r
.68344 .42913 .68606 .42732 .69385 .45845 .69033 .44282 Mtetra
.203 .202 .634 r
.69033 .44282 .69385 .45845 .70011 .45843 .69721 .4549 Mtetra
0 0 .457 r
.69721 .4549 .70011 .45843 .70667 .46356 .70395 .46303 Mtetra
.815 .976 .896 r
.70395 .46303 .70667 .46356 .71258 .4565 .70999 .4581 Mtetra
.892 .972 .663 r
.70999 .4581 .71258 .4565 .71824 .44542 .71579 .44881 Mtetra
.997 .821 .469 r
.71579 .44881 .71824 .44542 .72316 .42255 .7204 .42004 Mtetra
.819 .36 0 r
.7204 .42004 .72316 .42255 .72957 .42428 .72749 .43275 Mtetra
.19 0 .205 r
.72749 .43275 .72957 .42428 .73583 .42333 .73342 .42617 Mtetra
0 0 0 r
.73342 .42617 .73583 .42333 .74204 .42138 .73953 .42234 Mtetra
.924 .972 .694 r
.73953 .42234 .74204 .42138 .74749 .40828 .74527 .41296 Mtetra
.873 .847 .386 r
.74527 .41296 .74749 .40828 .75313 .39825 .75044 .39571 Mtetra
.245 .61 .955 r
.75044 .39571 .75313 .39825 .75967 .40075 .7569 .3971 Mtetra
.036 .386 .848 r
.7569 .3971 .75967 .40075 .7658 .39737 .76358 .40098 Mtetra
.659 .208 .169 r
.76358 .40098 .7658 .39737 .77286 .40594 .77033 .40535 Mtetra
.857 .403 .066 r
.77033 .40535 .77286 .40594 .78114 .4294 .77784 .41891 Mtetra
0 0 .51 r
.77784 .41891 .78114 .4294 .78795 .43316 .7857 .43594 Mtetra
0 0 0 r
.7857 .43594 .78795 .43316 .794 .42736 .79194 .43205 Mtetra
.972 .807 .386 r
.79194 .43205 .794 .42736 .79882 .40702 .79597 .40183 Mtetra
.924 .742 .638 r
.79597 .40183 .79882 .40702 .80371 .38809 .80102 .38456 Mtetra
.493 .675 .946 r
.80102 .38456 .80371 .38809 .8099 .38457 .80755 .38469 Mtetra
.641 .081 0 r
.80755 .38469 .8099 .38457 .8161 .381 .81457 .38998 Mtetra
.707 .346 .363 r
.81457 .38998 .8161 .381 .82232 .37753 .82192 .39835 Mtetra
.494 .231 .444 r
.82192 .39835 .82232 .37753 .8296 .38511 .82822 .39503 Mtetra
.457 .134 .329 r
.82822 .39503 .8296 .38511 .836 .38309 .83466 .393 Mtetra
.31 .015 .293 r
.83466 .393 .836 .38309 .84261 .38307 .84074 .38717 Mtetra
.688 .246 .194 r
.84074 .38717 .84261 .38307 .84961 .38662 .84796 .39276 Mtetra
.658 .257 .274 r
.84796 .39276 .84961 .38662 .85768 .40022 .85517 .39771 Mtetra
.9 .867 .798 r
.85517 .39771 .85768 .40022 .86378 .39436 .86108 .38991 Mtetra
0 .298 .794 r
.86108 .38991 .86378 .39436 .87063 .39549 .86842 .39556 Mtetra
.229 .749 .791 r
.86842 .39556 .87063 .39549 .87696 .39155 .87505 .3942 Mtetra
.869 .878 .441 r
.87505 .3942 .87696 .39155 .88207 .37667 .88029 .3802 Mtetra
0 0 0 r
.88029 .3802 .88207 .37667 .8886 .37462 .88628 .37312 Mtetra
.841 .946 .889 r
.88628 .37312 .8886 .37462 .89466 .36843 .89246 .36777 Mtetra
.492 .892 .944 r
.89246 .36777 .89466 .36843 .90099 .36451 .89903 .3657 Mtetra
.549 .886 .634 r
.89903 .3657 .90099 .36451 .908 .36617 .90524 .36047 Mtetra
.001 .247 .754 r
.90524 .36047 .908 .36617 .91551 .37165 .91297 .36782 Mtetra
.884 .976 .674 r
.31867 .5708 .32248 .56723 .3282 .55987 .3245 .56185 Mtetra
.571 .08 .051 r
.3245 .56185 .3282 .55987 .33369 .55635 .32969 .56385 Mtetra
.782 .864 .424 r
.32969 .56385 .33369 .55635 .33912 .55419 .33575 .55072 Mtetra
.794 .746 .809 r
.33575 .55072 .33912 .55419 .34491 .54519 .34135 .5457 Mtetra
.68 .17 .019 r
.34135 .5457 .34491 .54519 .35041 .54167 .34647 .54949 Mtetra
.654 .313 .383 r
.34647 .54949 .35041 .54167 .35525 .55141 .35161 .55379 Mtetra
.059 0 0 r
.35161 .55379 .35525 .55141 .35989 .56634 .35707 .55208 Mtetra
.618 .483 .675 r
.35707 .55208 .35989 .56634 .3656 .55985 .36256 .54994 Mtetra
.84 .644 .638 r
.36256 .54994 .3656 .55985 .37204 .53704 .36892 .52923 Mtetra
.818 .651 .676 r
.36892 .52923 .37204 .53704 .37751 .5352 .37488 .51657 Mtetra
.657 .489 .645 r
.37488 .51657 .37751 .5352 .38283 .53707 .3805 .51085 Mtetra
.592 .422 .621 r
.3805 .51085 .38283 .53707 .38908 .51676 .38597 .50894 Mtetra
.579 .533 .767 r
.38597 .50894 .38908 .51676 .39456 .51484 .39139 .50866 Mtetra
.893 .515 .058 r
.39139 .50866 .39456 .51484 .39938 .53083 .39622 .52398 Mtetra
.494 .511 .804 r
.39622 .52398 .39938 .53083 .4047 .53467 .40163 .52513 Mtetra
.828 .641 .65 r
.40163 .52513 .4047 .53467 .41036 .52952 .40771 .50825 Mtetra
.596 .437 .637 r
.40771 .50825 .41036 .52952 .41612 .5213 .41323 .50649 Mtetra
.723 .548 .654 r
.41323 .50649 .41612 .5213 .42183 .51427 .41902 .49696 Mtetra
.498 .383 .654 r
.41902 .49696 .42183 .51427 .42744 .5108 .42441 .50006 Mtetra
.562 .478 .717 r
.42441 .50006 .42744 .5108 .43277 .51752 .42991 .5003 Mtetra
.229 .196 .612 r
.42991 .5003 .43277 .51752 .4382 .52165 .43514 .51098 Mtetra
.034 .131 .635 r
.43514 .51098 .4382 .52165 .44357 .52954 .44048 .51999 Mtetra
.708 .401 0 r
.44048 .51999 .44357 .52954 .44902 .53635 .44567 .53673 Mtetra
.294 0 0 r
.44567 .53673 .44902 .53635 .45445 .54554 .45129 .53766 Mtetra
.676 .588 .749 r
.45129 .53766 .45445 .54554 .4603 .53539 .45701 .53457 Mtetra
.946 .818 .686 r
.45701 .53457 .4603 .53539 .46618 .523 .46294 .52045 Mtetra
.934 .75 .631 r
.46294 .52045 .46618 .523 .47223 .49786 .46896 .49881 Mtetra
.96 .916 .722 r
.46896 .49881 .47223 .49786 .47794 .4928 .47477 .48809 Mtetra
.702 .684 .83 r
.47477 .48809 .47794 .4928 .48372 .48118 .48045 .48532 Mtetra
.742 .352 .313 r
.48045 .48532 .48372 .48118 .48931 .48557 .48603 .49217 Mtetra
.783 .439 .404 r
.48603 .49217 .48931 .48557 .49485 .49913 .4916 .50403 Mtetra
.742 .364 .337 r
.4916 .50403 .49485 .49913 .50048 .50922 .49726 .5114 Mtetra
.349 0 0 r
.49726 .5114 .50048 .50922 .50616 .52026 .50302 .51143 Mtetra
.709 .591 .722 r
.50302 .51143 .50616 .52026 .51197 .51361 .50881 .50656 Mtetra
.701 .618 .761 r
.50881 .50656 .51197 .51361 .51776 .51079 .51461 .50289 Mtetra
.776 .637 .708 r
.51461 .50289 .51776 .51079 .52356 .51123 .52042 .49481 Mtetra
.569 .439 .664 r
.52042 .49481 .52356 .51123 .52938 .51507 .52622 .49486 Mtetra
.674 .496 .637 r
.52622 .49486 .52938 .51507 .53518 .50323 .53202 .487 Mtetra
.569 .441 .666 r
.53202 .487 .53518 .50323 .54098 .49391 .53785 .48703 Mtetra
.297 .399 .798 r
.53785 .48703 .54098 .49391 .54691 .50714 .54371 .49079 Mtetra
.361 .299 .652 r
.54371 .49079 .54691 .50714 .55299 .53009 .54964 .49834 Mtetra
.622 .437 .611 r
.54964 .49834 .55299 .53009 .55861 .4985 .55548 .49253 Mtetra
.764 .672 .761 r
.55548 .49253 .55861 .4985 .56436 .4854 .56133 .48695 Mtetra
.729 .978 .749 r
.56133 .48695 .56436 .4854 .57018 .47921 .56718 .48137 Mtetra
.728 .271 .168 r
.56718 .48137 .57018 .47921 .5763 .49229 .57319 .48701 Mtetra
.715 .305 0 r
.57319 .48701 .5763 .49229 .58255 .50938 .57935 .49909 Mtetra
.818 .633 .653 r
.57935 .49909 .58255 .50938 .58845 .50373 .58507 .48407 Mtetra
.78 .569 .614 r
.58507 .48407 .58845 .50373 .59391 .47733 .59064 .46279 Mtetra
.644 .5 .672 r
.59064 .46279 .59391 .47733 .5996 .46437 .59653 .45909 Mtetra
.873 .719 .688 r
.59653 .45909 .5996 .46437 .60523 .4499 .60222 .44643 Mtetra
.51 .681 .943 r
.60222 .44643 .60523 .4499 .61105 .44436 .6082 .44639 Mtetra
0 0 0 r
.6082 .44639 .61105 .44436 .61694 .44083 .61409 .44245 Mtetra
.957 .948 .667 r
.61409 .44245 .61694 .44083 .62281 .43663 .61978 .43133 Mtetra
.901 .522 .076 r
.61978 .43133 .62281 .43663 .62923 .44952 .62646 .45263 Mtetra
.978 .898 .553 r
.62646 .45263 .62923 .44952 .63528 .44946 .63198 .43594 Mtetra
.738 .565 .659 r
.63198 .43594 .63528 .44946 .64109 .44212 .6377 .42605 Mtetra
.468 .375 .667 r
.6377 .42605 .64109 .44212 .6471 .44022 .64392 .43032 Mtetra
.481 .445 .74 r
.64392 .43032 .6471 .44022 .653 .4351 .6501 .43261 Mtetra
.772 .837 .902 r
.6501 .43261 .653 .4351 .6591 .43499 .65606 .42884 Mtetra
.828 .694 .716 r
.65606 .42884 .6591 .43499 .66505 .43095 .66179 .41948 Mtetra
.503 .438 .716 r
.66179 .41948 .66505 .43095 .67214 .45203 .66802 .42157 Mtetra
.49 .345 .611 r
.66802 .42157 .67214 .45203 .67681 .41949 .67447 .42803 Mtetra
.748 .397 .387 r
.67447 .42803 .67681 .41949 .68344 .42913 .68118 .43882 Mtetra
.735 .392 .399 r
.68118 .43882 .68344 .42913 .69033 .44282 .68794 .44947 Mtetra
.615 .234 .298 r
.68794 .44947 .69033 .44282 .69721 .4549 .69438 .45268 Mtetra
.596 .068 0 r
.69438 .45268 .69721 .4549 .70395 .46303 .70104 .45943 Mtetra
.897 .785 .729 r
.70104 .45943 .70395 .46303 .70999 .4581 .7068 .44903 Mtetra
.721 .599 .72 r
.7068 .44903 .70999 .4581 .71579 .44881 .71281 .44345 Mtetra
.882 .73 .688 r
.71281 .44345 .71579 .44881 .7204 .42004 .71841 .43083 Mtetra
.61 .277 .382 r
.71841 .43083 .7204 .42004 .72749 .43275 .72496 .43433 Mtetra
.92 .961 .644 r
.72496 .43433 .72749 .43275 .73342 .42617 .73068 .42399 Mtetra
.891 .866 .808 r
.73068 .42399 .73342 .42617 .73953 .42234 .73657 .41665 Mtetra
.834 .713 .731 r
.73657 .41665 .73953 .42234 .74527 .41296 .74236 .40784 Mtetra
.89 .739 .687 r
.74236 .40784 .74527 .41296 .75044 .39571 .74786 .39515 Mtetra
.58 .005 0 r
.74786 .39515 .75044 .39571 .7569 .3971 .75458 .3999 Mtetra
.023 0 0 r
.75458 .3999 .7569 .3971 .76358 .40098 .76077 .39689 Mtetra
.136 .427 .868 r
.76077 .39689 .76358 .40098 .77033 .40535 .76747 .40048 Mtetra
0 0 .537 r
.76747 .40048 .77033 .40535 .77784 .41891 .77468 .41016 Mtetra
.622 .552 .754 r
.77468 .41016 .77784 .41891 .7857 .43594 .78105 .40856 Mtetra
.154 .122 .567 r
.78105 .40856 .7857 .43594 .79194 .43205 .78958 .43332 Mtetra
.995 .754 .435 r
.78958 .43332 .79194 .43205 .79597 .40183 .79203 .3836 Mtetra
.525 .405 .659 r
.79203 .3836 .79597 .40183 .80102 .38456 .79874 .38601 Mtetra
.82 .359 .128 r
.79874 .38601 .80102 .38456 .80755 .38469 .80623 .39678 Mtetra
.842 .501 .409 r
.80623 .39678 .80755 .38469 .81457 .38998 .81536 .42531 Mtetra
.233 .064 .436 r
.81536 .42531 .81457 .38998 .82192 .39835 .81952 .3979 Mtetra
.54 0 0 r
.81952 .3979 .82192 .39835 .82822 .39503 .82658 .40246 Mtetra
.32 0 .223 r
.82658 .40246 .82822 .39503 .83466 .393 .83287 .39855 Mtetra
0 0 0 r
.83287 .39855 .83466 .393 .84074 .38717 .83875 .39035 Mtetra
.526 .041 .047 r
.83875 .39035 .84074 .38717 .84796 .39276 .84562 .39214 Mtetra
0 .414 .686 r
.84562 .39214 .84796 .39276 .85517 .39771 .85251 .39395 Mtetra
.105 .427 .87 r
.85251 .39395 .85517 .39771 .86108 .38991 .85964 .39769 Mtetra
.332 0 .24 r
.85964 .39769 .86108 .38991 .86842 .39556 .866 .39371 Mtetra
.726 .904 .958 r
.866 .39371 .86842 .39556 .87505 .3942 .87243 .39042 Mtetra
.942 .795 .669 r
.87243 .39042 .87505 .3942 .88029 .3802 .87769 .37639 Mtetra
.889 .804 .759 r
.87769 .37639 .88029 .3802 .88628 .37312 .88349 .36752 Mtetra
.588 .621 .852 r
.88349 .36752 .88628 .37312 .89246 .36777 .89021 .36683 Mtetra
0 .476 .774 r
.89021 .36683 .89246 .36777 .89903 .3657 .89725 .36857 Mtetra
.819 .855 .4 r
.89725 .36857 .89903 .3657 .90524 .36047 .90249 .35499 Mtetra
.56 .611 .861 r
.90249 .35499 .90524 .36047 .91297 .36782 .90931 .3548 Mtetra
.83 .871 .875 r
.31512 .56954 .31867 .5708 .3245 .56185 .32072 .5648 Mtetra
.963 .939 .694 r
.32072 .5648 .3245 .56185 .32969 .56385 .32671 .55336 Mtetra
.564 .481 .719 r
.32671 .55336 .32969 .56385 .33575 .55072 .33202 .5535 Mtetra
0 0 0 r
.33202 .5535 .33575 .55072 .34135 .5457 .33753 .55037 Mtetra
.302 0 .052 r
.33753 .55037 .34135 .5457 .34647 .54949 .34297 .54866 Mtetra
.844 .4 .165 r
.34297 .54866 .34647 .54949 .35161 .55379 .34789 .55689 Mtetra
.425 0 .021 r
.34789 .55689 .35161 .55379 .35707 .55208 .35328 .55704 Mtetra
.954 .934 .6 r
.35328 .55704 .35707 .55208 .36256 .54994 .35937 .54313 Mtetra
.857 .676 .657 r
.35937 .54313 .36256 .54994 .36892 .52923 .36558 .52604 Mtetra
.906 .736 .659 r
.36558 .52604 .36892 .52923 .37488 .51657 .37179 .50824 Mtetra
.469 .459 .764 r
.37179 .50824 .37488 .51657 .3805 .51085 .37708 .51013 Mtetra
.296 0 0 r
.37708 .51013 .3805 .51085 .38597 .50894 .38241 .51185 Mtetra
.766 .966 .673 r
.38241 .51185 .38597 .50894 .39139 .50866 .3881 .50508 Mtetra
0 .045 .562 r
.3881 .50508 .39139 .50866 .39622 .52398 .39332 .5102 Mtetra
.631 .494 .677 r
.39332 .5102 .39622 .52398 .40163 .52513 .39887 .5075 Mtetra
.656 .492 .65 r
.39887 .5075 .40163 .52513 .40771 .50825 .40452 .50218 Mtetra
.68 .627 .789 r
.40452 .50218 .40771 .50825 .41323 .50649 .41008 .4996 Mtetra
.729 .629 .747 r
.41008 .4996 .41323 .50649 .41902 .49696 .41572 .49487 Mtetra
.869 .424 .102 r
.41572 .49487 .41902 .49696 .42441 .50006 .4209 .50481 Mtetra
.627 .84 .449 r
.4209 .50481 .42441 .50006 .42991 .5003 .42667 .49655 Mtetra
.734 .264 0 r
.42667 .49655 .42991 .5003 .43514 .51098 .43197 .50474 Mtetra
.82 .433 0 r
.43197 .50474 .43514 .51098 .44048 .51999 .43717 .51836 Mtetra
.906 .509 .24 r
.43717 .51836 .44048 .51999 .44567 .53673 .44242 .53241 Mtetra
.524 .633 .9 r
.44242 .53241 .44567 .53673 .45129 .53766 .44806 .53251 Mtetra
.54 .601 .863 r
.44806 .53251 .45129 .53766 .45701 .53457 .45372 .53262 Mtetra
.93 .781 .674 r
.45372 .53262 .45701 .53457 .46294 .52045 .4597 .51717 Mtetra
.917 .745 .652 r
.4597 .51717 .46294 .52045 .46896 .49881 .46569 .49896 Mtetra
.965 .831 .66 r
.46569 .49896 .46896 .49881 .47477 .48809 .4716 .48295 Mtetra
0 .258 .767 r
.4716 .48295 .47477 .48809 .48045 .48532 .47718 .48779 Mtetra
.483 0 0 r
.47718 .48779 .48045 .48532 .48603 .49217 .48284 .48884 Mtetra
.575 .08 0 r
.48284 .48884 .48603 .49217 .4916 .50403 .48846 .49523 Mtetra
0 0 .483 r
.48846 .49523 .4916 .50403 .49726 .5114 .49407 .50683 Mtetra
.736 .705 .821 r
.49407 .50683 .49726 .5114 .50302 .51143 .49986 .50317 Mtetra
.634 .56 .754 r
.49986 .50317 .50302 .51143 .50881 .50656 .50564 .50136 Mtetra
.382 .517 .869 r
.50564 .50136 .50881 .50656 .51461 .50289 .51142 .50327 Mtetra
.973 .849 .658 r
.51142 .50327 .51461 .50289 .52042 .49481 .51727 .48772 Mtetra
.561 .546 .795 r
.51727 .48772 .52042 .49481 .52622 .49486 .52307 .48776 Mtetra
.838 .674 .68 r
.52307 .48776 .52622 .49486 .53202 .487 .52887 .47514 Mtetra
.45 .397 .706 r
.52887 .47514 .53202 .487 .53785 .48703 .5347 .47857 Mtetra
.64 .56 .749 r
.5347 .47857 .53785 .48703 .54371 .49079 .54053 .47652 Mtetra
.61 .48 .678 r
.54053 .47652 .54371 .49079 .54964 .49834 .54638 .47468 Mtetra
.53 .386 .629 r
.54638 .47468 .54964 .49834 .55548 .49253 .55227 .47712 Mtetra
.569 .445 .672 r
.55227 .47712 .55548 .49253 .56133 .48695 .55816 .47714 Mtetra
.309 .336 .727 r
.55816 .47714 .56133 .48695 .56718 .48137 .56414 .48248 Mtetra
0 0 0 r
.56414 .48248 .56718 .48137 .57319 .48701 .57006 .48062 Mtetra
.558 .568 .819 r
.57006 .48062 .57319 .48701 .57935 .49909 .57602 .48063 Mtetra
.532 .406 .653 r
.57602 .48063 .57935 .49909 .58507 .48407 .58203 .48251 Mtetra
.963 .777 .604 r
.58203 .48251 .58507 .48407 .59064 .46279 .58759 .45925 Mtetra
.885 .771 .73 r
.58759 .45925 .59064 .46279 .59653 .45909 .59336 .44914 Mtetra
.709 .578 .706 r
.59336 .44914 .59653 .45909 .60222 .44643 .59921 .44363 Mtetra
.478 .716 .975 r
.59921 .44363 .60222 .44643 .6082 .44639 .6052 .44355 Mtetra
.716 .799 .916 r
.6052 .44355 .6082 .44639 .61409 .44245 .61114 .44081 Mtetra
.777 .894 .927 r
.61114 .44081 .61409 .44245 .61978 .43133 .61706 .43706 Mtetra
0 0 0 r
.61706 .43706 .61978 .43133 .62646 .45263 .62286 .4292 Mtetra
.552 .402 .631 r
.62286 .4292 .62646 .45263 .63198 .43594 .62893 .43028 Mtetra
.794 .694 .754 r
.62893 .43028 .63198 .43594 .6377 .42605 .63477 .42358 Mtetra
.649 .81 .961 r
.63477 .42358 .6377 .42605 .64392 .43032 .64078 .42173 Mtetra
0 .059 .614 r
.64078 .42173 .64392 .43032 .6501 .43261 .64726 .43218 Mtetra
.736 .971 .93 r
.64726 .43218 .6501 .43261 .65606 .42884 .65324 .42841 Mtetra
.913 .947 .808 r
.65324 .42841 .65606 .42884 .66179 .41948 .65908 .421 Mtetra
.408 .824 .639 r
.65908 .421 .66179 .41948 .66802 .42157 .66507 .41729 Mtetra
.842 .427 0 r
.66507 .41729 .66802 .42157 .67447 .42803 .67196 .43342 Mtetra
.795 .415 .336 r
.67196 .43342 .67447 .42803 .68118 .43882 .67873 .4452 Mtetra
.532 .146 .255 r
.67873 .4452 .68118 .43882 .68794 .44947 .68503 .44612 Mtetra
.685 .766 .913 r
.68503 .44612 .68794 .44947 .69438 .45268 .69119 .44379 Mtetra
.22 .301 .735 r
.69119 .44379 .69438 .45268 .70104 .45943 .69783 .45032 Mtetra
.707 .591 .724 r
.69783 .45032 .70104 .45943 .7068 .44903 .7039 .44538 Mtetra
.66 .742 .91 r
.7039 .44538 .7068 .44903 .71281 .44345 .71013 .44344 Mtetra
.984 .881 .646 r
.71013 .44344 .71281 .44345 .71841 .43083 .71564 .42903 Mtetra
.343 .732 .985 r
.71564 .42903 .71841 .43083 .72496 .43433 .722 .42913 Mtetra
.853 .731 .728 r
.722 .42913 .72496 .43433 .73068 .42399 .72779 .41969 Mtetra
.837 .759 .777 r
.72779 .41969 .73068 .42399 .73657 .41665 .73371 .41251 Mtetra
.863 .769 .757 r
.73371 .41251 .73657 .41665 .74236 .40784 .73953 .40408 Mtetra
.662 .736 .905 r
.73953 .40408 .74236 .40784 .74786 .39515 .74579 .40211 Mtetra
.402 .038 .228 r
.74579 .40211 .74786 .39515 .75458 .3999 .75206 .40012 Mtetra
.705 .169 0 r
.75206 .40012 .75458 .3999 .76077 .39689 .75894 .40632 Mtetra
.792 .44 .39 r
.75894 .40632 .76077 .39689 .76747 .40048 .7666 .42244 Mtetra
.224 .025 .386 r
.7666 .42244 .76747 .40048 .77468 .41016 .77184 .4058 Mtetra
.903 .766 .7 r
.77184 .4058 .77468 .41016 .78105 .40856 .77741 .39384 Mtetra
.69 .53 .664 r
.77741 .39384 .78105 .40856 .78958 .43332 .78337 .38703 Mtetra
.627 .426 .59 r
.78337 .38703 .78958 .43332 .79203 .3836 .78904 .37688 Mtetra
0 .097 .651 r
.78904 .37688 .79203 .3836 .79874 .38601 .79638 .38657 Mtetra
.904 .496 .197 r
.79638 .38657 .79874 .38601 .80623 .39678 .80477 .40768 Mtetra
.611 .274 .375 r
.80477 .40768 .80623 .39678 .81536 .42531 .81172 .4114 Mtetra
.633 .501 .684 r
.81172 .4114 .81536 .42531 .81952 .3979 .8181 .40833 Mtetra
.379 .074 .316 r
.8181 .40833 .81952 .3979 .82658 .40246 .82437 .40403 Mtetra
.248 0 0 r
.82437 .40403 .82658 .40246 .83287 .39855 .83104 .40386 Mtetra
.085 0 .038 r
.83104 .40386 .83287 .39855 .83875 .39035 .83722 .39843 Mtetra
.427 .08 .273 r
.83722 .39843 .83875 .39035 .84562 .39214 .84374 .39639 Mtetra
.614 .167 .165 r
.84374 .39639 .84562 .39214 .85251 .39395 .85083 .39983 Mtetra
.804 .407 .3 r
.85083 .39983 .85251 .39395 .85964 .39769 .859 .41336 Mtetra
.121 0 .324 r
.859 .41336 .85964 .39769 .866 .39371 .86417 .39767 Mtetra
.777 .811 .33 r
.86417 .39767 .866 .39371 .87243 .39042 .86938 .38276 Mtetra
.837 .681 .689 r
.86938 .38276 .87243 .39042 .87769 .37639 .87496 .37153 Mtetra
.883 .762 .723 r
.87496 .37153 .87769 .37639 .88349 .36752 .88062 .36126 Mtetra
.289 .422 .822 r
.88062 .36126 .88349 .36752 .89021 .36683 .8879 .36545 Mtetra
.002 .527 .851 r
.8879 .36545 .89021 .36683 .89725 .36857 .89495 .36718 Mtetra
.989 .862 .619 r
.89495 .36718 .89725 .36857 .90249 .35499 .9 .35176 Mtetra
.915 .834 .751 r
.9 .35176 .90249 .35499 .90931 .3548 .90572 .3423 Mtetra
.918 .794 .708 r
.31155 .56828 .31512 .56954 .32072 .5648 .31765 .5556 Mtetra
.837 .647 .646 r
.31765 .5556 .32072 .5648 .32671 .55336 .3241 .53671 Mtetra
.756 .564 .637 r
.3241 .53671 .32671 .55336 .33202 .5535 .33028 .52161 Mtetra
.601 .42 .609 r
.33028 .52161 .33202 .5535 .33753 .55037 .33577 .51815 Mtetra
.44 .297 .59 r
.33577 .51815 .33753 .55037 .34297 .54866 .34058 .5271 Mtetra
.409 .3 .618 r
.34058 .5271 .34297 .54866 .34789 .55689 .34553 .53434 Mtetra
.365 .265 .606 r
.34553 .53434 .34789 .55689 .35328 .55704 .35041 .5435 Mtetra
.679 .527 .672 r
.35041 .5435 .35328 .55704 .35937 .54313 .35608 .53812 Mtetra
.885 .705 .652 r
.35608 .53812 .35937 .54313 .36558 .52604 .3624 .51927 Mtetra
.836 .671 .678 r
.3624 .51927 .36558 .52604 .37179 .50824 .36841 .50606 Mtetra
.053 .521 .891 r
.36841 .50606 .37179 .50824 .37708 .51013 .37372 .50767 Mtetra
0 .173 .617 r
.37372 .50767 .37708 .51013 .38241 .51185 .37897 .51124 Mtetra
.51 0 0 r
.37897 .51124 .38241 .51185 .3881 .50508 .38427 .51402 Mtetra
.821 .844 .381 r
.38427 .51402 .3881 .50508 .39332 .5102 .39041 .49701 Mtetra
.589 .47 .686 r
.39041 .49701 .39332 .5102 .39887 .5075 .39588 .49626 Mtetra
.348 .333 .7 r
.39588 .49626 .39887 .5075 .40452 .50218 .40114 .50122 Mtetra
.706 .914 .966 r
.40114 .50122 .40452 .50218 .41008 .4996 .40672 .49853 Mtetra
.901 .86 .791 r
.40672 .49853 .41008 .4996 .41572 .49487 .41247 .49074 Mtetra
.803 .356 0 r
.41247 .49074 .41572 .49487 .4209 .50481 .41765 .50048 Mtetra
.834 .4 0 r
.41765 .50048 .4209 .50481 .42667 .49655 .42285 .51135 Mtetra
.572 .276 .428 r
.42285 .51135 .42667 .49655 .43197 .50474 .42836 .51302 Mtetra
.775 .448 .434 r
.42836 .51302 .43197 .50474 .43717 .51836 .4336 .52593 Mtetra
.362 .007 .221 r
.4336 .52593 .43717 .51836 .44242 .53241 .43928 .52338 Mtetra
.563 .506 .749 r
.43928 .52338 .44242 .53241 .44806 .53251 .44492 .52348 Mtetra
.855 .659 .636 r
.44492 .52348 .44806 .53251 .45372 .53262 .45103 .50275 Mtetra
.69 .49 .61 r
.45103 .50275 .45372 .53262 .4597 .51717 .45696 .48846 Mtetra
.594 .42 .615 r
.45696 .48846 .4597 .51717 .46569 .49896 .46264 .48601 Mtetra
.731 .564 .665 r
.46264 .48601 .46569 .49896 .4716 .48295 .46844 .47707 Mtetra
.749 .354 0 r
.46844 .47707 .4716 .48295 .47718 .48779 .4739 .48915 Mtetra
.748 .991 .801 r
.4739 .48915 .47718 .48779 .48284 .48884 .47966 .48402 Mtetra
.704 .274 0 r
.47966 .48402 .48284 .48884 .48846 .49523 .48523 .49388 Mtetra
.777 .899 .928 r
.48523 .49388 .48846 .49523 .49407 .50683 .491 .4902 Mtetra
.454 .36 .658 r
.491 .4902 .49407 .50683 .49986 .50317 .49671 .49477 Mtetra
.723 .605 .724 r
.49671 .49477 .49986 .50317 .50564 .50136 .50251 .48942 Mtetra
.692 .548 .686 r
.50251 .48942 .50564 .50136 .51142 .50327 .50832 .48388 Mtetra
.676 .5 .64 r
.50832 .48388 .51142 .50327 .51727 .48772 .51413 .47616 Mtetra
.619 .507 .704 r
.51413 .47616 .51727 .48772 .52307 .48776 .51993 .47433 Mtetra
.683 .531 .674 r
.51993 .47433 .52307 .48776 .52887 .47514 .52573 .46867 Mtetra
.646 .607 .796 r
.52573 .46867 .52887 .47514 .5347 .47857 .53155 .46682 Mtetra
.31 .306 .693 r
.53155 .46682 .5347 .47857 .54053 .47652 .5374 .47312 Mtetra
.757 .768 .862 r
.5374 .47312 .54053 .47652 .54638 .47468 .54325 .4694 Mtetra
.509 .582 .864 r
.54325 .4694 .54638 .47468 .55227 .47712 .54912 .46994 Mtetra
.642 .588 .779 r
.54912 .46994 .55227 .47712 .55816 .47714 .555 .46808 Mtetra
.799 .635 .678 r
.555 .46808 .55816 .47714 .56414 .48248 .56079 .45691 Mtetra
.59 .423 .624 r
.56079 .45691 .56414 .48248 .57006 .48062 .56668 .45504 Mtetra
.5 .359 .621 r
.56668 .45504 .57006 .48062 .57602 .48063 .57267 .45957 Mtetra
.736 .536 .622 r
.57267 .45957 .57602 .48063 .58203 .48251 .57837 .44402 Mtetra
.609 .419 .6 r
.57837 .44402 .58203 .48251 .58759 .45925 .58421 .43854 Mtetra
.431 .326 .634 r
.58421 .43854 .58759 .45925 .59336 .44914 .59031 .44543 Mtetra
0 .306 .795 r
.59031 .44543 .59336 .44914 .59921 .44363 .59639 .44959 Mtetra
.948 .864 .445 r
.59639 .44959 .59921 .44363 .6052 .44355 .6019 .42853 Mtetra
0 0 .439 r
.6019 .42853 .6052 .44355 .61114 .44081 .60842 .44897 Mtetra
.711 .358 .377 r
.60842 .44897 .61114 .44081 .61706 .43706 .61469 .45682 Mtetra
.595 .312 .456 r
.61469 .45682 .61706 .43706 .62286 .4292 .62088 .46046 Mtetra
0 0 .323 r
.62088 .46046 .62286 .4292 .62893 .43028 .62601 .42874 Mtetra
.901 .485 .159 r
.62601 .42874 .62893 .43028 .63477 .42358 .63261 .44478 Mtetra
.619 .336 .466 r
.63261 .44478 .63477 .42358 .64078 .42173 .63894 .45057 Mtetra
.644 .371 .49 r
.63894 .45057 .64078 .42173 .64726 .43218 .64549 .4611 Mtetra
.404 .174 .448 r
.64549 .4611 .64726 .43218 .65324 .42841 .65127 .45036 Mtetra
.203 0 .366 r
.65127 .45036 .65324 .42841 .65908 .421 .65681 .43421 Mtetra
.426 .134 .365 r
.65681 .43421 .65908 .421 .66507 .41729 .66284 .4304 Mtetra
.758 .434 .438 r
.66284 .4304 .66507 .41729 .67196 .43342 .66974 .44621 Mtetra
.712 .388 .427 r
.66974 .44621 .67196 .43342 .67873 .4452 .6765 .45705 Mtetra
.503 .19 .368 r
.6765 .45705 .67873 .4452 .68503 .44612 .68275 .45621 Mtetra
.189 0 .235 r
.68275 .45621 .68503 .44612 .69119 .44379 .68869 .44861 Mtetra
.559 .135 .193 r
.68869 .44861 .69119 .44379 .69783 .45032 .69511 .45044 Mtetra
.017 0 0 r
.69511 .45044 .69783 .45032 .7039 .44538 .70145 .45039 Mtetra
0 0 0 r
.70145 .45039 .7039 .44538 .71013 .44344 .70744 .44364 Mtetra
.888 .987 .799 r
.70744 .44364 .71013 .44344 .71564 .42903 .7134 .4365 Mtetra
.77 .76 .248 r
.7134 .4365 .71564 .42903 .722 .42913 .71858 .4163 Mtetra
.548 .454 .701 r
.71858 .4163 .722 .42913 .72779 .41969 .725 .41711 Mtetra
.851 .849 .84 r
.725 .41711 .72779 .41969 .73371 .41251 .731 .4111 Mtetra
.98 .815 .606 r
.731 .4111 .73371 .41251 .73953 .40408 .73615 .39207 Mtetra
.645 .522 .699 r
.73615 .39207 .73953 .40408 .74579 .40211 .74233 .38893 Mtetra
.59 .478 .694 r
.74233 .38893 .74579 .40211 .75206 .40012 .74867 .38807 Mtetra
.636 .516 .7 r
.74867 .38807 .75206 .40012 .75894 .40632 .75489 .3853 Mtetra
.654 .479 .635 r
.75489 .3853 .75894 .40632 .7666 .42244 .76084 .37877 Mtetra
.577 .392 .594 r
.76084 .37877 .7666 .42244 .77184 .4058 .76715 .37696 Mtetra
.49 .349 .617 r
.76715 .37696 .77184 .4058 .77741 .39384 .7741 .38323 Mtetra
.572 .495 .729 r
.7741 .38323 .77741 .39384 .78337 .38703 .78059 .38309 Mtetra
0 .157 .688 r
.78059 .38309 .78337 .38703 .78904 .37688 .78765 .38963 Mtetra
.708 .375 .411 r
.78765 .38963 .78904 .37688 .79638 .38657 .7951 .40027 Mtetra
.687 .36 .417 r
.7951 .40027 .79638 .38657 .80477 .40768 .80251 .40969 Mtetra
.834 .389 .172 r
.80251 .40969 .80477 .40768 .81172 .4114 .81024 .42199 Mtetra
0 0 .104 r
.81024 .42199 .81172 .4114 .8181 .40833 .81536 .40459 Mtetra
.896 .799 .744 r
.81536 .40459 .8181 .40833 .82437 .40403 .82116 .39496 Mtetra
.572 .52 .759 r
.82116 .39496 .82437 .40403 .83104 .40386 .82783 .39481 Mtetra
.744 .616 .716 r
.82783 .39481 .83104 .40386 .83722 .39843 .83389 .38806 Mtetra
.573 .5 .735 r
.83389 .38806 .83722 .39843 .84374 .39639 .84059 .38791 Mtetra
.571 .531 .772 r
.84059 .38791 .84374 .39639 .85083 .39983 .84732 .38776 Mtetra
.459 .41 .716 r
.84732 .38776 .85083 .39983 .859 .41336 .85446 .39145 Mtetra
.528 .395 .643 r
.85446 .39145 .859 .41336 .86417 .39767 .86153 .39409 Mtetra
.948 .801 .664 r
.86153 .39409 .86417 .39767 .86938 .38276 .86682 .37965 Mtetra
.855 .84 .83 r
.86682 .37965 .86938 .38276 .87496 .37153 .87294 .37324 Mtetra
.765 .927 .565 r
.87294 .37324 .87496 .37153 .88062 .36126 .8788 .36455 Mtetra
.517 .032 .044 r
.8788 .36455 .88062 .36126 .8879 .36545 .88583 .36625 Mtetra
.725 .2 0 r
.88583 .36625 .8879 .36545 .89495 .36718 .89355 .37372 Mtetra
.785 .72 .187 r
.89355 .37372 .89495 .36718 .9 .35176 .89754 .34889 Mtetra
.889 .859 .805 r
.89754 .34889 .9 .35176 .90572 .3423 .90352 .3414 Mtetra
.682 .525 .667 r
.3088 .55416 .31155 .56828 .31765 .5556 .31446 .54835 Mtetra
.871 .675 .635 r
.31446 .54835 .31765 .5556 .3241 .53671 .3212 .52494 Mtetra
.748 .581 .668 r
.3212 .52494 .3241 .53671 .33028 .52161 .32707 .51522 Mtetra
0 .075 .637 r
.32707 .51522 .33028 .52161 .33577 .51815 .33199 .52166 Mtetra
.83 .483 .4 r
.33199 .52166 .33577 .51815 .34058 .5271 .33659 .53449 Mtetra
.602 .249 .343 r
.33659 .53449 .34058 .5271 .34553 .53434 .34182 .53692 Mtetra
.391 0 0 r
.34182 .53692 .34553 .53434 .35041 .5435 .34719 .53703 Mtetra
.781 .658 .727 r
.34719 .53703 .35041 .5435 .35608 .53812 .35295 .52978 Mtetra
.828 .651 .662 r
.35295 .52978 .35608 .53812 .3624 .51927 .3591 .51478 Mtetra
.734 .698 .816 r
.3591 .51478 .3624 .51927 .36841 .50606 .36466 .51122 Mtetra
.683 .867 .471 r
.36466 .51122 .36841 .50606 .37372 .50767 .37048 .50232 Mtetra
.7 .656 .803 r
.37048 .50232 .37372 .50767 .37897 .51124 .37601 .4994 Mtetra
.292 .287 .682 r
.37601 .4994 .37897 .51124 .38427 .51402 .38117 .50549 Mtetra
.751 .613 .706 r
.38117 .50549 .38427 .51402 .39041 .49701 .3869 .49837 Mtetra
0 0 0 r
.3869 .49837 .39041 .49701 .39588 .49626 .39242 .4966 Mtetra
.552 0 0 r
.39242 .4966 .39588 .49626 .40114 .50122 .39779 .49915 Mtetra
.168 .605 .938 r
.39779 .49915 .40114 .50122 .40672 .49853 .40323 .50025 Mtetra
.758 .321 .212 r
.40323 .50025 .40672 .49853 .41247 .49074 .40853 .5063 Mtetra
.576 .283 .434 r
.40853 .5063 .41247 .49074 .41765 .50048 .41399 .5082 Mtetra
.693 .349 .388 r
.41399 .5082 .41765 .50048 .42285 .51135 .41935 .51446 Mtetra
.665 .23 .206 r
.41935 .51446 .42285 .51135 .42836 .51302 .42481 .51823 Mtetra
.396 0 .14 r
.42481 .51823 .42836 .51302 .4336 .52593 .43045 .5172 Mtetra
.615 .54 .747 r
.43045 .5172 .4336 .52593 .43928 .52338 .4361 .5159 Mtetra
.81 .656 .692 r
.4361 .5159 .43928 .52338 .44492 .52348 .442 .50524 Mtetra
.812 .596 .61 r
.442 .50524 .44492 .52348 .45103 .50275 .44828 .47768 Mtetra
.569 .408 .624 r
.44828 .47768 .45103 .50275 .45696 .48846 .45389 .47744 Mtetra
.579 .486 .713 r
.45389 .47744 .45696 .48846 .46264 .48601 .45952 .47709 Mtetra
.493 .465 .755 r
.45952 .47709 .46264 .48601 .46844 .47707 .46513 .47872 Mtetra
.583 .071 .001 r
.46513 .47872 .46844 .47707 .4739 .48915 .47075 .48122 Mtetra
.222 .32 .753 r
.47075 .48122 .4739 .48915 .47966 .48402 .47636 .48622 Mtetra
0 0 0 r
.47636 .48622 .47966 .48402 .48523 .49388 .48212 .48254 Mtetra
.481 .422 .714 r
.48212 .48254 .48523 .49388 .491 .4902 .48782 .48497 Mtetra
.654 .65 .834 r
.48782 .48497 .491 .4902 .49671 .49477 .49358 .48314 Mtetra
.535 .454 .71 r
.49358 .48314 .49671 .49477 .50251 .48942 .49933 .48419 Mtetra
.654 .651 .834 r
.49933 .48419 .50251 .48942 .50832 .48388 .50513 .48235 Mtetra
.922 .836 .742 r
.50513 .48235 .50832 .48388 .51413 .47616 .51096 .4722 Mtetra
.824 .749 .78 r
.51096 .4722 .51413 .47616 .51993 .47433 .51678 .46556 Mtetra
.751 .614 .706 r
.51678 .46556 .51993 .47433 .52573 .46867 .52259 .45839 Mtetra
.625 .524 .72 r
.52259 .45839 .52573 .46867 .53155 .46682 .5284 .45653 Mtetra
0 0 .495 r
.5284 .45653 .53155 .46682 .5374 .47312 .53426 .46969 Mtetra
.438 .652 .95 r
.53426 .46969 .5374 .47312 .54325 .4694 .54013 .47023 Mtetra
.251 .755 .716 r
.54013 .47023 .54325 .4694 .54912 .46994 .54601 .46836 Mtetra
.523 .832 1 r
.54601 .46836 .54912 .46994 .555 .46808 .55191 .46726 Mtetra
.967 .799 .622 r
.55191 .46726 .555 .46808 .56079 .45691 .55763 .4471 Mtetra
.756 .605 .69 r
.55763 .4471 .56079 .45691 .56668 .45504 .56343 .43875 Mtetra
.531 .415 .666 r
.56343 .43875 .56668 .45504 .57267 .45957 .56937 .44042 Mtetra
.148 .135 .585 r
.56937 .44042 .57267 .45957 .57837 .44402 .57553 .45538 Mtetra
.61 .286 .396 r
.57553 .45538 .57837 .44402 .58421 .43854 .58157 .45881 Mtetra
.392 .14 .408 r
.58157 .45881 .58421 .43854 .59031 .44543 .58743 .4513 Mtetra
0 0 0 r
.58743 .4513 .59031 .44543 .59639 .44959 .59321 .4401 Mtetra
.805 .634 .67 r
.59321 .4401 .59639 .44959 .6019 .42853 .59894 .428 Mtetra
.724 .195 0 r
.59894 .428 .6019 .42853 .60842 .44897 .6051 .43414 Mtetra
.369 .317 .668 r
.6051 .43414 .60842 .44897 .61469 .45682 .61132 .44089 Mtetra
.756 .565 .638 r
.61132 .44089 .61469 .45682 .62088 .46046 .617 .42717 Mtetra
.535 .371 .606 r
.617 .42717 .62088 .46046 .62601 .42874 .62315 .42996 Mtetra
.794 .334 .147 r
.62315 .42996 .62601 .42874 .63261 .44478 .62951 .43815 Mtetra
0 0 .393 r
.62951 .43815 .63261 .44478 .63894 .45057 .63606 .45065 Mtetra
.807 .329 .07 r
.63606 .45065 .63894 .45057 .64549 .4611 .64255 .45942 Mtetra
.938 .851 .731 r
.64255 .45942 .64549 .4611 .65127 .45036 .64835 .44864 Mtetra
.904 .876 .798 r
.64835 .44864 .65127 .45036 .65681 .43421 .65425 .44083 Mtetra
0 0 0 r
.65425 .44083 .65681 .43421 .66284 .4304 .65988 .42681 Mtetra
.94 .573 .208 r
.65988 .42681 .66284 .4304 .66974 .44621 .66734 .45541 Mtetra
.441 .106 .3 r
.66734 .45541 .66974 .44621 .6765 .45705 .67353 .45348 Mtetra
.82 .786 .821 r
.67353 .45348 .6765 .45705 .68275 .45621 .67957 .44771 Mtetra
.481 .475 .773 r
.67957 .44771 .68275 .45621 .68869 .44861 .68597 .44959 Mtetra
.185 0 0 r
.68597 .44959 .68869 .44861 .69511 .45044 .69231 .44957 Mtetra
.861 .953 .87 r
.69231 .44957 .69511 .45044 .70145 .45039 .69836 .44377 Mtetra
.816 .686 .72 r
.69836 .44377 .70145 .45039 .70744 .44364 .70424 .43484 Mtetra
.716 .602 .728 r
.70424 .43484 .70744 .44364 .7134 .4365 .71032 .42965 Mtetra
.786 .67 .736 r
.71032 .42965 .7134 .4365 .71858 .4163 .71628 .4224 Mtetra
0 0 0 r
.71628 .4224 .71858 .4163 .725 .41711 .72216 .41399 Mtetra
.934 .797 .685 r
.72216 .41399 .725 .41711 .731 .4111 .72772 .40066 Mtetra
.844 .647 .635 r
.72772 .40066 .731 .4111 .73615 .39207 .73298 .3831 Mtetra
.633 .553 .747 r
.73298 .3831 .73615 .39207 .74233 .38893 .73922 .38109 Mtetra
.652 .585 .767 r
.73922 .38109 .74233 .38893 .74867 .38807 .74546 .3787 Mtetra
.62 .54 .742 r
.74546 .3787 .74867 .38807 .75489 .3853 .75176 .37706 Mtetra
.599 .548 .769 r
.75176 .37706 .75489 .3853 .76084 .37877 .75813 .37617 Mtetra
.724 .242 0 r
.75813 .37617 .76084 .37877 .76715 .37696 .76537 .38666 Mtetra
.373 .057 .295 r
.76537 .38666 .76715 .37696 .7741 .38323 .77157 .38276 Mtetra
.03 .595 .787 r
.77157 .38276 .7741 .38323 .78059 .38309 .77812 .38314 Mtetra
.766 .255 0 r
.77812 .38314 .78059 .38309 .78765 .38963 .78534 .39151 Mtetra
.478 0 0 r
.78534 .39151 .78765 .38963 .7951 .40027 .79206 .39325 Mtetra
0 0 .534 r
.79206 .39325 .7951 .40027 .80251 .40969 .79975 .40595 Mtetra
.867 .798 .781 r
.79975 .40595 .80251 .40969 .81024 .42199 .80572 .39817 Mtetra
.707 .507 .616 r
.80572 .39817 .81024 .42199 .81536 .40459 .81119 .38475 Mtetra
.655 .484 .641 r
.81119 .38475 .81536 .40459 .82116 .39496 .81727 .37848 Mtetra
.535 .422 .671 r
.81727 .37848 .82116 .39496 .82783 .39481 .82409 .38014 Mtetra
.482 .4 .687 r
.82409 .38014 .82783 .39481 .83389 .38806 .83113 .38372 Mtetra
.748 .748 .851 r
.83113 .38372 .83389 .38806 .84059 .38791 .83747 .37977 Mtetra
.632 .573 .77 r
.83747 .37977 .84059 .38791 .84732 .38776 .84403 .3779 Mtetra
.629 .541 .736 r
.84403 .3779 .84732 .38776 .85446 .39145 .85058 .37583 Mtetra
.416 .351 .676 r
.85058 .37583 .85446 .39145 .86153 .39409 .85803 .38225 Mtetra
.768 .597 .667 r
.85803 .38225 .86153 .39409 .86682 .37965 .86372 .37167 Mtetra
.588 .552 .782 r
.86372 .37167 .86682 .37965 .87294 .37324 .87047 .37103 Mtetra
.924 .886 .777 r
.87047 .37103 .87294 .37324 .8788 .36455 .87636 .36231 Mtetra
.183 .597 .942 r
.87636 .36231 .8788 .36455 .88583 .36625 .88338 .36387 Mtetra
.198 .596 .945 r
.88338 .36387 .88583 .36625 .89355 .37372 .89044 .36548 Mtetra
.922 .701 .586 r
.89044 .36548 .89355 .37372 .89754 .34889 .89453 .34137 Mtetra
.836 .685 .695 r
.89453 .34137 .89754 .34889 .90352 .3414 .90013 .33063 Mtetra
.565 .412 .632 r
.30655 .5323 .3088 .55416 .31446 .54835 .31183 .53238 Mtetra
.664 .504 .657 r
.31183 .53238 .31446 .54835 .3212 .52494 .31745 .52706 Mtetra
.934 .965 .749 r
.31745 .52706 .3212 .52494 .32707 .51522 .32329 .51829 Mtetra
.425 0 .017 r
.32329 .51829 .32707 .51522 .33199 .52166 .32858 .51846 Mtetra
.856 .404 .022 r
.32858 .51846 .33199 .52166 .33659 .53449 .33338 .52763 Mtetra
.721 .35 0 r
.33338 .52763 .33659 .53449 .34182 .53692 .33812 .53885 Mtetra
.483 .876 .7 r
.33812 .53885 .34182 .53692 .34719 .53703 .3437 .53527 Mtetra
.907 .793 .723 r
.3437 .53527 .34719 .53703 .35295 .52978 .34969 .52394 Mtetra
.814 .681 .717 r
.34969 .52394 .35295 .52978 .3591 .51478 .35555 .51496 Mtetra
.948 .85 .712 r
.35555 .51496 .3591 .51478 .36466 .51122 .36155 .50272 Mtetra
.685 .579 .731 r
.36155 .50272 .36466 .51122 .37048 .50232 .36712 .49907 Mtetra
.838 .761 .777 r
.36712 .49907 .37048 .50232 .37601 .4994 .37285 .4921 Mtetra
.07 .237 .729 r
.37285 .4921 .37601 .4994 .38117 .50549 .37802 .49765 Mtetra
.749 .622 .718 r
.37802 .49765 .38117 .50549 .3869 .49837 .38374 .49124 Mtetra
0 .155 .687 r
.38374 .49124 .3869 .49837 .39242 .4966 .38892 .49765 Mtetra
.632 .117 .002 r
.38892 .49765 .39242 .4966 .39779 .49915 .39427 .50082 Mtetra
.714 .253 .156 r
.39427 .50082 .39779 .49915 .40323 .50025 .3996 .5055 Mtetra
.832 .498 .422 r
.3996 .5055 .40323 .50025 .40853 .5063 .40454 .52168 Mtetra
.491 .202 .402 r
.40454 .52168 .40853 .5063 .41399 .5082 .41016 .51991 Mtetra
0 0 .143 r
.41016 .51991 .41399 .5082 .41935 .51446 .41607 .50985 Mtetra
.331 .52 .89 r
.41607 .50985 .41935 .51446 .42481 .51823 .4216 .51177 Mtetra
.696 .628 .776 r
.4216 .51177 .42481 .51823 .43045 .5172 .4273 .5085 Mtetra
.681 .577 .732 r
.4273 .5085 .43045 .5172 .4361 .5159 .43301 .50493 Mtetra
.783 .608 .663 r
.43301 .50493 .4361 .5159 .442 .50524 .43896 .49266 Mtetra
.802 .609 .641 r
.43896 .49266 .442 .50524 .44828 .47768 .44499 .4758 Mtetra
.849 .846 .84 r
.44499 .4758 .44828 .47768 .45389 .47744 .45073 .47008 Mtetra
.697 .608 .753 r
.45073 .47008 .45389 .47744 .45952 .47709 .45643 .46643 Mtetra
.591 .498 .718 r
.45643 .46643 .45952 .47709 .46513 .47872 .46208 .46569 Mtetra
.353 .318 .68 r
.46208 .46569 .46513 .47872 .47075 .48122 .46763 .4715 Mtetra
0 0 .546 r
.46763 .4715 .47075 .48122 .47636 .48622 .47314 .48244 Mtetra
.635 .711 .902 r
.47314 .48244 .47636 .48622 .48212 .48254 .47887 .48102 Mtetra
.891 .858 .802 r
.47887 .48102 .48212 .48254 .48782 .48497 .4847 .47363 Mtetra
.397 .368 .709 r
.4847 .47363 .48782 .48497 .49358 .48314 .49039 .47789 Mtetra
.654 .65 .834 r
.49039 .47789 .49358 .48314 .49933 .48419 .49617 .47605 Mtetra
.342 .392 .769 r
.49617 .47605 .49933 .48419 .50513 .48235 .50192 .47981 Mtetra
.658 .801 .951 r
.50192 .47981 .50513 .48235 .51096 .4722 .50774 .47794 Mtetra
.679 .819 .377 r
.50774 .47794 .51096 .4722 .51678 .46556 .51359 .46681 Mtetra
.913 .98 .76 r
.51359 .46681 .51678 .46556 .52259 .45839 .51943 .45877 Mtetra
.684 .978 .892 r
.51943 .45877 .52259 .45839 .5284 .45653 .52525 .45505 Mtetra
.548 0 0 r
.52525 .45505 .5284 .45653 .53426 .46969 .5311 .45938 Mtetra
.411 .393 .729 r
.5311 .45938 .53426 .46969 .54013 .47023 .53697 .46306 Mtetra
.871 .685 .648 r
.53697 .46306 .54013 .47023 .54601 .46836 .54277 .44554 Mtetra
.505 .37 .63 r
.54277 .44554 .54601 .46836 .55191 .46726 .54867 .44921 Mtetra
.733 .542 .634 r
.54867 .44921 .55191 .46726 .55763 .4471 .55446 .4364 Mtetra
.008 .118 .631 r
.55446 .4364 .55763 .4471 .56343 .43875 .56046 .4465 Mtetra
.762 .414 .394 r
.56046 .4465 .56343 .43875 .56937 .44042 .56654 .45773 Mtetra
.712 .411 .466 r
.56654 .45773 .56937 .44042 .57553 .45538 .57272 .47126 Mtetra
.752 .445 .464 r
.57272 .47126 .57553 .45538 .58157 .45881 .57903 .48899 Mtetra
.15 0 .369 r
.57903 .48899 .58157 .45881 .58743 .4513 .58468 .46559 Mtetra
.411 .126 .367 r
.58468 .46559 .58743 .4513 .59321 .4401 .59064 .46113 Mtetra
0 0 .236 r
.59064 .46113 .59321 .4401 .59894 .428 .59619 .43792 Mtetra
0 0 0 r
.59619 .43792 .59894 .428 .6051 .43414 .6019 .42383 Mtetra
.155 .227 .687 r
.6019 .42383 .6051 .43414 .61132 .44089 .60814 .43191 Mtetra
.848 .659 .647 r
.60814 .43191 .61132 .44089 .617 .42717 .61375 .41526 Mtetra
.531 .45 .709 r
.61375 .41526 .617 .42717 .62315 .42996 .61985 .41647 Mtetra
0 0 .5 r
.61985 .41647 .62315 .42996 .62951 .43815 .62646 .43365 Mtetra
.874 .471 .019 r
.62646 .43365 .62951 .43815 .63606 .45065 .63318 .45132 Mtetra
.855 .422 .189 r
.63318 .45132 .63606 .45065 .64255 .45942 .63979 .4634 Mtetra
.676 .849 .437 r
.63979 .4634 .64255 .45942 .64835 .44864 .64567 .45382 Mtetra
.939 .867 .445 r
.64567 .45382 .64835 .44864 .65425 .44083 .65114 .43408 Mtetra
.736 .368 0 r
.65114 .43408 .65425 .44083 .65988 .42681 .65805 .45117 Mtetra
.576 .304 .466 r
.65805 .45117 .65988 .42681 .66734 .45541 .66443 .45376 Mtetra
.337 .741 .981 r
.66443 .45376 .66734 .45541 .67353 .45348 .67073 .45375 Mtetra
.788 .998 .854 r
.67073 .45375 .67353 .45348 .67957 .44771 .67681 .44853 Mtetra
.437 0 0 r
.67681 .44853 .67957 .44771 .68597 .44959 .68323 .45043 Mtetra
.561 .929 .786 r
.68323 .45043 .68597 .44959 .69231 .44957 .68939 .44654 Mtetra
.91 .809 .735 r
.68939 .44654 .69231 .44957 .69836 .44377 .69522 .43617 Mtetra
.854 .682 .668 r
.69522 .43617 .69836 .44377 .70424 .43484 .70084 .42231 Mtetra
.783 .599 .651 r
.70084 .42231 .70424 .43484 .71032 .42965 .70647 .40923 Mtetra
.502 .379 .645 r
.70647 .40923 .71032 .42965 .71628 .4224 .71304 .41293 Mtetra
.821 .645 .664 r
.71304 .41293 .71628 .4224 .72216 .41399 .71865 .39984 Mtetra
.784 .589 .638 r
.71865 .39984 .72216 .41399 .72772 .40066 .72411 .385 Mtetra
.641 .493 .666 r
.72411 .385 .72772 .40066 .73298 .3831 .73024 .38105 Mtetra
.554 .819 .995 r
.73024 .38105 .73298 .3831 .73922 .38109 .73655 .37983 Mtetra
0 .496 .812 r
.73655 .37983 .73922 .38109 .74546 .3787 .74308 .3815 Mtetra
.762 .31 .178 r
.74308 .3815 .74546 .3787 .75176 .37706 .75007 .3894 Mtetra
.523 .209 .377 r
.75007 .3894 .75176 .37706 .75813 .37617 .75654 .38927 Mtetra
.55 .237 .391 r
.75654 .38927 .75813 .37617 .76537 .38666 .76311 .39023 Mtetra
.231 0 0 r
.76311 .39023 .76537 .38666 .77157 .38276 .76948 .3882 Mtetra
.107 0 .04 r
.76948 .3882 .77157 .38276 .77812 .38314 .77563 .38318 Mtetra
.016 .59 .709 r
.77563 .38318 .77812 .38314 .78534 .39151 .78218 .38305 Mtetra
.691 .596 .745 r
.78218 .38305 .78534 .39151 .79206 .39325 .78843 .3791 Mtetra
.525 .431 .69 r
.78843 .3791 .79206 .39325 .79975 .40595 .79517 .38087 Mtetra
.692 .494 .615 r
.79517 .38087 .79975 .40595 .80572 .39817 .80073 .36857 Mtetra
.586 .414 .615 r
.80073 .36857 .80572 .39817 .81119 .38475 .80716 .36651 Mtetra
.602 .456 .655 r
.80716 .36651 .81119 .38475 .81727 .37848 .81361 .36445 Mtetra
.481 .403 .692 r
.81361 .36445 .81727 .37848 .82409 .38014 .82059 .36789 Mtetra
.469 .413 .712 r
.82059 .36789 .82409 .38014 .83113 .38372 .8276 .37125 Mtetra
.655 .526 .695 r
.8276 .37125 .83113 .38372 .83747 .37977 .83394 .36739 Mtetra
.588 .486 .706 r
.83394 .36739 .83747 .37977 .84403 .3779 .84059 .3666 Mtetra
.623 .519 .715 r
.84059 .3666 .84403 .3779 .85058 .37583 .84714 .36452 Mtetra
.475 .429 .726 r
.84714 .36452 .85058 .37583 .85803 .38225 .85422 .36746 Mtetra
.574 .459 .684 r
.85422 .36746 .85803 .38225 .86372 .37167 .86099 .36715 Mtetra
.899 .777 .717 r
.86099 .36715 .86372 .37167 .87047 .37103 .86665 .35626 Mtetra
.61 .481 .68 r
.86665 .35626 .87047 .37103 .87636 .36231 .87325 .35415 Mtetra
.468 .479 .786 r
.87325 .35415 .87636 .36231 .88338 .36387 .88034 .35633 Mtetra
.573 .555 .796 r
.88034 .35633 .88338 .36387 .89044 .36548 .88719 .35604 Mtetra
.844 .66 .653 r
.88719 .35604 .89044 .36548 .89453 .34137 .89242 .34166 Mtetra
.938 .959 .662 r
.89242 .34166 .89453 .34137 .90013 .33063 .89809 .33124 Mtetra
.838 .46 0 r
.30333 .52554 .30655 .5323 .31183 .53238 .30779 .53828 Mtetra
0 0 0 r
.30779 .53828 .31183 .53238 .31745 .52706 .31342 .5333 Mtetra
.989 .89 .58 r
.31342 .5333 .31745 .52706 .32329 .51829 .31997 .51341 Mtetra
.727 .68 .804 r
.31997 .51341 .32329 .51829 .32858 .51846 .32548 .5099 Mtetra
.668 .349 0 r
.32548 .5099 .32858 .51846 .33338 .52763 .33007 .5226 Mtetra
.387 .526 .874 r
.33007 .5226 .33338 .52763 .33812 .53885 .33533 .52421 Mtetra
.565 .444 .674 r
.33533 .52421 .33812 .53885 .3437 .53527 .3407 .52429 Mtetra
.699 .559 .692 r
.3407 .52429 .3437 .53527 .34969 .52394 .34639 .51883 Mtetra
.843 .702 .707 r
.34639 .51883 .34969 .52394 .35555 .51496 .35235 .50808 Mtetra
.834 .669 .679 r
.35235 .50808 .35555 .51496 .36155 .50272 .3584 .49514 Mtetra
.638 .571 .763 r
.3584 .49514 .36155 .50272 .36712 .49907 .36388 .49337 Mtetra
.144 .35 .809 r
.36388 .49337 .36712 .49907 .37285 .4921 .36911 .49718 Mtetra
.795 .916 .528 r
.36911 .49718 .37285 .4921 .37802 .49765 .375 .48705 Mtetra
.544 .468 .72 r
.375 .48705 .37802 .49765 .38374 .49124 .38041 .48768 Mtetra
.892 .47 .095 r
.38041 .48768 .38374 .49124 .38892 .49765 .38536 .4995 Mtetra
.819 .423 .301 r
.38536 .4995 .38892 .49765 .39427 .50082 .39048 .50882 Mtetra
.509 .156 .303 r
.39048 .50882 .39427 .50082 .3996 .5055 .396 .50889 Mtetra
.848 .499 .392 r
.396 .50889 .3996 .5055 .40454 .52168 .40098 .52396 Mtetra
.928 .973 .723 r
.40098 .52396 .40454 .52168 .41016 .51991 .40688 .51478 Mtetra
.856 .708 .697 r
.40688 .51478 .41016 .51991 .41607 .50985 .41287 .50286 Mtetra
.641 .589 .78 r
.41287 .50286 .41607 .50985 .4216 .51177 .41851 .50106 Mtetra
.565 .482 .72 r
.41851 .50106 .4216 .51177 .4273 .5085 .4241 .50111 Mtetra
.559 .537 .787 r
.4241 .50111 .4273 .5085 .43301 .50493 .42972 .50116 Mtetra
.884 .744 .702 r
.42972 .50116 .43301 .50493 .43896 .49266 .43568 .48891 Mtetra
.75 .742 .845 r
.43568 .48891 .43896 .49266 .44499 .4758 .4414 .48525 Mtetra
.221 0 .203 r
.4414 .48525 .44499 .4758 .45073 .47008 .44717 .47969 Mtetra
.517 .183 .34 r
.44717 .47969 .45073 .47008 .45643 .46643 .45282 .47971 Mtetra
.345 .058 .326 r
.45282 .47971 .45643 .46643 .46208 .46569 .4586 .47426 Mtetra
0 0 0 r
.4586 .47426 .46208 .46569 .46763 .4715 .46452 .461 Mtetra
.378 .366 .72 r
.46452 .461 .46763 .4715 .47314 .48244 .47013 .46522 Mtetra
.442 .347 .652 r
.47013 .46522 .47314 .48244 .47887 .48102 .47575 .47022 Mtetra
.652 .535 .708 r
.47575 .47022 .47887 .48102 .4847 .47363 .48151 .46714 Mtetra
0 0 .577 r
.48151 .46714 .4847 .47363 .49039 .47789 .48716 .47533 Mtetra
.446 0 0 r
.48716 .47533 .49039 .47789 .49617 .47605 .49289 .47992 Mtetra
.563 .122 .16 r
.49289 .47992 .49617 .47605 .50192 .47981 .49867 .48176 Mtetra
.905 .982 .719 r
.49867 .48176 .50192 .47981 .50774 .47794 .50454 .47313 Mtetra
.84 .723 .735 r
.50454 .47313 .50774 .47794 .51359 .46681 .51041 .46429 Mtetra
.924 .784 .688 r
.51041 .46429 .51359 .46681 .51943 .45877 .51627 .45052 Mtetra
.635 .562 .755 r
.51627 .45052 .51943 .45877 .52525 .45505 .52209 .44865 Mtetra
.562 .568 .817 r
.52209 .44865 .52525 .45505 .5311 .45938 .52793 .44856 Mtetra
.504 .445 .723 r
.52793 .44856 .5311 .45938 .53697 .46306 .53379 .45031 Mtetra
.736 .569 .666 r
.53379 .45031 .53697 .46306 .54277 .44554 .53963 .4412 Mtetra
.802 .735 .789 r
.53963 .4412 .54277 .44554 .54867 .44921 .54547 .43531 Mtetra
.423 .359 .681 r
.54547 .43531 .54867 .44921 .55446 .4364 .5514 .44 Mtetra
.844 .471 .345 r
.5514 .44 .55446 .4364 .56046 .4465 .55746 .45447 Mtetra
.645 .288 .351 r
.55746 .45447 .56046 .4465 .56654 .45773 .56348 .45888 Mtetra
.876 .479 .277 r
.56348 .45888 .56654 .45773 .57272 .47126 .56967 .47348 Mtetra
.534 .873 .614 r
.56967 .47348 .57272 .47126 .57903 .48899 .57563 .4684 Mtetra
.633 .467 .64 r
.57563 .4684 .57903 .48899 .58468 .46559 .5816 .46379 Mtetra
.925 .841 .742 r
.5816 .46379 .58468 .46559 .59064 .46113 .58747 .45356 Mtetra
.898 .69 .613 r
.58747 .45356 .59064 .46113 .59619 .43792 .59302 .42928 Mtetra
.799 .641 .686 r
.59302 .42928 .59619 .43792 .6019 .42383 .59882 .41888 Mtetra
.779 .364 0 r
.59882 .41888 .6019 .42383 .60814 .43191 .60519 .43241 Mtetra
.988 .839 .606 r
.60519 .43241 .60814 .43191 .61375 .41526 .61077 .41326 Mtetra
.499 0 0 r
.61077 .41326 .61375 .41526 .61985 .41647 .61698 .41819 Mtetra
.919 .564 .345 r
.61698 .41819 .61985 .41647 .62646 .43365 .62391 .44592 Mtetra
.806 .482 .441 r
.62391 .44592 .62646 .43365 .63318 .45132 .6308 .46814 Mtetra
.123 0 .296 r
.6308 .46814 .63318 .45132 .63979 .4634 .63656 .4541 Mtetra
.132 .235 .705 r
.63656 .4541 .63979 .4634 .64567 .45382 .64306 .46182 Mtetra
.729 .369 .368 r
.64306 .46182 .64567 .45382 .65114 .43408 .64967 .4709 Mtetra
.526 .28 .485 r
.64967 .4709 .65114 .43408 .65805 .45117 .65587 .46842 Mtetra
.643 .341 .444 r
.65587 .46842 .65805 .45117 .66443 .45376 .66249 .47542 Mtetra
.343 .106 .402 r
.66249 .47542 .66443 .45376 .67073 .45375 .66838 .46496 Mtetra
.25 0 .272 r
.66838 .46496 .67073 .45375 .67681 .44853 .67441 .45785 Mtetra
.439 .103 .298 r
.67441 .45785 .67681 .44853 .68323 .45043 .68068 .45589 Mtetra
.677 .784 .313 r
.68068 .45589 .68323 .45043 .68939 .44654 .68642 .44292 Mtetra
.873 .79 .765 r
.68642 .44292 .68939 .44654 .69522 .43617 .69237 .43446 Mtetra
.971 .813 .63 r
.69237 .43446 .69522 .43617 .70084 .42231 .69781 .41677 Mtetra
.884 .727 .683 r
.69781 .41677 .70084 .42231 .70647 .40923 .70345 .40367 Mtetra
.419 .528 .862 r
.70345 .40367 .70647 .40923 .71304 .41293 .70992 .40546 Mtetra
.694 .616 .764 r
.70992 .40546 .71304 .41293 .71865 .39984 .7161 .40179 Mtetra
.991 .875 .543 r
.7161 .40179 .71865 .39984 .72411 .385 .72136 .38309 Mtetra
.532 .821 .999 r
.72136 .38309 .72411 .385 .73024 .38105 .72768 .38196 Mtetra
.609 .058 0 r
.72768 .38196 .73024 .38105 .73655 .37983 .73435 .38592 Mtetra
.236 0 .12 r
.73435 .38592 .73655 .37983 .74308 .3815 .74052 .382 Mtetra
.277 0 0 r
.74052 .382 .74308 .3815 .75007 .3894 .74705 .38305 Mtetra
.149 .329 .789 r
.74705 .38305 .75007 .3894 .75654 .38927 .75392 .38851 Mtetra
.856 .97 .868 r
.75392 .38851 .75654 .38927 .76311 .39023 .76001 .38271 Mtetra
.747 .642 .744 r
.76001 .38271 .76311 .39023 .76948 .3882 .7661 .37694 Mtetra
.514 .452 .724 r
.7661 .37694 .76948 .3882 .77563 .38318 .77277 .37863 Mtetra
.382 .558 .903 r
.77277 .37863 .77563 .38318 .78218 .38305 .77947 .38035 Mtetra
.837 .854 .857 r
.77947 .38035 .78218 .38305 .78843 .3791 .78561 .37477 Mtetra
.919 .771 .681 r
.78561 .37477 .78843 .3791 .79517 .38087 .79109 .36139 Mtetra
.679 .501 .638 r
.79109 .36139 .79517 .38087 .80073 .36857 .79698 .35316 Mtetra
.636 .492 .669 r
.79698 .35316 .80073 .36857 .80716 .36651 .80326 .34951 Mtetra
.589 .453 .664 r
.80326 .34951 .80716 .36651 .81361 .36445 .80978 .34832 Mtetra
.562 .441 .672 r
.80978 .34832 .81361 .36445 .82059 .36789 .81644 .34856 Mtetra
.391 .312 .647 r
.81644 .34856 .82059 .36789 .8276 .37125 .82393 .35733 Mtetra
.547 .447 .693 r
.82393 .35733 .8276 .37125 .83394 .36739 .83071 .35819 Mtetra
.387 .406 .758 r
.83071 .35819 .83394 .36739 .84059 .3666 .83786 .3624 Mtetra
.662 .723 .895 r
.83786 .3624 .84059 .3666 .84714 .36452 .84441 .3603 Mtetra
0 .281 .783 r
.84441 .3603 .84714 .36452 .85422 .36746 .85178 .36596 Mtetra
.835 .945 .894 r
.85178 .36596 .85422 .36746 .86099 .36715 .85805 .36066 Mtetra
.843 .708 .715 r
.85805 .36066 .86099 .36715 .86665 .35626 .86383 .35079 Mtetra
.656 .664 .845 r
.86383 .35079 .86665 .35626 .87325 .35415 .87043 .34868 Mtetra
.413 .532 .868 r
.87043 .34868 .87325 .35415 .88034 .35633 .87751 .35062 Mtetra
.565 .609 .856 r
.87751 .35062 .88034 .35633 .88719 .35604 .88436 .35031 Mtetra
.899 .743 .68 r
.88436 .35031 .88719 .35604 .89242 .34166 .88975 .3372 Mtetra
.905 .784 .717 r
.88975 .3372 .89242 .34166 .89809 .33124 .89538 .3263 Mtetra
.9 .484 .165 r
.29985 .52261 .30333 .52554 .30779 .53828 .30441 .53367 Mtetra
0 .133 .672 r
.30441 .53367 .30779 .53828 .31342 .5333 .30941 .53857 Mtetra
.993 .864 .598 r
.30941 .53857 .31342 .5333 .31997 .51341 .31611 .51686 Mtetra
.98 .908 .658 r
.31611 .51686 .31997 .51341 .32548 .5099 .32231 .50253 Mtetra
0 0 .45 r
.32231 .50253 .32548 .5099 .33007 .5226 .32709 .51159 Mtetra
.712 .566 .688 r
.32709 .51159 .33007 .5226 .33533 .52421 .3328 .5053 Mtetra
.483 .364 .641 r
.3328 .5053 .33533 .52421 .3407 .52429 .33795 .50894 Mtetra
.478 .38 .665 r
.33795 .50894 .3407 .52429 .34639 .51883 .34316 .51209 Mtetra
.832 .671 .683 r
.34316 .51209 .34639 .51883 .35235 .50808 .34922 .49961 Mtetra
.5 .476 .762 r
.34922 .49961 .35235 .50808 .3584 .49514 .35455 .5009 Mtetra
.346 0 .134 r
.35455 .5009 .3584 .49514 .36388 .49337 .36006 .49912 Mtetra
.636 .258 .311 r
.36006 .49912 .36388 .49337 .36911 .49718 .36533 .50246 Mtetra
.719 .881 .483 r
.36533 .50246 .36911 .49718 .375 .48705 .37122 .49299 Mtetra
.42 .027 .186 r
.37122 .49299 .375 .48705 .38041 .48768 .37671 .49203 Mtetra
.286 0 .015 r
.37671 .49203 .38041 .48768 .38536 .4995 .38225 .49039 Mtetra
.486 .456 .75 r
.38225 .49039 .38536 .4995 .39048 .50882 .38767 .4921 Mtetra
.322 .263 .635 r
.38767 .4921 .39048 .50882 .396 .50889 .39286 .49998 Mtetra
0 0 .307 r
.39286 .49998 .396 .50889 .40098 .52396 .39789 .5131 Mtetra
.79 .613 .661 r
.39789 .5131 .40098 .52396 .40688 .51478 .40394 .50015 Mtetra
.693 .531 .662 r
.40394 .50015 .40688 .51478 .41287 .50286 .40975 .49322 Mtetra
.626 .533 .728 r
.40975 .49322 .41287 .50286 .41851 .50106 .41539 .49141 Mtetra
.564 .496 .737 r
.41539 .49141 .41851 .50106 .4241 .50111 .42098 .49145 Mtetra
.712 .581 .707 r
.42098 .49145 .4241 .50111 .42972 .50116 .42675 .48595 Mtetra
.614 .475 .669 r
.42675 .48595 .42972 .50116 .43568 .48891 .43243 .48372 Mtetra
0 .156 .697 r
.43243 .48372 .43568 .48891 .4414 .48525 .43792 .4893 Mtetra
.442 0 .094 r
.43792 .4893 .4414 .48525 .44717 .47969 .44358 .48934 Mtetra
.23 0 .211 r
.44358 .48934 .44717 .47969 .45282 .47971 .44938 .4838 Mtetra
.017 0 0 r
.44938 .4838 .45282 .47971 .4586 .47426 .45514 .48031 Mtetra
0 0 0 r
.45514 .48031 .4586 .47426 .46452 .461 .46103 .47027 Mtetra
.46103 .47027 .46452 .461 .47013 .46522 .46698 .4564 Mtetra
0 0 .391 r
.46698 .4564 .47013 .46522 .47575 .47022 .47247 .46919 Mtetra
.429 .826 .982 r
.47247 .46919 .47575 .47022 .48151 .46714 .47822 .4683 Mtetra
.836 .419 .249 r
.47822 .4683 .48151 .46714 .48716 .47533 .48384 .47835 Mtetra
.119 0 0 r
.48384 .47835 .48716 .47533 .49289 .47992 .48965 .47633 Mtetra
.804 .764 .816 r
.48965 .47633 .49289 .47992 .49867 .48176 .49551 .47097 Mtetra
.764 .6 .675 r
.49551 .47097 .49867 .48176 .50454 .47313 .50139 .46103 Mtetra
.684 .542 .687 r
.50139 .46103 .50454 .47313 .51041 .46429 .50723 .4559 Mtetra
.818 .65 .675 r
.50723 .4559 .51041 .46429 .51627 .45052 .5131 .44359 Mtetra
.568 .556 .801 r
.5131 .44359 .51627 .45052 .52209 .44865 .51892 .44341 Mtetra
.403 .53 .871 r
.51892 .44341 .52209 .44865 .52793 .44856 .52476 .44508 Mtetra
.509 .683 .945 r
.52476 .44508 .52793 .44856 .53379 .45031 .53063 .44501 Mtetra
.726 .679 .805 r
.53063 .44501 .53379 .45031 .53963 .4412 .5365 .4413 Mtetra
.837 .984 .87 r
.5365 .4413 .53963 .4412 .54547 .43531 .54236 .43594 Mtetra
.129 0 0 r
.54236 .43594 .54547 .43531 .5514 .44 .54827 .43594 Mtetra
.526 .655 .917 r
.54827 .43594 .5514 .44 .55746 .45447 .55419 .43588 Mtetra
.392 .308 .641 r
.55419 .43588 .55746 .45447 .56348 .45888 .56021 .44323 Mtetra
.697 .528 .655 r
.56021 .44323 .56348 .45888 .56967 .47348 .56609 .43544 Mtetra
.554 .378 .598 r
.56609 .43544 .56967 .47348 .57563 .4684 .57209 .43637 Mtetra
.684 .48 .604 r
.57209 .43637 .57563 .4684 .5816 .46379 .57786 .42193 Mtetra
.573 .389 .594 r
.57786 .42193 .5816 .46379 .58747 .45356 .58383 .42055 Mtetra
.501 .346 .603 r
.58383 .42055 .58747 .45356 .59302 .42928 .58995 .42595 Mtetra
.787 .326 0 r
.58995 .42595 .59302 .42928 .59882 .41888 .59623 .43677 Mtetra
.282 .039 .357 r
.59623 .43677 .59882 .41888 .60519 .43241 .60208 .42663 Mtetra
.889 .715 .659 r
.60208 .42663 .60519 .43241 .61077 .41326 .60776 .41071 Mtetra
.727 .229 0 r
.60776 .41071 .61077 .41326 .61698 .41819 .61407 .4192 Mtetra
.893 .502 .276 r
.61407 .4192 .61698 .41819 .62391 .44592 .6207 .43671 Mtetra
.696 .379 0 r
.6207 .43671 .62391 .44592 .6308 .46814 .62749 .45687 Mtetra
.603 .505 .715 r
.62749 .45687 .6308 .46814 .63656 .4541 .63368 .4556 Mtetra
.836 .404 .208 r
.63368 .4556 .63656 .4541 .64306 .46182 .64032 .46677 Mtetra
.873 .514 .366 r
.64032 .46677 .64306 .46182 .64967 .4709 .64743 .48902 Mtetra
.57 .279 .435 r
.64743 .48902 .64967 .4709 .65587 .46842 .65386 .49104 Mtetra
.591 .311 .46 r
.65386 .49104 .65587 .46842 .66249 .47542 .66039 .49493 Mtetra
.328 .084 .384 r
.66039 .49493 .66249 .47542 .66838 .46496 .66638 .48506 Mtetra
0 0 .276 r
.66638 .48506 .66838 .46496 .67441 .45785 .67185 .46403 Mtetra
0 0 0 r
.67185 .46403 .67441 .45785 .68068 .45589 .67775 .45356 Mtetra
.952 .811 .668 r
.67775 .45356 .68068 .45589 .68642 .44292 .68342 .4387 Mtetra
.89 .765 .717 r
.68342 .4387 .68642 .44292 .69237 .43446 .68925 .42769 Mtetra
.894 .706 .64 r
.68925 .42769 .69237 .43446 .69781 .41677 .69469 .40968 Mtetra
.661 .608 .784 r
.69469 .40968 .69781 .41677 .70345 .40367 .70093 .40719 Mtetra
.633 .174 .146 r
.70093 .40719 .70345 .40367 .70992 .40546 .70752 .41091 Mtetra
0 0 0 r
.70752 .41091 .70992 .40546 .7161 .40179 .71351 .40354 Mtetra
.986 .894 .568 r
.71351 .40354 .7161 .40179 .72136 .38309 .71894 .38705 Mtetra
0 0 0 r
.71894 .38705 .72136 .38309 .72768 .38196 .72498 .38096 Mtetra
.859 .954 .872 r
.72498 .38096 .72768 .38196 .73435 .38592 .73103 .37523 Mtetra
.672 .553 .711 r
.73103 .37523 .73435 .38592 .74052 .382 .7372 .37117 Mtetra
0 .042 .59 r
.7372 .37117 .74052 .382 .74705 .38305 .74459 .38491 Mtetra
.002 0 0 r
.74459 .38491 .74705 .38305 .75392 .38851 .75095 .38287 Mtetra
.215 .403 .833 r
.75095 .38287 .75392 .38851 .76001 .38271 .75777 .38701 Mtetra
.102 0 0 r
.75777 .38701 .76001 .38271 .7661 .37694 .76403 .38314 Mtetra
0 0 0 r
.76403 .38314 .7661 .37694 .77277 .37863 .76962 .37044 Mtetra
.306 .376 .771 r
.76962 .37044 .77277 .37863 .77947 .38035 .77657 .37534 Mtetra
.875 .749 .72 r
.77657 .37534 .77947 .38035 .78561 .37477 .78233 .36498 Mtetra
.811 .638 .668 r
.78233 .36498 .78561 .37477 .79109 .36139 .78793 .35285 Mtetra
.216 .309 .745 r
.78793 .35285 .79109 .36139 .79698 .35316 .79508 .35947 Mtetra
0 0 .047 r
.79508 .35947 .79698 .35316 .80326 .34951 .80107 .35198 Mtetra
0 0 0 r
.80107 .35198 .80326 .34951 .80978 .34832 .80727 .34702 Mtetra
.61 .906 .984 r
.80727 .34702 .80978 .34832 .81644 .34856 .81371 .34471 Mtetra
.007 .355 .829 r
.81371 .34471 .81644 .34856 .82393 .35733 .8208 .34917 Mtetra
.087 .233 .72 r
.8208 .34917 .82393 .35733 .83071 .35819 .8283 .35753 Mtetra
.702 .166 0 r
.8283 .35753 .83071 .35819 .83786 .3624 .83582 .36538 Mtetra
.62 .13 .067 r
.83582 .36538 .83786 .3624 .84441 .3603 .84299 .36922 Mtetra
.2 0 .226 r
.84299 .36922 .84441 .3603 .85178 .36596 .84908 .36208 Mtetra
.804 .792 .841 r
.84908 .36208 .85178 .36596 .85805 .36066 .85537 .35679 Mtetra
.933 .798 .687 r
.85537 .35679 .85805 .36066 .86383 .35079 .86084 .34391 Mtetra
.587 .581 .813 r
.86084 .34391 .86383 .35079 .87043 .34868 .86761 .34324 Mtetra
.43 .545 .871 r
.86761 .34324 .87043 .34868 .87751 .35062 .87466 .34492 Mtetra
.566 .61 .856 r
.87466 .34492 .87751 .35062 .88436 .35031 .88152 .34458 Mtetra
.799 .717 .774 r
.88152 .34458 .88436 .35031 .88975 .3372 .88768 .33804 Mtetra
.46 .865 .698 r
.88768 .33804 .88975 .3372 .89538 .3263 .89415 .33407 Mtetra
.508 .152 .297 r
.29562 .53037 .29985 .52261 .30441 .53367 .30092 .53047 Mtetra
.822 .761 .794 r
.30092 .53047 .30441 .53367 .30941 .53857 .30664 .52438 Mtetra
.7 .537 .663 r
.30664 .52438 .30941 .53857 .31611 .51686 .31243 .51721 Mtetra
.952 .811 .668 r
.31243 .51721 .31611 .51686 .32231 .50253 .3188 .50049 Mtetra
.485 .771 .995 r
.3188 .50049 .32231 .50253 .32709 .51159 .32415 .50003 Mtetra
.569 .472 .705 r
.32415 .50003 .32709 .51159 .3328 .5053 .3295 .49994 Mtetra
0 .154 .696 r
.3295 .49994 .3328 .5053 .33795 .50894 .33456 .50518 Mtetra
.707 .725 .864 r
.33456 .50518 .33795 .50894 .34316 .51209 .34008 .50256 Mtetra
.764 .609 .686 r
.34008 .50256 .34316 .51209 .34922 .49961 .34596 .49355 Mtetra
.216 .38 .813 r
.34596 .49355 .34922 .49961 .35455 .5009 .35118 .49702 Mtetra
.717 .723 .854 r
.35118 .49702 .35455 .5009 .36006 .49912 .35674 .49415 Mtetra
.453 .565 .878 r
.35674 .49415 .36006 .49912 .36533 .50246 .36213 .49513 Mtetra
.755 .634 .726 r
.36213 .49513 .36533 .50246 .37122 .49299 .36788 .48877 Mtetra
0 .342 .822 r
.36788 .48877 .37122 .49299 .37671 .49203 .37318 .49224 Mtetra
.95 .86 .716 r
.37318 .49224 .37671 .49203 .38225 .49039 .37919 .48029 Mtetra
.606 .513 .723 r
.37919 .48029 .38225 .49039 .38767 .4921 .38472 .47911 Mtetra
.453 .383 .688 r
.38472 .47911 .38767 .4921 .39286 .49998 .39007 .48242 Mtetra
.301 .243 .624 r
.39007 .48242 .39286 .49998 .39789 .5131 .39525 .49118 Mtetra
.661 .482 .631 r
.39525 .49118 .39789 .5131 .40394 .50015 .40107 .48387 Mtetra
.565 .436 .663 r
.40107 .48387 .40394 .50015 .40975 .49322 .40662 .48388 Mtetra
.628 .538 .733 r
.40662 .48388 .40975 .49322 .41539 .49141 .41226 .48207 Mtetra
.455 .434 .747 r
.41226 .48207 .41539 .49141 .42098 .49145 .41777 .48441 Mtetra
.315 .407 .797 r
.41777 .48441 .42098 .49145 .42675 .48595 .42327 .48773 Mtetra
.881 .992 .764 r
.42327 .48773 .42675 .48595 .43243 .48372 .42912 .48035 Mtetra
.423 .649 .952 r
.42912 .48035 .43243 .48372 .43792 .4893 .43474 .48092 Mtetra
.651 .567 .747 r
.43474 .48092 .43792 .4893 .44358 .48934 .44046 .47854 Mtetra
.295 .309 .705 r
.44046 .47854 .44358 .48934 .44938 .4838 .446 .48414 Mtetra
.452 0 0 r
.446 .48414 .44938 .4838 .45514 .48031 .45165 .48608 Mtetra
.868 .903 .489 r
.45165 .48608 .45514 .48031 .46103 .47027 .45765 .47232 Mtetra
.987 .849 .615 r
.45765 .47232 .46103 .47027 .46698 .4564 .46373 .45297 Mtetra
.908 .501 .136 r
.46373 .45297 .46698 .4564 .47247 .46919 .46918 .46763 Mtetra
.501 .823 1 r
.46918 .46763 .47247 .46919 .47822 .4683 .47494 .46669 Mtetra
.812 .327 0 r
.47494 .46669 .47822 .4683 .48384 .47835 .48059 .47493 Mtetra
.661 .744 .912 r
.48059 .47493 .48384 .47835 .48965 .47633 .48641 .47307 Mtetra
.852 .78 .78 r
.48641 .47307 .48965 .47633 .49551 .47097 .49229 .46572 Mtetra
.885 .716 .667 r
.49229 .46572 .49551 .47097 .50139 .46103 .49823 .45023 Mtetra
.57 .486 .72 r
.49823 .45023 .50139 .46103 .50723 .4559 .50404 .4501 Mtetra
.786 .684 .752 r
.50404 .4501 .50723 .4559 .5131 .44359 .5099 .44358 Mtetra
.361 0 0 r
.5099 .44358 .5131 .44359 .51892 .44341 .51573 .4453 Mtetra
.59 .083 .015 r
.51573 .4453 .51892 .44341 .52476 .44508 .52158 .44802 Mtetra
0 0 0 r
.52158 .44802 .52476 .44508 .53063 .44501 .52746 .44433 Mtetra
.102 .644 .844 r
.52746 .44433 .53063 .44501 .5365 .4413 .53335 .44454 Mtetra
.399 0 0 r
.53335 .44454 .5365 .4413 .54236 .43594 .53927 .44451 Mtetra
.673 .324 .373 r
.53927 .44451 .54236 .43594 .54827 .43594 .54524 .45042 Mtetra
.707 .396 .448 r
.54524 .45042 .54827 .43594 .55419 .43588 .55129 .46166 Mtetra
.39 .15 .426 r
.55129 .46166 .55419 .43588 .56021 .44323 .5572 .45221 Mtetra
.318 0 .24 r
.5572 .45221 .56021 .44323 .56609 .43544 .56316 .44816 Mtetra
.67 .35 .423 r
.56316 .44816 .56609 .43544 .57209 .43637 .56928 .45556 Mtetra
.687 .39 .466 r
.56928 .45556 .57209 .43637 .57786 .42193 .57551 .46735 Mtetra
.562 .316 .501 r
.57551 .46735 .57786 .42193 .58383 .42055 .58164 .46928 Mtetra
.634 .378 .512 r
.58164 .46928 .58383 .42055 .58995 .42595 .58804 .4841 Mtetra
.528 .294 .505 r
.58804 .4841 .58995 .42595 .59623 .43677 .59413 .48024 Mtetra
.359 .152 .457 r
.59413 .48024 .59623 .43677 .60208 .42663 .59987 .46092 Mtetra
.297 .094 .426 r
.59987 .46092 .60208 .42663 .60776 .41071 .60556 .44196 Mtetra
.317 .105 .425 r
.60556 .44196 .60776 .41071 .61407 .4192 .61128 .42576 Mtetra
.946 .848 .418 r
.61128 .42576 .61407 .4192 .6207 .43671 .61675 .40219 Mtetra
.377 .256 .585 r
.61675 .40219 .6207 .43671 .62749 .45687 .62332 .41699 Mtetra
.15 .086 .524 r
.62332 .41699 .62749 .45687 .63368 .4556 .63051 .44871 Mtetra
.813 .444 0 r
.63051 .44871 .63368 .4556 .64032 .46677 .63743 .46848 Mtetra
.881 .484 .275 r
.63743 .46848 .64032 .46677 .64743 .48902 .64435 .48532 Mtetra
.926 .542 .16 r
.64435 .48532 .64743 .48902 .65386 .49104 .65162 .50942 Mtetra
.546 .258 .429 r
.65162 .50942 .65386 .49104 .66039 .49493 .65808 .51005 Mtetra
.376 .099 .36 r
.65808 .51005 .66039 .49493 .66638 .48506 .66428 .5041 Mtetra
.01 0 .274 r
.66428 .5041 .66638 .48506 .67185 .46403 .66989 .4848 Mtetra
.219 .004 .359 r
.66989 .4848 .67185 .46403 .67775 .45356 .67567 .47024 Mtetra
.101 0 .29 r
.67567 .47024 .67775 .45356 .68342 .4387 .68141 .45542 Mtetra
0 0 .248 r
.68141 .45542 .68342 .4387 .68925 .42769 .68695 .43752 Mtetra
.039 0 .165 r
.68695 .43752 .68925 .42769 .69469 .40968 .69287 .4278 Mtetra
.294 .054 .368 r
.69287 .4278 .69469 .40968 .70093 .40719 .69873 .41738 Mtetra
.153 0 .22 r
.69873 .41738 .70093 .40719 .70752 .41091 .7047 .40912 Mtetra
.492 0 0 r
.7047 .40912 .70752 .41091 .71351 .40354 .71143 .41431 Mtetra
0 0 .178 r
.71143 .41431 .71351 .40354 .71894 .38705 .7172 .40273 Mtetra
.023 0 .263 r
.7172 .40273 .71894 .38705 .72498 .38096 .72266 .38641 Mtetra
.807 .818 .337 r
.72266 .38641 .72498 .38096 .73103 .37523 .72805 .36974 Mtetra
.731 .688 .809 r
.72805 .36974 .73103 .37523 .7372 .37117 .73423 .36575 Mtetra
0 .025 .594 r
.73423 .36575 .7372 .37117 .74459 .38491 .7413 .37486 Mtetra
.297 .332 .729 r
.7413 .37486 .74459 .38491 .75095 .38287 .74823 .38098 Mtetra
.858 .413 .015 r
.74823 .38098 .75095 .38287 .75777 .38701 .75586 .39633 Mtetra
.436 .1 .296 r
.75586 .39633 .75777 .38701 .76403 .38314 .7623 .39428 Mtetra
.736 .678 .13 r
.7623 .39428 .76403 .38314 .76962 .37044 .76662 .36414 Mtetra
.502 .55 .837 r
.76662 .36414 .76962 .37044 .77657 .37534 .77325 .36501 Mtetra
.779 .617 .679 r
.77325 .36501 .77657 .37534 .78233 .36498 .77904 .35495 Mtetra
.081 .189 .678 r
.77904 .35495 .78233 .36498 .78793 .35285 .78646 .365 Mtetra
.4 .103 .341 r
.78646 .365 .78793 .35285 .79508 .35947 .79274 .36076 Mtetra
.981 .897 .557 r
.79274 .36076 .79508 .35947 .80107 .35198 .79802 .34485 Mtetra
.63 .595 .795 r
.79802 .34485 .80107 .35198 .80727 .34702 .80452 .34316 Mtetra
.261 .528 .915 r
.80452 .34316 .80727 .34702 .81371 .34471 .81139 .34553 Mtetra
.345 0 0 r
.81139 .34553 .81371 .34471 .8208 .34917 .81821 .34689 Mtetra
.524 .008 0 r
.81821 .34689 .8208 .34917 .8283 .35753 .82561 .35406 Mtetra
0 .133 .658 r
.82561 .35406 .8283 .35753 .83582 .36538 .83302 .36078 Mtetra
.562 .659 .901 r
.83302 .36078 .83582 .36538 .84299 .36922 .83977 .3603 Mtetra
.583 .532 .763 r
.83977 .3603 .84299 .36922 .84908 .36208 .84654 .35975 Mtetra
.833 .891 .882 r
.84654 .35975 .84908 .36208 .85537 .35679 .85283 .35443 Mtetra
.952 .862 .715 r
.85283 .35443 .85537 .35679 .86084 .34391 .8585 .34313 Mtetra
.312 0 0 r
.8585 .34313 .86084 .34391 .86761 .34324 .86568 .34616 Mtetra
.596 .098 .04 r
.86568 .34616 .86761 .34324 .87466 .34492 .87295 .34959 Mtetra
.306 0 .065 r
.87295 .34959 .87466 .34492 .88152 .34458 .87963 .34746 Mtetra
.787 .858 .411 r
.87963 .34746 .88152 .34458 .88768 .33804 .88515 .33494 Mtetra
.281 .596 .949 r
.88515 .33494 .88768 .33804 .89415 .33407 .89228 .33658 Mtetra
.442 .464 .787 r
.29242 .52283 .29562 .53037 .30092 .53047 .2976 .52473 Mtetra
.815 .682 .717 r
.2976 .52473 .30092 .53047 .30664 .52438 .30352 .51568 Mtetra
.771 .621 .693 r
.30352 .51568 .30664 .52438 .31243 .51721 .30942 .50683 Mtetra
.781 .61 .669 r
.30942 .50683 .31243 .51721 .3188 .50049 .31548 .49522 Mtetra
.397 .521 .865 r
.31548 .49522 .3188 .50049 .32415 .50003 .32071 .4968 Mtetra
0 .279 .755 r
.32071 .4968 .32415 .50003 .3295 .49994 .32585 .50013 Mtetra
.042 0 0 r
.32585 .50013 .3295 .49994 .33456 .50518 .33122 .50013 Mtetra
.655 .652 .835 r
.33122 .50013 .33456 .50518 .34008 .50256 .3367 .49835 Mtetra
.738 .712 .827 r
.3367 .49835 .34008 .50256 .34596 .49355 .3423 .4948 Mtetra
.808 .999 .84 r
.3423 .4948 .34596 .49355 .35118 .49702 .34799 .48955 Mtetra
.565 .536 .782 r
.34799 .48955 .35118 .49702 .35674 .49415 .35341 .48948 Mtetra
.468 .588 .891 r
.35341 .48948 .35674 .49415 .36213 .49513 .35881 .4902 Mtetra
.777 .697 .775 r
.35881 .4902 .36213 .49513 .36788 .48877 .36452 .48474 Mtetra
.803 .733 .786 r
.36452 .48474 .36788 .48877 .37318 .49224 .37026 .47888 Mtetra
.623 .492 .682 r
.37026 .47888 .37318 .49224 .37919 .48029 .37583 .47655 Mtetra
.685 .724 .88 r
.37583 .47655 .37919 .48029 .38472 .47911 .38141 .47436 Mtetra
.757 .699 .797 r
.38141 .47436 .38472 .47911 .39007 .48242 .38709 .46989 Mtetra
.507 .424 .696 r
.38709 .46989 .39007 .48242 .39525 .49118 .39253 .47168 Mtetra
.587 .436 .643 r
.39253 .47168 .39525 .49118 .40107 .48387 .3981 .47042 Mtetra
.524 .427 .687 r
.3981 .47042 .40107 .48387 .40662 .48388 .40359 .47184 Mtetra
.616 .499 .697 r
.40359 .47184 .40662 .48388 .41226 .48207 .40922 .47002 Mtetra
0 .066 .589 r
.40922 .47002 .41226 .48207 .41777 .48441 .41444 .48057 Mtetra
.661 .716 .888 r
.41444 .48057 .41777 .48441 .42327 .48773 .42011 .47874 Mtetra
.574 .513 .749 r
.42011 .47874 .42327 .48773 .42912 .48035 .42575 .47848 Mtetra
.843 .85 .85 r
.42575 .47848 .42912 .48035 .43474 .48092 .43155 .473 Mtetra
.753 .626 .719 r
.43155 .473 .43474 .48092 .44046 .47854 .43738 .46635 Mtetra
0 0 .345 r
.43738 .46635 .44046 .47854 .446 .48414 .44263 .48303 Mtetra
.908 .522 .272 r
.44263 .48303 .446 .48414 .45165 .48608 .44797 .49878 Mtetra
.911 .822 .357 r
.44797 .49878 .45165 .48608 .45765 .47232 .45437 .46881 Mtetra
.903 .752 .684 r
.45437 .46881 .45765 .47232 .46373 .45297 .46037 .45466 Mtetra
.746 .986 .767 r
.46037 .45466 .46373 .45297 .46918 .46763 .46618 .44914 Mtetra
.323 .257 .626 r
.46618 .44914 .46918 .46763 .47494 .46669 .47176 .4581 Mtetra
.353 .389 .76 r
.47176 .4581 .47494 .46669 .48059 .47493 .47747 .46181 Mtetra
.674 .528 .679 r
.47747 .46181 .48059 .47493 .48641 .47307 .48331 .45678 Mtetra
.664 .503 .657 r
.48331 .45678 .48641 .47307 .49229 .46572 .48917 .45123 Mtetra
.709 .542 .66 r
.48917 .45123 .49229 .46572 .49823 .45023 .49504 .44315 Mtetra
.745 .64 .743 r
.49504 .44315 .49823 .45023 .50404 .4501 .50089 .43762 Mtetra
.442 .385 .698 r
.50089 .43762 .50404 .4501 .5099 .44358 .50669 .4412 Mtetra
.832 .363 0 r
.50669 .4412 .5099 .44358 .51573 .4453 .51249 .45108 Mtetra
.663 .275 .302 r
.51249 .45108 .51573 .4453 .52158 .44802 .51836 .4556 Mtetra
.6 .235 .322 r
.51836 .4556 .52158 .44802 .52746 .44433 .52427 .45832 Mtetra
.527 .224 .395 r
.52427 .45832 .52746 .44433 .53335 .44454 .5302 .45828 Mtetra
.691 .376 .439 r
.5302 .45828 .53335 .44454 .53927 .44451 .53618 .46763 Mtetra
.672 .387 .48 r
.53618 .46763 .53927 .44451 .54524 .45042 .54224 .47956 Mtetra
.656 .381 .491 r
.54224 .47956 .54524 .45042 .55129 .46166 .54835 .49184 Mtetra
.621 .352 .488 r
.54835 .49184 .55129 .46166 .5572 .45221 .5545 .49989 Mtetra
.617 .362 .509 r
.5545 .49989 .5572 .45221 .56316 .44816 .56072 .51105 Mtetra
.611 .364 .518 r
.56072 .51105 .56316 .44816 .56928 .45556 .56704 .52406 Mtetra
.577 .337 .516 r
.56704 .52406 .56928 .45556 .57551 .46735 .57331 .52983 Mtetra
.56 .321 .511 r
.57331 .52983 .57551 .46735 .58164 .46928 .57957 .53174 Mtetra
.575 .333 .513 r
.57957 .53174 .58164 .46928 .58804 .4841 .58591 .53669 Mtetra
.572 .327 .506 r
.58591 .53669 .58804 .4841 .59413 .48024 .59226 .54057 Mtetra
.304 .119 .456 r
.59226 .54057 .59413 .48024 .59987 .46092 .59785 .50781 Mtetra
.385 .174 .466 r
.59785 .50781 .59987 .46092 .60556 .44196 .60368 .48937 Mtetra
.285 .097 .441 r
.60368 .48937 .60556 .44196 .61128 .42576 .60923 .46203 Mtetra
.32 .114 .436 r
.60923 .46203 .61128 .42576 .61675 .40219 .61494 .44339 Mtetra
.157 0 .396 r
.61494 .44339 .61675 .40219 .62332 .41699 .62021 .41137 Mtetra
.782 .696 .769 r
.62021 .41137 .62332 .41699 .63051 .44871 .62619 .40535 Mtetra
.004 0 .471 r
.62619 .40535 .63051 .44871 .63743 .46848 .6338 .44844 Mtetra
.765 .516 0 r
.6338 .44844 .63743 .46848 .64435 .48532 .64176 .49615 Mtetra
.726 .386 .403 r
.64176 .49615 .64435 .48532 .65162 .50942 .64856 .50701 Mtetra
.725 .222 0 r
.64856 .50701 .65162 .50942 .65808 .51005 .65535 .51593 Mtetra
.249 0 .089 r
.65535 .51593 .65808 .51005 .66428 .5041 .66169 .51262 Mtetra
0 0 0 r
.66169 .51262 .66428 .5041 .66989 .4848 .66765 .50006 Mtetra
0 0 .04 r
.66765 .50006 .66989 .4848 .67567 .47024 .67299 .47453 Mtetra
.879 .888 .461 r
.67299 .47453 .67567 .47024 .68141 .45542 .67876 .45958 Mtetra
.94 .883 .473 r
.67876 .45958 .68141 .45542 .68695 .43752 .68434 .44163 Mtetra
0 0 0 r
.68434 .44163 .68695 .43752 .69287 .4278 .69038 .4338 Mtetra
.772 .805 .32 r
.69038 .4338 .69287 .4278 .69873 .41738 .69598 .41753 Mtetra
.755 .994 .865 r
.69598 .41753 .69873 .41738 .7047 .40912 .70215 .41268 Mtetra
.233 0 0 r
.70215 .41268 .7047 .40912 .71143 .41431 .7085 .41081 Mtetra
.832 .801 .822 r
.7085 .41081 .71143 .41431 .7172 .40273 .71461 .40473 Mtetra
.986 .887 .549 r
.71461 .40473 .7172 .40273 .72266 .38641 .72003 .38717 Mtetra
.997 .856 .567 r
.72003 .38717 .72266 .38641 .72805 .36974 .72528 .36782 Mtetra
.79 .898 .919 r
.72528 .36782 .72805 .36974 .73423 .36575 .73147 .36362 Mtetra
.862 .421 .018 r
.73147 .36362 .73423 .36575 .7413 .37486 .73898 .37925 Mtetra
.625 .184 .184 r
.73898 .37925 .7413 .37486 .74823 .38098 .74575 .38289 Mtetra
.796 .334 .141 r
.74575 .38289 .74823 .38098 .75586 .39633 .75298 .39234 Mtetra
.886 .786 .745 r
.75298 .39234 .75586 .39633 .7623 .39428 .75888 .38285 Mtetra
.859 .648 .615 r
.75888 .38285 .7623 .39428 .76662 .36414 .7639 .36177 Mtetra
.696 .853 .958 r
.7639 .36177 .76662 .36414 .77325 .36501 .77027 .35907 Mtetra
.369 .487 .848 r
.77027 .35907 .77325 .36501 .77904 .35495 .77707 .36169 Mtetra
.45 .068 .222 r
.77707 .36169 .77904 .35495 .78646 .365 .78363 .36091 Mtetra
.805 .776 .826 r
.78363 .36091 .78646 .365 .79274 .36076 .78982 .35544 Mtetra
.897 .745 .685 r
.78982 .35544 .79274 .36076 .79802 .34485 .79538 .34255 Mtetra
.644 .843 .977 r
.79538 .34255 .79802 .34485 .80452 .34316 .80186 .34044 Mtetra
.45 .724 .984 r
.80186 .34044 .80452 .34316 .81139 .34553 .80853 .34039 Mtetra
0 .219 .742 r
.80853 .34039 .81139 .34553 .81821 .34689 .81585 .34719 Mtetra
.219 0 0 r
.81585 .34719 .81821 .34689 .82561 .35406 .82268 .34818 Mtetra
.457 .543 .856 r
.82268 .34818 .82561 .35406 .83302 .36078 .82959 .34961 Mtetra
.459 .421 .729 r
.82959 .34961 .83302 .36078 .83977 .3603 .83669 .35283 Mtetra
.048 .227 .727 r
.83669 .35283 .83977 .3603 .84654 .35975 .84434 .36104 Mtetra
.381 .803 .614 r
.84434 .36104 .84654 .35975 .85283 .35443 .8508 .35708 Mtetra
.825 .887 .459 r
.8508 .35708 .85283 .35443 .8585 .34313 .85639 .34475 Mtetra
.669 .141 0 r
.85639 .34475 .8585 .34313 .86568 .34616 .86386 .35023 Mtetra
.795 .36 .213 r
.86386 .35023 .86568 .34616 .87295 .34959 .87202 .36161 Mtetra
.123 0 .272 r
.87202 .36161 .87295 .34959 .87963 .34746 .87767 .3498 Mtetra
.861 .892 .467 r
.87767 .3498 .87963 .34746 .88515 .33494 .88315 .33666 Mtetra
.439 0 0 r
.88315 .33666 .88515 .33494 .89228 .33658 .89031 .33833 Mtetra
.546 .026 0 r
.28858 .52431 .29242 .52283 .2976 .52473 .29376 .52624 Mtetra
.965 .82 .651 r
.29376 .52624 .2976 .52473 .30352 .51568 .30036 .50749 Mtetra
.777 .63 .698 r
.30036 .50749 .30352 .51568 .30942 .50683 .30626 .49872 Mtetra
.683 .585 .739 r
.30626 .49872 .30942 .50683 .31548 .49522 .3118 .4953 Mtetra
.02 .594 .71 r
.3118 .4953 .31548 .49522 .32071 .4968 .31715 .49517 Mtetra
.368 0 0 r
.31715 .49517 .32071 .4968 .32585 .50013 .32233 .49787 Mtetra
.655 .81 .957 r
.32233 .49787 .32585 .50013 .33122 .50013 .32781 .49609 Mtetra
.444 .614 .921 r
.32781 .49609 .33122 .50013 .3367 .49835 .33316 .49677 Mtetra
.635 .856 .983 r
.33316 .49677 .3367 .49835 .3423 .4948 .33867 .49499 Mtetra
.041 0 0 r
.33867 .49499 .3423 .4948 .34799 .48955 .34408 .49498 Mtetra
.472 .067 .191 r
.34408 .49498 .34799 .48955 .35341 .48948 .34952 .49499 Mtetra
.202 0 .029 r
.34952 .49499 .35341 .48948 .35881 .4902 .35513 .49203 Mtetra
.968 .907 .701 r
.35513 .49203 .35881 .4902 .36452 .48474 .3612 .47988 Mtetra
.751 .693 .796 r
.3612 .47988 .36452 .48474 .37026 .47888 .36687 .47555 Mtetra
.556 .051 0 r
.36687 .47555 .37026 .47888 .37583 .47655 .37208 .4811 Mtetra
.65 .247 .268 r
.37208 .4811 .37583 .47655 .38141 .47436 .37742 .48471 Mtetra
.404 .08 .298 r
.37742 .48471 .38141 .47436 .38709 .46989 .38306 .48201 Mtetra
0 0 .06 r
.38306 .48201 .38709 .46989 .39253 .47168 .3891 .46994 Mtetra
0 .269 .645 r
.3891 .46994 .39253 .47168 .3981 .47042 .39453 .47262 Mtetra
.49 0 0 r
.39453 .47262 .3981 .47042 .40359 .47184 .40003 .47388 Mtetra
.538 .031 0 r
.40003 .47388 .40359 .47184 .40922 .47002 .40554 .47571 Mtetra
.608 .22 .281 r
.40554 .47571 .40922 .47002 .41444 .48057 .41105 .4784 Mtetra
.65 .823 .966 r
.41105 .4784 .41444 .48057 .42011 .47874 .41673 .47656 Mtetra
.741 .837 .924 r
.41673 .47656 .42011 .47874 .42575 .47848 .42246 .47352 Mtetra
.73 .688 .81 r
.42246 .47352 .42575 .47848 .43155 .473 .42822 .46982 Mtetra
.857 .775 .77 r
.42822 .46982 .43155 .473 .43738 .46635 .43409 .46202 Mtetra
0 0 .433 r
.43409 .46202 .43738 .46635 .44263 .48303 .43957 .46919 Mtetra
.031 .088 .589 r
.43957 .46919 .44263 .48303 .44797 .49878 .44499 .4807 Mtetra
.783 .577 .621 r
.44499 .4807 .44797 .49878 .45437 .46881 .45118 .46034 Mtetra
.762 .624 .706 r
.45118 .46034 .45437 .46881 .46037 .45466 .45706 .45267 Mtetra
.831 .851 .861 r
.45706 .45267 .46037 .45466 .46618 .44914 .46288 .44755 Mtetra
.656 .871 .98 r
.46288 .44755 .46618 .44914 .47176 .4581 .46865 .44543 Mtetra
.516 .43 .698 r
.46865 .44543 .47176 .4581 .47747 .46181 .47437 .44703 Mtetra
.669 .514 .666 r
.47437 .44703 .47747 .46181 .48331 .45678 .48021 .44167 Mtetra
.606 .471 .671 r
.48021 .44167 .48331 .45678 .48917 .45123 .48602 .43978 Mtetra
.688 .55 .693 r
.48602 .43978 .48917 .45123 .49504 .44315 .49186 .4347 Mtetra
.62 .551 .755 r
.49186 .4347 .49504 .44315 .50089 .43762 .49768 .43321 Mtetra
0 .268 .774 r
.49768 .43321 .50089 .43762 .50669 .4412 .50347 .4377 Mtetra
.846 .403 0 r
.50347 .4377 .50669 .4412 .51249 .45108 .50926 .44944 Mtetra
.877 .441 .126 r
.50926 .44944 .51249 .45108 .51836 .4556 .51512 .46151 Mtetra
.696 .315 .321 r
.51512 .46151 .51836 .4556 .52427 .45832 .52104 .46747 Mtetra
.072 0 .129 r
.52104 .46747 .52427 .45832 .5302 .45828 .527 .45994 Mtetra
.908 .555 .36 r
.527 .45994 .5302 .45828 .53618 .46763 .53302 .48384 Mtetra
.747 .44 .463 r
.53302 .48384 .53618 .46763 .54224 .47956 .53913 .50113 Mtetra
.625 .339 .464 r
.53913 .50113 .54224 .47956 .54835 .49184 .54525 .50767 Mtetra
.782 .473 .465 r
.54525 .50767 .54835 .49184 .5545 .49989 .55154 .53029 Mtetra
.709 .428 .497 r
.55154 .53029 .5545 .49989 .56072 .51105 .55793 .55194 Mtetra
.704 .432 .51 r
.55793 .55194 .56072 .51105 .56704 .52406 .56449 .57925 Mtetra
.618 .366 .513 r
.56449 .57925 .56704 .52406 .57331 .52983 .57097 .5924 Mtetra
.394 .188 .478 r
.57097 .5924 .57331 .52983 .57957 .53174 .57697 .56912 Mtetra
.41 .183 .456 r
.57697 .56912 .57957 .53174 .58591 .53669 .58309 .55667 Mtetra
.201 0 .334 r
.58309 .55667 .58591 .53669 .59226 .54057 .58916 .54297 Mtetra
.994 .876 .58 r
.58916 .54297 .59226 .54057 .59785 .50781 .59509 .52385 Mtetra
0 0 .133 r
.59509 .52385 .59785 .50781 .60368 .48937 .60094 .50377 Mtetra
0 0 .106 r
.60094 .50377 .60368 .48937 .60923 .46203 .60677 .48522 Mtetra
.123 0 .331 r
.60677 .48522 .60923 .46203 .61494 .44339 .61255 .46637 Mtetra
.401 .152 .417 r
.61255 .46637 .61494 .44339 .62021 .41137 .61859 .45842 Mtetra
0 0 .267 r
.61859 .45842 .62021 .41137 .62619 .40535 .62309 .40019 Mtetra
.906 .525 .088 r
.62309 .40019 .62619 .40535 .6338 .44844 .63001 .42269 Mtetra
0 0 .13 r
.63001 .42269 .6338 .44844 .64176 .49615 .63807 .47571 Mtetra
0 0 .149 r
.63807 .47571 .64176 .49615 .64856 .50701 .64599 .51836 Mtetra
.722 .384 .405 r
.64599 .51836 .64856 .50701 .65535 .51593 .65288 .52931 Mtetra
.394 .099 .341 r
.65288 .52931 .65535 .51593 .66169 .51262 .65922 .52478 Mtetra
0 0 .042 r
.65922 .52478 .66169 .51262 .66765 .50006 .66499 .50652 Mtetra
.946 .836 .399 r
.66499 .50652 .66765 .50006 .67299 .47453 .67038 .48085 Mtetra
.931 .838 .392 r
.67038 .48085 .67299 .47453 .67876 .45958 .67577 .45698 Mtetra
.967 .775 .592 r
.67577 .45698 .67876 .45958 .68434 .44163 .6811 .43335 Mtetra
.635 .571 .765 r
.6811 .43335 .68434 .44163 .69038 .4338 .68745 .43135 Mtetra
.939 .826 .706 r
.68745 .43135 .69038 .4338 .69598 .41753 .69328 .41912 Mtetra
.836 .978 .682 r
.69328 .41912 .69598 .41753 .70215 .41268 .6993 .411 Mtetra
.906 .896 .807 r
.6993 .411 .70215 .41268 .7085 .41081 .70533 .40329 Mtetra
.767 .652 .734 r
.70533 .40329 .7085 .41081 .71461 .40473 .71141 .39649 Mtetra
.856 .676 .658 r
.71141 .39649 .71461 .40473 .72003 .38717 .717 .38163 Mtetra
.924 .733 .626 r
.717 .38163 .72003 .38717 .72528 .36782 .72228 .36222 Mtetra
.516 .584 .862 r
.72228 .36222 .72528 .36782 .73147 .36362 .72876 .36266 Mtetra
.845 .382 .029 r
.72876 .36266 .73147 .36362 .73898 .37925 .73609 .37545 Mtetra
.58 .127 0 r
.73609 .37545 .73898 .37925 .74575 .38289 .74328 .38515 Mtetra
.507 .831 .53 r
.74328 .38515 .74575 .38289 .75298 .39234 .74944 .37926 Mtetra
.713 .555 .674 r
.74944 .37926 .75298 .39234 .75888 .38285 .75549 .37176 Mtetra
.796 .619 .661 r
.75549 .37176 .75888 .38285 .7639 .36177 .76116 .35942 Mtetra
.675 .848 .966 r
.76116 .35942 .7639 .36177 .77027 .35907 .76757 .35697 Mtetra
.552 .822 .996 r
.76757 .35697 .77027 .35907 .77707 .36169 .77408 .35568 Mtetra
.545 .586 .846 r
.77408 .35568 .77707 .36169 .78363 .36091 .78071 .35575 Mtetra
.873 .747 .72 r
.78071 .35575 .78363 .36091 .78982 .35544 .78651 .34541 Mtetra
.785 .624 .681 r
.78651 .34541 .78982 .35544 .79538 .34255 .79231 .33523 Mtetra
.703 .628 .77 r
.79231 .33523 .79538 .34255 .80186 .34044 .79863 .3313 Mtetra
0 .016 .583 r
.79863 .3313 .80186 .34044 .80853 .34039 .80651 .34488 Mtetra
.648 .205 .184 r
.80651 .34488 .80853 .34039 .81585 .34719 .81364 .34937 Mtetra
.135 0 0 r
.81364 .34937 .81585 .34719 .82268 .34818 .82026 .34782 Mtetra
.644 .085 0 r
.82026 .34782 .82268 .34818 .82959 .34961 .82764 .35406 Mtetra
.604 .155 .159 r
.82764 .35406 .82959 .34961 .83669 .35283 .83478 .3574 Mtetra
.719 .282 .21 r
.83478 .3574 .83669 .35283 .84434 .36104 .84236 .36466 Mtetra
0 0 0 r
.84236 .36466 .84434 .36104 .8508 .35708 .84865 .35877 Mtetra
.671 .912 .586 r
.84865 .35877 .8508 .35708 .85639 .34475 .85481 .35155 Mtetra
.705 .304 .285 r
.85481 .35155 .85639 .34475 .86386 .35023 .86253 .35913 Mtetra
.739 .362 .338 r
.86253 .35913 .86386 .35023 .87202 .36161 .87067 .3701 Mtetra
0 0 0 r
.87067 .3701 .87202 .36161 .87767 .3498 .87549 .35028 Mtetra
.979 .903 .57 r
.87549 .35028 .87767 .3498 .88315 .33666 .88078 .33521 Mtetra
.011 .533 .857 r
.88078 .33521 .88315 .33666 .89031 .33833 .88795 .33693 Mtetra
0 0 0 r
.28388 .53739 .28858 .52431 .29376 .52624 .29049 .51932 Mtetra
.856 .675 .656 r
.29049 .51932 .29376 .52624 .30036 .50749 .29703 .50169 Mtetra
.83 .685 .703 r
.29703 .50169 .30036 .50749 .30626 .49872 .30306 .49108 Mtetra
.53 .512 .781 r
.30306 .49108 .30626 .49872 .3118 .4953 .30835 .49164 Mtetra
.767 .74 .829 r
.30835 .49164 .3118 .4953 .31715 .49517 .31395 .48751 Mtetra
0 0 .398 r
.31395 .48751 .31715 .49517 .32233 .49787 .31869 .49731 Mtetra
.746 .937 .948 r
.31869 .49731 .32233 .49787 .32781 .49609 .32427 .49403 Mtetra
.865 .813 .796 r
.32427 .49403 .32781 .49609 .33316 .49677 .33008 .48697 Mtetra
.13 .213 .683 r
.33008 .48697 .33316 .49677 .33867 .49499 .33511 .49353 Mtetra
0 .473 .791 r
.33511 .49353 .33867 .49499 .34408 .49498 .34045 .49499 Mtetra
.756 .266 .068 r
.34045 .49499 .34408 .49498 .34952 .49499 .3456 .5005 Mtetra
.796 .911 .517 r
.3456 .5005 .34952 .49499 .35513 .49203 .35163 .48988 Mtetra
.727 .831 .929 r
.35163 .48988 .35513 .49203 .3612 .47988 .35724 .4871 Mtetra
.832 .885 .454 r
.35724 .4871 .3612 .47988 .36687 .47555 .36342 .47303 Mtetra
0 .404 .82 r
.36342 .47303 .36687 .47555 .37208 .4811 .36879 .47543 Mtetra
0 .216 .739 r
.36879 .47543 .37208 .4811 .37742 .48471 .37406 .48047 Mtetra
.788 .726 .794 r
.37406 .48047 .37742 .48471 .38306 .48201 .37982 .47514 Mtetra
.77 .65 .73 r
.37982 .47514 .38306 .48201 .3891 .46994 .38564 .46838 Mtetra
.815 .873 .889 r
.38564 .46838 .3891 .46994 .39453 .47262 .39137 .46391 Mtetra
.674 .573 .734 r
.39137 .46391 .39453 .47262 .40003 .47388 .39705 .46061 Mtetra
.393 .341 .681 r
.39705 .46061 .40003 .47388 .40554 .47571 .40244 .46533 Mtetra
.298 .317 .712 r
.40244 .46533 .40554 .47571 .41105 .4784 .40784 .47048 Mtetra
.56 .527 .775 r
.40784 .47048 .41105 .4784 .41673 .47656 .41346 .47048 Mtetra
.871 .695 .662 r
.41346 .47048 .41673 .47656 .42246 .47352 .41962 .45424 Mtetra
.621 .46 .644 r
.41962 .45424 .42246 .47352 .42822 .46982 .42535 .45082 Mtetra
.584 .436 .646 r
.42535 .45082 .42822 .46982 .43409 .46202 .43102 .4497 Mtetra
.502 .424 .701 r
.43102 .4497 .43409 .46202 .43957 .46919 .43663 .4516 Mtetra
.056 .072 .559 r
.43663 .4516 .43957 .46919 .44499 .4807 .44195 .46569 Mtetra
.737 .557 .65 r
.44195 .46569 .44499 .4807 .45118 .46034 .44792 .45473 Mtetra
.815 .695 .733 r
.44792 .45473 .45118 .46034 .45706 .45267 .45382 .4465 Mtetra
.711 .646 .782 r
.45382 .4465 .45706 .45267 .46288 .44755 .45962 .44285 Mtetra
.24 .467 .877 r
.45962 .44285 .46288 .44755 .46865 .44543 .46531 .44545 Mtetra
.45 .879 .906 r
.46531 .44545 .46865 .44543 .47437 .44703 .4711 .44357 Mtetra
.865 .769 .754 r
.4711 .44357 .47437 .44703 .48021 .44167 .477 .43495 Mtetra
.683 .62 .779 r
.477 .43495 .48021 .44167 .48602 .43978 .48282 .43199 Mtetra
.526 .512 .783 r
.48282 .43199 .48602 .43978 .49186 .4347 .48861 .43267 Mtetra
.745 .23 0 r
.48861 .43267 .49186 .4347 .49768 .43321 .49435 .4398 Mtetra
.682 .31 .336 r
.49435 .4398 .49768 .43321 .50347 .4377 .50016 .44535 Mtetra
.12 0 .099 r
.50016 .44535 .50347 .4377 .50926 .44944 .50606 .43971 Mtetra
.35 .366 .736 r
.50606 .43971 .50926 .44944 .51512 .46151 .51193 .44402 Mtetra
.547 .419 .658 r
.51193 .44402 .51512 .46151 .52104 .46747 .51784 .44481 Mtetra
.608 .442 .632 r
.51784 .44481 .52104 .46747 .527 .45994 .52377 .44166 Mtetra
.778 .53 0 r
.52377 .44166 .527 .45994 .53302 .48384 .52978 .47969 Mtetra
.949 .593 .258 r
.52978 .47969 .53302 .48384 .53913 .50113 .5359 .50716 Mtetra
.874 .538 .412 r
.5359 .50716 .53913 .50113 .54525 .50767 .54215 .53351 Mtetra
.697 .411 .486 r
.54215 .53351 .54525 .50767 .55154 .53029 .54844 .55035 Mtetra
.753 .453 .476 r
.54844 .55035 .55154 .53029 .55793 .55194 .55486 .57218 Mtetra
.695 .397 .467 r
.55486 .57218 .55793 .55194 .56449 .57925 .56129 .58561 Mtetra
.784 .417 .361 r
.56129 .58561 .56449 .57925 .57097 .5924 .56778 .59777 Mtetra
.006 0 0 r
.56778 .59777 .57097 .5924 .57697 .56912 .57409 .59273 Mtetra
.327 .089 .392 r
.57409 .59273 .57697 .56912 .58309 .55667 .58029 .58147 Mtetra
.056 0 .306 r
.58029 .58147 .58309 .55667 .58916 .54297 .58629 .55952 Mtetra
.319 .055 .346 r
.58629 .55952 .58916 .54297 .59509 .52385 .5925 .55153 Mtetra
0 0 .286 r
.5925 .55153 .59509 .52385 .60094 .50377 .59827 .5237 Mtetra
.372 .115 .39 r
.59827 .5237 .60094 .50377 .60677 .48522 .60443 .51585 Mtetra
.413 .177 .443 r
.60443 .51585 .60677 .48522 .61255 .46637 .61053 .50592 Mtetra
.453 .221 .47 r
.61053 .50592 .61255 .46637 .61859 .45842 .61662 .49634 Mtetra
.184 .01 .396 r
.61662 .49634 .61859 .45842 .62309 .40019 .62216 .46858 Mtetra
0 0 .323 r
.62216 .46858 .62309 .40019 .63001 .42269 .62606 .39143 Mtetra
0 0 .429 r
.62606 .39143 .63001 .42269 .63807 .47571 .63351 .42883 Mtetra
.101 .045 .5 r
.63351 .42883 .63807 .47571 .64599 .51836 .64124 .46922 Mtetra
.145 .075 .513 r
.64124 .46922 .64599 .51836 .65288 .52931 .6491 .50866 Mtetra
.615 .456 .643 r
.6491 .50866 .65288 .52931 .65922 .52478 .65547 .50525 Mtetra
.783 .571 .613 r
.65547 .50525 .65922 .52478 .66499 .50652 .66112 .48449 Mtetra
.678 .494 .63 r
.66112 .48449 .66499 .50652 .67038 .48085 .66722 .47526 Mtetra
.933 .728 .603 r
.66722 .47526 .67038 .48085 .67577 .45698 .67261 .45083 Mtetra
.944 .716 .563 r
.67261 .45083 .67577 .45698 .6811 .43335 .67749 .41706 Mtetra
.532 .42 .671 r
.67749 .41706 .6811 .43335 .68745 .43135 .68399 .41851 Mtetra
.841 .63 .617 r
.68399 .41851 .68745 .43135 .69328 .41912 .68935 .39721 Mtetra
.677 .492 .628 r
.68935 .39721 .69328 .41912 .6993 .411 .6953 .38811 Mtetra
.625 .454 .631 r
.6953 .38811 .6993 .411 .70533 .40329 .70148 .38341 Mtetra
.672 .495 .637 r
.70148 .38341 .70533 .40329 .71141 .39649 .70749 .37565 Mtetra
.706 .514 .627 r
.70749 .37565 .71141 .39649 .717 .38163 .71326 .36415 Mtetra
.622 .471 .657 r
.71326 .36415 .717 .38163 .72228 .36222 .71952 .36084 Mtetra
.767 .935 .939 r
.71952 .36084 .72228 .36222 .72876 .36266 .72574 .35691 Mtetra
.561 .603 .852 r
.72574 .35691 .72876 .36266 .73609 .37545 .73221 .35665 Mtetra
.599 .45 .651 r
.73221 .35665 .73609 .37545 .74328 .38515 .73858 .35457 Mtetra
.48 .337 .609 r
.73858 .35457 .74328 .38515 .74944 .37926 .74558 .36134 Mtetra
.626 .472 .654 r
.74558 .36134 .74944 .37926 .75549 .37176 .75188 .35766 Mtetra
.696 .538 .669 r
.75188 .35766 .75549 .37176 .76116 .35942 .75795 .35073 Mtetra
.65 .572 .754 r
.75795 .35073 .76116 .35942 .76757 .35697 .76435 .34813 Mtetra
.335 .381 .761 r
.76435 .34813 .76757 .35697 .77408 .35568 .77132 .35283 Mtetra
.724 .829 .93 r
.77132 .35283 .77408 .35568 .78071 .35575 .77772 .34972 Mtetra
.818 .709 .745 r
.77772 .34972 .78071 .35575 .78651 .34541 .78373 .34181 Mtetra
.582 .726 .942 r
.78373 .34181 .78651 .34541 .79231 .33523 .79031 .34081 Mtetra
.117 0 .046 r
.79031 .34081 .79231 .33523 .79863 .3313 .79657 .33579 Mtetra
.811 .395 .259 r
.79657 .33579 .79863 .3313 .80651 .34488 .80439 .34848 Mtetra
.517 .041 .063 r
.80439 .34848 .80651 .34488 .81364 .34937 .81129 .35015 Mtetra
.312 0 0 r
.81129 .35015 .81364 .34937 .82026 .34782 .81818 .35133 Mtetra
.638 .165 .113 r
.81818 .35133 .82026 .34782 .82764 .35406 .82539 .3556 Mtetra
0 0 0 r
.82539 .3556 .82764 .35406 .83478 .3574 .83203 .35347 Mtetra
.734 .772 .884 r
.83203 .35347 .83478 .3574 .84236 .36466 .83855 .34997 Mtetra
.488 .405 .689 r
.83855 .34997 .84236 .36466 .84865 .35877 .84574 .35311 Mtetra
.647 .657 .846 r
.84574 .35311 .84865 .35877 .85481 .35155 .85245 .35114 Mtetra
.193 0 0 r
.85245 .35114 .85481 .35155 .86253 .35913 .85956 .35284 Mtetra
.753 .384 0 r
.85956 .35284 .86253 .35913 .87067 .3701 .86916 .37729 Mtetra
.838 .734 .21 r
.86916 .37729 .87067 .3701 .87549 .35028 .87294 .34765 Mtetra
.934 .867 .749 r
.87294 .34765 .87549 .35028 .88078 .33521 .87884 .33776 Mtetra
.116 0 0 r
.87884 .33776 .88078 .33521 .88795 .33693 .8856 .33558 Mtetra
.911 .739 .656 r
.28028 .53464 .28388 .53739 .29049 .51932 .28701 .51531 Mtetra
.889 .721 .667 r
.28701 .51531 .29049 .51932 .29703 .50169 .29352 .49842 Mtetra
.873 .748 .722 r
.29352 .49842 .29703 .50169 .30306 .49108 .29957 .48779 Mtetra
.699 .75 .891 r
.29957 .48779 .30306 .49108 .30835 .49164 .30505 .48543 Mtetra
.553 .566 .821 r
.30505 .48543 .30835 .49164 .31395 .48751 .31039 .48542 Mtetra
.808 .32 0 r
.31039 .48542 .31395 .48751 .31869 .49731 .3153 .49252 Mtetra
.802 .706 .758 r
.3153 .49252 .31869 .49731 .32427 .49403 .3211 .4858 Mtetra
.596 .538 .759 r
.3211 .4858 .32427 .49403 .33008 .48697 .32654 .485 Mtetra
.69 .151 0 r
.32654 .485 .33008 .48697 .33511 .49353 .33164 .49022 Mtetra
.727 .232 0 r
.33164 .49022 .33511 .49353 .34045 .49499 .33668 .49714 Mtetra
.783 .374 .276 r
.33668 .49714 .34045 .49499 .3456 .5005 .34173 .50456 Mtetra
.91 .962 .639 r
.34173 .50456 .3456 .5005 .35163 .48988 .34779 .49384 Mtetra
.919 .961 .643 r
.34779 .49384 .35163 .48988 .35724 .4871 .35385 .48292 Mtetra
.834 .731 .752 r
.35385 .48292 .35724 .4871 .36342 .47303 .35973 .47501 Mtetra
.47 .867 .686 r
.35973 .47501 .36342 .47303 .36879 .47543 .3654 .47136 Mtetra
.758 .727 .824 r
.3654 .47136 .36879 .47543 .37406 .48047 .3711 .46728 Mtetra
.645 .508 .681 r
.3711 .46728 .37406 .48047 .37982 .47514 .37677 .46385 Mtetra
.523 .448 .713 r
.37677 .46385 .37982 .47514 .38564 .46838 .38225 .46499 Mtetra
.74 .759 .868 r
.38225 .46499 .38564 .46838 .39137 .46391 .38793 .46171 Mtetra
.816 .832 .862 r
.38793 .46171 .39137 .46391 .39705 .46061 .39368 .45693 Mtetra
.527 .677 .933 r
.39368 .45693 .39705 .46061 .40244 .46533 .39926 .45673 Mtetra
.11 .23 .709 r
.39926 .45673 .40244 .46533 .40784 .47048 .40462 .46291 Mtetra
.694 .605 .752 r
.40462 .46291 .40784 .47048 .41346 .47048 .41036 .45927 Mtetra
.752 .589 .675 r
.41036 .45927 .41346 .47048 .41962 .45424 .4163 .44999 Mtetra
.911 .511 .125 r
.4163 .44999 .41962 .45424 .42535 .45082 .42146 .46488 Mtetra
0 0 .157 r
.42146 .46488 .42535 .45082 .43102 .4497 .42751 .45231 Mtetra
.249 0 0 r
.42751 .45231 .43102 .4497 .43663 .4516 .43321 .45149 Mtetra
.794 .317 .092 r
.43321 .45149 .43663 .4516 .44195 .46569 .43871 .45857 Mtetra
.836 .673 .681 r
.43871 .45857 .44195 .46569 .44792 .45473 .44473 .44603 Mtetra
.764 .622 .702 r
.44473 .44603 .44792 .45473 .45382 .4465 .45063 .43809 Mtetra
.634 .559 .752 r
.45063 .43809 .45382 .4465 .45962 .44285 .45639 .4362 Mtetra
.618 .59 .8 r
.45639 .4362 .45962 .44285 .46531 .44545 .46215 .43495 Mtetra
.623 .521 .718 r
.46215 .43495 .46531 .44545 .4711 .44357 .46794 .43306 Mtetra
.504 .449 .728 r
.46794 .43306 .4711 .44357 .477 .43495 .47368 .4346 Mtetra
.125 .67 .822 r
.47368 .4346 .477 .43495 .48282 .43199 .47948 .43442 Mtetra
.774 .348 .239 r
.47948 .43442 .48282 .43199 .48861 .43267 .4852 .44191 Mtetra
.328 0 .241 r
.4852 .44191 .48861 .43267 .49435 .4398 .49108 .43814 Mtetra
.795 .3 0 r
.49108 .43814 .49435 .4398 .50016 .44535 .49686 .44618 Mtetra
.461 0 0 r
.49686 .44618 .50016 .44535 .50606 .43971 .50274 .44802 Mtetra
.411 .058 .253 r
.50274 .44802 .50606 .43971 .51193 .44402 .50866 .44611 Mtetra
.886 .983 .706 r
.50866 .44611 .51193 .44402 .51784 .44481 .51462 .43757 Mtetra
.564 .55 .797 r
.51462 .43757 .51784 .44481 .52377 .44166 .52055 .43742 Mtetra
.963 .642 .356 r
.52055 .43742 .52377 .44166 .52978 .47969 .52652 .48464 Mtetra
.91 .588 .422 r
.52652 .48464 .52978 .47969 .5359 .50716 .53267 .52418 Mtetra
.811 .505 .473 r
.53267 .52418 .5359 .50716 .54215 .53351 .53895 .55495 Mtetra
.768 .47 .481 r
.53895 .55495 .54215 .53351 .54844 .55035 .54534 .58123 Mtetra
.657 .38 .49 r
.54534 .58123 .54844 .55035 .55486 .57218 .55174 .59439 Mtetra
.59 .306 .453 r
.55174 .59439 .55486 .57218 .56129 .58561 .55813 .59828 Mtetra
.697 .37 .419 r
.55813 .59828 .56129 .58561 .56778 .59777 .56461 .60786 Mtetra
.321 0 .249 r
.56461 .60786 .56778 .59777 .57409 .59273 .57096 .60341 Mtetra
.065 0 .158 r
.57096 .60341 .57409 .59273 .58029 .58147 .57725 .59424 Mtetra
0 0 .091 r
.57725 .59424 .58029 .58147 .58629 .55952 .58342 .579 Mtetra
.444 .171 .404 r
.58342 .579 .58629 .55952 .5925 .55153 .58975 .57445 Mtetra
0 0 .266 r
.58975 .57445 .5925 .55153 .59827 .5237 .59571 .55176 Mtetra
.149 0 .354 r
.59571 .55176 .59827 .5237 .60443 .51585 .60164 .53025 Mtetra
.276 .006 .31 r
.60164 .53025 .60443 .51585 .61053 .50592 .60784 .52224 Mtetra
.251 0 .323 r
.60784 .52224 .61053 .50592 .61662 .49634 .61397 .51236 Mtetra
0 0 0 r
.61397 .51236 .61662 .49634 .62216 .46858 .61948 .48094 Mtetra
.974 .783 .359 r
.61948 .48094 .62216 .46858 .62606 .39143 .62426 .42892 Mtetra
0 0 .263 r
.62426 .42892 .62606 .39143 .63351 .42883 .62907 .38353 Mtetra
.005 0 .468 r
.62907 .38353 .63351 .42883 .64124 .46922 .63684 .42827 Mtetra
0 0 .429 r
.63684 .42827 .64124 .46922 .6491 .50866 .64489 .47546 Mtetra
.273 .186 .571 r
.64489 .47546 .6491 .50866 .65547 .50525 .65211 .49562 Mtetra
.857 .663 .639 r
.65211 .49562 .65547 .50525 .66112 .48449 .65788 .47744 Mtetra
.91 .706 .614 r
.65788 .47744 .66112 .48449 .66722 .47526 .66341 .45452 Mtetra
.744 .541 .619 r
.66341 .45452 .66722 .47526 .67261 .45083 .66916 .43839 Mtetra
.891 .658 .579 r
.66916 .43839 .67261 .45083 .67749 .41706 .67407 .4048 Mtetra
.522 .445 .711 r
.67407 .4048 .67749 .41706 .68399 .41851 .68056 .4062 Mtetra
.724 .568 .678 r
.68056 .4062 .68399 .41851 .68935 .39721 .68661 .39842 Mtetra
.974 .925 .633 r
.68661 .39842 .68935 .39721 .6953 .38811 .69237 .38518 Mtetra
.881 .83 .792 r
.69237 .38518 .6953 .38811 .70148 .38341 .6984 .37743 Mtetra
.904 .724 .648 r
.6984 .37743 .70148 .38341 .70749 .37565 .70391 .3607 Mtetra
.678 .521 .665 r
.70391 .3607 .70749 .37565 .71326 .36415 .71 .35459 Mtetra
.026 .161 .668 r
.71 .35459 .71326 .36415 .71952 .36084 .71704 .36436 Mtetra
.519 .044 .067 r
.71704 .36436 .71952 .36084 .72574 .35691 .72364 .36597 Mtetra
.503 .152 .304 r
.72364 .36597 .72574 .35691 .73221 .35665 .73016 .36593 Mtetra
0 0 .107 r
.73016 .36593 .73221 .35665 .73858 .35457 .73594 .3545 Mtetra
.407 0 0 r
.73594 .3545 .73858 .35457 .74558 .36134 .74267 .35714 Mtetra
.174 .457 .883 r
.74267 .35714 .74558 .36134 .75188 .35766 .74947 .36034 Mtetra
.877 .919 .523 r
.74947 .36034 .75188 .35766 .75795 .35073 .75518 .34807 Mtetra
.932 .84 .731 r
.75518 .34807 .75795 .35073 .76435 .34813 .76099 .3374 Mtetra
.491 .446 .734 r
.76099 .3374 .76435 .34813 .77132 .35283 .76775 .33949 Mtetra
.637 .508 .688 r
.76775 .33949 .77132 .35283 .77772 .34972 .77412 .33621 Mtetra
.649 .513 .685 r
.77412 .33621 .77772 .34972 .78373 .34181 .78046 .33232 Mtetra
.541 .496 .755 r
.78046 .33232 .78373 .34181 .79031 .34081 .78717 .3329 Mtetra
.571 .546 .787 r
.78717 .3329 .79031 .34081 .79657 .33579 .79383 .33258 Mtetra
.142 .501 .908 r
.79383 .33258 .79657 .33579 .80439 .34848 .80077 .33521 Mtetra
.435 .382 .7 r
.80077 .33521 .80439 .34848 .81129 .35015 .80792 .33968 Mtetra
.51 .463 .741 r
.80792 .33968 .81129 .35015 .81818 .35133 .81484 .34124 Mtetra
.333 .359 .738 r
.81484 .34124 .81818 .35133 .82539 .3556 .82216 .34683 Mtetra
.687 .594 .746 r
.82216 .34683 .82539 .3556 .83203 .35347 .82862 .34285 Mtetra
.578 .503 .734 r
.82862 .34285 .83203 .35347 .83855 .34997 .83543 .34235 Mtetra
.75 .648 .748 r
.83543 .34235 .83855 .34997 .84574 .35311 .84172 .33641 Mtetra
.485 .389 .672 r
.84172 .33641 .84574 .35311 .85245 .35114 .84899 .34008 Mtetra
.371 .369 .728 r
.84899 .34008 .85245 .35114 .85956 .35284 .85648 .34544 Mtetra
.105 .271 .75 r
.85648 .34544 .85956 .35284 .86916 .37729 .86424 .35284 Mtetra
.734 .522 .605 r
.86424 .35284 .86916 .37729 .87294 .34765 .86935 .33545 Mtetra
.698 .556 .69 r
.86935 .33545 .87294 .34765 .87884 .33776 .87566 .32936 Mtetra
.396 .434 .783 r
.87566 .32936 .87884 .33776 .8856 .33558 .88307 .33293 Mtetra
.96 .82 .661 r
.27637 .53584 .28028 .53464 .28701 .51531 .28303 .51799 Mtetra
.976 .836 .639 r
.28303 .51799 .28701 .51531 .29352 .49842 .28978 .49819 Mtetra
.931 .847 .739 r
.28978 .49819 .29352 .49842 .29957 .48779 .29586 .48747 Mtetra
.878 .915 .849 r
.29586 .48747 .29957 .48779 .30505 .48543 .3016 .48144 Mtetra
.132 .447 .881 r
.3016 .48144 .30505 .48543 .31039 .48542 .30678 .48392 Mtetra
.835 .861 .864 r
.30678 .48392 .31039 .48542 .3153 .49252 .31246 .47889 Mtetra
.332 .294 .665 r
.31246 .47889 .3153 .49252 .3211 .4858 .31747 .4847 Mtetra
.816 .896 .899 r
.31747 .4847 .3211 .4858 .32654 .485 .32314 .48033 Mtetra
.777 .706 .784 r
.32314 .48033 .32654 .485 .33164 .49022 .32886 .47507 Mtetra
.312 .266 .645 r
.32886 .47507 .33164 .49022 .33668 .49714 .33388 .482 Mtetra
.512 .405 .669 r
.33388 .482 .33668 .49714 .34173 .50456 .33922 .48384 Mtetra
.592 .435 .637 r
.33922 .48384 .34173 .50456 .34779 .49384 .34478 .48202 Mtetra
.616 .501 .7 r
.34478 .48202 .34779 .49384 .35385 .48292 .35036 .4802 Mtetra
.823 .796 .826 r
.35036 .4802 .35385 .48292 .35973 .47501 .35613 .47472 Mtetra
.518 .899 .956 r
.35613 .47472 .35973 .47501 .3654 .47136 .36173 .47289 Mtetra
.968 .895 .698 r
.36173 .47289 .3654 .47136 .3711 .46728 .36785 .46027 Mtetra
.599 .568 .791 r
.36785 .46027 .3711 .46728 .37677 .46385 .3734 .45942 Mtetra
.732 .708 .828 r
.3734 .45942 .37677 .46385 .38225 .46499 .37909 .45594 Mtetra
.435 .429 .753 r
.37909 .45594 .38225 .46499 .38793 .46171 .38453 .4584 Mtetra
.784 .769 .84 r
.38453 .4584 .38793 .46171 .39368 .45693 .39028 .45395 Mtetra
.795 .788 .846 r
.39028 .45395 .39368 .45693 .39926 .45673 .39603 .44936 Mtetra
.335 .41 .79 r
.39603 .44936 .39926 .45673 .40462 .46291 .4015 .45252 Mtetra
.661 .544 .711 r
.4015 .45252 .40462 .46291 .41036 .45927 .40723 .44914 Mtetra
.459 .425 .733 r
.40723 .44914 .41036 .45927 .4163 .44999 .41277 .45149 Mtetra
.841 .443 .292 r
.41277 .45149 .4163 .44999 .42146 .46488 .41806 .46238 Mtetra
.926 .766 .664 r
.41806 .46238 .42146 .46488 .42751 .45231 .42426 .4456 Mtetra
.194 .346 .79 r
.42426 .4456 .42751 .45231 .43321 .45149 .42981 .44978 Mtetra
.363 .749 .988 r
.42981 .44978 .43321 .45149 .43871 .45857 .43551 .44968 Mtetra
.816 .644 .669 r
.43551 .44968 .43871 .45857 .44473 .44603 .44156 .43663 Mtetra
.628 .539 .735 r
.44156 .43663 .44473 .44603 .45063 .43809 .44732 .43474 Mtetra
.164 .511 .913 r
.44732 .43474 .45063 .43809 .45639 .4362 .453 .43681 Mtetra
.632 .094 0 r
.453 .43681 .45639 .4362 .46215 .43495 .45867 .44043 Mtetra
.127 0 0 r
.45867 .44043 .46215 .43495 .46794 .43306 .46452 .43668 Mtetra
.193 0 0 r
.46452 .43668 .46794 .43306 .47368 .4346 .47034 .43477 Mtetra
.616 .06 0 r
.47034 .43477 .47368 .4346 .47948 .43442 .47609 .43843 Mtetra
.814 .438 .344 r
.47609 .43843 .47948 .43442 .4852 .44191 .48176 .45023 Mtetra
.294 0 .198 r
.48176 .45023 .4852 .44191 .49108 .43814 .48767 .44644 Mtetra
.153 0 .132 r
.48767 .44644 .49108 .43814 .49686 .44618 .49361 .44078 Mtetra
.159 .383 .832 r
.49361 .44078 .49686 .44618 .50274 .44802 .49947 .44449 Mtetra
.098 .457 .886 r
.49947 .44449 .50274 .44802 .50866 .44611 .50537 .44713 Mtetra
.97 .913 .694 r
.50537 .44713 .50866 .44611 .51462 .43757 .51137 .43499 Mtetra
.51 0 0 r
.51137 .43499 .51462 .43757 .52055 .43742 .5173 .44021 Mtetra
.929 .61 .416 r
.5173 .44021 .52055 .43742 .52652 .48464 .52324 .48577 Mtetra
.925 .584 .372 r
.52324 .48577 .52652 .48464 .53267 .52418 .52936 .51671 Mtetra
.936 .588 .166 r
.52936 .51671 .53267 .52418 .53895 .55495 .5356 .5453 Mtetra
.935 .605 .162 r
.5356 .5453 .53895 .55495 .54534 .58123 .542 .57945 Mtetra
.944 .595 .321 r
.542 .57945 .54534 .58123 .55174 .59439 .54853 .61125 Mtetra
.464 .175 .389 r
.54853 .61125 .55174 .59439 .55813 .59828 .55489 .60835 Mtetra
.06 0 .137 r
.55489 .60835 .55813 .59828 .56461 .60786 .56121 .59976 Mtetra
.095 .253 .736 r
.56121 .59976 .56461 .60786 .57096 .60341 .5677 .60636 Mtetra
.057 0 0 r
.5677 .60636 .57096 .60341 .57725 .59424 .57411 .60394 Mtetra
0 0 0 r
.57411 .60394 .57725 .59424 .58342 .579 .58035 .59038 Mtetra
.109 0 .192 r
.58035 .59038 .58342 .579 .58975 .57445 .58665 .58127 Mtetra
0 0 0 r
.58665 .58127 .58975 .57445 .59571 .55176 .59285 .56808 Mtetra
0 0 .024 r
.59285 .56808 .59571 .55176 .60164 .53025 .59876 .543 Mtetra
.473 .159 .352 r
.59876 .543 .60164 .53025 .60784 .52224 .60516 .54136 Mtetra
.239 .003 .34 r
.60516 .54136 .60784 .52224 .61397 .51236 .61131 .52941 Mtetra
0 0 0 r
.61131 .52941 .61397 .51236 .61948 .48094 .61691 .49888 Mtetra
.61691 .49888 .61948 .48094 .62426 .42892 .62231 .46442 Mtetra
0 0 .256 r
.62231 .46442 .62426 .42892 .62907 .38353 .62733 .42158 Mtetra
.074 0 .361 r
.62733 .42158 .62907 .38353 .63684 .42827 .63251 .38772 Mtetra
0 0 .258 r
.63251 .38772 .63684 .42827 .64489 .47546 .6411 .45339 Mtetra
0 0 .436 r
.6411 .45339 .64489 .47546 .65211 .49562 .64859 .48187 Mtetra
.821 .616 .625 r
.64859 .48187 .65211 .49562 .65788 .47744 .65432 .46234 Mtetra
.554 .443 .682 r
.65432 .46234 .65788 .47744 .66341 .45452 .66081 .46276 Mtetra
.849 .796 .302 r
.66081 .46276 .66341 .45452 .66916 .43839 .66628 .43894 Mtetra
.949 .955 .718 r
.66628 .43894 .66916 .43839 .67407 .4048 .6723 .42877 Mtetra
.213 .008 .37 r
.6723 .42877 .67407 .4048 .68056 .4062 .67799 .41192 Mtetra
0 0 0 r
.67799 .41192 .68056 .4062 .68661 .39842 .68408 .4043 Mtetra
.93 .839 .392 r
.68408 .4043 .68661 .39842 .69237 .38518 .68937 .38118 Mtetra
.662 .731 .901 r
.68937 .38118 .69237 .38518 .6984 .37743 .69572 .37912 Mtetra
.967 .926 .603 r
.69572 .37912 .6984 .37743 .70391 .3607 .70144 .36548 Mtetra
0 0 0 r
.70144 .36548 .70391 .3607 .71 .35459 .70761 .3603 Mtetra
.674 .766 .282 r
.70761 .3603 .71 .35459 .71704 .36436 .71326 .34636 Mtetra
.557 .426 .658 r
.71326 .34636 .71704 .36436 .72364 .36597 .71975 .34666 Mtetra
.235 .203 .617 r
.71975 .34666 .72364 .36597 .73016 .36593 .72711 .3602 Mtetra
.654 .651 .835 r
.72711 .3602 .73016 .36593 .73594 .3545 .73353 .35811 Mtetra
.591 .803 .395 r
.73353 .35811 .73594 .3545 .74267 .35714 .73949 .34916 Mtetra
0 .141 .673 r
.73949 .34916 .74267 .35714 .74947 .36034 .74672 .35854 Mtetra
.773 .912 .934 r
.74672 .35854 .74947 .36034 .75518 .34807 .75305 .35453 Mtetra
0 0 0 r
.75305 .35453 .75518 .34807 .76099 .3374 .75869 .34112 Mtetra
.694 .833 .396 r
.75869 .34112 .76099 .3374 .76775 .33949 .76449 .33025 Mtetra
.676 .577 .737 r
.76449 .33025 .76775 .33949 .77412 .33621 .77083 .32654 Mtetra
.454 .44 .753 r
.77083 .32654 .77412 .33621 .78046 .33232 .77769 .32923 Mtetra
.737 .819 .915 r
.77769 .32923 .78046 .33232 .78717 .3329 .78409 .32586 Mtetra
.315 .418 .808 r
.78409 .32586 .78717 .3329 .79383 .33258 .79112 .32979 Mtetra
.875 .857 .821 r
.79112 .32979 .79383 .33258 .80077 .33521 .79724 .32282 Mtetra
.478 .419 .712 r
.79724 .32282 .80077 .33521 .80792 .33968 .80422 .32566 Mtetra
.583 .47 .69 r
.80422 .32566 .80792 .33968 .81484 .34124 .81091 .32479 Mtetra
.481 .387 .672 r
.81091 .32479 .81484 .34124 .82216 .34683 .81804 .3285 Mtetra
.599 .454 .655 r
.81804 .3285 .82216 .34683 .82862 .34285 .82466 .32634 Mtetra
.149 .167 .623 r
.82466 .32634 .82862 .34285 .83543 .34235 .83296 .34129 Mtetra
.951 .932 .741 r
.83296 .34129 .83543 .34235 .84172 .33641 .83888 .33146 Mtetra
.607 .669 .883 r
.83888 .33146 .84172 .33641 .84899 .34008 .84565 .33024 Mtetra
.435 .429 .754 r
.84565 .33024 .84899 .34008 .85648 .34544 .85292 .33353 Mtetra
.518 .451 .721 r
.85292 .33353 .85648 .34544 .86424 .35284 .86004 .33506 Mtetra
.682 .51 .647 r
.86004 .33506 .86424 .35284 .86935 .33545 .86619 .32733 Mtetra
.893 .698 .632 r
.86619 .32733 .86935 .33545 .87566 .32936 .87125 .30977 Mtetra
.597 .448 .649 r
.87125 .30977 .87566 .32936 .88307 .33293 .87798 .30758 Mtetra
.985 .836 .612 r
.27221 .54009 .27637 .53584 .28303 .51799 .27932 .51657 Mtetra
.933 .744 .624 r
.27932 .51657 .28303 .51799 .28978 .49819 .28659 .49001 Mtetra
.7 .594 .733 r
.28659 .49001 .28978 .49819 .29586 .48747 .29221 .48586 Mtetra
.335 .739 .982 r
.29221 .48586 .29586 .48747 .3016 .48144 .29756 .48585 Mtetra
0 0 0 r
.29756 .48585 .3016 .48144 .30678 .48392 .30315 .4823 Mtetra
.527 0 0 r
.30315 .4823 .30678 .48392 .31246 .47889 .30829 .48582 Mtetra
.637 .275 .34 r
.30829 .48582 .31246 .47889 .31747 .4847 .31345 .48946 Mtetra
.975 .922 .62 r
.31345 .48946 .31747 .4847 .32314 .48033 .31981 .47426 Mtetra
.727 .65 .772 r
.31981 .47426 .32314 .48033 .32886 .47507 .32547 .47013 Mtetra
0 .09 .64 r
.32547 .47013 .32886 .47507 .33388 .482 .33057 .47557 Mtetra
.552 .561 .817 r
.33057 .47557 .33388 .482 .33922 .48384 .33602 .47558 Mtetra
.633 .559 .753 r
.33602 .47558 .33922 .48384 .34478 .48202 .34158 .47376 Mtetra
.822 .651 .671 r
.34158 .47376 .34478 .48202 .35036 .4802 .34778 .46034 Mtetra
.272 .208 .6 r
.34778 .46034 .35036 .4802 .35613 .47472 .35272 .47048 Mtetra
.66 .695 .872 r
.35272 .47048 .35613 .47472 .36173 .47289 .35832 .46865 Mtetra
.868 .73 .708 r
.35832 .46865 .36173 .47289 .36785 .46027 .36441 .45721 Mtetra
.643 .758 .932 r
.36441 .45721 .36785 .46027 .3734 .45942 .37 .45563 Mtetra
.142 .468 .892 r
.37 .45563 .3734 .45942 .37909 .45594 .37543 .45802 Mtetra
0 0 0 r
.37543 .45802 .37909 .45594 .38453 .4584 .38107 .45616 Mtetra
0 .476 .857 r
.38107 .45616 .38453 .4584 .39028 .45395 .38656 .45806 Mtetra
.314 0 .002 r
.38656 .45806 .39028 .45395 .39603 .44936 .3922 .45688 Mtetra
.443 .075 .244 r
.3922 .45688 .39603 .44936 .4015 .45252 .39785 .45592 Mtetra
.163 0 0 r
.39785 .45592 .4015 .45252 .40723 .44914 .40354 .45405 Mtetra
0 0 0 r
.40354 .45405 .40723 .44914 .41277 .45149 .40937 .4489 Mtetra
.749 .813 .903 r
.40937 .4489 .41277 .45149 .41806 .46238 .41513 .44563 Mtetra
.678 .51 .651 r
.41513 .44563 .41806 .46238 .42426 .4456 .42101 .43881 Mtetra
.498 .524 .814 r
.42101 .43881 .42426 .4456 .42981 .44978 .42665 .4397 Mtetra
.57 .495 .732 r
.42665 .4397 .42981 .44978 .43551 .44968 .43235 .43948 Mtetra
.715 .578 .7 r
.43235 .43948 .43551 .44968 .44156 .43663 .43822 .43352 Mtetra
.872 .433 .052 r
.43822 .43352 .44156 .43663 .44732 .43474 .44365 .44508 Mtetra
.592 .258 .371 r
.44365 .44508 .44732 .43474 .453 .43681 .44934 .44777 Mtetra
.211 0 .221 r
.44934 .44777 .453 .43681 .45867 .44043 .45526 .44128 Mtetra
.278 .775 .738 r
.45526 .44128 .45867 .44043 .46452 .43668 .46109 .43938 Mtetra
.702 .255 .187 r
.46109 .43938 .46452 .43668 .47034 .43477 .4668 .44436 Mtetra
.694 .355 .397 r
.4668 .44436 .47034 .43477 .47609 .43843 .47252 .45186 Mtetra
.66 .344 .427 r
.47252 .45186 .47609 .43843 .48176 .45023 .47828 .45879 Mtetra
0 0 0 r
.47828 .45879 .48176 .45023 .48767 .44644 .48432 .44747 Mtetra
.856 .997 .809 r
.48432 .44747 .48767 .44644 .49361 .44078 .49029 .44098 Mtetra
.407 .859 .87 r
.49029 .44098 .49361 .44078 .49947 .44449 .49621 .43906 Mtetra
.482 .57 .868 r
.49621 .43906 .49947 .44449 .50537 .44713 .50212 .43982 Mtetra
.792 .659 .716 r
.50212 .43982 .50537 .44713 .51137 .43499 .50811 .43142 Mtetra
.89 .472 .077 r
.50811 .43142 .51137 .43499 .5173 .44021 .51401 .4461 Mtetra
.904 .585 .431 r
.51401 .4461 .5173 .44021 .52324 .48577 .51994 .48613 Mtetra
.934 .597 .37 r
.51994 .48613 .52324 .48577 .52936 .51671 .52604 .52011 Mtetra
.852 .476 .337 r
.52604 .52011 .52936 .51671 .5356 .5453 .53225 .53576 Mtetra
.966 .646 .27 r
.53225 .53576 .5356 .5453 .542 .57945 .53866 .58308 Mtetra
.894 .546 .378 r
.53866 .58308 .542 .57945 .54853 .61125 .54514 .60915 Mtetra
.932 .822 .714 r
.54514 .60915 .54853 .61125 .55489 .60835 .55145 .59653 Mtetra
.856 .647 .619 r
.55145 .59653 .55489 .60835 .56121 .59976 .55761 .57251 Mtetra
.272 .195 .584 r
.55761 .57251 .56121 .59976 .5677 .60636 .56417 .5882 Mtetra
.461 .363 .658 r
.56417 .5882 .5677 .60636 .57411 .60394 .57066 .59267 Mtetra
.739 .59 .69 r
.57066 .59267 .57411 .60394 .58035 .59038 .57699 .58454 Mtetra
.81 .708 .752 r
.57699 .58454 .58035 .59038 .58665 .58127 .58332 .57676 Mtetra
.913 .75 .667 r
.58332 .57676 .58665 .58127 .59285 .56808 .58948 .5605 Mtetra
.844 .682 .681 r
.58948 .5605 .59285 .56808 .59876 .543 .59567 .54737 Mtetra
0 0 0 r
.59567 .54737 .59876 .543 .60516 .54136 .60202 .54291 Mtetra
.994 .861 .588 r
.60202 .54291 .60516 .54136 .61131 .52941 .608 .52291 Mtetra
.898 .712 .642 r
.608 .52291 .61131 .52941 .61691 .49888 .61395 .50406 Mtetra
.996 .824 .47 r
.61395 .50406 .61691 .49888 .62231 .46442 .61947 .47193 Mtetra
.997 .781 .43 r
.61947 .47193 .62231 .46442 .62733 .42158 .62428 .41988 Mtetra
.976 .748 .527 r
.62428 .41988 .62733 .42158 .63251 .38772 .62927 .379 Mtetra
.971 .655 .302 r
.62927 .379 .63251 .38772 .6411 .45339 .63807 .45239 Mtetra
.937 .571 .276 r
.63807 .45239 .6411 .45339 .64859 .48187 .64559 .48211 Mtetra
.818 .998 .847 r
.64559 .48211 .64859 .48187 .65432 .46234 .65188 .47628 Mtetra
.413 .117 .35 r
.65188 .47628 .65432 .46234 .66081 .46276 .65824 .47229 Mtetra
.695 .714 .191 r
.65824 .47229 .66081 .46276 .66628 .43894 .66387 .45103 Mtetra
0 0 .104 r
.66387 .45103 .66628 .43894 .6723 .42877 .6697 .4354 Mtetra
.714 .774 .282 r
.6697 .4354 .6723 .42877 .67799 .41192 .67547 .41946 Mtetra
.142 0 .121 r
.67547 .41946 .67799 .41192 .68408 .4043 .68169 .41354 Mtetra
0 0 0 r
.68169 .41354 .68408 .4043 .68937 .38118 .68723 .39431 Mtetra
.093 0 .242 r
.68723 .39431 .68937 .38118 .69572 .37912 .69311 .3826 Mtetra
.831 .902 .489 r
.69311 .3826 .69572 .37912 .70144 .36548 .69895 .37056 Mtetra
.306 0 .071 r
.69895 .37056 .70144 .36548 .70761 .3603 .70533 .36848 Mtetra
0 0 .052 r
.70533 .36848 .70761 .3603 .71326 .34636 .71125 .3583 Mtetra
.151 0 .249 r
.71125 .3583 .71326 .34636 .71975 .34666 .71718 .34862 Mtetra
.858 .958 .617 r
.71718 .34862 .71975 .34666 .72711 .3602 .72309 .33902 Mtetra
.615 .452 .638 r
.72309 .33902 .72711 .3602 .73353 .35811 .72938 .33534 Mtetra
.599 .436 .632 r
.72938 .33534 .73353 .35811 .73949 .34916 .73574 .3326 Mtetra
.574 .445 .667 r
.73574 .3326 .73949 .34916 .74672 .35854 .74225 .33201 Mtetra
.575 .41 .621 r
.74225 .33201 .74672 .35854 .75305 .35453 .74874 .33079 Mtetra
.599 .434 .629 r
.74874 .33079 .75305 .35453 .75869 .34112 .75513 .32789 Mtetra
.551 .455 .699 r
.75513 .32789 .75869 .34112 .76449 .33025 .76178 .32832 Mtetra
.423 .775 .996 r
.76178 .32832 .76449 .33025 .77083 .32654 .76839 .32787 Mtetra
.392 .815 .635 r
.76839 .32787 .77083 .32654 .77769 .32923 .77475 .32404 Mtetra
.759 .719 .814 r
.77475 .32404 .77769 .32923 .78409 .32586 .78105 .31934 Mtetra
.219 .374 .806 r
.78105 .31934 .78409 .32586 .79112 .32979 .78815 .32412 Mtetra
.721 .687 .817 r
.78815 .32412 .79112 .32979 .79724 .32282 .79455 .32034 Mtetra
.753 .868 .932 r
.79455 .32034 .79724 .32282 .80422 .32566 .80098 .31669 Mtetra
.634 .56 .754 r
.80098 .31669 .80422 .32566 .81091 .32479 .80755 .31453 Mtetra
.529 .478 .743 r
.80755 .31453 .81091 .32479 .81804 .3285 .81442 .31549 Mtetra
.649 .519 .691 r
.81442 .31549 .81804 .3285 .82466 .32634 .82088 .31168 Mtetra
.323 .297 .675 r
.82088 .31168 .82466 .32634 .83296 .34129 .82852 .32013 Mtetra
.683 .497 .629 r
.82852 .32013 .83296 .34129 .83888 .33146 .83446 .31068 Mtetra
.355 .282 .636 r
.83446 .31068 .83888 .33146 .84565 .33024 .84241 .32138 Mtetra
.099 .23 .712 r
.84241 .32138 .84565 .33024 .85292 .33353 .85025 .33024 Mtetra
.837 .839 .847 r
.85025 .33024 .85292 .33353 .86004 .33506 .8566 .32432 Mtetra
.814 .634 .659 r
.8566 .32432 .86004 .33506 .86619 .32733 .86218 .31129 Mtetra
.696 .527 .654 r
.86218 .31129 .86619 .32733 .87125 .30977 .86828 .3033 Mtetra
.859 .72 .708 r
.86828 .3033 .87125 .30977 .87798 .30758 .87408 .29263 Mtetra
.853 .644 .62 r
.26922 .52863 .27221 .54009 .27932 .51657 .27673 .5 Mtetra
.78 .581 .63 r
.27673 .5 .27932 .51657 .28659 .49001 .28344 .48127 Mtetra
.28 .336 .742 r
.28344 .48127 .28659 .49001 .29221 .48586 .28847 .48543 Mtetra
.83 .933 .898 r
.28847 .48543 .29221 .48586 .29756 .48585 .29414 .48077 Mtetra
.435 .555 .878 r
.29414 .48077 .29756 .48585 .30315 .4823 .29943 .48185 Mtetra
.913 .576 .391 r
.29943 .48185 .30315 .4823 .30829 .48582 .30343 .5025 Mtetra
0 0 .136 r
.30343 .5025 .30829 .48582 .31345 .48946 .3098 .48805 Mtetra
.929 .778 .673 r
.3098 .48805 .31345 .48946 .31981 .47426 .31626 .47172 Mtetra
.74 .806 .904 r
.31626 .47172 .31981 .47426 .32547 .47013 .32186 .46869 Mtetra
.717 .183 0 r
.32186 .46869 .32547 .47013 .33057 .47557 .32698 .4739 Mtetra
.909 .805 .732 r
.32698 .4739 .33057 .47557 .33602 .47558 .33306 .4631 Mtetra
.629 .503 .69 r
.33306 .4631 .33602 .47558 .34158 .47376 .33865 .46059 Mtetra
.582 .467 .688 r
.33865 .46059 .34158 .47376 .34778 .46034 .34416 .4599 Mtetra
.846 .411 .192 r
.34416 .4599 .34778 .46034 .35272 .47048 .34916 .46886 Mtetra
.775 .873 .919 r
.34916 .46886 .35272 .47048 .35832 .46865 .35486 .46525 Mtetra
.829 .764 .79 r
.35486 .46525 .35832 .46865 .36441 .45721 .36071 .45877 Mtetra
0 0 0 r
.36071 .45877 .36441 .45721 .37 .45563 .36633 .45712 Mtetra
.36633 .45712 .37 .45563 .37543 .45802 .37196 .45527 Mtetra
.661 .785 .94 r
.37196 .45527 .37543 .45802 .38107 .45616 .37761 .4534 Mtetra
.542 .008 0 r
.37761 .4534 .38107 .45616 .38656 .45806 .38297 .45835 Mtetra
0 0 0 r
.38297 .45835 .38656 .45806 .3922 .45688 .38859 .45797 Mtetra
.619 .096 0 r
.38859 .45797 .3922 .45688 .39785 .45592 .39409 .46114 Mtetra
.301 0 .064 r
.39409 .46114 .39785 .45592 .40354 .45405 .39981 .45926 Mtetra
.95 .923 .566 r
.39981 .45926 .40354 .45405 .40937 .4489 .40603 .44404 Mtetra
.11 .381 .84 r
.40603 .44404 .40937 .4489 .41513 .44563 .41156 .44744 Mtetra
.937 .965 .734 r
.41156 .44744 .41513 .44563 .42101 .43881 .41755 .4381 Mtetra
.833 .934 .895 r
.41755 .4381 .42101 .43881 .42665 .4397 .42338 .43324 Mtetra
.701 .635 .779 r
.42338 .43324 .42665 .4397 .43235 .43948 .42917 .42979 Mtetra
0 0 .301 r
.42917 .42979 .43235 .43948 .43822 .43352 .43447 .44442 Mtetra
.566 .236 .368 r
.43447 .44442 .43822 .43352 .44365 .44508 .44018 .44617 Mtetra
.763 .298 .141 r
.44018 .44617 .44365 .44508 .44934 .44777 .44579 .45257 Mtetra
.371 0 .082 r
.44579 .45257 .44934 .44777 .45526 .44128 .45161 .45162 Mtetra
.437 .106 .305 r
.45161 .45162 .45526 .44128 .46109 .43938 .45747 .44971 Mtetra
.272 0 .234 r
.45747 .44971 .46109 .43938 .4668 .44436 .4634 .44459 Mtetra
.412 0 0 r
.4634 .44459 .4668 .44436 .47252 .45186 .46922 .44644 Mtetra
0 0 .422 r
.46922 .44644 .47252 .45186 .47828 .45879 .47495 .45526 Mtetra
.875 .77 .744 r
.47495 .45526 .47828 .45879 .48432 .44747 .48098 .4458 Mtetra
.933 .822 .713 r
.48098 .4458 .48432 .44747 .49029 .44098 .48703 .43367 Mtetra
.64 .589 .781 r
.48703 .43367 .49029 .44098 .49621 .43906 .49295 .43174 Mtetra
.217 .344 .779 r
.49295 .43174 .49621 .43906 .50212 .43982 .49884 .43625 Mtetra
.392 .63 .949 r
.49884 .43625 .50212 .43982 .50811 .43142 .50478 .43708 Mtetra
.832 .478 .385 r
.50478 .43708 .50811 .43142 .51401 .4461 .51068 .45354 Mtetra
.857 .525 .423 r
.51068 .45354 .51401 .4461 .51994 .48613 .51664 .47861 Mtetra
.947 .605 .2 r
.51664 .47861 .51994 .48613 .52604 .52011 .52271 .50945 Mtetra
.708 .406 0 r
.52271 .50945 .52604 .52011 .53225 .53576 .5289 .53012 Mtetra
.964 .634 .31 r
.5289 .53012 .53225 .53576 .53866 .58308 .53525 .57253 Mtetra
.814 .492 0 r
.53525 .57253 .53866 .58308 .54514 .60915 .5417 .59729 Mtetra
.835 .636 .634 r
.5417 .59729 .54514 .60915 .55145 .59653 .54795 .57758 Mtetra
.662 .495 .647 r
.54795 .57758 .55145 .59653 .55761 .57251 .55428 .57109 Mtetra
.851 .392 .067 r
.55428 .57109 .55761 .57251 .56417 .5882 .56078 .58264 Mtetra
.245 .445 .858 r
.56078 .58264 .56417 .5882 .57066 .59267 .56726 .58586 Mtetra
.845 .696 .696 r
.56726 .58586 .57066 .59267 .57699 .58454 .57354 .57383 Mtetra
.772 .613 .682 r
.57354 .57383 .57699 .58454 .58332 .57676 .57984 .56366 Mtetra
.769 .592 .658 r
.57984 .56366 .58332 .57676 .58948 .5605 .58607 .55136 Mtetra
.747 .619 .717 r
.58607 .55136 .58948 .5605 .59567 .54737 .59239 .54433 Mtetra
.803 .821 .865 r
.59239 .54433 .59567 .54737 .60202 .54291 .59875 .53934 Mtetra
.952 .752 .597 r
.59875 .53934 .60202 .54291 .608 .52291 .60461 .51325 Mtetra
.846 .658 .648 r
.60461 .51325 .608 .52291 .61395 .50406 .61063 .49643 Mtetra
.935 .701 .56 r
.61063 .49643 .61395 .50406 .61947 .47193 .61596 .45639 Mtetra
.889 .647 .566 r
.61596 .45639 .61947 .47193 .62428 .41988 .62106 .413 Mtetra
.945 .705 .546 r
.62106 .413 .62428 .41988 .62927 .379 .626 .36944 Mtetra
.972 .66 .307 r
.626 .36944 .62927 .379 .63807 .45239 .63497 .44993 Mtetra
.903 .49 .123 r
.63497 .44993 .63807 .45239 .64559 .48211 .64208 .46852 Mtetra
.612 .492 .692 r
.64208 .46852 .64559 .48211 .65188 .47628 .6485 .46641 Mtetra
.576 .513 .748 r
.6485 .46641 .65188 .47628 .65824 .47229 .655 .46596 Mtetra
.867 .713 .689 r
.655 .46596 .65824 .47229 .66387 .45103 .66102 .45328 Mtetra
.987 .889 .562 r
.66102 .45328 .66387 .45103 .6697 .4354 .66678 .43538 Mtetra
.992 .81 .557 r
.66678 .43538 .6697 .4354 .67547 .41946 .67216 .41026 Mtetra
.727 .606 .721 r
.67216 .41026 .67547 .41946 .68169 .41354 .67838 .40431 Mtetra
.84 .659 .658 r
.67838 .40431 .68169 .41354 .68723 .39431 .68416 .3897 Mtetra
.893 .76 .708 r
.68416 .3897 .68723 .39431 .69311 .3826 .69006 .37801 Mtetra
.857 .76 .754 r
.69006 .37801 .69311 .3826 .69895 .37056 .69611 .3694 Mtetra
.862 .946 .87 r
.69611 .3694 .69895 .37056 .70533 .36848 .70229 .36349 Mtetra
.862 .748 .735 r
.70229 .36349 .70533 .36848 .71125 .3583 .70826 .354 Mtetra
.748 .749 .853 r
.70826 .354 .71125 .3583 .71718 .34862 .71455 .35007 Mtetra
.367 .8 .628 r
.71455 .35007 .71718 .34862 .72309 .33902 .72086 .34643 Mtetra
.267 0 .172 r
.72086 .34643 .72309 .33902 .72938 .33534 .72715 .34226 Mtetra
.319 0 .172 r
.72715 .34226 .72938 .33534 .73574 .3326 .73352 .33921 Mtetra
.643 .245 .275 r
.73352 .33921 .73574 .3326 .74225 .33201 .74042 .34381 Mtetra
.38 .075 .318 r
.74042 .34381 .74225 .33201 .74874 .33079 .74674 .3395 Mtetra
.488 .13 .285 r
.74674 .3395 .74874 .33079 .75513 .32789 .75335 .33921 Mtetra
.326 .027 .296 r
.75335 .33921 .75513 .32789 .76178 .32832 .7596 .3337 Mtetra
.321 0 .098 r
.7596 .3337 .76178 .32832 .76839 .32787 .76611 .33157 Mtetra
.815 .865 .42 r
.76611 .33157 .76839 .32787 .77475 .32404 .77174 .31809 Mtetra
.698 .667 .816 r
.77174 .31809 .77475 .32404 .78105 .31934 .77817 .31483 Mtetra
.662 .712 .885 r
.77817 .31483 .78105 .31934 .78815 .32412 .78469 .31267 Mtetra
.575 .49 .721 r
.78469 .31267 .78815 .32412 .79455 .32034 .79138 .3122 Mtetra
.34 .404 .782 r
.79138 .3122 .79455 .32034 .80098 .31669 .79849 .31639 Mtetra
.681 .976 .9 r
.79849 .31639 .80098 .31669 .80755 .31453 .80492 .3124 Mtetra
.499 .801 .999 r
.80492 .3124 .80755 .31453 .81442 .31549 .81163 .31148 Mtetra
.542 .687 .933 r
.81163 .31148 .81442 .31549 .82088 .31168 .81841 .31102 Mtetra
.45 0 0 r
.81841 .31102 .82088 .31168 .82852 .32013 .82564 .31506 Mtetra
.716 .712 .846 r
.82564 .31506 .82852 .32013 .83446 .31068 .83218 .3116 Mtetra
.565 0 0 r
.83218 .3116 .83446 .31068 .84241 .32138 .83947 .31554 Mtetra
.559 .607 .858 r
.83947 .31554 .84241 .32138 .85025 .33024 .84638 .31524 Mtetra
.587 .466 .682 r
.84638 .31524 .85025 .33024 .8566 .32432 .85321 .31407 Mtetra
.753 .608 .698 r
.85321 .31407 .8566 .32432 .86218 .31129 .85933 .30606 Mtetra
.658 .683 .862 r
.85933 .30606 .86218 .31129 .86828 .3033 .86608 .30385 Mtetra
.629 .067 0 r
.86608 .30385 .86828 .3033 .87408 .29263 .87371 .30939 Mtetra
.795 .586 .618 r
.26679 .50993 .26922 .52863 .27673 .5 .27402 .48517 Mtetra
.717 .545 .656 r
.27402 .48517 .27673 .5 .28344 .48127 .28001 .47617 Mtetra
0 .241 .757 r
.28001 .47617 .28344 .48127 .28847 .48543 .28503 .48045 Mtetra
.655 .658 .841 r
.28503 .48045 .28847 .48543 .29414 .48077 .29051 .47864 Mtetra
.551 0 0 r
.29051 .47864 .29414 .48077 .29943 .48185 .2956 .48269 Mtetra
.918 .945 .802 r
.2956 .48269 .29943 .48185 .30343 .5025 .3015 .47503 Mtetra
.56 .394 .612 r
.3015 .47503 .30343 .5025 .3098 .48805 .30691 .47487 Mtetra
.646 .508 .681 r
.30691 .47487 .3098 .48805 .31626 .47172 .31255 .47139 Mtetra
.531 .901 .963 r
.31255 .47139 .31626 .47172 .32186 .46869 .31809 .46956 Mtetra
.943 .914 .758 r
.31809 .46956 .32186 .46869 .32698 .4739 .32411 .46001 Mtetra
.621 .487 .677 r
.32411 .46001 .32698 .4739 .33306 .4631 .32969 .45756 Mtetra
.652 .638 .823 r
.32969 .45756 .33306 .4631 .33865 .46059 .33525 .45571 Mtetra
.306 .498 .881 r
.33525 .45571 .33865 .46059 .34416 .4599 .34061 .45775 Mtetra
.906 .506 .228 r
.34061 .45775 .34416 .4599 .34916 .46886 .34538 .47087 Mtetra
.469 .867 .688 r
.34538 .47087 .34916 .46886 .35486 .46525 .3511 .4672 Mtetra
.977 .875 .667 r
.3511 .4672 .35486 .46525 .36071 .45877 .35742 .45205 Mtetra
.677 .615 .779 r
.35742 .45205 .36071 .45877 .36633 .45712 .36309 .44927 Mtetra
.226 .329 .76 r
.36309 .44927 .36633 .45712 .37196 .45527 .36843 .45366 Mtetra
.559 .84 .997 r
.36843 .45366 .37196 .45527 .37761 .4534 .37406 .45237 Mtetra
.841 .386 .122 r
.37406 .45237 .37761 .4534 .38297 .45835 .37926 .46105 Mtetra
.73 .3 .23 r
.37926 .46105 .38297 .45835 .38859 .45797 .38464 .46673 Mtetra
.491 .139 .297 r
.38464 .46673 .38859 .45797 .39409 .46114 .3903 .46649 Mtetra
0 0 0 r
.3903 .46649 .39409 .46114 .39981 .45926 .39629 .4583 Mtetra
.826 .917 .898 r
.39629 .4583 .39981 .45926 .40603 .44404 .40213 .45358 Mtetra
.121 0 .138 r
.40213 .45358 .40603 .44404 .41156 .44744 .40805 .44706 Mtetra
.15 .688 .838 r
.40805 .44706 .41156 .44744 .41755 .4381 .41375 .4468 Mtetra
0 0 0 r
.41375 .4468 .41755 .4381 .42338 .43324 .4198 .43607 Mtetra
.849 .979 .683 r
.4198 .43607 .42338 .43324 .42917 .42979 .42576 .42782 Mtetra
.897 .482 .182 r
.42576 .42782 .42917 .42979 .43447 .44442 .4311 .44091 Mtetra
0 .308 .787 r
.4311 .44091 .43447 .44442 .44018 .44617 .43676 .44449 Mtetra
.585 .019 0 r
.43676 .44449 .44018 .44617 .44579 .45257 .44242 .44906 Mtetra
.714 .758 .887 r
.44242 .44906 .44579 .45257 .45161 .45162 .44829 .44623 Mtetra
.376 .515 .87 r
.44829 .44623 .45161 .45162 .45747 .44971 .45408 .44806 Mtetra
.705 .88 .963 r
.45408 .44806 .45747 .44971 .4634 .44459 .45997 .44534 Mtetra
.137 0 0 r
.45997 .44534 .4634 .44459 .46922 .44644 .46583 .4453 Mtetra
.859 .908 .866 r
.46583 .4453 .46922 .44644 .47495 .45526 .4718 .4396 Mtetra
.753 .565 .641 r
.4718 .4396 .47495 .45526 .48098 .4458 .47788 .42644 Mtetra
.673 .497 .639 r
.47788 .42644 .48098 .4458 .48703 .43367 .48386 .4189 Mtetra
.606 .474 .675 r
.48386 .4189 .48703 .43367 .49295 .43174 .48977 .41695 Mtetra
.268 .247 .649 r
.48977 .41695 .49295 .43174 .49884 .43625 .49561 .42516 Mtetra
.082 .166 .653 r
.49561 .42516 .49884 .43625 .50478 .43708 .50148 .43395 Mtetra
.927 .539 .202 r
.50148 .43395 .50478 .43708 .51068 .45354 .50736 .45311 Mtetra
.897 .497 .244 r
.50736 .45311 .51068 .45354 .51664 .47861 .51334 .46883 Mtetra
.867 .536 .023 r
.51334 .46883 .51664 .47861 .52271 .50945 .51938 .49409 Mtetra
0 0 .263 r
.51938 .49409 .52271 .50945 .5289 .53012 .52553 .51861 Mtetra
.961 .648 .244 r
.52553 .51861 .5289 .53012 .53525 .57253 .53185 .56698 Mtetra
.906 .522 .09 r
.53185 .56698 .53525 .57253 .5417 .59729 .53826 .58753 Mtetra
.816 .644 .669 r
.53826 .58753 .5417 .59729 .54795 .57758 .54457 .57409 Mtetra
.679 .769 .919 r
.54457 .57409 .54795 .57758 .55428 .57109 .55094 .57173 Mtetra
.748 .994 .853 r
.55094 .57173 .55428 .57109 .56078 .58264 .55729 .56667 Mtetra
.063 .105 .594 r
.55729 .56667 .56078 .58264 .56726 .58586 .56386 .58026 Mtetra
0 .248 .761 r
.56386 .58026 .56726 .58586 .57354 .57383 .5704 .58589 Mtetra
.726 .726 .202 r
.5704 .58589 .57354 .57383 .57984 .56366 .57652 .56112 Mtetra
.952 .785 .638 r
.57652 .56112 .57984 .56366 .58607 .55136 .58266 .5417 Mtetra
.556 .506 .755 r
.58266 .5417 .58607 .55136 .59239 .54433 .58911 .5418 Mtetra
.886 .841 .796 r
.58911 .5418 .59239 .54433 .59875 .53934 .59542 .53372 Mtetra
.891 .728 .674 r
.59542 .53372 .59875 .53934 .60461 .51325 .60156 .51869 Mtetra
.996 .827 .47 r
.60156 .51869 .60461 .51325 .61063 .49643 .60725 .48678 Mtetra
.926 .686 .557 r
.60725 .48678 .61063 .49643 .61596 .45639 .61251 .44292 Mtetra
.881 .649 .584 r
.61251 .44292 .61596 .45639 .62106 .413 .61792 .40927 Mtetra
.965 .728 .53 r
.61792 .40927 .62106 .413 .626 .36944 .62287 .36443 Mtetra
.966 .642 .317 r
.62287 .36443 .626 .36944 .63497 .44993 .63114 .42543 Mtetra
0 0 .505 r
.63114 .42543 .63497 .44993 .64208 .46852 .63842 .45056 Mtetra
.499 .389 .66 r
.63842 .45056 .64208 .46852 .6485 .46641 .64501 .45345 Mtetra
.174 .212 .662 r
.64501 .45345 .6485 .46641 .655 .46596 .65189 .46317 Mtetra
.967 .768 .582 r
.65189 .46317 .655 .46596 .66102 .45328 .65739 .43719 Mtetra
.788 .585 .626 r
.65739 .43719 .66102 .45328 .66678 .43538 .66317 .4198 Mtetra
.839 .617 .602 r
.66317 .4198 .66678 .43538 .67216 .41026 .66855 .39438 Mtetra
.626 .484 .668 r
.66855 .39438 .67216 .41026 .67838 .40431 .67488 .39108 Mtetra
.777 .593 .65 r
.67488 .39108 .67838 .40431 .68416 .3897 .68075 .37812 Mtetra
.844 .64 .627 r
.68075 .37812 .68416 .3897 .69006 .37801 .68627 .35899 Mtetra
.619 .463 .648 r
.68627 .35899 .69006 .37801 .69611 .3694 .69257 .35544 Mtetra
.183 .206 .65 r
.69257 .35544 .69611 .3694 .70229 .36349 .69965 .36608 Mtetra
.991 .86 .508 r
.69965 .36608 .70229 .36349 .70826 .354 .70497 .34456 Mtetra
.678 .575 .733 r
.70497 .34456 .70826 .354 .71455 .35007 .71126 .3407 Mtetra
.446 .441 .76 r
.71126 .3407 .71455 .35007 .72086 .34643 .71796 .34333 Mtetra
.443 .696 .973 r
.71796 .34333 .72086 .34643 .72715 .34226 .72453 .34349 Mtetra
.325 .784 .648 r
.72453 .34349 .72715 .34226 .73352 .33921 .73092 .34034 Mtetra
.605 .055 0 r
.73092 .34034 .73352 .33921 .74042 .34381 .7378 .34438 Mtetra
.879 .992 .751 r
.7378 .34438 .74042 .34381 .74674 .3395 .74389 .33654 Mtetra
.585 .775 .97 r
.74389 .33654 .74674 .3395 .75335 .33921 .75045 .33527 Mtetra
.785 .782 .85 r
.75045 .33527 .75335 .33921 .7596 .3337 .75677 .33049 Mtetra
.921 .822 .732 r
.75677 .33049 .7596 .3337 .76611 .33157 .76265 .3199 Mtetra
.647 .53 .707 r
.76265 .3199 .76611 .33157 .77174 .31809 .76907 .31659 Mtetra
0 .28 .667 r
.76907 .31659 .77174 .31809 .77817 .31483 .77605 .32005 Mtetra
.311 0 .083 r
.77605 .32005 .77817 .31483 .78469 .31267 .78261 .31789 Mtetra
.78261 .31789 .78469 .31267 .79138 .3122 .78918 .31572 Mtetra
0 0 0 r
.78918 .31572 .79138 .3122 .79849 .31639 .79551 .31055 Mtetra
.655 .654 .837 r
.79551 .31055 .79849 .31639 .80492 .3124 .8021 .30838 Mtetra
0 .155 .686 r
.8021 .30838 .80492 .3124 .81163 .31148 .80953 .31516 Mtetra
.464 0 .033 r
.80953 .31516 .81163 .31148 .81841 .31102 .81646 .31605 Mtetra
.628 .189 .188 r
.81646 .31605 .81841 .31102 .82564 .31506 .82373 .32017 Mtetra
.492 .058 .141 r
.82373 .32017 .82564 .31506 .83218 .3116 .83072 .32103 Mtetra
.465 .118 .292 r
.83072 .32103 .83218 .3116 .83947 .31554 .83755 .31995 Mtetra
.722 .275 .189 r
.83755 .31995 .83947 .31554 .84638 .31524 .84527 .32744 Mtetra
.099 0 .255 r
.84527 .32744 .84638 .31524 .85321 .31407 .85102 .31539 Mtetra
.944 .919 .55 r
.85102 .31539 .85321 .31407 .85933 .30606 .85656 .30157 Mtetra
.711 .299 0 r
.85656 .30157 .85933 .30606 .86608 .30385 .86543 .31882 Mtetra
.843 .493 .391 r
.86543 .31882 .86608 .30385 .87371 .30939 .87616 .35201 Mtetra
.843 .672 .669 r
.26346 .50291 .26679 .50993 .27402 .48517 .26996 .48793 Mtetra
0 0 0 r
.26996 .48793 .27402 .48517 .28001 .47617 .27557 .48434 Mtetra
.27557 .48434 .28001 .47617 .28503 .48045 .28161 .47508 Mtetra
.774 .684 .763 r
.28161 .47508 .28503 .48045 .29051 .47864 .28738 .46935 Mtetra
.652 .552 .728 r
.28738 .46935 .29051 .47864 .2956 .48269 .29293 .46666 Mtetra
.582 .447 .662 r
.29293 .46666 .2956 .48269 .3015 .47503 .29837 .4657 Mtetra
.567 .502 .742 r
.29837 .4657 .3015 .47503 .30691 .47487 .30377 .46551 Mtetra
.206 .275 .715 r
.30377 .46551 .30691 .47487 .31255 .47139 .30883 .47081 Mtetra
.928 .841 .737 r
.30883 .47081 .31255 .47139 .31809 .46956 .31495 .45999 Mtetra
.638 .541 .728 r
.31495 .45999 .31809 .46956 .32411 .46001 .32053 .45771 Mtetra
.623 .805 .97 r
.32053 .45771 .32411 .46001 .32969 .45756 .32607 .45621 Mtetra
.321 .751 .971 r
.32607 .45621 .32969 .45756 .33525 .45571 .33154 .45605 Mtetra
.864 .47 .29 r
.33154 .45605 .33525 .45571 .34061 .45775 .33636 .46749 Mtetra
.714 .386 .421 r
.33636 .46749 .34061 .45775 .34538 .47087 .34139 .47627 Mtetra
0 0 0 r
.34139 .47627 .34538 .47087 .3511 .4672 .34732 .46911 Mtetra
.977 .828 .629 r
.34732 .46911 .3511 .4672 .35742 .45205 .35395 .44861 Mtetra
.728 .756 .875 r
.35395 .44861 .35742 .45205 .36309 .44927 .35964 .44558 Mtetra
0 .011 .524 r
.35964 .44558 .36309 .44927 .36843 .45366 .36493 .45094 Mtetra
.296 .64 .966 r
.36493 .45094 .36843 .45366 .37406 .45237 .37046 .4518 Mtetra
.22 .73 .889 r
.37046 .4518 .37406 .45237 .37926 .46105 .37608 .45144 Mtetra
.406 .402 .742 r
.37608 .45144 .37926 .46105 .38464 .46673 .38156 .45447 Mtetra
.154 .193 .65 r
.38156 .45447 .38464 .46673 .3903 .46649 .38686 .46248 Mtetra
.829 .746 .772 r
.38686 .46248 .3903 .46649 .39629 .4583 .39282 .45538 Mtetra
.396 .677 .973 r
.39282 .45538 .39629 .4583 .40213 .45358 .39848 .4558 Mtetra
.917 .978 .727 r
.39848 .4558 .40213 .45358 .40805 .44706 .40451 .44683 Mtetra
.581 .01 0 r
.40451 .44683 .40805 .44706 .41375 .4468 .41009 .45019 Mtetra
.99 .887 .613 r
.41009 .45019 .41375 .4468 .4198 .43607 .41641 .43255 Mtetra
.862 .765 .754 r
.41641 .43255 .4198 .43607 .42576 .42782 .42239 .42391 Mtetra
.875 .449 .038 r
.42239 .42391 .42576 .42782 .4311 .44091 .42774 .43637 Mtetra
.182 .447 .875 r
.42774 .43637 .4311 .44091 .43676 .44449 .43342 .43912 Mtetra
.695 .275 0 r
.43342 .43912 .43676 .44449 .44242 .44906 .43894 .44923 Mtetra
.909 .95 .814 r
.43894 .44923 .44242 .44906 .44829 .44623 .44494 .44187 Mtetra
.743 .724 .834 r
.44494 .44187 .44829 .44623 .45408 .44806 .45085 .43807 Mtetra
.752 .603 .692 r
.45085 .43807 .45408 .44806 .45997 .44534 .45686 .4299 Mtetra
.639 .491 .666 r
.45686 .4299 .45997 .44534 .46583 .4453 .46278 .42609 Mtetra
.615 .457 .645 r
.46278 .42609 .46583 .4453 .4718 .4396 .46869 .42289 Mtetra
.661 .499 .654 r
.46869 .42289 .4718 .4396 .47788 .42644 .47464 .41725 Mtetra
.7 .585 .723 r
.47464 .41725 .47788 .42644 .48386 .4189 .48059 .41258 Mtetra
.714 .648 .783 r
.48059 .41258 .48386 .4189 .48977 .41695 .48653 .40876 Mtetra
.408 .438 .779 r
.48653 .40876 .48977 .41695 .49561 .42516 .4924 .41139 Mtetra
.131 .163 .628 r
.4924 .41139 .49561 .42516 .50148 .43395 .49825 .42145 Mtetra
0 0 .216 r
.49825 .42145 .50148 .43395 .50736 .45311 .50408 .44289 Mtetra
0 0 .472 r
.50408 .44289 .50736 .45311 .51334 .46883 .51005 .45611 Mtetra
0 0 .218 r
.51005 .45611 .51334 .46883 .51938 .49409 .51606 .47816 Mtetra
.719 .468 0 r
.51606 .47816 .51938 .49409 .52553 .51861 .52217 .50853 Mtetra
.964 .645 .257 r
.52217 .50853 .52553 .51861 .53185 .56698 .52843 .55467 Mtetra
.822 .517 0 r
.52843 .55467 .53185 .56698 .53826 .58753 .53484 .58331 Mtetra
.933 .743 .622 r
.53484 .58331 .53826 .58753 .54457 .57409 .54112 .56017 Mtetra
.686 .536 .677 r
.54112 .56017 .54457 .57409 .55094 .57173 .54745 .55401 Mtetra
.651 .492 .655 r
.54745 .55401 .55094 .57173 .55729 .56667 .55379 .54871 Mtetra
0 0 .29 r
.55379 .54871 .55729 .56667 .56386 .58026 .56048 .57675 Mtetra
.869 .437 .025 r
.56048 .57675 .56386 .58026 .5704 .58589 .56714 .59168 Mtetra
.994 .84 .483 r
.56714 .59168 .5704 .58589 .57652 .56112 .57323 .5617 Mtetra
.985 .864 .633 r
.57323 .5617 .57652 .56112 .58266 .5417 .57944 .54435 Mtetra
.832 .964 .638 r
.57944 .54435 .58266 .5417 .58911 .5418 .58574 .53514 Mtetra
.802 .687 .738 r
.58574 .53514 .58911 .5418 .59542 .53372 .59206 .52704 Mtetra
.899 .71 .638 r
.59206 .52704 .59542 .53372 .60156 .51869 .59812 .50734 Mtetra
.899 .668 .581 r
.59812 .50734 .60156 .51869 .60725 .48678 .60376 .47246 Mtetra
.899 .656 .563 r
.60376 .47246 .60725 .48678 .61251 .44292 .60902 .42738 Mtetra
.888 .646 .567 r
.60902 .42738 .61251 .44292 .61792 .40927 .61419 .38472 Mtetra
.683 .489 .618 r
.61419 .38472 .61792 .40927 .62287 .36443 .62016 .37373 Mtetra
.915 .594 .422 r
.62016 .37373 .62287 .36443 .63114 .42543 .6283 .43159 Mtetra
.763 .377 .323 r
.6283 .43159 .63114 .42543 .63842 .45056 .63509 .4419 Mtetra
.471 .473 .779 r
.63509 .4419 .63842 .45056 .64501 .45345 .64163 .44374 Mtetra
.63 .547 .742 r
.64163 .44374 .64501 .45345 .65189 .46317 .64806 .44157 Mtetra
.668 .487 .632 r
.64806 .44157 .65189 .46317 .65739 .43719 .65426 .43343 Mtetra
.94 .772 .647 r
.65426 .43343 .65739 .43719 .66317 .4198 .66007 .41601 Mtetra
.945 .768 .633 r
.66007 .41601 .66317 .4198 .66855 .39438 .66576 .39715 Mtetra
.954 .916 .554 r
.66576 .39715 .66855 .39438 .67488 .39108 .67158 .38217 Mtetra
.787 .639 .698 r
.67158 .38217 .67488 .39108 .68075 .37812 .67764 .37292 Mtetra
.886 .743 .699 r
.67764 .37292 .68075 .37812 .68627 .35899 .68353 .36078 Mtetra
0 0 0 r
.68353 .36078 .68627 .35899 .69257 .35544 .68985 .35725 Mtetra
.166 0 0 r
.68985 .35725 .69257 .35544 .69965 .36608 .69633 .35644 Mtetra
.87 .668 .627 r
.69633 .35644 .69965 .36608 .70497 .34456 .70178 .337 Mtetra
.342 .42 .797 r
.70178 .337 .70497 .34456 .71126 .3407 .70851 .34061 Mtetra
.343 0 0 r
.70851 .34061 .71126 .3407 .71796 .34333 .71519 .34275 Mtetra
.502 .896 .944 r
.71519 .34275 .71796 .34333 .72453 .34349 .72164 .34063 Mtetra
.86 .847 .83 r
.72164 .34063 .72453 .34349 .73092 .34034 .72782 .33408 Mtetra
.651 .635 .821 r
.72782 .33408 .73092 .34034 .7378 .34438 .73429 .33194 Mtetra
.748 .581 .669 r
.73429 .33194 .7378 .34438 .74389 .33654 .74027 .32243 Mtetra
.658 .515 .677 r
.74027 .32243 .74389 .33654 .75045 .33527 .74658 .3178 Mtetra
.56 .432 .662 r
.74658 .3178 .75045 .33527 .75677 .33049 .75323 .31779 Mtetra
.191 .227 .67 r
.75323 .31779 .75677 .33049 .76265 .3199 .76064 .32767 Mtetra
.654 .268 .302 r
.76064 .32767 .76265 .3199 .76907 .31659 .76778 .3331 Mtetra
.438 .155 .384 r
.76778 .3331 .76907 .31659 .77605 .32005 .77421 .32904 Mtetra
.488 .131 .287 r
.77421 .32904 .77605 .32005 .78261 .31789 .78096 .32877 Mtetra
.441 .115 .315 r
.78096 .32877 .78261 .31789 .78918 .31572 .78757 .3266 Mtetra
.212 0 .254 r
.78757 .3266 .78918 .31572 .79551 .31055 .79371 .3187 Mtetra
.205 0 .181 r
.79371 .3187 .79551 .31055 .8021 .30838 .80002 .31278 Mtetra
.59 .135 .14 r
.80002 .31278 .8021 .30838 .80953 .31516 .80714 .3159 Mtetra
.68 .966 .756 r
.80714 .3159 .80953 .31516 .81646 .31605 .8135 .31045 Mtetra
0 .209 .734 r
.8135 .31045 .81646 .31605 .82373 .32017 .82107 .31769 Mtetra
.291 .66 .971 r
.82107 .31769 .82373 .32017 .83072 .32103 .82807 .31855 Mtetra
.214 .611 .951 r
.82807 .31855 .83072 .32103 .83755 .31995 .83516 .31995 Mtetra
.791 .999 .822 r
.83516 .31995 .83755 .31995 .84527 .32744 .84155 .31403 Mtetra
.275 .279 .683 r
.84155 .31403 .84527 .32744 .85102 .31539 .84946 .32299 Mtetra
.545 .158 .257 r
.84946 .32299 .85102 .31539 .85656 .30157 .85668 .32469 Mtetra
.487 .219 .433 r
.85668 .32469 .85656 .30157 .86543 .31882 .86341 .3215 Mtetra
.728 .238 .077 r
.86341 .3215 .86543 .31882 .87616 .35201 .87133 .32904 Mtetra
.726 .676 .801 r
.25998 .49773 .26346 .50291 .26996 .48793 .26562 .49408 Mtetra
.687 .866 .466 r
.26562 .49408 .26996 .48793 .27557 .48434 .2717 .48459 Mtetra
.947 .831 .698 r
.2717 .48459 .27557 .48434 .28161 .47508 .27811 .47069 Mtetra
.774 .716 .798 r
.27811 .47069 .28161 .47508 .28738 .46935 .28382 .46582 Mtetra
.565 .062 0 r
.28382 .46582 .28738 .46935 .29293 .46666 .2888 .47122 Mtetra
.248 0 0 r
.2888 .47122 .29293 .46666 .29837 .4657 .29432 .46939 Mtetra
.719 .317 .286 r
.29432 .46939 .29837 .4657 .30377 .46551 .29934 .47493 Mtetra
.591 .25 .36 r
.29934 .47493 .30377 .46551 .30883 .47081 .30461 .47742 Mtetra
.844 .912 .508 r
.30461 .47742 .30883 .47081 .31495 .45999 .31089 .46468 Mtetra
.817 .944 .589 r
.31089 .46468 .31495 .45999 .32053 .45771 .31695 .45517 Mtetra
.424 0 0 r
.31695 .45517 .32053 .45771 .32607 .45621 .32217 .45896 Mtetra
.819 .443 .342 r
.32217 .45896 .32607 .45621 .33154 .45605 .32701 .46952 Mtetra
.516 .206 .38 r
.32701 .46952 .33154 .45605 .33636 .46749 .33253 .4694 Mtetra
.767 .338 .232 r
.33253 .4694 .33636 .46749 .34139 .47627 .33768 .47601 Mtetra
.927 .881 .77 r
.33768 .47601 .34139 .47627 .34732 .46911 .34374 .46682 Mtetra
.928 .754 .645 r
.34374 .46682 .34732 .46911 .35395 .44861 .35039 .44649 Mtetra
.451 .761 .995 r
.35039 .44649 .35395 .44861 .35964 .44558 .35595 .44615 Mtetra
.209 0 0 r
.35595 .44615 .35964 .44558 .36493 .45094 .3615 .44656 Mtetra
.624 .163 0 r
.3615 .44656 .36493 .45094 .37046 .4518 .36672 .45386 Mtetra
.425 0 0 r
.36672 .45386 .37046 .4518 .37608 .45144 .3723 .45468 Mtetra
0 0 0 r
.3723 .45468 .37608 .45144 .38156 .45447 .3781 .45096 Mtetra
.748 .76 .863 r
.3781 .45096 .38156 .45447 .38686 .46248 .38389 .44742 Mtetra
.398 .33 .664 r
.38389 .44742 .38686 .46248 .39282 .45538 .38934 .45242 Mtetra
.761 .794 .88 r
.38934 .45242 .39282 .45538 .39848 .4558 .39517 .44876 Mtetra
.803 .664 .71 r
.39517 .44876 .39848 .4558 .40451 .44683 .40121 .43968 Mtetra
.547 .543 .801 r
.40121 .43968 .40451 .44683 .41009 .45019 .40691 .43978 Mtetra
.765 .605 .68 r
.40691 .43978 .41009 .45019 .41641 .43255 .41296 .4302 Mtetra
.895 .806 .752 r
.41296 .4302 .41641 .43255 .42239 .42391 .41899 .42073 Mtetra
.744 .253 0 r
.41899 .42073 .42239 .42391 .42774 .43637 .42447 .42859 Mtetra
0 0 .429 r
.42447 .42859 .42774 .43637 .43342 .43912 .42991 .43927 Mtetra
.847 .416 .203 r
.42991 .43927 .43342 .43912 .43894 .44923 .43543 .44943 Mtetra
.954 .892 .729 r
.43543 .44943 .43894 .44923 .44494 .44187 .44155 .43832 Mtetra
.872 .767 .744 r
.44155 .43832 .44494 .44187 .45085 .43807 .4476 .42889 Mtetra
.762 .617 .699 r
.4476 .42889 .45085 .43807 .45686 .4299 .45362 .42071 Mtetra
.629 .546 .742 r
.45362 .42071 .45686 .4299 .46278 .42609 .4595 .41876 Mtetra
.615 .576 .787 r
.4595 .41876 .46278 .42609 .46869 .42289 .46538 .41744 Mtetra
.654 .652 .836 r
.46538 .41744 .46869 .42289 .47464 .41725 .47128 .41549 Mtetra
.925 .827 .73 r
.47128 .41549 .47464 .41725 .48059 .41258 .47733 .40447 Mtetra
.502 .495 .781 r
.47733 .40447 .48059 .41258 .48653 .40876 .48321 .40552 Mtetra
.751 .786 .881 r
.48321 .40552 .48653 .40876 .4924 .41139 .48916 .40196 Mtetra
0 0 .567 r
.48916 .40196 .4924 .41139 .49825 .42145 .49499 .41243 Mtetra
.837 .498 0 r
.49499 .41243 .49825 .42145 .50408 .44289 .50079 .43371 Mtetra
0 .137 .659 r
.50079 .43371 .50408 .44289 .51005 .45611 .50677 .44206 Mtetra
0 .015 .552 r
.50677 .44206 .51005 .45611 .51606 .47816 .51278 .45584 Mtetra
0 0 .4 r
.51278 .45584 .51606 .47816 .52217 .50853 .51884 .4824 Mtetra
0 0 .191 r
.51884 .4824 .52217 .50853 .52843 .55467 .52502 .52453 Mtetra
0 0 .306 r
.52502 .52453 .52843 .55467 .53484 .58331 .53137 .56516 Mtetra
.782 .577 .622 r
.53137 .56516 .53484 .58331 .54112 .56017 .53767 .54577 Mtetra
.671 .523 .676 r
.53767 .54577 .54112 .56017 .54745 .55401 .544 .54038 Mtetra
.597 .483 .694 r
.544 .54038 .54745 .55401 .55379 .54871 .55037 .53891 Mtetra
.819 .487 0 r
.55037 .53891 .55379 .54871 .56048 .57675 .55699 .56299 Mtetra
.421 .369 .695 r
.55699 .56299 .56048 .57675 .56714 .59168 .5635 .56734 Mtetra
.771 .554 .604 r
.5635 .56734 .56714 .59168 .57323 .5617 .56967 .5434 Mtetra
.736 .546 .635 r
.56967 .5434 .57323 .5617 .57944 .54435 .57593 .53023 Mtetra
.642 .508 .684 r
.57593 .53023 .57944 .54435 .58574 .53514 .58233 .52653 Mtetra
.884 .683 .626 r
.58233 .52653 .58574 .53514 .59206 .52704 .5884 .50472 Mtetra
.758 .548 .612 r
.5884 .50472 .59206 .52704 .59812 .50734 .59445 .48515 Mtetra
.829 .595 .585 r
.59445 .48515 .59812 .50734 .60376 .47246 .60009 .4501 Mtetra
.857 .613 .569 r
.60009 .4501 .60376 .47246 .60902 .42738 .60535 .4046 Mtetra
.849 .606 .571 r
.60535 .4046 .60902 .42738 .61419 .38472 .61053 .36177 Mtetra
.053 .054 .539 r
.61053 .36177 .61419 .38472 .62016 .37373 .61739 .38232 Mtetra
.884 .549 .41 r
.61739 .38232 .62016 .37373 .6283 .43159 .62481 .41755 Mtetra
0 0 .534 r
.62481 .41755 .6283 .43159 .63509 .4419 .63177 .43383 Mtetra
.296 .381 .781 r
.63177 .43383 .63509 .4419 .64163 .44374 .6384 .43817 Mtetra
0 .265 .771 r
.6384 .43817 .64163 .44374 .64806 .44157 .64512 .44381 Mtetra
.96 .931 .6 r
.64512 .44381 .64806 .44157 .65426 .43343 .65113 .42993 Mtetra
.827 .805 .83 r
.65113 .42993 .65426 .43343 .66007 .41601 .65743 .42396 Mtetra
.755 .768 .263 r
.65743 .42396 .66007 .41601 .66576 .39715 .66314 .40437 Mtetra
0 0 0 r
.66314 .40437 .66576 .39715 .67158 .38217 .66896 .38838 Mtetra
.66896 .38838 .67158 .38217 .67764 .37292 .67488 .37551 Mtetra
.67488 .37551 .67764 .37292 .68353 .36078 .68115 .37025 Mtetra
0 0 .071 r
.68115 .37025 .68353 .36078 .68985 .35725 .68709 .35855 Mtetra
0 0 0 r
.68709 .35855 .68985 .35725 .69633 .35644 .69348 .35569 Mtetra
.976 .879 .671 r
.69348 .35569 .69633 .35644 .70178 .337 .69928 .34211 Mtetra
.706 .285 .246 r
.69928 .34211 .70178 .337 .70851 .34061 .70621 .34876 Mtetra
.429 .066 .246 r
.70621 .34876 .70851 .34061 .71519 .34275 .71271 .34731 Mtetra
0 0 0 r
.71271 .34731 .71519 .34275 .72164 .34063 .71892 .34073 Mtetra
.994 .861 .591 r
.71892 .34073 .72164 .34063 .72782 .33408 .7244 .32277 Mtetra
.661 .542 .709 r
.7244 .32277 .72782 .33408 .73429 .33194 .73075 .31893 Mtetra
.217 .241 .671 r
.73075 .31893 .73429 .33194 .74027 .32243 .738 .32831 Mtetra
.76 .356 .286 r
.738 .32831 .74027 .32243 .74658 .3178 .74537 .33839 Mtetra
.494 .216 .421 r
.74537 .33839 .74658 .3178 .75323 .31779 .75193 .33624 Mtetra
.527 .234 .414 r
.75193 .33624 .75323 .31779 .76064 .32767 .75866 .33622 Mtetra
.585 .212 .301 r
.75866 .33622 .76064 .32767 .76778 .3331 .76563 .3391 Mtetra
.45 .04 .17 r
.76563 .3391 .76778 .3331 .77421 .32904 .7724 .33885 Mtetra
.213 0 .225 r
.7724 .33885 .77421 .32904 .78096 .32877 .77865 .33191 Mtetra
.351 0 0 r
.77865 .33191 .78096 .32877 .78757 .3266 .78545 .33165 Mtetra
0 0 0 r
.78545 .33165 .78757 .3266 .79371 .3187 .79174 .32511 Mtetra
0 0 .017 r
.79174 .32511 .79371 .3187 .80002 .31278 .79792 .31726 Mtetra
0 0 0 r
.79792 .31726 .80002 .31278 .80714 .3159 .80401 .30861 Mtetra
.764 .664 .752 r
.80401 .30861 .80714 .3159 .8135 .31045 .81031 .30231 Mtetra
0 0 .429 r
.81031 .30231 .8135 .31045 .82107 .31769 .8188 .31957 Mtetra
.562 .019 0 r
.8188 .31957 .82107 .31769 .82807 .31855 .82607 .32291 Mtetra
.264 0 0 r
.82607 .32291 .82807 .31855 .83516 .31995 .83284 .32074 Mtetra
.697 .966 .733 r
.83284 .32074 .83516 .31995 .84155 .31403 .83925 .31481 Mtetra
.794 .301 .009 r
.83925 .31481 .84155 .31403 .84946 .32299 .84736 .32558 Mtetra
.313 0 0 r
.84736 .32558 .84946 .32299 .85668 .32469 .8544 .32532 Mtetra
.357 0 0 r
.8544 .32532 .85668 .32469 .86341 .3215 .8617 .32723 Mtetra
.534 .107 .177 r
.8617 .32723 .86341 .3215 .87133 .32904 .86901 .32897 Mtetra
.237 0 .13 r
.25543 .50565 .25998 .49773 .26562 .49408 .26109 .50197 Mtetra
.805 .884 .459 r
.26109 .50197 .26562 .49408 .2717 .48459 .26752 .48861 Mtetra
0 0 0 r
.26752 .48861 .2717 .48459 .27811 .47069 .27317 .48495 Mtetra
.22 0 .254 r
.27317 .48495 .27811 .47069 .28382 .46582 .27911 .47758 Mtetra
.446 .125 .327 r
.27911 .47758 .28382 .46582 .2888 .47122 .28464 .47575 Mtetra
.204 0 0 r
.28464 .47575 .2888 .47122 .29432 .46939 .2902 .47363 Mtetra
.802 .445 .381 r
.2902 .47363 .29432 .46939 .29934 .47493 .29485 .48465 Mtetra
.552 .211 .344 r
.29485 .48465 .29934 .47493 .30461 .47742 .30022 .48593 Mtetra
.909 .897 .485 r
.30022 .48593 .30461 .47742 .31089 .46468 .30687 .46828 Mtetra
.957 .949 .67 r
.30687 .46828 .31089 .46468 .31695 .45517 .31311 .45632 Mtetra
.836 .438 .291 r
.31311 .45632 .31695 .45517 .32217 .45896 .31795 .46625 Mtetra
.8 .471 .432 r
.31795 .46625 .32217 .45896 .32701 .46952 .32254 .48103 Mtetra
0 0 .004 r
.32254 .48103 .32701 .46952 .33253 .4694 .32875 .46986 Mtetra
.852 .976 .867 r
.32875 .46986 .33253 .4694 .33768 .47601 .33461 .4643 Mtetra
.722 .569 .681 r
.33461 .4643 .33768 .47601 .34374 .46682 .34058 .45694 Mtetra
.809 .632 .662 r
.34058 .45694 .34374 .46682 .35039 .44649 .34689 .44302 Mtetra
.858 .412 .017 r
.34689 .44302 .35039 .44649 .35595 .44615 .3519 .45319 Mtetra
.482 .102 .242 r
.3519 .45319 .35595 .44615 .3615 .44656 .35749 .45316 Mtetra
.673 .304 .338 r
.35749 .45316 .3615 .44656 .36672 .45386 .36284 .45826 Mtetra
0 0 0 r
.36284 .45826 .36672 .45386 .3723 .45468 .36875 .45237 Mtetra
.439 .744 .992 r
.36875 .45237 .3723 .45468 .3781 .45096 .3744 .45218 Mtetra
.54 0 0 r
.3744 .45218 .3781 .45096 .38389 .44742 .37996 .45443 Mtetra
.231 0 .103 r
.37996 .45443 .38389 .44742 .38934 .45242 .38579 .45092 Mtetra
.596 .028 0 r
.38579 .45092 .38934 .45242 .39517 .44876 .39131 .45525 Mtetra
.976 .892 .535 r
.39131 .45525 .39517 .44876 .40121 .43968 .39782 .43494 Mtetra
.831 .724 .746 r
.39782 .43494 .40121 .43968 .40691 .43978 .40382 .42676 Mtetra
.647 .512 .685 r
.40382 .42676 .40691 .43978 .41296 .4302 .40966 .4232 Mtetra
.701 .624 .767 r
.40966 .4232 .41296 .4302 .41899 .42073 .4155 .41954 Mtetra
.343 0 0 r
.4155 .41954 .41899 .42073 .42447 .42859 .42116 .42203 Mtetra
.131 .317 .784 r
.42116 .42203 .42447 .42859 .42991 .43927 .42678 .4265 Mtetra
.247 .252 .668 r
.42678 .4265 .42991 .43927 .43543 .44943 .43236 .4336 Mtetra
.723 .544 .649 r
.43236 .4336 .43543 .44943 .44155 .43832 .43844 .42348 Mtetra
.641 .496 .67 r
.43844 .42348 .44155 .43832 .4476 .42889 .44436 .41969 Mtetra
.814 .642 .669 r
.44436 .41969 .4476 .42889 .45362 .42071 .45048 .40677 Mtetra
.591 .469 .683 r
.45048 .40677 .45362 .42071 .4595 .41876 .45634 .40555 Mtetra
.486 .407 .693 r
.45634 .40555 .4595 .41876 .46538 .41744 .46214 .40786 Mtetra
.627 .539 .736 r
.46214 .40786 .46538 .41744 .47128 .41549 .46804 .40589 Mtetra
.731 .597 .706 r
.46804 .40589 .47128 .41549 .47733 .40447 .47403 .39938 Mtetra
.679 .677 .841 r
.47403 .39938 .47733 .40447 .48321 .40552 .47995 .39693 Mtetra
.026 .181 .689 r
.47995 .39693 .48321 .40552 .48916 .40196 .48577 .40415 Mtetra
.425 0 0 r
.48577 .40415 .48916 .40196 .49499 .41243 .49171 .40503 Mtetra
.645 .592 .78 r
.49171 .40503 .49499 .41243 .50079 .43371 .49769 .40291 Mtetra
.467 .321 .599 r
.49769 .40291 .50079 .43371 .50677 .44206 .50363 .40941 Mtetra
.457 .311 .594 r
.50363 .40941 .50677 .44206 .51278 .45584 .5096 .41694 Mtetra
.16 .086 .517 r
.5096 .41694 .51278 .45584 .51884 .4824 .51557 .44407 Mtetra
0 0 .442 r
.51557 .44407 .51884 .4824 .52502 .52453 .52166 .48094 Mtetra
0 0 .285 r
.52166 .48094 .52502 .52453 .53137 .56516 .52792 .53872 Mtetra
.498 .357 .619 r
.52792 .53872 .53137 .56516 .53767 .54577 .53427 .54259 Mtetra
.882 .803 .767 r
.53427 .54259 .53767 .54577 .544 .54038 .54059 .53357 Mtetra
.458 .52 .834 r
.54059 .53357 .544 .54038 .55037 .53891 .54698 .53498 Mtetra
.922 .532 .156 r
.54698 .53498 .55037 .53891 .55699 .56299 .55356 .55613 Mtetra
.456 .519 .834 r
.55356 .55613 .55699 .56299 .5635 .56734 .56003 .55759 Mtetra
.836 .654 .657 r
.56003 .55759 .5635 .56734 .56967 .5434 .56633 .54188 Mtetra
.957 .83 .678 r
.56633 .54188 .56967 .5434 .57593 .53023 .57259 .52681 Mtetra
.927 .78 .679 r
.57259 .52681 .57593 .53023 .58233 .52653 .57882 .51174 Mtetra
.858 .634 .597 r
.57882 .51174 .58233 .52653 .5884 .50472 .58474 .48175 Mtetra
.793 .57 .598 r
.58474 .48175 .5884 .50472 .59445 .48515 .59063 .45485 Mtetra
.768 .54 .589 r
.59063 .45485 .59445 .48515 .60009 .4501 .59639 .42578 Mtetra
.816 .582 .584 r
.59639 .42578 .60009 .4501 .60535 .4046 .60194 .39144 Mtetra
.879 .649 .587 r
.60194 .39144 .60535 .4046 .61053 .36177 .60743 .35949 Mtetra
.798 .317 0 r
.60743 .35949 .61053 .36177 .61739 .38232 .614 .36989 Mtetra
0 0 .297 r
.614 .36989 .61739 .38232 .62481 .41755 .62099 .39213 Mtetra
.248 .184 .585 r
.62099 .39213 .62481 .41755 .63177 .43383 .62788 .40795 Mtetra
.192 .144 .571 r
.62788 .40795 .63177 .43383 .6384 .43817 .63495 .42629 Mtetra
.617 .511 .711 r
.63495 .42629 .6384 .43817 .64512 .44381 .64138 .4242 Mtetra
.618 .461 .646 r
.64138 .4242 .64512 .44381 .65113 .42993 .64776 .42055 Mtetra
.561 .513 .759 r
.64776 .42055 .65113 .42993 .65743 .42396 .6543 .42045 Mtetra
.9 .802 .742 r
.6543 .42045 .65743 .42396 .66314 .40437 .66043 .41028 Mtetra
.791 .826 .353 r
.66043 .41028 .66314 .40437 .66896 .38838 .66629 .39416 Mtetra
.775 .821 .348 r
.66629 .39416 .66896 .38838 .67488 .37551 .67213 .37861 Mtetra
.585 .843 .486 r
.67213 .37861 .67488 .37551 .68115 .37025 .67832 .3711 Mtetra
.342 .811 .729 r
.67832 .3711 .68115 .37025 .68709 .35855 .68474 .36841 Mtetra
0 0 .021 r
.68474 .36841 .68709 .35855 .69348 .35569 .69056 .35399 Mtetra
.841 .919 .886 r
.69056 .35399 .69348 .35569 .69928 .34211 .69683 .34856 Mtetra
0 0 0 r
.69683 .34856 .69928 .34211 .70621 .34876 .70274 .3367 Mtetra
.671 .54 .697 r
.70274 .3367 .70621 .34876 .71271 .34731 .70906 .33214 Mtetra
.662 .51 .668 r
.70906 .33214 .71271 .34731 .71892 .34073 .71533 .32688 Mtetra
.604 .483 .688 r
.71533 .32688 .71892 .34073 .7244 .32277 .72182 .325 Mtetra
.402 0 0 r
.72182 .325 .7244 .32277 .73075 .31893 .7285 .32586 Mtetra
.6 .202 .262 r
.7285 .32586 .73075 .31893 .738 .32831 .73537 .32911 Mtetra
.361 0 0 r
.73537 .32911 .738 .32831 .74537 .33839 .74216 .33066 Mtetra
.323 .407 .793 r
.74216 .33066 .74537 .33839 .75193 .33624 .74916 .33467 Mtetra
.005 .528 .854 r
.74916 .33467 .75193 .33624 .75866 .33622 .75603 .33633 Mtetra
.741 .993 .849 r
.75603 .33633 .75866 .33622 .76563 .3391 .76242 .33127 Mtetra
.481 .501 .801 r
.76242 .33127 .76563 .3391 .7724 .33885 .76932 .33274 Mtetra
.422 .523 .855 r
.76932 .33274 .7724 .33885 .77865 .33191 .77628 .33454 Mtetra
0 0 0 r
.77628 .33454 .77865 .33191 .78545 .33165 .7828 .33059 Mtetra
.28 .754 .937 r
.7828 .33059 .78545 .33165 .79174 .32511 .78963 .33017 Mtetra
.296 0 .058 r
.78963 .33017 .79174 .32511 .79792 .31726 .79633 .32798 Mtetra
.141 0 .226 r
.79633 .32798 .79792 .31726 .80401 .30861 .80242 .31876 Mtetra
.429 .094 .294 r
.80242 .31876 .80401 .30861 .81031 .30231 .80913 .31656 Mtetra
.474 .169 .366 r
.80913 .31656 .81031 .30231 .8188 .31957 .81589 .31469 Mtetra
.109 .381 .84 r
.81589 .31469 .8188 .31957 .82607 .32291 .82328 .31919 Mtetra
.48 .681 .954 r
.82328 .31919 .82607 .32291 .83284 .32074 .83027 .31924 Mtetra
.192 .67 .933 r
.83027 .31924 .83284 .32074 .83925 .31481 .83735 .31978 Mtetra
.795 .369 .236 r
.83735 .31978 .83925 .31481 .84736 .32558 .84565 .33215 Mtetra
.108 0 .086 r
.84565 .33215 .84736 .32558 .8544 .32532 .85211 .32599 Mtetra
.08 0 0 r
.85211 .32599 .8544 .32532 .8617 .32723 .85919 .32572 Mtetra
.318 .754 .968 r
.85919 .32572 .8617 .32723 .86901 .32897 .8663 .32546 Mtetra
.426 0 0 r
.25172 .50284 .25543 .50565 .26109 .50197 .25679 .50667 Mtetra
.86 .961 .626 r
.25679 .50667 .26109 .50197 .26752 .48861 .26297 .49681 Mtetra
.574 .218 .327 r
.26297 .49681 .26752 .48861 .27317 .48495 .26822 .49874 Mtetra
.068 0 .171 r
.26822 .49874 .27317 .48495 .27911 .47758 .27435 .48936 Mtetra
0 0 0 r
.27435 .48936 .27911 .47758 .28464 .47575 .2806 .47821 Mtetra
.896 .988 .754 r
.2806 .47821 .28464 .47575 .2902 .47363 .2866 .47023 Mtetra
.85 .395 .008 r
.2866 .47023 .2902 .47363 .29485 .48465 .29137 .4794 Mtetra
.737 .681 .796 r
.29137 .4794 .29485 .48465 .30022 .48593 .29712 .47534 Mtetra
.786 .613 .667 r
.29712 .47534 .30022 .48593 .30687 .46828 .3034 .46322 Mtetra
.812 .705 .747 r
.3034 .46322 .30687 .46828 .31311 .45632 .30937 .45566 Mtetra
.808 .337 .101 r
.30937 .45566 .31311 .45632 .31795 .46625 .31439 .46274 Mtetra
.339 .607 .947 r
.31439 .46274 .31795 .46625 .32254 .48103 .31983 .46377 Mtetra
.63 .475 .653 r
.31983 .46377 .32254 .48103 .32875 .46986 .32558 .46004 Mtetra
0 .082 .619 r
.32558 .46004 .32875 .46986 .33461 .4643 .33063 .46827 Mtetra
.924 .961 .649 r
.33063 .46827 .33461 .4643 .34058 .45694 .33683 .45714 Mtetra
.955 .838 .688 r
.33683 .45714 .34058 .45694 .34689 .44302 .3432 .44273 Mtetra
.864 .449 .237 r
.3432 .44273 .34689 .44302 .3519 .45319 .34818 .45338 Mtetra
.606 .052 0 r
.34818 .45338 .3519 .45319 .35749 .45316 .35361 .45667 Mtetra
.545 .087 .115 r
.35361 .45667 .35749 .45316 .36284 .45826 .35914 .45838 Mtetra
.875 .957 .855 r
.35914 .45838 .36284 .45826 .36875 .45237 .36508 .4523 Mtetra
.732 .969 .934 r
.36508 .4523 .36875 .45237 .3744 .45218 .3709 .44868 Mtetra
.662 .744 .911 r
.3709 .44868 .3744 .45218 .37996 .45443 .37665 .44678 Mtetra
.637 .578 .772 r
.37665 .44678 .37996 .45443 .38579 .45092 .38241 .44487 Mtetra
.648 .626 .814 r
.38241 .44487 .38579 .45092 .39131 .45525 .38819 .44296 Mtetra
.766 .591 .661 r
.38819 .44296 .39131 .45525 .39782 .43494 .39436 .43142 Mtetra
.526 .696 .946 r
.39436 .43142 .39782 .43494 .40382 .42676 .40008 .43109 Mtetra
.927 .945 .601 r
.40008 .43109 .40382 .42676 .40966 .4232 .40627 .41849 Mtetra
.772 .716 .8 r
.40627 .41849 .40966 .4232 .4155 .41954 .41216 .41353 Mtetra
0 .144 .689 r
.41216 .41353 .4155 .41954 .42116 .42203 .4177 .41953 Mtetra
.854 .82 .814 r
.4177 .41953 .42116 .42203 .42678 .4265 .42367 .41297 Mtetra
0 .052 .573 r
.42367 .41297 .42678 .4265 .43236 .4336 .4291 .42462 Mtetra
.826 .65 .663 r
.4291 .42462 .43236 .4336 .43844 .42348 .4353 .41042 Mtetra
.679 .532 .679 r
.4353 .41042 .43844 .42348 .44436 .41969 .44125 .40511 Mtetra
.595 .467 .676 r
.44125 .40511 .44436 .41969 .45048 .40677 .4471 .40362 Mtetra
.534 .726 .962 r
.4471 .40362 .45048 .40677 .45634 .40555 .45294 .40307 Mtetra
.779 .834 .894 r
.45294 .40307 .45634 .40555 .46214 .40786 .45888 .39911 Mtetra
.258 .331 .748 r
.45888 .39911 .46214 .40786 .46804 .40589 .46465 .40386 Mtetra
.893 .839 .785 r
.46465 .40386 .46804 .40589 .47403 .39938 .47069 .39569 Mtetra
.74 .759 .868 r
.47069 .39569 .47403 .39938 .47995 .39693 .47664 .39224 Mtetra
0 .047 .597 r
.47664 .39224 .47995 .39693 .48577 .40415 .48246 .39864 Mtetra
.754 .689 .79 r
.48246 .39864 .48577 .40415 .49171 .40503 .48846 .39387 Mtetra
.617 .513 .714 r
.48846 .39387 .49171 .40503 .49769 .40291 .49444 .39196 Mtetra
0 0 .466 r
.49444 .39196 .49769 .40291 .50363 .40941 .5003 .40574 Mtetra
.82 .368 0 r
.5003 .40574 .50363 .40941 .5096 .41694 .50626 .4171 Mtetra
.912 .538 .304 r
.50626 .4171 .5096 .41694 .51557 .44407 .51224 .43773 Mtetra
.967 .645 .323 r
.51224 .43773 .51557 .44407 .52166 .48094 .51827 .48529 Mtetra
.905 .571 .4 r
.51827 .48529 .52166 .48094 .52792 .53872 .52449 .5188 Mtetra
.398 .309 .637 r
.52449 .5188 .52792 .53872 .53427 .54259 .53082 .52573 Mtetra
.551 .429 .668 r
.53082 .52573 .53427 .54259 .54059 .53357 .53717 .52609 Mtetra
.427 .481 .813 r
.53717 .52609 .54059 .53357 .54698 .53498 .54356 .52815 Mtetra
0 .179 .71 r
.54356 .52815 .54698 .53498 .55356 .55613 .55001 .53504 Mtetra
.494 .371 .641 r
.55001 .53504 .55356 .55613 .56003 .55759 .55648 .53836 Mtetra
.667 .497 .645 r
.55648 .53836 .56003 .55759 .56633 .54188 .56286 .53129 Mtetra
.827 .642 .653 r
.56286 .53129 .56633 .54188 .57259 .52681 .56913 .5155 Mtetra
.825 .635 .646 r
.56913 .5155 .57259 .52681 .57882 .51174 .57534 .49895 Mtetra
.851 .639 .615 r
.57534 .49895 .57882 .51174 .58474 .48175 .58139 .47515 Mtetra
.923 .712 .598 r
.58139 .47515 .58474 .48175 .59063 .45485 .5873 .44771 Mtetra
.93 .705 .576 r
.5873 .44771 .59063 .45485 .59639 .42578 .593 .41418 Mtetra
.903 .668 .573 r
.593 .41418 .59639 .42578 .60194 .39144 .59849 .37668 Mtetra
.834 .617 .609 r
.59849 .37668 .60194 .39144 .60743 .35949 .60421 .35314 Mtetra
.758 .375 0 r
.60421 .35314 .60743 .35949 .614 .36989 .61093 .36928 Mtetra
.899 .486 .191 r
.61093 .36928 .614 .36989 .62099 .39213 .61777 .38655 Mtetra
.896 .515 .063 r
.61777 .38655 .62099 .39213 .62788 .40795 .62487 .40955 Mtetra
.396 0 0 r
.62487 .40955 .62788 .40795 .63495 .42629 .63138 .41069 Mtetra
.405 .341 .672 r
.63138 .41069 .63495 .42629 .64138 .4242 .63806 .41622 Mtetra
.538 .53 .794 r
.63806 .41622 .64138 .4242 .64776 .42055 .64459 .41653 Mtetra
.811 .779 .823 r
.64459 .41653 .64776 .42055 .6543 .42045 .65091 .41074 Mtetra
.861 .664 .636 r
.65091 .41074 .6543 .42045 .66043 .41028 .65672 .3924 Mtetra
.597 .454 .658 r
.65672 .3924 .66043 .41028 .66629 .39416 .66317 .39031 Mtetra
.931 .778 .669 r
.66317 .39031 .66629 .39416 .67213 .37861 .66905 .37516 Mtetra
.9 .807 .746 r
.66905 .37516 .67213 .37861 .67832 .3711 .67515 .36526 Mtetra
.883 .729 .686 r
.67515 .36526 .67832 .3711 .68474 .36841 .68106 .3522 Mtetra
.734 .549 .643 r
.68106 .3522 .68474 .36841 .69056 .35399 .68704 .34096 Mtetra
.764 .587 .657 r
.68704 .34096 .69056 .35399 .69683 .34856 .69299 .32957 Mtetra
.589 .443 .65 r
.69299 .32957 .69683 .34856 .70274 .3367 .69945 .3278 Mtetra
.595 .54 .763 r
.69945 .3278 .70274 .3367 .70906 .33214 .70597 .32678 Mtetra
.895 .744 .687 r
.70597 .32678 .70906 .33214 .71533 .32688 .7118 .31377 Mtetra
.619 .499 .694 r
.7118 .31377 .71533 .32688 .72182 .325 .71824 .31132 Mtetra
.533 .44 .696 r
.71824 .31132 .72182 .325 .7285 .32586 .72492 .31229 Mtetra
.427 .373 .695 r
.72492 .31229 .7285 .32586 .73537 .32911 .73185 .31668 Mtetra
.716 .564 .681 r
.73185 .31668 .73537 .32911 .74216 .33066 .73803 .30936 Mtetra
.084 .091 .568 r
.73803 .30936 .74216 .33066 .74916 .33467 .74611 .32925 Mtetra
0 0 .368 r
.74611 .32925 .74916 .33467 .75603 .33633 .75382 .34255 Mtetra
.812 .791 .292 r
.75382 .34255 .75603 .33633 .76242 .33127 .75912 .32239 Mtetra
.762 .632 .716 r
.75912 .32239 .76242 .33127 .76932 .33274 .76534 .31489 Mtetra
.32 .272 .646 r
.76534 .31489 .76932 .33274 .77628 .33454 .7729 .32465 Mtetra
.716 .594 .718 r
.7729 .32465 .77628 .33454 .7828 .33059 .77927 .31883 Mtetra
.378 .365 .718 r
.77927 .31883 .7828 .33059 .78963 .33017 .78655 .32393 Mtetra
.651 .643 .829 r
.78655 .32393 .78963 .33017 .79633 .32798 .79326 .32173 Mtetra
.8 .707 .762 r
.79326 .32173 .79633 .32798 .80242 .31876 .79955 .31469 Mtetra
.661 .744 .912 r
.79955 .31469 .80242 .31876 .80913 .31656 .80628 .31247 Mtetra
.302 .555 .923 r
.80628 .31247 .80913 .31656 .81589 .31469 .8134 .31446 Mtetra
.944 .96 .72 r
.8134 .31446 .81589 .31469 .82328 .31919 .81944 .30453 Mtetra
.372 .332 .683 r
.81944 .30453 .82328 .31919 .83027 .31924 .82707 .31122 Mtetra
.639 .589 .782 r
.82707 .31122 .83027 .31924 .83735 .31978 .83387 .30898 Mtetra
.007 .134 .648 r
.83387 .30898 .83735 .31978 .84565 .33215 .84215 .32129 Mtetra
.671 .559 .719 r
.84215 .32129 .84565 .33215 .85211 .32599 .84881 .31708 Mtetra
.43 .449 .778 r
.84881 .31708 .85211 .32599 .85919 .32572 .85623 .31994 Mtetra
.731 .7 .822 r
.85623 .31994 .85919 .32572 .8663 .32546 .86292 .31577 Mtetra
.435 .709 .981 r
.24799 .50011 .25172 .50284 .25679 .50667 .25336 .50016 Mtetra
.581 .577 .814 r
.25336 .50016 .25679 .50667 .26297 .49681 .2588 .49962 Mtetra
.053 0 0 r
.2588 .49962 .26297 .49681 .26822 .49874 .26436 .49779 Mtetra
.911 .84 .762 r
.26436 .49779 .26822 .49874 .27435 .48936 .27052 .48833 Mtetra
.779 .908 .93 r
.27052 .48833 .27435 .48936 .2806 .47821 .27623 .48462 Mtetra
.956 .925 .577 r
.27623 .48462 .2806 .47821 .2866 .47023 .28285 .46864 Mtetra
.735 .208 0 r
.28285 .46864 .2866 .47023 .29137 .4794 .28789 .47414 Mtetra
.852 .705 .699 r
.28789 .47414 .29137 .4794 .29712 .47534 .29418 .46222 Mtetra
.751 .576 .659 r
.29418 .46222 .29712 .47534 .3034 .46322 .3004 .45125 Mtetra
0 0 .524 r
.3004 .45125 .3034 .46322 .30937 .45566 .30512 .4622 Mtetra
.475 .084 .219 r
.30512 .4622 .30937 .45566 .31439 .46274 .31062 .46219 Mtetra
.66 .932 .97 r
.31062 .46219 .31439 .46274 .31983 .46377 .3163 .4596 Mtetra
.515 .649 .918 r
.3163 .4596 .31983 .46377 .32558 .46004 .32182 .45957 Mtetra
.79 .946 .925 r
.32182 .45957 .32558 .46004 .33063 .46827 .32761 .4555 Mtetra
.755 .581 .66 r
.32761 .4555 .33063 .46827 .33683 .45714 .33381 .44456 Mtetra
.73 .567 .67 r
.33381 .44456 .33683 .45714 .3432 .44273 .33985 .43603 Mtetra
.071 .272 .761 r
.33985 .43603 .3432 .44273 .34818 .45338 .34515 .44077 Mtetra
.423 .37 .694 r
.34515 .44077 .34818 .45338 .35361 .45667 .35055 .44428 Mtetra
.612 .495 .696 r
.35055 .44428 .35361 .45667 .35914 .45838 .35625 .44238 Mtetra
.628 .48 .662 r
.35625 .44238 .35914 .45838 .36508 .4523 .36205 .43905 Mtetra
.644 .508 .683 r
.36205 .43905 .36508 .4523 .3709 .44868 .36785 .43554 Mtetra
.306 .286 .672 r
.36785 .43554 .3709 .44868 .37665 .44678 .37323 .44155 Mtetra
.722 .683 .811 r
.37323 .44155 .37665 .44678 .38241 .44487 .37907 .43797 Mtetra
.642 .599 .791 r
.37907 .43797 .38241 .44487 .38819 .44296 .38484 .43605 Mtetra
.38484 .43605 .38819 .44296 .39436 .43142 .39063 .43412 Mtetra
.56 .89 .633 r
.39063 .43412 .39436 .43142 .40008 .43109 .39656 .429 Mtetra
.395 .742 .992 r
.39656 .429 .40008 .43109 .40627 .41849 .4023 .4289 Mtetra
.011 0 .099 r
.4023 .4289 .40627 .41849 .41216 .41353 .40835 .42052 Mtetra
.206 0 .089 r
.40835 .42052 .41216 .41353 .4177 .41953 .41424 .41673 Mtetra
.808 .81 .853 r
.41424 .41673 .4177 .41953 .42367 .41297 .42017 .41184 Mtetra
.83 .914 .894 r
.42017 .41184 .42367 .41297 .4291 .42462 .4261 .40697 Mtetra
.634 .476 .651 r
.4261 .40697 .4291 .42462 .4353 .41042 .43201 .40285 Mtetra
.275 .374 .783 r
.43201 .40285 .4353 .41042 .44125 .40511 .43771 .40667 Mtetra
.836 .426 .265 r
.43771 .40667 .44125 .40511 .4471 .40362 .44327 .41748 Mtetra
.397 .095 .332 r
.44327 .41748 .4471 .40362 .45294 .40307 .44923 .41366 Mtetra
0 0 0 r
.44923 .41366 .45294 .40307 .45888 .39911 .45543 .39905 Mtetra
.871 .965 .856 r
.45543 .39905 .45888 .39911 .46465 .40386 .46143 .39298 Mtetra
.632 .525 .715 r
.46143 .39298 .46465 .40386 .47069 .39569 .46736 .39056 Mtetra
.635 .659 .856 r
.46736 .39056 .47069 .39569 .47664 .39224 .47328 .38897 Mtetra
0 .259 .739 r
.47328 .38897 .47664 .39224 .48246 .39864 .47915 .39287 Mtetra
.707 .665 .806 r
.47915 .39287 .48246 .39864 .48846 .39387 .48514 .3895 Mtetra
0 0 .492 r
.48514 .3895 .48846 .39387 .49444 .39196 .49102 .39661 Mtetra
.725 .32 .282 r
.49102 .39661 .49444 .39196 .5003 .40574 .49696 .4034 Mtetra
.549 .004 0 r
.49696 .4034 .5003 .40574 .50626 .4171 .50295 .40868 Mtetra
.922 .579 .126 r
.50295 .40868 .50626 .4171 .51224 .43773 .50888 .436 Mtetra
.946 .605 .338 r
.50888 .436 .51224 .43773 .51827 .48529 .5149 .47033 Mtetra
.711 .453 0 r
.5149 .47033 .51827 .48529 .52449 .5188 .52109 .49863 Mtetra
.357 .278 .629 r
.52109 .49863 .52449 .5188 .53082 .52573 .52739 .50704 Mtetra
.253 .215 .62 r
.52739 .50704 .53082 .52573 .53717 .52609 .53375 .51783 Mtetra
.532 .521 .789 r
.53375 .51783 .53717 .52609 .54356 .52815 .54012 .51826 Mtetra
.207 .285 .724 r
.54012 .51826 .54356 .52815 .55001 .53504 .54656 .52459 Mtetra
.351 .368 .738 r
.54656 .52459 .55001 .53504 .55648 .53836 .55303 .52905 Mtetra
.863 .67 .639 r
.55303 .52905 .55648 .53836 .56286 .53129 .55929 .50977 Mtetra
.679 .496 .632 r
.55929 .50977 .56286 .53129 .56913 .5155 .56563 .50067 Mtetra
.791 .594 .635 r
.56563 .50067 .56913 .5155 .57534 .49895 .57184 .48407 Mtetra
.867 .638 .59 r
.57184 .48407 .57534 .49895 .58139 .47515 .57776 .4514 Mtetra
.794 .568 .595 r
.57776 .4514 .58139 .47515 .5873 .44771 .58365 .42341 Mtetra
.8 .571 .591 r
.58365 .42341 .5873 .44771 .593 .41418 .58942 .39352 Mtetra
.847 .609 .578 r
.58942 .39352 .593 .41418 .59849 .37668 .59492 .35559 Mtetra
.317 .246 .617 r
.59492 .35559 .59849 .37668 .60421 .35314 .60145 .36612 Mtetra
.577 .251 .379 r
.60145 .36612 .60421 .35314 .61093 .36928 .60785 .36879 Mtetra
.786 .287 0 r
.60785 .36879 .61093 .36928 .61777 .38655 .61444 .37733 Mtetra
.806 .47 0 r
.61444 .37733 .61777 .38655 .62487 .40955 .62157 .40198 Mtetra
.073 .251 .741 r
.62157 .40198 .62487 .40955 .63138 .41069 .62824 .40851 Mtetra
.841 .381 0 r
.62824 .40851 .63138 .41069 .63806 .41622 .63518 .42131 Mtetra
.745 .335 .272 r
.63518 .42131 .63806 .41622 .64459 .41653 .64203 .42987 Mtetra
0 0 .108 r
.64203 .42987 .64459 .41653 .65091 .41074 .64798 .41305 Mtetra
1 .833 .517 r
.64798 .41305 .65091 .41074 .65672 .3924 .65352 .38691 Mtetra
.794 .719 .781 r
.65352 .38691 .65672 .3924 .66317 .39031 .6598 .38062 Mtetra
.803 .639 .679 r
.6598 .38062 .66317 .39031 .66905 .37516 .66586 .36931 Mtetra
.876 .728 .695 r
.66586 .36931 .66905 .37516 .67515 .36526 .67185 .35701 Mtetra
.866 .683 .652 r
.67185 .35701 .67515 .36526 .68106 .3522 .67765 .34109 Mtetra
.823 .634 .647 r
.67765 .34109 .68106 .3522 .68704 .34096 .68343 .32595 Mtetra
.63 .491 .674 r
.68343 .32595 .68704 .34096 .69299 .32957 .6898 .32254 Mtetra
.606 .59 .809 r
.6898 .32254 .69299 .32957 .69945 .3278 .69629 .32133 Mtetra
.582 .595 .831 r
.69629 .32133 .69945 .3278 .70597 .32678 .70283 .32062 Mtetra
.868 .721 .697 r
.70283 .32062 .70597 .32678 .7118 .31377 .70875 .30888 Mtetra
.695 .709 .859 r
.70875 .30888 .7118 .31377 .71824 .31132 .71518 .306 Mtetra
.658 .675 .855 r
.71518 .306 .71824 .31132 .72492 .31229 .72166 .30382 Mtetra
.589 .546 .775 r
.72166 .30382 .72492 .31229 .73185 .31668 .72824 .30295 Mtetra
.355 .325 .687 r
.72824 .30295 .73185 .31668 .73803 .30936 .73534 .30936 Mtetra
.83 .356 .045 r
.73534 .30936 .73803 .30936 .74611 .32925 .74287 .32135 Mtetra
.519 .522 .798 r
.74287 .32135 .74611 .32925 .75382 .34255 .74967 .32204 Mtetra
.689 .503 .63 r
.74967 .32204 .75382 .34255 .75912 .32239 .75574 .31236 Mtetra
.204 .278 .719 r
.75574 .31236 .75912 .32239 .76534 .31489 .76309 .3198 Mtetra
.693 .257 .209 r
.76309 .3198 .76534 .31489 .7729 .32465 .77041 .32617 Mtetra
.612 .915 .649 r
.77041 .32617 .7729 .32465 .77927 .31883 .7768 .32026 Mtetra
.399 0 0 r
.7768 .32026 .77927 .31883 .78655 .32393 .7838 .32176 Mtetra
.415 .761 .995 r
.7838 .32176 .78655 .32393 .79326 .32173 .79068 .32143 Mtetra
.733 .988 .885 r
.79068 .32143 .79326 .32173 .79955 .31469 .7972 .31674 Mtetra
.259 0 0 r
.7972 .31674 .79955 .31469 .80628 .31247 .80413 .31646 Mtetra
.628 .158 .119 r
.80413 .31646 .80628 .31247 .8134 .31446 .81149 .32071 Mtetra
0 0 0 r
.81149 .32071 .8134 .31446 .81944 .30453 .81718 .30669 Mtetra
.49 .817 .511 r
.81718 .30669 .81944 .30453 .82707 .31122 .8236 .30054 Mtetra
.624 .533 .731 r
.8236 .30054 .82707 .31122 .83387 .30898 .83039 .29829 Mtetra
.21 .273 .711 r
.83039 .29829 .83387 .30898 .84215 .32129 .83826 .30651 Mtetra
.518 .425 .69 r
.83826 .30651 .84215 .32129 .84881 .31708 .84551 .30819 Mtetra
.523 .506 .779 r
.84551 .30819 .84881 .31708 .85623 .31994 .8527 .30895 Mtetra
.669 .556 .718 r
.8527 .30895 .85623 .31994 .86292 .31577 .8594 .30477 Mtetra
.833 .818 .835 r
.24419 .4979 .24799 .50011 .25336 .50016 .25004 .49232 Mtetra
.165 .293 .75 r
.25004 .49232 .25336 .50016 .2588 .49962 .25507 .49685 Mtetra
.766 .796 .877 r
.25507 .49685 .2588 .49962 .26436 .49779 .26078 .49314 Mtetra
.779 .711 .788 r
.26078 .49314 .26436 .49779 .27052 .48833 .26663 .48781 Mtetra
.358 0 0 r
.26663 .48781 .27052 .48833 .27623 .48462 .27193 .48962 Mtetra
.98 .915 .624 r
.27193 .48962 .27623 .48462 .28285 .46864 .2786 .47347 Mtetra
.441 .009 .121 r
.2786 .47347 .28285 .46864 .28789 .47414 .28405 .47345 Mtetra
.93 .828 .722 r
.28405 .47345 .28789 .47414 .29418 .46222 .29038 .4615 Mtetra
.915 .857 .771 r
.29038 .4615 .29418 .46222 .3004 .45125 .29648 .45242 Mtetra
.493 .902 .81 r
.29648 .45242 .3004 .45125 .30512 .4622 .30215 .44953 Mtetra
.311 .292 .677 r
.30215 .44953 .30512 .4622 .31062 .46219 .30727 .45502 Mtetra
.092 .269 .752 r
.30727 .45502 .31062 .46219 .3163 .4596 .31247 .45983 Mtetra
.909 .931 .815 r
.31247 .45983 .3163 .4596 .32182 .45957 .31847 .45241 Mtetra
.799 .659 .709 r
.31847 .45241 .32182 .45957 .32761 .4555 .32457 .44333 Mtetra
.716 .561 .678 r
.32457 .44333 .32761 .4555 .33381 .44456 .33055 .43613 Mtetra
.718 .603 .727 r
.33055 .43613 .33381 .44456 .33985 .43603 .33639 .43102 Mtetra
.399 .548 .887 r
.33639 .43102 .33985 .43603 .34515 .44077 .34188 .43232 Mtetra
.364 .403 .768 r
.34188 .43232 .34515 .44077 .35055 .44428 .3473 .43536 Mtetra
.718 .597 .72 r
.3473 .43536 .35055 .44428 .35625 .44238 .35319 .42997 Mtetra
.397 .355 .695 r
.35319 .42997 .35625 .44238 .36205 .43905 .3586 .43393 Mtetra
.655 .662 .845 r
.3586 .43393 .36205 .43905 .36785 .43554 .36434 .43201 Mtetra
.023 .417 .861 r
.36434 .43201 .36785 .43554 .37323 .44155 .36987 .43471 Mtetra
.087 .279 .763 r
.36987 .43471 .37323 .44155 .37907 .43797 .37533 .43952 Mtetra
.485 0 0 r
.37533 .43952 .37907 .43797 .38484 .43605 .38096 .44116 Mtetra
.972 .914 .579 r
.38096 .44116 .38484 .43605 .39063 .43412 .3874 .42435 Mtetra
0 .004 .57 r
.3874 .42435 .39063 .43412 .39656 .429 .39273 .43401 Mtetra
.829 .477 .389 r
.39273 .43401 .39656 .429 .4023 .4289 .3979 .44913 Mtetra
.057 0 .247 r
.3979 .44913 .4023 .4289 .40835 .42052 .40426 .4339 Mtetra
.064 0 .18 r
.40426 .4339 .40835 .42052 .41424 .41673 .41041 .42393 Mtetra
0 0 0 r
.41041 .42393 .41424 .41673 .42017 .41184 .41646 .41616 Mtetra
.349 0 .025 r
.41646 .41616 .42017 .41184 .4261 .40697 .42229 .41533 Mtetra
.595 .233 .325 r
.42229 .41533 .4261 .40697 .43201 .40285 .42803 .41813 Mtetra
.468 .167 .372 r
.42803 .41813 .43201 .40285 .43771 .40667 .43393 .41616 Mtetra
.615 .266 .355 r
.43393 .41616 .43771 .40667 .44327 .41748 .43969 .41986 Mtetra
.666 .945 .687 r
.43969 .41986 .44327 .41748 .44923 .41366 .44572 .4141 Mtetra
.968 .878 .691 r
.44572 .4141 .44923 .41366 .45543 .39905 .45192 .40081 Mtetra
.484 .877 .701 r
.45192 .40081 .45543 .39905 .46143 .39298 .45789 .39697 Mtetra
.731 .912 .547 r
.45789 .39697 .46143 .39298 .46736 .39056 .46396 .38828 Mtetra
.457 0 0 r
.46396 .38828 .46736 .39056 .47328 .38897 .4698 .39261 Mtetra
0 0 0 r
.4698 .39261 .47328 .38897 .47915 .39287 .47581 .38775 Mtetra
.167 .41 .851 r
.47581 .38775 .47915 .39287 .48514 .3895 .48172 .39103 Mtetra
.28 0 0 r
.48172 .39103 .48514 .3895 .49102 .39661 .48769 .39123 Mtetra
0 .088 .643 r
.48769 .39123 .49102 .39661 .49696 .4034 .49363 .3978 Mtetra
0 .148 .691 r
.49363 .3978 .49696 .4034 .50295 .40868 .49961 .40397 Mtetra
.953 .604 .268 r
.49961 .40397 .50295 .40868 .50888 .436 .50549 .43426 Mtetra
.946 .603 .336 r
.50549 .43426 .50888 .436 .5149 .47033 .5115 .4679 Mtetra
.909 .501 .168 r
.5115 .4679 .5149 .47033 .52109 .49863 .51769 .48489 Mtetra
.158 .189 .644 r
.51769 .48489 .52109 .49863 .52739 .50704 .52397 .49448 Mtetra
0 0 .347 r
.52397 .49448 .52739 .50704 .53375 .51783 .53032 .51335 Mtetra
.71 .73 .866 r
.53032 .51335 .53375 .51783 .54012 .51826 .53669 .51024 Mtetra
.689 .61 .763 r
.53669 .51024 .54012 .51826 .54656 .52459 .54306 .5065 Mtetra
.531 .409 .659 r
.54306 .5065 .54656 .52459 .55303 .52905 .54948 .50774 Mtetra
.603 .445 .64 r
.54948 .50774 .55303 .52905 .55929 .50977 .55589 .50481 Mtetra
.921 .739 .638 r
.55589 .50481 .55929 .50977 .56563 .50067 .56212 .48489 Mtetra
.819 .607 .616 r
.56212 .48489 .56563 .50067 .57184 .48407 .56826 .46253 Mtetra
.795 .574 .601 r
.56826 .46253 .57184 .48407 .57776 .4514 .57429 .43712 Mtetra
.851 .63 .604 r
.57429 .43712 .57776 .4514 .58365 .42341 .58023 .41061 Mtetra
.903 .663 .566 r
.58023 .41061 .58365 .42341 .58942 .39352 .58579 .36887 Mtetra
.759 .541 .602 r
.58579 .36887 .58942 .39352 .59492 .35559 .59163 .34719 Mtetra
.805 .458 0 r
.59163 .34719 .59492 .35559 .60145 .36612 .59842 .3691 Mtetra
.713 .255 .162 r
.59842 .3691 .60145 .36612 .60785 .36879 .60491 .37516 Mtetra
.726 .335 .309 r
.60491 .37516 .60785 .36879 .61444 .37733 .61151 .3833 Mtetra
.872 .513 .368 r
.61151 .3833 .61444 .37733 .62157 .40198 .61863 .4075 Mtetra
.746 .343 .289 r
.61863 .4075 .62157 .40198 .62824 .40851 .6254 .41631 Mtetra
.762 .389 .35 r
.6254 .41631 .62824 .40851 .63518 .42131 .63232 .42802 Mtetra
.677 .281 .289 r
.63232 .42802 .63518 .42131 .64203 .42987 .63911 .43407 Mtetra
.992 .842 .478 r
.63911 .43407 .64203 .42987 .64798 .41305 .64473 .40717 Mtetra
.908 .73 .65 r
.64473 .40717 .64798 .41305 .65352 .38691 .65063 .38992 Mtetra
.946 .917 .548 r
.65063 .38992 .65352 .38691 .6598 .38062 .65659 .3749 Mtetra
.923 .732 .626 r
.65659 .3749 .6598 .38062 .66586 .36931 .66229 .35483 Mtetra
.76 .575 .647 r
.66229 .35483 .66586 .36931 .67185 .35701 .66828 .34255 Mtetra
.78 .587 .639 r
.66828 .34255 .67185 .35701 .67765 .34109 .67414 .32813 Mtetra
.792 .603 .645 r
.67414 .32813 .67765 .34109 .68343 .32595 .67999 .31414 Mtetra
.341 .337 .709 r
.67999 .31414 .68343 .32595 .6898 .32254 .68682 .31976 Mtetra
.757 .845 .917 r
.68682 .31976 .6898 .32254 .69629 .32133 .69319 .31603 Mtetra
.633 .665 .863 r
.69319 .31603 .69629 .32133 .70283 .32062 .69968 .31435 Mtetra
.741 .678 .789 r
.69968 .31435 .70283 .32062 .70875 .30888 .70601 .30961 Mtetra
.292 .782 .725 r
.70601 .30961 .70875 .30888 .71518 .306 .7125 .30727 Mtetra
0 0 0 r
.7125 .30727 .71518 .306 .72166 .30382 .71897 .30454 Mtetra
.698 .977 .788 r
.71897 .30454 .72166 .30382 .72824 .30295 .72529 .29929 Mtetra
.866 .453 .003 r
.72529 .29929 .72824 .30295 .73534 .30936 .73331 .3195 Mtetra
.423 .086 .286 r
.73331 .3195 .73534 .30936 .74287 .32135 .7399 .31731 Mtetra
0 0 .539 r
.7399 .31731 .74287 .32135 .74967 .32204 .74725 .32571 Mtetra
.813 .874 .436 r
.74725 .32571 .74967 .32204 .75574 .31236 .7531 .31249 Mtetra
.569 0 0 r
.7531 .31249 .75574 .31236 .76309 .3198 .76023 .31694 Mtetra
.557 .059 0 r
.76023 .31694 .76309 .3198 .77041 .32617 .7677 .32513 Mtetra
.259 .742 .928 r
.7677 .32513 .77041 .32617 .7768 .32026 .77455 .32479 Mtetra
.16 0 0 r
.77455 .32479 .7768 .32026 .7838 .32176 .78119 .32148 Mtetra
.438 .874 .895 r
.78119 .32148 .7838 .32176 .79068 .32143 .78793 .31926 Mtetra
.781 .307 0 r
.78793 .31926 .79068 .32143 .7972 .31674 .796 .33239 Mtetra
.551 .236 .388 r
.796 .33239 .7972 .31674 .80413 .31646 .80315 .33407 Mtetra
.374 .105 .372 r
.80315 .33407 .80413 .31646 .81149 .32071 .80956 .32712 Mtetra
0 0 0 r
.80956 .32712 .81149 .32071 .81718 .30669 .81547 .315 Mtetra
.81547 .315 .81718 .30669 .8236 .30054 .82082 .29709 Mtetra
.659 .786 .942 r
.82082 .29709 .8236 .30054 .83039 .29829 .82763 .29483 Mtetra
.562 .744 .962 r
.82763 .29483 .83039 .29829 .83826 .30651 .83458 .29383 Mtetra
.566 .474 .71 r
.83458 .29383 .83826 .30651 .84551 .30819 .84162 .29352 Mtetra
.654 .511 .677 r
.84162 .29352 .84551 .30819 .8527 .30895 .84823 .2888 Mtetra
.562 .423 .649 r
.84823 .2888 .8527 .30895 .8594 .30477 .85531 .28846 Mtetra
.673 .516 .665 r
.24145 .48317 .24419 .4979 .25004 .49232 .24729 .47761 Mtetra
.584 .457 .673 r
.24729 .47761 .25004 .49232 .25507 .49685 .25276 .47656 Mtetra
.589 .433 .638 r
.25276 .47656 .25507 .49685 .26078 .49314 .2583 .47471 Mtetra
.432 .329 .637 r
.2583 .47471 .26078 .49314 .26663 .48781 .26335 .47928 Mtetra
.756 .62 .708 r
.26335 .47928 .26663 .48781 .27193 .48962 .26936 .4719 Mtetra
.556 .421 .651 r
.26936 .4719 .27193 .48962 .2786 .47347 .27481 .47188 Mtetra
.633 .861 .985 r
.27481 .47188 .2786 .47347 .28405 .47345 .2804 .47002 Mtetra
.808 .764 .812 r
.2804 .47002 .28405 .47345 .29038 .4615 .28628 .46448 Mtetra
.639 .93 .669 r
.28628 .46448 .29038 .4615 .29648 .45242 .29215 .45897 Mtetra
.337 0 .133 r
.29215 .45897 .29648 .45242 .30215 .44953 .29778 .45709 Mtetra
.762 .424 .412 r
.29778 .45709 .30215 .44953 .30727 .45502 .30254 .46809 Mtetra
.564 .247 .389 r
.30254 .46809 .30727 .45502 .31247 .45983 .30796 .46995 Mtetra
0 0 0 r
.30796 .46995 .31247 .45983 .31847 .45241 .31442 .45602 Mtetra
.983 .903 .644 r
.31442 .45602 .31847 .45241 .32457 .44333 .32096 .44031 Mtetra
.848 .782 .787 r
.32096 .44031 .32457 .44333 .33055 .43613 .32695 .43318 Mtetra
.85 .786 .788 r
.32695 .43318 .33055 .43613 .33639 .43102 .33293 .42605 Mtetra
.675 .674 .842 r
.33293 .42605 .33639 .43102 .34188 .43232 .33862 .42376 Mtetra
.214 .305 .742 r
.33862 .42376 .34188 .43232 .3473 .43536 .34394 .42849 Mtetra
.704 .628 .769 r
.34394 .42849 .3473 .43536 .35319 .42997 .34974 .42476 Mtetra
.552 .615 .869 r
.34974 .42476 .35319 .42997 .3586 .43393 .35537 .42451 Mtetra
.626 .54 .737 r
.35537 .42451 .3586 .43393 .36434 .43201 .36111 .42258 Mtetra
.796 .468 0 r
.36111 .42258 .36434 .43201 .36987 .43471 .36592 .43965 Mtetra
0 0 0 r
.36592 .43965 .36987 .43471 .37533 .43952 .37188 .43424 Mtetra
0 .182 .715 r
.37188 .43424 .37533 .43952 .38096 .44116 .37736 .43939 Mtetra
.635 .857 .984 r
.37736 .43939 .38096 .44116 .3874 .42435 .38318 .43745 Mtetra
.63 .309 .409 r
.38318 .43745 .3874 .42435 .39273 .43401 .38872 .44253 Mtetra
.622 .264 .342 r
.38872 .44253 .39273 .43401 .3979 .44913 .39435 .44629 Mtetra
.93 .756 .645 r
.39435 .44629 .3979 .44913 .40426 .4339 .40091 .42653 Mtetra
.639 .589 .782 r
.40091 .42653 .40426 .4339 .41041 .42393 .40678 .42458 Mtetra
.971 .853 .666 r
.40678 .42458 .41041 .42393 .41646 .41616 .41313 .40891 Mtetra
.282 .39 .796 r
.41313 .40891 .41646 .41616 .42229 .41533 .41881 .41241 Mtetra
.596 .071 0 r
.41881 .41241 .42229 .41533 .42803 .41813 .42446 .41827 Mtetra
.435 .873 .89 r
.42446 .41827 .42803 .41813 .43393 .41616 .43037 .4163 Mtetra
.903 .954 .821 r
.43037 .4163 .43393 .41616 .43969 .41986 .43645 .40908 Mtetra
.56 .484 .726 r
.43645 .40908 .43969 .41986 .44572 .4141 .44233 .40899 Mtetra
.748 .701 .807 r
.44233 .40899 .44572 .4141 .45192 .40081 .44833 .40463 Mtetra
.943 .941 .605 r
.44833 .40463 .45192 .40081 .45789 .39697 .45453 .39144 Mtetra
.799 .703 .758 r
.45453 .39144 .45789 .39697 .46396 .38828 .46058 .38459 Mtetra
.663 .742 .908 r
.46058 .38459 .46396 .38828 .4698 .39261 .46653 .38258 Mtetra
.502 .459 .742 r
.46653 .38258 .4698 .39261 .47581 .38775 .47245 .38387 Mtetra
.648 .727 .906 r
.47245 .38387 .47581 .38775 .48172 .39103 .47843 .38208 Mtetra
.156 .262 .723 r
.47843 .38208 .48172 .39103 .48769 .39123 .48432 .38813 Mtetra
.86 .416 .019 r
.48432 .38813 .48769 .39123 .49363 .3978 .4902 .40032 Mtetra
.782 .352 .228 r
.4902 .40032 .49363 .3978 .49961 .40397 .49617 .40869 Mtetra
.897 .561 .403 r
.49617 .40869 .49961 .40397 .50549 .43426 .50205 .43912 Mtetra
.892 .553 .399 r
.50205 .43912 .50549 .43426 .5115 .4679 .50806 .46822 Mtetra
.234 0 0 r
.50806 .46822 .5115 .4679 .51769 .48489 .5143 .46911 Mtetra
0 0 .48 r
.5143 .46911 .51769 .48489 .52397 .49448 .52054 .48676 Mtetra
0 .121 .666 r
.52054 .48676 .52397 .49448 .53032 .51335 .52687 .49469 Mtetra
.515 .395 .655 r
.52687 .49469 .53032 .51335 .53669 .51024 .53323 .4966 Mtetra
.635 .506 .689 r
.53323 .4966 .53669 .51024 .54306 .5065 .5396 .49335 Mtetra
.735 .571 .67 r
.5396 .49335 .54306 .5065 .54948 .50774 .54594 .48418 Mtetra
.585 .425 .63 r
.54594 .48418 .54948 .50774 .55589 .50481 .55233 .48217 Mtetra
.749 .54 .613 r
.55233 .48217 .55589 .50481 .56212 .48489 .55857 .46391 Mtetra
.753 .547 .617 r
.55857 .46391 .56212 .48489 .56826 .46253 .56477 .44646 Mtetra
.837 .616 .603 r
.56477 .44646 .56826 .46253 .57429 .43712 .57079 .41985 Mtetra
.83 .607 .601 r
.57079 .41985 .57429 .43712 .58023 .41061 .57673 .39292 Mtetra
.867 .628 .575 r
.57673 .39292 .58023 .41061 .58579 .36887 .58236 .35394 Mtetra
.732 .555 .652 r
.58236 .35394 .58579 .36887 .59163 .34719 .58844 .34375 Mtetra
.923 .535 .161 r
.58844 .34375 .59163 .34719 .59842 .3691 .59522 .36608 Mtetra
.839 .389 0 r
.59522 .36608 .59842 .3691 .60491 .37516 .60189 .37925 Mtetra
.882 .513 .34 r
.60189 .37925 .60491 .37516 .61151 .3833 .60888 .40176 Mtetra
.701 .387 .442 r
.60888 .40176 .61151 .3833 .61863 .4075 .61573 .41522 Mtetra
.775 .404 .353 r
.61573 .41522 .61863 .4075 .6254 .41631 .62264 .42798 Mtetra
.439 .112 .312 r
.62264 .42798 .6254 .41631 .63232 .42802 .62914 .4259 Mtetra
.877 .882 .834 r
.62914 .4259 .63232 .42802 .63911 .43407 .6355 .41895 Mtetra
.821 .609 .617 r
.6355 .41895 .63911 .43407 .64473 .40717 .64134 .39799 Mtetra
.877 .677 .628 r
.64134 .39799 .64473 .40717 .65063 .38992 .64716 .37799 Mtetra
.792 .612 .657 r
.64716 .37799 .65063 .38992 .65659 .3749 .6532 .36505 Mtetra
.862 .664 .633 r
.6532 .36505 .65659 .3749 .66229 .35483 .65898 .34652 Mtetra
.877 .686 .64 r
.65898 .34652 .66229 .35483 .66828 .34255 .66474 .32885 Mtetra
.814 .611 .628 r
.66474 .32885 .66828 .34255 .67414 .32813 .67046 .31118 Mtetra
.362 .302 .655 r
.67046 .31118 .67414 .32813 .67999 .31414 .67734 .31855 Mtetra
.656 .211 .183 r
.67734 .31855 .67999 .31414 .68682 .31976 .68414 .3233 Mtetra
0 0 0 r
.68414 .3233 .68682 .31976 .69319 .31603 .69052 .31924 Mtetra
.752 .299 .176 r
.69052 .31924 .69319 .31603 .69968 .31435 .69757 .32728 Mtetra
.294 .007 .295 r
.69757 .32728 .69968 .31435 .70601 .30961 .70384 .32058 Mtetra
.236 0 .243 r
.70384 .32058 .70601 .30961 .7125 .30727 .7101 .31373 Mtetra
0 0 0 r
.7101 .31373 .7125 .30727 .71897 .30454 .7159 .29949 Mtetra
.342 .524 .89 r
.7159 .29949 .71897 .30454 .72529 .29929 .7227 .3016 Mtetra
.759 .284 .115 r
.7227 .3016 .72529 .29929 .73331 .3195 .72993 .30977 Mtetra
.594 .528 .75 r
.72993 .30977 .73331 .3195 .7399 .31731 .7366 .30863 Mtetra
0 0 .514 r
.7366 .30863 .7399 .31731 .74725 .32571 .74435 .32279 Mtetra
0 .399 .838 r
.74435 .32279 .74725 .32571 .7531 .31249 .75141 .3262 Mtetra
.436 .129 .345 r
.75141 .3262 .7531 .31249 .76023 .31694 .75804 .32326 Mtetra
.658 .243 .247 r
.75804 .32326 .76023 .31694 .7677 .32513 .76533 .32869 Mtetra
.59 .106 .074 r
.76533 .32869 .7677 .32513 .77455 .32479 .7725 .33204 Mtetra
.464 .074 .214 r
.7725 .33204 .77455 .32479 .78119 .32148 .77942 .33183 Mtetra
.489 .142 .303 r
.77942 .33183 .78119 .32148 .78793 .31926 .78636 .33154 Mtetra
.659 .308 .366 r
.78636 .33154 .78793 .31926 .796 .33239 .79399 .33898 Mtetra
.348 0 .148 r
.79399 .33898 .796 .33239 .80315 .33407 .80083 .33675 Mtetra
.671 .87 .486 r
.80083 .33675 .80315 .33407 .80956 .32712 .80708 .32774 Mtetra
.993 .871 .541 r
.80708 .32774 .80956 .32712 .81547 .315 .81241 .30889 Mtetra
.868 .735 .714 r
.81241 .30889 .81547 .315 .82082 .29709 .81844 .2981 Mtetra
0 0 0 r
.81844 .2981 .82082 .29709 .82763 .29483 .82534 .29654 Mtetra
.57 .879 .59 r
.82534 .29654 .82763 .29483 .83458 .29383 .83181 .29034 Mtetra
.659 .786 .942 r
.83181 .29034 .83458 .29383 .84162 .29352 .83866 .28807 Mtetra
.854 .754 .752 r
.83866 .28807 .84162 .29352 .84823 .2888 .84487 .2793 Mtetra
.567 .52 .762 r
.84487 .2793 .84823 .2888 .85531 .28846 .85195 .27894 Mtetra
.691 .547 .685 r
.23849 .47113 .24145 .48317 .24729 .47761 .24432 .46557 Mtetra
.641 .515 .694 r
.24432 .46557 .24729 .47761 .25276 .47656 .24995 .46254 Mtetra
.557 .444 .68 r
.24995 .46254 .25276 .47656 .2583 .47471 .25533 .46251 Mtetra
.507 .428 .701 r
.25533 .46251 .2583 .47471 .26335 .47928 .26063 .46385 Mtetra
.667 .509 .661 r
.26063 .46385 .26335 .47928 .26936 .4719 .26648 .45833 Mtetra
.268 .252 .655 r
.26648 .45833 .26936 .4719 .27481 .47188 .27142 .46475 Mtetra
.434 .481 .81 r
.27142 .46475 .27481 .47188 .2804 .47002 .27675 .46638 Mtetra
0 .262 .748 r
.27675 .46638 .2804 .47002 .28628 .46448 .28197 .46991 Mtetra
.448 .03 .151 r
.28197 .46991 .28628 .46448 .29215 .45897 .28748 .46985 Mtetra
.503 .168 .332 r
.28748 .46985 .29215 .45897 .29778 .45709 .293 .46979 Mtetra
.605 .285 .401 r
.293 .46979 .29778 .45709 .30254 .46809 .29829 .47342 Mtetra
.731 .903 .526 r
.29829 .47342 .30254 .46809 .30796 .46995 .30448 .46416 Mtetra
.747 .672 .778 r
.30448 .46416 .30796 .46995 .31442 .45602 .31035 .4594 Mtetra
.984 .821 .601 r
.31035 .4594 .31442 .45602 .32096 .44031 .31755 .43388 Mtetra
.814 .677 .712 r
.31755 .43388 .32096 .44031 .32695 .43318 .32369 .42443 Mtetra
.63 .552 .748 r
.32369 .42443 .32695 .43318 .33293 .42605 .32936 .42251 Mtetra
.687 .748 .898 r
.32936 .42251 .33293 .42605 .33862 .42376 .33506 .42021 Mtetra
.663 .741 .908 r
.33506 .42021 .33862 .42376 .34394 .42849 .34075 .41828 Mtetra
.622 .526 .724 r
.34075 .41828 .34394 .42849 .34974 .42476 .34646 .41635 Mtetra
.37 .408 .77 r
.34646 .41635 .34974 .42476 .35537 .42451 .35192 .41927 Mtetra
.67 .665 .836 r
.35192 .41927 .35537 .42451 .36111 .42258 .35767 .41701 Mtetra
.702 .665 .81 r
.35767 .41701 .36111 .42258 .36592 .43965 .36348 .41387 Mtetra
.174 .114 .544 r
.36348 .41387 .36592 .43965 .37188 .43424 .36839 .42957 Mtetra
0 .212 .733 r
.36839 .42957 .37188 .43424 .37736 .43939 .37389 .43417 Mtetra
.779 .703 .779 r
.37389 .43417 .37736 .43939 .38318 .43745 .37988 .42852 Mtetra
.307 .359 .753 r
.37988 .42852 .38318 .43745 .38872 .44253 .38546 .4325 Mtetra
.472 .44 .742 r
.38546 .4325 .38872 .44253 .39435 .44629 .39116 .43435 Mtetra
.725 .57 .68 r
.39116 .43435 .39435 .44629 .40091 .42653 .39726 .4267 Mtetra
.855 .974 .866 r
.39726 .4267 .40091 .42653 .40678 .42458 .40328 .42096 Mtetra
.876 .765 .736 r
.40328 .42096 .40678 .42458 .41313 .40891 .40945 .41098 Mtetra
.72 .974 .741 r
.40945 .41098 .41313 .40891 .41881 .41241 .41546 .40526 Mtetra
0 .198 .716 r
.41546 .40526 .41881 .41241 .42446 .41827 .4211 .41127 Mtetra
.247 .379 .8 r
.4211 .41127 .42446 .41827 .43037 .4163 .42684 .41496 Mtetra
.609 .885 .99 r
.42684 .41496 .43037 .4163 .43645 .40908 .43278 .41298 Mtetra
.662 .892 .543 r
.43278 .41298 .43645 .40908 .44233 .40899 .43889 .40532 Mtetra
.906 .758 .686 r
.43889 .40532 .44233 .40899 .44833 .40463 .44514 .39122 Mtetra
.677 .53 .677 r
.44514 .39122 .44833 .40463 .45453 .39144 .45117 .38581 Mtetra
.794 .699 .759 r
.45117 .38581 .45453 .39144 .46058 .38459 .45722 .37913 Mtetra
.702 .674 .82 r
.45722 .37913 .46058 .38459 .46653 .38258 .4632 .376 Mtetra
.151 .333 .792 r
.4632 .376 .46653 .38258 .47245 .38387 .46906 .38037 Mtetra
.411 .652 .957 r
.46906 .38037 .47245 .38387 .47843 .38208 .47501 .38091 Mtetra
.569 .885 .991 r
.47501 .38091 .47843 .38208 .48432 .38813 .48102 .37909 Mtetra
.818 .479 0 r
.48102 .37909 .48432 .38813 .4902 .40032 .48679 .39931 Mtetra
.844 .383 .088 r
.48679 .39931 .4902 .40032 .49617 .40869 .49274 .40957 Mtetra
.878 .479 .268 r
.49274 .40957 .49617 .40869 .50205 .43912 .49872 .42462 Mtetra
.195 .204 .641 r
.49872 .42462 .50205 .43912 .50806 .46822 .50482 .43386 Mtetra
.207 .127 .54 r
.50482 .43386 .50806 .46822 .5143 .46911 .51092 .45526 Mtetra
0 0 .395 r
.51092 .45526 .5143 .46911 .52054 .48676 .51713 .47384 Mtetra
.154 .198 .655 r
.51713 .47384 .52054 .48676 .52687 .49469 .52343 .48284 Mtetra
.77 .601 .669 r
.52343 .48284 .52687 .49469 .53323 .4966 .52977 .47178 Mtetra
.467 .338 .62 r
.52977 .47178 .53323 .4966 .5396 .49335 .53614 .47686 Mtetra
.782 .581 .629 r
.53614 .47686 .5396 .49335 .54594 .48418 .54243 .45968 Mtetra
.61 .439 .626 r
.54243 .45968 .54594 .48418 .55233 .48217 .54877 .45565 Mtetra
.749 .532 .602 r
.54877 .45565 .55233 .48217 .55857 .46391 .55496 .43402 Mtetra
.721 .507 .599 r
.55496 .43402 .55857 .46391 .56477 .44646 .56111 .4147 Mtetra
.731 .511 .594 r
.56111 .4147 .56477 .44646 .57079 .41985 .56717 .39226 Mtetra
.775 .548 .591 r
.56717 .39226 .57079 .41985 .57673 .39292 .57308 .36431 Mtetra
.72 .507 .6 r
.57308 .36431 .57673 .39292 .58236 .35394 .57906 .34595 Mtetra
0 .178 .697 r
.57906 .34595 .58236 .35394 .58844 .34375 .58549 .35346 Mtetra
.817 .471 .402 r
.58549 .35346 .58844 .34375 .59522 .36608 .59224 .37365 Mtetra
.755 .383 .348 r
.59224 .37365 .59522 .36608 .60189 .37925 .59887 .38456 Mtetra
.831 .451 .333 r
.59887 .38456 .60189 .37925 .60888 .40176 .6057 .40043 Mtetra
.905 .494 .172 r
.6057 .40043 .60888 .40176 .61573 .41522 .61269 .41898 Mtetra
.674 .22 .166 r
.61269 .41898 .61573 .41522 .62264 .42798 .61938 .42412 Mtetra
.899 .788 .729 r
.61938 .42412 .62264 .42798 .62914 .4259 .62562 .41318 Mtetra
.496 .429 .71 r
.62562 .41318 .62914 .4259 .6355 .41895 .63227 .41509 Mtetra
.952 .762 .609 r
.63227 .41509 .6355 .41895 .64134 .39799 .63809 .39274 Mtetra
.956 .727 .553 r
.63809 .39274 .64134 .39799 .64716 .37799 .64336 .35741 Mtetra
.678 .496 .632 r
.64336 .35741 .64716 .37799 .6532 .36505 .64956 .34871 Mtetra
.797 .588 .619 r
.64956 .34871 .6532 .36505 .65898 .34652 .65533 .33 Mtetra
.742 .553 .638 r
.65533 .33 .65898 .34652 .66474 .32885 .66133 .31775 Mtetra
.545 .476 .729 r
.66133 .31775 .66474 .32885 .67046 .31118 .66787 .31805 Mtetra
.697 .302 .295 r
.66787 .31805 .67046 .31118 .67734 .31855 .67476 .32515 Mtetra
.626 .222 .257 r
.67476 .32515 .67734 .31855 .68414 .3233 .68156 .32928 Mtetra
.321 0 .107 r
.68156 .32928 .68414 .3233 .69052 .31924 .68807 .32711 Mtetra
.572 .187 .274 r
.68807 .32711 .69052 .31924 .69757 .32728 .69485 .3296 Mtetra
.202 0 0 r
.69485 .3296 .69757 .32728 .70384 .32058 .70147 .32868 Mtetra
0 0 .069 r
.70147 .32868 .70384 .32058 .7101 .31373 .70767 .32011 Mtetra
.76 .786 .29 r
.70767 .32011 .7101 .31373 .7159 .29949 .71332 .30253 Mtetra
.216 0 0 r
.71332 .30253 .7159 .29949 .7227 .3016 .71992 .30112 Mtetra
.549 0 0 r
.71992 .30112 .7227 .3016 .72993 .30977 .72693 .30574 Mtetra
0 .132 .662 r
.72693 .30574 .72993 .30977 .7366 .30863 .73412 .31236 Mtetra
.877 .479 .271 r
.73412 .31236 .7366 .30863 .74435 .32279 .74233 .33302 Mtetra
0 0 .092 r
.74233 .33302 .74435 .32279 .75141 .3262 .74823 .31954 Mtetra
.142 .33 .792 r
.74823 .31954 .75141 .3262 .75804 .32326 .75549 .32499 Mtetra
.641 .11 0 r
.75549 .32499 .75804 .32326 .76533 .32869 .76275 .32985 Mtetra
.539 0 0 r
.76275 .32985 .76533 .32869 .7725 .33204 .76994 .33324 Mtetra
.561 0 0 r
.76994 .33324 .7725 .33204 .77942 .33183 .7772 .33697 Mtetra
.604 .161 .17 r
.7772 .33697 .77942 .33183 .78636 .33154 .78449 .34062 Mtetra
.128 0 .167 r
.78449 .34062 .78636 .33154 .79399 .33898 .79087 .33287 Mtetra
.651 .653 .839 r
.79087 .33287 .79399 .33898 .80083 .33675 .79772 .33064 Mtetra
.869 .736 .712 r
.79772 .33064 .80083 .33675 .80708 .32774 .80381 .31962 Mtetra
.928 .709 .586 r
.80381 .31962 .80708 .32774 .81241 .30889 .80862 .29491 Mtetra
.531 .44 .697 r
.80862 .29491 .81241 .30889 .81844 .2981 .81575 .29588 Mtetra
.559 .835 .997 r
.81575 .29588 .81844 .2981 .82534 .29654 .82267 .29431 Mtetra
.81 .912 .909 r
.82267 .29431 .82534 .29654 .83181 .29034 .82927 .28936 Mtetra
.733 .972 .929 r
.82927 .28936 .83181 .29034 .83866 .28807 .83595 .28513 Mtetra
.95 .85 .708 r
.83595 .28513 .83866 .28807 .84487 .2793 .84185 .27314 Mtetra
.653 .653 .837 r
.84185 .27314 .84487 .2793 .85195 .27894 .84873 .27084 Mtetra
.943 .962 .707 r
.23417 .4745 .23849 .47113 .24432 .46557 .24046 .464 Mtetra
.904 .807 .743 r
.24046 .464 .24432 .46557 .24995 .46254 .24671 .45364 Mtetra
.746 .61 .706 r
.24671 .45364 .24995 .46254 .25533 .46251 .25268 .44663 Mtetra
.545 .422 .663 r
.25268 .44663 .25533 .46251 .26063 .46385 .25803 .447 Mtetra
.504 .388 .654 r
.25803 .447 .26063 .46385 .26648 .45833 .26328 .44892 Mtetra
.502 .465 .748 r
.26328 .44892 .26648 .45833 .27142 .46475 .26862 .44999 Mtetra
0 .033 .55 r
.26862 .44999 .27142 .46475 .27675 .46638 .27321 .46116 Mtetra
.68 .244 0 r
.27321 .46116 .27675 .46638 .28197 .46991 .27808 .46931 Mtetra
.146 .679 .855 r
.27808 .46931 .28197 .46991 .28748 .46985 .28359 .46923 Mtetra
.91 .874 .789 r
.28359 .46923 .28748 .46985 .293 .46979 .28973 .46083 Mtetra
.68 .577 .732 r
.28973 .46083 .293 .46979 .29829 .47342 .29552 .45715 Mtetra
.725 .544 .646 r
.29552 .45715 .29829 .47342 .30448 .46416 .30179 .44651 Mtetra
.69 .515 .645 r
.30179 .44651 .30448 .46416 .31035 .4594 .30788 .43829 Mtetra
.666 .486 .632 r
.30788 .43829 .31035 .4594 .31755 .43388 .31393 .43063 Mtetra
.719 .771 .894 r
.31393 .43063 .31755 .43388 .32369 .42443 .31967 .42778 Mtetra
0 0 0 r
.31967 .42778 .32369 .42443 .32936 .42251 .32552 .4232 Mtetra
.687 .978 .891 r
.32552 .4232 .32936 .42251 .33506 .42021 .33132 .41946 Mtetra
.575 .902 .982 r
.33132 .41946 .33506 .42021 .34075 .41828 .33703 .41753 Mtetra
.768 .936 .939 r
.33703 .41753 .34075 .41828 .34646 .41635 .34284 .41382 Mtetra
.616 .796 .968 r
.34284 .41382 .34646 .41635 .35192 .41927 .34854 .41233 Mtetra
0 .109 .661 r
.34854 .41233 .35192 .41927 .35767 .41701 .35384 .41881 Mtetra
.964 .926 .71 r
.35384 .41881 .35767 .41701 .36348 .41387 .3601 .40724 Mtetra
.633 .603 .802 r
.3601 .40724 .36348 .41387 .36839 .42957 .36585 .40555 Mtetra
.563 .403 .622 r
.36585 .40555 .36839 .42957 .37389 .43417 .37156 .40493 Mtetra
.472 .324 .598 r
.37156 .40493 .37389 .43417 .37988 .42852 .37702 .41012 Mtetra
.439 .337 .642 r
.37702 .41012 .37988 .42852 .38546 .4325 .38255 .41462 Mtetra
.463 .357 .648 r
.38255 .41462 .38546 .4325 .39116 .43435 .38816 .41821 Mtetra
.54 .421 .665 r
.38816 .41821 .39116 .43435 .39726 .4267 .39391 .41881 Mtetra
.833 .666 .675 r
.39391 .41881 .39726 .4267 .40328 .42096 .40023 .40556 Mtetra
.373 .312 .659 r
.40023 .40556 .40328 .42096 .40945 .41098 .40582 .41109 Mtetra
.953 .886 .728 r
.40582 .41109 .40945 .41098 .41546 .40526 .41205 .39974 Mtetra
.314 .481 .865 r
.41205 .39974 .41546 .40526 .4211 .41127 .4178 .40201 Mtetra
.362 .387 .753 r
.4178 .40201 .4211 .41127 .42684 .41496 .42355 .40546 Mtetra
.474 .452 .753 r
.42355 .40546 .42684 .41496 .43278 .41298 .42938 .40716 Mtetra
.863 .708 .688 r
.42938 .40716 .43278 .41298 .43889 .40532 .43564 .39424 Mtetra
.801 .62 .657 r
.43564 .39424 .43889 .40532 .44514 .39122 .44189 .38048 Mtetra
.49 .441 .729 r
.44189 .38048 .44514 .39122 .45117 .38581 .44775 .38209 Mtetra
.795 .77 .831 r
.44775 .38209 .45117 .38581 .45722 .37913 .45378 .37705 Mtetra
.815 .864 .884 r
.45378 .37705 .45722 .37913 .4632 .376 .4598 .3723 Mtetra
.663 .743 .909 r
.4598 .3723 .4632 .376 .46906 .38037 .46578 .37027 Mtetra
.63 .535 .728 r
.46578 .37027 .46906 .38037 .47501 .38091 .47177 .36802 Mtetra
.592 .481 .695 r
.47177 .36802 .47501 .38091 .48102 .37909 .47777 .36671 Mtetra
0 0 .416 r
.47777 .36671 .48102 .37909 .48679 .39931 .48355 .38258 Mtetra
0 0 .459 r
.48355 .38258 .48679 .39931 .49274 .40957 .4894 .4009 Mtetra
.75 .409 0 r
.4894 .4009 .49274 .40957 .49872 .42462 .49533 .41842 Mtetra
.937 .577 .175 r
.49533 .41842 .49872 .42462 .50482 .43386 .5013 .44404 Mtetra
.725 .379 .392 r
.5013 .44404 .50482 .43386 .51092 .45526 .50747 .45448 Mtetra
.848 .949 .883 r
.50747 .45448 .51092 .45526 .51713 .47384 .51376 .44884 Mtetra
.431 .31 .614 r
.51376 .44884 .51713 .47384 .52343 .48284 .52002 .45568 Mtetra
.547 .387 .616 r
.52002 .45568 .52343 .48284 .52977 .47178 .52634 .45608 Mtetra
.699 .532 .658 r
.52634 .45608 .52977 .47178 .53614 .47686 .53265 .44806 Mtetra
.742 .524 .598 r
.53265 .44806 .53614 .47686 .54243 .45968 .5389 .4257 Mtetra
.592 .408 .601 r
.5389 .4257 .54243 .45968 .54877 .45565 .54519 .42167 Mtetra
.695 .482 .595 r
.54519 .42167 .54877 .45565 .55496 .43402 .55139 .40428 Mtetra
.748 .526 .594 r
.55139 .40428 .55496 .43402 .56111 .4147 .55747 .38007 Mtetra
.692 .479 .594 r
.55747 .38007 .56111 .4147 .56717 .39226 .56355 .36273 Mtetra
.765 .537 .589 r
.56355 .36273 .56717 .39226 .57308 .36431 .56945 .33523 Mtetra
.103 .066 .527 r
.56945 .33523 .57308 .36431 .57906 .34595 .57608 .35812 Mtetra
.725 .386 .405 r
.57608 .35812 .57906 .34595 .58549 .35346 .58262 .36996 Mtetra
.772 .451 .443 r
.58262 .36996 .58549 .35346 .59224 .37365 .58942 .39146 Mtetra
.67 .355 .432 r
.58942 .39146 .59224 .37365 .59887 .38456 .59608 .40147 Mtetra
.503 .202 .388 r
.59608 .40147 .59887 .38456 .6057 .40043 .60254 .40074 Mtetra
.517 0 0 r
.60254 .40074 .6057 .40043 .61269 .41898 .60912 .40395 Mtetra
.63 .493 .676 r
.60912 .40395 .61269 .41898 .61938 .42412 .61556 .40051 Mtetra
.628 .454 .627 r
.61556 .40051 .61938 .42412 .62562 .41318 .62194 .39505 Mtetra
.595 .452 .656 r
.62194 .39505 .62562 .41318 .63227 .41509 .62843 .39294 Mtetra
.771 .554 .605 r
.62843 .39294 .63227 .41509 .63809 .39274 .63429 .37176 Mtetra
.818 .588 .59 r
.63429 .37176 .63809 .39274 .64336 .35741 .6398 .34289 Mtetra
.782 .588 .638 r
.6398 .34289 .64336 .35741 .64956 .34871 .64576 .32818 Mtetra
.731 .531 .621 r
.64576 .32818 .64956 .34871 .65533 .33 .65171 .31405 Mtetra
.614 .474 .668 r
.65171 .31405 .65533 .33 .66133 .31775 .65811 .31124 Mtetra
.179 .358 .805 r
.65811 .31124 .66133 .31775 .66787 .31805 .66484 .31586 Mtetra
0 .323 .742 r
.66484 .31586 .66787 .31805 .67476 .32515 .67157 .31925 Mtetra
0 .251 .76 r
.67157 .31925 .67476 .32515 .68156 .32928 .67846 .32526 Mtetra
.308 .567 .93 r
.67846 .32526 .68156 .32928 .68807 .32711 .68518 .32696 Mtetra
.154 0 0 r
.68518 .32696 .68807 .32711 .69485 .3296 .69189 .32796 Mtetra
.835 .93 .893 r
.69189 .32796 .69485 .3296 .70147 .32868 .69828 .32258 Mtetra
.886 .729 .682 r
.69828 .32258 .70147 .32868 .70767 .32011 .70422 .30924 Mtetra
.801 .626 .665 r
.70422 .30924 .70767 .32011 .71332 .30253 .71019 .29697 Mtetra
.432 .554 .878 r
.71019 .29697 .71332 .30253 .71992 .30112 .71697 .29828 Mtetra
.221 .595 .948 r
.71697 .29828 .71992 .30112 .72693 .30574 .72379 .29977 Mtetra
.556 .605 .858 r
.72379 .29977 .72693 .30574 .73412 .31236 .73052 .29942 Mtetra
0 0 .509 r
.73052 .29942 .73412 .31236 .74233 .33302 .73854 .31766 Mtetra
.564 .449 .681 r
.73854 .31766 .74233 .33302 .74823 .31954 .74536 .31729 Mtetra
.566 .038 0 r
.74536 .31729 .74823 .31954 .75549 .32499 .75275 .32456 Mtetra
.563 0 0 r
.75275 .32456 .75549 .32499 .76275 .32985 .76004 .32956 Mtetra
.762 .249 0 r
.76004 .32956 .76275 .32985 .76994 .33324 .76771 .339 Mtetra
0 0 0 r
.76771 .339 .76994 .33324 .7772 .33697 .77409 .33123 Mtetra
.406 .536 .875 r
.77409 .33123 .7772 .33697 .78449 .34062 .78124 .33297 Mtetra
.862 .7 .68 r
.78124 .33297 .78449 .34062 .79087 .33287 .78718 .31997 Mtetra
.613 .502 .703 r
.78718 .31997 .79087 .33287 .79772 .33064 .79402 .31772 Mtetra
.764 .59 .662 r
.79402 .31772 .79772 .33064 .80381 .31962 .80011 .30675 Mtetra
.726 .569 .677 r
.80011 .30675 .80381 .31962 .80862 .29491 .80643 .29856 Mtetra
.797 .851 .396 r
.80643 .29856 .80862 .29491 .81575 .29588 .8122 .28453 Mtetra
.668 .551 .713 r
.8122 .28453 .81575 .29588 .82267 .29431 .81886 .28028 Mtetra
.622 .497 .688 r
.81886 .28028 .82267 .29431 .82927 .28936 .82565 .27736 Mtetra
.617 .514 .714 r
.82565 .27736 .82927 .28936 .83595 .28513 .83252 .27506 Mtetra
.722 .598 .717 r
.83252 .27506 .83595 .28513 .84185 .27314 .83901 .26889 Mtetra
.662 .744 .911 r
.83901 .26889 .84185 .27314 .84873 .27084 .84591 .26658 Mtetra
.955 .862 .708 r
.23003 .47558 .23417 .4745 .24046 .464 .23657 .46242 Mtetra
.922 .776 .682 r
.23657 .46242 .24046 .464 .24671 .45364 .24331 .44669 Mtetra
.752 .643 .741 r
.24331 .44669 .24671 .45364 .25268 .44663 .24918 .44087 Mtetra
.693 .65 .803 r
.24918 .44087 .25268 .44663 .25803 .447 .25481 .43795 Mtetra
.212 .29 .727 r
.25481 .43795 .25803 .447 .26328 .44892 .25982 .44269 Mtetra
.331 .455 .836 r
.25982 .44269 .26328 .44892 .26862 .44999 .26506 .44498 Mtetra
0 .001 .555 r
.26506 .44498 .26862 .44999 .27321 .46116 .27005 .45083 Mtetra
.864 .544 .024 r
.27005 .45083 .27321 .46116 .27808 .46931 .2741 .46945 Mtetra
.736 .972 .929 r
.2741 .46945 .27808 .46931 .28359 .46923 .2799 .46575 Mtetra
.871 .755 .732 r
.2799 .46575 .28359 .46923 .28973 .46083 .28618 .45555 Mtetra
.82 .704 .736 r
.28618 .45555 .28973 .46083 .29552 .45715 .29231 .44716 Mtetra
.715 .582 .705 r
.29231 .44716 .29552 .45715 .30179 .44651 .29826 .44132 Mtetra
.873 .711 .678 r
.29826 .44132 .30179 .44651 .30788 .43829 .3048 .42665 Mtetra
.447 .397 .709 r
.3048 .42665 .30788 .43829 .31393 .43063 .31017 .42923 Mtetra
.596 .869 .993 r
.31017 .42923 .31393 .43063 .31967 .42778 .31584 .42752 Mtetra
.336 .81 .906 r
.31584 .42752 .31967 .42778 .32552 .4232 .32149 .42644 Mtetra
.476 .832 .566 r
.32149 .42644 .32552 .4232 .33132 .41946 .32739 .42152 Mtetra
.343 0 0 r
.32739 .42152 .33132 .41946 .33703 .41753 .33298 .4218 Mtetra
0 0 0 r
.33298 .4218 .33703 .41753 .34284 .41382 .33882 .41799 Mtetra
.33882 .41799 .34284 .41382 .34854 .41233 .3447 .41371 Mtetra
.786 .348 .207 r
.3447 .41371 .34854 .41233 .35384 .41881 .34995 .42107 Mtetra
.931 .971 .729 r
.34995 .42107 .35384 .41881 .3601 .40724 .35613 .41158 Mtetra
.414 0 .063 r
.35613 .41158 .3601 .40724 .36585 .40555 .36182 .41149 Mtetra
0 0 0 r
.36182 .41149 .36585 .40555 .37156 .40493 .36795 .40274 Mtetra
.577 .021 0 r
.36795 .40274 .37156 .40493 .37702 .41012 .37344 .40747 Mtetra
.726 .816 .92 r
.37344 .40747 .37702 .41012 .38255 .41462 .37931 .40452 Mtetra
.476 .441 .74 r
.37931 .40452 .38255 .41462 .38816 .41821 .38498 .40625 Mtetra
.669 .536 .693 r
.38498 .40625 .38816 .41821 .39391 .41881 .39094 .40185 Mtetra
.63 .476 .656 r
.39094 .40185 .39391 .41881 .40023 .40556 .39687 .39808 Mtetra
.767 .646 .728 r
.39687 .39808 .40023 .40556 .40582 .41109 .40293 .39113 Mtetra
.656 .482 .637 r
.40293 .39113 .40582 .41109 .41205 .39974 .40897 .38466 Mtetra
0 0 .526 r
.40897 .38466 .41205 .39974 .4178 .40201 .41432 .39833 Mtetra
.509 .686 .947 r
.41432 .39833 .4178 .40201 .42355 .40546 .42018 .39813 Mtetra
.64 .592 .785 r
.42018 .39813 .42355 .40546 .42938 .40716 .42612 .39612 Mtetra
.72 .576 .692 r
.42612 .39612 .42938 .40716 .43564 .39424 .43221 .3894 Mtetra
.756 .715 .814 r
.43221 .3894 .43564 .39424 .44189 .38048 .43823 .38497 Mtetra
0 0 0 r
.43823 .38497 .44189 .38048 .44775 .38209 .44431 .37834 Mtetra
.627 .729 .92 r
.44431 .37834 .44775 .38209 .45378 .37705 .45027 .37684 Mtetra
.493 .895 .933 r
.45027 .37684 .45378 .37705 .4598 .3723 .45626 .37481 Mtetra
.775 .972 .688 r
.45626 .37481 .4598 .3723 .46578 .37027 .46235 .36766 Mtetra
.812 .335 0 r
.46235 .36766 .46578 .37027 .47177 .36802 .46815 .37717 Mtetra
.109 0 .115 r
.46815 .37717 .47177 .36802 .47777 .36671 .47426 .37072 Mtetra
.752 .341 .271 r
.47426 .37072 .47777 .36671 .48355 .38258 .48016 .37852 Mtetra
.906 .503 .111 r
.48016 .37852 .48355 .38258 .4894 .4009 .486 .39543 Mtetra
.816 .405 0 r
.486 .39543 .4894 .4009 .49533 .41842 .49196 .40939 Mtetra
.663 .34 0 r
.49196 .40939 .49533 .41842 .5013 .44404 .49798 .42552 Mtetra
0 0 .259 r
.49798 .42552 .5013 .44404 .50747 .45448 .50401 .45335 Mtetra
.959 .832 .674 r
.50401 .45335 .50747 .45448 .51376 .44884 .51035 .43801 Mtetra
.421 .403 .734 r
.51035 .43801 .51376 .44884 .52002 .45568 .51662 .44114 Mtetra
.632 .496 .679 r
.51662 .44114 .52002 .45568 .52634 .45608 .52292 .43776 Mtetra
.693 .515 .643 r
.52292 .43776 .52634 .45608 .53265 .44806 .52922 .42889 Mtetra
.766 .561 .62 r
.52922 .42889 .53265 .44806 .5389 .4257 .53548 .41113 Mtetra
.807 .604 .628 r
.53548 .41113 .5389 .4257 .54519 .42167 .54169 .39268 Mtetra
.711 .5 .602 r
.54169 .39268 .54519 .42167 .55139 .40428 .54786 .37559 Mtetra
.741 .522 .597 r
.54786 .37559 .55139 .40428 .55747 .38007 .55395 .35365 Mtetra
.698 .494 .609 r
.55395 .35365 .55747 .38007 .56355 .36273 .56005 .33988 Mtetra
.509 .371 .629 r
.56005 .33988 .56355 .36273 .56945 .33523 .56635 .34241 Mtetra
.859 .509 .388 r
.56635 .34241 .56945 .33523 .57608 .35812 .57299 .3664 Mtetra
.746 .379 .358 r
.57299 .3664 .57608 .35812 .58262 .36996 .57953 .37714 Mtetra
.857 .504 .383 r
.57953 .37714 .58262 .36996 .58942 .39146 .58638 .40081 Mtetra
.541 .178 .301 r
.58638 .40081 .58942 .39146 .59608 .40147 .59288 .40228 Mtetra
.795 .999 .81 r
.59288 .40228 .59608 .40147 .60254 .40074 .59924 .39619 Mtetra
.908 .76 .686 r
.59924 .39619 .60254 .40074 .60912 .40395 .6054 .38229 Mtetra
.468 .35 .635 r
.6054 .38229 .60912 .40395 .61556 .40051 .61202 .38673 Mtetra
.621 .496 .689 r
.61202 .38673 .61556 .40051 .62194 .39505 .61848 .38402 Mtetra
.83 .639 .645 r
.61848 .38402 .62194 .39505 .62843 .39294 .62454 .36799 Mtetra
.703 .501 .612 r
.62454 .36799 .62843 .39294 .63429 .37176 .63063 .35435 Mtetra
.806 .59 .609 r
.63063 .35435 .63429 .37176 .6398 .34289 .63641 .33278 Mtetra
.853 .658 .637 r
.63641 .33278 .6398 .34289 .64576 .32818 .64227 .31514 Mtetra
.685 .54 .683 r
.64227 .31514 .64576 .32818 .65171 .31405 .64855 .3094 Mtetra
0 .102 .646 r
.64855 .3094 .65171 .31405 .65811 .31124 .65536 .31631 Mtetra
.326 0 .054 r
.65536 .31631 .65811 .31124 .66484 .31586 .66185 .31478 Mtetra
.276 .75 .937 r
.66185 .31478 .66484 .31586 .67157 .31925 .66841 .3144 Mtetra
.286 .505 .893 r
.66841 .3144 .67157 .31925 .67846 .32526 .67513 .31681 Mtetra
.562 .534 .782 r
.67513 .31681 .67846 .32526 .68518 .32696 .68175 .31652 Mtetra
.194 .265 .709 r
.68175 .31652 .68518 .32696 .69189 .32796 .68879 .32392 Mtetra
.615 .726 .925 r
.68879 .32392 .69189 .32796 .69828 .32258 .69541 .32242 Mtetra
.996 .822 .551 r
.69541 .32242 .69828 .32258 .70422 .30924 .7008 .29882 Mtetra
.746 .603 .698 r
.7008 .29882 .70422 .30924 .71019 .29697 .70704 .29105 Mtetra
.632 .645 .845 r
.70704 .29105 .71019 .29697 .71697 .29828 .71364 .2893 Mtetra
0 0 .446 r
.71364 .2893 .71697 .29828 .72379 .29977 .72136 .30516 Mtetra
.089 0 0 r
.72136 .30516 .72379 .29977 .73052 .29942 .72784 .30054 Mtetra
.885 .463 .184 r
.72784 .30054 .73052 .29942 .73854 .31766 .73589 .31915 Mtetra
0 0 0 r
.73589 .31915 .73854 .31766 .74536 .31729 .7426 .31692 Mtetra
.693 .15 0 r
.7426 .31692 .74536 .31729 .75275 .32456 .75 .32417 Mtetra
.211 0 0 r
.75 .32417 .75275 .32456 .76004 .32956 .75706 .32587 Mtetra
.858 .444 0 r
.75706 .32587 .76004 .32956 .76771 .339 .76564 .34724 Mtetra
0 0 0 r
.76564 .34724 .76771 .339 .77409 .33123 .7711 .32709 Mtetra
.825 .798 .826 r
.7711 .32709 .77409 .33123 .78124 .33297 .77761 .32088 Mtetra
.805 .62 .651 r
.77761 .32088 .78124 .33297 .78718 .31997 .7835 .3071 Mtetra
.656 .528 .696 r
.7835 .3071 .78718 .31997 .79402 .31772 .79016 .30286 Mtetra
.771 .58 .641 r
.79016 .30286 .79402 .31772 .80011 .30675 .79604 .28952 Mtetra
.188 .19 .628 r
.79604 .28952 .80011 .30675 .80643 .29856 .80428 .30294 Mtetra
.961 .801 .362 r
.80428 .30294 .80643 .29856 .8122 .28453 .80853 .27193 Mtetra
.778 .6 .658 r
.80853 .27193 .8122 .28453 .81886 .28028 .81448 .26018 Mtetra
.592 .441 .645 r
.81448 .26018 .81886 .28028 .82565 .27736 .82131 .25787 Mtetra
.528 .402 .653 r
.82131 .25787 .82565 .27736 .83252 .27506 .82852 .2593 Mtetra
.473 .389 .68 r
.82852 .2593 .83252 .27506 .83901 .26889 .83597 .2627 Mtetra
.438 .536 .86 r
.83597 .2627 .83901 .26889 .84591 .26658 .84327 .26423 Mtetra
.724 .574 .686 r
.22696 .46443 .23003 .47558 .23657 .46242 .23298 .45728 Mtetra
.797 .7 .757 r
.23298 .45728 .23657 .46242 .24331 .44669 .23895 .45055 Mtetra
.884 .979 .685 r
.23895 .45055 .24331 .44669 .24918 .44087 .24513 .44137 Mtetra
.814 .98 .892 r
.24513 .44137 .24918 .44087 .25481 .43795 .25093 .43659 Mtetra
.552 0 0 r
.25093 .43659 .25481 .43795 .25982 .44269 .25605 .44004 Mtetra
.817 .336 0 r
.25605 .44004 .25982 .44269 .26506 .44498 .26086 .44768 Mtetra
.545 .06 .056 r
.26086 .44768 .26506 .44498 .27005 .45083 .26618 .44953 Mtetra
.886 .482 .245 r
.26618 .44953 .27005 .45083 .2741 .46945 .27076 .4612 Mtetra
.784 .638 .7 r
.27076 .4612 .2741 .46945 .2799 .46575 .27696 .45212 Mtetra
.677 .527 .674 r
.27696 .45212 .2799 .46575 .28618 .45555 .28288 .44671 Mtetra
.664 .571 .739 r
.28288 .44671 .28618 .45555 .29231 .44716 .28864 .44364 Mtetra
.805 .765 .816 r
.28864 .44364 .29231 .44716 .29826 .44132 .29456 .43821 Mtetra
.87 .772 .751 r
.29456 .43821 .29826 .44132 .3048 .42665 .30075 .42908 Mtetra
.945 .958 .725 r
.30075 .42908 .3048 .42665 .31017 .42923 .30699 .41893 Mtetra
.449 .419 .733 r
.30699 .41893 .31017 .42923 .31584 .42752 .3124 .42113 Mtetra
.765 .368 0 r
.3124 .42113 .31584 .42752 .32149 .42644 .31727 .43229 Mtetra
.992 .881 .578 r
.31727 .43229 .32149 .42644 .32739 .42152 .32421 .4109 Mtetra
.615 .517 .719 r
.32421 .4109 .32739 .42152 .33298 .4218 .32992 .4091 Mtetra
.051 .116 .611 r
.32992 .4091 .33298 .4218 .33882 .41799 .33501 .41818 Mtetra
.956 .851 .698 r
.33501 .41818 .33882 .41799 .3447 .41371 .34143 .40459 Mtetra
.179 .271 .722 r
.34143 .40459 .3447 .41371 .34995 .42107 .34678 .40993 Mtetra
.651 .533 .707 r
.34678 .40993 .34995 .42107 .35613 .41158 .35263 .40666 Mtetra
.719 .696 .827 r
.35263 .40666 .35613 .41158 .36182 .41149 .35849 .40328 Mtetra
0 0 .362 r
.35849 .40328 .36182 .41149 .36795 .40274 .36363 .4145 Mtetra
.546 .214 .357 r
.36363 .4145 .36795 .40274 .37344 .40747 .36931 .41583 Mtetra
0 0 .015 r
.36931 .41583 .37344 .40747 .37931 .40452 .37538 .40919 Mtetra
.66 .246 .248 r
.37538 .40919 .37931 .40452 .38498 .40625 .38096 .41349 Mtetra
0 0 0 r
.38096 .41349 .38498 .40625 .39094 .40185 .38713 .40472 Mtetra
.561 .886 .62 r
.38713 .40472 .39094 .40185 .39687 .39808 .39315 .39938 Mtetra
.868 .995 .802 r
.39315 .39938 .39687 .39808 .40293 .39113 .39923 .39252 Mtetra
.475 0 0 r
.39923 .39252 .40293 .39113 .40897 .38466 .40499 .39424 Mtetra
.403 .055 .256 r
.40499 .39424 .40897 .38466 .41432 .39833 .4109 .39223 Mtetra
.649 .632 .819 r
.4109 .39223 .41432 .39833 .42018 .39813 .41683 .39022 Mtetra
.636 .578 .772 r
.41683 .39022 .42018 .39813 .42612 .39612 .42277 .38821 Mtetra
.297 .382 .781 r
.42277 .38821 .42612 .39612 .43221 .3894 .42855 .39184 Mtetra
0 0 0 r
.42855 .39184 .43221 .3894 .43823 .38497 .43458 .38793 Mtetra
.789 .966 .659 r
.43458 .38793 .43823 .38497 .44431 .37834 .44072 .38009 Mtetra
.475 0 0 r
.44072 .38009 .44431 .37834 .45027 .37684 .44662 .38172 Mtetra
.723 .884 .488 r
.44662 .38172 .45027 .37684 .45626 .37481 .45281 .37183 Mtetra
.625 .779 .955 r
.45281 .37183 .45626 .37481 .46235 .36766 .4588 .37022 Mtetra
.787 .361 .239 r
.4588 .37022 .46235 .36766 .46815 .37717 .46462 .37883 Mtetra
.56 .03 0 r
.46462 .37883 .46815 .37717 .47426 .37072 .4706 .38149 Mtetra
.677 .333 .386 r
.4706 .38149 .47426 .37072 .48016 .37852 .47654 .38879 Mtetra
.574 .225 .339 r
.47654 .38879 .48016 .37852 .486 .39543 .48259 .39122 Mtetra
.138 .453 .884 r
.48259 .39122 .486 .39543 .49196 .40939 .48866 .39398 Mtetra
.251 .233 .643 r
.48866 .39398 .49196 .40939 .49798 .42552 .49472 .40249 Mtetra
.523 .38 .628 r
.49472 .40249 .49798 .42552 .50401 .45335 .50088 .40416 Mtetra
.432 .273 .564 r
.50088 .40416 .50401 .45335 .51035 .43801 .50701 .41685 Mtetra
.643 .47 .635 r
.50701 .41685 .51035 .43801 .51662 .44114 .51327 .41093 Mtetra
.616 .43 .607 r
.51327 .41093 .51662 .44114 .52292 .43776 .51954 .40508 Mtetra
.644 .447 .601 r
.51954 .40508 .52292 .43776 .52922 .42889 .5258 .39536 Mtetra
.619 .427 .6 r
.5258 .39536 .52922 .42889 .53548 .41113 .53205 .38846 Mtetra
.727 .524 .616 r
.53205 .38846 .53548 .41113 .54169 .39268 .53827 .37323 Mtetra
.776 .566 .614 r
.53827 .37323 .54169 .39268 .54786 .37559 .54442 .35373 Mtetra
.728 .525 .618 r
.54442 .35373 .54786 .37559 .55395 .35365 .55055 .339 Mtetra
.352 .31 .671 r
.55055 .339 .55395 .35365 .56005 .33988 .55686 .3451 Mtetra
.846 .475 .349 r
.55686 .3451 .56005 .33988 .56635 .34241 .56336 .36282 Mtetra
.54 .247 .419 r
.56336 .36282 .56635 .34241 .57299 .3664 .56972 .36386 Mtetra
.852 .401 .009 r
.56972 .36386 .57299 .3664 .57953 .37714 .57629 .37691 Mtetra
.793 .301 .02 r
.57629 .37691 .57953 .37714 .58638 .40081 .58287 .38569 Mtetra
.613 .481 .676 r
.58287 .38569 .58638 .40081 .59288 .40228 .58927 .38307 Mtetra
.496 .379 .65 r
.58927 .38307 .59288 .40228 .59924 .39619 .5958 .3858 Mtetra
.591 .516 .739 r
.5958 .3858 .59924 .39619 .6054 .38229 .60228 .38469 Mtetra
.507 0 0 r
.60228 .38469 .6054 .38229 .61202 .38673 .60886 .38673 Mtetra
.984 .87 .64 r
.60886 .38673 .61202 .38673 .61848 .38402 .61496 .37063 Mtetra
.821 .618 .628 r
.61496 .37063 .61848 .38402 .62454 .36799 .62094 .35226 Mtetra
.72 .544 .651 r
.62094 .35226 .62454 .36799 .63063 .35435 .62716 .34261 Mtetra
.817 .627 .645 r
.62716 .34261 .63063 .35435 .63641 .33278 .63317 .32721 Mtetra
.909 .737 .656 r
.63317 .32721 .63641 .33278 .64227 .31514 .6391 .31092 Mtetra
.844 .778 .788 r
.6391 .31092 .64227 .31514 .64855 .3094 .64534 .30365 Mtetra
0 .256 .765 r
.64534 .30365 .64855 .3094 .65536 .31631 .65209 .3094 Mtetra
0 .055 .621 r
.65209 .3094 .65536 .31631 .66185 .31478 .65905 .31858 Mtetra
.182 0 0 r
.65905 .31858 .66185 .31478 .66841 .3144 .66556 .31639 Mtetra
.799 .339 .146 r
.66556 .31639 .66841 .3144 .67513 .31681 .67265 .32634 Mtetra
.541 .177 .299 r
.67265 .32634 .67513 .31681 .68175 .31652 .67939 .32787 Mtetra
.707 .352 .372 r
.67939 .32787 .68175 .31652 .68879 .32392 .68661 .33801 Mtetra
0 0 .004 r
.68661 .33801 .68879 .32392 .69541 .32242 .69202 .31301 Mtetra
.811 .649 .681 r
.69202 .31301 .69541 .32242 .7008 .29882 .69811 .30164 Mtetra
.555 .838 .5 r
.69811 .30164 .7008 .29882 .70704 .29105 .70442 .2946 Mtetra
.55 .064 .055 r
.70442 .2946 .70704 .29105 .71364 .2893 .7113 .29709 Mtetra
.768 .382 .324 r
.7113 .29709 .71364 .2893 .72136 .30516 .71883 .30946 Mtetra
.346 0 .006 r
.71883 .30946 .72136 .30516 .72784 .30054 .72558 .30861 Mtetra
.572 .185 .269 r
.72558 .30861 .72784 .30054 .73589 .31915 .73259 .31128 Mtetra
0 .039 .607 r
.73259 .31128 .73589 .31915 .7426 .31692 .74021 .32228 Mtetra
.596 .157 .177 r
.74021 .32228 .7426 .31692 .75 .32417 .74737 .3257 Mtetra
.368 .797 .615 r
.74737 .3257 .75 .32417 .75706 .32587 .75404 .32173 Mtetra
.518 .683 .941 r
.75404 .32173 .75706 .32587 .76564 .34724 .76098 .32143 Mtetra
.72 .509 .603 r
.76098 .32143 .76564 .34724 .7711 .32709 .76671 .30507 Mtetra
.615 .449 .634 r
.76671 .30507 .7711 .32709 .77761 .32088 .77336 .30085 Mtetra
.318 .26 .633 r
.77336 .30085 .77761 .32088 .7835 .3071 .78123 .31151 Mtetra
.956 .816 .379 r
.78123 .31151 .7835 .3071 .79016 .30286 .78595 .28371 Mtetra
.716 .525 .63 r
.78595 .28371 .79016 .30286 .79604 .28952 .79198 .27228 Mtetra
.58 .448 .665 r
.79198 .27228 .79604 .28952 .80428 .30294 .79888 .27095 Mtetra
.681 .47 .594 r
.79888 .27095 .80428 .30294 .80853 .27193 .8046 .25635 Mtetra
.547 .437 .68 r
.8046 .25635 .80853 .27193 .81448 .26018 .81166 .25664 Mtetra
0 .371 .834 r
.81166 .25664 .81448 .26018 .82131 .25787 .81912 .26077 Mtetra
.549 .033 0 r
.81912 .26077 .82131 .25787 .82852 .2593 .82651 .26369 Mtetra
.658 .193 .137 r
.82651 .26369 .82852 .2593 .83597 .2627 .83418 .2691 Mtetra
.217 0 .096 r
.83418 .2691 .83597 .2627 .84327 .26423 .84093 .26489 Mtetra
.843 .704 .71 r
.22336 .45921 .22696 .46443 .23298 .45728 .22972 .44837 Mtetra
.768 .621 .697 r
.22972 .44837 .23298 .45728 .23895 .45055 .23586 .43977 Mtetra
.618 .515 .715 r
.23586 .43977 .23895 .45055 .24513 .44137 .24141 .43788 Mtetra
.703 .201 0 r
.24141 .43788 .24513 .44137 .25093 .43659 .24627 .44424 Mtetra
.564 .194 .298 r
.24627 .44424 .25093 .43659 .25605 .44004 .25154 .44608 Mtetra
.749 .392 .376 r
.25154 .44608 .25605 .44004 .26086 .44768 .25628 .45475 Mtetra
.162 0 .04 r
.25628 .45475 .26086 .44768 .26618 .44953 .26207 .45097 Mtetra
.622 .116 .025 r
.26207 .45097 .26618 .44953 .27076 .4612 .26731 .45408 Mtetra
.743 .64 .745 r
.26731 .45408 .27076 .4612 .27696 .45212 .27325 .4486 Mtetra
.882 .75 .712 r
.27325 .4486 .27696 .45212 .28288 .44671 .27967 .43676 Mtetra
.669 .557 .719 r
.27967 .43676 .28288 .44671 .28864 .44364 .28546 .43315 Mtetra
.76 .602 .681 r
.28546 .43315 .28864 .44364 .29456 .43821 .29166 .42385 Mtetra
.67 .517 .669 r
.29166 .42385 .29456 .43821 .30075 .42908 .29758 .41855 Mtetra
0 0 .495 r
.29758 .41855 .30075 .42908 .30699 .41893 .3024 .42908 Mtetra
0 0 0 r
.3024 .42908 .30699 .41893 .3124 .42113 .30861 .4198 Mtetra
.389 0 0 r
.30861 .4198 .3124 .42113 .31727 .43229 .31403 .42244 Mtetra
.658 .553 .724 r
.31403 .42244 .31727 .43229 .32421 .4109 .31984 .41925 Mtetra
.781 .857 .412 r
.31984 .41925 .32421 .4109 .32992 .4091 .32635 .4048 Mtetra
.713 .719 .854 r
.32635 .4048 .32992 .4091 .33501 .41818 .33215 .40179 Mtetra
.595 .455 .661 r
.33215 .40179 .33501 .41818 .34143 .40459 .33789 .39995 Mtetra
.659 .688 .866 r
.33789 .39995 .34143 .40459 .34678 .40993 .34365 .39798 Mtetra
0 .004 .555 r
.34365 .39798 .34678 .40993 .35263 .40666 .34874 .40855 Mtetra
.19 0 0 r
.34874 .40855 .35263 .40666 .35849 .40328 .35447 .40803 Mtetra
.666 .257 .258 r
.35447 .40803 .35849 .40328 .36363 .4145 .35996 .41254 Mtetra
.4 .758 .994 r
.35996 .41254 .36363 .4145 .36931 .41583 .36572 .41228 Mtetra
.861 .769 .759 r
.36572 .41228 .36931 .41583 .37538 .40919 .3719 .40368 Mtetra
.653 .653 .838 r
.3719 .40368 .37538 .40919 .38096 .41349 .37776 .40169 Mtetra
.764 .594 .667 r
.37776 .40169 .38096 .41349 .38713 .40472 .38402 .39096 Mtetra
.561 .451 .687 r
.38402 .39096 .38713 .40472 .39315 .39938 .38982 .39071 Mtetra
0 .12 .655 r
.38982 .39071 .39315 .39938 .39923 .39252 .39533 .39818 Mtetra
.081 0 0 r
.39533 .39818 .39923 .39252 .40499 .39424 .40132 .39429 Mtetra
.458 .883 .906 r
.40132 .39429 .40499 .39424 .4109 .39223 .40725 .39228 Mtetra
.371 0 0 r
.40725 .39228 .4109 .39223 .41683 .39022 .41306 .39404 Mtetra
.533 .834 .51 r
.41306 .39404 .41683 .39022 .42277 .38821 .41917 .38765 Mtetra
.542 .904 .966 r
.41917 .38765 .42277 .38821 .42855 .39184 .42513 .38562 Mtetra
.853 .7 .692 r
.42513 .38562 .42855 .39184 .43458 .38793 .43141 .3734 Mtetra
.559 .445 .68 r
.43141 .3734 .43458 .38793 .44072 .38009 .43734 .37319 Mtetra
.691 .629 .782 r
.43734 .37319 .44072 .38009 .44662 .38172 .44336 .36983 Mtetra
.695 .554 .69 r
.44336 .36983 .44662 .38172 .45281 .37183 .44945 .36406 Mtetra
.484 .499 .797 r
.44945 .36406 .45281 .37183 .4588 .37022 .45539 .36517 Mtetra
0 .076 .627 r
.45539 .36517 .4588 .37022 .46462 .37883 .46125 .37145 Mtetra
.673 .61 .777 r
.46125 .37145 .46462 .37883 .4706 .38149 .46733 .36849 Mtetra
.333 .312 .685 r
.46733 .36849 .4706 .38149 .47654 .38879 .47327 .37402 Mtetra
.205 .207 .638 r
.47327 .37402 .47654 .38879 .48259 .39122 .47921 .38295 Mtetra
.365 .418 .783 r
.47921 .38295 .48259 .39122 .48866 .39398 .48528 .38598 Mtetra
.458 .481 .795 r
.48528 .38598 .48866 .39398 .49472 .40249 .4914 .38756 Mtetra
.603 .473 .677 r
.4914 .38756 .49472 .40249 .50088 .40416 .49757 .3855 Mtetra
.445 .344 .646 r
.49757 .3855 .50088 .40416 .50701 .41685 .50372 .38998 Mtetra
.494 .348 .612 r
.50372 .38998 .50701 .41685 .51327 .41093 .50991 .39364 Mtetra
.729 .543 .639 r
.50991 .39364 .51327 .41093 .51954 .40508 .51618 .38202 Mtetra
.694 .5 .62 r
.51618 .38202 .51954 .40508 .5258 .39536 .52242 .37054 Mtetra
.687 .49 .615 r
.52242 .37054 .5258 .39536 .53205 .38846 .52864 .35892 Mtetra
.651 .455 .606 r
.52864 .35892 .53205 .38846 .53827 .37323 .53485 .34945 Mtetra
.738 .528 .609 r
.53485 .34945 .53827 .37323 .54442 .35373 .541 .33195 Mtetra
.276 .211 .601 r
.541 .33195 .54442 .35373 .55055 .339 .54731 .34351 Mtetra
.765 .355 .275 r
.54731 .34351 .55055 .339 .55686 .3451 .55366 .35261 Mtetra
.687 .305 .319 r
.55366 .35261 .55686 .3451 .56336 .36282 .56005 .35929 Mtetra
.897 .485 .088 r
.56005 .35929 .56336 .36282 .56972 .36386 .56663 .37708 Mtetra
.3 .002 .281 r
.56663 .37708 .56972 .36386 .57629 .37691 .57295 .37105 Mtetra
0 0 .443 r
.57295 .37105 .57629 .37691 .58287 .38569 .57954 .38128 Mtetra
.808 .762 .81 r
.57954 .38128 .58287 .38569 .58927 .38307 .58589 .37526 Mtetra
0 .136 .675 r
.58589 .37526 .58927 .38307 .5958 .3858 .59253 .38337 Mtetra
.873 .863 .826 r
.59253 .38337 .5958 .3858 .60228 .38469 .59888 .37632 Mtetra
.615 .566 .776 r
.59888 .37632 .60228 .38469 .60886 .38673 .60537 .37471 Mtetra
.806 .619 .65 r
.60537 .37471 .60886 .38673 .61496 .37063 .61152 .36019 Mtetra
.854 .656 .633 r
.61152 .36019 .61496 .37063 .62094 .35226 .61751 .34163 Mtetra
.817 .636 .658 r
.61751 .34163 .62094 .35226 .62716 .34261 .6236 .32776 Mtetra
.756 .571 .646 r
.6236 .32776 .62716 .34261 .63317 .32721 .62971 .31554 Mtetra
.76 .596 .674 r
.62971 .31554 .63317 .32721 .6391 .31092 .63589 .30577 Mtetra
.8 .735 .792 r
.63589 .30577 .6391 .31092 .64534 .30365 .64218 .2996 Mtetra
0 .006 .543 r
.64218 .2996 .64534 .30365 .65209 .3094 .64901 .30709 Mtetra
0 .348 .766 r
.64901 .30709 .65209 .3094 .65905 .31858 .65572 .31033 Mtetra
.471 .487 .793 r
.65572 .31033 .65905 .31858 .66556 .31639 .66239 .31185 Mtetra
.828 .768 .795 r
.66239 .31185 .66556 .31639 .67265 .32634 .66871 .30501 Mtetra
.215 .178 .599 r
.66871 .30501 .67265 .32634 .67939 .32787 .67604 .31929 Mtetra
.852 .677 .664 r
.67604 .31929 .67939 .32787 .68661 .33801 .68202 .30506 Mtetra
.68 .47 .594 r
.68202 .30506 .68661 .33801 .69202 .31301 .68793 .2902 Mtetra
.616 .446 .629 r
.68793 .2902 .69202 .31301 .69811 .30164 .69438 .28577 Mtetra
.55 .435 .675 r
.69438 .28577 .69811 .30164 .70442 .2946 .70109 .28592 Mtetra
.021 .186 .695 r
.70109 .28592 .70442 .2946 .7113 .29709 .70832 .29441 Mtetra
.65 .832 .97 r
.70832 .29441 .7113 .29709 .71883 .30946 .71495 .29216 Mtetra
.587 .45 .662 r
.71495 .29216 .71883 .30946 .72558 .30861 .72164 .29048 Mtetra
.485 .379 .659 r
.72164 .29048 .72558 .30861 .73259 .31128 .72866 .29364 Mtetra
.159 .163 .614 r
.72866 .29364 .73259 .31128 .74021 .32228 .73644 .30751 Mtetra
.458 .386 .688 r
.73644 .30751 .74021 .32228 .74737 .3257 .74359 .311 Mtetra
.7 .539 .666 r
.74359 .311 .74737 .3257 .75404 .32173 .74998 .30347 Mtetra
.656 .491 .649 r
.74998 .30347 .75404 .32173 .76098 .32143 .75647 .29731 Mtetra
.678 .484 .617 r
.75647 .29731 .76098 .32143 .76671 .30507 .76263 .28687 Mtetra
.52 .403 .66 r
.76263 .28687 .76671 .30507 .77336 .30085 .76973 .28848 Mtetra
.76 .592 .67 r
.76973 .28848 .77336 .30085 .78123 .31151 .7759 .27836 Mtetra
.657 .452 .595 r
.7759 .27836 .78123 .31151 .78595 .28371 .78191 .26647 Mtetra
.811 .591 .604 r
.78191 .26647 .78595 .28371 .79198 .27228 .78712 .24556 Mtetra
.459 .33 .617 r
.78712 .24556 .79198 .27228 .79888 .27095 .79465 .25186 Mtetra
.651 .483 .644 r
.79465 .25186 .79888 .27095 .8046 .25635 .80112 .24578 Mtetra
.637 .543 .732 r
.80112 .24578 .8046 .25635 .81166 .25664 .8079 .243 Mtetra
.531 .443 .701 r
.8079 .243 .81166 .25664 .81912 .26077 .81503 .24384 Mtetra
.327 .285 .657 r
.81503 .24384 .81912 .26077 .82651 .26369 .82297 .25273 Mtetra
.215 .274 .71 r
.82297 .25273 .82651 .26369 .83418 .2691 .83091 .2608 Mtetra
.638 .587 .781 r
.83091 .2608 .83418 .2691 .84093 .26489 .83785 .25846 Mtetra
.61 .492 .694 r
.22041 .44678 .22336 .45921 .22972 .44837 .22596 .44489 Mtetra
0 .205 .69 r
.22596 .44489 .22972 .44837 .23586 .43977 .23102 .44852 Mtetra
.561 .204 .32 r
.23102 .44852 .23586 .43977 .24141 .43788 .23627 .45028 Mtetra
.643 .322 .412 r
.23627 .45028 .24141 .43788 .24627 .44424 .24122 .45582 Mtetra
.627 .298 .395 r
.24122 .45582 .24627 .44424 .25154 .44608 .2463 .46032 Mtetra
.423 .112 .332 r
.2463 .46032 .25154 .44608 .25628 .45475 .252 .45765 Mtetra
.85 .992 .738 r
.252 .45765 .25628 .45475 .26207 .45097 .25811 .45011 Mtetra
.918 .843 .754 r
.25811 .45011 .26207 .45097 .26731 .45408 .26442 .44005 Mtetra
.692 .534 .668 r
.26442 .44005 .26731 .45408 .27325 .4486 .27044 .43345 Mtetra
.56 .439 .671 r
.27044 .43345 .27325 .4486 .27967 .43676 .27597 .43316 Mtetra
.827 .761 .789 r
.27597 .43316 .27967 .43676 .28546 .43315 .28199 .42655 Mtetra
.832 .68 .694 r
.28199 .42655 .28546 .43315 .29166 .42385 .28837 .415 Mtetra
.568 .517 .758 r
.28837 .415 .29166 .42385 .29758 .41855 .29393 .41462 Mtetra
.251 .539 .922 r
.29393 .41462 .29758 .41855 .3024 .42908 .29937 .41628 Mtetra
.079 .133 .618 r
.29937 .41628 .3024 .42908 .30861 .4198 .30436 .42486 Mtetra
.455 .023 .128 r
.30436 .42486 .30861 .4198 .31403 .42244 .30996 .42509 Mtetra
.516 .019 .015 r
.30996 .42509 .31403 .42244 .31984 .41925 .31548 .4267 Mtetra
0 0 0 r
.31548 .4267 .31984 .41925 .32635 .4048 .32169 .4177 Mtetra
.44 .12 .325 r
.32169 .4177 .32635 .4048 .33215 .40179 .32747 .41574 Mtetra
.23 0 .245 r
.32747 .41574 .33215 .40179 .33789 .39995 .33355 .40881 Mtetra
.471 .109 .269 r
.33355 .40881 .33789 .39995 .34365 .39798 .33924 .40845 Mtetra
.534 .191 .331 r
.33924 .40845 .34365 .39798 .34874 .40855 .34488 .40949 Mtetra
.304 .794 .756 r
.34488 .40949 .34874 .40855 .35447 .40803 .3507 .40751 Mtetra
.545 .904 .968 r
.3507 .40751 .35447 .40803 .35996 .41254 .35654 .40553 Mtetra
.697 .627 .774 r
.35654 .40553 .35996 .41254 .36572 .41228 .36246 .40194 Mtetra
.696 .57 .709 r
.36246 .40194 .36572 .41228 .3719 .40368 .36847 .39691 Mtetra
.565 .57 .817 r
.36847 .39691 .3719 .40368 .37776 .40169 .37426 .39652 Mtetra
.887 .72 .669 r
.37426 .39652 .37776 .40169 .38402 .39096 .38076 .38074 Mtetra
.398 .392 .735 r
.38076 .38074 .38402 .39096 .38982 .39071 .38641 .38383 Mtetra
.554 .561 .816 r
.38641 .38383 .38982 .39071 .39533 .39818 .39223 .38364 Mtetra
.641 .499 .673 r
.39223 .38364 .39533 .39818 .40132 .39429 .39821 .3798 Mtetra
.39821 .3798 .40132 .39429 .40725 .39228 .40419 .37598 Mtetra
.455 .361 .66 r
.40419 .37598 .40725 .39228 .41306 .39404 .40992 .37942 Mtetra
.641 .498 .673 r
.40992 .37942 .41306 .39404 .41917 .38765 .41594 .37554 Mtetra
.656 .528 .696 r
.41594 .37554 .41917 .38765 .42513 .38562 .42196 .37167 Mtetra
.606 .48 .683 r
.42196 .37167 .42513 .38562 .43141 .3734 .42793 .36963 Mtetra
.257 .554 .93 r
.42793 .36963 .43141 .3734 .43734 .37319 .4338 .37127 Mtetra
.857 .867 .846 r
.4338 .37127 .43734 .37319 .44336 .36983 .43991 .36518 Mtetra
.348 .55 .908 r
.43991 .36518 .44336 .36983 .44945 .36406 .44583 .3667 Mtetra
.937 .962 .671 r
.44583 .3667 .44945 .36406 .45539 .36517 .45207 .35566 Mtetra
.353 .379 .749 r
.45207 .35566 .45539 .36517 .46125 .37145 .45798 .35931 Mtetra
.265 .277 .686 r
.45798 .35931 .46125 .37145 .46733 .36849 .46387 .36559 Mtetra
.162 .558 .93 r
.46387 .36559 .46733 .36849 .47327 .37402 .46988 .3672 Mtetra
.065 .273 .763 r
.46988 .3672 .47327 .37402 .47921 .38295 .47587 .37241 Mtetra
.668 .554 .717 r
.47587 .37241 .47921 .38295 .48528 .38598 .48202 .36853 Mtetra
.683 .511 .647 r
.48202 .36853 .48528 .38598 .4914 .38756 .48822 .36089 Mtetra
.556 .393 .615 r
.48822 .36089 .4914 .38756 .49757 .3855 .49435 .36043 Mtetra
.549 .391 .62 r
.49435 .36043 .49757 .3855 .50372 .38998 .50049 .36053 Mtetra
.552 .384 .607 r
.50049 .36053 .50372 .38998 .50991 .39364 .50665 .36032 Mtetra
.677 .469 .597 r
.50665 .36032 .50991 .39364 .51618 .38202 .51289 .34601 Mtetra
.587 .4 .594 r
.51289 .34601 .51618 .38202 .52242 .37054 .51908 .34205 Mtetra
.649 .456 .608 r
.51908 .34205 .52242 .37054 .52864 .35892 .52527 .3331 Mtetra
.459 .326 .612 r
.52527 .3331 .52864 .35892 .53485 .34945 .53148 .33851 Mtetra
0 0 .311 r
.53148 .33851 .53485 .34945 .541 .33195 .53779 .3564 Mtetra
.575 .288 .443 r
.53779 .3564 .541 .33195 .54731 .34351 .5441 .36008 Mtetra
.733 .412 .437 r
.5441 .36008 .54731 .34351 .55366 .35261 .55055 .37601 Mtetra
.488 .21 .418 r
.55055 .37601 .55366 .35261 .56005 .35929 .5569 .3739 Mtetra
.471 .158 .354 r
.5569 .3739 .56005 .35929 .56663 .37708 .56328 .3724 Mtetra
.745 .735 .843 r
.56328 .3724 .56663 .37708 .57295 .37105 .56963 .36834 Mtetra
.276 .645 .966 r
.56963 .36834 .57295 .37105 .57954 .38128 .57608 .36923 Mtetra
.56 .475 .716 r
.57608 .36923 .57954 .38128 .58589 .37526 .58253 .36899 Mtetra
.321 .463 .847 r
.58253 .36899 .58589 .37526 .59253 .38337 .58906 .37172 Mtetra
.653 .537 .709 r
.58906 .37172 .59253 .38337 .59888 .37632 .59549 .36807 Mtetra
.685 .606 .762 r
.59549 .36807 .59888 .37632 .60537 .37471 .60192 .36436 Mtetra
.861 .66 .629 r
.60192 .36436 .60537 .37471 .61152 .36019 .60795 .34481 Mtetra
.724 .549 .653 r
.60795 .34481 .61152 .36019 .61751 .34163 .61419 .33501 Mtetra
.893 .716 .654 r
.61419 .33501 .61751 .34163 .6236 .32776 .62022 .31859 Mtetra
.857 .669 .647 r
.62022 .31859 .6236 .32776 .62971 .31554 .62621 .30221 Mtetra
.724 .561 .669 r
.62621 .30221 .62971 .31554 .63589 .30577 .63243 .29383 Mtetra
.35 .342 .709 r
.63243 .29383 .63589 .30577 .64218 .2996 .63913 .29898 Mtetra
.727 .197 0 r
.63913 .29898 .64218 .2996 .64901 .30709 .64597 .3064 Mtetra
.974 .884 .678 r
.64597 .3064 .64901 .30709 .65572 .31033 .65201 .29298 Mtetra
.536 .415 .662 r
.65201 .29298 .65572 .31033 .66239 .31185 .65862 .29374 Mtetra
.691 .513 .641 r
.65862 .29374 .66239 .31185 .66871 .30501 .66484 .28505 Mtetra
.513 .387 .645 r
.66484 .28505 .66871 .30501 .67604 .31929 .67156 .28703 Mtetra
.568 .391 .602 r
.67156 .28703 .67604 .31929 .68202 .30506 .67812 .2853 Mtetra
.463 .355 .645 r
.67812 .2853 .68202 .30506 .68793 .2902 .68501 .2896 Mtetra
.722 .974 .926 r
.68501 .2896 .68793 .2902 .69438 .28577 .69149 .28552 Mtetra
.971 .919 .688 r
.69149 .28552 .69438 .28577 .70109 .28592 .69753 .27338 Mtetra
.029 .121 .626 r
.69753 .27338 .70109 .28592 .70832 .29441 .70495 .28544 Mtetra
.688 .595 .747 r
.70495 .28544 .70832 .29441 .71495 .29216 .71147 .28131 Mtetra
.454 .427 .739 r
.71147 .28131 .71495 .29216 .72164 .29048 .71842 .28388 Mtetra
.301 .438 .832 r
.71842 .28388 .72164 .29048 .72866 .29364 .72545 .28725 Mtetra
.19 .375 .817 r
.72545 .28725 .72866 .29364 .73644 .30751 .73261 .29177 Mtetra
.56 .444 .678 r
.73261 .29177 .73644 .30751 .74359 .311 .73947 .29144 Mtetra
.622 .463 .645 r
.73947 .29144 .74359 .311 .74998 .30347 .74609 .28722 Mtetra
.515 .412 .675 r
.74609 .28722 .74998 .30347 .75647 .29731 .75314 .28884 Mtetra
.904 .699 .615 r
.75314 .28884 .75647 .29731 .76263 .28687 .75853 .26817 Mtetra
.594 .448 .653 r
.75853 .26817 .76263 .28687 .76973 .28848 .7653 .26587 Mtetra
.716 .513 .614 r
.7653 .26587 .76973 .28848 .7759 .27836 .77116 .25218 Mtetra
.602 .427 .618 r
.77116 .25218 .7759 .27836 .78191 .26647 .77778 .24808 Mtetra
.587 .445 .655 r
.77778 .24808 .78191 .26647 .78712 .24556 .7846 .2462 Mtetra
.503 0 0 r
.7846 .2462 .78712 .24556 .79465 .25186 .7919 .24964 Mtetra
.721 .895 .959 r
.7919 .24964 .79465 .25186 .80112 .24578 .79863 .24623 Mtetra
.954 .946 .643 r
.79863 .24623 .80112 .24578 .8079 .243 .80459 .23427 Mtetra
.291 .368 .769 r
.80459 .23427 .8079 .243 .81503 .24384 .81211 .23929 Mtetra
0 0 .538 r
.81211 .23929 .81503 .24384 .82297 .25273 .82016 .24922 Mtetra
0 .029 .558 r
.82016 .24922 .82297 .25273 .83091 .2608 .82811 .25747 Mtetra
.845 .854 .85 r
.82811 .25747 .83091 .2608 .83785 .25846 .83468 .25123 Mtetra
.335 .741 .981 r
.21646 .44509 .22041 .44678 .22596 .44489 .22185 .44501 Mtetra
.87 .486 .312 r
.22185 .44501 .22596 .44489 .23102 .44852 .22615 .45698 Mtetra
.562 .201 .313 r
.22615 .45698 .23102 .44852 .23627 .45028 .23142 .4588 Mtetra
.767 .438 .429 r
.23142 .4588 .23627 .45028 .24122 .45582 .23578 .47131 Mtetra
.513 .205 .382 r
.23578 .47131 .24122 .45582 .2463 .46032 .24127 .47132 Mtetra
0 0 0 r
.24127 .47132 .2463 .46032 .252 .45765 .248 .45684 Mtetra
.801 .922 .918 r
.248 .45684 .252 .45765 .25811 .45011 .25386 .45261 Mtetra
.977 .856 .654 r
.25386 .45261 .25811 .45011 .26442 .44005 .26082 .43483 Mtetra
.819 .706 .741 r
.26082 .43483 .26442 .44005 .27044 .43345 .26697 .42667 Mtetra
.341 .444 .821 r
.26697 .42667 .27044 .43345 .27597 .43316 .27229 .42905 Mtetra
.807 .741 .79 r
.27229 .42905 .27597 .43316 .28199 .42655 .27829 .42296 Mtetra
.837 .761 .778 r
.27829 .42296 .28199 .42655 .28837 .415 .28437 .41573 Mtetra
.685 .178 .028 r
.28437 .41573 .28837 .415 .29393 .41462 .2896 .41999 Mtetra
0 0 0 r
.2896 .41999 .29393 .41462 .29937 .41628 .2957 .41268 Mtetra
.808 .337 0 r
.2957 .41268 .29937 .41628 .30436 .42486 .30068 .42126 Mtetra
.145 .5 .908 r
.30068 .42126 .30436 .42486 .30996 .42509 .30616 .42326 Mtetra
.773 .868 .919 r
.30616 .42326 .30996 .42509 .31548 .4267 .31204 .41952 Mtetra
.113 .29 .765 r
.31204 .41952 .31548 .4267 .32169 .4177 .3174 .42407 Mtetra
.13 0 0 r
.3174 .42407 .32169 .4177 .32747 .41574 .3233 .42033 Mtetra
.846 .953 .604 r
.3233 .42033 .32747 .41574 .33355 .40881 .32961 .41013 Mtetra
.233 .737 .675 r
.32961 .41013 .33355 .40881 .33924 .40845 .33541 .40815 Mtetra
.941 .866 .736 r
.33541 .40815 .33924 .40845 .34488 .40949 .34175 .39702 Mtetra
.651 .521 .691 r
.34175 .39702 .34488 .40949 .3507 .40751 .34766 .39329 Mtetra
.647 .504 .674 r
.34766 .39329 .3507 .40751 .35654 .40553 .3536 .38924 Mtetra
.586 .45 .662 r
.3536 .38924 .35654 .40553 .36246 .40194 .3594 .38778 Mtetra
.669 .518 .672 r
.3594 .38778 .36246 .40194 .36847 .39691 .36541 .38256 Mtetra
.378 .324 .67 r
.36541 .38256 .36847 .39691 .37426 .39652 .37094 .38735 Mtetra
.794 .635 .684 r
.37094 .38735 .37426 .39652 .38076 .38074 .37722 .37664 Mtetra
.552 .68 .923 r
.37722 .37664 .38076 .38074 .38641 .38383 .38303 .37609 Mtetra
.718 .621 .748 r
.38303 .37609 .38641 .38383 .39223 .38364 .38904 .37138 Mtetra
.499 .427 .706 r
.38904 .37138 .39223 .38364 .39821 .3798 .3948 .37285 Mtetra
.553 .56 .815 r
.3948 .37285 .39821 .3798 .40419 .37598 .40064 .37267 Mtetra
.762 .788 .874 r
.40064 .37267 .40419 .37598 .40992 .37942 .40665 .36878 Mtetra
.584 .501 .727 r
.40665 .36878 .40992 .37942 .41594 .37554 .41255 .36786 Mtetra
.571 .549 .792 r
.41255 .36786 .41594 .37554 .42196 .37167 .41846 .36737 Mtetra
.661 .713 .886 r
.41846 .36737 .42196 .37167 .42793 .36963 .42444 .36532 Mtetra
.539 .665 .919 r
.42444 .36532 .42793 .36963 .4338 .37127 .43038 .36494 Mtetra
0 .07 .633 r
.43038 .36494 .4338 .37127 .43991 .36518 .43614 .37191 Mtetra
.328 0 .126 r
.43614 .37191 .43991 .36518 .44583 .3667 .44218 .36985 Mtetra
.982 .911 .616 r
.44218 .36985 .44583 .3667 .45207 .35566 .44856 .35398 Mtetra
.672 .884 .976 r
.44856 .35398 .45207 .35566 .45798 .35931 .45461 .35149 Mtetra
0 .173 .696 r
.45461 .35149 .45798 .35931 .46387 .36559 .46048 .35823 Mtetra
.554 .551 .806 r
.46048 .35823 .46387 .36559 .46988 .3672 .46652 .35804 Mtetra
.726 .604 .721 r
.46652 .35804 .46988 .3672 .47587 .37241 .47269 .35218 Mtetra
.607 .447 .639 r
.47269 .35218 .47587 .37241 .48202 .36853 .47881 .34895 Mtetra
.683 .502 .635 r
.47881 .34895 .48202 .36853 .48822 .36089 .48501 .34031 Mtetra
.558 .412 .639 r
.48501 .34031 .48822 .36089 .49435 .36043 .4911 .33992 Mtetra
.616 .453 .637 r
.4911 .33992 .49435 .36043 .50049 .36053 .49725 .33601 Mtetra
.559 .399 .622 r
.49725 .33601 .50049 .36053 .50665 .36032 .50339 .33542 Mtetra
.536 .382 .62 r
.50339 .33542 .50665 .36032 .51289 .34601 .50954 .33627 Mtetra
.715 .591 .716 r
.50954 .33627 .51289 .34601 .51908 .34205 .51573 .33058 Mtetra
0 0 .357 r
.51573 .33058 .51908 .34205 .52527 .3331 .5219 .34762 Mtetra
.654 .327 .407 r
.5219 .34762 .52527 .3331 .53148 .33851 .52815 .3551 Mtetra
.749 .428 .441 r
.52815 .3551 .53148 .33851 .53779 .3564 .53448 .37315 Mtetra
.771 .45 .444 r
.53448 .37315 .53779 .3564 .5441 .36008 .54093 .39469 Mtetra
.431 .183 .436 r
.54093 .39469 .5441 .36008 .55055 .37601 .54728 .38662 Mtetra
0 0 .027 r
.54728 .38662 .55055 .37601 .5569 .3739 .55358 .37463 Mtetra
.985 .884 .642 r
.55358 .37463 .5569 .3739 .56328 .3724 .55982 .35886 Mtetra
.739 .57 .663 r
.55982 .35886 .56328 .3724 .56963 .36834 .56609 .34914 Mtetra
.674 .498 .639 r
.56609 .34914 .56963 .36834 .57608 .36923 .57238 .34135 Mtetra
.435 .305 .604 r
.57238 .34135 .57608 .36923 .58253 .36899 .57892 .34857 Mtetra
.233 .191 .604 r
.57892 .34857 .58253 .36899 .58906 .37172 .5856 .36082 Mtetra
.168 .24 .695 r
.5856 .36082 .58906 .37172 .59549 .36807 .59226 .36837 Mtetra
.973 .912 .684 r
.59226 .36837 .59549 .36807 .60192 .36436 .59851 .35552 Mtetra
.884 .683 .626 r
.59851 .35552 .60192 .36436 .60795 .34481 .60453 .33507 Mtetra
.875 .671 .623 r
.60453 .33507 .60795 .34481 .61419 .33501 .61048 .31434 Mtetra
.712 .518 .624 r
.61048 .31434 .61419 .33501 .62022 .31859 .61663 .30224 Mtetra
.696 .525 .652 r
.61663 .30224 .62022 .31859 .62621 .30221 .62287 .29407 Mtetra
.598 .561 .784 r
.62287 .29407 .62621 .30221 .63243 .29383 .62934 .29288 Mtetra
.416 0 0 r
.62934 .29288 .63243 .29383 .63913 .29898 .63599 .29632 Mtetra
.847 .861 .853 r
.63599 .29632 .63913 .29898 .64597 .3064 .64232 .29031 Mtetra
.673 .512 .658 r
.64232 .29031 .64597 .3064 .65201 .29298 .64864 .28392 Mtetra
.487 .478 .773 r
.64864 .28392 .65201 .29298 .65862 .29374 .65528 .28527 Mtetra
.326 .393 .778 r
.65528 .28527 .65862 .29374 .66484 .28505 .66207 .28921 Mtetra
.412 0 .025 r
.66207 .28921 .66484 .28505 .67156 .28703 .66872 .28934 Mtetra
.682 .183 .053 r
.66872 .28934 .67156 .28703 .67812 .2853 .67565 .29487 Mtetra
.187 0 .178 r
.67565 .29487 .67812 .2853 .68501 .2896 .68204 .28846 Mtetra
.883 .952 .847 r
.68204 .28846 .68501 .2896 .69149 .28552 .6884 .2817 Mtetra
.9 .805 .745 r
.6884 .2817 .69149 .28552 .69753 .27338 .69458 .27172 Mtetra
.904 .919 .819 r
.69458 .27172 .69753 .27338 .70495 .28544 .70088 .26412 Mtetra
.58 .427 .638 r
.70088 .26412 .70495 .28544 .71147 .28131 .70751 .26234 Mtetra
.39 .31 .645 r
.70751 .26234 .71147 .28131 .71842 .28388 .71471 .26936 Mtetra
.511 .421 .69 r
.71471 .26936 .71842 .28388 .72545 .28725 .72161 .27093 Mtetra
.33 .288 .659 r
.72161 .27093 .72545 .28725 .73261 .29177 .72897 .2789 Mtetra
.561 .469 .708 r
.72897 .2789 .73261 .29177 .73947 .29144 .73583 .27857 Mtetra
.612 .501 .702 r
.73583 .27857 .73947 .29144 .74609 .28722 .74257 .27628 Mtetra
.671 .558 .718 r
.74257 .27628 .74609 .28722 .75314 .28884 .74919 .27203 Mtetra
.692 .521 .65 r
.74919 .27203 .75314 .28884 .75853 .26817 .75553 .26392 Mtetra
.662 .743 .91 r
.75553 .26392 .75853 .26817 .7653 .26587 .7623 .26161 Mtetra
.933 .793 .682 r
.7623 .26161 .7653 .26587 .77116 .25218 .76819 .2479 Mtetra
.85 .797 .799 r
.76819 .2479 .77116 .25218 .77778 .24808 .77456 .24064 Mtetra
.578 .574 .812 r
.77456 .24064 .77778 .24808 .7846 .2462 .78148 .23988 Mtetra
.72 .679 .81 r
.78148 .23988 .7846 .2462 .7919 .24964 .78813 .2358 Mtetra
.551 .453 .697 r
.78813 .2358 .7919 .24964 .79863 .24623 .79516 .23585 Mtetra
.422 .417 .749 r
.79516 .23585 .79863 .24623 .80459 .23427 .8025 .23909 Mtetra
.712 .262 .182 r
.8025 .23909 .80459 .23427 .81211 .23929 .81029 .24664 Mtetra
.526 .124 .22 r
.81029 .24664 .81211 .23929 .82016 .24922 .81757 .2482 Mtetra
.658 .116 0 r
.81757 .2482 .82016 .24922 .82811 .25747 .82552 .25626 Mtetra
.744 .967 .933 r
.82552 .25626 .82811 .25747 .83468 .25123 .8323 .25193 Mtetra
0 .209 .693 r
.21266 .44158 .21646 .44509 .22185 .44501 .21771 .44517 Mtetra
.881 .513 .342 r
.21771 .44517 .22185 .44501 .22615 .45698 .22183 .45907 Mtetra
.292 0 0 r
.22183 .45907 .22615 .45698 .23142 .4588 .22728 .45904 Mtetra
.872 .491 .319 r
.22728 .45904 .23142 .4588 .23578 .47131 .23162 .47162 Mtetra
.437 .874 .891 r
.23162 .47162 .23578 .47131 .24127 .47132 .23729 .46972 Mtetra
.556 0 0 r
.23729 .46972 .24127 .47132 .248 .45684 .24249 .47341 Mtetra
.862 .829 .355 r
.24249 .47341 .248 .45684 .25386 .45261 .25039 .44544 Mtetra
.807 .664 .705 r
.25039 .44544 .25386 .45261 .26082 .43483 .25671 .43565 Mtetra
.943 .906 .756 r
.25671 .43565 .26082 .43483 .26697 .42667 .26303 .4256 Mtetra
.694 .152 0 r
.26303 .4256 .26697 .42667 .27229 .42905 .26818 .43037 Mtetra
.961 .886 .711 r
.26818 .43037 .27229 .42905 .27829 .42296 .2747 .41774 Mtetra
.671 .668 .838 r
.2747 .41774 .27829 .42296 .28437 .41573 .28041 .41544 Mtetra
.709 .954 .951 r
.28041 .41544 .28437 .41573 .2896 .41999 .28621 .4122 Mtetra
.634 .576 .772 r
.28621 .4122 .2896 .41999 .2957 .41268 .29192 .41027 Mtetra
.421 0 0 r
.29192 .41027 .2957 .41268 .30068 .42126 .29725 .41389 Mtetra
.535 .536 .802 r
.29725 .41389 .30068 .42126 .30616 .42326 .30285 .41404 Mtetra
.48 .46 .759 r
.30285 .41404 .30616 .42326 .31204 .41952 .30839 .41539 Mtetra
.19 .493 .903 r
.30839 .41539 .31204 .41952 .3174 .42407 .3139 .41749 Mtetra
.709 .642 .78 r
.3139 .41749 .3174 .42407 .3233 .42033 .31982 .41372 Mtetra
.846 .687 .686 r
.31982 .41372 .3233 .42033 .32961 .41013 .32629 .4009 Mtetra
.744 .609 .707 r
.32629 .4009 .32961 .41013 .33541 .40815 .3324 .39387 Mtetra
.606 .477 .678 r
.3324 .39387 .33541 .40815 .34175 .39702 .33821 .39175 Mtetra
.829 .713 .736 r
.33821 .39175 .34175 .39702 .34766 .39329 .34441 .38303 Mtetra
.515 .463 .737 r
.34441 .38303 .34766 .39329 .3536 .38924 .35008 .38386 Mtetra
.097 .36 .826 r
.35008 .38386 .3536 .38924 .3594 .38778 .35562 .38739 Mtetra
.326 0 0 r
.35562 .38739 .3594 .38778 .36541 .38256 .36129 .38913 Mtetra
0 0 0 r
.36129 .38913 .36541 .38256 .37094 .38735 .36736 .38336 Mtetra
.754 .75 .849 r
.36736 .38336 .37094 .38735 .37722 .37664 .37334 .37941 Mtetra
.81 .982 .702 r
.37334 .37941 .37722 .37664 .38303 .37609 .37948 .37189 Mtetra
.692 .726 .876 r
.37948 .37189 .38303 .37609 .38904 .37138 .38541 .36932 Mtetra
0 .506 .859 r
.38541 .36932 .38904 .37138 .3948 .37285 .39117 .37095 Mtetra
.182 .642 .939 r
.39117 .37095 .3948 .37285 .40064 .37267 .39699 .37167 Mtetra
.85 .921 .878 r
.39699 .37167 .40064 .37267 .40665 .36878 .40307 .36617 Mtetra
.66 .814 .957 r
.40307 .36617 .40665 .36878 .41255 .36786 .40903 .36408 Mtetra
.735 .76 .873 r
.40903 .36408 .41255 .36786 .41846 .36737 .41504 .36068 Mtetra
.645 .615 .804 r
.41504 .36068 .41846 .36737 .42444 .36532 .42102 .35862 Mtetra
.581 .583 .82 r
.42102 .35862 .42444 .36532 .43038 .36494 .42697 .3579 Mtetra
0 0 .531 r
.42697 .3579 .43038 .36494 .43614 .37191 .43267 .36663 Mtetra
.724 .694 .822 r
.43267 .36663 .43614 .37191 .44218 .36985 .43876 .36294 Mtetra
.809 .678 .719 r
.43876 .36294 .44218 .36985 .44856 .35398 .44498 .35399 Mtetra
.564 .932 .922 r
.44498 .35399 .44856 .35398 .45461 .35149 .45105 .3513 Mtetra
.183 0 0 r
.45105 .3513 .45461 .35149 .46048 .35823 .45705 .35229 Mtetra
.651 .644 .83 r
.45705 .35229 .46048 .35823 .46652 .35804 .46314 .3502 Mtetra
.692 .611 .761 r
.46314 .3502 .46652 .35804 .47269 .35218 .46927 .34643 Mtetra
.698 .67 .819 r
.46927 .34643 .47269 .35218 .47881 .34895 .47539 .34327 Mtetra
.825 .713 .741 r
.47539 .34327 .47881 .34895 .48501 .34031 .4816 .3349 Mtetra
.304 .487 .873 r
.4816 .3349 .48501 .34031 .4911 .33992 .48767 .33719 Mtetra
0 .342 .777 r
.48767 .33719 .4911 .33992 .49725 .33601 .49377 .3403 Mtetra
.525 .069 .112 r
.49377 .3403 .49725 .33601 .50339 .33542 .49991 .34195 Mtetra
.449 .044 .178 r
.49991 .34195 .50339 .33542 .50954 .33627 .50609 .3418 Mtetra
.426 0 .12 r
.50609 .3418 .50954 .33627 .51573 .33058 .51229 .34157 Mtetra
.772 .431 .407 r
.51229 .34157 .51573 .33058 .5219 .34762 .51848 .35728 Mtetra
.604 .243 .329 r
.51848 .35728 .5219 .34762 .52815 .3551 .52476 .36099 Mtetra
.472 .051 .159 r
.52476 .36099 .52815 .3551 .53448 .37315 .53106 .36143 Mtetra
.298 .311 .705 r
.53106 .36143 .53448 .37315 .54093 .39469 .53741 .36711 Mtetra
.688 .485 .607 r
.53741 .36711 .54093 .39469 .54728 .38662 .5437 .354 Mtetra
.687 .476 .596 r
.5437 .354 .54728 .38662 .55358 .37463 .54994 .33846 Mtetra
.714 .492 .586 r
.54994 .33846 .55358 .37463 .55982 .35886 .55607 .31629 Mtetra
.45 .292 .574 r
.55607 .31629 .55982 .35886 .56609 .34914 .56252 .32565 Mtetra
.61 .439 .626 r
.56252 .32565 .56609 .34914 .57238 .34135 .56883 .32151 Mtetra
.255 .208 .611 r
.56883 .32151 .57238 .34135 .57892 .34857 .5754 .33267 Mtetra
.008 .066 .574 r
.5754 .33267 .57892 .34857 .5856 .36082 .58209 .3469 Mtetra
.17 .198 .648 r
.58209 .3469 .5856 .36082 .59226 .36837 .58877 .35648 Mtetra
.81 .623 .649 r
.58877 .35648 .59226 .36837 .59851 .35552 .59498 .34174 Mtetra
.86 .637 .599 r
.59498 .34174 .59851 .35552 .60453 .33507 .60087 .31548 Mtetra
.755 .549 .618 r
.60087 .31548 .60453 .33507 .61048 .31434 .60694 .29925 Mtetra
.738 .558 .65 r
.60694 .29925 .61048 .31434 .61663 .30224 .61312 .2885 Mtetra
.562 .458 .693 r
.61312 .2885 .61663 .30224 .62287 .29407 .6196 .28812 Mtetra
.483 .568 .865 r
.6196 .28812 .62287 .29407 .62934 .29288 .62613 .28879 Mtetra
.642 .184 0 r
.62613 .28879 .62934 .29288 .63599 .29632 .63301 .29881 Mtetra
0 0 0 r
.63301 .29881 .63599 .29632 .64232 .29031 .63945 .29487 Mtetra
.63945 .29487 .64232 .29031 .64864 .28392 .64577 .28771 Mtetra
.64577 .28771 .64864 .28392 .65528 .28527 .65213 .28158 Mtetra
0 0 .517 r
.65213 .28158 .65528 .28527 .66207 .28921 .65907 .28904 Mtetra
.914 .972 .787 r
.65907 .28904 .66207 .28921 .66872 .28934 .66536 .28085 Mtetra
.148 .278 .742 r
.66536 .28085 .66872 .28934 .67565 .29487 .67233 .28725 Mtetra
.775 .663 .74 r
.67233 .28725 .67565 .29487 .68204 .28846 .67869 .28017 Mtetra
.741 .635 .741 r
.67869 .28017 .68204 .28846 .6884 .2817 .6851 .27419 Mtetra
.744 .652 .759 r
.6851 .27419 .6884 .2817 .69458 .27172 .69153 .26862 Mtetra
.899 .84 .779 r
.69153 .26862 .69458 .27172 .70088 .26412 .69779 .25992 Mtetra
.499 .667 .938 r
.69779 .25992 .70088 .26412 .70751 .26234 .70453 .25984 Mtetra
.746 .26 0 r
.70453 .25984 .70751 .26234 .71471 .26936 .71198 .27093 Mtetra
0 0 0 r
.71198 .27093 .71471 .26936 .72161 .27093 .71866 .26864 Mtetra
0 .267 .704 r
.71866 .26864 .72161 .27093 .72897 .2789 .72578 .27272 Mtetra
.652 .652 .837 r
.72578 .27272 .72897 .2789 .73583 .27857 .73251 .27043 Mtetra
.604 .57 .789 r
.73251 .27043 .73583 .27857 .74257 .27628 .73931 .26904 Mtetra
.559 .57 .821 r
.73931 .26904 .74257 .27628 .74919 .27203 .74622 .26866 Mtetra
.84 .841 .846 r
.74622 .26866 .74919 .27203 .75553 .26392 .75272 .26251 Mtetra
.901 .946 .826 r
.75272 .26251 .75553 .26392 .7623 .26161 .75912 .25505 Mtetra
.786 .699 .768 r
.75912 .25505 .7623 .26161 .76819 .2479 .76558 .24845 Mtetra
.422 .862 .773 r
.76558 .24845 .76819 .2479 .77456 .24064 .77231 .2453 Mtetra
.407 0 .05 r
.77231 .2453 .77456 .24064 .78148 .23988 .77931 .2452 Mtetra
.307 0 .054 r
.77931 .2452 .78148 .23988 .78813 .2358 .78619 .24327 Mtetra
.4 .014 .188 r
.78619 .24327 .78813 .2358 .79516 .23585 .79312 .2418 Mtetra
.487 .059 .151 r
.79312 .2418 .79516 .23585 .8025 .23909 .80028 .2427 Mtetra
.48 0 0 r
.80028 .2427 .8025 .23909 .81029 .24664 .80754 .24425 Mtetra
0 .373 .797 r
.80754 .24425 .81029 .24664 .81757 .2482 .81502 .24777 Mtetra
.722 .193 0 r
.81502 .24777 .81757 .2482 .82552 .25626 .82308 .25689 Mtetra
.73 .978 .749 r
.82308 .25689 .82552 .25626 .8323 .25193 .82969 .25057 Mtetra
.43 0 0 r
.20849 .44171 .21266 .44158 .21771 .44517 .21372 .44349 Mtetra
.903 .519 .288 r
.21372 .44349 .21771 .44517 .22183 .45907 .21787 .45693 Mtetra
.382 .737 .991 r
.21787 .45693 .22183 .45907 .22728 .45904 .22333 .45686 Mtetra
.891 .476 .204 r
.22333 .45686 .22728 .45904 .23162 .47162 .22779 .46804 Mtetra
.66 .743 .911 r
.22779 .46804 .23162 .47162 .23729 .46972 .23347 .46613 Mtetra
.855 .756 .753 r
.23347 .46613 .23729 .46972 .24249 .47341 .23976 .45733 Mtetra
.785 .586 .631 r
.23976 .45733 .24249 .47341 .25039 .44544 .24685 .43898 Mtetra
.795 .673 .729 r
.24685 .43898 .25039 .44544 .25671 .43565 .25302 .43108 Mtetra
.841 .726 .737 r
.25302 .43108 .25671 .43565 .26303 .4256 .25928 .42201 Mtetra
.383 .634 .954 r
.25928 .42201 .26303 .4256 .26818 .43037 .26475 .42267 Mtetra
.726 .623 .742 r
.26475 .42267 .26818 .43037 .2747 .41774 .27069 .41762 Mtetra
.864 .944 .868 r
.27069 .41762 .2747 .41774 .28041 .41544 .27669 .41182 Mtetra
0 .154 .649 r
.27669 .41182 .28041 .41544 .28621 .4122 .28194 .41597 Mtetra
.945 .957 .672 r
.28194 .41597 .28621 .4122 .29192 .41027 .28838 .4043 Mtetra
.15 .365 .819 r
.28838 .4043 .29192 .41027 .29725 .41389 .29372 .40773 Mtetra
.706 .651 .793 r
.29372 .40773 .29725 .41389 .30285 .41404 .29958 .40423 Mtetra
.397 .398 .743 r
.29958 .40423 .30285 .41404 .30839 .41539 .30501 .40703 Mtetra
.639 .568 .759 r
.30501 .40703 .30839 .41539 .3139 .41749 .3108 .40486 Mtetra
.488 .414 .7 r
.3108 .40486 .3139 .41749 .31982 .41372 .31635 .40657 Mtetra
.836 .677 .684 r
.31635 .40657 .31982 .41372 .32629 .4009 .32283 .39397 Mtetra
.834 .679 .691 r
.32283 .39397 .32629 .4009 .3324 .39387 .32924 .38216 Mtetra
.525 .449 .713 r
.32924 .38216 .3324 .39387 .33821 .39175 .33488 .38284 Mtetra
0 .002 .574 r
.33488 .38284 .33821 .39175 .34441 .38303 .34009 .39145 Mtetra
.573 .205 .306 r
.34009 .39145 .34441 .38303 .35008 .38386 .3457 .39374 Mtetra
.287 0 .196 r
.3457 .39374 .35008 .38386 .35562 .38739 .35167 .38983 Mtetra
.877 .99 .734 r
.35167 .38983 .35562 .38739 .36129 .38913 .35787 .38165 Mtetra
.745 .639 .742 r
.35787 .38165 .36129 .38913 .36736 .38336 .36394 .37591 Mtetra
.792 .658 .715 r
.36394 .37591 .36736 .38336 .37334 .37941 .37014 .36739 Mtetra
.389 .358 .704 r
.37014 .36739 .37334 .37941 .37948 .37189 .37576 .37115 Mtetra
.647 .929 .972 r
.37576 .37115 .37948 .37189 .38541 .36932 .3817 .36853 Mtetra
.572 .904 .979 r
.3817 .36853 .38541 .36932 .39117 .37095 .38763 .36648 Mtetra
.539 .657 .912 r
.38763 .36648 .39117 .37095 .39699 .37167 .39349 .36613 Mtetra
.722 .682 .811 r
.39349 .36613 .39699 .37167 .40307 .36617 .39952 .36238 Mtetra
.54 .697 .942 r
.39952 .36238 .40307 .36617 .40903 .36408 .40542 .36184 Mtetra
.846 .849 .846 r
.40542 .36184 .40903 .36408 .41504 .36068 .41154 .35593 Mtetra
.492 .621 .907 r
.41154 .35593 .41504 .36068 .42102 .35862 .41745 .35615 Mtetra
.476 .762 .993 r
.41745 .35615 .42102 .35862 .42697 .3579 .42341 .35564 Mtetra
.442 .762 .996 r
.42341 .35564 .42697 .3579 .43267 .36663 .42938 .35524 Mtetra
.562 .479 .719 r
.42938 .35524 .43267 .36663 .43876 .36294 .43536 .35491 Mtetra
.729 .624 .741 r
.43536 .35491 .43876 .36294 .44498 .35399 .4415 .34957 Mtetra
.79 .745 .812 r
.4415 .34957 .44498 .35399 .45105 .3513 .44765 .34421 Mtetra
.5 .53 .819 r
.44765 .34421 .45105 .3513 .45705 .35229 .45365 .34487 Mtetra
.561 .554 .804 r
.45365 .34487 .45705 .35229 .46314 .3502 .4597 .34452 Mtetra
.827 .713 .739 r
.4597 .34452 .46314 .3502 .46927 .34643 .46593 .33599 Mtetra
.606 .52 .73 r
.46593 .33599 .46927 .34643 .47539 .34327 .47203 .33437 Mtetra
.574 .527 .765 r
.47203 .33437 .47539 .34327 .4816 .3349 .47813 .33375 Mtetra
.374 0 0 r
.47813 .33375 .4816 .3349 .48767 .33719 .4842 .33662 Mtetra
.523 0 0 r
.4842 .33662 .48767 .33719 .49377 .3403 .4903 .34016 Mtetra
.554 0 0 r
.4903 .34016 .49377 .3403 .49991 .34195 .49643 .34374 Mtetra
.236 0 0 r
.49643 .34374 .49991 .34195 .50609 .3418 .50263 .34359 Mtetra
.467 .864 .681 r
.50263 .34359 .50609 .3418 .51229 .34157 .50887 .33955 Mtetra
.592 .845 .992 r
.50887 .33955 .51229 .34157 .51848 .35728 .51511 .33784 Mtetra
.514 .387 .645 r
.51511 .33784 .51848 .35728 .52476 .36099 .52136 .33953 Mtetra
.523 .385 .635 r
.52136 .33953 .52476 .36099 .53106 .36143 .52764 .34094 Mtetra
.253 .202 .604 r
.52764 .34094 .53106 .36143 .53741 .36711 .53397 .35219 Mtetra
.837 .62 .608 r
.53397 .35219 .53741 .36711 .5437 .354 .54021 .32814 Mtetra
.656 .465 .614 r
.54021 .32814 .5437 .354 .54994 .33846 .54647 .31935 Mtetra
.72 .528 .63 r
.54647 .31935 .54994 .33846 .55607 .31629 .5527 .30744 Mtetra
.104 .237 .718 r
.5527 .30744 .55607 .31629 .56252 .32565 .5591 .31412 Mtetra
.548 .472 .722 r
.5591 .31412 .56252 .32565 .56883 .32151 .56547 .31419 Mtetra
0 0 .398 r
.56547 .31419 .56883 .32151 .5754 .33267 .57204 .32668 Mtetra
0 0 .501 r
.57204 .32668 .5754 .33267 .58209 .3469 .57864 .33622 Mtetra
.342 .358 .732 r
.57864 .33622 .58209 .3469 .58877 .35648 .58521 .34072 Mtetra
.799 .593 .623 r
.58521 .34072 .58877 .35648 .59498 .34174 .59134 .32248 Mtetra
.745 .544 .623 r
.59134 .32248 .59498 .34174 .60087 .31548 .5975 .30773 Mtetra
.833 .68 .693 r
.5975 .30773 .60087 .31548 .60694 .29925 .60371 .29643 Mtetra
.906 .836 .765 r
.60371 .29643 .60694 .29925 .61312 .2885 .60996 .28713 Mtetra
.582 .017 0 r
.60996 .28713 .61312 .2885 .6196 .28812 .61662 .29257 Mtetra
.002 0 0 r
.61662 .29257 .6196 .28812 .62613 .28879 .62302 .28844 Mtetra
.784 .283 0 r
.62302 .28844 .62613 .28879 .63301 .29881 .62988 .29747 Mtetra
0 .493 .798 r
.62988 .29747 .63301 .29881 .63945 .29487 .63653 .29907 Mtetra
.789 .884 .461 r
.63653 .29907 .63945 .29487 .64577 .28771 .6427 .28685 Mtetra
.27 .757 .917 r
.6427 .28685 .64577 .28771 .65213 .28158 .6493 .28626 Mtetra
0 0 0 r
.6493 .28626 .65213 .28158 .65907 .28904 .65566 .27947 Mtetra
.571 .519 .758 r
.65566 .27947 .65907 .28904 .66536 .28085 .66229 .27887 Mtetra
.892 .9 .826 r
.66229 .27887 .66536 .28085 .67233 .28725 .66863 .27153 Mtetra
.607 .473 .672 r
.66863 .27153 .67233 .28725 .67869 .28017 .6752 .26894 Mtetra
.524 .465 .732 r
.6752 .26894 .67869 .28017 .6851 .27419 .68195 .26967 Mtetra
.871 .779 .758 r
.68195 .26967 .6851 .27419 .69153 .26862 .68821 .26074 Mtetra
0 .147 .682 r
.68821 .26074 .69153 .26862 .69779 .25992 .69543 .26935 Mtetra
.471 .107 .266 r
.69543 .26935 .69779 .25992 .70453 .25984 .7022 .26899 Mtetra
.536 .162 .279 r
.7022 .26899 .70453 .25984 .71198 .27093 .70911 .27058 Mtetra
.465 .887 .91 r
.70911 .27058 .71198 .27093 .71866 .26864 .71582 .26828 Mtetra
.029 .598 .766 r
.71582 .26828 .71866 .26864 .72578 .27272 .72269 .26848 Mtetra
.758 .777 .868 r
.72269 .26848 .72578 .27272 .73251 .27043 .72931 .26422 Mtetra
.091 .319 .796 r
.72931 .26422 .73251 .27043 .73931 .26904 .73658 .2696 Mtetra
.77 .264 0 r
.73658 .2696 .73931 .26904 .74622 .26866 .74419 .27889 Mtetra
0 0 0 r
.74419 .27889 .74622 .26866 .75272 .26251 .74976 .25928 Mtetra
.958 .819 .665 r
.74976 .25928 .75272 .26251 .75912 .25505 .75562 .24444 Mtetra
.453 .433 .746 r
.75562 .24444 .75912 .25505 .76558 .24845 .76279 .24692 Mtetra
.504 0 0 r
.76279 .24692 .76558 .24845 .77231 .2453 .77025 .25263 Mtetra
.436 .041 .19 r
.77025 .25263 .77231 .2453 .77931 .2452 .77725 .25204 Mtetra
.633 .215 .233 r
.77725 .25204 .77931 .2452 .78619 .24327 .78473 .25695 Mtetra
.397 .089 .322 r
.78473 .25695 .78619 .24327 .79312 .2418 .79151 .25304 Mtetra
.348 .027 .271 r
.79151 .25304 .79312 .2418 .80028 .2427 .79825 .24871 Mtetra
.422 0 .128 r
.79825 .24871 .80028 .2427 .80754 .24425 .80537 .24832 Mtetra
.587 .105 .078 r
.80537 .24832 .80754 .24425 .81502 .24777 .81288 .25188 Mtetra
.626 .147 .097 r
.81288 .25188 .81502 .24777 .82308 .25689 .82053 .25647 Mtetra
.902 .985 .773 r
.82053 .25647 .82308 .25689 .82969 .25057 .82697 .24816 Mtetra
.235 0 0 r
.20414 .44345 .20849 .44171 .21372 .44349 .20956 .44332 Mtetra
.873 .486 .302 r
.20956 .44332 .21372 .44349 .21787 .45693 .21385 .45526 Mtetra
.326 .74 .978 r
.21385 .45526 .21787 .45693 .22333 .45686 .21932 .45517 Mtetra
0 .402 .736 r
.21932 .45517 .22333 .45686 .22779 .46804 .22463 .45697 Mtetra
.648 .533 .709 r
.22463 .45697 .22779 .46804 .23347 .46613 .23041 .45381 Mtetra
.791 .606 .652 r
.23041 .45381 .23347 .46613 .23976 .45733 .23722 .43917 Mtetra
.697 .518 .641 r
.23722 .43917 .23976 .45733 .24685 .43898 .24351 .43 Mtetra
.773 .625 .696 r
.24351 .43 .24685 .43898 .25302 .43108 .24978 .42109 Mtetra
.668 .556 .72 r
.24978 .42109 .25302 .43108 .25928 .42201 .25559 .41749 Mtetra
.342 .555 .913 r
.25559 .41749 .25928 .42201 .26475 .42267 .26101 .41882 Mtetra
.848 .751 .756 r
.26101 .41882 .26475 .42267 .27069 .41762 .26722 .41044 Mtetra
.776 .653 .727 r
.26722 .41044 .27069 .41762 .27669 .41182 .27334 .40313 Mtetra
.745 .616 .715 r
.27334 .40313 .27669 .41182 .28194 .41597 .27941 .39643 Mtetra
.342 .258 .615 r
.27941 .39643 .28194 .41597 .28838 .4043 .28444 .40354 Mtetra
.835 .383 .145 r
.28444 .40354 .28838 .4043 .29372 .40773 .28942 .41205 Mtetra
.891 .966 .642 r
.28942 .41205 .29372 .40773 .29958 .40423 .2958 .40151 Mtetra
.767 .814 .89 r
.2958 .40151 .29958 .40423 .30501 .40703 .30169 .39772 Mtetra
.669 .568 .732 r
.30169 .39772 .30501 .40703 .3108 .40486 .30757 .39428 Mtetra
.556 .484 .729 r
.30757 .39428 .3108 .40486 .31635 .40657 .31323 .3941 Mtetra
.771 .593 .658 r
.31323 .3941 .31635 .40657 .32283 .39397 .31968 .38203 Mtetra
.665 .534 .695 r
.31968 .38203 .32283 .39397 .32924 .38216 .32562 .37783 Mtetra
.721 .254 0 r
.32562 .37783 .32924 .38216 .33488 .38284 .33081 .386 Mtetra
.065 0 0 r
.33081 .386 .33488 .38284 .34009 .39145 .33665 .38398 Mtetra
.7 .619 .762 r
.33665 .38398 .34009 .39145 .3457 .39374 .34261 .3801 Mtetra
.605 .482 .685 r
.34261 .3801 .3457 .39374 .35167 .38983 .34847 .37807 Mtetra
.274 .286 .691 r
.34847 .37807 .35167 .38983 .35787 .38165 .35394 .38355 Mtetra
.76 .99 .779 r
.35394 .38355 .35787 .38165 .36394 .37591 .36003 .37775 Mtetra
.96 .937 .712 r
.36003 .37775 .36394 .37591 .37014 .36739 .3664 .36641 Mtetra
.761 .931 .942 r
.3664 .36641 .37014 .36739 .37576 .37115 .37239 .36269 Mtetra
.305 .374 .769 r
.37239 .36269 .37576 .37115 .3817 .36853 .37804 .36627 Mtetra
.651 .836 .971 r
.37804 .36627 .3817 .36853 .38763 .36648 .38398 .36422 Mtetra
.441 .76 .996 r
.38398 .36422 .38763 .36648 .39349 .36613 .38985 .36383 Mtetra
.767 .852 .914 r
.38985 .36383 .39349 .36613 .39952 .36238 .39589 .3601 Mtetra
.442 .76 .996 r
.39589 .3601 .39952 .36238 .40542 .36184 .4018 .35971 Mtetra
.768 .864 .92 r
.4018 .35971 .40542 .36184 .41154 .35593 .40785 .35596 Mtetra
.09 .648 .757 r
.40785 .35596 .41154 .35593 .41745 .35615 .4138 .35556 Mtetra
.744 .957 .942 r
.4138 .35556 .41745 .35615 .42341 .35564 .41987 .3518 Mtetra
.663 .742 .909 r
.41987 .3518 .42341 .35564 .42938 .35524 .4259 .34971 Mtetra
.654 .66 .843 r
.4259 .34971 .42938 .35524 .43536 .35491 .43194 .34762 Mtetra
.764 .654 .741 r
.43194 .34762 .43536 .35491 .4415 .34957 .43812 .34116 Mtetra
.633 .569 .765 r
.43812 .34116 .4415 .34957 .44765 .34421 .44418 .33905 Mtetra
.735 .704 .822 r
.44418 .33905 .44765 .34421 .45365 .34487 .4503 .3351 Mtetra
.652 .555 .733 r
.4503 .3351 .45365 .34487 .4597 .34452 .4564 .33209 Mtetra
.558 .465 .705 r
.4564 .33209 .4597 .34452 .46593 .33599 .46246 .33184 Mtetra
.187 .491 .902 r
.46246 .33184 .46593 .33599 .47203 .33437 .4685 .33415 Mtetra
.488 0 0 r
.4685 .33415 .47203 .33437 .47813 .33375 .47456 .33711 Mtetra
.438 0 0 r
.47456 .33711 .47813 .33375 .4842 .33662 .48068 .33784 Mtetra
0 0 0 r
.48068 .33784 .4842 .33662 .4903 .34016 .48685 .33623 Mtetra
.508 .681 .944 r
.48685 .33623 .4903 .34016 .49643 .34374 .49303 .336 Mtetra
.7 .62 .763 r
.49303 .336 .49643 .34374 .50263 .34359 .49925 .33196 Mtetra
.731 .58 .685 r
.49925 .33196 .50263 .34359 .50887 .33955 .50551 .32417 Mtetra
.688 .525 .66 r
.50551 .32417 .50887 .33955 .51511 .33784 .51176 .31709 Mtetra
.563 .415 .638 r
.51176 .31709 .51511 .33784 .52136 .33953 .51799 .3163 Mtetra
.582 .42 .627 r
.51799 .3163 .52136 .33953 .52764 .34094 .52424 .31413 Mtetra
.594 .419 .614 r
.52424 .31413 .52764 .34094 .53397 .35219 .53049 .3106 Mtetra
.525 .346 .581 r
.53049 .3106 .53397 .35219 .54021 .32814 .53678 .31264 Mtetra
.617 .479 .67 r
.53678 .31264 .54021 .32814 .54647 .31935 .54308 .30966 Mtetra
.651 .559 .738 r
.54308 .30966 .54647 .31935 .5527 .30744 .54938 .30666 Mtetra
.469 .87 .962 r
.54938 .30666 .5527 .30744 .5591 .31412 .5557 .305 Mtetra
.606 .544 .759 r
.5557 .305 .5591 .31412 .56547 .31419 .56205 .30351 Mtetra
.171 .244 .697 r
.56205 .30351 .56547 .31419 .57204 .32668 .56853 .31066 Mtetra
.161 .17 .62 r
.56853 .31066 .57204 .32668 .57864 .33622 .57513 .32169 Mtetra
.604 .478 .682 r
.57513 .32169 .57864 .33622 .58521 .34072 .58156 .31949 Mtetra
.687 .499 .627 r
.58156 .31949 .58521 .34072 .59134 .32248 .58785 .30964 Mtetra
.7 .552 .682 r
.58785 .30964 .59134 .32248 .5975 .30773 .5942 .30308 Mtetra
.864 .764 .75 r
.5942 .30308 .5975 .30773 .60371 .29643 .60048 .29395 Mtetra
.925 .844 .746 r
.60048 .29395 .60371 .29643 .60996 .28713 .60671 .28358 Mtetra
.78 .322 0 r
.60671 .28358 .60996 .28713 .61662 .29257 .61357 .29579 Mtetra
.103 0 0 r
.61357 .29579 .61662 .29257 .62302 .28844 .62006 .29355 Mtetra
.764 .35 .265 r
.62006 .29355 .62302 .28844 .62988 .29747 .62697 .30343 Mtetra
.133 0 .003 r
.62697 .30343 .62988 .29747 .63653 .29907 .63345 .29924 Mtetra
.65 .969 .876 r
.63345 .29924 .63653 .29907 .6427 .28685 .63994 .29521 Mtetra
.012 0 .064 r
.63994 .29521 .6427 .28685 .6493 .28626 .6463 .28745 Mtetra
.622 .945 .747 r
.6463 .28745 .6493 .28626 .65566 .27947 .65276 .28243 Mtetra
0 0 0 r
.65276 .28243 .65566 .27947 .66229 .27887 .65918 .27637 Mtetra
.843 .879 .867 r
.65918 .27637 .66229 .27887 .66863 .27153 .66561 .27055 Mtetra
.26 0 0 r
.66561 .27055 .66863 .27153 .6752 .26894 .67244 .27303 Mtetra
.417 0 .015 r
.67244 .27303 .6752 .26894 .68195 .26967 .67919 .27334 Mtetra
.67 .2 .127 r
.67919 .27334 .68195 .26967 .68821 .26074 .68624 .27876 Mtetra
.484 .184 .381 r
.68624 .27876 .68821 .26074 .69543 .26935 .69296 .27734 Mtetra
.362 0 .187 r
.69296 .27734 .69543 .26935 .7022 .26899 .69966 .27504 Mtetra
.425 .003 .133 r
.69966 .27504 .7022 .26899 .70911 .27058 .70649 .2747 Mtetra
0 0 0 r
.70649 .2747 .70911 .27058 .71582 .26828 .7131 .27044 Mtetra
.656 .91 .594 r
.7131 .27044 .71582 .26828 .72269 .26848 .71954 .26322 Mtetra
.658 .693 .871 r
.71954 .26322 .72269 .26848 .72931 .26422 .72629 .26091 Mtetra
.659 .8 .95 r
.72629 .26091 .72931 .26422 .73658 .2696 .73305 .25859 Mtetra
.563 .494 .736 r
.73305 .25859 .73658 .2696 .74419 .27889 .73997 .25817 Mtetra
.709 .514 .623 r
.73997 .25817 .74419 .27889 .74976 .25928 .74609 .24638 Mtetra
.744 .579 .67 r
.74609 .24638 .74976 .25928 .75562 .24444 .75236 .23698 Mtetra
.528 .547 .819 r
.75236 .23698 .75562 .24444 .76279 .24692 .75935 .2372 Mtetra
.366 .395 .759 r
.75935 .2372 .76279 .24692 .77025 .25263 .76667 .2412 Mtetra
0 .013 .573 r
.76667 .2412 .77025 .25263 .77725 .25204 .77493 .25616 Mtetra
0 0 0 r
.77493 .25616 .77725 .25204 .78473 .25695 .78134 .24796 Mtetra
0 .088 .637 r
.78134 .24796 .78473 .25695 .79151 .25304 .78943 .25931 Mtetra
0 0 0 r
.78943 .25931 .79151 .25304 .79825 .24871 .79587 .25104 Mtetra
.79587 .25104 .79825 .24871 .80537 .24832 .80258 .24591 Mtetra
.421 .759 .995 r
.80258 .24591 .80537 .24832 .81288 .25188 .80974 .24551 Mtetra
.553 .601 .856 r
.80974 .24551 .81288 .25188 .82053 .25647 .81692 .24511 Mtetra
.711 .578 .704 r
.81692 .24511 .82053 .25647 .82697 .24816 .82354 .23876 Mtetra
.363 0 .189 r
.1991 .45183 .20414 .44345 .20956 .44332 .20471 .44991 Mtetra
.627 .246 .302 r
.20471 .44991 .20956 .44332 .21385 .45526 .20981 .4535 Mtetra
.638 .855 .982 r
.20981 .4535 .21385 .45526 .21932 .45517 .21546 .45158 Mtetra
.657 .742 .912 r
.21546 .45158 .21932 .45517 .22463 .45697 .22112 .4497 Mtetra
.744 .639 .744 r
.22112 .4497 .22463 .45697 .23041 .45381 .22712 .44408 Mtetra
.78 .621 .683 r
.22712 .44408 .23041 .45381 .23722 .43917 .23355 .43377 Mtetra
.804 .7 .75 r
.23355 .43377 .23722 .43917 .24351 .43 .23971 .42641 Mtetra
.882 .749 .71 r
.23971 .42641 .24351 .43 .24978 .42109 .24627 .41423 Mtetra
.561 .565 .814 r
.24627 .41423 .24978 .42109 .25559 .41749 .25181 .41387 Mtetra
.795 .763 .824 r
.25181 .41387 .25559 .41749 .26101 .41882 .25776 .40878 Mtetra
.566 .497 .737 r
.25776 .40878 .26101 .41882 .26722 .41044 .26334 .40834 Mtetra
.05 .544 .885 r
.26334 .40834 .26722 .41044 .27334 .40313 .26879 .40965 Mtetra
.539 .141 .237 r
.26879 .40965 .27334 .40313 .27941 .39643 .27425 .4111 Mtetra
.667 .352 .431 r
.27425 .4111 .27941 .39643 .28444 .40354 .27924 .4192 Mtetra
.452 .144 .352 r
.27924 .4192 .28444 .40354 .28942 .41205 .28502 .41722 Mtetra
.968 .928 .612 r
.28502 .41722 .28942 .41205 .2958 .40151 .29179 .40172 Mtetra
.958 .824 .67 r
.29179 .40172 .2958 .40151 .30169 .39772 .29861 .38504 Mtetra
.404 .358 .693 r
.29861 .38504 .30169 .39772 .30757 .39428 .304 .38853 Mtetra
.819 .699 .732 r
.304 .38853 .30757 .39428 .31323 .3941 .31024 .37989 Mtetra
.641 .5 .675 r
.31024 .37989 .31323 .3941 .31968 .38203 .31615 .37613 Mtetra
.592 .613 .842 r
.31615 .37613 .31968 .38203 .32562 .37783 .32188 .37521 Mtetra
.834 .363 .003 r
.32188 .37521 .32562 .37783 .33081 .386 .32702 .38415 Mtetra
.779 .873 .917 r
.32702 .38415 .33081 .386 .33665 .38398 .33298 .38025 Mtetra
.842 .766 .778 r
.33298 .38025 .33665 .38398 .34261 .3801 .33915 .37283 Mtetra
.692 .62 .771 r
.33915 .37283 .34261 .3801 .34847 .37807 .3451 .3693 Mtetra
.581 .531 .763 r
.3451 .3693 .34847 .37807 .35394 .38355 .3509 .36852 Mtetra
.675 .517 .664 r
.3509 .36852 .35394 .38355 .36003 .37775 .357 .36252 Mtetra
.446 .363 .669 r
.357 .36252 .36003 .37775 .3664 .36641 .36263 .36576 Mtetra
.743 .949 .946 r
.36263 .36576 .3664 .36641 .37239 .36269 .36862 .36213 Mtetra
.623 .931 .967 r
.36862 .36213 .37239 .36269 .37804 .36627 .37457 .35957 Mtetra
.478 .53 .833 r
.37457 .35957 .37804 .36627 .38398 .36422 .38038 .36041 Mtetra
.291 .576 .938 r
.38038 .36041 .38398 .36422 .38985 .36383 .38618 .36177 Mtetra
.837 .861 .862 r
.38618 .36177 .38985 .36383 .39589 .3601 .3923 .35628 Mtetra
0 .372 .834 r
.3923 .35628 .39589 .3601 .4018 .35971 .39808 .35941 Mtetra
.741 .968 .933 r
.39808 .35941 .4018 .35971 .40785 .35596 .40416 .35555 Mtetra
.897 .935 .832 r
.40416 .35555 .40785 .35596 .4138 .35556 .41035 .34847 Mtetra
.41 .48 .822 r
.41035 .34847 .4138 .35556 .41987 .3518 .41624 .3503 Mtetra
.914 .861 .774 r
.41624 .3503 .41987 .3518 .4259 .34971 .42251 .3412 Mtetra
.571 .533 .774 r
.42251 .3412 .4259 .34971 .43194 .34762 .4285 .34065 Mtetra
.695 .633 .782 r
.4285 .34065 .43194 .34762 .43812 .34116 .4346 .33713 Mtetra
.663 .733 .902 r
.4346 .33713 .43812 .34116 .44418 .33905 .44067 .33502 Mtetra
.54 .687 .934 r
.44067 .33502 .44418 .33905 .4503 .3351 .44672 .3345 Mtetra
.178 0 0 r
.44672 .3345 .4503 .3351 .4564 .33209 .45274 .3358 Mtetra
.685 .907 .563 r
.45274 .3358 .4564 .33209 .46246 .33184 .45898 .32793 Mtetra
.76 .295 0 r
.45898 .32793 .46246 .33184 .4685 .33415 .46488 .3378 Mtetra
.041 0 0 r
.46488 .3378 .4685 .33415 .47456 .33711 .47105 .33506 Mtetra
.526 .818 .999 r
.47105 .33506 .47456 .33711 .48068 .33784 .47721 .33391 Mtetra
.754 .767 .864 r
.47721 .33391 .48068 .33784 .48685 .33623 .48342 .32994 Mtetra
.851 .707 .702 r
.48342 .32994 .48685 .33623 .49303 .336 .48972 .3186 Mtetra
.505 .391 .658 r
.48972 .3186 .49303 .336 .49925 .33196 .49588 .32038 Mtetra
.325 .329 .709 r
.49588 .32038 .49925 .33196 .50551 .32417 .50205 .32533 Mtetra
.875 .994 .775 r
.50205 .32533 .50551 .32417 .51176 .31709 .50832 .31773 Mtetra
.62 .959 .853 r
.50832 .31773 .51176 .31709 .51799 .3163 .51458 .31387 Mtetra
.179 .606 .941 r
.51458 .31387 .51799 .3163 .52424 .31413 .52083 .31504 Mtetra
.697 .982 .824 r
.52083 .31504 .52424 .31413 .53049 .3106 .52711 .31021 Mtetra
.586 .933 .945 r
.52711 .31021 .53049 .3106 .53678 .31264 .5334 .30749 Mtetra
.658 .685 .864 r
.5334 .30749 .53678 .31264 .54308 .30966 .5397 .3053 Mtetra
.767 .756 .843 r
.5397 .3053 .54308 .30966 .54938 .30666 .546 .30078 Mtetra
.773 .701 .782 r
.546 .30078 .54938 .30666 .5557 .305 .5523 .29506 Mtetra
.571 .51 .748 r
.5523 .29506 .5557 .305 .56205 .30351 .55865 .29446 Mtetra
.132 .252 .723 r
.55865 .29446 .56205 .30351 .56853 .31066 .56512 .30093 Mtetra
.222 .298 .73 r
.56512 .30093 .56853 .31066 .57513 .32169 .57162 .30672 Mtetra
.503 .41 .682 r
.57162 .30672 .57513 .32169 .58156 .31949 .5781 .30837 Mtetra
.795 .621 .665 r
.5781 .30837 .58156 .31949 .58785 .30964 .58435 .29617 Mtetra
.608 .49 .693 r
.58435 .29617 .58785 .30964 .5942 .30308 .59079 .29395 Mtetra
.804 .648 .689 r
.59079 .29395 .5942 .30308 .60048 .29395 .59704 .28335 Mtetra
.401 .397 .739 r
.59704 .28335 .60048 .29395 .60671 .28358 .60363 .2867 Mtetra
.664 .186 .106 r
.60363 .2867 .60671 .28358 .61357 .29579 .6103 .29166 Mtetra
0 .3 .791 r
.6103 .29166 .61357 .29579 .62006 .29355 .617 .29611 Mtetra
.697 .211 .09 r
.617 .29611 .62006 .29355 .62697 .30343 .62379 .30201 Mtetra
.888 .46 .115 r
.62379 .30201 .62697 .30343 .63345 .29924 .63101 .31928 Mtetra
0 0 .239 r
.63101 .31928 .63345 .29924 .63994 .29521 .63702 .29995 Mtetra
.028 0 0 r
.63702 .29995 .63994 .29521 .6463 .28745 .64355 .29574 Mtetra
0 0 0 r
.64355 .29574 .6463 .28745 .65276 .28243 .64985 .28566 Mtetra
.324 0 0 r
.64985 .28566 .65276 .28243 .65918 .27637 .65654 .28534 Mtetra
.279 0 .184 r
.65654 .28534 .65918 .27637 .66561 .27055 .66308 .28111 Mtetra
.477 .125 .288 r
.66308 .28111 .66561 .27055 .67244 .27303 .66982 .28078 Mtetra
.281 0 .146 r
.66982 .28078 .67244 .27303 .67919 .27334 .67642 .27725 Mtetra
.672 .207 .14 r
.67642 .27725 .67919 .27334 .68624 .27876 .68349 .28279 Mtetra
.599 .126 .102 r
.68349 .28279 .68624 .27876 .69296 .27734 .69052 .2864 Mtetra
.535 .158 .272 r
.69052 .2864 .69296 .27734 .69966 .27504 .69747 .28806 Mtetra
.409 .09 .309 r
.69747 .28806 .69966 .27504 .70649 .2747 .70419 .28502 Mtetra
.005 0 .13 r
.70419 .28502 .70649 .2747 .7131 .27044 .7105 .27486 Mtetra
.889 .864 .419 r
.7105 .27486 .7131 .27044 .71954 .26322 .71631 .25704 Mtetra
.652 .654 .839 r
.71631 .25704 .71954 .26322 .72629 .26091 .72307 .25471 Mtetra
.726 .687 .812 r
.72307 .25471 .72629 .26091 .73305 .25859 .72971 .25048 Mtetra
.699 .623 .767 r
.72971 .25048 .73305 .25859 .73997 .25817 .73637 .24626 Mtetra
.699 .563 .697 r
.73637 .24626 .73997 .25817 .74609 .24638 .7429 .24021 Mtetra
.724 .688 .815 r
.7429 .24021 .74609 .24638 .75236 .23698 .74957 .23605 Mtetra
.88 .974 .839 r
.74957 .23605 .75236 .23698 .75935 .2372 .75604 .22911 Mtetra
0 0 .565 r
.75604 .22911 .75935 .2372 .76667 .2412 .76402 .24161 Mtetra
.829 .355 .041 r
.76402 .24161 .76667 .2412 .77493 .25616 .77215 .25492 Mtetra
.982 .887 .656 r
.77215 .25492 .77493 .25616 .78134 .24796 .7781 .24077 Mtetra
.558 .575 .827 r
.7781 .24077 .78134 .24796 .78943 .25931 .78518 .24035 Mtetra
.653 .485 .644 r
.78518 .24035 .78943 .25931 .79587 .25104 .79178 .23406 Mtetra
.558 .436 .669 r
.79178 .23406 .79587 .25104 .80258 .24591 .79889 .23362 Mtetra
.562 .479 .719 r
.79889 .23362 .80258 .24591 .80974 .24551 .80604 .23319 Mtetra
.7 .561 .694 r
.80604 .23319 .80974 .24551 .81692 .24511 .81265 .22687 Mtetra
.684 .508 .643 r
.81265 .22687 .81692 .24511 .82354 .23876 .81908 .21864 Mtetra
.87 .816 .794 r
.19506 .44978 .1991 .45183 .20471 .44991 .20125 .4422 Mtetra
.794 .65 .704 r
.20125 .4422 .20471 .44991 .20981 .4535 .2076 .43283 Mtetra
.699 .511 .63 r
.2076 .43283 .20981 .4535 .21546 .45158 .21406 .42213 Mtetra
.638 .446 .607 r
.21406 .42213 .21546 .45158 .22112 .4497 .22024 .4143 Mtetra
.513 .34 .584 r
.22024 .4143 .22112 .4497 .22712 .44408 .22547 .41669 Mtetra
.554 .386 .607 r
.22547 .41669 .22712 .44408 .23355 .43377 .23099 .41609 Mtetra
.56 .423 .651 r
.23099 .41609 .23355 .43377 .23971 .42641 .23653 .41558 Mtetra
.416 .391 .723 r
.23653 .41558 .23971 .42641 .24627 .41423 .2418 .41824 Mtetra
.563 .868 .569 r
.2418 .41824 .24627 .41423 .25181 .41387 .24784 .4123 Mtetra
.309 0 0 r
.24784 .4123 .25181 .41387 .25776 .40878 .25318 .41463 Mtetra
.07 0 0 r
.25318 .41463 .25776 .40878 .26334 .40834 .25904 .41098 Mtetra
.292 0 0 r
.25904 .41098 .26334 .40834 .26879 .40965 .26463 .41071 Mtetra
.187 .711 .692 r
.26463 .41071 .26879 .40965 .27425 .4111 .27034 .4092 Mtetra
.878 .45 .17 r
.27034 .4092 .27425 .4111 .27924 .4192 .27512 .41996 Mtetra
.964 .802 .634 r
.27512 .41996 .27924 .4192 .28502 .41722 .28242 .39797 Mtetra
.722 .531 .631 r
.28242 .39797 .28502 .41722 .29179 .40172 .28896 .38566 Mtetra
.66 .501 .658 r
.28896 .38566 .29179 .40172 .29861 .38504 .29497 .3802 Mtetra
.655 .682 .863 r
.29497 .3802 .29861 .38504 .304 .38853 .30074 .37824 Mtetra
.608 .519 .728 r
.30074 .37824 .304 .38853 .31024 .37989 .30651 .3766 Mtetra
.528 .723 .962 r
.30651 .3766 .31024 .37989 .31615 .37613 .31221 .37604 Mtetra
.498 .898 .933 r
.31221 .37604 .31615 .37613 .32188 .37521 .31803 .37401 Mtetra
.792 .298 .013 r
.31803 .37401 .32188 .37521 .32702 .38415 .32328 .38113 Mtetra
.88 .786 .753 r
.32328 .38113 .32702 .38415 .33298 .38025 .32959 .37176 Mtetra
.696 .597 .742 r
.32959 .37176 .33298 .38025 .33915 .37283 .33557 .36759 Mtetra
.689 .252 0 r
.33557 .36759 .33915 .37283 .3451 .3693 .34081 .37651 Mtetra
.146 0 .033 r
.34081 .37651 .3451 .3693 .3509 .36852 .34682 .37241 Mtetra
.369 0 0 r
.34682 .37241 .3509 .36852 .357 .36252 .35264 .37219 Mtetra
.144 0 .116 r
.35264 .37219 .357 .36252 .36263 .36576 .35875 .36651 Mtetra
.072 0 0 r
.35875 .36651 .36263 .36576 .36862 .36213 .36459 .36625 Mtetra
.637 .199 .193 r
.36459 .36625 .36862 .36213 .37457 .35957 .37026 .37002 Mtetra
.298 0 .211 r
.37026 .37002 .37457 .35957 .38038 .36041 .37632 .36606 Mtetra
0 0 0 r
.37632 .36606 .38038 .36041 .38618 .36177 .38254 .35874 Mtetra
.549 .022 0 r
.38254 .35874 .38618 .36177 .3923 .35628 .3882 .36419 Mtetra
0 0 0 r
.3882 .36419 .3923 .35628 .39808 .35941 .39449 .35557 Mtetra
.8 .771 .826 r
.39449 .35557 .39808 .35941 .40416 .35555 .40063 .35022 Mtetra
.838 .721 .736 r
.40063 .35022 .40416 .35555 .41035 .34847 .40691 .34117 Mtetra
.494 .521 .814 r
.40691 .34117 .41035 .34847 .41624 .3503 .41283 .34191 Mtetra
.06 .219 .715 r
.41283 .34191 .41624 .3503 .42251 .3412 .4186 .34801 Mtetra
0 0 0 r
.4186 .34801 .42251 .3412 .4285 .34065 .42485 .34039 Mtetra
.863 .962 .865 r
.42485 .34039 .4285 .34065 .4346 .33713 .43104 .33438 Mtetra
.584 .788 .977 r
.43104 .33438 .4346 .33713 .44067 .33502 .4371 .33307 Mtetra
.484 .805 1 r
.4371 .33307 .44067 .33502 .44672 .3345 .44316 .33218 Mtetra
.827 .353 0 r
.44316 .33218 .44672 .3345 .45274 .3358 .44898 .34212 Mtetra
.915 .898 .488 r
.44898 .34212 .45274 .3358 .45898 .32793 .45546 .32489 Mtetra
.639 .789 .954 r
.45546 .32489 .45898 .32793 .46488 .3378 .46159 .32303 Mtetra
.233 .226 .645 r
.46159 .32303 .46488 .3378 .47105 .33506 .46756 .33111 Mtetra
.851 .776 .778 r
.46756 .33111 .47105 .33506 .47721 .33391 .47383 .32337 Mtetra
.456 .428 .739 r
.47383 .32337 .47721 .33391 .48342 .32994 .47995 .32546 Mtetra
.74 .739 .851 r
.47995 .32546 .48342 .32994 .48972 .3186 .48618 .32164 Mtetra
.581 .092 .061 r
.48618 .32164 .48972 .3186 .49588 .32038 .49235 .32451 Mtetra
.617 .164 .155 r
.49235 .32451 .49588 .32038 .50205 .32533 .49854 .32808 Mtetra
.64 .915 .622 r
.49854 .32808 .50205 .32533 .50832 .31773 .50484 .32159 Mtetra
0 0 0 r
.50484 .32159 .50832 .31773 .51458 .31387 .51112 .31729 Mtetra
.51112 .31729 .51458 .31387 .52083 .31504 .51741 .31194 Mtetra
.911 .806 .731 r
.51741 .31194 .52083 .31504 .52711 .31021 .52371 .30094 Mtetra
0 0 .299 r
.52371 .30094 .52711 .31021 .5334 .30749 .53003 .31692 Mtetra
0 0 0 r
.53003 .31692 .5334 .30749 .5397 .3053 .53632 .3016 Mtetra
.86 .796 .786 r
.53632 .3016 .5397 .3053 .546 .30078 .54262 .29385 Mtetra
.45 .514 .833 r
.54262 .29385 .546 .30078 .5523 .29506 .54897 .29516 Mtetra
.892 .481 .216 r
.54897 .29516 .5523 .29506 .55865 .29446 .55551 .31212 Mtetra
.501 .196 .382 r
.55551 .31212 .55865 .29446 .56512 .30093 .56194 .31169 Mtetra
.353 .017 .248 r
.56194 .31169 .56512 .30093 .57162 .30672 .56835 .30828 Mtetra
.908 .978 .703 r
.56835 .30828 .57162 .30672 .5781 .30837 .57467 .2987 Mtetra
.68 .578 .734 r
.57467 .2987 .5781 .30837 .58435 .29617 .58108 .29459 Mtetra
.939 .88 .75 r
.58108 .29459 .58435 .29617 .59079 .29395 .58736 .2843 Mtetra
.73 .605 .717 r
.58736 .2843 .59079 .29395 .59704 .28335 .59372 .27797 Mtetra
0 .292 .789 r
.59372 .27797 .59704 .28335 .60363 .2867 .60035 .28292 Mtetra
0 0 .494 r
.60035 .28292 .60363 .2867 .6103 .29166 .60708 .29034 Mtetra
.65 .099 0 r
.60708 .29034 .6103 .29166 .617 .29611 .61385 .29676 Mtetra
.701 .172 0 r
.61385 .29676 .617 .29611 .62379 .30201 .62066 .30297 Mtetra
.678 .145 0 r
.62066 .30297 .62379 .30201 .63101 .31928 .62751 .30859 Mtetra
.839 .648 .645 r
.62751 .30859 .63101 .31928 .63702 .29995 .63365 .29257 Mtetra
.76 .664 .756 r
.63365 .29257 .63702 .29995 .64355 .29574 .64011 .2864 Mtetra
.686 .589 .742 r
.64011 .2864 .64355 .29574 .64985 .28566 .64664 .28217 Mtetra
.906 .818 .749 r
.64664 .28217 .64985 .28566 .65654 .28534 .65294 .27212 Mtetra
.468 .406 .704 r
.65294 .27212 .65654 .28534 .66308 .28111 .65977 .27464 Mtetra
.554 .593 .847 r
.65977 .27464 .66308 .28111 .66982 .28078 .66651 .27426 Mtetra
.739 .357 0 r
.66651 .27426 .66982 .28078 .67642 .27725 .67415 .29225 Mtetra
.496 .176 .353 r
.67415 .29225 .67642 .27725 .68349 .28279 .68097 .29192 Mtetra
.339 0 .207 r
.68097 .29192 .68349 .28279 .69052 .2864 .68768 .28874 Mtetra
0 0 0 r
.68768 .28874 .69052 .2864 .69747 .28806 .69444 .28644 Mtetra
.963 .881 .704 r
.69444 .28644 .69747 .28806 .70419 .28502 .70065 .27405 Mtetra
.713 .582 .707 r
.70065 .27405 .70419 .28502 .7105 .27486 .70719 .26778 Mtetra
.929 .722 .602 r
.70719 .26778 .7105 .27486 .71631 .25704 .71272 .24511 Mtetra
.699 .562 .697 r
.71272 .24511 .71631 .25704 .72307 .25471 .71924 .23905 Mtetra
.616 .48 .673 r
.71924 .23905 .72307 .25471 .72971 .25048 .72594 .23595 Mtetra
.58 .465 .688 r
.72594 .23595 .72971 .25048 .73637 .24626 .73279 .23469 Mtetra
.56 .485 .727 r
.73279 .23469 .73637 .24626 .7429 .24021 .73972 .23431 Mtetra
.898 .748 .686 r
.73972 .23431 .7429 .24021 .74957 .23605 .74575 .22117 Mtetra
.551 .445 .686 r
.74575 .22117 .74957 .23605 .75604 .22911 .75272 .22106 Mtetra
0 .086 .64 r
.75272 .22106 .75604 .22911 .76402 .24161 .76053 .23144 Mtetra
0 0 .266 r
.76053 .23144 .76402 .24161 .77215 .25492 .76958 .25655 Mtetra
.99 .848 .482 r
.76958 .25655 .77215 .25492 .7781 .24077 .77484 .23344 Mtetra
.91 .722 .636 r
.77484 .23344 .7781 .24077 .78518 .24035 .78048 .21592 Mtetra
.346 .259 .614 r
.78048 .21592 .78518 .24035 .79178 .23406 .78856 .22711 Mtetra
0 .085 .645 r
.78856 .22711 .79178 .23406 .79889 .23362 .7966 .23706 Mtetra
0 0 0 r
.7966 .23706 .79889 .23362 .80604 .23319 .80296 .22769 Mtetra
.48 .599 .894 r
.80296 .22769 .80604 .23319 .81265 .22687 .81023 .22819 Mtetra
.883 .953 .605 r
.81023 .22819 .81265 .22687 .81908 .21864 .81643 .21725 Mtetra
.654 .522 .69 r
.19206 .43734 .19506 .44978 .20125 .4422 .19787 .43353 Mtetra
.816 .648 .674 r
.19787 .43353 .20125 .4422 .2076 .43283 .2046 .42035 Mtetra
.739 .574 .669 r
.2046 .42035 .2076 .43283 .21406 .42213 .21093 .41114 Mtetra
.618 .514 .714 r
.21093 .41114 .21406 .42213 .22024 .4143 .21656 .40909 Mtetra
.654 .663 .846 r
.21656 .40909 .22024 .4143 .22547 .41669 .22219 .40713 Mtetra
.384 .394 .747 r
.22219 .40713 .22547 .41669 .23099 .41609 .2274 .40986 Mtetra
.332 .465 .844 r
.2274 .40986 .23099 .41609 .23653 .41558 .2327 .41196 Mtetra
0 .135 .627 r
.2327 .41196 .23653 .41558 .2418 .41824 .23784 .41609 Mtetra
.848 .83 .829 r
.23784 .41609 .2418 .41824 .24784 .4123 .24391 .4099 Mtetra
.15 .592 .931 r
.24391 .4099 .24784 .4123 .25318 .41463 .24937 .41099 Mtetra
.235 .556 .933 r
.24937 .41099 .25318 .41463 .25904 .41098 .25481 .41246 Mtetra
.488 .896 .784 r
.25481 .41246 .25904 .41098 .26463 .41071 .26065 .4093 Mtetra
.846 .88 .865 r
.26065 .4093 .26463 .41071 .27034 .4092 .26669 .40377 Mtetra
.831 .707 .728 r
.26669 .40377 .27034 .4092 .27512 .41996 .27303 .39445 Mtetra
.601 .426 .616 r
.27303 .39445 .27512 .41996 .28242 .39797 .27893 .39065 Mtetra
.739 .638 .748 r
.27893 .39065 .28242 .39797 .28896 .38566 .28496 .38527 Mtetra
.788 .955 .924 r
.28496 .38527 .28896 .38566 .29497 .3802 .2909 .38105 Mtetra
0 0 0 r
.2909 .38105 .29497 .3802 .30074 .37824 .29661 .38017 Mtetra
.323 0 0 r
.29661 .38017 .30074 .37824 .30651 .3766 .30226 .38049 Mtetra
0 0 0 r
.30226 .38049 .30651 .3766 .31221 .37604 .30828 .37555 Mtetra
.752 .953 .941 r
.30828 .37555 .31221 .37604 .31803 .37401 .31422 .37182 Mtetra
.592 .034 0 r
.31422 .37182 .31803 .37401 .32328 .38113 .31963 .37654 Mtetra
.526 .647 .91 r
.31963 .37654 .32328 .38113 .32959 .37176 .32538 .37631 Mtetra
.592 .157 .184 r
.32538 .37631 .32959 .37176 .33557 .36759 .33097 .37904 Mtetra
.6 .26 .364 r
.33097 .37904 .33557 .36759 .34081 .37651 .33654 .38268 Mtetra
.288 0 .064 r
.33654 .38268 .34081 .37651 .34682 .37241 .34246 .38064 Mtetra
.466 .088 .237 r
.34246 .38064 .34682 .37241 .35264 .37219 .3483 .38049 Mtetra
0 0 0 r
.3483 .38049 .35264 .37219 .35875 .36651 .35458 .37223 Mtetra
.543 .125 .198 r
.35458 .37223 .35875 .36651 .36459 .36625 .36035 .37397 Mtetra
0 0 0 r
.36035 .37397 .36459 .36625 .37026 .37002 .36664 .36561 Mtetra
.833 .747 .769 r
.36664 .36561 .37026 .37002 .37632 .36606 .37288 .35802 Mtetra
.102 .258 .739 r
.37288 .35802 .37632 .36606 .38254 .35874 .37853 .36332 Mtetra
.718 .308 .27 r
.37853 .36332 .38254 .35874 .3882 .36419 .38416 .36988 Mtetra
.844 .918 .521 r
.38416 .36988 .3882 .36419 .39449 .35557 .39064 .35723 Mtetra
.985 .848 .624 r
.39064 .35723 .39449 .35557 .40063 .35022 .39738 .33763 Mtetra
.524 .441 .704 r
.39738 .33763 .40063 .35022 .40691 .34117 .40329 .33832 Mtetra
0 .148 .606 r
.40329 .33832 .40691 .34117 .41283 .34191 .40909 .34253 Mtetra
.594 .04 0 r
.40909 .34253 .41283 .34191 .4186 .34801 .41496 .34599 Mtetra
.848 .869 .857 r
.41496 .34599 .4186 .34801 .42485 .34039 .42116 .34014 Mtetra
.907 .941 .819 r
.42116 .34014 .42485 .34039 .43104 .33438 .42742 .33261 Mtetra
.633 .871 .986 r
.42742 .33261 .43104 .33438 .4371 .33307 .43352 .33048 Mtetra
.565 .794 .985 r
.43352 .33048 .4371 .33307 .44316 .33218 .4396 .32926 Mtetra
.789 .305 0 r
.4396 .32926 .44316 .33218 .44898 .34212 .44543 .3385 Mtetra
.919 .768 .677 r
.44543 .3385 .44898 .34212 .45546 .32489 .4519 .32329 Mtetra
.725 .904 .958 r
.4519 .32329 .45546 .32489 .46159 .32303 .45807 .32005 Mtetra
.724 .223 0 r
.45807 .32005 .46159 .32303 .46756 .33111 .46403 .32814 Mtetra
.659 .801 .951 r
.46403 .32814 .46756 .33111 .47383 .32337 .47022 .32599 Mtetra
.41 0 0 r
.47022 .32599 .47383 .32337 .47995 .32546 .47638 .32679 Mtetra
.544 .919 .769 r
.47638 .32679 .47995 .32546 .48618 .32164 .48263 .32282 Mtetra
.407 0 0 r
.48263 .32282 .48618 .32164 .49235 .32451 .48883 .32433 Mtetra
.295 0 0 r
.48883 .32433 .49235 .32451 .49854 .32808 .49505 .326 Mtetra
.866 .875 .843 r
.49505 .326 .49854 .32808 .50484 .32159 .50137 .31949 Mtetra
.859 .877 .851 r
.50137 .31949 .50484 .32159 .51112 .31729 .50768 .31326 Mtetra
.799 .776 .832 r
.50768 .31326 .51112 .31729 .51741 .31194 .51398 .30791 Mtetra
.893 .776 .725 r
.51398 .30791 .51741 .31194 .52371 .30094 .5203 .29689 Mtetra
0 .233 .738 r
.5203 .29689 .52371 .30094 .53003 .31692 .5266 .30156 Mtetra
.714 .541 .655 r
.5266 .30156 .53003 .31692 .53632 .3016 .53291 .29264 Mtetra
.632 .562 .759 r
.53291 .29264 .53632 .3016 .54262 .29385 .53923 .29041 Mtetra
0 .265 .746 r
.53923 .29041 .54262 .29385 .54897 .29516 .54562 .29459 Mtetra
.786 .286 0 r
.54562 .29459 .54897 .29516 .55551 .31212 .55208 .3032 Mtetra
.477 .477 .778 r
.55208 .3032 .55551 .31212 .56194 .31169 .55853 .30455 Mtetra
.442 .505 .828 r
.55853 .30455 .56194 .31169 .56835 .30828 .56501 .30602 Mtetra
.947 .831 .697 r
.56501 .30602 .56835 .30828 .57467 .2987 .57129 .29271 Mtetra
.652 .654 .839 r
.57129 .29271 .57467 .2987 .58108 .29459 .57774 .29047 Mtetra
.89 .783 .737 r
.57774 .29047 .58108 .29459 .58736 .2843 .58404 .28015 Mtetra
.887 .784 .742 r
.58404 .28015 .58736 .2843 .59372 .27797 .59033 .27017 Mtetra
.805 .445 0 r
.59033 .27017 .59372 .27797 .60035 .28292 .59733 .29134 Mtetra
.645 .26 .301 r
.59733 .29134 .60035 .28292 .60708 .29034 .60405 .29679 Mtetra
.645 .231 .245 r
.60405 .29679 .60708 .29034 .61385 .29676 .6108 .30176 Mtetra
.239 0 0 r
.6108 .30176 .61385 .29676 .62066 .30297 .61738 .2995 Mtetra
.236 .573 .941 r
.61738 .2995 .62066 .30297 .62751 .30859 .6241 .30114 Mtetra
.827 .689 .711 r
.6241 .30114 .62751 .30859 .63365 .29257 .63046 .29109 Mtetra
.974 .847 .655 r
.63046 .29109 .63365 .29257 .64011 .2864 .6366 .27539 Mtetra
.668 .555 .717 r
.6366 .27539 .64011 .2864 .64664 .28217 .64313 .27123 Mtetra
.49 .45 .739 r
.64313 .27123 .64664 .28217 .65294 .27212 .64991 .27271 Mtetra
.029 0 0 r
.64991 .27271 .65294 .27212 .65977 .27464 .65663 .27231 Mtetra
0 .446 .837 r
.65663 .27231 .65977 .27464 .66651 .27426 .66351 .27485 Mtetra
.728 .205 0 r
.66351 .27485 .66651 .27426 .67415 .29225 .67065 .28217 Mtetra
0 0 .243 r
.67065 .28217 .67415 .29225 .68097 .29192 .6786 .30474 Mtetra
.002 0 .17 r
.6786 .30474 .68097 .29192 .68768 .28874 .68488 .2924 Mtetra
.145 0 0 r
.68488 .2924 .68768 .28874 .69444 .28644 .69167 .29009 Mtetra
.805 .893 .475 r
.69167 .29009 .69444 .28644 .70065 .27405 .69792 .27768 Mtetra
0 0 0 r
.69792 .27768 .70065 .27405 .70719 .26778 .70438 .26941 Mtetra
.997 .839 .501 r
.70438 .26941 .70719 .26778 .71272 .24511 .70982 .24458 Mtetra
.966 .926 .701 r
.70982 .24458 .71272 .24511 .71924 .23905 .71601 .23292 Mtetra
.759 .703 .798 r
.71601 .23292 .71924 .23905 .72594 .23595 .72259 .22766 Mtetra
.391 .444 .796 r
.72259 .22766 .72594 .23595 .73279 .23469 .72971 .23046 Mtetra
.856 .802 .796 r
.72971 .23046 .73279 .23469 .73972 .23431 .73615 .22292 Mtetra
.642 .537 .719 r
.73615 .22292 .73972 .23431 .74575 .22117 .74289 .21965 Mtetra
.75 .946 .945 r
.74289 .21965 .74575 .22117 .75272 .22106 .74959 .21554 Mtetra
0 .016 .583 r
.74959 .21554 .75272 .22106 .76053 .23144 .75733 .22513 Mtetra
.196 .388 .826 r
.75733 .22513 .76053 .23144 .76958 .25655 .76474 .22947 Mtetra
.705 .493 .599 r
.76474 .22947 .76958 .25655 .77484 .23344 .77062 .21433 Mtetra
.486 .376 .653 r
.77062 .21433 .77484 .23344 .78048 .21592 .77796 .21728 Mtetra
.711 .186 0 r
.77796 .21728 .78048 .21592 .78856 .22711 .78572 .22463 Mtetra
.783 .318 0 r
.78572 .22463 .78856 .22711 .7966 .23706 .79419 .23937 Mtetra
.97 .854 .452 r
.79419 .23937 .7966 .23706 .80296 .22769 .79945 .21745 Mtetra
.71 .593 .723 r
.79945 .21745 .80296 .22769 .81023 .22819 .80614 .21176 Mtetra
.564 .443 .673 r
.80614 .21176 .81023 .22819 .81643 .21725 .81331 .21103 Mtetra
.86 .844 .827 r
.18796 .43565 .19206 .43734 .19787 .43353 .19404 .42919 Mtetra
.894 .72 .659 r
.19404 .42919 .19787 .43353 .2046 .42035 .20137 .41031 Mtetra
.764 .609 .686 r
.20137 .41031 .2046 .42035 .21093 .41114 .2077 .40111 Mtetra
.664 .554 .72 r
.2077 .40111 .21093 .41114 .21656 .40909 .21346 .39761 Mtetra
.348 .335 .703 r
.21346 .39761 .21656 .40909 .22219 .40713 .21854 .40146 Mtetra
.782 .688 .761 r
.21854 .40146 .22219 .40713 .2274 .40986 .22458 .39521 Mtetra
.454 .369 .671 r
.22458 .39521 .2274 .40986 .2327 .41196 .22981 .39789 Mtetra
0 0 .477 r
.22981 .39789 .2327 .41196 .23784 .41609 .23422 .41 Mtetra
.713 .657 .792 r
.23422 .41 .23784 .41609 .24391 .4099 .24008 .40629 Mtetra
.531 .019 0 r
.24008 .40629 .24391 .4099 .24937 .41099 .24518 .41141 Mtetra
.735 .244 .071 r
.24518 .41141 .24937 .41099 .25481 .41246 .25031 .41674 Mtetra
.829 .967 .648 r
.25031 .41674 .25481 .41246 .26065 .4093 .25666 .40775 Mtetra
.923 .803 .709 r
.25666 .40775 .26065 .4093 .26669 .40377 .26333 .39458 Mtetra
.542 .499 .758 r
.26333 .39458 .26669 .40377 .27303 .39445 .26893 .39464 Mtetra
.717 .973 .927 r
.26893 .39464 .27303 .39445 .27893 .39065 .27484 .39097 Mtetra
.946 .881 .737 r
.27484 .39097 .27893 .39065 .28496 .38527 .28133 .37974 Mtetra
.55 .611 .866 r
.28133 .37974 .28496 .38527 .2909 .38105 .287 .37938 Mtetra
.603 .86 .992 r
.287 .37938 .2909 .38105 .29661 .38017 .29278 .37762 Mtetra
.657 .814 .959 r
.29278 .37762 .29661 .38017 .30226 .38049 .29859 .37559 Mtetra
.721 .703 .833 r
.29859 .37559 .30226 .38049 .30828 .37555 .30452 .37215 Mtetra
.663 .762 .924 r
.30452 .37215 .30828 .37555 .31422 .37182 .31036 .3701 Mtetra
.775 .268 0 r
.31036 .3701 .31422 .37182 .31963 .37654 .31563 .37698 Mtetra
.04 0 0 r
.31563 .37698 .31963 .37654 .32538 .37631 .32139 .37682 Mtetra
.734 .238 .057 r
.32139 .37682 .32538 .37631 .33097 .37904 .32681 .38243 Mtetra
.351 0 0 r
.32681 .38243 .33097 .37904 .33654 .38268 .33262 .38229 Mtetra
.687 .149 0 r
.33262 .38229 .33654 .38268 .34246 .38064 .33816 .38717 Mtetra
.546 .143 .229 r
.33816 .38717 .34246 .38064 .3483 .38049 .34391 .38895 Mtetra
.22 0 .113 r
.34391 .38895 .3483 .38049 .35458 .37223 .35 .38497 Mtetra
.492 .16 .332 r
.35 .38497 .35458 .37223 .36035 .37397 .35589 .38483 Mtetra
0 0 0 r
.35589 .38483 .36035 .37397 .36664 .36561 .36235 .37398 Mtetra
.36235 .37398 .36664 .36561 .37288 .35802 .36873 .36442 Mtetra
.36873 .36442 .37288 .35802 .37853 .36332 .37487 .35947 Mtetra
.831 .771 .795 r
.37487 .35947 .37853 .36332 .38416 .36988 .3811 .35271 Mtetra
.702 .524 .645 r
.3811 .35271 .38416 .36988 .39064 .35723 .38743 .34367 Mtetra
.705 .547 .671 r
.38743 .34367 .39064 .35723 .39738 .33763 .39367 .33644 Mtetra
.725 .195 0 r
.39367 .33644 .39738 .33763 .40329 .33832 .39937 .34258 Mtetra
.377 0 .009 r
.39937 .34258 .40329 .33832 .40909 .34253 .40536 .34233 Mtetra
.854 .966 .872 r
.40536 .34233 .40909 .34253 .41496 .34599 .41156 .33651 Mtetra
.626 .547 .745 r
.41156 .33651 .41496 .34599 .42116 .34014 .41765 .33438 Mtetra
.75 .691 .794 r
.41765 .33438 .42116 .34014 .42742 .33261 .42383 .32959 Mtetra
.829 .817 .838 r
.42383 .32959 .42742 .33261 .43352 .33048 .43004 .32379 Mtetra
.686 .639 .796 r
.43004 .32379 .43352 .33048 .4396 .32926 .43618 .32061 Mtetra
.632 .566 .762 r
.43618 .32061 .4396 .32926 .44543 .3385 .4423 .31847 Mtetra
.547 .405 .64 r
.4423 .31847 .44543 .3385 .4519 .32329 .44839 .31842 Mtetra
.705 .711 .853 r
.44839 .31842 .4519 .32329 .45807 .32005 .45456 .31531 Mtetra
.609 .682 .894 r
.45456 .31531 .45807 .32005 .46403 .32814 .46071 .314 Mtetra
.504 .414 .687 r
.46071 .314 .46403 .32814 .47022 .32599 .46683 .31541 Mtetra
0 0 .468 r
.46683 .31541 .47022 .32599 .47638 .32679 .47278 .32833 Mtetra
.518 .901 .737 r
.47278 .32833 .47638 .32679 .48263 .32282 .47906 .3243 Mtetra
0 0 0 r
.47906 .3243 .48263 .32282 .48883 .32433 .48532 .32213 Mtetra
.407 .756 .994 r
.48532 .32213 .48883 .32433 .49505 .326 .49157 .32182 Mtetra
.715 .751 .88 r
.49157 .32182 .49505 .326 .50137 .31949 .49787 .31864 Mtetra
.888 .938 .842 r
.49787 .31864 .50137 .31949 .50768 .31326 .5042 .31175 Mtetra
.944 .857 .726 r
.5042 .31175 .50768 .31326 .51398 .30791 .51055 .30012 Mtetra
.798 .664 .716 r
.51055 .30012 .51398 .30791 .5203 .29689 .51687 .29134 Mtetra
.159 .398 .843 r
.51687 .29134 .5203 .29689 .5266 .30156 .52317 .29485 Mtetra
.715 .656 .79 r
.52317 .29485 .5266 .30156 .53291 .29264 .5295 .29076 Mtetra
.774 .901 .931 r
.5295 .29076 .53291 .29264 .53923 .29041 .53584 .28672 Mtetra
.7 .776 .91 r
.53584 .28672 .53923 .29041 .54562 .29459 .54219 .2839 Mtetra
.168 .242 .697 r
.54219 .2839 .54562 .29459 .55208 .3032 .54862 .29089 Mtetra
.448 .401 .713 r
.54862 .29089 .55208 .3032 .55853 .30455 .55507 .29358 Mtetra
.202 .261 .702 r
.55507 .29358 .55853 .30455 .56501 .30602 .5616 .30032 Mtetra
.909 .734 .653 r
.5616 .30032 .56501 .30602 .57129 .29271 .56785 .28338 Mtetra
.629 .556 .754 r
.56785 .28338 .57129 .29271 .57774 .29047 .5743 .28113 Mtetra
.8 .644 .688 r
.5743 .28113 .57774 .29047 .58404 .28015 .58061 .27064 Mtetra
.543 .504 .762 r
.58061 .27064 .58404 .28015 .59033 .27017 .58711 .27067 Mtetra
.883 .462 .197 r
.58711 .27067 .59033 .27017 .59733 .29134 .594 .28718 Mtetra
.516 .682 .941 r
.594 .28718 .59733 .29134 .60405 .29679 .60058 .28683 Mtetra
.159 .255 .714 r
.60058 .28683 .60405 .29679 .6108 .30176 .60737 .2937 Mtetra
.856 .687 .672 r
.60737 .2937 .6108 .30176 .61738 .2995 .61362 .27991 Mtetra
.312 .251 .627 r
.61362 .27991 .61738 .2995 .6241 .30114 .62055 .28916 Mtetra
0 0 .352 r
.62055 .28916 .6241 .30114 .63046 .29109 .62791 .30932 Mtetra
0 0 .15 r
.62791 .30932 .63046 .29109 .6366 .27539 .6339 .28747 Mtetra
0 0 .049 r
.6339 .28747 .6366 .27539 .64313 .27123 .64006 .27184 Mtetra
.027 0 0 r
.64006 .27184 .64313 .27123 .64991 .27271 .64677 .27142 Mtetra
.78 .279 0 r
.64677 .27142 .64991 .27271 .65663 .27231 .65395 .28154 Mtetra
.604 .223 .294 r
.65395 .28154 .65663 .27231 .66351 .27485 .66093 .28564 Mtetra
.775 .409 .364 r
.66093 .28564 .66351 .27485 .67065 .28217 .66851 .30166 Mtetra
.704 .377 .42 r
.66851 .30166 .67065 .28217 .6786 .30474 .67614 .31671 Mtetra
.741 .705 .168 r
.67614 .31671 .6786 .30474 .68488 .2924 .68162 .28746 Mtetra
.825 .765 .796 r
.68162 .28746 .68488 .2924 .69167 .29009 .68818 .28051 Mtetra
.732 .613 .725 r
.68818 .28051 .69167 .29009 .69792 .27768 .69477 .27415 Mtetra
.949 .808 .669 r
.69477 .27415 .69792 .27768 .70438 .26941 .70086 .25917 Mtetra
.891 .677 .606 r
.70086 .25917 .70438 .26941 .70982 .24458 .70647 .23663 Mtetra
.703 .629 .771 r
.70647 .23663 .70982 .24458 .71601 .23292 .71312 .23233 Mtetra
.952 .942 .732 r
.71312 .23233 .71601 .23292 .72259 .22766 .71939 .22198 Mtetra
.48 .588 .885 r
.71939 .22198 .72259 .22766 .72971 .23046 .72637 .22252 Mtetra
.658 .607 .786 r
.72637 .22252 .72971 .23046 .73615 .22292 .73314 .21964 Mtetra
.671 .811 .95 r
.73314 .21964 .73615 .22292 .74289 .21965 .73995 .21709 Mtetra
.847 .894 .871 r
.73995 .21709 .74289 .21965 .74959 .21554 .74652 .21112 Mtetra
0 .237 .75 r
.74652 .21112 .74959 .21554 .75733 .22513 .75398 .21692 Mtetra
.757 .651 .744 r
.75398 .21692 .75733 .22513 .76474 .22947 .76054 .21037 Mtetra
.591 .444 .65 r
.76054 .21037 .76474 .22947 .77062 .21433 .76743 .20796 Mtetra
0 0 .553 r
.76743 .20796 .77062 .21433 .77796 .21728 .77546 .21923 Mtetra
.716 .203 .004 r
.77546 .21923 .77796 .21728 .78572 .22463 .78325 .22666 Mtetra
.842 .387 .125 r
.78325 .22666 .78572 .22463 .79419 .23937 .79176 .24173 Mtetra
.96 .867 .463 r
.79176 .24173 .79419 .23937 .79945 .21745 .79724 .22169 Mtetra
.889 .832 .365 r
.79724 .22169 .79945 .21745 .80614 .21176 .8026 .20116 Mtetra
.624 .539 .739 r
.8026 .20116 .80614 .21176 .81331 .21103 .8096 .19871 Mtetra
.825 .933 .559 r
.18297 .44219 .18796 .43565 .19404 .42919 .18958 .43095 Mtetra
.964 .864 .691 r
.18958 .43095 .19404 .42919 .20137 .41031 .19653 .41609 Mtetra
.964 .935 .625 r
.19653 .41609 .20137 .41031 .2077 .40111 .20347 .40105 Mtetra
.742 .963 .938 r
.20347 .40105 .2077 .40111 .21346 .39761 .20927 .39741 Mtetra
.197 .723 .842 r
.20927 .39741 .21346 .39761 .21854 .40146 .21477 .39683 Mtetra
.042 .375 .841 r
.21477 .39683 .21854 .40146 .22458 .39521 .21996 .39979 Mtetra
.696 .294 .282 r
.21996 .39979 .22458 .39521 .22981 .39789 .22495 .40516 Mtetra
.728 .372 .376 r
.22495 .40516 .22981 .39789 .23422 .41 .2297 .41352 Mtetra
.083 0 0 r
.2297 .41352 .23422 .41 .24008 .40629 .23543 .41154 Mtetra
.281 0 .005 r
.23543 .41154 .24008 .40629 .24518 .41141 .24114 .40999 Mtetra
.622 .879 .989 r
.24114 .40999 .24518 .41141 .25031 .41674 .24689 .408 Mtetra
.772 .63 .703 r
.24689 .408 .25031 .41674 .25666 .40775 .2532 .39952 Mtetra
.811 .653 .687 r
.2532 .39952 .25666 .40775 .26333 .39458 .25975 .38812 Mtetra
.713 .648 .783 r
.25975 .38812 .26333 .39458 .26893 .39464 .26567 .38425 Mtetra
.738 .593 .694 r
.26567 .38425 .26893 .39464 .27484 .39097 .27187 .37676 Mtetra
.67 .519 .671 r
.27187 .37676 .27484 .39097 .28133 .37974 .27791 .37141 Mtetra
.128 .264 .736 r
.27791 .37141 .28133 .37974 .287 .37938 .28317 .37632 Mtetra
.616 .77 .954 r
.28317 .37632 .287 .37938 .29278 .37762 .28894 .37484 Mtetra
.442 .725 .986 r
.28894 .37484 .29278 .37762 .29859 .37559 .29463 .37469 Mtetra
.919 .862 .768 r
.29463 .37469 .29859 .37559 .30452 .37215 .301 .36516 Mtetra
.408 .483 .825 r
.301 .36516 .30452 .37215 .31036 .3701 .30658 .36683 Mtetra
.889 .462 .112 r
.30658 .36683 .31036 .3701 .31563 .37698 .3115 .37887 Mtetra
.533 .909 .742 r
.3115 .37887 .31563 .37698 .32139 .37682 .31753 .37492 Mtetra
.809 .322 0 r
.31753 .37492 .32139 .37682 .32681 .38243 .3228 .38289 Mtetra
.71 .981 .904 r
.3228 .38289 .32681 .38243 .33262 .38229 .32886 .37892 Mtetra
.673 .164 0 r
.32886 .37892 .33262 .38229 .33816 .38717 .33429 .38562 Mtetra
.318 .748 .971 r
.33429 .38562 .33816 .38717 .34391 .38895 .34016 .38541 Mtetra
.86 .779 .77 r
.34016 .38541 .34391 .38895 .35 .38497 .3465 .37712 Mtetra
.79 .654 .713 r
.3465 .37712 .35 .38497 .35589 .38483 .35285 .36845 Mtetra
.595 .457 .663 r
.35285 .36845 .35589 .38483 .36235 .37398 .35885 .36637 Mtetra
.814 .668 .701 r
.35885 .36637 .36235 .37398 .36873 .36442 .36528 .35601 Mtetra
.785 .644 .706 r
.36528 .35601 .36873 .36442 .37487 .35947 .37162 .34718 Mtetra
.764 .592 .664 r
.37162 .34718 .37487 .35947 .3811 .35271 .37804 .33622 Mtetra
.627 .477 .659 r
.37804 .33622 .3811 .35271 .38743 .34367 .38412 .3325 Mtetra
.392 .376 .722 r
.38412 .3325 .38743 .34367 .39367 .33644 .38991 .33578 Mtetra
.837 .948 .892 r
.38991 .33578 .39367 .33644 .39937 .34258 .39608 .33051 Mtetra
.664 .535 .696 r
.39608 .33051 .39937 .34258 .40536 .34233 .40222 .32621 Mtetra
.586 .452 .665 r
.40222 .32621 .40536 .34233 .41156 .33651 .40826 .32456 Mtetra
.641 .522 .703 r
.40826 .32456 .41156 .33651 .41765 .33438 .41437 .32131 Mtetra
.357 .327 .688 r
.41437 .32131 .41765 .33438 .42383 .32959 .42023 .32595 Mtetra
.684 .765 .913 r
.42023 .32595 .42383 .32959 .43004 .32379 .42636 .32348 Mtetra
.42 .858 .923 r
.42636 .32348 .43004 .32379 .43618 .32061 .43247 .32182 Mtetra
.285 .773 .703 r
.43247 .32182 .43618 .32061 .4423 .31847 .43861 .31951 Mtetra
.562 .933 .815 r
.43861 .31951 .4423 .31847 .44839 .31842 .44481 .31583 Mtetra
.76 .846 .915 r
.44481 .31583 .44839 .31842 .45456 .31531 .45101 .31209 Mtetra
.52 .735 .972 r
.45101 .31209 .45456 .31531 .46071 .314 .45716 .31146 Mtetra
.478 .766 .994 r
.45716 .31146 .46071 .314 .46683 .31541 .46332 .31086 Mtetra
.092 .411 .862 r
.46332 .31086 .46683 .31541 .47278 .32833 .46944 .31399 Mtetra
.603 .478 .682 r
.46944 .31399 .47278 .32833 .47906 .3243 .47567 .31181 Mtetra
.448 .397 .708 r
.47567 .31181 .47906 .3243 .48532 .32213 .48186 .31442 Mtetra
.446 .489 .81 r
.48186 .31442 .48532 .32213 .49157 .32182 .48809 .31592 Mtetra
.607 .635 .852 r
.48809 .31592 .49157 .32182 .49787 .31864 .49437 .3146 Mtetra
.787 .775 .842 r
.49437 .3146 .49787 .31864 .5042 .31175 .50071 .30961 Mtetra
.951 .811 .669 r
.50071 .30961 .5042 .31175 .51055 .30012 .50711 .29393 Mtetra
.588 .614 .846 r
.50711 .29393 .51055 .30012 .51687 .29134 .51341 .29296 Mtetra
0 0 0 r
.51341 .29296 .51687 .29134 .52317 .29485 .51974 .29076 Mtetra
.756 .769 .864 r
.51974 .29076 .52317 .29485 .5295 .29076 .52608 .28666 Mtetra
.836 .78 .799 r
.52608 .28666 .5295 .29076 .53584 .28672 .53242 .27977 Mtetra
.646 .619 .808 r
.53242 .27977 .53584 .28672 .54219 .2839 .53877 .27754 Mtetra
.012 .263 .765 r
.53877 .27754 .54219 .2839 .54862 .29089 .54519 .28292 Mtetra
.336 .416 .796 r
.54519 .28292 .54862 .29089 .55507 .29358 .55164 .2861 Mtetra
.568 .565 .81 r
.55164 .2861 .55507 .29358 .5616 .30032 .55809 .2855 Mtetra
.609 .479 .679 r
.55809 .2855 .5616 .30032 .56785 .28338 .56453 .28292 Mtetra
.977 .871 .664 r
.56453 .28292 .56785 .28338 .5743 .28113 .5708 .26812 Mtetra
0 0 .359 r
.5708 .26812 .5743 .28113 .58061 .27064 .57763 .28795 Mtetra
.164 0 .27 r
.57763 .28795 .58061 .27064 .58711 .27067 .58396 .27653 Mtetra
0 0 0 r
.58396 .27653 .58711 .27067 .594 .28718 .59035 .26846 Mtetra
.183 .166 .604 r
.59035 .26846 .594 .28718 .60058 .28683 .59719 .28072 Mtetra
.405 .526 .866 r
.59719 .28072 .60058 .28683 .60737 .2937 .60385 .28229 Mtetra
.302 .323 .716 r
.60385 .28229 .60737 .2937 .61362 .27991 .61064 .28775 Mtetra
.22 0 .112 r
.61064 .28775 .61362 .27991 .62055 .28916 .61719 .2835 Mtetra
0 0 .468 r
.61719 .2835 .62055 .28916 .62791 .30932 .62422 .2937 Mtetra
.659 .507 .667 r
.62422 .2937 .62791 .30932 .6339 .28747 .63078 .28828 Mtetra
.206 .724 .696 r
.63078 .28828 .6339 .28747 .64006 .27184 .63747 .28639 Mtetra
.629 .289 .376 r
.63747 .28639 .64006 .27184 .64677 .27142 .64449 .29284 Mtetra
.53 .231 .404 r
.64449 .29284 .64677 .27142 .65395 .28154 .65136 .29398 Mtetra
.534 .188 .327 r
.65136 .29398 .65395 .28154 .66093 .28564 .65828 .29553 Mtetra
.732 .356 .339 r
.65828 .29553 .66093 .28564 .66851 .30166 .66567 .30689 Mtetra
.808 .396 .266 r
.66567 .30689 .66851 .30166 .67614 .31671 .67325 .3207 Mtetra
.934 .883 .469 r
.67325 .3207 .67614 .31671 .68162 .28746 .67932 .30205 Mtetra
0 0 .035 r
.67932 .30205 .68162 .28746 .68818 .28051 .6851 .27884 Mtetra
.966 .876 .695 r
.6851 .27884 .68818 .28051 .69477 .27415 .69135 .26591 Mtetra
.701 .623 .766 r
.69135 .26591 .69477 .27415 .70086 .25917 .69806 .26156 Mtetra
.989 .857 .493 r
.69806 .26156 .70086 .25917 .70647 .23663 .70369 .23876 Mtetra
.731 .936 .607 r
.70369 .23876 .70647 .23663 .71312 .23233 .71014 .23062 Mtetra
.97 .874 .683 r
.71014 .23062 .71312 .23233 .71939 .22198 .71625 .21731 Mtetra
.646 .72 .902 r
.71625 .21731 .71939 .22198 .72637 .22252 .72306 .2152 Mtetra
.43 .498 .828 r
.72306 .2152 .72637 .22252 .73314 .21964 .73015 .21696 Mtetra
.851 .887 .864 r
.73015 .21696 .73314 .21964 .73995 .21709 .73673 .21082 Mtetra
.1 .326 .8 r
.73673 .21082 .73995 .21709 .74652 .21112 .74412 .21608 Mtetra
.495 .035 .089 r
.74412 .21608 .74652 .21112 .75398 .21692 .75129 .21755 Mtetra
.835 .992 .74 r
.75129 .21755 .75398 .21692 .76054 .21037 .75778 .20981 Mtetra
.176 .706 .85 r
.75778 .20981 .76054 .21037 .76743 .20796 .76485 .20935 Mtetra
.837 .374 .095 r
.76485 .20935 .76743 .20796 .77546 .21923 .77313 .22356 Mtetra
.483 .003 .039 r
.77313 .22356 .77546 .21923 .78325 .22666 .78044 .22505 Mtetra
.592 .048 0 r
.78044 .22505 .78325 .22666 .79176 .24173 .78831 .23248 Mtetra
.809 .659 .697 r
.78831 .23248 .79176 .24173 .79724 .22169 .79466 .22215 Mtetra
.985 .891 .559 r
.79466 .22215 .79724 .22169 .8026 .20116 .80038 .20507 Mtetra
.839 .843 .379 r
.80038 .20507 .8026 .20116 .8096 .19871 .80608 .18837 Mtetra
.98 .883 .661 r
.17824 .44587 .18297 .44219 .18958 .43095 .18547 .42898 Mtetra
.885 .812 .771 r
.18547 .42898 .18958 .43095 .19653 .41609 .19183 .42017 Mtetra
.905 .977 .691 r
.19183 .42017 .19653 .41609 .20347 .40105 .19829 .41023 Mtetra
0 0 0 r
.19829 .41023 .20347 .40105 .20927 .39741 .20468 .40085 Mtetra
.62 .919 .654 r
.20468 .40085 .20927 .39741 .21477 .39683 .21069 .39525 Mtetra
.879 .46 .21 r
.21069 .39525 .21477 .39683 .21996 .39979 .21514 .40592 Mtetra
.685 .304 .32 r
.21514 .40592 .21996 .39979 .22495 .40516 .22013 .41149 Mtetra
.492 .084 .193 r
.22013 .41149 .22495 .40516 .2297 .41352 .22561 .41219 Mtetra
.78 .898 .926 r
.22561 .41219 .2297 .41352 .23543 .41154 .23152 .4083 Mtetra
.343 .647 .967 r
.23152 .4083 .23543 .41154 .24114 .40999 .23703 .40894 Mtetra
.856 .895 .863 r
.23703 .40894 .24114 .40999 .24689 .408 .24313 .40313 Mtetra
.788 .718 .787 r
.24313 .40313 .24689 .408 .2532 .39952 .24923 .39733 Mtetra
.895 .806 .753 r
.24923 .39733 .2532 .39952 .25975 .38812 .25567 .38749 Mtetra
.857 .923 .872 r
.25567 .38749 .25975 .38812 .26567 .38425 .26175 .38181 Mtetra
.871 .812 .788 r
.26175 .38181 .26567 .38425 .27187 .37676 .268 .37396 Mtetra
.412 .71 .984 r
.268 .37396 .27187 .37676 .27791 .37141 .27363 .37399 Mtetra
0 0 0 r
.27363 .37399 .27791 .37141 .28317 .37632 .27948 .37129 Mtetra
.829 .721 .745 r
.27948 .37129 .28317 .37632 .28894 .37484 .28577 .36294 Mtetra
.448 .398 .71 r
.28577 .36294 .28894 .37484 .29463 .37469 .29127 .36522 Mtetra
.45 .44 .757 r
.29127 .36522 .29463 .37469 .301 .36516 .29684 .36697 Mtetra
.197 0 0 r
.29684 .36697 .301 .36516 .30658 .36683 .30258 .36664 Mtetra
.852 .425 .209 r
.30258 .36664 .30658 .36683 .3115 .37887 .30761 .37698 Mtetra
.352 .746 .985 r
.30761 .37698 .3115 .37887 .31753 .37492 .31339 .37683 Mtetra
.786 .355 .226 r
.31339 .37683 .31753 .37492 .3228 .38289 .31867 .38485 Mtetra
.766 .993 .785 r
.31867 .38485 .3228 .38289 .32886 .37892 .32487 .37894 Mtetra
.916 .929 .805 r
.32487 .37894 .32886 .37892 .33429 .38562 .3312 .37085 Mtetra
.638 .495 .672 r
.3312 .37085 .33429 .38562 .34016 .38541 .33727 .36701 Mtetra
.569 .427 .649 r
.33727 .36701 .34016 .38541 .3465 .37712 .34319 .36592 Mtetra
.715 .574 .694 r
.34319 .36592 .3465 .37712 .35285 .36845 .34943 .35938 Mtetra
.77 .628 .703 r
.34943 .35938 .35285 .36845 .35885 .36637 .35576 .35094 Mtetra
.748 .563 .645 r
.35576 .35094 .35885 .36637 .36528 .35601 .36228 .33873 Mtetra
.413 .325 .647 r
.36228 .33873 .36528 .35601 .37162 .34718 .36795 .34321 Mtetra
.89 .759 .71 r
.36795 .34321 .37162 .34718 .37804 .33622 .37444 .33113 Mtetra
.852 .432 0 r
.37444 .33113 .37804 .33622 .38412 .3325 .37977 .34406 Mtetra
.481 .138 .307 r
.37977 .34406 .38412 .3325 .38991 .33578 .38574 .34381 Mtetra
.388 .004 .185 r
.38574 .34381 .38991 .33578 .39608 .33051 .39179 .34238 Mtetra
.218 0 .197 r
.39179 .34238 .39608 .33051 .40222 .32621 .39803 .33645 Mtetra
.284 0 .194 r
.39803 .33645 .40222 .32621 .40826 .32456 .4042 .33242 Mtetra
0 0 0 r
.4042 .33242 .40826 .32456 .41437 .32131 .41046 .32599 Mtetra
.41046 .32599 .41437 .32131 .42023 .32595 .41664 .32199 Mtetra
.652 .739 .913 r
.41664 .32199 .42023 .32595 .42636 .32348 .42275 .32 Mtetra
.695 .779 .916 r
.42275 .32 .42636 .32348 .43247 .32182 .4289 .31735 Mtetra
.642 .709 .896 r
.4289 .31735 .43247 .32182 .43861 .31951 .43504 .31552 Mtetra
.742 .763 .87 r
.43504 .31552 .43861 .31951 .44481 .31583 .44125 .31183 Mtetra
.744 .764 .869 r
.44125 .31183 .44481 .31583 .45101 .31209 .44746 .30808 Mtetra
.101 .451 .884 r
.44746 .30808 .45101 .31209 .45716 .31146 .45354 .31071 Mtetra
.745 .956 .942 r
.45354 .31071 .45716 .31146 .46332 .31086 .45978 .30684 Mtetra
0 .294 .782 r
.45978 .30684 .46332 .31086 .46944 .31399 .46589 .31081 Mtetra
.514 .739 .976 r
.46589 .31081 .46944 .31399 .47567 .31181 .47211 .31019 Mtetra
.939 .851 .729 r
.47211 .31019 .47567 .31181 .48186 .31442 .47851 .29868 Mtetra
.598 .464 .67 r
.47851 .29868 .48186 .31442 .48809 .31592 .48477 .29648 Mtetra
.431 .329 .638 r
.48477 .29648 .48809 .31592 .49437 .3146 .49097 .30113 Mtetra
.677 .532 .681 r
.49097 .30113 .49437 .3146 .50071 .30961 .4973 .29561 Mtetra
.721 .555 .664 r
.4973 .29561 .50071 .30961 .50711 .29393 .50366 .287 Mtetra
.015 .243 .748 r
.50366 .287 .50711 .29393 .51341 .29296 .50993 .29267 Mtetra
.912 .953 .809 r
.50993 .29267 .51341 .29296 .51974 .29076 .51629 .28477 Mtetra
.773 .7 .782 r
.51629 .28477 .51974 .29076 .52608 .28666 .52264 .27901 Mtetra
.594 .573 .8 r
.52264 .27901 .52608 .28666 .53242 .27977 .52899 .27787 Mtetra
.394 0 0 r
.52899 .27787 .53242 .27977 .53877 .27754 .53538 .28177 Mtetra
0 0 0 r
.53538 .28177 .53877 .27754 .54519 .28292 .54176 .27452 Mtetra
.623 .571 .776 r
.54176 .27452 .54519 .28292 .55164 .2861 .54816 .2726 Mtetra
.334 .312 .686 r
.54816 .2726 .55164 .2861 .55809 .2855 .55465 .27819 Mtetra
.865 .699 .675 r
.55465 .27819 .55809 .2855 .56453 .28292 .56097 .26442 Mtetra
.026 .057 .556 r
.56097 .26442 .56453 .28292 .5708 .26812 .56765 .27999 Mtetra
.246 0 .224 r
.56765 .27999 .5708 .26812 .57763 .28795 .57409 .27392 Mtetra
.605 .484 .688 r
.57409 .27392 .57763 .28795 .58396 .27653 .58059 .27165 Mtetra
.534 .651 .91 r
.58059 .27165 .58396 .27653 .59035 .26846 .58714 .27126 Mtetra
.747 .283 .147 r
.58714 .27126 .59035 .26846 .59719 .28072 .5939 .27901 Mtetra
.614 .887 .99 r
.5939 .27901 .59719 .28072 .60385 .28229 .60047 .27673 Mtetra
0 .016 .579 r
.60047 .27673 .60385 .28229 .61064 .28775 .60734 .28502 Mtetra
.139 .565 .926 r
.60734 .28502 .61064 .28775 .61719 .2835 .61408 .28667 Mtetra
.517 .011 0 r
.61408 .28667 .61719 .2835 .62422 .2937 .62087 .28887 Mtetra
.265 .509 .901 r
.62087 .28887 .62422 .2937 .63078 .28828 .62769 .29117 Mtetra
.755 .291 .145 r
.62769 .29117 .63078 .28828 .63747 .28639 .63477 .29961 Mtetra
.587 .241 .35 r
.63477 .29961 .63747 .28639 .64449 .29284 .64175 .30355 Mtetra
.366 .022 .243 r
.64175 .30355 .64449 .29284 .65136 .29398 .64849 .30047 Mtetra
.721 .308 .263 r
.64849 .30047 .65136 .29398 .65828 .29553 .65573 .30907 Mtetra
.661 .31 .367 r
.65573 .30907 .65828 .29553 .66567 .30689 .66302 .31736 Mtetra
.394 .043 .246 r
.66302 .31736 .66567 .30689 .67325 .3207 .66989 .31504 Mtetra
.951 .743 .587 r
.66989 .31504 .67325 .3207 .67932 .30205 .67566 .2897 Mtetra
.555 .475 .719 r
.67566 .2897 .67932 .30205 .6851 .27884 .68261 .28937 Mtetra
0 0 0 r
.68261 .28937 .6851 .27884 .69135 .26591 .68848 .26819 Mtetra
.68848 .26819 .69135 .26591 .69806 .26156 .69518 .26319 Mtetra
.984 .89 .55 r
.69518 .26319 .69806 .26156 .70369 .23876 .70113 .24505 Mtetra
0 0 0 r
.70113 .24505 .70369 .23876 .71014 .23062 .70732 .23195 Mtetra
.811 .978 .69 r
.70732 .23195 .71014 .23062 .71625 .21731 .71379 .22384 Mtetra
.305 0 .097 r
.71379 .22384 .71625 .21731 .72306 .2152 .72062 .22145 Mtetra
.375 0 .109 r
.72062 .22145 .72306 .2152 .73015 .21696 .72755 .22033 Mtetra
.311 0 0 r
.72755 .22033 .73015 .21696 .73673 .21082 .73455 .21987 Mtetra
.575 .187 .269 r
.73455 .21987 .73673 .21082 .74412 .21608 .74184 .22307 Mtetra
0 0 0 r
.74184 .22307 .74412 .21608 .75129 .21755 .74833 .21485 Mtetra
0 .143 .619 r
.74833 .21485 .75129 .21755 .75778 .20981 .75587 .22061 Mtetra
.468 .112 .278 r
.75587 .22061 .75778 .20981 .76485 .20935 .76298 .22015 Mtetra
.673 .295 .321 r
.76298 .22015 .76485 .20935 .77313 .22356 .77081 .22835 Mtetra
0 0 0 r
.77081 .22835 .77313 .22356 .78044 .22505 .7775 .222 Mtetra
.153 .548 .926 r
.7775 .222 .78044 .22505 .78831 .23248 .78491 .22403 Mtetra
.835 .684 .695 r
.78491 .22403 .78831 .23248 .79466 .22215 .7912 .21282 Mtetra
.777 .643 .714 r
.7912 .21282 .79466 .22215 .80038 .20507 .79772 .20445 Mtetra
.999 .839 .53 r
.79772 .20445 .80038 .20507 .80608 .18837 .80296 .18243 Mtetra
.979 .911 .656 r
.17337 .45047 .17824 .44587 .18547 .42898 .18054 .43456 Mtetra
.966 .935 .636 r
.18054 .43456 .18547 .42898 .19183 .42017 .18756 .41963 Mtetra
.773 .94 .935 r
.18756 .41963 .19183 .42017 .19829 .41023 .19343 .41576 Mtetra
.961 .939 .634 r
.19343 .41576 .19829 .41023 .20468 .40085 .20037 .40123 Mtetra
.439 0 0 r
.20037 .40123 .20468 .40085 .21069 .39525 .20567 .40301 Mtetra
.419 .031 .194 r
.20567 .40301 .21069 .39525 .21514 .40592 .21124 .40225 Mtetra
.603 .092 0 r
.21124 .40225 .21514 .40592 .22013 .41149 .21623 .40781 Mtetra
.6 .726 .933 r
.21623 .40781 .22013 .41149 .22561 .41219 .22188 .40661 Mtetra
.807 .7 .747 r
.22188 .40661 .22561 .41219 .23152 .4083 .22815 .39897 Mtetra
.549 .501 .755 r
.22815 .39897 .23152 .4083 .23703 .40894 .23372 .39883 Mtetra
.673 .56 .72 r
.23372 .39883 .23703 .40894 .24313 .40313 .23965 .39494 Mtetra
.819 .657 .682 r
.23965 .39494 .24313 .40313 .24923 .39733 .24632 .38268 Mtetra
.694 .532 .663 r
.24632 .38268 .24923 .39733 .25567 .38749 .25251 .37563 Mtetra
.605 .498 .706 r
.25251 .37563 .25567 .38749 .26175 .38181 .25827 .3738 Mtetra
.64 .579 .77 r
.25827 .3738 .26175 .38181 .268 .37396 .26407 .37161 Mtetra
.868 .819 .798 r
.26407 .37161 .268 .37396 .27363 .37399 .2703 .36414 Mtetra
.57 .505 .743 r
.2703 .36414 .27363 .37399 .27948 .37129 .27599 .36352 Mtetra
.636 .582 .777 r
.27599 .36352 .27948 .37129 .28577 .36294 .28181 .36146 Mtetra
.797 .895 .913 r
.28181 .36146 .28577 .36294 .29127 .36522 .2878 .35721 Mtetra
0 .169 .693 r
.2878 .35721 .29127 .36522 .29684 .36697 .29306 .36317 Mtetra
0 .323 .796 r
.29306 .36317 .29684 .36697 .30258 .36664 .29855 .36641 Mtetra
.855 .43 .214 r
.29855 .36641 .30258 .36664 .30761 .37698 .30356 .377 Mtetra
.612 .055 0 r
.30356 .377 .30761 .37698 .31339 .37683 .3091 .38068 Mtetra
0 0 0 r
.3091 .38068 .31339 .37683 .31867 .38485 .31522 .37595 Mtetra
.762 .626 .71 r
.31522 .37595 .31867 .38485 .32487 .37894 .32154 .36817 Mtetra
.762 .604 .682 r
.32154 .36817 .32487 .37894 .3312 .37085 .32795 .35875 Mtetra
.686 .548 .691 r
.32795 .35875 .3312 .37085 .33727 .36701 .33411 .35335 Mtetra
.463 .39 .689 r
.33411 .35335 .33727 .36701 .34319 .36592 .33982 .35563 Mtetra
.693 .572 .714 r
.33982 .35563 .34319 .36592 .34943 .35938 .34597 .35076 Mtetra
.787 .642 .701 r
.34597 .35076 .34943 .35938 .35576 .35094 .35235 .34155 Mtetra
0 .057 .612 r
.35235 .34155 .35576 .35094 .36228 .33873 .3578 .34982 Mtetra
.817 .83 .356 r
.3578 .34982 .36228 .33873 .36795 .34321 .36477 .32933 Mtetra
.382 .334 .679 r
.36477 .32933 .36795 .34321 .37444 .33113 .37047 .33356 Mtetra
.818 .409 .273 r
.37047 .33356 .37444 .33113 .37977 .34406 .3759 .34423 Mtetra
.873 .463 .244 r
.3759 .34423 .37977 .34406 .38574 .34381 .38128 .35749 Mtetra
0 0 .122 r
.38128 .35749 .38574 .34381 .39179 .34238 .38776 .34692 Mtetra
.384 0 .025 r
.38776 .34692 .39179 .34238 .39803 .33645 .39379 .3467 Mtetra
.79 .821 .344 r
.39379 .3467 .39803 .33645 .4042 .33242 .40059 .32759 Mtetra
.848 .741 .745 r
.40059 .32759 .4042 .33242 .41046 .32599 .40696 .31861 Mtetra
.317 .421 .81 r
.40696 .31861 .41046 .32599 .41664 .32199 .4129 .32149 Mtetra
.453 .87 .946 r
.4129 .32149 .41664 .32199 .42275 .32 .41902 .3198 Mtetra
.875 .963 .853 r
.41902 .3198 .42275 .32 .4289 .31735 .42531 .31336 Mtetra
.56 .704 .937 r
.42531 .31336 .4289 .31735 .43504 .31552 .43143 .31254 Mtetra
.878 .815 .783 r
.43143 .31254 .43504 .31552 .44125 .31183 .43777 .30431 Mtetra
.131 .299 .767 r
.43777 .30431 .44125 .31183 .44746 .30808 .44376 .30914 Mtetra
.334 .809 .741 r
.44376 .30914 .44746 .30808 .45354 .31071 .44998 .30668 Mtetra
.749 .765 .866 r
.44998 .30668 .45354 .31071 .45978 .30684 .45623 .3028 Mtetra
.744 .764 .869 r
.45623 .3028 .45978 .30684 .46589 .31081 .46249 .29902 Mtetra
.504 .442 .72 r
.46249 .29902 .46589 .31081 .47211 .31019 .46867 .3001 Mtetra
.758 .612 .697 r
.46867 .3001 .47211 .31019 .47851 .29868 .47503 .29177 Mtetra
.606 .599 .818 r
.47503 .29177 .47851 .29868 .48477 .29648 .48129 .29042 Mtetra
.672 .658 .828 r
.48129 .29042 .48477 .29648 .49097 .30113 .48757 .28774 Mtetra
.557 .457 .697 r
.48757 .28774 .49097 .30113 .4973 .29561 .49385 .28735 Mtetra
.253 .355 .775 r
.49385 .28735 .4973 .29561 .50366 .287 .50011 .29154 Mtetra
.508 .048 .095 r
.50011 .29154 .50366 .287 .50993 .29267 .50642 .29308 Mtetra
.967 .916 .702 r
.50642 .29308 .50993 .29267 .51629 .28477 .51282 .28089 Mtetra
.745 .778 .88 r
.51282 .28089 .51629 .28477 .52264 .27901 .51918 .27712 Mtetra
.433 .794 .996 r
.51918 .27712 .52264 .27901 .52899 .27787 .52555 .2764 Mtetra
.774 .268 0 r
.52555 .2764 .52899 .27787 .53538 .28177 .53196 .28507 Mtetra
.884 .949 .593 r
.53196 .28507 .53538 .28177 .54176 .27452 .53834 .2735 Mtetra
.817 .954 .906 r
.53834 .2735 .54176 .27452 .54816 .2726 .54474 .26842 Mtetra
0 .363 .832 r
.54474 .26842 .54816 .2726 .55465 .27819 .55122 .2721 Mtetra
.83 .717 .74 r
.55122 .2721 .55465 .27819 .56097 .26442 .55761 .26338 Mtetra
.616 .051 0 r
.55761 .26338 .56097 .26442 .56765 .27999 .56417 .26881 Mtetra
.709 .575 .702 r
.56417 .26881 .56765 .27999 .57409 .27392 .5706 .26267 Mtetra
0 .073 .61 r
.5706 .26267 .57409 .27392 .58059 .27165 .57731 .27353 Mtetra
.429 .834 .639 r
.57731 .27353 .58059 .27165 .58714 .27126 .58382 .2693 Mtetra
.715 .194 0 r
.58382 .2693 .58714 .27126 .5939 .27901 .59059 .27754 Mtetra
0 .496 .805 r
.59059 .27754 .5939 .27901 .60047 .27673 .59727 .27916 Mtetra
.456 0 0 r
.59727 .27916 .60047 .27673 .60734 .28502 .60398 .28078 Mtetra
.791 .351 0 r
.60398 .28078 .60734 .28502 .61408 .28667 .61107 .29487 Mtetra
.088 0 .067 r
.61107 .29487 .61408 .28667 .62087 .28887 .61764 .28859 Mtetra
.774 .268 0 r
.61764 .28859 .62087 .28887 .62769 .29117 .6247 .29766 Mtetra
.522 .099 .178 r
.6247 .29766 .62769 .29117 .63477 .29961 .63157 .29935 Mtetra
.51 0 0 r
.63157 .29935 .63477 .29961 .64175 .30355 .63856 .30329 Mtetra
.839 .992 .853 r
.63856 .30329 .64175 .30355 .64849 .30047 .6452 .29696 Mtetra
0 .237 .725 r
.6452 .29696 .64849 .30047 .65573 .30907 .65229 .30187 Mtetra
0 .021 .594 r
.65229 .30187 .65573 .30907 .66302 .31736 .65965 .31181 Mtetra
.365 .537 .892 r
.65965 .31181 .66302 .31736 .66989 .31504 .66671 .31356 Mtetra
.987 .825 .595 r
.66671 .31356 .66989 .31504 .67566 .2897 .67274 .29283 Mtetra
0 0 0 r
.67274 .29283 .67566 .2897 .68261 .28937 .67951 .28847 Mtetra
.984 .872 .641 r
.67951 .28847 .68261 .28937 .68848 .26819 .6857 .27261 Mtetra
.593 .121 .105 r
.6857 .27261 .68848 .26819 .69518 .26319 .6929 .27625 Mtetra
.767 .7 .159 r
.6929 .27625 .69518 .26319 .70113 .24505 .69801 .24209 Mtetra
.97 .813 .631 r
.69801 .24209 .70113 .24505 .70732 .23195 .70396 .22445 Mtetra
.061 .257 .75 r
.70396 .22445 .70732 .23195 .71379 .22384 .71134 .23104 Mtetra
.324 0 .13 r
.71134 .23104 .71379 .22384 .72062 .22145 .71821 .22864 Mtetra
.71821 .22864 .72062 .22145 .72755 .22033 .72509 .22624 Mtetra
.587 .147 .171 r
.72509 .22624 .72755 .22033 .73455 .21987 .7324 .22975 Mtetra
.275 0 .201 r
.7324 .22975 .73455 .21987 .74184 .22307 .73916 .22492 Mtetra
.981 .873 .505 r
.73916 .22492 .74184 .22307 .74833 .21485 .74482 .20488 Mtetra
0 .005 .575 r
.74482 .20488 .74833 .21485 .75587 .22061 .75293 .21837 Mtetra
.65 .136 0 r
.75293 .21837 .75587 .22061 .76298 .22015 .76081 .22761 Mtetra
.396 0 .163 r
.76081 .22761 .76298 .22015 .77081 .22835 .76793 .2264 Mtetra
.77 .933 .938 r
.76793 .2264 .77081 .22835 .7775 .222 .7748 .22196 Mtetra
.801 1 .818 r
.7748 .22196 .7775 .222 .78491 .22403 .78152 .21557 Mtetra
.836 .684 .695 r
.78152 .21557 .78491 .22403 .7912 .21282 .78781 .20433 Mtetra
.7 .621 .766 r
.78781 .20433 .7912 .21282 .79772 .20445 .79469 .1999 Mtetra
.956 .791 .637 r
.79469 .1999 .79772 .20445 .80296 .18243 .80043 .18295 Mtetra
.675 .521 .668 r
.17055 .43592 .17337 .45047 .18054 .43456 .17663 .43014 Mtetra
.807 .732 .781 r
.17663 .43014 .18054 .43456 .18756 .41963 .1828 .42365 Mtetra
.775 .968 .674 r
.1828 .42365 .18756 .41963 .19343 .41576 .18906 .41611 Mtetra
.95 .819 .68 r
.18906 .41611 .19343 .41576 .20037 .40123 .19623 .39965 Mtetra
.551 0 0 r
.19623 .39965 .20037 .40123 .20567 .40301 .20136 .40323 Mtetra
.005 0 0 r
.20136 .40323 .20567 .40301 .21124 .40225 .20688 .4031 Mtetra
.362 .833 .809 r
.20688 .4031 .21124 .40225 .21623 .40781 .2126 .4011 Mtetra
.757 .659 .753 r
.2126 .4011 .21623 .40781 .22188 .40661 .21869 .39527 Mtetra
.745 .588 .68 r
.21869 .39527 .22188 .40661 .22815 .39897 .22506 .38654 Mtetra
.723 .565 .676 r
.22506 .38654 .22815 .39897 .23372 .39883 .23133 .37875 Mtetra
.603 .442 .637 r
.23133 .37875 .23372 .39883 .23965 .39494 .23717 .37565 Mtetra
.6 .443 .641 r
.23717 .37565 .23965 .39494 .24632 .38268 .24299 .37285 Mtetra
.622 .535 .736 r
.24299 .37285 .24632 .38268 .25251 .37563 .24876 .37082 Mtetra
.822 .725 .758 r
.24876 .37082 .25251 .37563 .25827 .3738 .25501 .36316 Mtetra
.558 .486 .729 r
.25501 .36316 .25827 .3738 .26407 .37161 .26065 .36278 Mtetra
.553 .515 .767 r
.26065 .36278 .26407 .37161 .2703 .36414 .2663 .36253 Mtetra
.508 0 0 r
.2663 .36253 .2703 .36414 .27599 .36352 .27167 .36605 Mtetra
.939 .965 .728 r
.27167 .36605 .27599 .36352 .28181 .36146 .27814 .35594 Mtetra
.335 .505 .877 r
.27814 .35594 .28181 .36146 .2878 .35721 .28368 .35768 Mtetra
.819 .378 .193 r
.28368 .35768 .2878 .35721 .29306 .36317 .28874 .36629 Mtetra
.78 .373 .281 r
.28874 .36629 .29306 .36317 .29855 .36641 .29386 .37484 Mtetra
.765 .418 .398 r
.29386 .37484 .29855 .36641 .30356 .377 .29877 .38714 Mtetra
.605 .249 .341 r
.29877 .38714 .30356 .377 .3091 .38068 .30433 .39089 Mtetra
0 0 .014 r
.30433 .39089 .3091 .38068 .31522 .37595 .3107 .383 Mtetra
0 0 0 r
.3107 .383 .31522 .37595 .32154 .36817 .31718 .3732 Mtetra
.993 .877 .587 r
.31718 .3732 .32154 .36817 .32795 .35875 .3244 .35158 Mtetra
.641 .604 .796 r
.3244 .35158 .32795 .35875 .33411 .35335 .33036 .34948 Mtetra
.844 .768 .778 r
.33036 .34948 .33411 .35335 .33982 .35563 .33667 .34188 Mtetra
.533 .435 .689 r
.33667 .34188 .33982 .35563 .34597 .35076 .3425 .34224 Mtetra
.711 .608 .74 r
.3425 .34224 .34597 .35076 .35235 .34155 .34865 .33743 Mtetra
.826 .761 .791 r
.34865 .33743 .35235 .34155 .3578 .34982 .35491 .33065 Mtetra
.437 .331 .636 r
.35491 .33065 .3578 .34982 .36477 .32933 .36059 .33471 Mtetra
.826 .464 .371 r
.36059 .33471 .36477 .32933 .37047 .33356 .36575 .3501 Mtetra
.67 .351 .425 r
.36575 .3501 .37047 .33356 .3759 .34423 .37127 .35964 Mtetra
.62 .296 .4 r
.37127 .35964 .3759 .34423 .38128 .35749 .37703 .3653 Mtetra
0 0 0 r
.37703 .3653 .38128 .35749 .38776 .34692 .38344 .35726 Mtetra
.953 .86 .443 r
.38344 .35726 .38776 .34692 .39379 .3467 .39066 .32979 Mtetra
.73 .544 .64 r
.39066 .32979 .39379 .3467 .40059 .32759 .39716 .31836 Mtetra
.639 .56 .749 r
.39716 .31836 .40059 .32759 .40696 .31861 .40328 .31586 Mtetra
.89 .463 .117 r
.40328 .31586 .40696 .31861 .4129 .32149 .40882 .32956 Mtetra
0 0 0 r
.40882 .32956 .4129 .32149 .41902 .3198 .41517 .32229 Mtetra
.939 .963 .684 r
.41517 .32229 .41902 .3198 .42531 .31336 .42164 .3112 Mtetra
.839 .869 .865 r
.42164 .3112 .42531 .31336 .43143 .31254 .42791 .30556 Mtetra
.682 .632 .793 r
.42791 .30556 .43143 .31254 .43777 .30431 .43412 .30238 Mtetra
.483 0 0 r
.43412 .30238 .43777 .30431 .44376 .30914 .44014 .3066 Mtetra
.744 .85 .929 r
.44014 .3066 .44376 .30914 .44998 .30668 .44639 .30313 Mtetra
.663 .77 .929 r
.44639 .30313 .44998 .30668 .45623 .3028 .45262 .30093 Mtetra
.812 .896 .902 r
.45262 .30093 .45623 .3028 .46249 .29902 .45891 .29613 Mtetra
.647 .808 .96 r
.45891 .29613 .46249 .29902 .46867 .3001 .46516 .29406 Mtetra
0 0 .476 r
.46516 .29406 .46867 .3001 .47503 .29177 .47124 .30294 Mtetra
.705 .353 .377 r
.47124 .30294 .47503 .29177 .48129 .29042 .47736 .3127 Mtetra
.349 .079 .356 r
.47736 .3127 .48129 .29042 .48757 .28774 .48377 .30522 Mtetra
.397 .1 .339 r
.48377 .30522 .48757 .28774 .49385 .28735 .49014 .30106 Mtetra
.273 0 .254 r
.49014 .30106 .49385 .28735 .50011 .29154 .49653 .29495 Mtetra
.326 0 0 r
.49653 .29495 .50011 .29154 .50642 .29308 .50288 .29466 Mtetra
.964 .94 .675 r
.50288 .29466 .50642 .29308 .51282 .28089 .50932 .28225 Mtetra
0 0 0 r
.50932 .28225 .51282 .28089 .51918 .27712 .51569 .28 Mtetra
.51569 .28 .51918 .27712 .52555 .2764 .52209 .27754 Mtetra
.102 0 0 r
.52209 .27754 .52555 .2764 .53196 .28507 .52849 .27713 Mtetra
.782 .659 .727 r
.52849 .27713 .53196 .28507 .53834 .2735 .5349 .26931 Mtetra
.828 .781 .808 r
.5349 .26931 .53834 .2735 .54474 .26842 .54131 .26274 Mtetra
0 .257 .767 r
.54131 .26274 .54474 .26842 .55122 .2721 .5478 .26795 Mtetra
.859 .786 .778 r
.5478 .26795 .55122 .2721 .55761 .26338 .55421 .25988 Mtetra
0 .269 .75 r
.55421 .25988 .55761 .26338 .56417 .26881 .56075 .26411 Mtetra
0 .314 .804 r
.56075 .26411 .56417 .26881 .5706 .26267 .56734 .26846 Mtetra
.622 .193 .207 r
.56734 .26846 .5706 .26267 .57731 .27353 .57397 .27263 Mtetra
.318 .787 .933 r
.57397 .27263 .57731 .27353 .58382 .2693 .58055 .27178 Mtetra
.716 .233 .098 r
.58055 .27178 .58382 .2693 .59059 .27754 .5873 .27837 Mtetra
.553 0 0 r
.5873 .27837 .59059 .27754 .59727 .27916 .59404 .28195 Mtetra
.757 .294 .149 r
.59404 .28195 .59727 .27916 .60398 .28078 .60094 .29032 Mtetra
.711 .335 .333 r
.60094 .29032 .60398 .28078 .61107 .29487 .60794 .29995 Mtetra
0 0 0 r
.60794 .29995 .61107 .29487 .61764 .28859 .61452 .29293 Mtetra
.61452 .29293 .61764 .28859 .6247 .29766 .62112 .28662 Mtetra
.594 .515 .734 r
.62112 .28662 .6247 .29766 .63157 .29935 .62788 .28509 Mtetra
.553 .452 .694 r
.62788 .28509 .63157 .29935 .63856 .30329 .6347 .28475 Mtetra
.472 .368 .655 r
.6347 .28475 .63856 .30329 .6452 .29696 .64167 .28782 Mtetra
0 .167 .685 r
.64167 .28782 .6452 .29696 .65229 .30187 .64891 .29636 Mtetra
.533 .631 .894 r
.64891 .29636 .65229 .30187 .65965 .31181 .65583 .29604 Mtetra
.08 .126 .61 r
.65583 .29604 .65965 .31181 .66671 .31356 .66337 .309 Mtetra
.921 .785 .692 r
.66337 .309 .66671 .31356 .67274 .29283 .66976 .29539 Mtetra
.711 .922 .583 r
.66976 .29539 .67274 .29283 .67951 .28847 .67637 .28698 Mtetra
.984 .844 .622 r
.67637 .28698 .67951 .28847 .6857 .27261 .68248 .26909 Mtetra
.84 .838 .843 r
.68248 .26909 .6857 .27261 .6929 .27625 .68916 .26273 Mtetra
.812 .614 .635 r
.68916 .26273 .6929 .27625 .69801 .24209 .6953 .24676 Mtetra
.369 0 .009 r
.6953 .24676 .69801 .24209 .70396 .22445 .7023 .24635 Mtetra
.491 .197 .394 r
.7023 .24635 .70396 .22445 .71134 .23104 .70928 .24527 Mtetra
.303 .007 .285 r
.70928 .24527 .71134 .23104 .71821 .22864 .71595 .23888 Mtetra
.203 0 .184 r
.71595 .23888 .71821 .22864 .72509 .22624 .72263 .2325 Mtetra
.411 0 .116 r
.72263 .2325 .72509 .22624 .7324 .22975 .7297 .23207 Mtetra
0 0 0 r
.7297 .23207 .7324 .22975 .73916 .22492 .73649 .22719 Mtetra
.812 .936 .568 r
.73649 .22719 .73916 .22492 .74482 .20488 .74289 .21686 Mtetra
.575 .214 .319 r
.74289 .21686 .74482 .20488 .75293 .21837 .7503 .22034 Mtetra
.648 .116 0 r
.7503 .22034 .75293 .21837 .76081 .22761 .7579 .22585 Mtetra
.957 .905 .727 r
.7579 .22585 .76081 .22761 .76793 .2264 .76425 .21464 Mtetra
.666 .549 .713 r
.76425 .21464 .76793 .2264 .7748 .22196 .77112 .2102 Mtetra
.633 .531 .72 r
.77112 .2102 .7748 .22196 .78152 .21557 .77811 .2071 Mtetra
.807 .673 .715 r
.77811 .2071 .78152 .21557 .78781 .20433 .78459 .1978 Mtetra
.651 .652 .838 r
.78459 .1978 .78781 .20433 .79469 .1999 .79165 .19533 Mtetra
.956 .791 .637 r
.79165 .19533 .79469 .1999 .80043 .18295 .79741 .17836 Mtetra
.494 .377 .648 r
.16806 .4184 .17055 .43592 .17663 .43014 .17332 .42012 Mtetra
.583 .51 .738 r
.17332 .42012 .17663 .43014 .1828 .42365 .1789 .41914 Mtetra
.658 .7 .877 r
.1789 .41914 .1828 .42365 .18906 .41611 .1846 .41715 Mtetra
.925 .937 .792 r
.1846 .41715 .18906 .41611 .19623 .39965 .19099 .40857 Mtetra
.608 .247 .331 r
.19099 .40857 .19623 .39965 .20136 .40323 .19613 .41211 Mtetra
.863 .907 .496 r
.19613 .41211 .20136 .40323 .20688 .4031 .20321 .39666 Mtetra
.817 .683 .715 r
.20321 .39666 .20688 .4031 .2126 .4011 .20968 .38705 Mtetra
.71 .546 .665 r
.20968 .38705 .2126 .4011 .21869 .39527 .21597 .37917 Mtetra
.603 .461 .662 r
.21597 .37917 .21869 .39527 .22506 .38654 .22173 .37675 Mtetra
.589 .517 .741 r
.22173 .37675 .22506 .38654 .23133 .37875 .22738 .37562 Mtetra
.581 .756 .961 r
.22738 .37562 .23133 .37875 .23717 .37565 .23305 .3745 Mtetra
.421 .821 .982 r
.23305 .3745 .23717 .37565 .24299 .37285 .23872 .37359 Mtetra
.6 .951 .889 r
.23872 .37359 .24299 .37285 .24876 .37082 .2446 .37041 Mtetra
.74 .953 .945 r
.2446 .37041 .24876 .37082 .25501 .36316 .25052 .36681 Mtetra
.083 0 0 r
.25052 .36681 .25501 .36316 .26065 .36278 .25632 .36475 Mtetra
.364 0 0 r
.25632 .36475 .26065 .36278 .2663 .36253 .26192 .36538 Mtetra
.832 .454 .338 r
.26192 .36538 .2663 .36253 .27167 .36605 .26659 .37772 Mtetra
.793 .834 .367 r
.26659 .37772 .27167 .36605 .27814 .35594 .27378 .35886 Mtetra
.453 0 0 r
.27378 .35886 .27814 .35594 .28368 .35768 .2794 .35989 Mtetra
.856 .483 .342 r
.2794 .35989 .28368 .35768 .28874 .36629 .28404 .37423 Mtetra
.589 .209 .29 r
.28404 .37423 .28874 .36629 .29386 .37484 .28958 .37718 Mtetra
.884 .536 .383 r
.28958 .37718 .29386 .37484 .29877 .38714 .2939 .39765 Mtetra
.636 .285 .359 r
.2939 .39765 .29877 .38714 .30433 .39089 .29939 .40283 Mtetra
.801 .829 .357 r
.29939 .40283 .30433 .39089 .3107 .383 .30664 .38261 Mtetra
.943 .864 .731 r
.30664 .38261 .3107 .383 .31718 .3732 .31328 .37084 Mtetra
.942 .753 .618 r
.31328 .37084 .31718 .3732 .3244 .35158 .32078 .3453 Mtetra
.648 .633 .822 r
.32078 .3453 .3244 .35158 .33036 .34948 .32675 .34319 Mtetra
.818 .694 .727 r
.32675 .34319 .33036 .34948 .33667 .34188 .33315 .33423 Mtetra
.638 .59 .784 r
.33315 .33423 .33667 .34188 .3425 .34224 .33913 .33211 Mtetra
.661 .556 .726 r
.33913 .33211 .3425 .34224 .34865 .33743 .3452 .32863 Mtetra
.159 .276 .736 r
.3452 .32863 .34865 .33743 .35491 .33065 .35081 .33367 Mtetra
.85 .473 .335 r
.35081 .33367 .35491 .33065 .36059 .33471 .35593 .3485 Mtetra
.498 .168 .338 r
.35593 .3485 .36059 .33471 .36575 .3501 .3619 .34859 Mtetra
.87 .43 .14 r
.3619 .34859 .36575 .3501 .37127 .35964 .36731 .36016 Mtetra
.561 0 0 r
.36731 .36016 .37127 .35964 .37703 .3653 .3732 .36332 Mtetra
.95 .778 .634 r
.3732 .36332 .37703 .3653 .38344 .35726 .38022 .34217 Mtetra
.811 .605 .623 r
.38022 .34217 .38344 .35726 .39066 .32979 .38714 .32211 Mtetra
.786 .659 .723 r
.38714 .32211 .39066 .32979 .39716 .31836 .39351 .31403 Mtetra
.835 .395 0 r
.39351 .31403 .39716 .31836 .40328 .31586 .39907 .32585 Mtetra
.633 .272 .34 r
.39907 .32585 .40328 .31586 .40882 .32956 .40495 .33095 Mtetra
.931 .968 .748 r
.40495 .33095 .40882 .32956 .41517 .32229 .41141 .32146 Mtetra
.94 .88 .748 r
.41141 .32146 .41517 .32229 .42164 .3112 .41788 .31083 Mtetra
.9 .944 .827 r
.41788 .31083 .42164 .3112 .42791 .30556 .42424 .30345 Mtetra
.435 0 0 r
.42424 .30345 .42791 .30556 .43412 .30238 .43024 .30744 Mtetra
.645 .216 .214 r
.43024 .30744 .43412 .30238 .44014 .3066 .43627 .31189 Mtetra
.705 .872 .47 r
.43627 .31189 .44014 .3066 .44639 .30313 .44273 .30156 Mtetra
.824 .912 .898 r
.44273 .30156 .44639 .30313 .45262 .30093 .44904 .29651 Mtetra
.763 .752 .843 r
.44904 .29651 .45262 .30093 .45891 .29613 .45534 .29204 Mtetra
.718 .248 0 r
.45534 .29204 .45891 .29613 .46516 .29406 .46137 .30143 Mtetra
.784 .413 .355 r
.46137 .30143 .46516 .29406 .47124 .30294 .46738 .31473 Mtetra
.676 .326 .373 r
.46738 .31473 .47124 .30294 .47736 .3127 .47356 .32289 Mtetra
0 0 0 r
.47356 .32289 .47736 .3127 .48377 .30522 .48012 .30781 Mtetra
.791 .971 .673 r
.48012 .30781 .48377 .30522 .49014 .30106 .48656 .29981 Mtetra
.592 .9 .986 r
.48656 .29981 .49014 .30106 .49653 .29495 .49293 .29758 Mtetra
.269 0 0 r
.49293 .29758 .49653 .29495 .50288 .29466 .49931 .29725 Mtetra
.986 .9 .598 r
.49931 .29725 .50288 .29466 .50932 .28225 .5058 .28 Mtetra
0 .253 .666 r
.5058 .28 .50932 .28225 .51569 .28 .51217 .28352 Mtetra
.694 .908 .559 r
.51217 .28352 .51569 .28 .52209 .27754 .5186 .27522 Mtetra
.889 .866 .81 r
.5186 .27522 .52209 .27754 .52849 .27713 .52502 .26747 Mtetra
.601 .536 .753 r
.52502 .26747 .52849 .27713 .5349 .26931 .53145 .26593 Mtetra
.823 .821 .847 r
.53145 .26593 .5349 .26931 .54131 .26274 .53787 .26021 Mtetra
.666 .846 .969 r
.53787 .26021 .54131 .26274 .5478 .26795 .54432 .25774 Mtetra
.463 .444 .752 r
.54432 .25774 .5478 .26795 .55421 .25988 .55081 .25949 Mtetra
.871 .975 .849 r
.55081 .25949 .55421 .25988 .56075 .26411 .55726 .25287 Mtetra
0 0 .245 r
.55726 .25287 .56075 .26411 .56734 .26846 .56404 .27365 Mtetra
0 0 0 r
.56404 .27365 .56734 .26846 .57397 .27263 .57055 .26804 Mtetra
.761 .322 0 r
.57055 .26804 .57397 .27263 .58055 .27178 .57737 .28101 Mtetra
.604 .222 .292 r
.57737 .28101 .58055 .27178 .5873 .27837 .58411 .28511 Mtetra
.561 .143 .206 r
.58411 .28511 .5873 .27837 .59404 .28195 .59086 .28773 Mtetra
.735 .318 .257 r
.59086 .28773 .59404 .28195 .60094 .29032 .59779 .29661 Mtetra
.517 .089 .166 r
.59779 .29661 .60094 .29032 .60794 .29995 .6046 .29826 Mtetra
.906 .912 .815 r
.6046 .29826 .60794 .29995 .61452 .29293 .61118 .29021 Mtetra
.432 .745 .993 r
.61118 .29021 .61452 .29293 .62112 .28662 .61797 .28987 Mtetra
.821 .93 .552 r
.61797 .28987 .62112 .28662 .62788 .28509 .62445 .2788 Mtetra
.399 .522 .866 r
.62445 .2788 .62788 .28509 .6347 .28475 .63135 .28044 Mtetra
.902 .792 .729 r
.63135 .28044 .6347 .28475 .64167 .28782 .63781 .26932 Mtetra
.249 .218 .626 r
.63781 .26932 .64167 .28782 .64891 .29636 .64508 .27975 Mtetra
.517 .411 .672 r
.64508 .27975 .64891 .29636 .65583 .29604 .65205 .28081 Mtetra
0 0 .498 r
.65205 .28081 .65583 .29604 .66337 .309 .6598 .29949 Mtetra
.837 .666 .671 r
.6598 .29949 .66337 .309 .66976 .29539 .66622 .28614 Mtetra
.83 .667 .68 r
.66622 .28614 .66976 .29539 .67637 .28698 .67265 .27383 Mtetra
.71 .56 .682 r
.67265 .27383 .67637 .28698 .68248 .26909 .6793 .2665 Mtetra
.774 .886 .926 r
.6793 .2665 .68248 .26909 .68916 .26273 .6861 .26214 Mtetra
.927 .961 .775 r
.6861 .26214 .68916 .26273 .6953 .24676 .69265 .25309 Mtetra
.141 0 .013 r
.69265 .25309 .6953 .24676 .7023 .24635 .69945 .2487 Mtetra
.621 .893 .578 r
.69945 .2487 .7023 .24635 .70928 .24527 .7061 .2415 Mtetra
.768 .817 .892 r
.7061 .2415 .70928 .24527 .71595 .23888 .71292 .2371 Mtetra
.829 .942 .898 r
.71292 .2371 .71595 .23888 .72263 .2325 .71966 .23153 Mtetra
.916 .961 .798 r
.71966 .23153 .72263 .2325 .7297 .23207 .72623 .22315 Mtetra
.464 .48 .79 r
.72623 .22315 .7297 .23207 .73649 .22719 .73346 .22468 Mtetra
.423 .76 .996 r
.73346 .22468 .73649 .22719 .74289 .21686 .74059 .22423 Mtetra
.204 0 .092 r
.74059 .22423 .74289 .21686 .7503 .22034 .74745 .2198 Mtetra
.4 0 0 r
.74745 .2198 .7503 .22034 .7579 .22585 .75492 .22333 Mtetra
.923 .893 .781 r
.75492 .22333 .7579 .22585 .76425 .21464 .76145 .21408 Mtetra
.835 .995 .847 r
.76145 .21408 .76425 .21464 .77112 .2102 .76818 .20764 Mtetra
.692 .878 .968 r
.76818 .20764 .77112 .2102 .77811 .2071 .77519 .20451 Mtetra
.885 .903 .836 r
.77519 .20451 .77811 .2071 .78459 .1978 .78185 .19718 Mtetra
.487 .895 .923 r
.78185 .19718 .78459 .1978 .79165 .19533 .78894 .19468 Mtetra
.999 .835 .525 r
.78894 .19468 .79165 .19533 .79741 .17836 .79422 .17193 Mtetra
0 0 .4 r
.16659 .39194 .16806 .4184 .17332 .42012 .16981 .41199 Mtetra
.674 .593 .757 r
.16981 .41199 .17332 .42012 .1789 .41914 .17562 .40873 Mtetra
.747 .598 .691 r
.17562 .40873 .1789 .41914 .1846 .41715 .18197 .40065 Mtetra
.55 .423 .659 r
.18197 .40065 .1846 .41715 .19099 .40857 .18748 .40035 Mtetra
.859 .67 .645 r
.18748 .40035 .19099 .40857 .19613 .41211 .19504 .38037 Mtetra
.576 .393 .596 r
.19504 .38037 .19613 .41211 .20321 .39666 .20083 .37746 Mtetra
.208 .161 .582 r
.20083 .37746 .20321 .39666 .20968 .38705 .20541 .38666 Mtetra
.711 .189 0 r
.20541 .38666 .20968 .38705 .21597 .37917 .21047 .39153 Mtetra
.408 .072 .28 r
.21047 .39153 .21597 .37917 .22173 .37675 .21623 .3895 Mtetra
0 0 .049 r
.21623 .3895 .22173 .37675 .22738 .37562 .22269 .38022 Mtetra
.535 .091 .142 r
.22269 .38022 .22738 .37562 .23305 .3745 .22812 .38193 Mtetra
.686 .853 .441 r
.22812 .38193 .23305 .3745 .23872 .37359 .23471 .37111 Mtetra
.746 .832 .917 r
.23471 .37111 .23872 .37359 .2446 .37041 .24061 .36776 Mtetra
.648 .807 .96 r
.24061 .36776 .2446 .37041 .25052 .36681 .2464 .36583 Mtetra
.742 .925 .952 r
.2464 .36583 .25052 .36681 .25632 .36475 .25233 .3624 Mtetra
.21 .637 .952 r
.25233 .3624 .25632 .36475 .26192 .36538 .25792 .36316 Mtetra
.859 .833 .82 r
.25792 .36316 .26192 .36538 .26659 .37772 .26415 .35641 Mtetra
.527 .383 .628 r
.26415 .35641 .26659 .37772 .27378 .35886 .26978 .35703 Mtetra
.328 .738 .979 r
.26978 .35703 .27378 .35886 .2794 .35989 .27549 .35694 Mtetra
.09 .521 .906 r
.27549 .35694 .2794 .35989 .28404 .37423 .28108 .35862 Mtetra
.334 .282 .65 r
.28108 .35862 .28404 .37423 .28958 .37718 .28642 .36414 Mtetra
0 .062 .584 r
.28642 .36414 .28958 .37718 .2939 .39765 .2915 .37367 Mtetra
.544 .387 .619 r
.2915 .37367 .2939 .39765 .29939 .40283 .29733 .37346 Mtetra
.73 .514 .599 r
.29733 .37346 .29939 .40283 .30664 .38261 .30458 .35297 Mtetra
.665 .464 .603 r
.30458 .35297 .30664 .38261 .31328 .37084 .31116 .34168 Mtetra
.655 .457 .604 r
.31116 .34168 .31328 .37084 .32078 .3453 .31763 .33174 Mtetra
.569 .46 .69 r
.31763 .33174 .32078 .3453 .32675 .34319 .32351 .3309 Mtetra
.649 .523 .697 r
.32351 .3309 .32675 .34319 .33315 .33423 .32958 .32722 Mtetra
.7 .635 .781 r
.32958 .32722 .33315 .33423 .33913 .33211 .33566 .32351 Mtetra
.527 .509 .779 r
.33566 .32351 .33913 .33211 .3452 .32863 .34151 .32371 Mtetra
.921 .531 .15 r
.34151 .32371 .3452 .32863 .35081 .33367 .34644 .34074 Mtetra
.851 .514 .416 r
.34644 .34074 .35081 .33367 .35593 .3485 .35113 .36375 Mtetra
0 0 0 r
.35113 .36375 .35593 .3485 .3619 .34859 .35806 .34622 Mtetra
.88 .836 .799 r
.35806 .34622 .3619 .34859 .36731 .36016 .36446 .33837 Mtetra
.69 .499 .624 r
.36446 .33837 .36731 .36016 .3732 .36332 .37098 .3279 Mtetra
.642 .438 .591 r
.37098 .3279 .3732 .36332 .38022 .34217 .37748 .31728 Mtetra
.581 .412 .617 r
.37748 .31728 .38022 .34217 .38714 .32211 .38361 .31468 Mtetra
.587 .574 .805 r
.38361 .31468 .38714 .32211 .39351 .31403 .38968 .31368 Mtetra
.829 .368 .118 r
.38968 .31368 .39351 .31403 .39907 .32585 .39533 .32319 Mtetra
.618 .813 .975 r
.39533 .32319 .39907 .32585 .40495 .33095 .40149 .32142 Mtetra
.72 .6 .722 r
.40149 .32142 .40495 .33095 .41141 .32146 .40781 .31565 Mtetra
.878 .721 .683 r
.40781 .31565 .41141 .32146 .41788 .31083 .41441 .30176 Mtetra
.647 .569 .753 r
.41441 .30176 .41788 .31083 .42424 .30345 .42062 .29901 Mtetra
.571 .105 0 r
.42062 .29901 .42424 .30345 .43024 .30744 .42651 .30648 Mtetra
.909 .911 .81 r
.42651 .30648 .43024 .30744 .43627 .31189 .43292 .29847 Mtetra
.605 .487 .692 r
.43292 .29847 .43627 .31189 .44273 .30156 .43915 .29626 Mtetra
.853 .735 .732 r
.43915 .29626 .44273 .30156 .44904 .29651 .44559 .28645 Mtetra
.681 .572 .726 r
.44559 .28645 .44904 .29651 .45534 .29204 .45189 .28212 Mtetra
0 .124 .65 r
.45189 .28212 .45534 .29204 .46137 .30143 .45793 .29034 Mtetra
.897 .573 .081 r
.45793 .29034 .46137 .30143 .46738 .31473 .4636 .32004 Mtetra
.947 .906 .525 r
.4636 .32004 .46738 .31473 .47356 .32289 .47024 .30224 Mtetra
.759 .549 .613 r
.47024 .30224 .47356 .32289 .48012 .30781 .47684 .28456 Mtetra
.488 .352 .622 r
.47684 .28456 .48012 .30781 .48656 .29981 .48311 .28729 Mtetra
.674 .54 .693 r
.48311 .28729 .48656 .29981 .49293 .29758 .48951 .28227 Mtetra
.638 .494 .67 r
.48951 .28227 .49293 .29758 .49931 .29725 .4959 .27809 Mtetra
.493 .373 .646 r
.4959 .27809 .49931 .29725 .5058 .28 .50225 .28021 Mtetra
.679 .139 0 r
.50225 .28021 .5058 .28 .51217 .28352 .50862 .28572 Mtetra
.975 .923 .628 r
.50862 .28572 .51217 .28352 .5186 .27522 .5151 .27102 Mtetra
.755 .769 .865 r
.5151 .27102 .5186 .27522 .52502 .26747 .52153 .26688 Mtetra
.673 .957 .947 r
.52153 .26688 .52502 .26747 .53145 .26593 .52797 .26345 Mtetra
.885 .861 .812 r
.52797 .26345 .53145 .26593 .53787 .26021 .53441 .2558 Mtetra
.811 .772 .816 r
.53441 .2558 .53787 .26021 .54432 .25774 .54085 .24976 Mtetra
.477 .504 .806 r
.54085 .24976 .54432 .25774 .55081 .25949 .54734 .25076 Mtetra
.225 .329 .761 r
.54734 .25076 .55081 .25949 .55726 .25287 .55389 .25562 Mtetra
.79 .344 .188 r
.55389 .25562 .55726 .25287 .56404 .27365 .56055 .26552 Mtetra
.6 .57 .792 r
.56055 .26552 .56404 .27365 .57055 .26804 .56712 .26412 Mtetra
0 .116 .632 r
.56712 .26412 .57055 .26804 .57737 .28101 .57383 .27001 Mtetra
.666 .555 .72 r
.57383 .27001 .57737 .28101 .58411 .28511 .58041 .26592 Mtetra
.025 .055 .554 r
.58041 .26592 .58411 .28511 .59086 .28773 .5874 .28212 Mtetra
0 .24 .756 r
.5874 .28212 .59086 .28773 .59779 .29661 .59426 .28774 Mtetra
.693 .606 .754 r
.59426 .28774 .59779 .29661 .6046 .29826 .60092 .28342 Mtetra
.601 .477 .684 r
.60092 .28342 .6046 .29826 .61118 .29021 .60764 .28109 Mtetra
.63 .568 .766 r
.60764 .28109 .61118 .29021 .61797 .28987 .61438 .27875 Mtetra
.744 .599 .695 r
.61438 .27875 .61797 .28987 .62445 .2788 .62096 .27069 Mtetra
.75 .649 .75 r
.62096 .27069 .62445 .2788 .63135 .28044 .62759 .26448 Mtetra
.708 .536 .654 r
.62759 .26448 .63135 .28044 .63781 .26932 .63413 .25569 Mtetra
0 .005 .556 r
.63413 .25569 .63781 .26932 .64508 .27975 .64154 .27043 Mtetra
.221 .318 .751 r
.64154 .27043 .64508 .27975 .65205 .28081 .64868 .27598 Mtetra
.822 .773 .806 r
.64868 .27598 .65205 .28081 .6598 .29949 .65536 .26924 Mtetra
.568 .393 .604 r
.65536 .26924 .6598 .29949 .66622 .28614 .66222 .26687 Mtetra
.65 .482 .643 r
.66222 .26687 .66622 .28614 .67265 .27383 .66892 .2606 Mtetra
.691 .548 .686 r
.66892 .2606 .67265 .27383 .6793 .2665 .67562 .25432 Mtetra
.408 .386 .723 r
.67562 .25432 .6793 .2665 .6861 .26214 .68283 .2579 Mtetra
.509 .689 .949 r
.68283 .2579 .6861 .26214 .69265 .25309 .68986 .2575 Mtetra
.488 .008 .042 r
.68986 .2575 .69265 .25309 .69945 .2487 .69704 .25911 Mtetra
.434 .072 .251 r
.69704 .25911 .69945 .2487 .7061 .2415 .70409 .25795 Mtetra
.269 0 .297 r
.70409 .25795 .7061 .2415 .71292 .2371 .71072 .24949 Mtetra
.45 .107 .292 r
.71072 .24949 .71292 .2371 .71966 .23153 .71779 .2483 Mtetra
.443 .133 .344 r
.71779 .2483 .71966 .23153 .72623 .22315 .72481 .24587 Mtetra
.179 0 .324 r
.72481 .24587 .72623 .22315 .73346 .22468 .73095 .23015 Mtetra
.387 0 .06 r
.73095 .23015 .73346 .22468 .74059 .22423 .73812 .22971 Mtetra
.679 .23 .179 r
.73812 .22971 .74059 .22423 .74745 .2198 .74582 .23639 Mtetra
0 0 .21 r
.74582 .23639 .74745 .2198 .75492 .22333 .75176 .21855 Mtetra
.905 .795 .728 r
.75176 .21855 .75492 .22333 .76145 .21408 .75816 .20743 Mtetra
.738 .689 .804 r
.75816 .20743 .76145 .21408 .76818 .20764 .76503 .2026 Mtetra
.369 .567 .913 r
.76503 .2026 .76818 .20764 .77519 .20451 .77243 .20408 Mtetra
.947 .957 .714 r
.77243 .20408 .77519 .20451 .78185 .19718 .77884 .19345 Mtetra
.905 .843 .773 r
.77884 .19345 .78185 .19718 .78894 .19468 .78535 .18417 Mtetra
.596 .528 .748 r
.78535 .18417 .78894 .19468 .79422 .17193 .79253 .18256 Mtetra
.361 .048 .293 r
.16044 .40736 .16659 .39194 .16981 .41199 .16632 .40354 Mtetra
.687 .593 .746 r
.16632 .40354 .16981 .41199 .17562 .40873 .1722 .39974 Mtetra
0 0 .57 r
.1722 .39974 .17562 .40873 .18197 .40065 .17686 .40728 Mtetra
.897 .946 .589 r
.17686 .40728 .18197 .40065 .18748 .40035 .18375 .39423 Mtetra
.887 .697 .641 r
.18375 .39423 .18748 .40035 .19504 .38037 .19157 .37197 Mtetra
.824 .467 0 r
.19157 .37197 .19504 .38037 .20083 .37746 .19569 .38535 Mtetra
.686 .325 .355 r
.19569 .38535 .20083 .37746 .20541 .38666 .20056 .39182 Mtetra
.537 .106 .17 r
.20056 .39182 .20541 .38666 .21047 .39153 .20595 .39351 Mtetra
.795 .999 .812 r
.20595 .39351 .21047 .39153 .21623 .3895 .2121 .38765 Mtetra
.917 .795 .711 r
.2121 .38765 .21623 .3895 .22269 .38022 .21894 .37458 Mtetra
.532 .603 .87 r
.21894 .37458 .22269 .38022 .22812 .38193 .22454 .37439 Mtetra
.788 .656 .717 r
.22454 .37439 .22812 .38193 .23471 .37111 .23092 .36602 Mtetra
.656 .678 .859 r
.23092 .36602 .23471 .37111 .24061 .36776 .23671 .36395 Mtetra
.791 .764 .828 r
.23671 .36395 .24061 .36776 .2464 .36583 .24279 .35888 Mtetra
.195 .361 .803 r
.24279 .35888 .2464 .36583 .25233 .3624 .24813 .36228 Mtetra
.945 .853 .72 r
.24813 .36228 .25233 .3624 .25792 .36316 .25486 .34973 Mtetra
.56 .455 .691 r
.25486 .34973 .25792 .36316 .26415 .35641 .26057 .34915 Mtetra
.407 .476 .819 r
.26057 .34915 .26415 .35641 .26978 .35703 .26611 .35079 Mtetra
.772 .362 0 r
.26611 .35079 .26978 .35703 .27549 .35694 .27096 .36151 Mtetra
.755 .362 .309 r
.27096 .36151 .27549 .35694 .28108 .35862 .27606 .36979 Mtetra
.596 .248 .349 r
.27606 .36979 .28108 .35862 .28642 .36414 .28156 .37342 Mtetra
.543 .173 .29 r
.28156 .37342 .28642 .36414 .2915 .37367 .28724 .37516 Mtetra
.807 1 .826 r
.28724 .37516 .2915 .37367 .29733 .37346 .29349 .36923 Mtetra
.903 .741 .671 r
.29349 .36923 .29733 .37346 .30458 .35297 .3005 .3527 Mtetra
.939 .88 .749 r
.3005 .3527 .30458 .35297 .31116 .34168 .30707 .34201 Mtetra
.917 .942 .804 r
.30707 .34201 .31116 .34168 .31763 .33174 .31344 .33389 Mtetra
0 0 0 r
.31344 .33389 .31763 .33174 .32351 .3309 .31942 .33177 Mtetra
.127 0 0 r
.31942 .33177 .32351 .3309 .32958 .32722 .32527 .33172 Mtetra
0 0 0 r
.32527 .33172 .32958 .32722 .33566 .32351 .3315 .32598 Mtetra
.834 .44 .3 r
.3315 .32598 .33566 .32351 .34151 .32371 .33666 .33817 Mtetra
.426 .104 .314 r
.33666 .33817 .34151 .32371 .34644 .34074 .34272 .33603 Mtetra
.831 .743 .766 r
.34272 .33603 .34644 .34074 .35113 .36375 .34909 .32829 Mtetra
.581 .392 .589 r
.34909 .32829 .35113 .36375 .35806 .34622 .35527 .32429 Mtetra
.595 .431 .629 r
.35527 .32429 .35806 .34622 .36446 .33837 .3614 .32117 Mtetra
.69 .516 .647 r
.3614 .32117 .36446 .33837 .37098 .3279 .36779 .31302 Mtetra
.39 .33 .67 r
.36779 .31302 .37098 .3279 .37748 .31728 .37358 .31725 Mtetra
.395 0 0 r
.37358 .31725 .37748 .31728 .38361 .31468 .3795 .31932 Mtetra
0 0 0 r
.3795 .31932 .38361 .31468 .38968 .31368 .38581 .31337 Mtetra
.744 .97 .93 r
.38581 .31337 .38968 .31368 .39533 .32319 .39205 .30932 Mtetra
.708 .548 .669 r
.39205 .30932 .39533 .32319 .40149 .32142 .39843 .30169 Mtetra
.614 .453 .64 r
.39843 .30169 .40149 .32142 .40781 .31565 .40466 .2978 Mtetra
.543 .413 .654 r
.40466 .2978 .40781 .31565 .41441 .30176 .41076 .29773 Mtetra
.663 .744 .91 r
.41076 .29773 .41441 .30176 .42062 .29901 .41695 .29552 Mtetra
.675 .779 .928 r
.41695 .29552 .42062 .29901 .42651 .30648 .42317 .29313 Mtetra
.643 .511 .688 r
.42317 .29313 .42651 .30648 .43292 .29847 .42944 .28933 Mtetra
.267 .342 .755 r
.42944 .28933 .43292 .29847 .43915 .29626 .43549 .29357 Mtetra
.903 .824 .759 r
.43549 .29357 .43915 .29626 .44559 .28645 .44195 .28385 Mtetra
.782 .853 .904 r
.44195 .28385 .44559 .28645 .45189 .28212 .44826 .2796 Mtetra
.724 .21 0 r
.44826 .2796 .45189 .28212 .45793 .29034 .4543 .28733 Mtetra
.926 .538 .204 r
.4543 .28733 .45793 .29034 .4636 .32004 .46013 .30811 Mtetra
.726 .577 .687 r
.46013 .30811 .4636 .32004 .47024 .30224 .4666 .3005 Mtetra
.961 .809 .647 r
.4666 .3005 .47024 .30224 .47684 .28456 .47323 .28246 Mtetra
.566 .01 0 r
.47323 .28246 .47684 .28456 .48311 .28729 .47948 .28782 Mtetra
.772 .996 .857 r
.47948 .28782 .48311 .28729 .48951 .28227 .4859 .2825 Mtetra
.325 0 0 r
.4859 .2825 .48951 .28227 .4959 .27809 .49225 .28412 Mtetra
.409 0 .108 r
.49225 .28412 .4959 .27809 .50225 .28021 .49865 .2838 Mtetra
.683 .222 .152 r
.49865 .2838 .50225 .28021 .50862 .28572 .50504 .28935 Mtetra
.966 .916 .57 r
.50504 .28935 .50862 .28572 .5151 .27102 .51156 .27286 Mtetra
.913 .976 .698 r
.51156 .27286 .5151 .27102 .52153 .26688 .51803 .26286 Mtetra
.791 .786 .848 r
.51803 .26286 .52153 .26688 .52797 .26345 .52448 .25777 Mtetra
.596 .646 .87 r
.52448 .25777 .52797 .26345 .53441 .2558 .53095 .25656 Mtetra
.947 .957 .725 r
.53095 .25656 .53441 .2558 .54085 .24976 .53739 .24613 Mtetra
.506 .714 .965 r
.53739 .24613 .54085 .24976 .54734 .25076 .54388 .24564 Mtetra
.079 .375 .839 r
.54388 .24564 .54734 .25076 .55389 .25562 .55042 .24941 Mtetra
.66 .262 0 r
.55042 .24941 .55389 .25562 .56055 .26552 .5571 .26216 Mtetra
.769 .824 .895 r
.5571 .26216 .56055 .26552 .56712 .26412 .56365 .25792 Mtetra
.054 .306 .793 r
.56365 .25792 .56712 .26412 .57383 .27001 .57034 .2628 Mtetra
0 0 .508 r
.57034 .2628 .57383 .27001 .58041 .26592 .57717 .27341 Mtetra
.182 0 .066 r
.57717 .27341 .58041 .26592 .5874 .28212 .58379 .2691 Mtetra
.321 .315 .696 r
.58379 .2691 .5874 .28212 .59426 .28774 .59063 .27468 Mtetra
.487 .422 .71 r
.59063 .27468 .59426 .28774 .60092 .28342 .59743 .27632 Mtetra
.778 .684 .76 r
.59743 .27632 .60092 .28342 .60764 .28109 .60404 .26959 Mtetra
.616 .521 .724 r
.60404 .26959 .60764 .28109 .61438 .27875 .61078 .26724 Mtetra
.749 .597 .688 r
.61078 .26724 .61438 .27875 .62096 .27069 .61734 .25862 Mtetra
.7 .563 .697 r
.61734 .25862 .62096 .27069 .62759 .26448 .62397 .25247 Mtetra
.613 .513 .717 r
.62397 .25247 .62759 .26448 .63413 .25569 .63073 .25009 Mtetra
0 0 .476 r
.63073 .25009 .63413 .25569 .64154 .27043 .63797 .26029 Mtetra
.557 .509 .757 r
.63797 .26029 .64154 .27043 .64868 .27598 .64487 .25984 Mtetra
.32 .284 .661 r
.64487 .25984 .64868 .27598 .65536 .26924 .65211 .26703 Mtetra
.95 .868 .722 r
.65211 .26703 .65536 .26924 .66222 .26687 .65857 .25512 Mtetra
.664 .548 .713 r
.65857 .25512 .66222 .26687 .66892 .2606 .66536 .25079 Mtetra
.626 .555 .755 r
.66536 .25079 .66892 .2606 .67562 .25432 .67225 .24839 Mtetra
.222 .432 .855 r
.67225 .24839 .67562 .25432 .68283 .2579 .67945 .2518 Mtetra
0 .025 .593 r
.67945 .2518 .68283 .2579 .68986 .2575 .687 .2611 Mtetra
.706 .873 .472 r
.687 .2611 .68986 .2575 .69704 .25911 .69354 .25064 Mtetra
.451 .486 .804 r
.69354 .25064 .69704 .25911 .70409 .25795 .70075 .25224 Mtetra
.381 .543 .891 r
.70075 .25224 .70409 .25795 .71072 .24949 .70799 .25385 Mtetra
.757 .852 .409 r
.70799 .25385 .71072 .24949 .71779 .2483 .71435 .24051 Mtetra
.64 .61 .803 r
.71435 .24051 .71779 .2483 .72481 .24587 .72138 .23806 Mtetra
.875 .709 .673 r
.72138 .23806 .72481 .24587 .73095 .23015 .72765 .22412 Mtetra
.709 .698 .837 r
.72765 .22412 .73095 .23015 .73812 .22971 .73459 .22037 Mtetra
.787 .649 .71 r
.73459 .22037 .73812 .22971 .74582 .23639 .74118 .21141 Mtetra
.704 .497 .605 r
.74118 .21141 .74582 .23639 .75176 .21855 .74739 .19759 Mtetra
.543 .404 .642 r
.74739 .19759 .75176 .21855 .75816 .20743 .7546 .19745 Mtetra
.683 .586 .74 r
.7546 .19745 .75816 .20743 .76503 .2026 .76151 .19297 Mtetra
.735 .619 .729 r
.76151 .19297 .76503 .2026 .77243 .20408 .76826 .18652 Mtetra
.676 .507 .649 r
.76826 .18652 .77243 .20408 .77884 .19345 .77493 .1791 Mtetra
.73 .561 .663 r
.77493 .1791 .77884 .19345 .78535 .18417 .78143 .16979 Mtetra
.585 .473 .693 r
.78143 .16979 .78535 .18417 .79253 .18256 .78859 .16807 Mtetra
.632 .482 .661 r
.15781 .39142 .16044 .40736 .16632 .40354 .16367 .38755 Mtetra
.351 .286 .643 r
.16367 .38755 .16632 .40354 .1722 .39974 .16857 .39248 Mtetra
.626 .59 .794 r
.16857 .39248 .1722 .39974 .17686 .40728 .17423 .39073 Mtetra
.316 .257 .632 r
.17423 .39073 .17686 .40728 .18375 .39423 .17909 .39657 Mtetra
.967 .79 .612 r
.17909 .39657 .18375 .39423 .19157 .37197 .18764 .36796 Mtetra
.934 .564 .269 r
.18764 .36796 .19157 .37197 .19569 .38535 .19141 .38443 Mtetra
.467 0 0 r
.19141 .38443 .19569 .38535 .20056 .39182 .19667 .3871 Mtetra
.722 .712 .84 r
.19667 .3871 .20056 .39182 .20595 .39351 .20258 .38368 Mtetra
.711 .586 .714 r
.20258 .38368 .20595 .39351 .2121 .38765 .20869 .37817 Mtetra
.819 .644 .665 r
.20869 .37817 .2121 .38765 .21894 .37458 .21566 .36392 Mtetra
.715 .578 .7 r
.21566 .36392 .21894 .37458 .22454 .37439 .22183 .35769 Mtetra
.619 .469 .657 r
.22183 .35769 .22454 .37439 .23092 .36602 .22773 .35428 Mtetra
.637 .52 .704 r
.22773 .35428 .23092 .36602 .23671 .36395 .23361 .35127 Mtetra
.639 .512 .692 r
.23361 .35127 .23671 .36395 .24279 .35888 .23953 .34791 Mtetra
.512 .453 .727 r
.23953 .34791 .24279 .35888 .24813 .36228 .2451 .34856 Mtetra
.342 .305 .672 r
.2451 .34856 .24813 .36228 .25486 .34973 .25035 .35312 Mtetra
.813 .432 .332 r
.25035 .35312 .25486 .34973 .26057 .34915 .25507 .3644 Mtetra
.659 .337 .418 r
.25507 .3644 .26057 .34915 .26611 .35079 .26013 .3724 Mtetra
.553 .254 .415 r
.26013 .3724 .26611 .35079 .27096 .36151 .26568 .37493 Mtetra
.619 .286 .385 r
.26568 .37493 .27096 .36151 .27606 .36979 .27105 .38 Mtetra
.602 .244 .336 r
.27105 .38 .27606 .36979 .28156 .37342 .27657 .38373 Mtetra
.158 0 .112 r
.27657 .38373 .28156 .37342 .28724 .37516 .28281 .37836 Mtetra
.984 .894 .647 r
.28281 .37836 .28724 .37516 .29349 .36923 .2899 .36153 Mtetra
.805 .664 .707 r
.2899 .36153 .29349 .36923 .3005 .3527 .29644 .35182 Mtetra
.928 .862 .754 r
.29644 .35182 .3005 .3527 .30707 .34201 .30301 .34141 Mtetra
.89 .919 .836 r
.30301 .34141 .30707 .34201 .31344 .33389 .30933 .33439 Mtetra
.412 .862 .854 r
.30933 .33439 .31344 .33389 .31942 .33177 .31532 .33225 Mtetra
.506 0 0 r
.31532 .33225 .31942 .33177 .32527 .33172 .32102 .33478 Mtetra
.94 .963 .687 r
.32102 .33478 .32527 .33172 .3315 .32598 .32762 .32353 Mtetra
.621 .074 0 r
.32762 .32353 .3315 .32598 .33666 .33817 .33319 .32892 Mtetra
.741 .613 .716 r
.33319 .32892 .33666 .33817 .34272 .33603 .33951 .3222 Mtetra
.685 .533 .674 r
.33951 .3222 .34272 .33603 .34909 .32829 .3458 .31605 Mtetra
.575 .479 .708 r
.3458 .31605 .34909 .32829 .35527 .32429 .3518 .31504 Mtetra
.769 .627 .703 r
.3518 .31504 .35527 .32429 .3614 .32117 .35821 .30664 Mtetra
.533 .429 .682 r
.35821 .30664 .3614 .32117 .36779 .31302 .36416 .30691 Mtetra
.177 .389 .832 r
.36416 .30691 .36779 .31302 .37358 .31725 .36999 .31019 Mtetra
.546 .565 .825 r
.36999 .31019 .37358 .31725 .3795 .31932 .37603 .30991 Mtetra
.807 .643 .68 r
.37603 .30991 .3795 .31932 .38581 .31337 .3826 .29828 Mtetra
.598 .468 .674 r
.3826 .29828 .38581 .31337 .39205 .30932 .38874 .29608 Mtetra
.619 .497 .692 r
.38874 .29608 .39205 .30932 .39843 .30169 .39492 .29333 Mtetra
.633 .576 .772 r
.39492 .29333 .39843 .30169 .40466 .2978 .40108 .29112 Mtetra
0 .227 .743 r
.40108 .29112 .40466 .2978 .41076 .29773 .40698 .29643 Mtetra
.859 .916 .868 r
.40698 .29643 .41076 .29773 .41695 .29552 .41332 .29041 Mtetra
.092 .386 .846 r
.41332 .29041 .41695 .29552 .42317 .29313 .41935 .29374 Mtetra
.558 0 0 r
.41935 .29374 .42317 .29313 .42944 .28933 .42542 .297 Mtetra
0 0 0 r
.42542 .297 .42944 .28933 .43549 .29357 .4318 .29075 Mtetra
.601 .802 .977 r
.4318 .29075 .43549 .29357 .44195 .28385 .43806 .28914 Mtetra
.799 .905 .503 r
.43806 .28914 .44195 .28385 .44826 .2796 .4446 .27722 Mtetra
.806 .322 0 r
.4446 .27722 .44826 .2796 .4543 .28733 .4506 .2869 Mtetra
.919 .543 .286 r
.4506 .2869 .4543 .28733 .46013 .30811 .45637 .30965 Mtetra
.499 0 0 r
.45637 .30965 .46013 .30811 .4666 .3005 .46267 .312 Mtetra
0 0 0 r
.46267 .312 .4666 .3005 .47323 .28246 .46938 .29339 Mtetra
.533 .173 .302 r
.46938 .29339 .47323 .28246 .47948 .28782 .47571 .29504 Mtetra
.209 0 .057 r
.47571 .29504 .47948 .28782 .4859 .2825 .48214 .29153 Mtetra
.452 .073 .228 r
.48214 .29153 .4859 .2825 .49225 .28412 .48855 .29122 Mtetra
.085 0 0 r
.48855 .29122 .49225 .28412 .49865 .2838 .49502 .28633 Mtetra
.598 .089 .013 r
.49502 .28633 .49865 .2838 .50504 .28935 .50144 .28989 Mtetra
.98 .892 .662 r
.50144 .28989 .50504 .28935 .51156 .27286 .50799 .27503 Mtetra
.901 .975 .681 r
.50799 .27503 .51156 .27286 .51803 .26286 .51449 .26494 Mtetra
.855 .983 .697 r
.51449 .26494 .51803 .26286 .52448 .25777 .52098 .25619 Mtetra
.704 .917 .967 r
.52098 .25619 .52448 .25777 .53095 .25656 .52745 .25294 Mtetra
.613 .761 .95 r
.52745 .25294 .53095 .25656 .53739 .24613 .53394 .25129 Mtetra
0 0 0 r
.53394 .25129 .53739 .24613 .54388 .24564 .54042 .24262 Mtetra
.773 .842 .904 r
.54042 .24262 .54388 .24564 .55042 .24941 .54691 .23841 Mtetra
0 .058 .603 r
.54691 .23841 .55042 .24941 .5571 .26216 .55355 .24909 Mtetra
0 .019 .566 r
.55355 .24909 .5571 .26216 .56365 .25792 .56029 .26197 Mtetra
0 0 0 r
.56029 .26197 .56365 .25792 .57034 .2628 .56686 .25696 Mtetra
0 .043 .605 r
.56686 .25696 .57034 .2628 .57717 .27341 .57365 .26487 Mtetra
.168 .301 .757 r
.57365 .26487 .57717 .27341 .58379 .2691 .58045 .27033 Mtetra
.383 0 0 r
.58045 .27033 .58379 .2691 .59063 .27468 .58722 .27193 Mtetra
.648 .836 .973 r
.58722 .27193 .59063 .27468 .59743 .27632 .59393 .26958 Mtetra
.875 .721 .688 r
.59393 .26958 .59743 .27632 .60404 .26959 .6004 .25648 Mtetra
.608 .497 .702 r
.6004 .25648 .60404 .26959 .61078 .26724 .60713 .25411 Mtetra
.818 .62 .635 r
.60713 .25411 .61078 .26724 .61734 .25862 .61346 .23764 Mtetra
.724 .523 .618 r
.61346 .23764 .61734 .25862 .62397 .25247 .61985 .22418 Mtetra
.492 .343 .606 r
.61985 .22418 .62397 .25247 .63073 .25009 .62675 .22722 Mtetra
.429 .316 .624 r
.62675 .22722 .63073 .25009 .63797 .26029 .63378 .23278 Mtetra
.423 .297 .604 r
.63378 .23278 .63797 .26029 .64487 .25984 .64091 .23976 Mtetra
.441 .338 .642 r
.64091 .23976 .64487 .25984 .65211 .26703 .64801 .24422 Mtetra
.698 .5 .616 r
.64801 .24422 .65211 .26703 .65857 .25512 .65446 .23236 Mtetra
.579 .42 .63 r
.65446 .23236 .65857 .25512 .66536 .25079 .6613 .22994 Mtetra
.381 .294 .632 r
.6613 .22994 .66536 .25079 .67225 .24839 .66861 .23703 Mtetra
.402 .394 .736 r
.66861 .23703 .67225 .24839 .67945 .2518 .6758 .24041 Mtetra
0 0 .43 r
.6758 .24041 .67945 .2518 .687 .2611 .6838 .25867 Mtetra
.858 .903 .865 r
.6838 .25867 .687 .2611 .69354 .25064 .69058 .2522 Mtetra
.931 .95 .619 r
.69058 .2522 .69354 .25064 .70075 .25224 .69702 .23973 Mtetra
.323 .328 .71 r
.69702 .23973 .70075 .25224 .70799 .25385 .70449 .24532 Mtetra
.768 .655 .738 r
.70449 .24532 .70799 .25385 .71435 .24051 .71123 .23805 Mtetra
.965 .858 .685 r
.71123 .23805 .71435 .24051 .72138 .23806 .71755 .2243 Mtetra
.642 .514 .692 r
.71755 .2243 .72138 .23806 .72765 .22412 .72448 .22024 Mtetra
.881 .832 .794 r
.72448 .22024 .72765 .22412 .73459 .22037 .73113 .21192 Mtetra
.884 .701 .65 r
.73113 .21192 .73459 .22037 .74118 .21141 .73722 .19583 Mtetra
.732 .554 .65 r
.73722 .19583 .74118 .21141 .74739 .19759 .74368 .18549 Mtetra
.387 .375 .724 r
.74368 .18549 .74739 .19759 .7546 .19745 .75121 .18958 Mtetra
.755 .664 .761 r
.75121 .18958 .7546 .19745 .76151 .19297 .75799 .18341 Mtetra
.848 .673 .664 r
.75799 .18341 .76151 .19297 .76826 .18652 .76416 .16968 Mtetra
.641 .489 .661 r
.76416 .16968 .76826 .18652 .77493 .1791 .77102 .16468 Mtetra
.564 .459 .694 r
.77102 .16468 .77493 .1791 .78143 .16979 .77824 .16381 Mtetra
.656 .679 .86 r
.77824 .16381 .78143 .16979 .78859 .16807 .78533 .16128 Mtetra
.337 .297 .665 r
.15495 .37751 .15781 .39142 .16367 .38755 .15986 .38198 Mtetra
.848 .425 0 r
.15986 .38198 .16367 .38755 .16857 .39248 .16414 .39229 Mtetra
.528 .906 .952 r
.16414 .39229 .16857 .39248 .17423 .39073 .16985 .39027 Mtetra
.4 .839 .942 r
.16985 .39027 .17423 .39073 .17909 .39657 .17548 .38904 Mtetra
.877 .682 .635 r
.17548 .38904 .17909 .39657 .18764 .36796 .18351 .36555 Mtetra
.289 .68 .973 r
.18351 .36555 .18764 .36796 .19141 .38443 .18896 .36595 Mtetra
.524 .392 .643 r
.18896 .36595 .19141 .38443 .19667 .3871 .19441 .36654 Mtetra
.557 .407 .633 r
.19441 .36654 .19667 .3871 .20258 .38368 .20004 .36566 Mtetra
.647 .482 .646 r
.20004 .36566 .20258 .38368 .20869 .37817 .20613 .36026 Mtetra
.609 .456 .649 r
.20613 .36026 .20869 .37817 .21566 .36392 .212 .35709 Mtetra
.643 .612 .804 r
.212 .35709 .21566 .36392 .22183 .35769 .21778 .35502 Mtetra
.617 .07 0 r
.21778 .35502 .22183 .35769 .22773 .35428 .2229 .35996 Mtetra
0 0 0 r
.2229 .35996 .22773 .35428 .23361 .35127 .22896 .35523 Mtetra
.68 .931 .633 r
.22896 .35523 .23361 .35127 .23953 .34791 .23521 .34844 Mtetra
.815 .376 .199 r
.23521 .34844 .23953 .34791 .2451 .34856 .2401 .35684 Mtetra
.829 .504 .438 r
.2401 .35684 .2451 .34856 .25035 .35312 .24391 .37807 Mtetra
.567 .276 .432 r
.24391 .37807 .25035 .35312 .25507 .3644 .24932 .3818 Mtetra
.612 .297 .412 r
.24932 .3818 .25507 .3644 .26013 .3724 .25461 .38739 Mtetra
.259 0 .239 r
.25461 .38739 .26013 .3724 .26568 .37493 .2609 .3814 Mtetra
.473 .056 .168 r
.2609 .3814 .26568 .37493 .27105 .38 .26666 .38196 Mtetra
.727 .986 .795 r
.26666 .38196 .27105 .38 .27657 .38373 .2729 .37655 Mtetra
.753 .655 .753 r
.2729 .37655 .27657 .38373 .28281 .37836 .27919 .37068 Mtetra
.873 .685 .645 r
.27919 .37068 .28281 .37836 .2899 .36153 .28651 .35101 Mtetra
.803 .629 .666 r
.28651 .35101 .2899 .36153 .29644 .35182 .2933 .33792 Mtetra
.652 .512 .679 r
.2933 .33792 .29644 .35182 .30301 .34141 .29944 .33354 Mtetra
.611 .573 .787 r
.29944 .33354 .30301 .34141 .30933 .33439 .30539 .332 Mtetra
.453 .766 .996 r
.30539 .332 .30933 .33439 .31532 .33225 .31128 .33148 Mtetra
.427 0 0 r
.31128 .33148 .31532 .33225 .32102 .33478 .31698 .33411 Mtetra
.95 .838 .698 r
.31698 .33411 .32102 .33478 .32762 .32353 .32379 .32005 Mtetra
.719 .783 .903 r
.32379 .32005 .32762 .32353 .33319 .32892 .32988 .31698 Mtetra
.551 .468 .714 r
.32988 .31698 .33319 .32892 .33951 .3222 .33581 .31667 Mtetra
.776 .708 .787 r
.33581 .31667 .33951 .3222 .3458 .31605 .34208 .31102 Mtetra
.589 .663 .89 r
.34208 .31102 .3458 .31605 .3518 .31504 .34809 .30995 Mtetra
.801 .728 .784 r
.34809 .30995 .3518 .31504 .35821 .30664 .3544 .30354 Mtetra
.662 .796 .946 r
.3544 .30354 .35821 .30664 .36416 .30691 .3605 .30135 Mtetra
.626 .656 .86 r
.3605 .30135 .36416 .30691 .36999 .31019 .36658 .2997 Mtetra
.56 .494 .739 r
.36658 .2997 .36999 .31019 .37603 .30991 .37262 .29918 Mtetra
.618 .525 .727 r
.37262 .29918 .37603 .30991 .3826 .29828 .37875 .29698 Mtetra
.868 .909 .858 r
.37875 .29698 .3826 .29828 .38874 .29608 .38509 .29068 Mtetra
0 0 .467 r
.38509 .29068 .38874 .29608 .39492 .29333 .39082 .29838 Mtetra
.198 0 0 r
.39082 .29838 .39492 .29333 .40108 .29112 .39702 .29617 Mtetra
.213 0 0 r
.39702 .29617 .40108 .29112 .40698 .29643 .40322 .29408 Mtetra
.896 .842 .784 r
.40322 .29408 .40698 .29643 .41332 .29041 .40968 .2854 Mtetra
0 .183 .711 r
.40968 .2854 .41332 .29041 .41935 .29374 .41564 .29052 Mtetra
.185 .566 .936 r
.41564 .29052 .41935 .29374 .42542 .297 .42177 .29202 Mtetra
.677 .705 .869 r
.42177 .29202 .42542 .297 .4318 .29075 .42806 .28944 Mtetra
.198 .692 .919 r
.42806 .28944 .4318 .29075 .43806 .28914 .43428 .28954 Mtetra
.977 .873 .666 r
.43428 .28954 .43806 .28914 .4446 .27722 .44094 .27414 Mtetra
.723 .221 0 r
.44094 .27414 .4446 .27722 .4506 .2869 .44697 .28239 Mtetra
.941 .574 .221 r
.44697 .28239 .4506 .2869 .45637 .30965 .45266 .30813 Mtetra
.828 .353 .023 r
.45266 .30813 .45637 .30965 .46267 .312 .45879 .31851 Mtetra
0 0 0 r
.45879 .31851 .46267 .312 .46938 .29339 .46539 .30836 Mtetra
.426 .105 .315 r
.46539 .30836 .46938 .29339 .47571 .29504 .47183 .3061 Mtetra
0 0 0 r
.47183 .3061 .47571 .29504 .48214 .29153 .47846 .29252 Mtetra
.29 .781 .73 r
.47846 .29252 .48214 .29153 .48855 .29122 .48491 .29024 Mtetra
0 .515 .766 r
.48491 .29024 .48855 .29122 .49502 .28633 .49134 .29132 Mtetra
.508 .053 .105 r
.49134 .29132 .49502 .28633 .50144 .28989 .49779 .29295 Mtetra
.693 .928 .611 r
.49779 .29295 .50144 .28989 .50799 .27503 .50434 .28533 Mtetra
.375 .017 .224 r
.50434 .28533 .50799 .27503 .51449 .26494 .51085 .28303 Mtetra
.146 0 .25 r
.51085 .28303 .51449 .26494 .52098 .25619 .51741 .27155 Mtetra
.369 .058 .302 r
.51741 .27155 .52098 .25619 .52745 .25294 .52393 .26734 Mtetra
0 0 0 r
.52393 .26734 .52745 .25294 .53394 .25129 .53044 .24654 Mtetra
.705 .733 .873 r
.53044 .24654 .53394 .25129 .54042 .24262 .53695 .24336 Mtetra
.238 .749 .731 r
.53695 .24336 .54042 .24262 .54691 .23841 .54348 .2415 Mtetra
.823 .398 .232 r
.54348 .2415 .54691 .23841 .55355 .24909 .55015 .25411 Mtetra
.642 .197 .178 r
.55015 .25411 .55355 .24909 .56029 .26197 .55682 .25891 Mtetra
.651 .143 0 r
.55682 .25891 .56029 .26197 .56686 .25696 .56357 .26712 Mtetra
.743 .372 .35 r
.56357 .26712 .56686 .25696 .57365 .26487 .57045 .27956 Mtetra
.289 0 .268 r
.57045 .27956 .57365 .26487 .58045 .27033 .5771 .27331 Mtetra
.838 .949 .596 r
.5771 .27331 .58045 .27033 .58722 .27193 .58366 .26275 Mtetra
.69 .599 .75 r
.58366 .26275 .58722 .27193 .59393 .26958 .59034 .25841 Mtetra
.723 .587 .703 r
.59034 .25841 .59393 .26958 .6004 .25648 .59696 .25153 Mtetra
.849 .768 .773 r
.59696 .25153 .6004 .25648 .60713 .25411 .60355 .24331 Mtetra
.822 .642 .659 r
.60355 .24331 .60713 .25411 .61346 .23764 .60997 .22946 Mtetra
.853 .689 .678 r
.60997 .22946 .61346 .23764 .61985 .22418 .61637 .21638 Mtetra
.05 .244 .741 r
.61637 .21638 .61985 .22418 .62675 .22722 .62338 .22279 Mtetra
.336 .581 .933 r
.62338 .22279 .62675 .22722 .63378 .23278 .63027 .22414 Mtetra
.034 .209 .713 r
.63027 .22414 .63378 .23278 .64091 .23976 .63741 .23152 Mtetra
.699 .625 .77 r
.63741 .23152 .64091 .23976 .64801 .24422 .64416 .22723 Mtetra
.413 .339 .664 r
.64416 .22723 .64801 .24422 .65446 .23236 .65129 .23191 Mtetra
.839 .99 .857 r
.65129 .23191 .65446 .23236 .6613 .22994 .65798 .22559 Mtetra
0 0 .511 r
.65798 .22559 .6613 .22994 .66861 .23703 .66536 .23413 Mtetra
0 .141 .616 r
.66536 .23413 .66861 .23703 .6758 .24041 .67266 .23968 Mtetra
.409 0 0 r
.67266 .23968 .6758 .24041 .6838 .25867 .67992 .24327 Mtetra
.551 .443 .685 r
.67992 .24327 .6838 .25867 .69058 .2522 .68701 .24284 Mtetra
.69 .601 .751 r
.68701 .24284 .69058 .2522 .69702 .23973 .6939 .23838 Mtetra
.57 .904 .979 r
.6939 .23838 .69702 .23973 .70449 .24532 .70092 .23593 Mtetra
.88 .687 .637 r
.70092 .23593 .70449 .24532 .71123 .23805 .70705 .21825 Mtetra
.464 .357 .648 r
.70705 .21825 .71123 .23805 .71755 .2243 .71443 .22174 Mtetra
.931 .884 .765 r
.71443 .22174 .71755 .2243 .72448 .22024 .721 .2118 Mtetra
.455 .49 .806 r
.721 .2118 .72448 .22024 .73113 .21192 .72831 .21329 Mtetra
.978 .895 .545 r
.72831 .21329 .73113 .21192 .73722 .19583 .73433 .1956 Mtetra
.437 .875 .88 r
.73433 .1956 .73722 .19583 .74368 .18549 .74139 .19311 Mtetra
0 0 0 r
.74139 .19311 .74368 .18549 .75121 .18958 .74798 .18408 Mtetra
.903 .772 .707 r
.74798 .18408 .75121 .18958 .75799 .18341 .75432 .172 Mtetra
.758 .605 .689 r
.75432 .172 .75799 .18341 .76416 .16968 .76088 .16307 Mtetra
.734 .69 .809 r
.76088 .16307 .76416 .16968 .77102 .16468 .76778 .15839 Mtetra
.103 .336 .807 r
.76778 .15839 .77102 .16468 .77824 .16381 .77551 .16358 Mtetra
.094 0 0 r
.77551 .16358 .77824 .16381 .78533 .16128 .78292 .16444 Mtetra
.847 .414 .194 r
.15057 .37664 .15495 .37751 .15986 .38198 .15498 .38553 Mtetra
.688 .26 .226 r
.15498 .38553 .15986 .38198 .16414 .39229 .15989 .39035 Mtetra
.083 .584 .894 r
.15989 .39035 .16414 .39229 .16985 .39027 .16527 .39129 Mtetra
.955 .858 .705 r
.16527 .39129 .16985 .39027 .17548 .38904 .17233 .37727 Mtetra
.795 .614 .655 r
.17233 .37727 .17548 .38904 .18351 .36555 .17938 .36301 Mtetra
.76 .826 .904 r
.17938 .36301 .18351 .36555 .18896 .36595 .18526 .35939 Mtetra
.758 .664 .758 r
.18526 .35939 .18896 .36595 .19441 .36654 .19137 .35366 Mtetra
.527 .437 .697 r
.19137 .35366 .19441 .36654 .20004 .36566 .19686 .35401 Mtetra
.634 .519 .705 r
.19686 .35401 .20004 .36566 .20613 .36026 .2027 .35109 Mtetra
0 0 .344 r
.2027 .35109 .20613 .36026 .212 .35709 .2072 .36164 Mtetra
0 0 0 r
.2072 .36164 .212 .35709 .21778 .35502 .21336 .35588 Mtetra
.777 .321 .165 r
.21336 .35588 .21778 .35502 .2229 .35996 .21831 .36271 Mtetra
.442 .842 .644 r
.21831 .36271 .2229 .35996 .22896 .35523 .22432 .35873 Mtetra
.796 .408 .32 r
.22432 .35873 .22896 .35523 .23521 .34844 .22904 .36871 Mtetra
.645 .34 .44 r
.22904 .36871 .23521 .34844 .2401 .35684 .23393 .3775 Mtetra
.697 .393 .458 r
.23393 .3775 .2401 .35684 .24391 .37807 .2384 .39161 Mtetra
.484 .15 .323 r
.2384 .39161 .24391 .37807 .24932 .3818 .24418 .39149 Mtetra
.497 .128 .269 r
.24418 .39149 .24932 .3818 .25461 .38739 .24991 .3921 Mtetra
.872 .965 .637 r
.24991 .3921 .25461 .38739 .2609 .3814 .25662 .38143 Mtetra
.896 .94 .833 r
.25662 .38143 .2609 .3814 .26666 .38196 .26302 .37419 Mtetra
.864 .681 .654 r
.26302 .37419 .26666 .38196 .2729 .37655 .27027 .35641 Mtetra
.588 .432 .638 r
.27027 .35641 .2729 .37655 .27919 .37068 .27627 .35393 Mtetra
.75 .559 .637 r
.27627 .35393 .27919 .37068 .28651 .35101 .28312 .34052 Mtetra
.824 .64 .653 r
.28312 .34052 .28651 .35101 .2933 .33792 .29013 .32465 Mtetra
.546 .448 .695 r
.29013 .32465 .2933 .33792 .29944 .33354 .29595 .32446 Mtetra
.171 .28 .734 r
.29595 .32446 .29944 .33354 .30539 .332 .30145 .32929 Mtetra
.439 .738 .991 r
.30145 .32929 .30539 .332 .31128 .33148 .30733 .329 Mtetra
.85 .39 .049 r
.30733 .329 .31128 .33148 .31698 .33411 .31255 .339 Mtetra
.902 .952 .606 r
.31255 .339 .31698 .33411 .32379 .32005 .31928 .32664 Mtetra
.891 .921 .53 r
.31928 .32664 .32379 .32005 .32988 .31698 .32614 .31188 Mtetra
.829 .73 .756 r
.32614 .31188 .32988 .31698 .33581 .31667 .33255 .30382 Mtetra
.483 .413 .702 r
.33255 .30382 .33581 .31667 .34208 .31102 .33839 .30531 Mtetra
.745 .694 .803 r
.33839 .30531 .34208 .31102 .34809 .30995 .3446 .30075 Mtetra
.577 .527 .763 r
.3446 .30075 .34809 .30995 .3544 .30354 .35062 .29984 Mtetra
.527 .713 .957 r
.35062 .29984 .3544 .30354 .3605 .30135 .35663 .29923 Mtetra
.868 .858 .829 r
.35663 .29923 .3605 .30135 .36658 .2997 .36299 .29236 Mtetra
.552 .56 .816 r
.36299 .29236 .36658 .2997 .37262 .29918 .36903 .29196 Mtetra
.571 .574 .817 r
.36903 .29196 .37262 .29918 .37875 .29698 .3751 .29122 Mtetra
0 0 .476 r
.3751 .29122 .37875 .29698 .38509 .29068 .38079 .29909 Mtetra
.2 0 .087 r
.38079 .29909 .38509 .29068 .39082 .29838 .38706 .29505 Mtetra
.662 .786 .94 r
.38706 .29505 .39082 .29838 .39702 .29617 .39327 .29283 Mtetra
.766 .807 .886 r
.39327 .29283 .39702 .29617 .40322 .29408 .39956 .28872 Mtetra
.868 .734 .712 r
.39956 .28872 .40322 .29408 .40968 .2854 .40614 .27728 Mtetra
.763 .402 0 r
.40614 .27728 .40968 .2854 .41564 .29052 .41172 .29271 Mtetra
0 0 0 r
.41172 .29271 .41564 .29052 .42177 .29202 .418 .29046 Mtetra
.504 .848 .996 r
.418 .29046 .42177 .29202 .42806 .28944 .42426 .28907 Mtetra
.9 .948 .827 r
.42426 .28907 .42806 .28944 .43428 .28954 .43072 .28158 Mtetra
.861 .686 .662 r
.43072 .28158 .43428 .28954 .44094 .27414 .4374 .26618 Mtetra
.815 .45 0 r
.4374 .26618 .44094 .27414 .44697 .28239 .44318 .28379 Mtetra
.899 .52 .306 r
.44318 .28379 .44697 .28239 .45266 .30813 .44896 .30478 Mtetra
.792 .317 0 r
.44896 .30478 .45266 .30813 .45879 .31851 .4551 .31518 Mtetra
.834 .821 .837 r
.4551 .31518 .45879 .31851 .46539 .30836 .46163 .30898 Mtetra
.571 .007 0 r
.46163 .30898 .46539 .30836 .47183 .3061 .46798 .31263 Mtetra
.954 .882 .483 r
.46798 .31263 .47183 .3061 .47846 .29252 .47479 .29095 Mtetra
.313 .753 .966 r
.47479 .29095 .47846 .29252 .48491 .29024 .48122 .29063 Mtetra
.798 .319 .079 r
.48122 .29063 .48491 .29024 .49134 .29132 .48757 .29976 Mtetra
.205 0 .095 r
.48757 .29976 .49134 .29132 .49779 .29295 .49412 .29549 Mtetra
.994 .876 .579 r
.49412 .29549 .49779 .29295 .50434 .28533 .50079 .27522 Mtetra
.678 .574 .732 r
.50079 .27522 .50434 .28533 .51085 .28303 .50732 .27096 Mtetra
.802 .619 .654 r
.50732 .27096 .51085 .28303 .51741 .27155 .51388 .25718 Mtetra
.68 .529 .673 r
.51388 .25718 .51741 .27155 .52393 .26734 .5204 .25102 Mtetra
.734 .549 .643 r
.5204 .25102 .52393 .26734 .53044 .24654 .52692 .23989 Mtetra
.492 .558 .851 r
.52692 .23989 .53044 .24654 .53695 .24336 .53345 .24032 Mtetra
.648 .139 0 r
.53345 .24032 .53695 .24336 .54348 .2415 .54004 .24822 Mtetra
.789 .398 .314 r
.54004 .24822 .54348 .2415 .55015 .25411 .54673 .26157 Mtetra
.782 .395 .323 r
.54673 .26157 .55015 .25411 .55682 .25891 .55351 .27506 Mtetra
.586 .252 .371 r
.55351 .27506 .55682 .25891 .56357 .26712 .56026 .27949 Mtetra
.025 0 .131 r
.56026 .27949 .56357 .26712 .57045 .27956 .56687 .26937 Mtetra
.553 .505 .756 r
.56687 .26937 .57045 .27956 .5771 .27331 .57361 .26896 Mtetra
.908 .786 .715 r
.57361 .26896 .5771 .27331 .58366 .26275 .58016 .25688 Mtetra
.542 .621 .88 r
.58016 .25688 .58366 .26275 .59034 .25841 .58693 .25643 Mtetra
.922 .89 .781 r
.58693 .25643 .59034 .25841 .59696 .25153 .59352 .24714 Mtetra
.942 .773 .644 r
.59352 .24714 .59696 .25153 .60355 .24331 .59989 .22931 Mtetra
.78 .592 .646 r
.59989 .22931 .60355 .24331 .60997 .22946 .60632 .216 Mtetra
.606 .492 .698 r
.60632 .216 .60997 .22946 .61637 .21638 .61304 .21359 Mtetra
.682 .177 0 r
.61304 .21359 .61637 .21638 .62338 .22279 .62014 .22267 Mtetra
.187 0 0 r
.62014 .22267 .62338 .22279 .63027 .22414 .62704 .22389 Mtetra
.668 .116 0 r
.62704 .22389 .63027 .22414 .63741 .23152 .63416 .23033 Mtetra
.36 0 0 r
.63416 .23033 .63741 .23152 .64416 .22723 .64122 .23377 Mtetra
.656 .229 .221 r
.64122 .23377 .64416 .22723 .65129 .23191 .64843 .23968 Mtetra
0 0 0 r
.64843 .23968 .65129 .23191 .65798 .22559 .65491 .22727 Mtetra
.662 .942 .684 r
.65491 .22727 .65798 .22559 .66536 .23413 .66163 .22086 Mtetra
.243 .263 .683 r
.66163 .22086 .66536 .23413 .67266 .23968 .66901 .22837 Mtetra
.726 .59 .702 r
.66901 .22837 .67266 .23968 .67992 .24327 .67572 .22125 Mtetra
.638 .463 .629 r
.67572 .22125 .67992 .24327 .68701 .24284 .68247 .21479 Mtetra
.543 .379 .609 r
.68247 .21479 .68701 .24284 .6939 .23838 .68954 .21433 Mtetra
.604 .433 .623 r
.68954 .21433 .6939 .23838 .70092 .23593 .69641 .20986 Mtetra
.58 .41 .616 r
.69641 .20986 .70092 .23593 .70705 .21825 .70338 .20684 Mtetra
.398 .393 .737 r
.70338 .20684 .70705 .21825 .71443 .22174 .71075 .2103 Mtetra
0 0 .285 r
.71075 .2103 .71443 .22174 .721 .2118 .71953 .23502 Mtetra
0 0 .247 r
.71953 .23502 .721 .2118 .72831 .21329 .7252 .21057 Mtetra
.976 .834 .637 r
.7252 .21057 .72831 .21329 .73433 .1956 .73131 .19374 Mtetra
.607 .893 .989 r
.73131 .19374 .73433 .1956 .74139 .19311 .73839 .19123 Mtetra
.969 .89 .695 r
.73839 .19123 .74139 .19311 .74798 .18408 .74473 .17846 Mtetra
.901 .77 .707 r
.74473 .17846 .74798 .18408 .75432 .172 .75109 .16639 Mtetra
.851 .764 .766 r
.75109 .16639 .75432 .172 .76088 .16307 .7577 .15786 Mtetra
.661 .715 .888 r
.7577 .15786 .76088 .16307 .76778 .15839 .76478 .15532 Mtetra
.602 .113 0 r
.76478 .15532 .76778 .15839 .77551 .16358 .77292 .16525 Mtetra
.425 .821 .602 r
.77292 .16525 .77551 .16358 .78292 .16444 .77987 .16041 Mtetra
.406 0 .13 r
.1453 .38316 .15057 .37664 .15498 .38553 .1508 .38271 Mtetra
0 .422 .826 r
.1508 .38271 .15498 .38553 .15989 .39035 .15603 .38479 Mtetra
.803 .701 .752 r
.15603 .38479 .15989 .39035 .16527 .39129 .16235 .37745 Mtetra
.641 .503 .679 r
.16235 .37745 .16527 .39129 .17233 .37727 .16826 .37369 Mtetra
.801 .771 .825 r
.16826 .37369 .17233 .37727 .17938 .36301 .17436 .36835 Mtetra
0 0 0 r
.17436 .36835 .17938 .36301 .18526 .35939 .18026 .36475 Mtetra
.2 0 0 r
.18026 .36475 .18526 .35939 .19137 .35366 .18601 .36268 Mtetra
0 0 0 r
.18601 .36268 .19137 .35366 .19686 .35401 .19251 .35358 Mtetra
.134 .676 .829 r
.19251 .35358 .19686 .35401 .2027 .35109 .19809 .35336 Mtetra
.575 .073 .025 r
.19809 .35336 .2027 .35109 .2072 .36164 .2034 .35595 Mtetra
.773 .694 .776 r
.2034 .35595 .2072 .36164 .21336 .35588 .20956 .35022 Mtetra
0 .098 .648 r
.20956 .35022 .21336 .35588 .21831 .36271 .21465 .35546 Mtetra
.714 .634 .767 r
.21465 .35546 .21831 .36271 .22432 .35873 .2207 .35117 Mtetra
.958 .617 .255 r
.2207 .35117 .22432 .35873 .22904 .36871 .22419 .37407 Mtetra
.68 .276 .274 r
.22419 .37407 .22904 .36871 .23393 .3775 .2294 .37944 Mtetra
.829 .431 .295 r
.2294 .37944 .23393 .3775 .2384 .39161 .23415 .39041 Mtetra
.778 .915 .931 r
.23415 .39041 .2384 .39161 .24418 .39149 .24028 .38636 Mtetra
.846 .726 .73 r
.24028 .38636 .24418 .39149 .24991 .3921 .24694 .37644 Mtetra
.67 .512 .662 r
.24694 .37644 .24991 .3921 .25662 .38143 .25324 .37043 Mtetra
.829 .639 .645 r
.25324 .37043 .25662 .38143 .26302 .37419 .26053 .35268 Mtetra
.725 .525 .621 r
.26053 .35268 .26302 .37419 .27027 .35641 .26747 .33856 Mtetra
.559 .422 .651 r
.26747 .33856 .27027 .35641 .27627 .35393 .27333 .33769 Mtetra
.648 .493 .659 r
.27333 .33769 .27627 .35393 .28312 .34052 .27952 .33276 Mtetra
.763 .647 .734 r
.27952 .33276 .28312 .34052 .29013 .32465 .28585 .32594 Mtetra
.285 .776 .718 r
.28585 .32594 .29013 .32465 .29595 .32446 .29184 .32378 Mtetra
.903 .522 .295 r
.29184 .32378 .29595 .32446 .30145 .32929 .29648 .34054 Mtetra
.15 0 .127 r
.29648 .34054 .30145 .32929 .30733 .329 .3028 .33455 Mtetra
.571 .143 .19 r
.3028 .33455 .30733 .329 .31255 .339 .30853 .33712 Mtetra
.927 .817 .717 r
.30853 .33712 .31255 .339 .31928 .32664 .31531 .3245 Mtetra
.923 .81 .717 r
.31531 .3245 .31928 .32664 .32614 .31188 .32205 .31194 Mtetra
.956 .874 .714 r
.32205 .31194 .32614 .31188 .33255 .30382 .32878 .29922 Mtetra
.544 .667 .918 r
.32878 .29922 .33255 .30382 .33839 .30531 .33475 .29865 Mtetra
0 .245 .754 r
.33475 .29865 .33839 .30531 .3446 .30075 .34041 .3035 Mtetra
.613 .125 .071 r
.34041 .3035 .3446 .30075 .35062 .29984 .34619 .30697 Mtetra
0 0 0 r
.34619 .30697 .35062 .29984 .35663 .29923 .3525 .30157 Mtetra
.605 .93 .709 r
.3525 .30157 .35663 .29923 .36299 .29236 .35879 .29646 Mtetra
.811 .953 .613 r
.35879 .29646 .36299 .29236 .36903 .29196 .36532 .28693 Mtetra
0 0 .455 r
.36532 .28693 .36903 .29196 .3751 .29122 .37099 .29427 Mtetra
.855 .474 .325 r
.37099 .29427 .3751 .29122 .38079 .29909 .37632 .31011 Mtetra
.383 .03 .237 r
.37632 .31011 .38079 .29909 .38706 .29505 .38255 .30794 Mtetra
0 0 0 r
.38255 .30794 .38706 .29505 .39327 .29283 .38942 .29126 Mtetra
.906 .877 .795 r
.38942 .29126 .39327 .29283 .39956 .28872 .39591 .28276 Mtetra
.799 .707 .763 r
.39591 .28276 .39956 .28872 .40614 .27728 .40233 .27572 Mtetra
.885 .457 .157 r
.40233 .27572 .40614 .27728 .41172 .29271 .40797 .28946 Mtetra
.661 .794 .946 r
.40797 .28946 .41172 .29271 .418 .29046 .41426 .28721 Mtetra
.906 .798 .73 r
.41426 .28721 .418 .29046 .42426 .28907 .42086 .27592 Mtetra
.769 .59 .657 r
.42086 .27592 .42426 .28907 .43072 .28158 .42746 .26409 Mtetra
.006 .044 .55 r
.42746 .26409 .43072 .28158 .4374 .26618 .43329 .27742 Mtetra
.728 .375 .38 r
.43329 .27742 .4374 .26618 .44318 .28379 .43924 .28914 Mtetra
.756 .351 .284 r
.43924 .28914 .44318 .28379 .44896 .30478 .44532 .29864 Mtetra
0 .12 .67 r
.44532 .29864 .44896 .30478 .4551 .31518 .45154 .30509 Mtetra
.739 .607 .711 r
.45154 .30509 .4551 .31518 .46163 .30898 .45809 .29802 Mtetra
.359 .368 .734 r
.45809 .29802 .46163 .30898 .46798 .31263 .46443 .30165 Mtetra
.851 .653 .633 r
.46443 .30165 .46798 .31263 .47479 .29095 .47121 .28255 Mtetra
.55 .537 .794 r
.47121 .28255 .47479 .29095 .48122 .29063 .47765 .28218 Mtetra
0 0 .283 r
.47765 .28218 .48122 .29063 .48757 .29976 .48391 .29683 Mtetra
.772 .847 .907 r
.48391 .29683 .48757 .29976 .49412 .29549 .49047 .29259 Mtetra
.941 .805 .682 r
.49047 .29259 .49412 .29549 .50079 .27522 .49713 .27766 Mtetra
.626 .923 .659 r
.49713 .27766 .50079 .27522 .50732 .27096 .5037 .27153 Mtetra
.99 .851 .608 r
.5037 .27153 .50732 .27096 .51388 .25718 .51032 .25173 Mtetra
.882 .745 .706 r
.51032 .25173 .51388 .25718 .5204 .25102 .51687 .23966 Mtetra
.693 .566 .706 r
.51687 .23966 .5204 .25102 .52692 .23989 .52339 .23419 Mtetra
.547 .626 .882 r
.52339 .23419 .52692 .23989 .53345 .24032 .52992 .23366 Mtetra
.909 .54 .094 r
.52992 .23366 .53345 .24032 .54004 .24822 .53658 .25958 Mtetra
.839 .49 .394 r
.53658 .25958 .54004 .24822 .54673 .26157 .54338 .28669 Mtetra
.53 .234 .408 r
.54338 .28669 .54673 .26157 .55351 .27506 .55011 .28836 Mtetra
.139 0 .187 r
.55011 .28836 .55351 .27506 .56026 .27949 .55678 .27975 Mtetra
.961 .935 .71 r
.55678 .27975 .56026 .27949 .56687 .26937 .56339 .26803 Mtetra
.822 .949 .903 r
.56339 .26803 .56687 .26937 .57361 .26896 .57007 .26264 Mtetra
.886 .732 .685 r
.57007 .26264 .57361 .26896 .58016 .25688 .57662 .24901 Mtetra
.836 .689 .7 r
.57662 .24901 .58016 .25688 .58693 .25643 .58318 .23787 Mtetra
.661 .492 .644 r
.58318 .23787 .58693 .25643 .59352 .24714 .58981 .23109 Mtetra
.78 .58 .629 r
.58981 .23109 .59352 .24714 .59989 .22931 .59624 .21569 Mtetra
.645 .515 .69 r
.59624 .21569 .59989 .22931 .60632 .216 .60291 .21154 Mtetra
0 0 .439 r
.60291 .21154 .60632 .216 .61304 .21359 .60996 .22063 Mtetra
.405 0 .135 r
.60996 .22063 .61304 .21359 .62014 .22267 .61679 .22001 Mtetra
.497 0 0 r
.61679 .22001 .62014 .22267 .62704 .22389 .62387 .22622 Mtetra
.568 .036 0 r
.62387 .22622 .62704 .22389 .63416 .23033 .6309 .22976 Mtetra
.427 0 0 r
.6309 .22976 .63416 .23033 .64122 .23377 .63798 .23323 Mtetra
.719 .978 .916 r
.63798 .23323 .64122 .23377 .64843 .23968 .64479 .22882 Mtetra
.717 .59 .713 r
.64479 .22882 .64843 .23968 .65491 .22727 .65153 .22244 Mtetra
.741 .758 .866 r
.65153 .22244 .65491 .22727 .66163 .22086 .65837 .21832 Mtetra
.421 .759 .995 r
.65837 .21832 .66163 .22086 .66901 .22837 .66539 .21785 Mtetra
.579 .518 .751 r
.66539 .21785 .66901 .22837 .67572 .22125 .6724 .21671 Mtetra
.824 .794 .824 r
.6724 .21671 .67572 .22125 .68247 .21479 .67916 .21024 Mtetra
.867 .799 .782 r
.67916 .21024 .68247 .21479 .68954 .21433 .68582 .20184 Mtetra
.488 .433 .722 r
.68582 .20184 .68954 .21433 .69641 .20986 .69301 .2033 Mtetra
.65 .654 .84 r
.69301 .2033 .69641 .20986 .70338 .20684 .70002 .20081 Mtetra
.543 .622 .88 r
.70002 .20081 .70338 .20684 .71075 .2103 .70716 .2003 Mtetra
.326 .374 .758 r
.70716 .2003 .71075 .2103 .71953 .23502 .71463 .20459 Mtetra
.61 .42 .6 r
.71463 .20459 .71953 .23502 .7252 .21057 .72144 .19812 Mtetra
.734 .582 .685 r
.72144 .19812 .7252 .21057 .73131 .19374 .72814 .18983 Mtetra
.508 .716 .966 r
.72814 .18983 .73131 .19374 .73839 .19123 .73536 .18923 Mtetra
.986 .85 .621 r
.73536 .18923 .73839 .19123 .74473 .17846 .74141 .17197 Mtetra
.723 .692 .819 r
.74141 .17197 .74473 .17846 .75109 .16639 .74837 .16764 Mtetra
.986 .87 .511 r
.74837 .16764 .75109 .16639 .7577 .15786 .7541 .14736 Mtetra
.615 .539 .747 r
.7541 .14736 .7577 .15786 .76478 .15532 .7612 .14509 Mtetra
.131 .241 .711 r
.7612 .14509 .76478 .15532 .77292 .16525 .76917 .15308 Mtetra
.614 .516 .719 r
.76917 .15308 .77292 .16525 .77987 .16041 .77631 .15051 Mtetra
.928 .945 .602 r
.13993 .39012 .1453 .38316 .1508 .38271 .14708 .37587 Mtetra
.791 .669 .729 r
.14708 .37587 .1508 .38271 .15603 .38479 .15347 .36791 Mtetra
.557 .424 .656 r
.15347 .36791 .15603 .38479 .16235 .37745 .15902 .36718 Mtetra
.707 .578 .709 r
.15902 .36718 .16235 .37745 .16826 .37369 .16514 .36163 Mtetra
.608 .499 .704 r
.16514 .36163 .16826 .37369 .17436 .36835 .17086 .35957 Mtetra
.588 .537 .765 r
.17086 .35957 .17436 .36835 .18026 .36475 .1765 .35847 Mtetra
.687 .648 .805 r
.1765 .35847 .18026 .36475 .18601 .36268 .18236 .35542 Mtetra
.759 .651 .742 r
.18236 .35542 .18601 .36268 .19251 .35358 .18857 .34912 Mtetra
.734 .728 .845 r
.18857 .34912 .19251 .35358 .19809 .35336 .1945 .34548 Mtetra
0 .156 .689 r
.1945 .34548 .19809 .35336 .2034 .35595 .1995 .35105 Mtetra
.657 .689 .868 r
.1995 .35105 .2034 .35595 .20956 .35022 .2053 .34895 Mtetra
.815 .902 .902 r
.2053 .34895 .20956 .35022 .21465 .35546 .21138 .34425 Mtetra
.613 .513 .717 r
.21138 .34425 .21465 .35546 .2207 .35117 .21721 .34214 Mtetra
.707 .371 0 r
.21721 .34214 .2207 .35117 .22419 .37407 .22167 .35453 Mtetra
.493 .366 .636 r
.22167 .35453 .22419 .37407 .2294 .37944 .2272 .35622 Mtetra
.4 .282 .602 r
.2272 .35622 .2294 .37944 .23415 .39041 .2324 .36176 Mtetra
.591 .409 .604 r
.2324 .36176 .23415 .39041 .24028 .38636 .2385 .35773 Mtetra
.606 .42 .604 r
.2385 .35773 .24028 .38636 .24694 .37644 .24471 .35251 Mtetra
.629 .449 .619 r
.24471 .35251 .24694 .37644 .25324 .37043 .25099 .34654 Mtetra
.25099 .34654 .25324 .37043 .26053 .35268 .25726 .34057 Mtetra
.658 .531 .699 r
.25726 .34057 .26053 .35268 .26747 .33856 .26338 .33652 Mtetra
.701 .866 .96 r
.26338 .33652 .26747 .33856 .27333 .33769 .2694 .33374 Mtetra
.212 .537 .925 r
.2694 .33374 .27333 .33769 .27952 .33276 .27508 .33538 Mtetra
.735 .291 .196 r
.27508 .33538 .27952 .33276 .28585 .32594 .28043 .34176 Mtetra
.485 .163 .345 r
.28043 .34176 .28585 .32594 .29184 .32378 .28632 .34152 Mtetra
.668 .35 .427 r
.28632 .34152 .29184 .32378 .29648 .34054 .29148 .35144 Mtetra
.126 0 .104 r
.29148 .35144 .29648 .34054 .3028 .33455 .29784 .34538 Mtetra
.56 .201 .316 r
.29784 .34538 .3028 .33455 .30853 .33712 .30361 .34787 Mtetra
.714 .803 .332 r
.30361 .34787 .30853 .33712 .31531 .3245 .3107 .33131 Mtetra
.62 .82 .412 r
.3107 .33131 .31531 .3245 .32205 .31194 .31733 .32117 Mtetra
0 0 0 r
.31733 .32117 .32205 .31194 .32878 .29922 .3241 .3086 Mtetra
.529 .154 .274 r
.3241 .3086 .32878 .29922 .33475 .29865 .32996 .31014 Mtetra
.466 .113 .282 r
.32996 .31014 .33475 .29865 .34041 .3035 .33596 .30983 Mtetra
0 0 0 r
.33596 .30983 .34041 .3035 .34619 .30697 .34232 .30381 Mtetra
.817 .814 .847 r
.34232 .30381 .34619 .30697 .3525 .30157 .34865 .29828 Mtetra
.861 .803 .792 r
.34865 .29828 .3525 .30157 .35879 .29646 .3551 .29057 Mtetra
.833 .714 .732 r
.3551 .29057 .35879 .29646 .36532 .28693 .36162 .28132 Mtetra
.338 .514 .883 r
.36162 .28132 .36532 .28693 .37099 .29427 .36758 .28301 Mtetra
.269 .299 .708 r
.36758 .28301 .37099 .29427 .37632 .31011 .37341 .28793 Mtetra
.506 .366 .625 r
.37341 .28793 .37632 .31011 .38255 .30794 .37944 .28936 Mtetra
.375 .293 .634 r
.37944 .28936 .38255 .30794 .38942 .29126 .38532 .29487 Mtetra
.987 .899 .603 r
.38532 .29487 .38942 .29126 .39591 .28276 .39225 .27672 Mtetra
.726 .683 .808 r
.39225 .27672 .39591 .28276 .40233 .27572 .39857 .27259 Mtetra
.319 .654 .971 r
.39857 .27259 .40233 .27572 .40797 .28946 .40471 .27322 Mtetra
.44 .354 .663 r
.40471 .27322 .40797 .28946 .41426 .28721 .41078 .27638 Mtetra
.825 .64 .652 r
.41078 .27638 .41426 .28721 .42086 .27592 .41753 .26103 Mtetra
.153 .171 .626 r
.41753 .26103 .42086 .27592 .42746 .26409 .42345 .26988 Mtetra
.709 .3 .269 r
.42345 .26988 .42746 .26409 .43329 .27742 .42947 .27711 Mtetra
.775 .275 .009 r
.42947 .27711 .43329 .27742 .43924 .28914 .43554 .28494 Mtetra
0 .198 .705 r
.43554 .28494 .43924 .28914 .44532 .29864 .44174 .28969 Mtetra
.053 .213 .711 r
.44174 .28969 .44532 .29864 .45154 .30509 .44795 .29609 Mtetra
.548 .523 .779 r
.44795 .29609 .45154 .30509 .45809 .29802 .45436 .29577 Mtetra
.386 .754 .992 r
.45436 .29577 .45809 .29802 .46443 .30165 .46079 .29545 Mtetra
.859 .722 .711 r
.46079 .29545 .46443 .30165 .47121 .28255 .46745 .28411 Mtetra
.152 0 0 r
.46745 .28411 .47121 .28255 .47765 .28218 .4739 .28376 Mtetra
.734 .244 .074 r
.4739 .28376 .47765 .28218 .48391 .29683 .48028 .29064 Mtetra
.65 .656 .843 r
.48028 .29064 .48391 .29683 .49047 .29259 .48682 .28833 Mtetra
.929 .767 .661 r
.48682 .28833 .49047 .29259 .49713 .27766 .49353 .27146 Mtetra
.896 .728 .665 r
.49353 .27146 .49713 .27766 .5037 .27153 .50018 .2556 Mtetra
.755 .565 .64 r
.50018 .2556 .5037 .27153 .51032 .25173 .50677 .24277 Mtetra
.827 .664 .681 r
.50677 .24277 .51032 .25173 .51687 .23966 .51333 .23055 Mtetra
.641 .572 .761 r
.51333 .23055 .51687 .23966 .52339 .23419 .51985 .22785 Mtetra
.864 .477 0 r
.51985 .22785 .52339 .23419 .52992 .23366 .5264 .2478 Mtetra
.722 .374 .389 r
.5264 .2478 .52992 .23366 .53658 .25958 .53303 .26115 Mtetra
.887 .484 .25 r
.53303 .26115 .53658 .25958 .54338 .28669 .53978 .28035 Mtetra
.383 .517 .868 r
.53978 .28035 .54338 .28669 .55011 .28836 .54652 .282 Mtetra
.826 .72 .748 r
.54652 .282 .55011 .28836 .55678 .27975 .5532 .27341 Mtetra
.894 .732 .673 r
.5532 .27341 .55678 .27975 .56339 .26803 .55979 .25844 Mtetra
.748 .623 .72 r
.55979 .25844 .56339 .26803 .57007 .26264 .56646 .25127 Mtetra
.79 .621 .671 r
.56646 .25127 .57007 .26264 .57662 .24901 .57304 .23975 Mtetra
.82 .661 .685 r
.57304 .23975 .57662 .24901 .58318 .23787 .57961 .22811 Mtetra
.887 .68 .617 r
.57961 .22811 .58318 .23787 .58981 .23109 .58595 .20667 Mtetra
.464 .333 .617 r
.58595 .20667 .58981 .23109 .59624 .21569 .59279 .21056 Mtetra
.434 .6 .915 r
.59279 .21056 .59624 .21569 .60291 .21154 .59959 .21122 Mtetra
.855 .4 .088 r
.59959 .21122 .60291 .21154 .60996 .22063 .60679 .22538 Mtetra
.348 0 0 r
.60679 .22538 .60996 .22063 .61679 .22001 .61365 .22485 Mtetra
.727 .284 .198 r
.61365 .22485 .61679 .22001 .62387 .22622 .62081 .23313 Mtetra
.18 0 .033 r
.62081 .23313 .62387 .22622 .6309 .22976 .62763 .2292 Mtetra
.845 .986 .861 r
.62763 .2292 .6309 .22976 .63798 .23323 .63436 .22282 Mtetra
.632 .55 .744 r
.63436 .22282 .63798 .23323 .64479 .22882 .64124 .22005 Mtetra
.633 .582 .779 r
.64124 .22005 .64479 .22882 .65153 .22244 .64815 .21759 Mtetra
.66 .728 .9 r
.64815 .21759 .65153 .22244 .65837 .21832 .65507 .21513 Mtetra
.474 .743 .987 r
.65507 .21513 .65837 .21832 .66539 .21785 .66209 .21457 Mtetra
.817 .856 .877 r
.66209 .21457 .66539 .21785 .6724 .21671 .66891 .20904 Mtetra
.642 .615 .808 r
.66891 .20904 .6724 .21671 .67916 .21024 .67588 .20656 Mtetra
.885 .838 .794 r
.67588 .20656 .67916 .21024 .68582 .20184 .68256 .19814 Mtetra
.269 .593 .948 r
.68256 .19814 .68582 .20184 .69301 .2033 .68976 .19956 Mtetra
.379 .656 .966 r
.68976 .19956 .69301 .2033 .70002 .20081 .69695 .20011 Mtetra
.982 .901 .654 r
.69695 .20011 .70002 .20081 .70716 .2003 .70329 .18575 Mtetra
.526 .435 .695 r
.70329 .18575 .70716 .2003 .71463 .20459 .7105 .18617 Mtetra
.623 .469 .652 r
.7105 .18617 .71463 .20459 .72144 .19812 .71743 .1817 Mtetra
.37 .318 .668 r
.71743 .1817 .72144 .19812 .72814 .18983 .72506 .18757 Mtetra
.912 .914 .807 r
.72506 .18757 .72814 .18983 .73536 .18923 .73176 .17912 Mtetra
.819 .654 .678 r
.73176 .17912 .73536 .18923 .74141 .17197 .7382 .16725 Mtetra
.662 .741 .909 r
.7382 .16725 .74141 .17197 .74837 .16764 .74531 .1647 Mtetra
.987 .806 .573 r
.74531 .1647 .74837 .16764 .7541 .14736 .75094 .14263 Mtetra
.706 .759 .893 r
.75094 .14263 .7541 .14736 .7612 .14509 .75797 .13926 Mtetra
.419 .561 .891 r
.75797 .13926 .7612 .14509 .76917 .15308 .76538 .14041 Mtetra
.651 .532 .705 r
.76538 .14041 .76917 .15308 .77631 .15051 .77238 .1362 Mtetra
.444 .34 .642 r
.13748 .37253 .13993 .39012 .14708 .37587 .14258 .37543 Mtetra
.938 .805 .686 r
.14258 .37543 .14708 .37587 .15347 .36791 .14995 .35935 Mtetra
0 0 .341 r
.14995 .35935 .15347 .36791 .15902 .36718 .1543 .36894 Mtetra
.957 .9 .725 r
.1543 .36894 .15902 .36718 .16514 .36163 .1612 .35671 Mtetra
.657 .687 .866 r
.1612 .35671 .16514 .36163 .17086 .35957 .16693 .35463 Mtetra
.655 .686 .867 r
.16693 .35463 .17086 .35957 .1765 .35847 .17267 .35259 Mtetra
.652 .647 .833 r
.17267 .35259 .1765 .35847 .18236 .35542 .17843 .35047 Mtetra
.658 .687 .866 r
.17843 .35047 .18236 .35542 .18857 .34912 .18421 .34836 Mtetra
.421 .84 .963 r
.18421 .34836 .18857 .34912 .1945 .34548 .18989 .34718 Mtetra
.931 .955 .774 r
.18989 .34718 .1945 .34548 .1995 .35105 .19642 .33805 Mtetra
.559 .458 .696 r
.19642 .33805 .1995 .35105 .2053 .34895 .20207 .3374 Mtetra
.534 .46 .718 r
.20207 .3374 .2053 .34895 .21138 .34425 .20767 .33746 Mtetra
.643 .616 .808 r
.20767 .33746 .21138 .34425 .21721 .34214 .2135 .33535 Mtetra
.711 .645 .782 r
.2135 .33535 .21721 .34214 .22167 .35453 .21953 .33138 Mtetra
.501 .355 .615 r
.21953 .33138 .22167 .35453 .2272 .35622 .22503 .33297 Mtetra
.337 .235 .589 r
.22503 .33297 .2272 .35622 .2324 .36176 .23001 .34047 Mtetra
.578 .419 .63 r
.23001 .34047 .2324 .36176 .2385 .35773 .23591 .33834 Mtetra
.628 .463 .64 r
.23591 .33834 .2385 .35773 .24471 .35251 .24206 .33366 Mtetra
.619 .459 .643 r
.24206 .33366 .24471 .35251 .25099 .34654 .24815 .32963 Mtetra
.3 .247 .629 r
.24815 .32963 .25099 .34654 .25726 .34057 .25336 .33596 Mtetra
.797 .74 .8 r
.25336 .33596 .25726 .34057 .26338 .33652 .25964 .33004 Mtetra
.903 .518 .082 r
.25964 .33004 .26338 .33652 .2694 .33374 .26416 .34556 Mtetra
.387 .039 .248 r
.26416 .34556 .2694 .33374 .27508 .33538 .27018 .34341 Mtetra
.529 .137 .243 r
.27018 .34341 .27508 .33538 .28043 .34176 .27592 .345 Mtetra
.697 .251 .187 r
.27592 .345 .28043 .34176 .28632 .34152 .28139 .35043 Mtetra
.637 .265 .321 r
.28139 .35043 .28632 .34152 .29148 .35144 .28693 .35544 Mtetra
.746 .331 .263 r
.28693 .35544 .29148 .35144 .29784 .34538 .29232 .36313 Mtetra
.219 0 .247 r
.29232 .36313 .29784 .34538 .30361 .34787 .29889 .35506 Mtetra
0 0 0 r
.29889 .35506 .30361 .34787 .3107 .33131 .30553 .34561 Mtetra
.863 .833 .361 r
.30553 .34561 .3107 .33131 .31733 .32117 .31332 .31904 Mtetra
.88 .849 .808 r
.31332 .31904 .31733 .32117 .3241 .3086 .31979 .31137 Mtetra
0 0 0 r
.31979 .31137 .3241 .3086 .32996 .31014 .3259 .30936 Mtetra
.887 .921 .84 r
.3259 .30936 .32996 .31014 .33596 .30983 .33233 .30235 Mtetra
.279 .402 .809 r
.33233 .30235 .33596 .30983 .34232 .30381 .33815 .30535 Mtetra
.969 .915 .697 r
.33815 .30535 .34232 .30381 .34865 .29828 .34494 .29232 Mtetra
.652 .655 .841 r
.34494 .29232 .34865 .29828 .3551 .29057 .35109 .29009 Mtetra
.923 .912 .79 r
.35109 .29009 .3551 .29057 .36162 .28132 .35762 .28123 Mtetra
.781 .98 .908 r
.35762 .28123 .36162 .28132 .36758 .28301 .36392 .27654 Mtetra
.365 .492 .854 r
.36392 .27654 .36758 .28301 .37341 .28793 .3699 .27832 Mtetra
0 0 .279 r
.3699 .27832 .37341 .28793 .37944 .28936 .37531 .29242 Mtetra
.901 .553 .376 r
.37531 .29242 .37944 .28936 .38532 .29487 .38021 .31956 Mtetra
.843 .76 .247 r
.38021 .31956 .38532 .29487 .39225 .27672 .3885 .27254 Mtetra
.476 .667 .946 r
.3885 .27254 .39225 .27672 .39857 .27259 .39466 .27247 Mtetra
.923 .939 .794 r
.39466 .27247 .39857 .27259 .40471 .27322 .40118 .26383 Mtetra
.592 .536 .761 r
.40118 .26383 .40471 .27322 .41078 .27638 .40741 .26249 Mtetra
.401 .351 .687 r
.40741 .26249 .41078 .27638 .41753 .26103 .41349 .26608 Mtetra
.694 .269 .233 r
.41349 .26608 .41753 .26103 .42345 .26988 .41951 .27234 Mtetra
.687 .204 .098 r
.41951 .27234 .42345 .26988 .42947 .27711 .42561 .27773 Mtetra
.282 0 0 r
.42561 .27773 .42947 .27711 .43554 .28494 .43188 .27879 Mtetra
0 0 .483 r
.43188 .27879 .43554 .28494 .44174 .28969 .43797 .28743 Mtetra
.019 .521 .87 r
.43797 .28743 .44174 .28969 .44795 .29609 .4443 .28908 Mtetra
.398 .496 .842 r
.4443 .28908 .44795 .29609 .45436 .29577 .45066 .29073 Mtetra
.657 .705 .882 r
.45066 .29073 .45436 .29577 .46079 .29545 .45714 .28843 Mtetra
.836 .7 .713 r
.45714 .28843 .46079 .29545 .46745 .28411 .4638 .27791 Mtetra
.223 .424 .848 r
.4638 .27791 .46745 .28411 .4739 .28376 .4702 .28097 Mtetra
.493 0 0 r
.4702 .28097 .4739 .28376 .48028 .29064 .4766 .28637 Mtetra
.527 .693 .944 r
.4766 .28637 .48028 .29064 .48682 .28833 .48313 .28577 Mtetra
.964 .782 .609 r
.48313 .28577 .48682 .28833 .49353 .27146 .48994 .26264 Mtetra
.881 .686 .634 r
.48994 .26264 .49353 .27146 .50018 .2556 .49664 .24316 Mtetra
.684 .548 .695 r
.49664 .24316 .50018 .2556 .50677 .24277 .50319 .23766 Mtetra
.883 .756 .717 r
.50319 .23766 .50677 .24277 .51333 .23055 .50977 .22619 Mtetra
0 0 .511 r
.50977 .22619 .51333 .23055 .51985 .22785 .51627 .23343 Mtetra
.872 .502 .342 r
.51627 .23343 .51985 .22785 .5264 .2478 .52281 .25718 Mtetra
.606 .221 .286 r
.52281 .25718 .5264 .2478 .53303 .26115 .52946 .26157 Mtetra
.831 .368 .109 r
.52946 .26157 .53303 .26115 .53978 .28035 .53618 .27316 Mtetra
.153 .341 .799 r
.53618 .27316 .53978 .28035 .54652 .282 .54293 .27764 Mtetra
.932 .775 .664 r
.54293 .27764 .54652 .282 .5532 .27341 .54957 .26127 Mtetra
.807 .623 .653 r
.54957 .26127 .5532 .27341 .55979 .25844 .55618 .24727 Mtetra
.786 .621 .676 r
.55618 .24727 .55979 .25844 .56646 .25127 .5628 .23625 Mtetra
.698 .536 .665 r
.5628 .23625 .56646 .25127 .57304 .23975 .56944 .22863 Mtetra
.568 .499 .738 r
.56944 .22863 .57304 .23975 .57961 .22811 .57619 .22773 Mtetra
.993 .813 .56 r
.57619 .22773 .57961 .22811 .58595 .20667 .58249 .20218 Mtetra
.319 .571 .93 r
.58249 .20218 .58595 .20667 .59279 .21056 .58928 .20361 Mtetra
.752 .68 .782 r
.58928 .20361 .59279 .21056 .59959 .21122 .59594 .19812 Mtetra
0 0 .526 r
.59594 .19812 .59959 .21122 .60679 .22538 .60313 .21298 Mtetra
.203 .248 .686 r
.60313 .21298 .60679 .22538 .61365 .22485 .6102 .22035 Mtetra
.611 .157 0 r
.6102 .22035 .61365 .22485 .62081 .23313 .61742 .23056 Mtetra
.969 .824 .646 r
.61742 .23056 .62081 .23313 .62763 .2292 .62383 .21356 Mtetra
.7 .534 .659 r
.62383 .21356 .62763 .2292 .63436 .22282 .6305 .20549 Mtetra
.061 .098 .587 r
.6305 .20549 .63436 .22282 .64124 .22005 .63799 .21947 Mtetra
.831 .988 .868 r
.63799 .21947 .64124 .22005 .64815 .21759 .64477 .21333 Mtetra
0 0 .528 r
.64477 .21333 .64815 .21759 .65507 .21513 .65214 .22142 Mtetra
.755 .333 .247 r
.65214 .22142 .65507 .21513 .66209 .21457 .65971 .23233 Mtetra
0 0 .144 r
.65971 .23233 .66209 .21457 .66891 .20904 .66588 .21143 Mtetra
.529 .858 .576 r
.66588 .21143 .66891 .20904 .67588 .20656 .67269 .20523 Mtetra
.916 .946 .805 r
.67269 .20523 .67588 .20656 .68256 .19814 .6794 .19677 Mtetra
.575 .906 .979 r
.6794 .19677 .68256 .19814 .68976 .19956 .68641 .19427 Mtetra
.795 .76 .82 r
.68641 .19427 .68976 .19956 .69695 .20011 .69324 .18832 Mtetra
.704 .572 .704 r
.69324 .18832 .69695 .20011 .70329 .18575 .70006 .18208 Mtetra
.944 .826 .697 r
.70006 .18208 .70329 .18575 .7105 .18617 .70646 .16886 Mtetra
.551 .428 .666 r
.70646 .16886 .7105 .18617 .71743 .1817 .71362 .16825 Mtetra
.424 .382 .708 r
.71362 .16825 .71743 .1817 .72506 .18757 .72106 .17159 Mtetra
.528 .424 .68 r
.72106 .17159 .72506 .18757 .73176 .17912 .72835 .17194 Mtetra
.647 .635 .825 r
.72835 .17194 .73176 .17912 .7382 .16725 .73547 .16939 Mtetra
0 0 0 r
.73547 .16939 .7382 .16725 .74531 .1647 .7426 .16682 Mtetra
.979 .856 .47 r
.7426 .16682 .74531 .1647 .75094 .14263 .74824 .14423 Mtetra
.555 .89 .64 r
.74824 .14423 .75094 .14263 .75797 .13926 .75511 .13843 Mtetra
.542 .917 .941 r
.75511 .13843 .75797 .13926 .76538 .14041 .76222 .13564 Mtetra
.815 .794 .832 r
.76222 .13564 .76538 .14041 .77238 .1362 .76907 .12944 Mtetra
.671 .594 .761 r
.13389 .36442 .13748 .37253 .14258 .37543 .13972 .36125 Mtetra
.324 .286 .661 r
.13972 .36125 .14258 .37543 .14995 .35935 .14463 .36584 Mtetra
.784 .434 .395 r
.14463 .36584 .14995 .35935 .1543 .36894 .14869 .37798 Mtetra
.835 .907 .498 r
.14869 .37798 .1543 .36894 .1612 .35671 .15588 .36354 Mtetra
0 0 0 r
.15588 .36354 .1612 .35671 .16693 .35463 .16201 .35823 Mtetra
.937 .967 .714 r
.16201 .35823 .16693 .35463 .17267 .35259 .16875 .34751 Mtetra
0 .179 .706 r
.16875 .34751 .17267 .35259 .17843 .35047 .1738 .3518 Mtetra
.696 .21 .09 r
.1738 .3518 .17843 .35047 .18421 .34836 .17886 .35646 Mtetra
.148 0 .023 r
.17886 .35646 .18421 .34836 .18989 .34718 .18486 .35259 Mtetra
.89 .962 .631 r
.18486 .35259 .18989 .34718 .19642 .33805 .19166 .34119 Mtetra
0 0 0 r
.19166 .34119 .19642 .33805 .20207 .3374 .19753 .33856 Mtetra
.418 .863 .802 r
.19753 .33856 .20207 .3374 .20767 .33746 .2034 .33604 Mtetra
.872 .871 .833 r
.2034 .33604 .20767 .33746 .2135 .33535 .20971 .32925 Mtetra
.721 .669 .798 r
.20971 .32925 .2135 .33535 .21953 .33138 .21574 .32527 Mtetra
.511 .579 .86 r
.21574 .32527 .21953 .33138 .22503 .33297 .22139 .32532 Mtetra
.637 .591 .786 r
.22139 .32532 .22503 .33297 .23001 .34047 .22727 .32318 Mtetra
.588 .445 .654 r
.22727 .32318 .23001 .34047 .23591 .33834 .23316 .32103 Mtetra
.401 .314 .642 r
.23316 .32103 .23591 .33834 .24206 .33366 .23849 .32513 Mtetra
.275 .362 .772 r
.23849 .32513 .24206 .33366 .24815 .32963 .24393 .32846 Mtetra
.856 .415 .159 r
.24393 .32846 .24815 .32963 .25336 .33596 .24882 .33851 Mtetra
.702 .971 .747 r
.24882 .33851 .25336 .33596 .25964 .33004 .25511 .33279 Mtetra
.667 .199 .133 r
.25511 .33279 .25964 .33004 .26416 .34556 .26055 .33725 Mtetra
.063 .235 .729 r
.26055 .33725 .26416 .34556 .27018 .34341 .26597 .34238 Mtetra
.724 .196 0 r
.26597 .34238 .27018 .34341 .27592 .345 .27138 .34817 Mtetra
0 0 0 r
.27138 .34817 .27592 .345 .28139 .35043 .27745 .346 Mtetra
.574 .092 0 r
.27745 .346 .28139 .35043 .28693 .35544 .28288 .35252 Mtetra
0 .206 .646 r
.28288 .35252 .28693 .35544 .29232 .36313 .28857 .35613 Mtetra
.527 .563 .835 r
.28857 .35613 .29232 .36313 .29889 .35506 .29456 .35604 Mtetra
.974 .84 .648 r
.29456 .35604 .29889 .35506 .30553 .34561 .30191 .33708 Mtetra
.898 .686 .606 r
.30191 .33708 .30553 .34561 .31332 .31904 .30994 .30748 Mtetra
.816 .628 .649 r
.30994 .30748 .31332 .31904 .31979 .31137 .31695 .29173 Mtetra
.236 .185 .595 r
.31695 .29173 .31979 .31137 .3259 .30936 .32231 .30079 Mtetra
.834 .666 .674 r
.32231 .30079 .3259 .30936 .33233 .30235 .32916 .28727 Mtetra
.45 .37 .674 r
.32916 .28727 .33233 .30235 .33815 .30535 .33499 .28978 Mtetra
.645 .495 .666 r
.33499 .28978 .33815 .30535 .34494 .29232 .34128 .28516 Mtetra
.555 .57 .824 r
.34128 .28516 .34494 .29232 .35109 .29009 .34734 .28464 Mtetra
.687 .689 .846 r
.34734 .28464 .35109 .29009 .35762 .28123 .35355 .28175 Mtetra
.457 .887 .859 r
.35355 .28175 .35762 .28123 .36392 .27654 .35976 .27923 Mtetra
.391 0 0 r
.35976 .27923 .36392 .27654 .3699 .27832 .36581 .27998 Mtetra
.719 .234 .092 r
.36581 .27998 .3699 .27832 .37531 .29242 .37162 .28594 Mtetra
.771 .686 .77 r
.37162 .28594 .37531 .29242 .38021 .31956 .37806 .27986 Mtetra
.649 .436 .581 r
.37806 .27986 .38021 .31956 .3885 .27254 .38482 .26641 Mtetra
.44 .55 .871 r
.38482 .26641 .3885 .27254 .39466 .27247 .39094 .26727 Mtetra
.539 .642 .9 r
.39094 .26727 .39466 .27247 .40118 .26383 .39714 .26679 Mtetra
.645 .926 .649 r
.39714 .26679 .40118 .26383 .40741 .26249 .40359 .26042 Mtetra
.934 .567 .283 r
.40359 .26042 .40741 .26249 .41349 .26608 .40888 .28529 Mtetra
.417 .115 .342 r
.40888 .28529 .41349 .26608 .41951 .27234 .41528 .28206 Mtetra
.1 0 .073 r
.41528 .28206 .41951 .27234 .42561 .27773 .42179 .27596 Mtetra
.73 .205 0 r
.42179 .27596 .42561 .27773 .43188 .27879 .42788 .28324 Mtetra
.749 .325 .244 r
.42788 .28324 .43188 .27879 .43797 .28743 .43398 .29177 Mtetra
0 0 0 r
.43398 .29177 .43797 .28743 .4443 .28908 .4405 .2875 Mtetra
.876 .909 .848 r
.4405 .2875 .4443 .28908 .45066 .29073 .44708 .28064 Mtetra
.721 .598 .719 r
.44708 .28064 .45066 .29073 .45714 .28843 .45365 .2745 Mtetra
.339 .313 .683 r
.45365 .2745 .45714 .28843 .4638 .27791 .45998 .27948 Mtetra
.749 .987 .772 r
.45998 .27948 .4638 .27791 .4702 .28097 .46657 .27325 Mtetra
.731 .647 .765 r
.46657 .27325 .4702 .28097 .4766 .28637 .47315 .26804 Mtetra
.655 .488 .646 r
.47315 .26804 .4766 .28637 .48313 .28577 .47974 .2618 Mtetra
.622 .444 .62 r
.47974 .2618 .48313 .28577 .48994 .26264 .48632 .25608 Mtetra
.813 .706 .747 r
.48632 .25608 .48994 .26264 .49664 .24316 .49293 .24789 Mtetra
.8 .909 .511 r
.49293 .24789 .49664 .24316 .50319 .23766 .49956 .23602 Mtetra
.575 .879 .993 r
.49956 .23602 .50319 .23766 .50977 .22619 .50611 .23398 Mtetra
.847 .483 .363 r
.50611 .23398 .50977 .22619 .51627 .23343 .51257 .25655 Mtetra
.668 .35 .427 r
.51257 .25655 .51627 .23343 .52281 .25718 .51918 .26958 Mtetra
.546 .189 .313 r
.51918 .26958 .52281 .25718 .52946 .26157 .52586 .27199 Mtetra
.621 .244 .307 r
.52586 .27199 .52946 .26157 .53618 .27316 .53259 .27724 Mtetra
.789 .359 .23 r
.53259 .27724 .53618 .27316 .54293 .27764 .5394 .28838 Mtetra
.732 .757 .25 r
.5394 .28838 .54293 .27764 .54957 .26127 .54605 .26639 Mtetra
.71 .859 .44 r
.54605 .26639 .54957 .26127 .55618 .24727 .55273 .25481 Mtetra
.674 .78 .306 r
.55273 .25481 .55618 .24727 .5628 .23625 .55935 .23971 Mtetra
.919 .931 .56 r
.55935 .23971 .5628 .23625 .56944 .22863 .56594 .22551 Mtetra
.868 .851 .824 r
.56594 .22551 .56944 .22863 .57619 .22773 .5726 .21824 Mtetra
.877 .68 .633 r
.5726 .21824 .57619 .22773 .58249 .20218 .57905 .19949 Mtetra
.639 .842 .978 r
.57905 .19949 .58249 .20218 .58928 .20361 .58578 .19717 Mtetra
.116 .344 .811 r
.58578 .19717 .58928 .20361 .59594 .19812 .59267 .20162 Mtetra
.744 .282 .153 r
.59267 .20162 .59594 .19812 .60313 .21298 .59971 .21002 Mtetra
.452 .747 .992 r
.59971 .21002 .60313 .21298 .6102 .22035 .60658 .20955 Mtetra
.301 .34 .736 r
.60658 .20955 .6102 .22035 .61742 .23056 .61362 .21432 Mtetra
.424 .352 .672 r
.61362 .21432 .61742 .23056 .62383 .21356 .62069 .21818 Mtetra
.168 0 0 r
.62069 .21818 .62383 .21356 .6305 .20549 .62759 .21571 Mtetra
.687 .302 .311 r
.62759 .21571 .6305 .20549 .63799 .21947 .63491 .22457 Mtetra
.011 0 0 r
.63491 .22457 .63799 .21947 .64477 .21333 .6418 .22013 Mtetra
.703 .28 .239 r
.6418 .22013 .64477 .21333 .65214 .22142 .6492 .22834 Mtetra
.284 0 .07 r
.6492 .22834 .65214 .22142 .65971 .23233 .65622 .22586 Mtetra
.879 .74 .704 r
.65622 .22586 .65971 .23233 .66588 .21143 .66281 .21372 Mtetra
.199 0 0 r
.66281 .21372 .66588 .21143 .67269 .20523 .66993 .21318 Mtetra
.679 .74 .236 r
.66993 .21318 .67269 .20523 .6794 .19677 .67619 .19484 Mtetra
.767 .933 .939 r
.67619 .19484 .6794 .19677 .68641 .19427 .68312 .1904 Mtetra
.9 .831 .77 r
.68312 .1904 .68641 .19427 .69324 .18832 .68978 .18093 Mtetra
.811 .7 .742 r
.68978 .18093 .69324 .18832 .70006 .18208 .69648 .17252 Mtetra
.827 .665 .682 r
.69648 .17252 .70006 .18208 .70646 .16886 .70297 .16058 Mtetra
.638 .599 .793 r
.70297 .16058 .70646 .16886 .71362 .16825 .71001 .15803 Mtetra
.268 .332 .745 r
.71001 .15803 .71362 .16825 .72106 .17159 .71757 .16337 Mtetra
.743 .654 .761 r
.71757 .16337 .72106 .17159 .72835 .17194 .72444 .15746 Mtetra
.526 .436 .696 r
.72444 .15746 .72835 .17194 .73547 .16939 .73175 .1578 Mtetra
.703 .576 .709 r
.73175 .1578 .73547 .16939 .7426 .16682 .73863 .15171 Mtetra
.781 .586 .636 r
.73863 .15171 .7426 .16682 .74824 .14423 .74492 .13778 Mtetra
.453 .557 .871 r
.74492 .13778 .74824 .14423 .75511 .13843 .75231 .13865 Mtetra
.902 .983 .721 r
.75231 .13865 .75511 .13843 .76222 .13564 .75893 .12922 Mtetra
.709 .691 .831 r
.75893 .12922 .76222 .13564 .76907 .12944 .76597 .12529 Mtetra
.429 .451 .782 r
.13035 .35585 .13389 .36442 .13972 .36125 .13561 .35734 Mtetra
.681 .177 0 r
.13561 .35734 .13972 .36125 .14463 .36584 .14033 .36344 Mtetra
.427 0 0 r
.14033 .36344 .14463 .36584 .14869 .37798 .14543 .36672 Mtetra
.818 .63 .648 r
.14543 .36672 .14869 .37798 .15588 .36354 .15293 .34984 Mtetra
.661 .517 .678 r
.15293 .34984 .15588 .36354 .16201 .35823 .15898 .34512 Mtetra
.559 .457 .694 r
.15898 .34512 .16201 .35823 .16875 .34751 .16458 .34443 Mtetra
.026 .479 .878 r
.16458 .34443 .16875 .34751 .1738 .3518 .16991 .34627 Mtetra
.829 .709 .732 r
.16991 .34627 .1738 .3518 .17886 .35646 .17648 .33712 Mtetra
.636 .468 .639 r
.17648 .33712 .17886 .35646 .18486 .35259 .1826 .33198 Mtetra
.57 .415 .632 r
.1826 .33198 .18486 .35259 .19166 .34119 .18836 .33025 Mtetra
.614 .517 .721 r
.18836 .33025 .19166 .34119 .19753 .33856 .19417 .32812 Mtetra
.617 .527 .729 r
.19417 .32812 .19753 .33856 .2034 .33604 .2 .32598 Mtetra
.487 .455 .748 r
.2 .32598 .2034 .33604 .20971 .32925 .20553 .32688 Mtetra
.818 .84 .865 r
.20553 .32688 .20971 .32925 .21574 .32527 .21169 .32172 Mtetra
.75 .779 .876 r
.21169 .32172 .21574 .32527 .22139 .32532 .21772 .31798 Mtetra
0 .097 .653 r
.21772 .31798 .22139 .32532 .22727 .32318 .22281 .32397 Mtetra
.045 0 0 r
.22281 .32397 .22727 .32318 .23316 .32103 .22855 .32364 Mtetra
.812 .413 .296 r
.22855 .32364 .23316 .32103 .23849 .32513 .23331 .33401 Mtetra
.329 0 .152 r
.23331 .33401 .23849 .32513 .24393 .32846 .23927 .33186 Mtetra
.766 .354 .27 r
.23927 .33186 .24393 .32846 .24882 .33851 .24433 .34002 Mtetra
.441 0 0 r
.24433 .34002 .24882 .33851 .25511 .33279 .25001 .34158 Mtetra
.597 .22 .297 r
.25001 .34158 .25511 .33279 .26055 .33725 .25555 .34513 Mtetra
0 0 0 r
.25555 .34513 .26055 .33725 .26597 .34238 .26191 .33918 Mtetra
.514 .742 .978 r
.26191 .33918 .26597 .34238 .27138 .34817 .26785 .33849 Mtetra
.546 .503 .759 r
.26785 .33849 .27138 .34817 .27745 .346 .27377 .3382 Mtetra
.543 .545 .807 r
.27377 .3382 .27745 .346 .28288 .35252 .27971 .33791 Mtetra
.544 .437 .683 r
.27971 .33791 .28288 .35252 .28857 .35613 .28568 .33763 Mtetra
.652 .484 .645 r
.28568 .33763 .28857 .35613 .29456 .35604 .29208 .33164 Mtetra
.684 .487 .614 r
.29208 .33164 .29456 .35604 .30191 .33708 .29886 .32044 Mtetra
.764 .569 .634 r
.29886 .32044 .30191 .33708 .30994 .30748 .30588 .30562 Mtetra
.914 .839 .756 r
.30588 .30562 .30994 .30748 .31695 .29173 .31254 .29538 Mtetra
.752 .956 .651 r
.31254 .29538 .31695 .29173 .32231 .30079 .31903 .28757 Mtetra
.619 .498 .693 r
.31903 .28757 .32231 .30079 .32916 .28727 .32519 .28474 Mtetra
0 .381 .778 r
.32519 .28474 .32916 .28727 .33499 .28978 .33104 .2872 Mtetra
.844 .843 .843 r
.33104 .2872 .33499 .28978 .34128 .28516 .33744 .28102 Mtetra
.523 .69 .944 r
.33744 .28102 .34128 .28516 .34734 .28464 .3435 .2805 Mtetra
.663 .742 .909 r
.3435 .2805 .34734 .28464 .35355 .28175 .34969 .27825 Mtetra
.783 .801 .867 r
.34969 .27825 .35355 .28175 .35976 .27923 .35601 .27364 Mtetra
.74 .703 .816 r
.35601 .27364 .35976 .27923 .36581 .27998 .36233 .26927 Mtetra
0 0 .314 r
.36233 .26927 .36581 .27998 .37162 .28594 .36771 .28368 Mtetra
.933 .814 .704 r
.36771 .28368 .37162 .28594 .37806 .27986 .37452 .27017 Mtetra
.748 .614 .711 r
.37452 .27017 .37806 .27986 .38482 .26641 .38101 .26285 Mtetra
0 .206 .687 r
.38101 .26285 .38482 .26641 .39094 .26727 .38699 .26703 Mtetra
.277 0 0 r
.38699 .26703 .39094 .26727 .39714 .26679 .39311 .2686 Mtetra
.973 .922 .674 r
.39311 .2686 .39714 .26679 .40359 .26042 .39989 .25492 Mtetra
.861 .451 0 r
.39989 .25492 .40359 .26042 .40888 .28529 .40553 .26996 Mtetra
.077 .116 .599 r
.40553 .26996 .40888 .28529 .41528 .28206 .41142 .28016 Mtetra
.932 .847 .737 r
.41142 .28016 .41528 .28206 .42179 .27596 .41813 .26877 Mtetra
.255 .403 .819 r
.41813 .26877 .42179 .27596 .42788 .28324 .42435 .27195 Mtetra
.505 .455 .735 r
.42435 .27195 .42788 .28324 .43398 .29177 .43067 .27266 Mtetra
.545 .409 .647 r
.43067 .27266 .43398 .29177 .4405 .2875 .43706 .2722 Mtetra
.252 .238 .649 r
.43706 .2722 .4405 .2875 .44708 .28064 .44327 .27943 Mtetra
.587 .903 .983 r
.44327 .27943 .44708 .28064 .45365 .2745 .44976 .2771 Mtetra
.962 .94 .642 r
.44976 .2771 .45365 .2745 .45998 .27948 .45653 .26336 Mtetra
.495 .396 .671 r
.45653 .26336 .45998 .27948 .46657 .27325 .46295 .26474 Mtetra
.727 .629 .749 r
.46295 .26474 .46657 .27325 .47315 .26804 .46954 .25926 Mtetra
.631 .575 .773 r
.46954 .25926 .47315 .26804 .47974 .2618 .47607 .25691 Mtetra
.881 .762 .726 r
.47607 .25691 .47974 .2618 .48632 .25608 .48274 .2459 Mtetra
.551 .503 .755 r
.48274 .2459 .48632 .25608 .49293 .24789 .48926 .24547 Mtetra
.935 .839 .725 r
.48926 .24547 .49293 .24789 .49956 .23602 .49592 .23349 Mtetra
.188 .62 .944 r
.49592 .23349 .49956 .23602 .50611 .23398 .50246 .23448 Mtetra
.74 .227 0 r
.50246 .23448 .50611 .23398 .51257 .25655 .50899 .24174 Mtetra
.24 .239 .656 r
.50899 .24174 .51257 .25655 .51918 .26958 .51559 .24925 Mtetra
0 0 .517 r
.51559 .24925 .51918 .26958 .52586 .27199 .52223 .26677 Mtetra
.73 .296 0 r
.52223 .26677 .52586 .27199 .53259 .27724 .52897 .27931 Mtetra
.983 .907 .604 r
.52897 .27931 .53259 .27724 .5394 .28838 .53569 .26245 Mtetra
.728 .513 .599 r
.53569 .26245 .5394 .28838 .54605 .26639 .54235 .24508 Mtetra
.575 .421 .636 r
.54235 .24508 .54605 .26639 .55273 .25481 .54909 .24288 Mtetra
.689 .56 .704 r
.54909 .24288 .55273 .25481 .55935 .23971 .55581 .2373 Mtetra
.938 .856 .734 r
.55581 .2373 .55935 .23971 .56594 .22551 .56246 .22583 Mtetra
.982 .899 .65 r
.56246 .22583 .56594 .22551 .5726 .21824 .56904 .21077 Mtetra
.886 .711 .659 r
.56904 .21077 .5726 .21824 .57905 .19949 .57556 .19498 Mtetra
.509 .675 .939 r
.57556 .19498 .57905 .19949 .58578 .19717 .58234 .19458 Mtetra
.924 .862 .76 r
.58234 .19458 .58578 .19717 .59267 .20162 .58893 .18451 Mtetra
.089 .116 .594 r
.58893 .18451 .59267 .20162 .59971 .21002 .59604 .19717 Mtetra
.41 .377 .712 r
.59604 .19717 .59971 .21002 .60658 .20955 .60299 .20049 Mtetra
.37 .422 .785 r
.60299 .20049 .60658 .20955 .61362 .21432 .60998 .20337 Mtetra
.211 .279 .716 r
.60998 .20337 .61362 .21432 .62069 .21818 .61711 .20969 Mtetra
.447 .485 .806 r
.61711 .20969 .62069 .21818 .62759 .21571 .62414 .21114 Mtetra
.625 .174 0 r
.62414 .21114 .62759 .21571 .63491 .22457 .63153 .22197 Mtetra
.774 .891 .927 r
.63153 .22197 .63491 .22457 .6418 .22013 .63844 .21751 Mtetra
.484 0 0 r
.63844 .21751 .6418 .22013 .6492 .22834 .64577 .22376 Mtetra
.659 .747 .915 r
.64577 .22376 .6492 .22834 .65622 .22586 .6528 .22126 Mtetra
.52 .684 .941 r
.6528 .22126 .65622 .22586 .66281 .21372 .65993 .22071 Mtetra
.57 .139 .183 r
.65993 .22071 .66281 .21372 .66993 .21318 .66727 .22409 Mtetra
0 0 0 r
.66727 .22409 .66993 .21318 .67619 .19484 .67336 .20102 Mtetra
.1 0 0 r
.67336 .20102 .67619 .19484 .68312 .1904 .68032 .19654 Mtetra
0 0 0 r
.68032 .19654 .68312 .1904 .68978 .18093 .68682 .1831 Mtetra
.392 0 0 r
.68682 .1831 .68978 .18093 .69648 .17252 .69411 .18452 Mtetra
0 0 0 r
.69411 .18452 .69648 .17252 .70297 .16058 .70006 .16235 Mtetra
.369 0 0 r
.70006 .16235 .70297 .16058 .71001 .15803 .70737 .16377 Mtetra
0 0 0 r
.70737 .16377 .71001 .15803 .71757 .16337 .71405 .15468 Mtetra
.681 .613 .773 r
.71405 .15468 .71757 .16337 .72444 .15746 .72106 .15076 Mtetra
.755 .7 .8 r
.72106 .15076 .72444 .15746 .73175 .1578 .72797 .14533 Mtetra
.653 .536 .708 r
.72797 .14533 .73175 .1578 .73863 .15171 .73498 .14109 Mtetra
.833 .654 .661 r
.73498 .14109 .73863 .15171 .74492 .13778 .74131 .12751 Mtetra
.455 .451 .764 r
.74131 .12751 .74492 .13778 .75231 .13865 .74877 .12931 Mtetra
.577 .543 .78 r
.74877 .12931 .75231 .13865 .75893 .12922 .75604 .12818 Mtetra
.837 .987 .867 r
.75604 .12818 .75893 .12922 .76597 .12529 .76292 .12187 Mtetra
.971 .913 .691 r
.12529 .35936 .13035 .35585 .13561 .35734 .13249 .34529 Mtetra
.503 .432 .709 r
.13249 .34529 .13561 .35734 .14033 .36344 .13785 .34602 Mtetra
.545 .413 .651 r
.13785 .34602 .14033 .36344 .14543 .36672 .14337 .34559 Mtetra
.549 .397 .628 r
.14337 .34559 .14543 .36672 .15293 .34984 .14895 .34483 Mtetra
.244 .492 .894 r
.14895 .34483 .15293 .34984 .15898 .34512 .15424 .34668 Mtetra
.589 .946 .827 r
.15424 .34668 .15898 .34512 .16458 .34443 .16019 .34302 Mtetra
.905 .834 .766 r
.16019 .34302 .16458 .34443 .16991 .34627 .16683 .33336 Mtetra
.471 .401 .697 r
.16683 .33336 .16991 .34627 .17648 .33712 .17221 .33489 Mtetra
.509 .798 .998 r
.17221 .33489 .17648 .33712 .1826 .33198 .17788 .33395 Mtetra
.833 .444 .313 r
.17788 .33395 .1826 .33198 .18836 .33025 .18225 .34528 Mtetra
.234 0 .213 r
.18225 .34528 .18836 .33025 .19417 .32812 .18851 .33933 Mtetra
.37 .015 .225 r
.18851 .33933 .19417 .32812 .2 .32598 .19437 .33719 Mtetra
0 0 0 r
.19437 .33719 .2 .32598 .20553 .32688 .20083 .32933 Mtetra
.045 0 0 r
.20083 .32933 .20553 .32688 .21169 .32172 .20663 .32797 Mtetra
.007 0 0 r
.20663 .32797 .21169 .32172 .21772 .31798 .21271 .32397 Mtetra
.591 .175 .223 r
.21271 .32397 .21772 .31798 .22281 .32397 .21811 .32697 Mtetra
0 0 0 r
.21811 .32697 .22281 .32397 .22855 .32364 .22404 .32481 Mtetra
.841 .436 .274 r
.22404 .32481 .22855 .32364 .23331 .33401 .22873 .33597 Mtetra
0 0 0 r
.22873 .33597 .23331 .33401 .23927 .33186 .2347 .33381 Mtetra
.856 .476 .327 r
.2347 .33381 .23927 .33186 .24433 .34002 .23923 .34795 Mtetra
.434 .034 .18 r
.23923 .34795 .24433 .34002 .25001 .34158 .24509 .34773 Mtetra
.791 .427 .366 r
.24509 .34773 .25001 .34158 .25555 .34513 .24986 .36042 Mtetra
0 0 0 r
.24986 .36042 .25555 .34513 .26191 .33918 .2571 .34468 Mtetra
.863 .95 .594 r
.2571 .34468 .26191 .33918 .26785 .33849 .26396 .33298 Mtetra
.653 .673 .857 r
.26396 .33298 .26785 .33849 .27377 .3382 .27004 .33079 Mtetra
.787 .667 .731 r
.27004 .33079 .27377 .3382 .27971 .33791 .27658 .32294 Mtetra
.637 .495 .672 r
.27658 .32294 .27971 .33791 .28568 .33763 .28282 .31889 Mtetra
.674 .498 .64 r
.28282 .31889 .28568 .33763 .29208 .33164 .28934 .31122 Mtetra
.662 .483 .632 r
.28934 .31122 .29208 .33164 .29886 .32044 .29584 .30374 Mtetra
.547 .422 .662 r
.29584 .30374 .29886 .32044 .30588 .30562 .30183 .30325 Mtetra
.429 .763 .996 r
.30183 .30325 .30588 .30562 .31254 .29538 .30784 .30278 Mtetra
.903 .912 .514 r
.30784 .30278 .31254 .29538 .31903 .28757 .31496 .2862 Mtetra
.885 .892 .831 r
.31496 .2862 .31903 .28757 .32519 .28474 .32142 .27902 Mtetra
.448 .572 .886 r
.32142 .27902 .32519 .28474 .33104 .2872 .32738 .27964 Mtetra
.659 .611 .789 r
.32738 .27964 .33104 .2872 .33744 .28102 .33357 .27687 Mtetra
.844 .771 .781 r
.33357 .27687 .33744 .28102 .3435 .2805 .34007 .2692 Mtetra
.576 .494 .726 r
.34007 .2692 .3435 .2805 .34969 .27825 .34618 .26809 Mtetra
.667 .564 .73 r
.34618 .26809 .34969 .27825 .35601 .27364 .35247 .26428 Mtetra
.062 .205 .701 r
.35247 .26428 .35601 .27364 .36233 .26927 .35822 .27039 Mtetra
.811 .363 .175 r
.35822 .27039 .36233 .26927 .36771 .28368 .36385 .27983 Mtetra
.93 .757 .645 r
.36385 .27983 .36771 .28368 .37452 .27017 .37099 .26027 Mtetra
0 .09 .632 r
.37099 .26027 .37452 .27017 .38101 .26285 .37675 .26831 Mtetra
.199 0 0 r
.37675 .26831 .38101 .26285 .38699 .26703 .38304 .26602 Mtetra
.244 .736 .917 r
.38304 .26602 .38699 .26703 .39311 .2686 .38926 .26565 Mtetra
.932 .792 .683 r
.38926 .26565 .39311 .2686 .39989 .25492 .39613 .25054 Mtetra
.758 .761 .855 r
.39613 .25054 .39989 .25492 .40553 .26996 .40252 .24623 Mtetra
.542 .386 .619 r
.40252 .24623 .40553 .26996 .41142 .28016 .40878 .2457 Mtetra
.565 .378 .587 r
.40878 .2457 .41142 .28016 .41813 .26877 .41514 .24274 Mtetra
.011 0 .493 r
.41514 .24274 .41813 .26877 .42435 .27195 .42078 .26191 Mtetra
.513 .482 .759 r
.42078 .26191 .42435 .27195 .43067 .27266 .42711 .2623 Mtetra
.408 .411 .751 r
.42711 .2623 .43067 .27266 .43706 .2722 .4334 .26475 Mtetra
.002 .229 .739 r
.4334 .26475 .43706 .2722 .44327 .27943 .43964 .27039 Mtetra
.476 .483 .785 r
.43964 .27039 .44327 .27943 .44976 .2771 .44605 .27138 Mtetra
.873 .737 .709 r
.44605 .27138 .44976 .2771 .45653 .26336 .4528 .25947 Mtetra
.874 .798 .771 r
.4528 .25947 .45653 .26336 .46295 .26474 .45945 .2506 Mtetra
.686 .534 .675 r
.45945 .2506 .46295 .26474 .46954 .25926 .46604 .24419 Mtetra
.637 .496 .675 r
.46604 .24419 .46954 .25926 .47607 .25691 .47259 .24003 Mtetra
.691 .519 .65 r
.47259 .24003 .47607 .25691 .48274 .2459 .47921 .23192 Mtetra
.645 .511 .685 r
.47921 .23192 .48274 .2459 .48926 .24547 .48577 .22767 Mtetra
.38 .305 .647 r
.48577 .22767 .48926 .24547 .49592 .23349 .49224 .23291 Mtetra
.275 .771 .892 r
.49224 .23291 .49592 .23349 .50246 .23448 .49881 .23198 Mtetra
.371 .733 .989 r
.49881 .23198 .50246 .23448 .50899 .24174 .50539 .23186 Mtetra
0 0 .407 r
.50539 .23186 .50899 .24174 .51559 .24925 .51194 .24598 Mtetra
.76 .277 0 r
.51194 .24598 .51559 .24925 .52223 .26677 .51859 .25646 Mtetra
.74 .609 .712 r
.51859 .25646 .52223 .26677 .52897 .27931 .52531 .24926 Mtetra
.536 .367 .599 r
.52531 .24926 .52897 .27931 .53569 .26245 .53203 .24886 Mtetra
.771 .592 .656 r
.53203 .24886 .53569 .26245 .54235 .24508 .53873 .23682 Mtetra
.798 .669 .722 r
.53873 .23682 .54235 .24508 .54909 .24288 .54543 .228 Mtetra
.65 .508 .677 r
.54543 .228 .54909 .24288 .55581 .2373 .55215 .22319 Mtetra
.638 .507 .687 r
.55215 .22319 .55581 .2373 .56246 .22583 .55889 .2192 Mtetra
.858 .723 .713 r
.55889 .2192 .56246 .22583 .56904 .21077 .56553 .20811 Mtetra
.956 .827 .677 r
.56553 .20811 .56904 .21077 .57556 .19498 .5721 .1932 Mtetra
.857 .928 .874 r
.5721 .1932 .57556 .19498 .58234 .19458 .57879 .18698 Mtetra
.583 .584 .819 r
.57879 .18698 .58234 .19458 .58893 .18451 .58557 .18582 Mtetra
.743 .238 .023 r
.58557 .18582 .58893 .18451 .59604 .19717 .59258 .1937 Mtetra
.251 .599 .951 r
.59258 .1937 .59604 .19717 .60299 .20049 .59949 .19499 Mtetra
0 .089 .64 r
.59949 .19499 .60299 .20049 .60998 .20337 .6066 .20235 Mtetra
.186 .7 .89 r
.6066 .20235 .60998 .20337 .61711 .20969 .61356 .20219 Mtetra
.276 .412 .819 r
.61356 .20219 .61711 .20969 .62414 .21114 .62065 .20563 Mtetra
0 0 .497 r
.62065 .20563 .62414 .21114 .63153 .22197 .628 .21536 Mtetra
.595 .629 .854 r
.628 .21536 .63153 .22197 .63844 .21751 .63502 .21395 Mtetra
.769 .836 .903 r
.63502 .21395 .63844 .21751 .64577 .22376 .64195 .20949 Mtetra
.426 .374 .697 r
.64195 .20949 .64577 .22376 .6528 .22126 .6492 .21278 Mtetra
.328 .416 .8 r
.6492 .21278 .6528 .22126 .65993 .22071 .6565 .21608 Mtetra
0 .254 .76 r
.6565 .21608 .65993 .22071 .66727 .22409 .66394 .22143 Mtetra
.967 .844 .668 r
.66394 .22143 .66727 .22409 .67336 .20102 .67045 .20624 Mtetra
.857 .854 .398 r
.67045 .20624 .67336 .20102 .68032 .19654 .67675 .18798 Mtetra
.86 .694 .675 r
.67675 .18798 .68032 .19654 .68682 .1831 .68326 .17447 Mtetra
.699 .624 .769 r
.68326 .17447 .68682 .1831 .69411 .18452 .69022 .16996 Mtetra
.779 .589 .643 r
.69022 .16996 .69411 .18452 .70006 .16235 .69669 .15665 Mtetra
.543 .64 .897 r
.69669 .15665 .70006 .16235 .70737 .16377 .70388 .15602 Mtetra
.8 .69 .743 r
.70388 .15602 .70737 .16377 .71405 .15468 .71064 .14795 Mtetra
.767 .704 .793 r
.71064 .14795 .71405 .15468 .72106 .15076 .71753 .14209 Mtetra
.814 .676 .711 r
.71753 .14209 .72106 .15076 .72797 .14533 .72416 .13231 Mtetra
.195 .238 .68 r
.72416 .13231 .72797 .14533 .73498 .14109 .73205 .14072 Mtetra
.405 .856 .886 r
.73205 .14072 .73498 .14109 .74131 .12751 .73924 .13851 Mtetra
.12 0 .157 r
.73924 .13851 .74131 .12751 .74877 .12931 .74599 .13026 Mtetra
.891 .971 .659 r
.74599 .13026 .74877 .12931 .75604 .12818 .75257 .11986 Mtetra
.578 .568 .807 r
.75257 .11986 .75604 .12818 .76292 .12187 .75987 .11873 Mtetra
.793 .676 .736 r
.12147 .35279 .12529 .35936 .13249 .34529 .12789 .34504 Mtetra
.41 .85 .93 r
.12789 .34504 .13249 .34529 .13785 .34602 .13353 .34361 Mtetra
.815 .831 .862 r
.13353 .34361 .13785 .34602 .14337 .34559 .13962 .33854 Mtetra
0 0 .567 r
.13962 .33854 .14337 .34559 .14895 .34483 .14435 .34489 Mtetra
.817 .376 .19 r
.14435 .34489 .14895 .34483 .15424 .34668 .14891 .35299 Mtetra
.976 .921 .622 r
.14891 .35299 .15424 .34668 .16019 .34302 .15647 .33577 Mtetra
.802 .668 .715 r
.15647 .33577 .16019 .34302 .16683 .33336 .16306 .32663 Mtetra
.868 .473 .003 r
.16306 .32663 .16683 .33336 .17221 .33489 .16721 .33898 Mtetra
.309 0 0 r
.16721 .33898 .17221 .33489 .17788 .33395 .17285 .33845 Mtetra
.592 .15 .168 r
.17285 .33845 .17788 .33395 .18225 .34528 .17814 .34136 Mtetra
.485 .682 .953 r
.17814 .34136 .18225 .34528 .18851 .33933 .1838 .34114 Mtetra
.358 .816 .712 r
.1838 .34114 .18851 .33933 .19437 .33719 .18974 .3384 Mtetra
.904 .968 .812 r
.18974 .3384 .19437 .33719 .20083 .32933 .19622 .33065 Mtetra
.777 .997 .856 r
.19622 .33065 .20083 .32933 .20663 .32797 .20243 .32545 Mtetra
.42 .745 .993 r
.20243 .32545 .20663 .32797 .21271 .32397 .20814 .32514 Mtetra
.713 .226 .087 r
.20814 .32514 .21271 .32397 .21811 .32697 .21333 .33036 Mtetra
.008 0 0 r
.21333 .33036 .21811 .32697 .22404 .32481 .21928 .3282 Mtetra
.801 .408 .309 r
.21928 .3282 .22404 .32481 .22873 .33597 .22404 .33862 Mtetra
.49 0 0 r
.22404 .33862 .22873 .33597 .2347 .33381 .22968 .34031 Mtetra
.737 .359 .335 r
.22968 .34031 .2347 .33381 .23923 .34795 .23469 .34911 Mtetra
.655 .971 .859 r
.23469 .34911 .23923 .34795 .24509 .34773 .24092 .34502 Mtetra
.834 .828 .842 r
.24092 .34502 .24509 .34773 .24986 .36042 .24731 .33901 Mtetra
.638 .462 .63 r
.24731 .33901 .24986 .36042 .2571 .34468 .25371 .33302 Mtetra
.794 .616 .661 r
.25371 .33302 .2571 .34468 .26396 .33298 .26071 .31979 Mtetra
.687 .541 .682 r
.26071 .31979 .26396 .33298 .27004 .33079 .2671 .31378 Mtetra
.721 .538 .642 r
.2671 .31378 .27004 .33079 .27658 .32294 .27385 .3032 Mtetra
.638 .469 .637 r
.27385 .3032 .27658 .32294 .28282 .31889 .28018 .29764 Mtetra
.673 .488 .627 r
.28018 .29764 .28282 .31889 .28934 .31122 .28677 .28889 Mtetra
.431 .309 .613 r
.28677 .28889 .28934 .31122 .29584 .30374 .29237 .29307 Mtetra
.552 .489 .738 r
.29237 .29307 .29584 .30374 .30183 .30325 .29836 .2926 Mtetra
.555 .491 .739 r
.29836 .2926 .30183 .30325 .30784 .30278 .30437 .29206 Mtetra
.807 .632 .664 r
.30437 .29206 .30784 .30278 .31496 .2862 .31128 .2787 Mtetra
.739 .648 .759 r
.31128 .2787 .31496 .2862 .32142 .27902 .31763 .27331 Mtetra
.654 .668 .851 r
.31763 .27331 .32142 .27902 .32738 .27964 .32378 .27105 Mtetra
.723 .619 .741 r
.32378 .27105 .32738 .27964 .33357 .27687 .33013 .26569 Mtetra
.397 .385 .729 r
.33013 .26569 .33357 .27687 .34007 .2692 .336 .26841 Mtetra
.24 .74 .902 r
.336 .26841 .34007 .2692 .34618 .26809 .34209 .26792 Mtetra
.535 0 0 r
.34209 .26792 .34618 .26809 .35247 .26428 .34798 .27124 Mtetra
.266 0 .05 r
.34798 .27124 .35247 .26428 .35822 .27039 .35422 .26896 Mtetra
.91 .88 .793 r
.35422 .26896 .35822 .27039 .36385 .27983 .36082 .26021 Mtetra
.653 .48 .637 r
.36082 .26021 .36385 .27983 .37099 .26027 .36729 .2536 Mtetra
0 0 .424 r
.36729 .2536 .37099 .26027 .37675 .26831 .37299 .26278 Mtetra
.826 .729 .758 r
.37299 .26278 .37675 .26831 .38304 .26602 .37956 .2547 Mtetra
.492 .445 .732 r
.37956 .2547 .38304 .26602 .38926 .26565 .38571 .25564 Mtetra
.721 .598 .718 r
.38571 .25564 .38926 .26565 .39613 .25054 .3922 .24955 Mtetra
.647 .929 .972 r
.3922 .24955 .39613 .25054 .40252 .24623 .39855 .24669 Mtetra
.796 .995 .867 r
.39855 .24669 .40252 .24623 .40878 .2457 .40502 .2412 Mtetra
.628 .719 .912 r
.40502 .2412 .40878 .2457 .41514 .24274 .41135 .2394 Mtetra
0 .231 .699 r
.41135 .2394 .41514 .24274 .42078 .26191 .4175 .2434 Mtetra
.111 .111 .577 r
.4175 .2434 .42078 .26191 .42711 .2623 .42344 .25502 Mtetra
.565 .579 .827 r
.42344 .25502 .42711 .2623 .4334 .26475 .42983 .25426 Mtetra
0 0 .326 r
.42983 .25426 .4334 .26475 .43964 .27039 .43578 .2694 Mtetra
.771 .263 0 r
.43578 .2694 .43964 .27039 .44605 .27138 .44201 .27759 Mtetra
.979 .875 .503 r
.44201 .27759 .44605 .27138 .4528 .25947 .4491 .25344 Mtetra
.652 .665 .85 r
.4491 .25344 .4528 .25947 .45945 .2506 .45562 .25108 Mtetra
.988 .8 .562 r
.45562 .25108 .45945 .2506 .46604 .24419 .4627 .2219 Mtetra
.457 .333 .622 r
.4627 .2219 .46604 .24419 .47259 .24003 .46909 .22535 Mtetra
.687 .531 .669 r
.46909 .22535 .47259 .24003 .47921 .23192 .47568 .21859 Mtetra
0 .002 .553 r
.47568 .21859 .47921 .23192 .48577 .22767 .482 .23089 Mtetra
.5 0 0 r
.482 .23089 .48577 .22767 .49224 .23291 .48852 .23295 Mtetra
.659 .108 0 r
.48852 .23295 .49224 .23291 .49881 .23198 .49505 .23844 Mtetra
.651 .228 .228 r
.49505 .23844 .49881 .23198 .50539 .23186 .50162 .24395 Mtetra
.699 .336 .356 r
.50162 .24395 .50539 .23186 .51194 .24598 .50822 .25432 Mtetra
.04 0 .007 r
.50822 .25432 .51194 .24598 .51859 .25646 .51494 .24812 Mtetra
.699 .624 .769 r
.51494 .24812 .51859 .25646 .52531 .24926 .52166 .24376 Mtetra
.688 .707 .862 r
.52166 .24376 .52531 .24926 .53203 .24886 .52839 .24067 Mtetra
.853 .69 .68 r
.52839 .24067 .53203 .24886 .53873 .23682 .5351 .22741 Mtetra
.72 .613 .738 r
.5351 .22741 .53873 .23682 .54543 .228 .54182 .22175 Mtetra
0 0 .451 r
.54182 .22175 .54543 .228 .55215 .22319 .54867 .23206 Mtetra
.142 0 .075 r
.54867 .23206 .55215 .22319 .55889 .2192 .55544 .22666 Mtetra
0 0 0 r
.55544 .22666 .55889 .2192 .56553 .20811 .56214 .21632 Mtetra
.56214 .21632 .56553 .20811 .5721 .1932 .56876 .20119 Mtetra
.56876 .20119 .5721 .1932 .57879 .18698 .57533 .18549 Mtetra
.771 .266 0 r
.57533 .18549 .57879 .18698 .58557 .18582 .58234 .19537 Mtetra
0 0 .047 r
.58234 .19537 .58557 .18582 .59258 .1937 .58904 .18726 Mtetra
0 0 .562 r
.58904 .18726 .59258 .1937 .59949 .19499 .59615 .19649 Mtetra
.347 0 0 r
.59615 .19649 .59949 .19499 .6066 .20235 .60311 .19776 Mtetra
.661 .744 .912 r
.60311 .19776 .6066 .20235 .61356 .20219 .61001 .19526 Mtetra
.423 .522 .854 r
.61001 .19526 .61356 .20219 .62065 .20563 .61704 .19658 Mtetra
.457 .478 .792 r
.61704 .19658 .62065 .20563 .628 .21536 .6241 .19794 Mtetra
.689 .516 .648 r
.6241 .19794 .628 .21536 .63502 .21395 .63086 .18964 Mtetra
.572 .408 .621 r
.63086 .18964 .63502 .21395 .64195 .20949 .63783 .18712 Mtetra
.606 .439 .629 r
.63783 .18712 .64195 .20949 .6492 .21278 .64474 .18268 Mtetra
.483 .331 .598 r
.64474 .18268 .6492 .21278 .6565 .21608 .65198 .18591 Mtetra
.451 .309 .596 r
.65198 .18591 .6565 .21608 .66394 .22143 .65936 .19118 Mtetra
.682 .469 .591 r
.65936 .19118 .66394 .22143 .67045 .20624 .66588 .17697 Mtetra
.683 .471 .593 r
.66588 .17697 .67045 .20624 .67675 .18798 .67238 .1632 Mtetra
.519 .371 .62 r
.67238 .1632 .67675 .18798 .68326 .17447 .67959 .1639 Mtetra
.622 .545 .747 r
.67959 .1639 .68326 .17447 .69022 .16996 .68666 .16133 Mtetra
.598 .571 .795 r
.68666 .16133 .69022 .16996 .69669 .15665 .69381 .15971 Mtetra
0 0 0 r
.69381 .15971 .69669 .15665 .70388 .15602 .70069 .15321 Mtetra
.775 .889 .926 r
.70069 .15321 .70388 .15602 .71064 .14795 .70768 .14867 Mtetra
.299 .786 .73 r
.70768 .14867 .71064 .14795 .71753 .14209 .71481 .14607 Mtetra
.938 .853 .419 r
.71481 .14607 .71753 .14209 .72416 .13231 .72066 .1239 Mtetra
.364 .439 .805 r
.72066 .1239 .72416 .13231 .73205 .14072 .72815 .12672 Mtetra
.664 .526 .686 r
.72815 .12672 .73205 .14072 .73924 .13851 .73511 .1214 Mtetra
.413 .341 .667 r
.73511 .1214 .73924 .13851 .74599 .13026 .7428 .12593 Mtetra
.925 .822 .726 r
.7428 .12593 .74599 .13026 .75257 .11986 .74931 .11439 Mtetra
.556 .661 .906 r
.74931 .11439 .75257 .11986 .75987 .11873 .75664 .1135 Mtetra
.773 .69 .772 r
.11754 .34698 .12147 .35279 .12789 .34504 .12373 .34114 Mtetra
0 .373 .828 r
.12373 .34114 .12789 .34504 .13353 .34361 .12887 .34375 Mtetra
.844 .957 .885 r
.12887 .34375 .13353 .34361 .13962 .33854 .13503 .33828 Mtetra
.717 .202 0 r
.13503 .33828 .13962 .33854 .14435 .34489 .13992 .34323 Mtetra
.044 .574 .861 r
.13992 .34323 .14435 .34489 .14891 .35299 .14534 .34409 Mtetra
.743 .618 .72 r
.14534 .34409 .14891 .35299 .15647 .33577 .15167 .33746 Mtetra
.807 .999 .839 r
.15167 .33746 .15647 .33577 .16306 .32663 .1579 .33173 Mtetra
.349 0 .012 r
.1579 .33173 .16306 .32663 .16721 .33898 .16352 .33121 Mtetra
.52 .529 .806 r
.16352 .33121 .16721 .33898 .17285 .33845 .1691 .33127 Mtetra
.833 .442 0 r
.1691 .33127 .17285 .33845 .17814 .34136 .17337 .34326 Mtetra
.198 0 0 r
.17337 .34326 .17814 .34136 .1838 .34114 .17904 .34303 Mtetra
.584 .07 0 r
.17904 .34303 .1838 .34114 .18974 .3384 .1844 .34593 Mtetra
.955 .926 .578 r
.1844 .34593 .18974 .3384 .19622 .33065 .19195 .32838 Mtetra
.224 .659 .955 r
.19195 .32838 .19622 .33065 .20243 .32545 .19757 .32891 Mtetra
.293 0 0 r
.19757 .32891 .20243 .32545 .20814 .32514 .20331 .32853 Mtetra
.624 .925 .67 r
.20331 .32853 .20814 .32514 .21333 .33036 .20961 .32281 Mtetra
0 .007 .583 r
.20961 .32281 .21333 .33036 .21928 .3282 .21467 .32969 Mtetra
.831 .423 .271 r
.21467 .32969 .21928 .3282 .22404 .33862 .2194 .3404 Mtetra
0 0 0 r
.2194 .3404 .22404 .33862 .22968 .34031 .22542 .33823 Mtetra
.779 .87 .915 r
.22542 .33823 .22968 .34031 .23469 .34911 .23163 .33411 Mtetra
.638 .495 .672 r
.23163 .33411 .23469 .34911 .24092 .34502 .23784 .33 Mtetra
.806 .603 .628 r
.23784 .33 .24092 .34502 .24731 .33901 .24542 .31068 Mtetra
.502 .341 .595 r
.24542 .31068 .24731 .33901 .25371 .33302 .25112 .31223 Mtetra
.628 .457 .632 r
.25112 .31223 .25371 .33302 .26071 .31979 .25743 .30705 Mtetra
.65 .522 .694 r
.25743 .30705 .26071 .31979 .2671 .31378 .26364 .30306 Mtetra
.776 .615 .68 r
.26364 .30306 .2671 .31378 .27385 .3032 .27038 .29269 Mtetra
.657 .553 .725 r
.27038 .29269 .27385 .3032 .28018 .29764 .27656 .28913 Mtetra
.631 .574 .772 r
.27656 .28913 .28018 .29764 .28677 .28889 .28264 .28689 Mtetra
.788 .88 .913 r
.28264 .28689 .28677 .28889 .29237 .29307 .2889 .28258 Mtetra
.123 .218 .691 r
.2889 .28258 .29237 .29307 .29836 .2926 .29441 .28847 Mtetra
.871 .766 .743 r
.29441 .28847 .29836 .2926 .30437 .29206 .3011 .2785 Mtetra
.601 .484 .691 r
.3011 .2785 .30437 .29206 .31128 .2787 .30724 .27625 Mtetra
.627 .834 .98 r
.30724 .27625 .31128 .2787 .31763 .27331 .31337 .27426 Mtetra
.874 .988 .823 r
.31337 .27426 .31763 .27331 .32378 .27105 .31985 .26719 Mtetra
.784 .783 .852 r
.31985 .26719 .32378 .27105 .33013 .26569 .32619 .26237 Mtetra
0 .246 .708 r
.32619 .26237 .33013 .26569 .336 .26841 .332 .26599 Mtetra
.677 .141 0 r
.332 .26599 .336 .26841 .34209 .26792 .33769 .27223 Mtetra
.364 0 0 r
.33769 .27223 .34209 .26792 .34798 .27124 .3438 .27215 Mtetra
.345 .82 .78 r
.3438 .27215 .34798 .27124 .35422 .26896 .35006 .26987 Mtetra
.978 .868 .66 r
.35006 .26987 .35422 .26896 .36082 .26021 .35711 .25335 Mtetra
.729 .663 .784 r
.35711 .25335 .36082 .26021 .36729 .2536 .36349 .2487 Mtetra
.236 .499 .9 r
.36349 .2487 .36729 .2536 .37299 .26278 .36954 .25072 Mtetra
.726 .575 .686 r
.36954 .25072 .37299 .26278 .37956 .2547 .37609 .2431 Mtetra
.552 .477 .725 r
.37609 .2431 .37956 .2547 .38571 .25564 .3823 .24259 Mtetra
.622 .503 .697 r
.3823 .24259 .38571 .25564 .3922 .24955 .38864 .23961 Mtetra
0 .139 .661 r
.38864 .23961 .3922 .24955 .39855 .24669 .39456 .24704 Mtetra
.224 0 0 r
.39456 .24704 .39855 .24669 .40502 .2412 .40079 .24794 Mtetra
.683 .837 .411 r
.40079 .24794 .40502 .2412 .41135 .2394 .40754 .23612 Mtetra
.195 .577 .94 r
.40754 .23612 .41135 .2394 .4175 .2434 .41378 .23749 Mtetra
.712 .292 0 r
.41378 .23749 .4175 .2434 .42344 .25502 .41972 .24885 Mtetra
0 .014 .58 r
.41972 .24885 .42344 .25502 .42983 .25426 .42585 .25625 Mtetra
.771 .308 .146 r
.42585 .25625 .42983 .25426 .43578 .2694 .43201 .26464 Mtetra
.669 .727 .893 r
.43201 .26464 .43578 .2694 .44201 .27759 .43853 .26211 Mtetra
.69 .528 .662 r
.43853 .26211 .44201 .27759 .4491 .25344 .4452 .25481 Mtetra
.993 .822 .569 r
.4452 .25481 .4491 .25344 .45562 .25108 .45231 .2284 Mtetra
.686 .491 .618 r
.45231 .2284 .45562 .25108 .4627 .2219 .459 .21775 Mtetra
.759 .781 .871 r
.459 .21775 .4627 .2219 .46909 .22535 .46554 .21348 Mtetra
.578 .492 .722 r
.46554 .21348 .46909 .22535 .47568 .21859 .47203 .21216 Mtetra
.827 .432 0 r
.47203 .21216 .47568 .21859 .482 .23089 .47828 .22895 Mtetra
.316 .738 .974 r
.47828 .22895 .482 .23089 .48852 .23295 .48484 .22878 Mtetra
.844 .408 0 r
.48484 .22878 .48852 .23295 .49505 .23844 .49126 .2433 Mtetra
.795 .382 .267 r
.49126 .2433 .49505 .23844 .50162 .24395 .4978 .25557 Mtetra
.594 .225 .312 r
.4978 .25557 .50162 .24395 .50822 .25432 .50446 .25999 Mtetra
.793 .882 .457 r
.50446 .25999 .50822 .25432 .51494 .24812 .51126 .24632 Mtetra
.844 .922 .884 r
.51126 .24632 .51494 .24812 .52166 .24376 .518 .2404 Mtetra
.769 .835 .902 r
.518 .2404 .52166 .24376 .52839 .24067 .52475 .23604 Mtetra
.51 .674 .938 r
.52475 .23604 .52839 .24067 .5351 .22741 .53151 .23562 Mtetra
.17 0 .059 r
.53151 .23562 .5351 .22741 .54182 .22175 .53828 .23112 Mtetra
.667 .276 .296 r
.53828 .23112 .54182 .22175 .54867 .23206 .54513 .2384 Mtetra
.365 0 .069 r
.54513 .2384 .54867 .23206 .55544 .22666 .55197 .2376 Mtetra
0 0 0 r
.55197 .2376 .55544 .22666 .56214 .21632 .55865 .2192 Mtetra
.921 .944 .594 r
.55865 .2192 .56214 .21632 .56876 .20119 .56533 .20595 Mtetra
.476 0 .044 r
.56533 .20595 .56876 .20119 .57533 .18549 .57222 .20741 Mtetra
.358 .074 .339 r
.57222 .20741 .57533 .18549 .58234 .19537 .57899 .20099 Mtetra
0 0 0 r
.57899 .20099 .58234 .19537 .58904 .18726 .58577 .19458 Mtetra
.386 0 .121 r
.58577 .19458 .58904 .18726 .59615 .19649 .59267 .19376 Mtetra
.446 .763 .996 r
.59267 .19376 .59615 .19649 .60311 .19776 .5996 .19314 Mtetra
.865 .794 .779 r
.5996 .19314 .60311 .19776 .61001 .19526 .60635 .18461 Mtetra
.72 .596 .717 r
.60635 .18461 .61001 .19526 .61704 .19658 .61314 .17825 Mtetra
.671 .499 .644 r
.61314 .17825 .61704 .19658 .6241 .19794 .61991 .17081 Mtetra
.616 .43 .607 r
.61991 .17081 .6241 .19794 .63086 .18964 .6267 .16448 Mtetra
.473 .337 .615 r
.6267 .16448 .63086 .18964 .63783 .18712 .63384 .16766 Mtetra
.583 .436 .647 r
.63384 .16766 .63783 .18712 .64474 .18268 .6408 .16512 Mtetra
.703 .524 .643 r
.6408 .16512 .64474 .18268 .65198 .18591 .6475 .15575 Mtetra
.481 .329 .597 r
.6475 .15575 .65198 .18591 .65936 .19118 .65474 .15904 Mtetra
.623 .424 .592 r
.65474 .15904 .65936 .19118 .66588 .17697 .66148 .15063 Mtetra
.539 .379 .613 r
.66148 .15063 .66588 .17697 .67238 .1632 .66859 .14999 Mtetra
.375 .354 .707 r
.66859 .14999 .67238 .1632 .67959 .1639 .67597 .15424 Mtetra
.555 .524 .775 r
.67597 .15424 .67959 .1639 .68666 .16133 .68315 .1536 Mtetra
.712 .653 .789 r
.68315 .1536 .68666 .16133 .69381 .15971 .69013 .14907 Mtetra
.555 .505 .755 r
.69013 .14907 .69381 .15971 .70069 .15321 .69735 .14842 Mtetra
.919 .799 .712 r
.69735 .14842 .70069 .15321 .70768 .14867 .7039 .13618 Mtetra
.137 .208 .674 r
.7039 .13618 .70768 .14867 .71481 .14607 .71175 .14517 Mtetra
.06 .612 .826 r
.71175 .14517 .71481 .14607 .72066 .1239 .71913 .14563 Mtetra
.363 .082 .345 r
.71913 .14563 .72066 .1239 .72815 .12672 .72605 .13904 Mtetra
0 0 .129 r
.72605 .13904 .72815 .12672 .73511 .1214 .73256 .12655 Mtetra
0 0 0 r
.73256 .12655 .73511 .1214 .7428 .12593 .73948 .12004 Mtetra
.843 .76 .771 r
.73948 .12004 .7428 .12593 .74931 .11439 .74626 .11173 Mtetra
.642 .866 .983 r
.74626 .11173 .74931 .11439 .75664 .1135 .75347 .10907 Mtetra
.571 .489 .724 r
.11427 .33593 .11754 .34698 .12373 .34114 .11984 .33497 Mtetra
.884 .481 .04 r
.11984 .33497 .12373 .34114 .12887 .34375 .12381 .34674 Mtetra
0 0 0 r
.12381 .34674 .12887 .34375 .13503 .33828 .12958 .34463 Mtetra
.022 0 0 r
.12958 .34463 .13503 .33828 .13992 .34323 .13555 .34091 Mtetra
.344 0 0 r
.13555 .34091 .13992 .34323 .14534 .34409 .14074 .34373 Mtetra
.935 .839 .725 r
.14074 .34373 .14534 .34409 .15167 .33746 .14781 .33108 Mtetra
.694 .652 .803 r
.14781 .33108 .15167 .33746 .1579 .33173 .15375 .32778 Mtetra
0 .245 .728 r
.15375 .32778 .1579 .33173 .16352 .33121 .15892 .33121 Mtetra
.149 .692 .797 r
.15892 .33121 .16352 .33121 .1691 .33127 .16458 .33064 Mtetra
.522 0 0 r
.16458 .33064 .1691 .33127 .17337 .34326 .16987 .33359 Mtetra
.721 .597 .717 r
.16987 .33359 .17337 .34326 .17904 .34303 .17616 .32767 Mtetra
.402 .33 .662 r
.17616 .32767 .17904 .34303 .1844 .34593 .18145 .33103 Mtetra
.636 .493 .672 r
.18145 .33103 .1844 .34593 .19195 .32838 .18755 .32708 Mtetra
.846 .895 .873 r
.18755 .32708 .19195 .32838 .19757 .32891 .19383 .32141 Mtetra
0 .006 .581 r
.19383 .32141 .19757 .32891 .20331 .32853 .19883 .32817 Mtetra
.733 .957 .945 r
.19883 .32817 .20331 .32853 .20961 .32281 .20495 .32446 Mtetra
.774 .331 .198 r
.20495 .32446 .20961 .32281 .21467 .32969 .20995 .33191 Mtetra
.479 0 0 r
.20995 .33191 .21467 .32969 .2194 .3404 .21557 .3336 Mtetra
.643 .624 .816 r
.21557 .3336 .2194 .3404 .22542 .33823 .22159 .33142 Mtetra
.763 .671 .761 r
.22159 .33142 .22542 .33823 .23163 .33411 .22798 .32535 Mtetra
.735 .621 .731 r
.22798 .32535 .23163 .33411 .23784 .33 .23438 .31928 Mtetra
.712 .581 .707 r
.23438 .31928 .23784 .33 .24542 .31068 .24078 .31322 Mtetra
.733 .981 .756 r
.24078 .31322 .24542 .31068 .25112 .31223 .24717 .30718 Mtetra
.792 .73 .795 r
.24717 .30718 .25112 .31223 .25743 .30705 .25356 .30118 Mtetra
.723 .686 .814 r
.25356 .30118 .25743 .30705 .26364 .30306 .25977 .29722 Mtetra
.769 .7 .787 r
.25977 .29722 .26364 .30306 .27038 .29269 .26613 .29164 Mtetra
.753 .933 .946 r
.26613 .29164 .27038 .29269 .27656 .28913 .27234 .28783 Mtetra
.344 .782 .965 r
.27234 .28783 .27656 .28913 .28264 .28689 .27831 .2872 Mtetra
.451 .883 .885 r
.27831 .2872 .28264 .28689 .2889 .28258 .28443 .28496 Mtetra
.409 0 0 r
.28443 .28496 .2889 .28258 .29441 .28847 .29031 .28602 Mtetra
.652 .841 .973 r
.29031 .28602 .29441 .28847 .3011 .2785 .29646 .28376 Mtetra
0 0 0 r
.29646 .28376 .3011 .2785 .30724 .27625 .30297 .27656 Mtetra
.109 0 0 r
.30297 .27656 .30724 .27625 .31337 .27426 .30896 .27685 Mtetra
.468 0 0 r
.30896 .27685 .31337 .27426 .31985 .26719 .31489 .27845 Mtetra
0 0 0 r
.31489 .27845 .31985 .26719 .32619 .26237 .32187 .26442 Mtetra
.315 .777 .644 r
.32187 .26442 .32619 .26237 .332 .26599 .32812 .26139 Mtetra
.342 .578 .929 r
.32812 .26139 .332 .26599 .33769 .27223 .33413 .26249 Mtetra
.498 .476 .764 r
.33413 .26249 .33769 .27223 .3438 .27215 .34019 .26308 Mtetra
.479 .48 .781 r
.34019 .26308 .3438 .27215 .35006 .26987 .34626 .26395 Mtetra
.882 .724 .68 r
.34626 .26395 .35006 .26987 .35711 .25335 .35323 .24941 Mtetra
.722 .775 .894 r
.35323 .24941 .35711 .25335 .36349 .2487 .35955 .24608 Mtetra
.56 .806 .991 r
.35955 .24608 .36349 .2487 .36954 .25072 .36578 .2447 Mtetra
.664 .665 .841 r
.36578 .2447 .36954 .25072 .37609 .2431 .37209 .24212 Mtetra
.29 0 0 r
.37209 .24212 .37609 .2431 .3823 .24259 .37819 .24427 Mtetra
.131 0 0 r
.37819 .24427 .3823 .24259 .38864 .23961 .38444 .24378 Mtetra
.167 0 0 r
.38444 .24378 .38864 .23961 .39456 .24704 .39077 .24199 Mtetra
.759 .736 .831 r
.39077 .24199 .39456 .24704 .40079 .24794 .39724 .2373 Mtetra
.608 .527 .737 r
.39724 .2373 .40079 .24794 .40754 .23612 .40361 .23524 Mtetra
.58 .914 .972 r
.40361 .23524 .40754 .23612 .41378 .23749 .41001 .23281 Mtetra
.854 .426 0 r
.41001 .23281 .41378 .23749 .41972 .24885 .41584 .24687 Mtetra
.93 .553 .259 r
.41584 .24687 .41972 .24885 .42585 .25625 .42142 .27083 Mtetra
.328 .005 .255 r
.42142 .27083 .42585 .25625 .43201 .26464 .42801 .26649 Mtetra
.965 .939 .675 r
.42801 .26649 .43201 .26464 .43853 .26211 .43487 .25338 Mtetra
.87 .684 .648 r
.43487 .25338 .43853 .26211 .4452 .25481 .44182 .23593 Mtetra
.807 .586 .603 r
.44182 .23593 .4452 .25481 .45231 .2284 .44885 .21305 Mtetra
.499 .404 .679 r
.44885 .21305 .45231 .2284 .459 .21775 .45526 .21412 Mtetra
0 .127 .62 r
.45526 .21412 .459 .21775 .46554 .21348 .46162 .21925 Mtetra
.542 .097 .144 r
.46162 .21925 .46554 .21348 .47203 .21216 .46808 .22166 Mtetra
.738 .362 .339 r
.46808 .22166 .47203 .21216 .47828 .22895 .47442 .2332 Mtetra
.324 0 0 r
.47442 .2332 .47828 .22895 .48484 .22878 .48101 .23277 Mtetra
.832 .424 .272 r
.48101 .23277 .48484 .22878 .49126 .2433 .48745 .2475 Mtetra
.827 .418 .27 r
.48745 .2475 .49126 .2433 .4978 .25557 .49397 .26199 Mtetra
.636 .207 .211 r
.49397 .26199 .4978 .25557 .50446 .25999 .50066 .26709 Mtetra
.912 .871 .437 r
.50066 .26709 .50446 .25999 .51126 .24632 .50754 .24584 Mtetra
.983 .851 .631 r
.50754 .24584 .51126 .24632 .518 .2404 .51435 .22752 Mtetra
.76 .591 .668 r
.51435 .22752 .518 .2404 .52475 .23604 .5211 .21707 Mtetra
.184 .166 .602 r
.5211 .21707 .52475 .23604 .53151 .23562 .52785 .22798 Mtetra
0 .142 .684 r
.52785 .22798 .53151 .23562 .53828 .23112 .53466 .23532 Mtetra
.658 .189 .127 r
.53466 .23532 .53828 .23112 .54513 .2384 .54153 .24081 Mtetra
.984 .899 .577 r
.54153 .24081 .54513 .2384 .55197 .2376 .54826 .22255 Mtetra
.758 .574 .648 r
.54826 .22255 .55197 .2376 .55865 .2192 .555 .21042 Mtetra
.778 .654 .725 r
.555 .21042 .55865 .2192 .56533 .20595 .56176 .20235 Mtetra
.863 .433 .007 r
.56176 .20235 .56533 .20595 .57222 .20741 .56889 .21963 Mtetra
.256 0 .199 r
.56889 .21963 .57222 .20741 .57899 .20099 .57574 .21427 Mtetra
0 0 .012 r
.57574 .21427 .57899 .20099 .58577 .19458 .58238 .19783 Mtetra
.951 .913 .543 r
.58238 .19783 .58577 .19458 .59267 .19376 .58897 .18116 Mtetra
.403 .378 .717 r
.58897 .18116 .59267 .19376 .5996 .19314 .59598 .18441 Mtetra
.829 .677 .695 r
.59598 .18441 .5996 .19314 .60635 .18461 .60266 .17312 Mtetra
.774 .614 .681 r
.60266 .17312 .60635 .18461 .61314 .17825 .60936 .16301 Mtetra
.744 .563 .65 r
.60936 .16301 .61314 .17825 .61991 .17081 .616 .152 Mtetra
.613 .458 .648 r
.616 .152 .61991 .17081 .6267 .16448 .62285 .14795 Mtetra
.583 .453 .669 r
.62285 .14795 .6267 .16448 .63384 .16766 .62978 .14578 Mtetra
.506 .372 .632 r
.62978 .14578 .63384 .16766 .6408 .16512 .63686 .14701 Mtetra
.587 .445 .656 r
.63686 .14701 .6408 .16512 .6475 .15575 .64382 .14444 Mtetra
.617 .529 .732 r
.64382 .14444 .6475 .15575 .65474 .15904 .65079 .14186 Mtetra
.477 .38 .667 r
.65079 .14186 .65474 .15904 .66148 .15063 .65799 .14395 Mtetra
.419 .531 .865 r
.65799 .14395 .66148 .15063 .66859 .14999 .6652 .14523 Mtetra
.005 .355 .829 r
.6652 .14523 .66859 .14999 .67597 .15424 .67259 .14946 Mtetra
.757 .777 .87 r
.67259 .14946 .67597 .15424 .68315 .1536 .67957 .14493 Mtetra
.555 .547 .801 r
.67957 .14493 .68315 .1536 .69013 .14907 .68677 .14427 Mtetra
.345 .58 .93 r
.68677 .14427 .69013 .14907 .69735 .14842 .69412 .14558 Mtetra
.646 .853 .979 r
.69412 .14558 .69735 .14842 .7039 .13618 .70126 .14296 Mtetra
.717 .283 .217 r
.70126 .14296 .7039 .13618 .71175 .14517 .70917 .15225 Mtetra
0 0 0 r
.70917 .15225 .71175 .14517 .71913 .14563 .71574 .13969 Mtetra
.918 .766 .677 r
.71574 .13969 .71913 .14563 .72605 .13904 .72216 .12537 Mtetra
.35 .334 .7 r
.72216 .12537 .72605 .13904 .73256 .12655 .7299 .13048 Mtetra
0 0 0 r
.7299 .13048 .73256 .12655 .73948 .12004 .73699 .12588 Mtetra
.73699 .12588 .73948 .12004 .74626 .11173 .74373 .11637 Mtetra
.74373 .11637 .74626 .11173 .75347 .10907 .75082 .11176 Mtetra
.36 0 .025 r
.10887 .34117 .11427 .33593 .11984 .33497 .11439 .34076 Mtetra
.649 .245 .266 r
.11439 .34076 .11984 .33497 .12381 .34674 .1193 .34519 Mtetra
.336 .762 .974 r
.1193 .34519 .12381 .34674 .12958 .34463 .12486 .34482 Mtetra
.737 .971 .93 r
.12486 .34482 .12958 .34463 .13555 .34091 .13087 .34094 Mtetra
.818 .961 .903 r
.13087 .34094 .13555 .34091 .14074 .34373 .13702 .33598 Mtetra
.805 .662 .705 r
.13702 .33598 .14074 .34373 .14781 .33108 .14377 .32605 Mtetra
.745 .713 .821 r
.14377 .32605 .14781 .33108 .15375 .32778 .14983 .32181 Mtetra
.723 .675 .802 r
.14983 .32181 .15375 .32778 .15892 .33121 .15587 .3178 Mtetra
0 .032 .562 r
.15587 .3178 .15892 .33121 .16458 .33064 .16043 .32667 Mtetra
.489 0 0 r
.16043 .32667 .16458 .33064 .16987 .33359 .16549 .33151 Mtetra
.876 .833 .801 r
.16549 .33151 .16987 .33359 .17616 .32767 .17202 .32368 Mtetra
.725 .23 0 r
.17202 .32368 .17616 .32767 .18145 .33103 .1769 .33068 Mtetra
.933 .863 .748 r
.1769 .33068 .18145 .33103 .18755 .32708 .18379 .31957 Mtetra
.709 .631 .769 r
.18379 .31957 .18755 .32708 .19383 .32141 .18993 .31534 Mtetra
.833 .416 0 r
.18993 .31534 .19383 .32141 .19883 .32817 .19447 .32645 Mtetra
.896 .844 .786 r
.19447 .32645 .19883 .32817 .20495 .32446 .20111 .31767 Mtetra
.534 .572 .84 r
.20111 .31767 .20495 .32446 .20995 .33191 .20689 .31741 Mtetra
.596 .471 .68 r
.20689 .31741 .20995 .33191 .21557 .3336 .21288 .31521 Mtetra
.653 .485 .644 r
.21288 .31521 .21557 .3336 .22159 .33142 .21925 .30916 Mtetra
.591 .425 .625 r
.21925 .30916 .22159 .33142 .22798 .32535 .22536 .30587 Mtetra
.646 .475 .638 r
.22536 .30587 .22798 .32535 .23438 .31928 .23174 .2999 Mtetra
.538 .399 .64 r
.23174 .2999 .23438 .31928 .24078 .31322 .23759 .29955 Mtetra
.683 .534 .677 r
.23759 .29955 .24078 .31322 .24717 .30718 .24397 .29359 Mtetra
.378 .336 .685 r
.24397 .29359 .24717 .30718 .25356 .30118 .24952 .29707 Mtetra
.512 .689 .948 r
.24952 .29707 .25356 .30118 .25977 .29722 .25544 .29662 Mtetra
.641 .083 0 r
.25544 .29662 .25977 .29722 .26613 .29164 .26097 .30105 Mtetra
.197 0 .085 r
.26097 .30105 .26613 .29164 .27234 .28783 .26724 .297 Mtetra
.19 0 .075 r
.26724 .297 .27234 .28783 .27831 .2872 .27351 .29297 Mtetra
0 0 0 r
.27351 .29297 .27831 .2872 .28443 .28496 .27979 .28895 Mtetra
.292 0 0 r
.27979 .28895 .28443 .28496 .29031 .28602 .28582 .28836 Mtetra
.456 0 0 r
.28582 .28836 .29031 .28602 .29646 .28376 .2917 .28991 Mtetra
0 0 0 r
.2917 .28991 .29646 .28376 .30297 .27656 .29824 .28285 Mtetra
.391 0 .087 r
.29824 .28285 .30297 .27656 .30896 .27685 .3043 .2825 Mtetra
0 0 0 r
.3043 .2825 .30896 .27685 .31489 .27845 .31063 .27861 Mtetra
.947 .907 .748 r
.31063 .27861 .31489 .27845 .32187 .26442 .31744 .2677 Mtetra
.595 .904 .636 r
.31744 .2677 .32187 .26442 .32812 .26139 .3239 .26175 Mtetra
.787 .99 .887 r
.3239 .26175 .32812 .26139 .33413 .26249 .33031 .25664 Mtetra
.771 .706 .791 r
.33031 .25664 .33413 .26249 .34019 .26308 .33676 .25104 Mtetra
.667 .541 .702 r
.33676 .25104 .34019 .26308 .34626 .26395 .34314 .24649 Mtetra
.407 .321 .647 r
.34314 .24649 .34626 .26395 .35323 .24941 .34904 .25043 Mtetra
.333 .812 .764 r
.34904 .25043 .35323 .24941 .35955 .24608 .35533 .2481 Mtetra
.854 .995 .756 r
.35533 .2481 .35955 .24608 .36578 .2447 .36193 .24022 Mtetra
.613 .715 .918 r
.36193 .24022 .36578 .2447 .37209 .24212 .3682 .23863 Mtetra
.848 .396 0 r
.3682 .23863 .37209 .24212 .37819 .24427 .37382 .25042 Mtetra
.579 .15 .19 r
.37382 .25042 .37819 .24427 .38444 .24378 .37993 .25357 Mtetra
.302 0 .155 r
.37993 .25357 .38444 .24378 .39077 .24199 .38635 .25063 Mtetra
.039 0 0 r
.38635 .25063 .39077 .24199 .39724 .2373 .39291 .24479 Mtetra
.796 .87 .432 r
.39291 .24479 .39724 .2373 .40361 .23524 .39984 .2298 Mtetra
0 0 .497 r
.39984 .2298 .40361 .23524 .41001 .23281 .40586 .23739 Mtetra
.872 .504 .348 r
.40586 .23739 .41001 .23281 .41584 .24687 .4114 .25934 Mtetra
.656 .297 .353 r
.4114 .25934 .41584 .24687 .42142 .27083 .41756 .26691 Mtetra
.856 .417 0 r
.41756 .26691 .42142 .27083 .42801 .26649 .42358 .28062 Mtetra
.778 .774 .269 r
.42358 .28062 .42801 .26649 .43487 .25338 .43091 .25421 Mtetra
.988 .795 .554 r
.43091 .25421 .43487 .25338 .44182 .23593 .4383 .22231 Mtetra
.602 .487 .695 r
.4383 .22231 .44182 .23593 .44885 .21305 .44481 .21991 Mtetra
0 0 0 r
.44481 .21991 .44885 .21305 .45526 .21412 .45144 .21344 Mtetra
.163 0 0 r
.45144 .21344 .45526 .21412 .46162 .21925 .45789 .2148 Mtetra
.934 .558 .189 r
.45789 .2148 .46162 .21925 .46808 .22166 .46389 .24029 Mtetra
0 0 .161 r
.46389 .24029 .46808 .22166 .47442 .2332 .47075 .22525 Mtetra
.823 .682 .709 r
.47075 .22525 .47442 .2332 .48101 .23277 .4775 .21493 Mtetra
0 0 .146 r
.4775 .21493 .48101 .23277 .48745 .2475 .48367 .24579 Mtetra
.904 .492 .169 r
.48367 .24579 .48745 .2475 .49397 .26199 .49014 .26493 Mtetra
.967 .925 .6 r
.49014 .26493 .49397 .26199 .50066 .26709 .49703 .24904 Mtetra
.802 .586 .609 r
.49703 .24904 .50066 .26709 .50754 .24584 .50392 .22851 Mtetra
.784 .577 .62 r
.50392 .22851 .50754 .24584 .51435 .22752 .51072 .2113 Mtetra
.634 .488 .666 r
.51072 .2113 .51435 .22752 .5211 .21707 .51745 .20682 Mtetra
0 0 .408 r
.51745 .20682 .5211 .21707 .52785 .22798 .52418 .22146 Mtetra
.395 .524 .869 r
.52418 .22146 .52785 .22798 .53466 .23532 .53098 .22288 Mtetra
.786 .61 .663 r
.53098 .22288 .53466 .23532 .54153 .24081 .53775 .21076 Mtetra
.68 .469 .593 r
.53775 .21076 .54153 .24081 .54826 .22255 .54448 .19693 Mtetra
.537 .379 .614 r
.54448 .19693 .54826 .22255 .555 .21042 .5513 .19636 Mtetra
.016 .098 .607 r
.5513 .19636 .555 .21042 .56176 .20235 .55827 .20757 Mtetra
.183 0 0 r
.55827 .20757 .56176 .20235 .56889 .21963 .56514 .20508 Mtetra
.213 .228 .659 r
.56514 .20508 .56889 .21963 .57574 .21427 .57219 .21305 Mtetra
.99 .784 .532 r
.57219 .21305 .57574 .21427 .58238 .19783 .57859 .18094 Mtetra
.823 .602 .603 r
.57859 .18094 .58238 .19783 .58897 .18116 .58508 .15909 Mtetra
.548 .399 .631 r
.58508 .15909 .58897 .18116 .59598 .18441 .59196 .15809 Mtetra
.587 .411 .61 r
.59196 .15809 .59598 .18441 .60266 .17312 .5988 .15412 Mtetra
.656 .485 .641 r
.5988 .15412 .60266 .17312 .60936 .16301 .60556 .14737 Mtetra
.593 .466 .677 r
.60556 .14737 .60936 .16301 .616 .152 .61246 .14491 Mtetra
.508 .565 .848 r
.61246 .14491 .616 .152 .62285 .14795 .61945 .14498 Mtetra
.513 .783 .994 r
.61945 .14498 .62285 .14795 .62978 .14578 .62643 .14389 Mtetra
.597 .05 0 r
.62643 .14389 .62978 .14578 .63686 .14701 .63373 .15079 Mtetra
.224 0 0 r
.63373 .15079 .63686 .14701 .64382 .14444 .64077 .14954 Mtetra
.588 .118 .107 r
.64077 .14954 .64382 .14444 .65079 .14186 .64805 .15346 Mtetra
.329 0 .216 r
.64805 .15346 .65079 .14186 .65799 .14395 .65505 .14986 Mtetra
.522 .066 .111 r
.65505 .14986 .65799 .14395 .6652 .14523 .66234 .15219 Mtetra
.482 .048 .137 r
.66234 .15219 .6652 .14523 .67259 .14946 .66962 .1535 Mtetra
0 0 0 r
.66962 .1535 .67259 .14946 .67957 .14493 .67664 .14894 Mtetra
.634 .141 .065 r
.67664 .14894 .67957 .14493 .68677 .14427 .68419 .1542 Mtetra
.029 0 .081 r
.68419 .1542 .68677 .14427 .69412 .14558 .69103 .14567 Mtetra
.855 .997 .787 r
.69103 .14567 .69412 .14558 .70126 .14296 .6979 .13793 Mtetra
.661 .734 .904 r
.6979 .13793 .70126 .14296 .70917 .15225 .70508 .1353 Mtetra
.662 .502 .658 r
.70508 .1353 .70917 .15225 .71574 .13969 .71204 .12893 Mtetra
.677 .575 .734 r
.71204 .12893 .71574 .13969 .72216 .12537 .71911 .12434 Mtetra
.492 0 0 r
.71911 .12434 .72216 .12537 .7299 .13048 .72687 .12953 Mtetra
.909 .974 .795 r
.72687 .12953 .7299 .13048 .73699 .12588 .7337 .12097 Mtetra
.913 .804 .726 r
.7337 .12097 .73699 .12588 .74373 .11637 .74031 .1095 Mtetra
.427 .533 .862 r
.74031 .1095 .74373 .11637 .75082 .11176 .74787 .11074 Mtetra
.346 .746 .983 r
.10437 .33924 .10887 .34117 .11439 .34076 .10987 .33902 Mtetra
.742 .219 0 r
.10987 .33902 .11439 .34076 .1193 .34519 .11463 .34463 Mtetra
.747 .242 .019 r
.11463 .34463 .1193 .34519 .12486 .34482 .11944 .35021 Mtetra
.983 .903 .643 r
.11944 .35021 .12486 .34482 .13087 .34094 .12725 .33228 Mtetra
.689 .597 .747 r
.12725 .33228 .13087 .34094 .13702 .33598 .13328 .32825 Mtetra
.809 .664 .702 r
.13328 .32825 .13702 .33598 .14377 .32605 .1401 .31791 Mtetra
.552 .537 .792 r
.1401 .31791 .14377 .32605 .14983 .32181 .14571 .31743 Mtetra
.205 .513 .913 r
.14571 .31743 .14983 .32181 .15587 .3178 .15108 .31911 Mtetra
.824 .995 .855 r
.15108 .31911 .15587 .3178 .16043 .32667 .15735 .31334 Mtetra
0 0 .388 r
.15735 .31334 .16043 .32667 .16549 .33151 .16154 .32562 Mtetra
.527 .602 .872 r
.16154 .32562 .16549 .33151 .17202 .32368 .16721 .32535 Mtetra
.6 .083 0 r
.16721 .32535 .17202 .32368 .1769 .33068 .17253 .32852 Mtetra
.906 .806 .738 r
.17253 .32852 .1769 .33068 .18379 .31957 .17946 .31728 Mtetra
.724 .853 .943 r
.17946 .31728 .18379 .31957 .18993 .31534 .18549 .31417 Mtetra
.722 .192 0 r
.18549 .31417 .18993 .31534 .19447 .32645 .19061 .31968 Mtetra
.643 .624 .816 r
.19061 .31968 .19447 .32645 .20111 .31767 .19658 .31748 Mtetra
.525 .907 .945 r
.19658 .31748 .20111 .31767 .20689 .31741 .20257 .31528 Mtetra
.904 .817 .751 r
.20257 .31528 .20689 .31741 .21288 .31521 .2094 .30479 Mtetra
.831 .645 .651 r
.2094 .30479 .21288 .31521 .21925 .30916 .21683 .28812 Mtetra
.502 .364 .626 r
.21683 .28812 .21925 .30916 .22536 .30587 .22249 .28921 Mtetra
.486 .379 .658 r
.22249 .28921 .22536 .30587 .23174 .2999 .22815 .29061 Mtetra
.321 .376 .763 r
.22815 .29061 .23174 .2999 .23759 .29955 .23369 .29356 Mtetra
.533 .604 .871 r
.23369 .29356 .23759 .29955 .24397 .29359 .23957 .29321 Mtetra
.776 .285 .052 r
.23957 .29321 .24397 .29359 .24952 .29707 .24481 .30019 Mtetra
.651 .941 .691 r
.24481 .30019 .24952 .29707 .25544 .29662 .25123 .29428 Mtetra
.164 .621 .934 r
.25123 .29428 .25544 .29662 .26097 .30105 .25707 .2951 Mtetra
.724 .686 .813 r
.25707 .2951 .26097 .30105 .26724 .297 .26334 .29106 Mtetra
0 .165 .703 r
.26334 .29106 .26724 .297 .27351 .29297 .26888 .29612 Mtetra
.635 .931 .676 r
.26888 .29612 .27351 .29297 .27979 .28895 .27534 .29018 Mtetra
.693 .19 .042 r
.27534 .29018 .27979 .28895 .28582 .28836 .28093 .29533 Mtetra
.511 .093 .183 r
.28093 .29533 .28582 .28836 .2917 .28991 .28684 .29685 Mtetra
.725 .876 .471 r
.28684 .29685 .2917 .28991 .29824 .28285 .29375 .28536 Mtetra
.463 .859 .668 r
.29375 .28536 .29824 .28285 .3043 .2825 .30011 .28116 Mtetra
.865 .907 .86 r
.30011 .28116 .3043 .2825 .31063 .27861 .30663 .27477 Mtetra
.883 .779 .743 r
.30663 .27477 .31063 .27861 .31744 .2677 .31341 .26445 Mtetra
.145 .552 .926 r
.31341 .26445 .31744 .2677 .3239 .26175 .3194 .26595 Mtetra
0 0 0 r
.3194 .26595 .3239 .26175 .33031 .25664 .32584 .26071 Mtetra
.32584 .26071 .33031 .25664 .33676 .25104 .33224 .25639 Mtetra
.466 .012 .088 r
.33224 .25639 .33676 .25104 .34314 .24649 .33831 .25738 Mtetra
0 0 0 r
.33831 .25738 .34314 .24649 .34904 .25043 .34501 .24825 Mtetra
.889 .859 .805 r
.34501 .24825 .34904 .25043 .35533 .2481 .35164 .24017 Mtetra
.779 .66 .731 r
.35164 .24017 .35533 .2481 .36193 .24022 .35823 .23251 Mtetra
.613 .59 .803 r
.35823 .23251 .36193 .24022 .3682 .23863 .36451 .23075 Mtetra
.727 .356 0 r
.36451 .23075 .3682 .23863 .37382 .25042 .37003 .24432 Mtetra
.944 .585 .212 r
.37003 .24432 .37382 .25042 .37993 .25357 .37503 .27025 Mtetra
.366 .049 .289 r
.37503 .27025 .37993 .25357 .38635 .25063 .38155 .26643 Mtetra
0 0 0 r
.38155 .26643 .38635 .25063 .39291 .24479 .38874 .24755 Mtetra
.33 0 0 r
.38874 .24755 .39291 .24479 .39984 .2298 .39506 .24788 Mtetra
.423 .108 .324 r
.39506 .24788 .39984 .2298 .40586 .23739 .40152 .24551 Mtetra
.816 .452 .367 r
.40152 .24551 .40586 .23739 .4114 .25934 .40721 .26372 Mtetra
.596 .129 .115 r
.40721 .26372 .4114 .25934 .41756 .26691 .41353 .26733 Mtetra
.958 .925 .725 r
.41353 .26733 .41756 .26691 .42358 .28062 .42041 .25558 Mtetra
.625 .442 .614 r
.42041 .25558 .42358 .28062 .43091 .25421 .4271 .2492 Mtetra
.919 .752 .658 r
.4271 .2492 .43091 .25421 .4383 .22231 .43411 .23182 Mtetra
.209 0 .105 r
.43411 .23182 .4383 .22231 .44481 .21991 .44071 .22749 Mtetra
0 0 0 r
.44071 .22749 .44481 .21991 .45144 .21344 .44749 .21659 Mtetra
.741 .283 .163 r
.44749 .21659 .45144 .21344 .45789 .2148 .45381 .22436 Mtetra
.21 0 .109 r
.45381 .22436 .45789 .2148 .46389 .24029 .46045 .21996 Mtetra
.344 .265 .622 r
.46045 .21996 .46389 .24029 .47075 .22525 .46689 .22672 Mtetra
.222 0 0 r
.46689 .22672 .47075 .22525 .4775 .21493 .47349 .22697 Mtetra
.668 .302 .342 r
.47349 .22697 .4775 .21493 .48367 .24579 .48 .23531 Mtetra
.619 .542 .745 r
.48 .23531 .48367 .24579 .49014 .26493 .48671 .23287 Mtetra
.389 .255 .576 r
.48671 .23287 .49014 .26493 .49703 .24904 .49332 .2413 Mtetra
.897 .709 .64 r
.49332 .2413 .49703 .24904 .50392 .22851 .50022 .22241 Mtetra
.939 .732 .596 r
.50022 .22241 .50392 .22851 .51072 .2113 .5071 .19629 Mtetra
.179 .197 .641 r
.5071 .19629 .51072 .2113 .51745 .20682 .51377 .20485 Mtetra
.866 .42 .06 r
.51377 .20485 .51745 .20682 .52418 .22146 .52049 .21974 Mtetra
.935 .892 .763 r
.52049 .21974 .52418 .22146 .53098 .22288 .52729 .20945 Mtetra
.794 .606 .647 r
.52729 .20945 .53098 .22288 .53775 .21076 .53406 .19553 Mtetra
.679 .524 .668 r
.53406 .19553 .53775 .21076 .54448 .19693 .54084 .18892 Mtetra
0 .206 .722 r
.54084 .18892 .54448 .19693 .5513 .19636 .54771 .19551 Mtetra
.68 .957 .947 r
.54771 .19551 .5513 .19636 .55827 .20757 .55454 .19179 Mtetra
.594 .466 .676 r
.55454 .19179 .55827 .20757 .56514 .20508 .56139 .18928 Mtetra
.746 .561 .645 r
.56139 .18928 .56514 .20508 .57219 .21305 .56813 .17769 Mtetra
.61 .408 .584 r
.56813 .17769 .57219 .21305 .57859 .18094 .57491 .16979 Mtetra
.792 .627 .677 r
.57491 .16979 .57859 .18094 .58508 .15909 .58162 .15866 Mtetra
.314 .8 .885 r
.58162 .15866 .58508 .15909 .59196 .15809 .58852 .15726 Mtetra
.974 .896 .683 r
.58852 .15726 .59196 .15809 .5988 .15412 .59515 .14367 Mtetra
.6 .533 .75 r
.59515 .14367 .5988 .15412 .60556 .14737 .60204 .14176 Mtetra
.413 .574 .903 r
.60204 .14176 .60556 .14737 .61246 .14491 .60904 .14268 Mtetra
0 .34 .737 r
.60904 .14268 .61246 .14491 .61945 .14498 .61614 .14589 Mtetra
.863 .992 .74 r
.61614 .14589 .61945 .14498 .62643 .14389 .6229 .1374 Mtetra
0 0 .355 r
.6229 .1374 .62643 .14389 .63373 .15079 .63043 .15091 Mtetra
.077 0 0 r
.63043 .15091 .63373 .15079 .64077 .14954 .63756 .15128 Mtetra
.721 .208 .001 r
.63756 .15128 .64077 .14954 .64805 .15346 .64502 .15901 Mtetra
0 0 0 r
.64502 .15901 .64805 .15346 .65505 .14986 .652 .15415 Mtetra
.51 .015 .015 r
.652 .15415 .65505 .14986 .66234 .15219 .65932 .15657 Mtetra
.303 0 0 r
.65932 .15657 .66234 .15219 .66962 .1535 .66654 .15587 Mtetra
.623 .092 0 r
.66654 .15587 .66962 .1535 .67664 .14894 .67407 .16099 Mtetra
0 0 0 r
.67407 .16099 .67664 .14894 .68419 .1542 .68037 .14149 Mtetra
.551 .474 .721 r
.68037 .14149 .68419 .1542 .69103 .14567 .68764 .14082 Mtetra
.886 .802 .761 r
.68764 .14082 .69103 .14567 .6979 .13793 .69442 .13121 Mtetra
.651 .659 .845 r
.69442 .13121 .6979 .13793 .70508 .1353 .70161 .12856 Mtetra
.724 .692 .819 r
.70161 .12856 .70508 .1353 .71204 .12893 .7087 .12408 Mtetra
.537 .687 .936 r
.7087 .12408 .71204 .12893 .71911 .12434 .71603 .12326 Mtetra
.723 .973 .928 r
.71603 .12326 .71911 .12434 .72687 .12953 .72315 .11875 Mtetra
.752 .616 .708 r
.72315 .11875 .72687 .12953 .7337 .12097 .73003 .11078 Mtetra
.579 .531 .765 r
.73003 .11078 .7337 .12097 .74031 .1095 .73739 .10943 Mtetra
.785 .285 0 r
.73739 .10943 .74031 .1095 .74787 .11074 .74579 .12165 Mtetra
.688 .266 .239 r
.09904 .34335 .10437 .33924 .10987 .33902 .10384 .34853 Mtetra
.59 .22 .309 r
.10384 .34853 .10987 .33902 .11463 .34463 .10891 .3519 Mtetra
.256 0 .037 r
.10891 .3519 .11463 .34463 .11944 .35021 .11473 .34976 Mtetra
.942 .79 .662 r
.11473 .34976 .11944 .35021 .12725 .33228 .12278 .33021 Mtetra
.899 .806 .748 r
.12278 .33021 .12725 .33228 .13328 .32825 .12965 .31963 Mtetra
.685 .596 .75 r
.12965 .31963 .13328 .32825 .1401 .31791 .13568 .31575 Mtetra
.181 .641 .938 r
.13568 .31575 .1401 .31791 .14571 .31743 .14116 .31635 Mtetra
.876 .466 .242 r
.14116 .31635 .14571 .31743 .15108 .31911 .14535 .32785 Mtetra
.572 .19 .28 r
.14535 .32785 .15108 .31911 .15735 .31334 .15064 .33066 Mtetra
.659 .339 .42 r
.15064 .33066 .15735 .31334 .16154 .32562 .15522 .33976 Mtetra
.392 .054 .268 r
.15522 .33976 .16154 .32562 .16721 .32535 .16115 .33759 Mtetra
0 0 .011 r
.16115 .33759 .16721 .32535 .17253 .32852 .16776 .32955 Mtetra
.682 .978 .881 r
.16776 .32955 .17253 .32852 .17946 .31728 .17392 .32549 Mtetra
.698 .329 .344 r
.17392 .32549 .17946 .31728 .18549 .31417 .17881 .33306 Mtetra
.345 .038 .293 r
.17881 .33306 .18549 .31417 .19061 .31968 .18507 .32844 Mtetra
0 0 0 r
.18507 .32844 .19061 .31968 .19658 .31748 .19144 .32275 Mtetra
.19144 .32275 .19658 .31748 .20257 .31528 .1979 .31621 Mtetra
.963 .857 .688 r
.1979 .31621 .20257 .31528 .2094 .30479 .20528 .30071 Mtetra
.662 .743 .91 r
.20528 .30071 .2094 .30479 .21683 .28812 .21128 .29848 Mtetra
.504 .133 .268 r
.21128 .29848 .21683 .28812 .22249 .28921 .21697 .29958 Mtetra
.341 0 .181 r
.21697 .29958 .22249 .28921 .22815 .29061 .22301 .29735 Mtetra
.733 .353 .33 r
.22301 .29735 .22815 .29061 .23369 .29356 .22802 .30614 Mtetra
.375 .026 .239 r
.22802 .30614 .23369 .29356 .23957 .29321 .23411 .30391 Mtetra
.636 .274 .34 r
.23411 .30391 .23957 .29321 .24481 .30019 .23949 .30954 Mtetra
0 0 0 r
.23949 .30954 .24481 .30019 .25123 .29428 .24612 .30172 Mtetra
.24612 .30172 .25123 .29428 .25707 .2951 .2525 .2966 Mtetra
.765 .996 .832 r
.2525 .2966 .25707 .2951 .26334 .29106 .25893 .29106 Mtetra
.825 .974 .891 r
.25893 .29106 .26334 .29106 .26888 .29612 .26534 .28563 Mtetra
.511 .47 .747 r
.26534 .28563 .26888 .29612 .27534 .29018 .27129 .28596 Mtetra
.914 .514 .158 r
.27129 .28596 .27534 .29018 .28093 .29533 .27604 .30169 Mtetra
.744 .899 .51 r
.27604 .30169 .28093 .29533 .28684 .29685 .28294 .29075 Mtetra
.867 .717 .693 r
.28294 .29075 .28684 .29685 .29375 .28536 .28999 .27758 Mtetra
.399 .471 .819 r
.28999 .27758 .29375 .28536 .30011 .28116 .29593 .27919 Mtetra
.678 .88 .974 r
.29593 .27919 .30011 .28116 .30663 .27477 .3022 .27646 Mtetra
0 0 0 r
.3022 .27646 .30663 .27477 .31341 .26445 .30846 .27415 Mtetra
.66 .793 .337 r
.30846 .27415 .31341 .26445 .3194 .26595 .31555 .25985 Mtetra
.109 .362 .826 r
.31555 .25985 .3194 .26595 .32584 .26071 .32143 .26329 Mtetra
.226 0 0 r
.32143 .26329 .32584 .26071 .33224 .25639 .3276 .26291 Mtetra
.286 0 .03 r
.3276 .26291 .33224 .25639 .33831 .25738 .33387 .26119 Mtetra
.316 0 0 r
.33387 .26119 .33831 .25738 .34501 .24825 .34007 .26092 Mtetra
.695 .767 .276 r
.34007 .26092 .34501 .24825 .35164 .24017 .34741 .24143 Mtetra
.958 .936 .72 r
.34741 .24143 .35164 .24017 .35823 .23251 .35425 .22978 Mtetra
.654 .121 0 r
.35425 .22978 .35823 .23251 .36451 .23075 .3601 .23618 Mtetra
.779 .381 .301 r
.3601 .23618 .36451 .23075 .37003 .24432 .36575 .24732 Mtetra
.903 .551 .364 r
.36575 .24732 .37003 .24432 .37503 .27025 .37064 .2752 Mtetra
.77 .36 .275 r
.37064 .2752 .37503 .27025 .38155 .26643 .37652 .28543 Mtetra
0 0 .155 r
.37652 .28543 .38155 .26643 .38874 .24755 .38355 .27164 Mtetra
.088 0 .236 r
.38355 .27164 .38874 .24755 .39506 .24788 .39061 .25665 Mtetra
0 0 0 r
.39061 .25665 .39506 .24788 .40152 .24551 .39752 .24435 Mtetra
.895 .921 .831 r
.39752 .24435 .40152 .24551 .40721 .26372 .40422 .23675 Mtetra
.372 .254 .587 r
.40422 .23675 .40721 .26372 .41353 .26733 .41035 .24425 Mtetra
.632 .452 .622 r
.41035 .24425 .41353 .26733 .42041 .25558 .41702 .23789 Mtetra
.585 .445 .657 r
.41702 .23789 .42041 .25558 .4271 .2492 .42356 .23549 Mtetra
.688 .541 .68 r
.42356 .23549 .4271 .2492 .43411 .23182 .43024 .22912 Mtetra
.086 .548 .905 r
.43024 .22912 .43411 .23182 .44071 .22749 .43669 .23067 Mtetra
.734 .274 .158 r
.43669 .23067 .44071 .22749 .44749 .21659 .44301 .2382 Mtetra
.146 0 .25 r
.44301 .2382 .44749 .21659 .45381 .22436 .44988 .22582 Mtetra
.993 .862 .6 r
.44988 .22582 .45381 .22436 .46045 .21996 .45691 .20532 Mtetra
.408 .352 .684 r
.45691 .20532 .46045 .21996 .46689 .22672 .46339 .20869 Mtetra
.49 .379 .655 r
.46339 .20869 .46689 .22672 .47349 .22697 .46995 .21015 Mtetra
.589 .453 .665 r
.46995 .21015 .47349 .22697 .48 .23531 .4766 .2077 Mtetra
.469 .323 .6 r
.4766 .2077 .48 .23531 .48671 .23287 .48319 .21096 Mtetra
.706 .508 .617 r
.48319 .21096 .48671 .23287 .49332 .2413 .49 .19874 Mtetra
.444 .278 .56 r
.49 .19874 .49332 .2413 .50022 .22241 .4966 .20551 Mtetra
.589 .454 .665 r
.4966 .20551 .50022 .22241 .5071 .19629 .50333 .20303 Mtetra
.08 0 0 r
.50333 .20303 .5071 .19629 .51377 .20485 .51008 .1986 Mtetra
0 .246 .759 r
.51008 .1986 .51377 .20485 .52049 .21974 .51682 .20397 Mtetra
.604 .472 .675 r
.51682 .20397 .52049 .21974 .52729 .20945 .52361 .201 Mtetra
.815 .676 .709 r
.52361 .201 .52729 .20945 .53406 .19553 .53041 .19092 Mtetra
.901 .786 .725 r
.53041 .19092 .53406 .19553 .54084 .18892 .53718 .17937 Mtetra
0 0 .415 r
.53718 .17937 .54084 .18892 .54771 .19551 .54408 .19349 Mtetra
.051 .561 .879 r
.54408 .19349 .54771 .19551 .55454 .19179 .55098 .19483 Mtetra
.822 .95 .601 r
.55098 .19483 .55454 .19179 .56139 .18928 .55777 .18443 Mtetra
.936 .772 .653 r
.55777 .18443 .56139 .18928 .56813 .17769 .56446 .1673 Mtetra
.678 .578 .736 r
.56446 .1673 .56813 .17769 .57491 .16979 .5713 .16285 Mtetra
.878 .726 .689 r
.5713 .16285 .57491 .16979 .58162 .15866 .57799 .1498 Mtetra
.69 .612 .764 r
.57799 .1498 .58162 .15866 .58852 .15726 .58483 .14552 Mtetra
.521 .465 .734 r
.58483 .14552 .58852 .15726 .59515 .14367 .59177 .1457 Mtetra
.632 .927 .665 r
.59177 .1457 .59515 .14367 .60204 .14176 .59859 .13934 Mtetra
.429 .778 .997 r
.59859 .13934 .60204 .14176 .60904 .14268 .60556 .13863 Mtetra
.509 .714 .964 r
.60556 .13863 .60904 .14268 .61614 .14589 .61255 .13796 Mtetra
.087 .277 .76 r
.61255 .13796 .61614 .14589 .6229 .1374 .61978 .14373 Mtetra
.742 .313 .231 r
.61978 .14373 .6229 .1374 .63043 .15091 .62722 .154 Mtetra
.123 0 0 r
.62722 .154 .63043 .15091 .63756 .15128 .6343 .15234 Mtetra
.081 0 0 r
.6343 .15234 .63756 .15128 .64502 .15901 .64145 .15195 Mtetra
.335 .471 .849 r
.64145 .15195 .64502 .15901 .652 .15415 .64875 .15436 Mtetra
.208 0 0 r
.64875 .15436 .652 .15415 .65932 .15657 .65603 .15557 Mtetra
.594 .027 0 r
.65603 .15557 .65932 .15657 .66654 .15587 .66359 .16187 Mtetra
0 0 0 r
.66359 .16187 .66654 .15587 .67407 .16099 .67059 .15538 Mtetra
.895 .775 .721 r
.67059 .15538 .67407 .16099 .68037 .14149 .67733 .14383 Mtetra
.695 .923 .597 r
.67733 .14383 .68037 .14149 .68764 .14082 .68422 .13557 Mtetra
.835 .782 .801 r
.68422 .13557 .68764 .14082 .69442 .13121 .69115 .12818 Mtetra
.847 .89 .87 r
.69115 .12818 .69442 .13121 .70161 .12856 .69813 .12183 Mtetra
.334 .484 .86 r
.69813 .12183 .70161 .12856 .7087 .12408 .70565 .12417 Mtetra
.399 .855 .834 r
.70565 .12417 .7087 .12408 .71603 .12326 .71289 .1215 Mtetra
.893 .952 .835 r
.71289 .1215 .71603 .12326 .72315 .11875 .71982 .11382 Mtetra
.662 .743 .91 r
.71982 .11382 .72315 .11875 .73003 .11078 .72709 .11113 Mtetra
.768 .993 .787 r
.72709 .11113 .73003 .11078 .73739 .10943 .73409 .10446 Mtetra
0 .156 .689 r
.73409 .10446 .73739 .10943 .74579 .12165 .74211 .11156 Mtetra
.773 .853 .911 r
.09451 .34119 .09904 .34335 .10384 .34853 .10053 .33727 Mtetra
0 .076 .608 r
.10053 .33727 .10384 .34853 .10891 .3519 .1051 .34433 Mtetra
.641 .599 .791 r
.1051 .34433 .10891 .3519 .11473 .34976 .11093 .34207 Mtetra
.841 .675 .677 r
.11093 .34207 .11473 .34976 .12278 .33021 .11832 .32784 Mtetra
.903 .788 .725 r
.11832 .32784 .12278 .33021 .12965 .31963 .12541 .31572 Mtetra
.496 .69 .954 r
.12541 .31572 .12965 .31963 .13568 .31575 .13101 .31536 Mtetra
.832 .392 .186 r
.13101 .31536 .13568 .31575 .14116 .31635 .13549 .32412 Mtetra
.725 .361 .359 r
.13549 .32412 .14116 .31635 .14535 .32785 .14002 .33291 Mtetra
.835 .488 .399 r
.14002 .33291 .14535 .32785 .15064 .33066 .14365 .34963 Mtetra
.64 .323 .42 r
.14365 .34963 .15064 .33066 .15522 .33976 .14836 .35788 Mtetra
.267 0 .247 r
.14836 .35788 .15522 .33976 .16115 .33759 .1548 .35175 Mtetra
0 0 0 r
.1548 .35175 .16115 .33759 .16776 .32955 .16175 .34124 Mtetra
.16175 .34124 .16776 .32955 .17392 .32549 .1684 .33317 Mtetra
.269 0 .059 r
.1684 .33317 .17392 .32549 .17881 .33306 .17439 .33097 Mtetra
.643 .856 .981 r
.17439 .33097 .17881 .33306 .18507 .32844 .18039 .32877 Mtetra
.922 .922 .794 r
.18039 .32877 .18507 .32844 .19144 .32275 .18713 .31983 Mtetra
.866 .807 .79 r
.18713 .31983 .19144 .32275 .1979 .31621 .19376 .3118 Mtetra
.888 .744 .697 r
.19376 .3118 .1979 .31621 .20528 .30071 .20099 .29802 Mtetra
.651 .108 0 r
.20099 .29802 .20528 .30071 .21128 .29848 .20622 .30344 Mtetra
.689 .918 .588 r
.20622 .30344 .21128 .29848 .21697 .29958 .21284 .29546 Mtetra
.494 .683 .95 r
.21284 .29546 .21697 .29958 .22301 .29735 .2187 .29513 Mtetra
.63 .074 0 r
.2187 .29513 .22301 .29735 .22802 .30614 .22407 .30013 Mtetra
.531 .605 .873 r
.22407 .30013 .22802 .30614 .23411 .30391 .22998 .29976 Mtetra
.543 .704 .945 r
.22998 .29976 .23411 .30391 .23949 .30954 .23596 .29897 Mtetra
.748 .604 .697 r
.23596 .29897 .23949 .30954 .24612 .30172 .24261 .29095 Mtetra
.741 .598 .697 r
.24261 .29095 .24612 .30172 .2525 .2966 .24923 .28321 Mtetra
.601 .486 .694 r
.24923 .28321 .2525 .2966 .25893 .29106 .25536 .28094 Mtetra
.62 .54 .743 r
.25536 .28094 .25893 .29106 .26534 .28563 .26151 .27863 Mtetra
.116 .326 .796 r
.26151 .27863 .26534 .28563 .27129 .28596 .26717 .28241 Mtetra
.815 .8 .838 r
.26717 .28241 .27129 .28596 .27604 .30169 .27365 .27666 Mtetra
.656 .464 .612 r
.27365 .27666 .27604 .30169 .28294 .29075 .28037 .26775 Mtetra
.683 .489 .618 r
.28037 .26775 .28294 .29075 .28999 .27758 .2872 .25726 Mtetra
.492 .362 .632 r
.2872 .25726 .28999 .27758 .29593 .27919 .29312 .25866 Mtetra
.536 .393 .634 r
.29312 .25866 .29593 .27919 .3022 .27646 .2992 .25823 Mtetra
.703 .52 .638 r
.2992 .25823 .3022 .27646 .30846 .27415 .30597 .24851 Mtetra
.427 .294 .596 r
.30597 .24851 .30846 .27415 .31555 .25985 .31173 .25312 Mtetra
.646 .635 .825 r
.31173 .25312 .31555 .25985 .32143 .26329 .31799 .25079 Mtetra
.686 .548 .693 r
.31799 .25079 .32143 .26329 .3276 .26291 .32449 .24517 Mtetra
.352 .282 .637 r
.32449 .24517 .3276 .26291 .33387 .26119 .3303 .25041 Mtetra
.633 .539 .731 r
.3303 .25041 .33387 .26119 .34007 .26092 .33666 .24753 Mtetra
.696 .547 .68 r
.33666 .24753 .34007 .26092 .34741 .24143 .34325 .2409 Mtetra
.953 .877 .723 r
.34325 .2409 .34741 .24143 .35425 .22978 .35016 .22851 Mtetra
.643 .084 0 r
.35016 .22851 .35425 .22978 .3601 .23618 .35608 .23376 Mtetra
.778 .277 0 r
.35608 .23376 .3601 .23618 .36575 .24732 .36187 .24228 Mtetra
.908 .51 .109 r
.36187 .24228 .36575 .24732 .37064 .2752 .36724 .26009 Mtetra
.336 .298 .667 r
.36724 .26009 .37064 .2752 .37652 .28543 .37334 .26499 Mtetra
.791 .572 .604 r
.37334 .26499 .37652 .28543 .38355 .27164 .38077 .24274 Mtetra
.687 .477 .597 r
.38077 .24274 .38355 .27164 .39061 .25665 .38776 .22879 Mtetra
.654 .455 .602 r
.38776 .22879 .39061 .25665 .39752 .24435 .39454 .21887 Mtetra
.594 .417 .612 r
.39454 .21887 .39752 .24435 .40422 .23675 .40107 .2146 Mtetra
.118 .093 .551 r
.40107 .2146 .40422 .23675 .41035 .24425 .40694 .22782 Mtetra
.764 .569 .634 r
.40694 .22782 .41035 .24425 .41702 .23789 .41388 .21366 Mtetra
.626 .444 .616 r
.41388 .21366 .41702 .23789 .42356 .23549 .42053 .20735 Mtetra
.532 .365 .6 r
.42053 .20735 .42356 .23549 .43024 .22912 .42698 .20686 Mtetra
.495 .358 .624 r
.42698 .20686 .43024 .22912 .43669 .23067 .4334 .20833 Mtetra
.184 .14 .571 r
.4334 .20833 .43669 .23067 .44301 .2382 .43956 .22025 Mtetra
.539 .412 .656 r
.43956 .22025 .44301 .2382 .44988 .22582 .44611 .2198 Mtetra
.842 .732 .743 r
.44611 .2198 .44988 .22582 .45691 .20532 .4529 .21053 Mtetra
0 0 0 r
.4529 .21053 .45691 .20532 .46339 .20869 .45966 .20222 Mtetra
.54 .602 .865 r
.45966 .20222 .46339 .20869 .46995 .21015 .46625 .2017 Mtetra
.634 .59 .787 r
.46625 .2017 .46995 .21015 .4766 .2077 .47291 .19924 Mtetra
.547 .543 .802 r
.47291 .19924 .4766 .2077 .48319 .21096 .47955 .19872 Mtetra
.546 .471 .723 r
.47955 .19872 .48319 .21096 .49 .19874 .48621 .19821 Mtetra
.091 .644 .808 r
.48621 .19821 .49 .19874 .4966 .20551 .4929 .19815 Mtetra
.716 .658 .792 r
.4929 .19815 .4966 .20551 .50333 .20303 .49965 .19368 Mtetra
.157 .282 .742 r
.49965 .19368 .50333 .20303 .51008 .1986 .50634 .19913 Mtetra
.653 .104 0 r
.50634 .19913 .51008 .1986 .51682 .20397 .51309 .20464 Mtetra
.97 .929 .682 r
.51309 .20464 .51682 .20397 .52361 .201 .51992 .19148 Mtetra
.826 .663 .68 r
.51992 .19148 .52361 .201 .53041 .19092 .52673 .17918 Mtetra
.47 .433 .735 r
.52673 .17918 .53041 .19092 .53718 .17937 .53354 .18055 Mtetra
.648 .107 0 r
.53354 .18055 .53718 .17937 .54408 .19349 .54041 .1859 Mtetra
.545 .571 .832 r
.54041 .1859 .54408 .19349 .55098 .19483 .54728 .18536 Mtetra
.776 .643 .715 r
.54728 .18536 .55098 .19483 .55777 .18443 .55411 .17689 Mtetra
.87 .712 .683 r
.55411 .17689 .55777 .18443 .56446 .1673 .56087 .16351 Mtetra
.662 .792 .944 r
.56087 .16351 .56446 .1673 .5713 .16285 .56775 .16096 Mtetra
.944 .889 .746 r
.56775 .16096 .5713 .16285 .57799 .1498 .5745 .14998 Mtetra
.816 .999 .834 r
.5745 .14998 .57799 .1498 .58483 .14552 .58132 .14352 Mtetra
0 .5 .838 r
.58132 .14352 .58483 .14552 .59177 .1457 .58832 .14534 Mtetra
.159 .698 .82 r
.58832 .14534 .59177 .1457 .59859 .13934 .5953 .14474 Mtetra
.566 .101 .11 r
.5953 .14474 .59859 .13934 .60556 .13863 .6024 .1481 Mtetra
.217 0 .117 r
.6024 .1481 .60556 .13863 .61255 .13796 .60933 .14352 Mtetra
.712 .267 .191 r
.60933 .14352 .61255 .13796 .61978 .14373 .61666 .1518 Mtetra
.622 .202 .225 r
.61666 .1518 .61978 .14373 .62722 .154 .62397 .15714 Mtetra
.56 .85 .524 r
.62397 .15714 .62722 .154 .6343 .15234 .63087 .14975 Mtetra
.64 .865 .984 r
.63087 .14975 .6343 .15234 .64145 .15195 .63796 .14713 Mtetra
.212 .501 .905 r
.63796 .14713 .64145 .15195 .64875 .15436 .64526 .14953 Mtetra
.817 .793 .83 r
.64526 .14953 .64875 .15436 .65603 .15557 .65223 .14314 Mtetra
.486 .437 .728 r
.65223 .14314 .65603 .15557 .66359 .16187 .65954 .14428 Mtetra
.498 .393 .666 r
.65954 .14428 .66359 .16187 .67059 .15538 .66689 .14547 Mtetra
.823 .662 .684 r
.66689 .14547 .67059 .15538 .67733 .14383 .67363 .13371 Mtetra
.802 .65 .694 r
.67363 .13371 .67733 .14383 .68422 .13557 .68041 .12327 Mtetra
.821 .632 .648 r
.68041 .12327 .68422 .13557 .69115 .12818 .68695 .1088 Mtetra
.627 .465 .644 r
.68695 .1088 .69115 .12818 .69813 .12183 .69398 .10362 Mtetra
.505 .393 .66 r
.69398 .10362 .69813 .12183 .70565 .12417 .70139 .10456 Mtetra
.597 .445 .646 r
.70139 .10456 .70565 .12417 .71289 .1215 .70855 .10104 Mtetra
.535 .4 .643 r
.70855 .10104 .71289 .1215 .71982 .11382 .71594 .10063 Mtetra
.568 .479 .714 r
.71594 .10063 .71982 .11382 .72709 .11113 .72329 .09931 Mtetra
.745 .598 .694 r
.72329 .09931 .72709 .11113 .73409 .10446 .73017 .09099 Mtetra
.575 .48 .709 r
.73017 .09099 .73409 .10446 .74211 .11156 .73754 .08939 Mtetra
.18 .701 .876 r
.08977 .34043 .09451 .34119 .10053 .33727 .0953 .34021 Mtetra
.576 .921 .721 r
.0953 .34021 .10053 .33727 .1051 .34433 .10144 .3356 Mtetra
.732 .617 .73 r
.10144 .3356 .1051 .34433 .11093 .34207 .10775 .3297 Mtetra
.808 .618 .646 r
.10775 .3297 .11093 .34207 .11832 .32784 .11544 .3132 Mtetra
.619 .484 .675 r
.11544 .3132 .11832 .32784 .12541 .31572 .12139 .31 Mtetra
.896 .49 .078 r
.12139 .31 .12541 .31572 .13101 .31536 .12539 .3222 Mtetra
.824 .488 .42 r
.12539 .3222 .13101 .31536 .13549 .32412 .12872 .34024 Mtetra
.725 .407 .44 r
.12872 .34024 .13549 .32412 .14002 .33291 .13255 .35485 Mtetra
.698 .392 .454 r
.13255 .35485 .14002 .33291 .14365 .34963 .13639 .37006 Mtetra
.566 .251 .395 r
.13639 .37006 .14365 .34963 .14836 .35788 .14167 .37389 Mtetra
0 0 .071 r
.14167 .37389 .14836 .35788 .1548 .35175 .14864 .36372 Mtetra
0 0 0 r
.14864 .36372 .1548 .35175 .16175 .34124 .15605 .34961 Mtetra
.693 .861 .453 r
.15605 .34961 .16175 .34124 .1684 .33317 .16312 .33815 Mtetra
.361 0 0 r
.16312 .33815 .1684 .33317 .17439 .33097 .16891 .33792 Mtetra
.587 .829 .453 r
.16891 .33792 .17439 .33097 .18039 .32877 .17568 .32907 Mtetra
.943 .886 .747 r
.17568 .32907 .18039 .32877 .18713 .31983 .18271 .31769 Mtetra
0 .456 .801 r
.18271 .31769 .18713 .31983 .19376 .3118 .18833 .31938 Mtetra
.679 .862 .463 r
.18833 .31938 .19376 .3118 .20099 .29802 .19526 .30872 Mtetra
.063 0 .034 r
.19526 .30872 .20099 .29802 .20622 .30344 .20171 .30271 Mtetra
.574 .909 .975 r
.20171 .30271 .20622 .30344 .21284 .29546 .20776 .30047 Mtetra
.349 0 0 r
.20776 .30047 .21284 .29546 .2187 .29513 .21365 .30011 Mtetra
.204 0 0 r
.21365 .30011 .2187 .29513 .22407 .30013 .21968 .29844 Mtetra
.781 .897 .925 r
.21968 .29844 .22407 .30013 .22998 .29976 .22597 .29424 Mtetra
.845 .725 .73 r
.22597 .29424 .22998 .29976 .23596 .29897 .23282 .28425 Mtetra
.538 .432 .681 r
.23282 .28425 .23596 .29897 .24261 .29095 .23876 .2839 Mtetra
.642 .621 .814 r
.23876 .2839 .24261 .29095 .24923 .28321 .24489 .28163 Mtetra
.78 .907 .929 r
.24489 .28163 .24923 .28321 .25536 .28094 .25121 .27742 Mtetra
.882 .786 .751 r
.25121 .27742 .25536 .28094 .26151 .27863 .25803 .26746 Mtetra
.699 .57 .706 r
.25803 .26746 .26151 .27863 .26717 .28241 .26447 .26182 Mtetra
.454 .334 .626 r
.26447 .26182 .26717 .28241 .27365 .27666 .27023 .26454 Mtetra
.812 .624 .647 r
.27023 .26454 .27365 .27666 .28037 .26775 .27749 .24888 Mtetra
.374 .287 .628 r
.27749 .24888 .28037 .26775 .2872 .25726 .28311 .25371 Mtetra
.742 .798 .898 r
.28311 .25371 .2872 .25726 .29312 .25866 .28942 .25005 Mtetra
.62 .571 .778 r
.28942 .25005 .29312 .25866 .2992 .25823 .29562 .248 Mtetra
.628 .544 .74 r
.29562 .248 .2992 .25823 .30597 .24851 .30188 .2454 Mtetra
.592 .788 .974 r
.30188 .2454 .30597 .24851 .31173 .25312 .30808 .24384 Mtetra
.664 .581 .752 r
.30808 .24384 .31173 .25312 .31799 .25079 .31442 .24036 Mtetra
.671 .565 .728 r
.31442 .24036 .31799 .25079 .32449 .24517 .32082 .23625 Mtetra
.076 .233 .723 r
.32082 .23625 .32449 .24517 .3303 .25041 .32661 .24164 Mtetra
.778 .646 .716 r
.32661 .24164 .3303 .25041 .33666 .24753 .3333 .23333 Mtetra
.472 .396 .689 r
.3333 .23333 .33666 .24753 .34325 .2409 .33939 .23483 Mtetra
.891 .724 .669 r
.33939 .23483 .34325 .2409 .35016 .22851 .34654 .21886 Mtetra
0 0 .357 r
.34654 .21886 .35016 .22851 .35608 .23376 .35203 .23134 Mtetra
0 .219 .626 r
.35203 .23134 .35608 .23376 .36187 .24228 .35809 .23483 Mtetra
0 0 .388 r
.35809 .23483 .36187 .24228 .36724 .26009 .36384 .24511 Mtetra
.594 .47 .68 r
.36384 .24511 .36724 .26009 .37334 .26499 .37029 .24273 Mtetra
.703 .505 .617 r
.37029 .24273 .37334 .26499 .38077 .24274 .37722 .23061 Mtetra
.856 .647 .619 r
.37722 .23061 .38077 .24274 .38776 .22879 .38459 .20848 Mtetra
.52 .384 .636 r
.38459 .20848 .38776 .22879 .39454 .21887 .39091 .20871 Mtetra
.713 .595 .722 r
.39091 .20871 .39454 .21887 .40107 .2146 .39751 .20294 Mtetra
.598 .508 .723 r
.39751 .20294 .40107 .2146 .40694 .22782 .40396 .20095 Mtetra
.591 .411 .606 r
.40396 .20095 .40694 .22782 .41388 .21366 .41051 .19656 Mtetra
.587 .449 .66 r
.41051 .19656 .41388 .21366 .42053 .20735 .417 .19412 Mtetra
.603 .492 .7 r
.417 .19412 .42053 .20735 .42698 .20686 .42351 .19168 Mtetra
.369 .319 .671 r
.42351 .19168 .42698 .20686 .4334 .20833 .42982 .19597 Mtetra
.468 .419 .72 r
.42982 .19597 .4334 .20833 .43956 .22025 .43626 .1974 Mtetra
.192 .143 .57 r
.43626 .1974 .43956 .22025 .44611 .2198 .44245 .20932 Mtetra
.767 .62 .697 r
.44245 .20932 .44611 .2198 .4529 .21053 .44924 .20039 Mtetra
.848 .662 .65 r
.44924 .20039 .4529 .21053 .45966 .20222 .45618 .18428 Mtetra
.54 .413 .656 r
.45618 .18428 .45966 .20222 .46625 .2017 .46275 .18373 Mtetra
.584 .442 .654 r
.46275 .18373 .46625 .2017 .47291 .19924 .46939 .18124 Mtetra
.316 .261 .636 r
.46939 .18124 .47291 .19924 .47955 .19872 .47589 .18786 Mtetra
.557 .499 .746 r
.47589 .18786 .47955 .19872 .48621 .19821 .48255 .18707 Mtetra
.279 .32 .726 r
.48255 .18707 .48621 .19821 .4929 .19815 .48918 .19173 Mtetra
.543 .609 .869 r
.48918 .19173 .4929 .19815 .49965 .19368 .4959 .19114 Mtetra
.689 .871 .967 r
.4959 .19114 .49965 .19368 .50634 .19913 .50266 .1881 Mtetra
.547 .491 .745 r
.50266 .1881 .50634 .19913 .51309 .20464 .50943 .18756 Mtetra
.253 .228 .636 r
.50943 .18756 .51309 .20464 .51992 .19148 .51619 .1955 Mtetra
0 0 0 r
.51619 .1955 .51992 .19148 .52673 .17918 .52303 .18898 Mtetra
.039 0 .044 r
.52303 .18898 .52673 .17918 .53354 .18055 .52987 .18179 Mtetra
.264 .758 .685 r
.52987 .18179 .53354 .18055 .54041 .1859 .53672 .17925 Mtetra
.727 .688 .813 r
.53672 .17925 .54041 .1859 .54728 .18536 .54358 .17474 Mtetra
.62 .542 .746 r
.54358 .17474 .54728 .18536 .55411 .17689 .55046 .17219 Mtetra
.877 .791 .762 r
.55046 .17219 .55411 .17689 .56087 .16351 .55729 .16276 Mtetra
.532 .909 .949 r
.55729 .16276 .56087 .16351 .56775 .16096 .56419 .1602 Mtetra
.914 .959 .803 r
.56419 .1602 .56775 .16096 .5745 .14998 .57101 .15167 Mtetra
.824 .983 .702 r
.57101 .15167 .5745 .14998 .58132 .14352 .57783 .14316 Mtetra
.735 .208 0 r
.57783 .14316 .58132 .14352 .58832 .14534 .58497 .15151 Mtetra
.474 .023 .098 r
.58497 .15151 .58832 .14534 .5953 .14474 .59203 .15283 Mtetra
.162 0 .047 r
.59203 .15283 .5953 .14474 .6024 .1481 .59897 .14827 Mtetra
.083 .643 .729 r
.59897 .14827 .6024 .1481 .60933 .14352 .60603 .14763 Mtetra
.685 .208 .112 r
.60603 .14763 .60933 .14352 .61666 .1518 .61334 .15439 Mtetra
.723 .934 .606 r
.61334 .15439 .61666 .1518 .62397 .15714 .62022 .14585 Mtetra
.671 .564 .725 r
.62022 .14585 .62397 .15714 .63087 .14975 .62723 .14126 Mtetra
.443 .491 .814 r
.62723 .14126 .63087 .14975 .63796 .14713 .63446 .14258 Mtetra
.769 .794 .873 r
.63446 .14258 .63796 .14713 .64526 .14953 .64149 .13777 Mtetra
.614 .524 .73 r
.64149 .13777 .64526 .14953 .65223 .14314 .64861 .13513 Mtetra
.64 .615 .808 r
.64861 .13513 .65223 .14314 .65954 .14428 .65576 .13248 Mtetra
.665 .554 .719 r
.65576 .13248 .65954 .14428 .66689 .14547 .66283 .12796 Mtetra
.652 .492 .655 r
.66283 .12796 .66689 .14547 .67363 .13371 .66984 .12191 Mtetra
.667 .555 .719 r
.66984 .12191 .67363 .13371 .68041 .12327 .67693 .11728 Mtetra
.947 .759 .616 r
.67693 .11728 .68041 .12327 .68695 .1088 .68319 .09724 Mtetra
.586 .511 .737 r
.68319 .09724 .68695 .1088 .69398 .10362 .69041 .09549 Mtetra
.042 .242 .741 r
.69041 .09549 .69398 .10362 .70139 .10456 .69817 .10227 Mtetra
.785 .929 .929 r
.69817 .10227 .70139 .10456 .70855 .10104 .70527 .09737 Mtetra
.691 .826 .948 r
.70527 .09737 .70855 .10104 .71594 .10063 .71249 .0942 Mtetra
.782 .729 .803 r
.71249 .0942 .71594 .10063 .72329 .09931 .71953 .08806 Mtetra
.625 .54 .738 r
.71953 .08806 .72329 .09931 .73017 .09099 .72679 .0851 Mtetra
.504 .622 .901 r
.72679 .0851 .73017 .09099 .73754 .08939 .73427 .0849 Mtetra
.436 .301 .598 r
.0882 .31659 .08977 .34043 .0953 .34021 .09319 .32009 Mtetra
.547 .399 .632 r
.09319 .32009 .0953 .34021 .10144 .3356 .09881 .31917 Mtetra
.702 .528 .649 r
.09881 .31917 .10144 .3356 .10775 .3297 .10548 .31049 Mtetra
.549 .405 .638 r
.10548 .31049 .10775 .3297 .11544 .3132 .11113 .30952 Mtetra
.714 .77 .897 r
.11113 .30952 .11544 .3132 .12139 .31 .11706 .30651 Mtetra
.94 .608 .374 r
.11706 .30651 .12139 .31 .12539 .3222 .11945 .33111 Mtetra
.797 .463 .423 r
.11945 .33111 .12539 .3222 .12872 .34024 .12293 .34791 Mtetra
.816 .481 .421 r
.12293 .34791 .12872 .34024 .13255 .35485 .12634 .36601 Mtetra
.644 .289 .355 r
.12634 .36601 .13255 .35485 .13639 .37006 .13131 .37206 Mtetra
.684 .206 .109 r
.13131 .37206 .13639 .37006 .14167 .37389 .13648 .37683 Mtetra
.969 .913 .698 r
.13648 .37683 .14167 .37389 .14864 .36372 .14396 .36266 Mtetra
.933 .819 .71 r
.14396 .36266 .14864 .36372 .15605 .34961 .15139 .34859 Mtetra
.882 .892 .835 r
.15139 .34859 .15605 .34961 .16312 .33815 .158 .34139 Mtetra
.822 .993 .745 r
.158 .34139 .16312 .33815 .16891 .33792 .16465 .33378 Mtetra
.793 .765 .828 r
.16465 .33378 .16891 .33792 .17568 .32907 .17105 .32838 Mtetra
.901 .896 .813 r
.17105 .32838 .17568 .32907 .18271 .31769 .17775 .32028 Mtetra
.48 0 0 r
.17775 .32028 .18271 .31769 .18833 .31938 .18337 .32197 Mtetra
.976 .886 .673 r
.18337 .32197 .18833 .31938 .19526 .30872 .19094 .30569 Mtetra
.861 .806 .795 r
.19094 .30569 .19526 .30872 .20171 .30271 .19759 .29787 Mtetra
.808 .354 0 r
.19759 .29787 .20171 .30271 .20776 .30047 .20244 .30743 Mtetra
.601 .192 .24 r
.20244 .30743 .20776 .30047 .21365 .30011 .20795 .31105 Mtetra
.746 .84 .39 r
.20795 .31105 .21365 .30011 .21968 .29844 .21544 .29504 Mtetra
.826 .802 .828 r
.21544 .29504 .21968 .29844 .22597 .29424 .22193 .28886 Mtetra
.825 .728 .758 r
.22193 .28886 .22597 .29424 .23282 .28425 .22861 .28075 Mtetra
.13 .53 .917 r
.22861 .28075 .23282 .28425 .23876 .2839 .23438 .28236 Mtetra
.865 .889 .851 r
.23438 .28236 .23876 .2839 .24489 .28163 .24091 .2758 Mtetra
.782 .709 .782 r
.24091 .2758 .24489 .28163 .25121 .27742 .24741 .26967 Mtetra
.795 .667 .722 r
.24741 .26967 .25121 .27742 .25803 .26746 .25413 .26101 Mtetra
.532 .591 .859 r
.25413 .26101 .25803 .26746 .26447 .26182 .26013 .26064 Mtetra
.947 .823 .689 r
.26013 .26064 .26447 .26182 .27023 .26454 .2674 .24539 Mtetra
.553 .411 .642 r
.2674 .24539 .27023 .26454 .27749 .24888 .27347 .24425 Mtetra
0 .297 .787 r
.27347 .24425 .27749 .24888 .28311 .25371 .27919 .24785 Mtetra
.641 .664 .856 r
.27919 .24785 .28311 .25371 .28942 .25005 .28539 .24576 Mtetra
.645 .737 .916 r
.28539 .24576 .28942 .25005 .29562 .248 .29159 .24369 Mtetra
.663 .742 .909 r
.29159 .24369 .29562 .248 .30188 .2454 .29784 .24135 Mtetra
.888 .773 .73 r
.29784 .24135 .30188 .2454 .30808 .24384 .30474 .23018 Mtetra
.596 .481 .692 r
.30474 .23018 .30808 .24384 .31442 .24036 .31099 .22795 Mtetra
.381 .358 .708 r
.31099 .22795 .31442 .24036 .32082 .23625 .31689 .23101 Mtetra
0 0 .479 r
.31689 .23101 .32082 .23625 .32661 .24164 .32257 .23801 Mtetra
.489 .719 .973 r
.32257 .23801 .32661 .24164 .3333 .23333 .32878 .2375 Mtetra
.9 .961 .632 r
.32878 .2375 .3333 .23333 .33939 .23483 .33572 .22567 Mtetra
.783 .643 .706 r
.33572 .22567 .33939 .23483 .34654 .21886 .34247 .21665 Mtetra
.758 .247 0 r
.34247 .21665 .34654 .21886 .35203 .23134 .34822 .22447 Mtetra
.409 .514 .854 r
.34822 .22447 .35203 .23134 .35809 .23483 .35441 .22568 Mtetra
.438 .459 .785 r
.35441 .22568 .35809 .23483 .36384 .24511 .36061 .22708 Mtetra
.679 .505 .644 r
.36061 .22708 .36384 .24511 .37029 .24273 .36732 .21922 Mtetra
.653 .465 .617 r
.36732 .21922 .37029 .24273 .37722 .23061 .37405 .211 Mtetra
.701 .512 .63 r
.37405 .211 .37722 .23061 .38459 .20848 .38086 .20061 Mtetra
.663 .615 .79 r
.38086 .20061 .38459 .20848 .39091 .20871 .38733 .19755 Mtetra
.373 .376 .734 r
.38733 .19755 .39091 .20871 .39751 .20294 .39355 .2005 Mtetra
.118 .587 .917 r
.39355 .2005 .39751 .20294 .40396 .20095 .39988 .20165 Mtetra
.532 .923 .848 r
.39988 .20165 .40396 .20095 .41051 .19656 .40642 .19828 Mtetra
.749 .987 .772 r
.40642 .19828 .41051 .19656 .417 .19412 .41308 .19199 Mtetra
.813 .898 .902 r
.41308 .19199 .417 .19412 .42351 .19168 .41969 .1869 Mtetra
.005 .365 .835 r
.41969 .1869 .42351 .19168 .42982 .19597 .42603 .19035 Mtetra
0 0 .407 r
.42603 .19035 .42982 .19597 .43626 .1974 .43224 .1994 Mtetra
.154 0 0 r
.43224 .1994 .43626 .1974 .44245 .20932 .43879 .19889 Mtetra
.735 .605 .713 r
.43879 .19889 .44245 .20932 .44924 .20039 .44553 .1919 Mtetra
.837 .68 .687 r
.44553 .1919 .44924 .20039 .45618 .18428 .45239 .1797 Mtetra
.663 .742 .909 r
.45239 .1797 .45618 .18428 .46275 .18373 .45902 .17721 Mtetra
.65 .655 .841 r
.45902 .17721 .46275 .18373 .46939 .18124 .46566 .17472 Mtetra
.73 .327 0 r
.46566 .17472 .46939 .18124 .47589 .18786 .47203 .18836 Mtetra
0 0 0 r
.47203 .18836 .47589 .18786 .48255 .18707 .47871 .18773 Mtetra
.47871 .18773 .48255 .18707 .48918 .19173 .48542 .18711 Mtetra
.042 .402 .856 r
.48542 .18711 .48918 .19173 .4959 .19114 .4921 .19035 Mtetra
.777 .973 .917 r
.4921 .19035 .4959 .19114 .50266 .1881 .4989 .18543 Mtetra
.647 .853 .979 r
.4989 .18543 .50266 .1881 .50943 .18756 .5057 .18291 Mtetra
.74 .288 0 r
.5057 .18291 .50943 .18756 .51619 .1955 .51244 .19486 Mtetra
.523 .907 .944 r
.51244 .19486 .51619 .1955 .52303 .18898 .5193 .19234 Mtetra
.906 .944 .586 r
.5193 .19234 .52303 .18898 .52987 .18179 .52617 .17908 Mtetra
.853 .883 .86 r
.52617 .17908 .52987 .18179 .53672 .17925 .53303 .17258 Mtetra
.727 .688 .813 r
.53303 .17258 .53672 .17925 .54358 .17474 .5399 .16806 Mtetra
.542 .603 .864 r
.5399 .16806 .54358 .17474 .55046 .17219 .5468 .16747 Mtetra
.561 .702 .935 r
.5468 .16747 .55046 .17219 .55729 .16276 .55372 .16636 Mtetra
.041 0 0 r
.55372 .16636 .55729 .16276 .56419 .1602 .56065 .16379 Mtetra
0 0 0 r
.56065 .16379 .56419 .1602 .57101 .15167 .56755 .15728 Mtetra
.56755 .15728 .57101 .15167 .57783 .14316 .57444 .1508 Mtetra
.505 .08 .166 r
.57444 .1508 .57783 .14316 .58497 .15151 .58149 .1526 Mtetra
.805 .326 .071 r
.58149 .1526 .58497 .15151 .59203 .15283 .58878 .16394 Mtetra
0 0 .028 r
.58878 .16394 .59203 .15283 .59897 .14827 .59562 .15281 Mtetra
0 0 0 r
.59562 .15281 .59897 .14827 .60603 .14763 .60251 .14429 Mtetra
.657 .825 .964 r
.60251 .14429 .60603 .14763 .61334 .15439 .60955 .14167 Mtetra
.735 .582 .683 r
.60955 .14167 .61334 .15439 .62022 .14585 .61643 .1332 Mtetra
.305 .317 .709 r
.61643 .1332 .62022 .14585 .62723 .14126 .62376 .13838 Mtetra
.9 .883 .807 r
.62376 .13838 .62723 .14126 .63446 .14258 .63065 .12986 Mtetra
.399 .378 .72 r
.63065 .12986 .63446 .14258 .64149 .13777 .63798 .13309 Mtetra
.825 .802 .83 r
.63798 .13309 .64149 .13777 .64861 .13513 .64496 .12651 Mtetra
.527 .537 .809 r
.64496 .12651 .64861 .13513 .65576 .13248 .65222 .12632 Mtetra
.738 .719 .833 r
.65222 .12632 .65576 .13248 .66283 .12796 .6593 .12167 Mtetra
.883 .755 .716 r
.6593 .12167 .66283 .12796 .66984 .12191 .66606 .11012 Mtetra
.55 .487 .737 r
.66606 .11012 .66984 .12191 .67693 .11728 .67334 .10941 Mtetra
.822 .701 .73 r
.67334 .10941 .67693 .11728 .68319 .09724 .68019 .10009 Mtetra
.588 .862 .53 r
.68019 .10009 .68319 .09724 .69041 .09549 .68712 .09234 Mtetra
.361 .699 .984 r
.68712 .09234 .69041 .09549 .69817 .10227 .69449 .09249 Mtetra
.796 .654 .705 r
.69449 .09249 .69817 .10227 .70527 .09737 .70131 .08287 Mtetra
.197 .224 .663 r
.70131 .08287 .70527 .09737 .71249 .0942 .70928 .09165 Mtetra
.775 .916 .933 r
.70928 .09165 .71249 .0942 .71953 .08806 .71644 .08695 Mtetra
.609 .051 0 r
.71644 .08695 .71953 .08806 .72679 .0851 .72442 .09421 Mtetra
.484 .076 .19 r
.72442 .09421 .72679 .0851 .73427 .0849 .73205 .09548 Mtetra
.647 .607 .795 r
.08436 .30924 .0882 .31659 .09319 .32009 .09016 .30686 Mtetra
.457 .389 .693 r
.09016 .30686 .09319 .32009 .09881 .31917 .09543 .3084 Mtetra
.445 .419 .736 r
.09543 .3084 .09881 .31917 .10548 .31049 .10074 .30983 Mtetra
.863 .452 .246 r
.10074 .30983 .10548 .31049 .11113 .30952 .10482 .32061 Mtetra
.701 .357 .39 r
.10482 .32061 .11113 .30952 .11706 .30651 .10917 .32984 Mtetra
.678 .373 .451 r
.10917 .32984 .11706 .30651 .11945 .33111 .11301 .34337 Mtetra
.73 .396 .415 r
.11301 .34337 .11945 .33111 .12293 .34791 .11708 .35571 Mtetra
.805 .465 .413 r
.11708 .35571 .12293 .34791 .12634 .36601 .12068 .37223 Mtetra
0 0 0 r
.12068 .37223 .12634 .36601 .13131 .37206 .12694 .36804 Mtetra
.812 .769 .812 r
.12694 .36804 .13131 .37206 .13648 .37683 .13346 .36184 Mtetra
.753 .572 .65 r
.13346 .36184 .13648 .37683 .14396 .36266 .1407 .34966 Mtetra
.77 .594 .66 r
.1407 .34966 .14396 .36266 .15139 .34859 .14791 .33754 Mtetra
.652 .545 .72 r
.14791 .33754 .15139 .34859 .158 .34139 .1541 .33396 Mtetra
.71 .639 .776 r
.1541 .33396 .158 .34139 .16465 .33378 .16037 .32969 Mtetra
.859 .762 .754 r
.16037 .32969 .16465 .33378 .17105 .32838 .16722 .32035 Mtetra
.633 .59 .788 r
.16722 .32035 .17105 .32838 .17775 .32028 .17327 .31812 Mtetra
.9 .822 .761 r
.17327 .31812 .17775 .32028 .18337 .32197 .1802 .30807 Mtetra
.778 .593 .649 r
.1802 .30807 .18337 .32197 .19094 .30569 .18751 .29425 Mtetra
.16 .225 .683 r
.18751 .29425 .19094 .30569 .19759 .29787 .19275 .29969 Mtetra
.448 0 0 r
.19275 .29969 .19759 .29787 .20244 .30743 .19843 .30132 Mtetra
.325 .497 .875 r
.19843 .30132 .20244 .30743 .20795 .31105 .20413 .30296 Mtetra
.843 .677 .676 r
.20413 .30296 .20795 .31105 .21544 .29504 .21145 .2889 Mtetra
.649 .655 .842 r
.21145 .2889 .21544 .29504 .22193 .28886 .21757 .28662 Mtetra
.899 .828 .767 r
.21757 .28662 .22193 .28886 .22861 .28075 .22442 .27691 Mtetra
.663 .764 .925 r
.22442 .27691 .22861 .28075 .23438 .28236 .23056 .27462 Mtetra
.75 .65 .751 r
.23056 .27462 .23438 .28236 .24091 .2758 .23706 .26857 Mtetra
.758 .665 .759 r
.23706 .26857 .24091 .2758 .24741 .26967 .24356 .26249 Mtetra
.817 .685 .719 r
.24356 .26249 .24741 .26967 .25413 .26101 .25037 .25289 Mtetra
.781 .656 .724 r
.25037 .25289 .25413 .26101 .26013 .26064 .25704 .24484 Mtetra
.598 .463 .668 r
.25704 .24484 .26013 .26064 .2674 .24539 .26324 .24218 Mtetra
.759 .818 .899 r
.26324 .24218 .2674 .24539 .27347 .24425 .26955 .23822 Mtetra
0 0 .496 r
.26955 .23822 .27347 .24425 .27919 .24785 .27498 .24535 Mtetra
.43 .762 .996 r
.27498 .24535 .27919 .24785 .28539 .24576 .28106 .24483 Mtetra
.764 .946 .939 r
.28106 .24483 .28539 .24576 .29159 .24369 .28745 .24066 Mtetra
.141 .568 .927 r
.28745 .24066 .29159 .24369 .29784 .24135 .29343 .24198 Mtetra
.971 .87 .68 r
.29343 .24198 .29784 .24135 .30474 .23018 .30067 .22657 Mtetra
.192 .562 .935 r
.30067 .22657 .30474 .23018 .31099 .22795 .30666 .22798 Mtetra
.585 .017 0 r
.30666 .22798 .31099 .22795 .31689 .23101 .31252 .23181 Mtetra
.558 0 0 r
.31252 .23181 .31689 .23101 .32257 .23801 .31846 .23508 Mtetra
.522 0 0 r
.31846 .23508 .32257 .23801 .32878 .2375 .32432 .24013 Mtetra
.888 .986 .72 r
.32432 .24013 .32878 .2375 .33572 .22567 .33114 .23073 Mtetra
.963 .923 .586 r
.33114 .23073 .33572 .22567 .34247 .21665 .33841 .21375 Mtetra
.297 .67 .974 r
.33841 .21375 .34247 .21665 .34822 .22447 .3446 .2142 Mtetra
.649 .558 .738 r
.3446 .2142 .34822 .22447 .35441 .22568 .35104 .21086 Mtetra
.544 .438 .683 r
.35104 .21086 .35441 .22568 .36061 .22708 .35733 .21025 Mtetra
.681 .513 .651 r
.35733 .21025 .36061 .22708 .36732 .21922 .36402 .20281 Mtetra
.384 .316 .657 r
.36402 .20281 .36732 .21922 .37405 .211 .3701 .20688 Mtetra
.814 .79 .83 r
.3701 .20688 .37405 .211 .38086 .20061 .37673 .20088 Mtetra
.248 0 0 r
.37673 .20088 .38086 .20061 .38733 .19755 .38302 .20202 Mtetra
.629 .168 .139 r
.38302 .20202 .38733 .19755 .39355 .2005 .38919 .20645 Mtetra
0 0 0 r
.38919 .20645 .39355 .2005 .39988 .20165 .39587 .2001 Mtetra
.928 .881 .768 r
.39587 .2001 .39988 .20165 .40642 .19828 .40269 .19003 Mtetra
.671 .612 .78 r
.40269 .19003 .40642 .19828 .41308 .19199 .40925 .1866 Mtetra
.6 .676 .894 r
.40925 .1866 .41308 .19199 .41969 .1869 .41574 .18512 Mtetra
.867 .42 .09 r
.41574 .18512 .41969 .1869 .42603 .19035 .42175 .19846 Mtetra
.626 .22 .253 r
.42175 .19846 .42603 .19035 .43224 .1994 .42811 .20357 Mtetra
0 0 0 r
.42811 .20357 .43224 .1994 .43879 .19889 .4348 .19915 Mtetra
.875 .987 .826 r
.4348 .19915 .43879 .19889 .44553 .1919 .44158 .19181 Mtetra
.911 .964 .803 r
.44158 .19181 .44553 .1919 .45239 .1797 .44838 .18341 Mtetra
.94 .938 .592 r
.44838 .18341 .45239 .1797 .45902 .17721 .45531 .16884 Mtetra
0 .105 .655 r
.45531 .16884 .45902 .17721 .46566 .17472 .46174 .17644 Mtetra
.768 .987 .751 r
.46174 .17644 .46566 .17472 .47203 .18836 .46851 .16955 Mtetra
0 0 .437 r
.46851 .16955 .47203 .18836 .47871 .18773 .47483 .1888 Mtetra
.344 0 0 r
.47483 .1888 .47871 .18773 .48542 .18711 .48153 .19027 Mtetra
.571 .06 0 r
.48153 .19027 .48542 .18711 .4921 .19035 .48823 .19376 Mtetra
.382 0 0 r
.48823 .19376 .4921 .19035 .4989 .18543 .49501 .1945 Mtetra
.034 0 .01 r
.49501 .1945 .4989 .18543 .5057 .18291 .50187 .18797 Mtetra
.09 0 0 r
.50187 .18797 .5057 .18291 .51244 .19486 .50872 .18488 Mtetra
.684 .589 .744 r
.50872 .18488 .51244 .19486 .5193 .19234 .51558 .18035 Mtetra
.747 .595 .687 r
.51558 .18035 .5193 .19234 .52617 .17908 .52245 .17159 Mtetra
.712 .658 .794 r
.52245 .17159 .52617 .17908 .53303 .17258 .52932 .16715 Mtetra
0 .323 .81 r
.52932 .16715 .53303 .17258 .5399 .16806 .53624 .17148 Mtetra
.017 0 0 r
.53624 .17148 .5399 .16806 .5468 .16747 .54315 .16891 Mtetra
.514 .898 .733 r
.54315 .16891 .5468 .16747 .55372 .16636 .55008 .16444 Mtetra
.617 .893 .988 r
.55008 .16444 .55372 .16636 .56065 .16379 .55702 .16186 Mtetra
0 .318 .691 r
.55702 .16186 .56065 .16379 .56755 .15728 .56407 .16498 Mtetra
.386 0 .115 r
.56407 .16498 .56755 .15728 .57444 .1508 .57109 .16431 Mtetra
.123 0 .162 r
.57109 .16431 .57444 .1508 .58149 .1526 .57801 .15574 Mtetra
0 0 0 r
.57801 .15574 .58149 .1526 .58878 .16394 .58503 .15313 Mtetra
.791 .634 .686 r
.58503 .15313 .58878 .16394 .59562 .15281 .59189 .14257 Mtetra
.549 .512 .766 r
.59189 .14257 .59562 .15281 .60251 .14429 .59898 .14192 Mtetra
.184 .638 .941 r
.59898 .14192 .60251 .14429 .60955 .14167 .60614 .14273 Mtetra
.913 .976 .696 r
.60614 .14273 .60955 .14167 .61643 .1332 .61299 .13222 Mtetra
.255 .75 .907 r
.61299 .13222 .61643 .1332 .62376 .13838 .62014 .13153 Mtetra
.65 .656 .843 r
.62014 .13153 .62376 .13838 .63065 .12986 .62725 .12888 Mtetra
.92 .959 .791 r
.62725 .12888 .63065 .12986 .63798 .13309 .63415 .11993 Mtetra
.606 .501 .709 r
.63415 .11993 .63798 .13309 .64496 .12651 .64128 .11726 Mtetra
.669 .6 .769 r
.64128 .11726 .64496 .12651 .65222 .12632 .64838 .11348 Mtetra
.657 .536 .705 r
.64838 .11348 .65222 .12632 .6593 .12167 .65546 .10886 Mtetra
0 .037 .585 r
.65546 .10886 .6593 .12167 .66606 .11012 .66338 .12194 Mtetra
0 0 .061 r
.66338 .12194 .66606 .11012 .67334 .10941 .67013 .10933 Mtetra
.983 .908 .625 r
.67013 .10933 .67334 .10941 .68019 .10009 .67669 .09391 Mtetra
.033 .311 .8 r
.67669 .09391 .68019 .10009 .68712 .09234 .68434 .09903 Mtetra
0 0 0 r
.68434 .09903 .68712 .09234 .69449 .09249 .69086 .08354 Mtetra
.75 .648 .748 r
.69086 .08354 .69449 .09249 .70131 .08287 .69787 .07695 Mtetra
0 .165 .703 r
.69787 .07695 .70131 .08287 .70928 .09165 .70574 .08416 Mtetra
.439 .523 .847 r
.70574 .08416 .70928 .09165 .71644 .08695 .71328 .08526 Mtetra
.806 .332 0 r
.71328 .08526 .71644 .08695 .72442 .09421 .72181 .10046 Mtetra
.076 0 0 r
.72181 .10046 .72442 .09421 .73205 .09548 .72906 .09571 Mtetra
.832 .412 .242 r
.07942 .30956 .08436 .30924 .09016 .30686 .08359 .31882 Mtetra
.636 .288 .365 r
.08359 .31882 .09016 .30686 .09543 .3084 .0883 .32464 Mtetra
.115 0 .141 r
.0883 .32464 .09543 .3084 .10074 .30983 .09489 .31694 Mtetra
.81 .47 .413 r
.09489 .31694 .10074 .30983 .10482 .32061 .09825 .33312 Mtetra
.704 .368 .404 r
.09825 .33312 .10482 .32061 .10917 .32984 .10247 .34343 Mtetra
.749 .425 .435 r
.10247 .34343 .10917 .32984 .11301 .34337 .10607 .35891 Mtetra
.62 .287 .385 r
.10607 .35891 .11301 .34337 .11708 .35571 .11097 .36499 Mtetra
.504 .117 .239 r
.11097 .36499 .11708 .35571 .12068 .37223 .11652 .36627 Mtetra
.779 .7 .776 r
.11652 .36627 .12068 .37223 .12694 .36804 .12305 .36006 Mtetra
.701 .623 .767 r
.12305 .36006 .12694 .36804 .13346 .36184 .12932 .35585 Mtetra
.812 .706 .748 r
.12932 .35585 .13346 .36184 .1407 .34966 .1361 .34764 Mtetra
.932 .769 .657 r
.1361 .34764 .1407 .34966 .14791 .33754 .14432 .32739 Mtetra
.677 .571 .729 r
.14432 .32739 .14791 .33754 .1541 .33396 .15057 .32319 Mtetra
.734 .594 .7 r
.15057 .32319 .1541 .33396 .16037 .32969 .1572 .31587 Mtetra
.597 .479 .689 r
.1572 .31587 .16037 .32969 .16722 .32035 .16324 .31363 Mtetra
.765 .677 .766 r
.16324 .31363 .16722 .32035 .17327 .31812 .16973 .30756 Mtetra
.538 .486 .745 r
.16973 .30756 .17327 .31812 .1802 .30807 .17557 .30722 Mtetra
.258 0 0 r
.17557 .30722 .1802 .30807 .18751 .29425 .18122 .30886 Mtetra
.569 .227 .349 r
.18122 .30886 .18751 .29425 .19275 .29969 .18669 .31242 Mtetra
.073 0 .075 r
.18669 .31242 .19275 .29969 .19843 .30132 .19331 .30549 Mtetra
.937 .964 .679 r
.19331 .30549 .19843 .30132 .20413 .30296 .20047 .29336 Mtetra
.843 .66 .654 r
.20047 .29336 .20413 .30296 .21145 .2889 .20807 .27658 Mtetra
.025 .117 .624 r
.20807 .27658 .21145 .2889 .21757 .28662 .21321 .28399 Mtetra
.89 .817 .769 r
.21321 .28399 .21757 .28662 .22442 .27691 .22007 .27453 Mtetra
.839 .853 .855 r
.22007 .27453 .22442 .27691 .23056 .27462 .22657 .26855 Mtetra
.431 .557 .882 r
.22657 .26855 .23056 .27462 .23706 .26857 .23244 .26925 Mtetra
.411 .862 .842 r
.23244 .26925 .23706 .26857 .24356 .26249 .23861 .26694 Mtetra
.967 .935 .641 r
.23861 .26694 .24356 .26249 .25037 .25289 .24596 .25184 Mtetra
.935 .855 .738 r
.24596 .25184 .25037 .25289 .25704 .24484 .25298 .24012 Mtetra
.813 .36 0 r
.25298 .24012 .25704 .24484 .26324 .24218 .25806 .25034 Mtetra
.539 .136 .226 r
.25806 .25034 .26324 .24218 .26955 .23822 .26389 .25258 Mtetra
.138 0 .145 r
.26389 .25258 .26955 .23822 .27498 .24535 .27053 .24539 Mtetra
.725 .21 0 r
.27053 .24539 .27498 .24535 .28106 .24483 .2761 .2514 Mtetra
0 0 0 r
.2761 .2514 .28106 .24483 .28745 .24066 .28253 .2471 Mtetra
.378 0 .069 r
.28253 .2471 .28745 .24066 .29343 .24198 .28866 .2467 Mtetra
.488 .017 .061 r
.28866 .2467 .29343 .24198 .30067 .22657 .29468 .24825 Mtetra
.429 .122 .341 r
.29468 .24825 .30067 .22657 .30666 .22798 .301 .24589 Mtetra
.307 0 .265 r
.301 .24589 .30666 .22798 .31252 .23181 .30756 .24053 Mtetra
0 0 0 r
.30756 .24053 .31252 .23181 .31846 .23508 .31417 .23449 Mtetra
.6 .029 0 r
.31417 .23449 .31846 .23508 .32432 .24013 .32008 .23881 Mtetra
.767 .933 .939 r
.32008 .23881 .32432 .24013 .33114 .23073 .32659 .23459 Mtetra
.995 .861 .582 r
.32659 .23459 .33114 .23073 .33841 .21375 .33433 .21089 Mtetra
.75 .847 .923 r
.33433 .21089 .33841 .21375 .3446 .2142 .34079 .20709 Mtetra
.161 .356 .809 r
.34079 .20709 .3446 .2142 .35104 .21086 .34682 .21068 Mtetra
.128 .676 .796 r
.34682 .21068 .35104 .21086 .35733 .21025 .35312 .2102 Mtetra
.159 0 0 r
.35312 .2102 .35733 .21025 .36402 .20281 .35938 .21103 Mtetra
.278 0 .082 r
.35938 .21103 .36402 .20281 .3701 .20688 .36584 .20861 Mtetra
.927 .973 .734 r
.36584 .20861 .3701 .20688 .37673 .20088 .37269 .1985 Mtetra
.413 .767 .995 r
.37269 .1985 .37673 .20088 .38302 .20202 .37907 .19795 Mtetra
.76 .286 0 r
.37907 .19795 .38302 .20202 .38919 .20645 .38499 .20783 Mtetra
.897 .988 .766 r
.38499 .20783 .38919 .20645 .39587 .2001 .3918 .1991 Mtetra
.959 .865 .703 r
.3918 .1991 .39587 .2001 .40269 .19003 .39881 .18549 Mtetra
0 .14 .658 r
.39881 .18549 .40269 .19003 .40925 .1866 .40503 .19073 Mtetra
.393 0 0 r
.40503 .19073 .40925 .1866 .41574 .18512 .41147 .19128 Mtetra
.702 .282 .244 r
.41147 .19128 .41574 .18512 .42175 .19846 .4177 .19883 Mtetra
.495 0 0 r
.4177 .19883 .42175 .19846 .42811 .20357 .42413 .20192 Mtetra
.858 .922 .871 r
.42413 .20192 .42811 .20357 .4348 .19915 .4309 .19557 Mtetra
.806 .827 .867 r
.4309 .19557 .4348 .19915 .44158 .19181 .43764 .19018 Mtetra
.905 .906 .813 r
.43764 .19018 .44158 .19181 .44838 .18341 .44446 .18189 Mtetra
.932 .893 .768 r
.44446 .18189 .44838 .18341 .45531 .16884 .45132 .1718 Mtetra
.862 .458 .267 r
.45132 .1718 .45531 .16884 .46174 .17644 .45754 .18919 Mtetra
.247 0 .183 r
.45754 .18919 .46174 .17644 .46851 .16955 .46433 .18406 Mtetra
.624 .267 .344 r
.46433 .18406 .46851 .16955 .47483 .1888 .4709 .19088 Mtetra
.154 0 0 r
.4709 .19088 .47483 .1888 .48153 .19027 .47765 .19034 Mtetra
.253 0 0 r
.47765 .19034 .48153 .19027 .48823 .19376 .48439 .19179 Mtetra
.681 .904 .975 r
.48439 .19179 .48823 .19376 .49501 .1945 .49123 .18863 Mtetra
.795 .736 .798 r
.49123 .18863 .49501 .1945 .50187 .18797 .4981 .1822 Mtetra
.796 .74 .801 r
.4981 .1822 .50187 .18797 .50872 .18488 .50498 .1758 Mtetra
.741 .634 .742 r
.50498 .1758 .50872 .18488 .51558 .18035 .51185 .16943 Mtetra
.822 .645 .663 r
.51185 .16943 .51558 .18035 .52245 .17159 .51874 .15591 Mtetra
.495 .403 .68 r
.51874 .15591 .52245 .17159 .52932 .16715 .5256 .15688 Mtetra
0 .029 .593 r
.5256 .15688 .52932 .16715 .53624 .17148 .53252 .16721 Mtetra
.662 .77 .93 r
.53252 .16721 .53624 .17148 .54315 .16891 .53945 .16463 Mtetra
.779 .803 .872 r
.53945 .16463 .54315 .16891 .55008 .16444 .54638 .15967 Mtetra
.332 .582 .934 r
.54638 .15967 .55008 .16444 .55702 .16186 .55338 .16087 Mtetra
.778 .273 0 r
.55338 .16087 .55702 .16186 .56407 .16498 .56052 .17104 Mtetra
.107 0 0 r
.56052 .17104 .56407 .16498 .57109 .16431 .56754 .16732 Mtetra
.933 .931 .569 r
.56754 .16732 .57109 .16431 .57801 .15574 .57438 .15236 Mtetra
.913 .848 .766 r
.57438 .15236 .57801 .15574 .58503 .15313 .58128 .14233 Mtetra
.271 .328 .739 r
.58128 .14233 .58503 .15313 .59189 .14257 .58848 .14712 Mtetra
.663 .851 .449 r
.58848 .14712 .59189 .14257 .59898 .14192 .59536 .13655 Mtetra
.353 .562 .915 r
.59536 .13655 .59898 .14192 .60614 .14273 .60254 .13786 Mtetra
0 .24 .75 r
.60254 .13786 .60614 .14273 .61299 .13222 .60987 .1432 Mtetra
0 0 0 r
.60987 .1432 .61299 .13222 .62014 .13153 .61652 .12467 Mtetra
.816 .722 .761 r
.61652 .12467 .62014 .13153 .62725 .12888 .62345 .11661 Mtetra
.512 .456 .731 r
.62345 .11661 .62725 .12888 .63415 .11993 .63068 .11691 Mtetra
.65 .848 .976 r
.63068 .11691 .63415 .11993 .64128 .11726 .63783 .11423 Mtetra
.727 .872 .949 r
.63783 .11423 .64128 .11726 .64838 .11348 .64495 .11048 Mtetra
.853 .89 .864 r
.64495 .11048 .64838 .11348 .65546 .10886 .65197 .10389 Mtetra
.715 .763 .89 r
.65197 .10389 .65546 .10886 .66338 .12194 .65911 .10018 Mtetra
.636 .46 .627 r
.65911 .10018 .66338 .12194 .67013 .10933 .66613 .09355 Mtetra
.545 .438 .683 r
.66613 .09355 .67013 .10933 .67669 .09391 .67344 .09279 Mtetra
.737 .974 .926 r
.67344 .09279 .67669 .09391 .68434 .09903 .68058 .08811 Mtetra
.699 .587 .727 r
.68058 .08811 .68434 .09903 .69086 .08354 .68767 .08252 Mtetra
.725 .976 .923 r
.68767 .08252 .69086 .08354 .69787 .07695 .69482 .0779 Mtetra
.488 .888 .74 r
.69482 .0779 .69787 .07695 .70574 .08416 .702 .07359 Mtetra
.058 .193 .69 r
.702 .07359 .70574 .08416 .71328 .08526 .71002 .08214 Mtetra
0 .321 .771 r
.71002 .08214 .71328 .08526 .72181 .10046 .71781 .08629 Mtetra
.374 .347 .7 r
.71781 .08629 .72181 .10046 .72906 .09571 .72568 .09062 Mtetra
.62 .28 .372 r
.07254 .32307 .07942 .30956 .08359 .31882 .07727 .32857 Mtetra
.763 .425 .413 r
.07727 .32857 .08359 .31882 .0883 .32464 .08091 .34212 Mtetra
.521 .195 .354 r
.08091 .34212 .0883 .32464 .09489 .31694 .08626 .34379 Mtetra
.693 .395 .466 r
.08626 .34379 .09489 .31694 .09825 .33312 .08948 .36122 Mtetra
.577 .279 .426 r
.08948 .36122 .09825 .33312 .10247 .34343 .09436 .36698 Mtetra
.489 .183 .374 r
.09436 .36698 .10247 .34343 .10607 .35891 .10002 .36716 Mtetra
.07 0 0 r
.10002 .36716 .10607 .35891 .11097 .36499 .10629 .36296 Mtetra
.803 .867 .895 r
.10629 .36296 .11097 .36499 .11652 .36627 .11263 .3582 Mtetra
.829 .671 .686 r
.11263 .3582 .11652 .36627 .12305 .36006 .12 .34539 Mtetra
.64 .5 .676 r
.12 .34539 .12305 .36006 .12932 .35585 .12627 .34118 Mtetra
.741 .565 .656 r
.12627 .34118 .12932 .35585 .1361 .34764 .13335 .33049 Mtetra
.71 .531 .645 r
.13335 .33049 .1361 .34764 .14432 .32739 .14029 .3208 Mtetra
.769 .681 .766 r
.14029 .3208 .14432 .32739 .15057 .32319 .14679 .31462 Mtetra
.652 .587 .769 r
.14679 .31462 .15057 .32319 .1572 .31587 .15289 .31173 Mtetra
.809 .767 .814 r
.15289 .31173 .1572 .31587 .16324 .31363 .15939 .30566 Mtetra
.789 .66 .72 r
.15939 .30566 .16324 .31363 .16973 .30756 .16617 .29704 Mtetra
0 0 .365 r
.16617 .29704 .16973 .30756 .17557 .30722 .17074 .30795 Mtetra
.512 0 0 r
.17074 .30795 .17557 .30722 .18122 .30886 .1763 .3105 Mtetra
.44 0 0 r
.1763 .3105 .18122 .30886 .18669 .31242 .18199 .31215 Mtetra
.257 .763 .87 r
.18199 .31215 .18669 .31242 .19331 .30549 .18798 .31124 Mtetra
.987 .899 .611 r
.18798 .31124 .19331 .30549 .20047 .29336 .19602 .29112 Mtetra
.944 .752 .614 r
.19602 .29112 .20047 .29336 .20807 .27658 .20486 .26282 Mtetra
0 0 .485 r
.20486 .26282 .20807 .27658 .21321 .28399 .20959 .27391 Mtetra
.708 .59 .722 r
.20959 .27391 .21321 .28399 .22007 .27453 .21606 .26843 Mtetra
.725 .685 .812 r
.21606 .26843 .22007 .27453 .22657 .26855 .22239 .26428 Mtetra
.4 .638 .952 r
.22239 .26428 .22657 .26855 .23244 .26925 .22829 .26466 Mtetra
.504 .668 .937 r
.22829 .26466 .23244 .26925 .23861 .26694 .23429 .26428 Mtetra
0 .41 .798 r
.23429 .26428 .23861 .26694 .24596 .25184 .24008 .26647 Mtetra
0 0 .003 r
.24008 .26647 .24596 .25184 .25298 .24012 .24712 .25505 Mtetra
.134 0 .148 r
.24712 .25505 .25298 .24012 .25806 .25034 .25379 .24761 Mtetra
.512 0 0 r
.25379 .24761 .25806 .25034 .26389 .25258 .25943 .25214 Mtetra
.94 .885 .75 r
.25943 .25214 .26389 .25258 .27053 .24539 .26642 .24105 Mtetra
.528 .036 0 r
.26642 .24105 .27053 .24539 .2761 .2514 .27198 .24706 Mtetra
.662 .744 .911 r
.27198 .24706 .2761 .2514 .28253 .2471 .27827 .2447 Mtetra
.077 .564 .897 r
.27827 .2447 .28253 .2471 .28866 .2467 .28429 .24591 Mtetra
.866 .434 .178 r
.28429 .24591 .28866 .2467 .29468 .24825 .28949 .25822 Mtetra
.318 0 .146 r
.28949 .25822 .29468 .24825 .301 .24589 .29585 .25585 Mtetra
.835 .869 .425 r
.29585 .25585 .301 .24589 .30756 .24053 .3034 .2374 Mtetra
.91 .802 .728 r
.3034 .2374 .30756 .24053 .31417 .23449 .31043 .22555 Mtetra
.291 .376 .778 r
.31043 .22555 .31417 .23449 .32008 .23881 .31641 .22867 Mtetra
.62 .545 .748 r
.31641 .22867 .32008 .23881 .32659 .23459 .3228 .22627 Mtetra
.731 .636 .753 r
.3228 .22627 .32659 .23459 .33433 .21089 .32941 .22075 Mtetra
.489 .101 .23 r
.32941 .22075 .33433 .21089 .34079 .20709 .3356 .2218 Mtetra
.246 0 .203 r
.3356 .2218 .34079 .20709 .34682 .21068 .34223 .21621 Mtetra
.583 .136 .155 r
.34223 .21621 .34682 .21068 .35312 .2102 .34833 .2196 Mtetra
.326 0 .138 r
.34833 .2196 .35312 .2102 .35938 .21103 .35479 .21749 Mtetra
0 0 0 r
.35479 .21749 .35938 .21103 .36584 .20861 .36159 .20922 Mtetra
.983 .843 .625 r
.36159 .20922 .36584 .20861 .37269 .1985 .369 .18898 Mtetra
0 0 .426 r
.369 .18898 .37269 .1985 .37907 .19795 .37478 .20048 Mtetra
.793 .351 .196 r
.37478 .20048 .37907 .19795 .38499 .20783 .3807 .21049 Mtetra
.986 .901 .621 r
.3807 .21049 .38499 .20783 .3918 .1991 .38794 .19298 Mtetra
.808 .721 .769 r
.38794 .19298 .3918 .1991 .39881 .18549 .3947 .18559 Mtetra
.665 .97 .908 r
.3947 .18559 .39881 .18549 .40503 .19073 .40131 .18165 Mtetra
.442 .467 .79 r
.40131 .18165 .40503 .19073 .41147 .19128 .40772 .18292 Mtetra
0 .039 .609 r
.40772 .18292 .41147 .19128 .4177 .19883 .41391 .19106 Mtetra
.408 .487 .83 r
.41391 .19106 .4177 .19883 .42413 .20192 .4204 .19251 Mtetra
.736 .623 .733 r
.4204 .19251 .42413 .20192 .4309 .19557 .42717 .18613 Mtetra
.518 .505 .781 r
.42717 .18613 .4309 .19557 .43764 .19018 .43375 .18613 Mtetra
.828 .806 .83 r
.43375 .18613 .43764 .19018 .44446 .18189 .44054 .17967 Mtetra
.638 .874 .986 r
.44054 .17967 .44446 .18189 .45132 .1718 .44723 .17715 Mtetra
.832 .436 .3 r
.44723 .17715 .45132 .1718 .45754 .18919 .45348 .19381 Mtetra
.855 .462 .299 r
.45348 .19381 .45754 .18919 .46433 .18406 .45978 .2128 Mtetra
.212 0 .304 r
.45978 .2128 .46433 .18406 .4709 .19088 .46682 .19907 Mtetra
0 0 0 r
.46682 .19907 .4709 .19088 .47765 .19034 .47374 .19056 Mtetra
.426 .87 .859 r
.47374 .19056 .47765 .19034 .48439 .19179 .48056 .18802 Mtetra
.94 .797 .675 r
.48056 .18802 .48439 .19179 .49123 .18863 .48756 .17238 Mtetra
.589 .46 .672 r
.48756 .17238 .49123 .18863 .4981 .1822 .49439 .16982 Mtetra
.666 .545 .707 r
.49439 .16982 .4981 .1822 .50498 .1758 .50125 .16505 Mtetra
.72 .597 .717 r
.50125 .16505 .50498 .1758 .51185 .16943 .50813 .15861 Mtetra
.826 .648 .662 r
.50813 .15861 .51185 .16943 .51874 .15591 .51503 .14482 Mtetra
.265 .316 .729 r
.51503 .14482 .51874 .15591 .5256 .15688 .52187 .14962 Mtetra
0 .121 .672 r
.52187 .14962 .5256 .15688 .53252 .16721 .52878 .15695 Mtetra
.622 .552 .755 r
.52878 .15695 .53252 .16721 .53945 .16463 .53571 .15435 Mtetra
.276 .342 .751 r
.53571 .15435 .53945 .16463 .54638 .15967 .5427 .15867 Mtetra
.554 .911 .963 r
.5427 .15867 .54638 .15967 .55338 .16087 .54968 .15607 Mtetra
.327 .579 .933 r
.54968 .15607 .55338 .16087 .56052 .17104 .55672 .1573 Mtetra
.545 .457 .707 r
.55672 .1573 .56052 .17104 .56754 .16732 .56377 .15662 Mtetra
.735 .608 .716 r
.56377 .15662 .56754 .16732 .57438 .15236 .57075 .14952 Mtetra
.777 .885 .923 r
.57075 .14952 .57438 .15236 .58128 .14233 .57777 .14489 Mtetra
.589 .058 0 r
.57777 .14489 .58128 .14233 .58848 .14712 .58498 .14917 Mtetra
.642 .931 .668 r
.58498 .14917 .58848 .14712 .59536 .13655 .59199 .14254 Mtetra
.347 0 .019 r
.59199 .14254 .59536 .13655 .60254 .13786 .59915 .14188 Mtetra
0 0 0 r
.59915 .14188 .60254 .13786 .60987 .1432 .60623 .13724 Mtetra
.958 .748 .577 r
.60623 .13724 .60987 .1432 .61652 .12467 .61267 .11096 Mtetra
.555 .464 .707 r
.61267 .11096 .61652 .12467 .62345 .11661 .61983 .10995 Mtetra
.792 .722 .786 r
.61983 .10995 .62345 .11661 .63068 .11691 .62682 .10317 Mtetra
.137 .192 .657 r
.62682 .10317 .63068 .11691 .63783 .11423 .6344 .11213 Mtetra
.984 .843 .623 r
.6344 .11213 .63783 .11423 .64495 .11048 .64097 .09401 Mtetra
.707 .534 .651 r
.64097 .09401 .64495 .11048 .65197 .10389 .64787 .08499 Mtetra
.633 .472 .646 r
.64787 .08499 .65197 .10389 .65911 .10018 .65491 .07946 Mtetra
.528 .393 .64 r
.65491 .07946 .65911 .10018 .66613 .09355 .6622 .07917 Mtetra
.636 .507 .689 r
.6622 .07917 .66613 .09355 .67344 .09279 .66933 .07494 Mtetra
.511 .399 .663 r
.66933 .07494 .67344 .09279 .68058 .08811 .67672 .07543 Mtetra
.353 .351 .718 r
.67672 .07543 .68058 .08811 .68767 .08252 .68435 .07965 Mtetra
.737 .89 .949 r
.68435 .07965 .68767 .08252 .69482 .0779 .69156 .07562 Mtetra
.956 .899 .727 r
.69156 .07562 .69482 .0779 .702 .07359 .69832 .06392 Mtetra
.397 .436 .784 r
.69832 .06392 .702 .07359 .71002 .08214 .70593 .06629 Mtetra
.15 .179 .636 r
.70593 .06629 .71002 .08214 .71781 .08629 .71413 .07689 Mtetra
.182 .306 .756 r
.71413 .07689 .71781 .08629 .72568 .09062 .72209 .08266 Mtetra
.672 .345 .412 r
.06529 .33863 .07254 .32307 .07727 .32857 .06949 .348 Mtetra
.665 .349 .43 r
.06949 .348 .07727 .32857 .08091 .34212 .07358 .3585 Mtetra
.569 .237 .366 r
.07358 .3585 .08091 .34212 .08626 .34379 .07869 .36216 Mtetra
.709 .394 .442 r
.07869 .36216 .08626 .34379 .08948 .36122 .08235 .37657 Mtetra
.679 .35 .41 r
.08235 .37657 .08948 .36122 .09436 .36698 .08669 .3865 Mtetra
.081 0 .151 r
.08669 .3865 .09436 .36698 .10002 .36716 .09375 .37662 Mtetra
0 0 0 r
.09375 .37662 .10002 .36716 .10629 .36296 .10059 .36835 Mtetra
.921 .967 .668 r
.10059 .36835 .10629 .36296 .11263 .3582 .10794 .35615 Mtetra
.913 .801 .723 r
.10794 .35615 .11263 .3582 .12 .34539 .11534 .3433 Mtetra
.845 .854 .849 r
.11534 .3433 .12 .34539 .12627 .34118 .12188 .33709 Mtetra
.851 .763 .764 r
.12188 .33709 .12627 .34118 .13335 .33049 .12873 .32836 Mtetra
.899 .819 .759 r
.12873 .32836 .13335 .33049 .14029 .3208 .13575 .31813 Mtetra
.776 .839 .9 r
.13575 .31813 .14029 .3208 .14679 .31462 .14203 .31392 Mtetra
.865 .921 .864 r
.14203 .31392 .14679 .31462 .15289 .31173 .14857 .30758 Mtetra
.864 .76 .746 r
.14857 .30758 .15289 .31173 .15939 .30566 .15552 .2977 Mtetra
.579 .566 .803 r
.15552 .2977 .15939 .30566 .16617 .29704 .16145 .29657 Mtetra
.273 0 0 r
.16145 .29657 .16617 .29704 .17074 .30795 .16709 .29806 Mtetra
.359 .391 .758 r
.16709 .29806 .17074 .30795 .1763 .3105 .17265 .3005 Mtetra
0 .033 .596 r
.17265 .3005 .1763 .3105 .18199 .31215 .17768 .30795 Mtetra
.874 .761 .734 r
.17768 .30795 .18199 .31215 .18798 .31124 .18476 .29709 Mtetra
.829 .622 .623 r
.18476 .29709 .18798 .31124 .19602 .29112 .19302 .27512 Mtetra
.769 .575 .637 r
.19302 .27512 .19602 .29112 .20486 .26282 .20045 .26044 Mtetra
.653 .104 0 r
.20045 .26044 .20486 .26282 .20959 .27391 .20577 .26579 Mtetra
.196 .339 .783 r
.20577 .26579 .20959 .27391 .21606 .26843 .21133 .26929 Mtetra
.389 0 0 r
.21133 .26929 .21606 .26843 .22239 .26428 .21711 .27087 Mtetra
.612 .195 .227 r
.21711 .27087 .22239 .26428 .22829 .26466 .22268 .27489 Mtetra
.017 0 0 r
.22268 .27489 .22829 .26466 .23429 .26428 .22927 .26866 Mtetra
.383 0 0 r
.22927 .26866 .23429 .26428 .24008 .26647 .23525 .26897 Mtetra
.98 .893 .663 r
.23525 .26897 .24008 .26647 .24712 .25505 .24279 .2525 Mtetra
.786 .858 .904 r
.24279 .2525 .24712 .25505 .25379 .24761 .24922 .24804 Mtetra
.918 .948 .801 r
.24922 .24804 .25379 .24761 .25943 .25214 .25601 .23942 Mtetra
.383 .355 .704 r
.25601 .23942 .25943 .25214 .26642 .24105 .26181 .24233 Mtetra
.762 .996 .843 r
.26181 .24233 .26642 .24105 .27198 .24706 .26834 .23684 Mtetra
.54 .496 .756 r
.26834 .23684 .27198 .24706 .27827 .2447 .27447 .23642 Mtetra
.429 .479 .81 r
.27447 .23642 .27827 .2447 .28429 .24591 .28048 .23764 Mtetra
0 0 .414 r
.28048 .23764 .28429 .24591 .28949 .25822 .28585 .24745 Mtetra
.538 .487 .746 r
.28585 .24745 .28949 .25822 .29585 .25585 .29207 .24705 Mtetra
.873 .682 .642 r
.29207 .24705 .29585 .25585 .3034 .2374 .2997 .22767 Mtetra
.774 .631 .703 r
.2997 .22767 .3034 .2374 .31043 .22555 .30653 .21876 Mtetra
.287 .449 .848 r
.30653 .21876 .31043 .22555 .31641 .22867 .31257 .22103 Mtetra
.559 .571 .822 r
.31257 .22103 .31641 .22867 .3228 .22627 .31885 .22022 Mtetra
0 .063 .618 r
.31885 .22022 .3228 .22627 .32941 .22075 .32469 .22647 Mtetra
.735 .324 .269 r
.32469 .22647 .32941 .22075 .3356 .2218 .33043 .23522 Mtetra
0 0 .01 r
.33043 .23522 .3356 .2218 .34223 .21621 .33743 .22433 Mtetra
.258 0 .062 r
.33743 .22433 .34223 .21621 .34833 .2196 .34392 .22176 Mtetra
.735 .981 .755 r
.34392 .22176 .34833 .2196 .35479 .21749 .35064 .21537 Mtetra
.929 .845 .74 r
.35064 .21537 .35479 .21749 .36159 .20922 .35764 .20387 Mtetra
.769 .737 .823 r
.35764 .20387 .36159 .20922 .369 .18898 .36429 .19868 Mtetra
.31 0 .137 r
.36429 .19868 .369 .18898 .37478 .20048 .3708 .19622 Mtetra
.037 .424 .866 r
.3708 .19622 .37478 .20048 .3807 .21049 .37707 .19895 Mtetra
.666 .552 .716 r
.37707 .19895 .3807 .21049 .38794 .19298 .38371 .19454 Mtetra
.981 .905 .656 r
.38371 .19454 .38794 .19298 .3947 .18559 .39086 .179 Mtetra
.793 .705 .768 r
.39086 .179 .3947 .18559 .40131 .18165 .3976 .172 Mtetra
.418 .439 .775 r
.3976 .172 .40131 .18165 .40772 .18292 .40399 .17375 Mtetra
.772 .422 0 r
.40399 .17375 .40772 .18292 .41391 .19106 .40981 .19143 Mtetra
.925 .964 .778 r
.40981 .19143 .41391 .19106 .4204 .19251 .41669 .18217 Mtetra
.423 .429 .761 r
.41669 .18217 .4204 .19251 .42717 .18613 .42319 .18401 Mtetra
.376 .768 .988 r
.42319 .18401 .42717 .18613 .43375 .18613 .4298 .18347 Mtetra
.852 .875 .856 r
.4298 .18347 .43375 .18613 .44054 .17967 .43661 .17699 Mtetra
.431 0 0 r
.43661 .17699 .44054 .17967 .44723 .17715 .44311 .18169 Mtetra
.655 .191 .139 r
.44311 .18169 .44723 .17715 .45348 .19381 .44965 .18715 Mtetra
.509 .587 .869 r
.44965 .18715 .45348 .19381 .45978 .2128 .45636 .18699 Mtetra
.562 .394 .611 r
.45636 .18699 .45978 .2128 .46682 .19907 .46315 .18445 Mtetra
.619 .493 .686 r
.46315 .18445 .46682 .19907 .47374 .19056 .46997 .18097 Mtetra
.688 .599 .751 r
.46997 .18097 .47374 .19056 .48056 .18802 .47683 .17643 Mtetra
.719 .585 .704 r
.47683 .17643 .48056 .18802 .48756 .17238 .48372 .16955 Mtetra
.65 .848 .976 r
.48372 .16955 .48756 .17238 .49439 .16982 .49056 .16699 Mtetra
.938 .84 .721 r
.49056 .16699 .49439 .16982 .50125 .16505 .49751 .15451 Mtetra
.62 .545 .748 r
.49751 .15451 .50125 .16505 .50813 .15861 .50437 .15193 Mtetra
.726 .689 .815 r
.50437 .15193 .50813 .15861 .51503 .14482 .51125 .14743 Mtetra
.639 .125 .006 r
.51125 .14743 .51503 .14482 .52187 .14962 .51811 .15254 Mtetra
0 0 0 r
.51811 .15254 .52187 .14962 .52878 .15695 .52503 .14994 Mtetra
.777 .7 .778 r
.52503 .14994 .52878 .15695 .53571 .15435 .53196 .14345 Mtetra
.435 .43 .754 r
.53196 .14345 .53571 .15435 .5427 .15867 .53892 .14524 Mtetra
.603 .496 .705 r
.53892 .14524 .5427 .15867 .54968 .15607 .5459 .14262 Mtetra
.5459 .14262 .54968 .15607 .55672 .1573 .55289 .14 Mtetra
.539 .42 .666 r
.55289 .14 .55672 .1573 .56377 .15662 .55992 .13934 Mtetra
.322 .276 .651 r
.55992 .13934 .56377 .15662 .57075 .14952 .56707 .1456 Mtetra
.713 .24 0 r
.56707 .1456 .57075 .14952 .57777 .14489 .57438 .15699 Mtetra
.24 0 .17 r
.57438 .15699 .57777 .14489 .58498 .14917 .58145 .15176 Mtetra
.733 .942 .623 r
.58145 .15176 .58498 .14917 .59199 .14254 .58846 .1432 Mtetra
0 0 0 r
.58846 .1432 .59199 .14254 .59915 .14188 .59564 .1425 Mtetra
.924 .975 .718 r
.59564 .1425 .59915 .14188 .60623 .13724 .6026 .13203 Mtetra
.941 .777 .65 r
.6026 .13203 .60623 .13724 .61267 .11096 .60934 .1148 Mtetra
.405 0 0 r
.60934 .1148 .61267 .11096 .61983 .10995 .6166 .11585 Mtetra
0 0 0 r
.6166 .11585 .61983 .10995 .62682 .10317 .62346 .10414 Mtetra
.575 .006 0 r
.62346 .10414 .62682 .10317 .6344 .11213 .6309 .10884 Mtetra
.985 .786 .556 r
.6309 .10884 .6344 .11213 .64097 .09401 .63718 .08232 Mtetra
.557 .493 .739 r
.63718 .08232 .64097 .09401 .64787 .08499 .64441 .08132 Mtetra
.752 .844 .92 r
.64441 .08132 .64787 .08499 .65491 .07946 .65153 .0771 Mtetra
.853 .927 .877 r
.65153 .0771 .65491 .07946 .6622 .07917 .65856 .07067 Mtetra
.297 .404 .803 r
.65856 .07067 .6622 .07917 .66933 .07494 .66607 .0741 Mtetra
.071 .623 .822 r
.66607 .0741 .66933 .07494 .67672 .07543 .67346 .07438 Mtetra
.265 0 0 r
.67346 .07438 .67672 .07543 .68435 .07965 .68103 .0772 Mtetra
.279 .698 .97 r
.68103 .0772 .68435 .07965 .69156 .07562 .6885 .07741 Mtetra
.974 .885 .516 r
.6885 .07741 .69156 .07562 .69832 .06392 .69484 .05788 Mtetra
.128 .387 .841 r
.69484 .05788 .69832 .06392 .70593 .06629 .70257 .06191 Mtetra
.456 .682 .962 r
.70257 .06191 .70593 .06629 .71413 .07689 .71007 .06173 Mtetra
.2 .221 .658 r
.71007 .06173 .71413 .07689 .72209 .08266 .71822 .07068 Mtetra
.868 .536 .421 r
.05971 .34228 .06529 .33863 .06949 .348 .06216 .36367 Mtetra
.703 .379 .425 r
.06216 .36367 .06949 .348 .07358 .3585 .06604 .3758 Mtetra
.599 .271 .385 r
.06604 .3758 .07358 .3585 .07869 .36216 .07094 .38117 Mtetra
.652 .333 .419 r
.07094 .38117 .07869 .36216 .08235 .37657 .07532 .39057 Mtetra
0 0 0 r
.07532 .39057 .08235 .37657 .08669 .3865 .08274 .37832 Mtetra
.811 .664 .7 r
.08274 .37832 .08669 .3865 .09375 .37662 .08996 .3674 Mtetra
.829 .657 .67 r
.08996 .3674 .09375 .37662 .10059 .36835 .09767 .35275 Mtetra
.74 .56 .65 r
.09767 .35275 .10059 .36835 .10794 .35615 .1049 .34143 Mtetra
.449 .372 .678 r
.1049 .34143 .10794 .35615 .11534 .3433 .11039 .34321 Mtetra
.275 .776 .866 r
.11039 .34321 .11534 .3433 .12188 .33709 .11628 .34215 Mtetra
.522 .844 .547 r
.11628 .34215 .12188 .33709 .12873 .32836 .12285 .33591 Mtetra
.702 .886 .504 r
.12285 .33591 .12873 .32836 .13575 .31813 .12994 .3255 Mtetra
.776 .919 .542 r
.12994 .3255 .13575 .31813 .14203 .31392 .13712 .31418 Mtetra
.951 .849 .705 r
.13712 .31418 .14203 .31392 .14857 .30758 .14469 .29958 Mtetra
.795 .662 .716 r
.14469 .29958 .14857 .30758 .15552 .2977 .15156 .29053 Mtetra
.758 .665 .759 r
.15156 .29053 .15552 .2977 .16145 .29657 .15806 .28446 Mtetra
.657 .535 .704 r
.15806 .28446 .16145 .29657 .16709 .29806 .16434 .2803 Mtetra
0 0 .489 r
.16434 .2803 .16709 .29806 .17265 .3005 .16878 .29239 Mtetra
.699 .622 .767 r
.16878 .29239 .17265 .3005 .17768 .30795 .17511 .28818 Mtetra
.501 .37 .635 r
.17511 .28818 .17768 .30795 .18476 .29709 .1809 .28889 Mtetra
.698 .62 .766 r
.1809 .28889 .18476 .29709 .19302 .27512 .18726 .28469 Mtetra
.757 .868 .44 r
.18726 .28469 .19302 .27512 .20045 .26044 .19469 .27045 Mtetra
.69 .324 .349 r
.19469 .27045 .20045 .26044 .20577 .26579 .19973 .27874 Mtetra
.676 .328 .376 r
.19973 .27874 .20577 .26579 .21133 .26929 .20476 .28762 Mtetra
.397 .075 .299 r
.20476 .28762 .21133 .26929 .21711 .27087 .21101 .28503 Mtetra
.048 0 .085 r
.21101 .28503 .21711 .27087 .22268 .27489 .21782 .27692 Mtetra
.973 .9 .687 r
.21782 .27692 .22268 .27489 .22927 .26866 .22527 .26206 Mtetra
.869 .709 .68 r
.22527 .26206 .22927 .26866 .23525 .26897 .23268 .24741 Mtetra
.722 .521 .618 r
.23268 .24741 .23525 .26897 .24279 .2525 .23995 .23379 Mtetra
.601 .447 .645 r
.23995 .23379 .24279 .2525 .24922 .24804 .24626 .23035 Mtetra
.611 .46 .652 r
.24626 .23035 .24922 .24804 .25601 .23942 .25261 .22661 Mtetra
.045 .125 .624 r
.25261 .22661 .25601 .23942 .26181 .24233 .25798 .23422 Mtetra
.634 .594 .791 r
.25798 .23422 .26181 .24233 .26834 .23684 .26426 .23184 Mtetra
0 .208 .723 r
.26426 .23184 .26834 .23684 .27447 .23642 .26998 .23622 Mtetra
.133 .68 .802 r
.26998 .23622 .27447 .23642 .28048 .23764 .27614 .23575 Mtetra
.831 .359 .042 r
.27614 .23575 .28048 .23764 .28585 .24745 .28152 .24547 Mtetra
.781 .897 .925 r
.28152 .24547 .28585 .24745 .29207 .24705 .28805 .2411 Mtetra
.934 .716 .584 r
.28805 .2411 .29207 .24705 .2997 .22767 .29692 .20575 Mtetra
0 0 .495 r
.29692 .20575 .2997 .22767 .30653 .21876 .302 .22053 Mtetra
.688 .188 .051 r
.302 .22053 .30653 .21876 .31257 .22103 .30783 .22597 Mtetra
.482 .011 .058 r
.30783 .22597 .31257 .22103 .31885 .22022 .31397 .2275 Mtetra
.235 0 .015 r
.31397 .2275 .31885 .22022 .32469 .22647 .32041 .22508 Mtetra
.606 .901 .986 r
.32041 .22508 .32469 .22647 .33043 .23522 .32687 .22265 Mtetra
.011 .111 .623 r
.32687 .22265 .33043 .23522 .33743 .22433 .33267 .23093 Mtetra
.694 .865 .462 r
.33267 .23093 .33743 .22433 .34392 .22176 .33971 .21975 Mtetra
.956 .802 .649 r
.33971 .21975 .34392 .22176 .35064 .21537 .3472 .2007 Mtetra
.695 .537 .669 r
.3472 .2007 .35064 .21537 .35764 .20387 .35396 .19345 Mtetra
.761 .618 .7 r
.35396 .19345 .35764 .20387 .36429 .19868 .36079 .18489 Mtetra
.599 .484 .694 r
.36079 .18489 .36429 .19868 .3708 .19622 .36729 .18242 Mtetra
.563 .462 .697 r
.36729 .18242 .3708 .19622 .37707 .19895 .37375 .18115 Mtetra
.487 .377 .654 r
.37375 .18115 .37707 .19895 .38371 .19454 .38011 .18233 Mtetra
.521 .456 .724 r
.38011 .18233 .38371 .19454 .39086 .179 .38655 .18232 Mtetra
.869 .971 .655 r
.38655 .18232 .39086 .179 .3976 .172 .39348 .1719 Mtetra
.409 .858 .893 r
.39348 .1719 .3976 .172 .40399 .17375 .40004 .16987 Mtetra
.369 .654 .967 r
.40004 .16987 .40399 .17375 .40981 .19143 .40652 .17029 Mtetra
.635 .46 .629 r
.40652 .17029 .40981 .19143 .41669 .18217 .41327 .16409 Mtetra
.483 .373 .653 r
.41327 .16409 .41669 .18217 .42319 .18401 .41976 .16545 Mtetra
.43 .334 .645 r
.41976 .16545 .42319 .18401 .4298 .18347 .42623 .1686 Mtetra
.54 .438 .687 r
.42623 .1686 .4298 .18347 .43661 .17699 .43285 .16801 Mtetra
.691 .343 0 r
.43285 .16801 .43661 .17699 .44311 .18169 .43903 .18372 Mtetra
.911 .977 .7 r
.43903 .18372 .44311 .18169 .44965 .18715 .446 .1732 Mtetra
.707 .552 .676 r
.446 .1732 .44965 .18715 .45636 .18699 .45288 .16564 Mtetra
.323 .244 .611 r
.45288 .16564 .45636 .18699 .46315 .18445 .45943 .17286 Mtetra
.367 .373 .734 r
.45943 .17286 .46315 .18445 .46997 .18097 .46612 .176 Mtetra
.94 .759 .629 r
.46612 .176 .46997 .18097 .47683 .17643 .47326 .15544 Mtetra
.699 .505 .622 r
.47326 .15544 .47683 .17643 .48372 .16955 .4802 .14441 Mtetra
.621 .436 .611 r
.4802 .14441 .48372 .16955 .49056 .16699 .48705 .13791 Mtetra
.461 .312 .591 r
.48705 .13791 .49056 .16699 .49751 .15451 .49381 .1412 Mtetra
.694 .551 .687 r
.49381 .1412 .49751 .15451 .50437 .15193 .50068 .13467 Mtetra
.363 .301 .653 r
.50068 .13467 .50437 .15193 .51125 .14743 .50749 .13959 Mtetra
0 .212 .729 r
.50749 .13959 .51125 .14743 .51811 .15254 .51435 .14579 Mtetra
.542 .604 .865 r
.51435 .14579 .51811 .15254 .52503 .14994 .52127 .14512 Mtetra
.642 .736 .917 r
.52127 .14512 .52503 .14994 .53196 .14345 .52822 .14283 Mtetra
.323 .802 .902 r
.52822 .14283 .53196 .14345 .53892 .14524 .53519 .14148 Mtetra
0 .208 .694 r
.53519 .14148 .53892 .14524 .5459 .14262 .54222 .14639 Mtetra
.476 0 0 r
.54222 .14639 .5459 .14262 .55289 .14 .54928 .14843 Mtetra
0 0 0 r
.54928 .14843 .55289 .14 .55992 .13934 .55625 .138 Mtetra
.449 0 0 r
.55625 .138 .55992 .13934 .56707 .1456 .56339 .14232 Mtetra
.205 .6 .947 r
.56339 .14232 .56707 .1456 .57438 .15699 .57054 .14356 Mtetra
.084 .16 .646 r
.57054 .14356 .57438 .15699 .58145 .15176 .57786 .15284 Mtetra
.95 .954 .667 r
.57786 .15284 .58145 .15176 .58846 .1432 .58482 .14024 Mtetra
.891 .882 .818 r
.58482 .14024 .58846 .1432 .59564 .1425 .59185 .13204 Mtetra
.768 .63 .708 r
.59185 .13204 .59564 .1425 .6026 .13203 .59886 .12339 Mtetra
.777 .667 .742 r
.59886 .12339 .6026 .13203 .60934 .1148 .60589 .11575 Mtetra
.832 .994 .747 r
.60589 .11575 .60934 .1148 .6166 .11585 .61289 .10762 Mtetra
.436 .499 .826 r
.61289 .10762 .6166 .11585 .62346 .10414 .62019 .10882 Mtetra
.913 .877 .448 r
.62019 .10882 .62346 .10414 .6309 .10884 .62681 .08937 Mtetra
.747 .542 .617 r
.62681 .08937 .6309 .10884 .63718 .08232 .63355 .07497 Mtetra
.61 .623 .839 r
.63355 .07497 .63718 .08232 .64441 .08132 .64075 .07304 Mtetra
.508 .539 .823 r
.64075 .07304 .64441 .08132 .65153 .0771 .64806 .07306 Mtetra
.55 .748 .969 r
.64806 .07306 .65153 .0771 .65856 .07067 .65534 .07177 Mtetra
.051 0 0 r
.65534 .07177 .65856 .07067 .66607 .0741 .66268 .07119 Mtetra
.57 .829 .994 r
.66268 .07119 .66607 .0741 .67346 .07438 .66998 .06928 Mtetra
.453 .639 .936 r
.66998 .06928 .67346 .07438 .68103 .0772 .67741 .06938 Mtetra
.847 .715 .717 r
.67741 .06938 .68103 .0772 .6885 .07741 .68429 .05875 Mtetra
.638 .476 .647 r
.68429 .05875 .6885 .07741 .69484 .05788 .69142 .053 Mtetra
.524 .689 .943 r
.69142 .053 .69484 .05788 .70257 .06191 .69886 .0522 Mtetra
.115 .254 .73 r
.69886 .0522 .70257 .06191 .71007 .06173 .70681 .05906 Mtetra
.775 .915 .933 r
.70681 .05906 .71007 .06173 .71822 .07068 .71407 .05429 Mtetra
.914 .593 .424 r
.05466 .34206 .05971 .34228 .06216 .36367 .05618 .36961 Mtetra
.778 .412 .364 r
.05618 .36961 .06216 .36367 .06604 .3758 .06018 .38094 Mtetra
.734 .338 .302 r
.06018 .38094 .06604 .3758 .07094 .38117 .06474 .38873 Mtetra
.61 .211 .263 r
.06474 .38873 .07094 .38117 .07532 .39057 .0699 .3927 Mtetra
.333 .8 .697 r
.0699 .3927 .07532 .39057 .08274 .37832 .07602 .38997 Mtetra
.924 .913 .524 r
.07602 .38997 .08274 .37832 .08996 .3674 .08462 .3694 Mtetra
.967 .844 .669 r
.08462 .3694 .08996 .3674 .09767 .35275 .09292 .35065 Mtetra
.908 .806 .736 r
.09292 .35065 .09767 .35275 .1049 .34143 .10025 .33878 Mtetra
.652 .828 .968 r
.10025 .33878 .1049 .34143 .11039 .34321 .10628 .33654 Mtetra
.685 .653 .812 r
.10628 .33654 .11039 .34321 .11628 .34215 .11245 .3333 Mtetra
.625 .57 .772 r
.11245 .3333 .11628 .34215 .12285 .33591 .11851 .33105 Mtetra
.729 .731 .852 r
.11851 .33105 .12285 .33591 .12994 .3255 .12478 .32727 Mtetra
.955 .916 .734 r
.12478 .32727 .12994 .3255 .13712 .31418 .13209 .31515 Mtetra
.961 .853 .69 r
.13209 .31515 .13712 .31418 .14469 .29958 .13986 .29922 Mtetra
.858 .941 .874 r
.13986 .29922 .14469 .29958 .15156 .29053 .1464 .29311 Mtetra
.971 .902 .692 r
.1464 .29311 .15156 .29053 .15806 .28446 .15396 .27836 Mtetra
.528 .606 .875 r
.15396 .27836 .15806 .28446 .16434 .2803 .15981 .27795 Mtetra
.665 .118 0 r
.15981 .27795 .16434 .2803 .16878 .29239 .16501 .28327 Mtetra
.766 .634 .714 r
.16501 .28327 .16878 .29239 .17511 .28818 .17178 .27523 Mtetra
.395 .359 .7 r
.17178 .27523 .17511 .28818 .1809 .28889 .17735 .27782 Mtetra
.611 .523 .73 r
.17735 .27782 .1809 .28889 .18726 .28469 .1835 .27551 Mtetra
.704 .604 .742 r
.1835 .27551 .18726 .28469 .19469 .27045 .18993 .27061 Mtetra
.959 .84 .681 r
.18993 .27061 .19469 .27045 .19973 .27874 .1976 .2542 Mtetra
0 0 .38 r
.1976 .2542 .19973 .27874 .20476 .28762 .2015 .27346 Mtetra
.736 .469 0 r
.2015 .27346 .20476 .28762 .21101 .28503 .20552 .29248 Mtetra
.992 .882 .569 r
.20552 .29248 .21101 .28503 .21782 .27692 .21405 .26768 Mtetra
.876 .677 .63 r
.21405 .26768 .21782 .27692 .22527 .26206 .22229 .24501 Mtetra
.7 .524 .646 r
.22229 .24501 .22527 .26206 .23268 .24741 .22914 .23612 Mtetra
0 0 .488 r
.22914 .23612 .23268 .24741 .23995 .23379 .23418 .24622 Mtetra
0 0 0 r
.23418 .24622 .23995 .23379 .24626 .23035 .24165 .23075 Mtetra
.841 .984 .868 r
.24165 .23075 .24626 .23035 .25261 .22661 .24823 .22467 Mtetra
.635 .875 .986 r
.24823 .22467 .25261 .22661 .25798 .23422 .25448 .22232 Mtetra
.542 .47 .724 r
.25448 .22232 .25798 .23422 .26426 .23184 .26059 .22177 Mtetra
0 0 .469 r
.26059 .22177 .26426 .23184 .26998 .23622 .26582 .23181 Mtetra
0 .054 .565 r
.26582 .23181 .26998 .23622 .27614 .23575 .27151 .23714 Mtetra
.822 .387 .208 r
.27151 .23714 .27614 .23575 .28152 .24547 .27681 .24778 Mtetra
.744 .985 .765 r
.27681 .24778 .28152 .24547 .28805 .2411 .28353 .24141 Mtetra
.975 .816 .621 r
.28353 .24141 .28805 .2411 .29692 .20575 .29151 .21848 Mtetra
.732 .381 .384 r
.29151 .21848 .29692 .20575 .302 .22053 .29671 .23184 Mtetra
.039 0 .036 r
.29671 .23184 .302 .22053 .30783 .22597 .30346 .22494 Mtetra
.771 .947 .935 r
.30346 .22494 .30783 .22597 .31397 .2275 .31004 .22053 Mtetra
.533 .583 .851 r
.31004 .22053 .31397 .2275 .32041 .22508 .31635 .22007 Mtetra
.75 .745 .848 r
.31635 .22007 .32041 .22508 .32687 .22265 .32295 .21565 Mtetra
.32 .465 .849 r
.32295 .21565 .32687 .22265 .33267 .23093 .32914 .21768 Mtetra
.76 .589 .664 r
.32914 .21768 .33267 .23093 .33971 .21975 .33617 .2068 Mtetra
.603 .496 .706 r
.33617 .2068 .33971 .21975 .3472 .2007 .34267 .20433 Mtetra
.779 .961 .65 r
.34267 .20433 .3472 .2007 .35396 .19345 .34955 .19562 Mtetra
.969 .933 .673 r
.34955 .19562 .35396 .19345 .36079 .18489 .35671 .18179 Mtetra
.47 .752 .991 r
.35671 .18179 .36079 .18489 .36729 .18242 .36312 .18113 Mtetra
.585 .011 0 r
.36312 .18113 .36729 .18242 .37375 .18115 .36928 .18593 Mtetra
0 0 0 r
.36928 .18593 .37375 .18115 .38011 .18233 .37594 .18151 Mtetra
.618 .051 0 r
.37594 .18151 .38011 .18233 .38655 .18232 .38216 .18654 Mtetra
.057 0 0 r
.38216 .18654 .38655 .18232 .39348 .1719 .38877 .18404 Mtetra
0 0 0 r
.38877 .18404 .39348 .1719 .40004 .16987 .39608 .16545 Mtetra
.193 .519 .917 r
.39608 .16545 .40004 .16987 .40652 .17029 .40251 .16733 Mtetra
.881 .849 .808 r
.40251 .16733 .40652 .17029 .41327 .16409 .40936 .15928 Mtetra
.823 .774 .806 r
.40936 .15928 .41327 .16409 .41976 .16545 .41615 .15242 Mtetra
.44 .394 .711 r
.41615 .15242 .41976 .16545 .42623 .1686 .42264 .15435 Mtetra
.54 .444 .694 r
.42264 .15435 .42623 .1686 .43285 .16801 .42925 .15374 Mtetra
.305 .29 .677 r
.42925 .15374 .43285 .16801 .43903 .18372 .43571 .15882 Mtetra
.339 .238 .591 r
.43571 .15882 .43903 .18372 .446 .1732 .44215 .1665 Mtetra
.794 .71 .771 r
.44215 .1665 .446 .1732 .45288 .16564 .44903 .15943 Mtetra
0 .273 .778 r
.44903 .15943 .45288 .16564 .45943 .17286 .45563 .1642 Mtetra
.796 .666 .721 r
.45563 .1642 .45943 .17286 .46612 .176 .46257 .15525 Mtetra
.695 .503 .624 r
.46257 .15525 .46612 .176 .47326 .15544 .46953 .14473 Mtetra
.768 .621 .697 r
.46953 .14473 .47326 .15544 .4802 .14441 .47644 .13572 Mtetra
.633 .59 .787 r
.47644 .13572 .4802 .14441 .48705 .13791 .48324 .13312 Mtetra
.308 .568 .931 r
.48324 .13312 .48705 .13791 .49381 .1412 .49002 .13442 Mtetra
.34 .49 .863 r
.49002 .13442 .49381 .1412 .50068 .13467 .49683 .13631 Mtetra
.238 0 0 r
.49683 .13631 .50068 .13467 .50749 .13959 .50369 .1367 Mtetra
.659 .141 0 r
.50369 .1367 .50749 .13959 .51435 .14579 .51054 .14486 Mtetra
.581 .006 0 r
.51054 .14486 .51435 .14579 .52127 .14512 .51747 .15019 Mtetra
.753 .884 .474 r
.51747 .15019 .52127 .14512 .52822 .14283 .52445 .13797 Mtetra
.928 .781 .678 r
.52445 .13797 .52822 .14283 .53519 .14148 .5314 .12284 Mtetra
.453 .352 .651 r
.5314 .12284 .53519 .14148 .54222 .14639 .53839 .12533 Mtetra
.003 .029 .533 r
.53839 .12533 .54222 .14639 .54928 .14843 .54552 .14159 Mtetra
.217 .415 .842 r
.54552 .14159 .54928 .14843 .55625 .138 .55263 .14485 Mtetra
0 0 0 r
.55263 .14485 .55625 .138 .56339 .14232 .55969 .13935 Mtetra
.85 .885 .864 r
.55969 .13935 .56339 .14232 .57054 .14356 .56674 .13281 Mtetra
.532 .495 .761 r
.56674 .13281 .57054 .14356 .57786 .15284 .57389 .13245 Mtetra
.575 .426 .641 r
.57389 .13245 .57786 .15284 .58482 .14024 .58102 .12977 Mtetra
.723 .607 .728 r
.58102 .12977 .58482 .14024 .59185 .13204 .58809 .12339 Mtetra
.635 .599 .797 r
.58809 .12339 .59185 .13204 .59886 .12339 .59526 .1207 Mtetra
.858 .904 .865 r
.59526 .1207 .59886 .12339 .60589 .11575 .60233 .11397 Mtetra
.602 .903 .985 r
.60233 .11397 .60589 .11575 .61289 .10762 .60952 .11126 Mtetra
.913 .908 .508 r
.60952 .11126 .61289 .10762 .62019 .10882 .6163 .09491 Mtetra
.601 .491 .701 r
.6163 .09491 .62019 .10882 .62681 .08937 .6235 .09218 Mtetra
.911 .928 .551 r
.6235 .09218 .62681 .08937 .63355 .07497 .63028 .07772 Mtetra
0 0 0 r
.63028 .07772 .63355 .07497 .64075 .07304 .63748 .07497 Mtetra
.747 .956 .654 r
.63748 .07497 .64075 .07304 .64806 .07306 .64447 .06671 Mtetra
.261 .463 .868 r
.64447 .06671 .64806 .07306 .65534 .07177 .65193 .06941 Mtetra
.415 .786 .994 r
.65193 .06941 .65534 .07177 .66268 .07119 .65928 .06856 Mtetra
.855 .918 .872 r
.65928 .06856 .66268 .07119 .66998 .06928 .66637 .06197 Mtetra
.745 .69 .799 r
.66637 .06197 .66998 .06928 .67741 .06938 .67352 .05656 Mtetra
.686 .555 .701 r
.67352 .05656 .67741 .06938 .68429 .05875 .68066 .05063 Mtetra
.313 .428 .819 r
.68066 .05063 .68429 .05875 .69142 .053 .6883 .05364 Mtetra
.219 0 0 r
.6883 .05364 .69142 .053 .69886 .0522 .69587 .05472 Mtetra
.704 .187 0 r
.69587 .05472 .69886 .0522 .70681 .05906 .70392 .06273 Mtetra
0 0 0 r
.70392 .06273 .70681 .05906 .71407 .05429 .71121 .05794 Mtetra
.959 .639 .37 r
.05052 .33548 .05466 .34206 .05618 .36961 .05206 .36265 Mtetra
.961 .639 .361 r
.05206 .36265 .05618 .36961 .06018 .38094 .05373 .3897 Mtetra
.686 .316 .34 r
.05373 .3897 .06018 .38094 .06474 .38873 .05837 .39704 Mtetra
.326 0 .089 r
.05837 .39704 .06474 .38873 .0699 .3927 .06431 .39563 Mtetra
.921 .974 .763 r
.06431 .39563 .0699 .3927 .07602 .38997 .07145 .38591 Mtetra
.845 .766 .774 r
.07145 .38591 .07602 .38997 .08462 .3694 .07838 .37755 Mtetra
.981 .91 .603 r
.07838 .37755 .08462 .3694 .09292 .35065 .08703 .35659 Mtetra
.962 .941 .651 r
.08703 .35659 .09292 .35065 .10025 .33878 .09489 .34116 Mtetra
.937 .956 .759 r
.09489 .34116 .10025 .33878 .10628 .33654 .10201 .33088 Mtetra
.788 .713 .782 r
.10201 .33088 .10628 .33654 .11245 .3333 .10861 .32452 Mtetra
.172 .306 .76 r
.10861 .32452 .11245 .3333 .11851 .33105 .11388 .32826 Mtetra
.835 .826 .839 r
.11388 .32826 .11851 .33105 .12478 .32727 .12048 .322 Mtetra
.886 .726 .678 r
.12048 .322 .12478 .32727 .13209 .31515 .12833 .30582 Mtetra
.745 .621 .721 r
.12833 .30582 .13209 .31515 .13986 .29922 .13499 .29888 Mtetra
.858 .941 .873 r
.13499 .29888 .13986 .29922 .1464 .29311 .14155 .29273 Mtetra
.949 .82 .683 r
.14155 .29273 .1464 .29311 .15396 .27836 .1494 .276 Mtetra
.839 .849 .852 r
.1494 .276 .15396 .27836 .15981 .27795 .15592 .26995 Mtetra
0 .166 .699 r
.15592 .26995 .15981 .27795 .16501 .28327 .16113 .27518 Mtetra
.633 .592 .79 r
.16113 .27518 .16501 .28327 .17178 .27523 .16724 .27287 Mtetra
.583 .832 .992 r
.16724 .27287 .17178 .27523 .17735 .27782 .1733 .27118 Mtetra
.805 .695 .743 r
.1733 .27118 .17735 .27782 .1835 .27551 .1801 .263 Mtetra
.496 .431 .713 r
.1801 .263 .1835 .27551 .18993 .27061 .18594 .26352 Mtetra
.823 .69 .717 r
.18594 .26352 .18993 .27061 .1976 .2542 .19294 .25349 Mtetra
.912 .548 .33 r
.19294 .25349 .1976 .2542 .2015 .27346 .1967 .27389 Mtetra
.582 .022 0 r
.1967 .27389 .2015 .27346 .20552 .29248 .20232 .2774 Mtetra
.798 .599 .633 r
.20232 .2774 .20552 .29248 .21405 .26768 .21012 .25999 Mtetra
.791 .671 .731 r
.21012 .25999 .21405 .26768 .22229 .24501 .21694 .25178 Mtetra
.91 .939 .575 r
.21694 .25178 .22229 .24501 .22914 .23612 .22442 .23687 Mtetra
.002 0 0 r
.22442 .23687 .22914 .23612 .23418 .24622 .23047 .23641 Mtetra
.838 .658 .659 r
.23047 .23641 .23418 .24622 .24165 .23075 .23797 .22086 Mtetra
.621 .548 .752 r
.23797 .22086 .24165 .23075 .24823 .22467 .24421 .21846 Mtetra
.023 .311 .8 r
.24421 .21846 .24823 .22467 .25448 .22232 .24992 .2222 Mtetra
.474 0 0 r
.24992 .2222 .25448 .22232 .26059 .22177 .25575 .22496 Mtetra
.849 .464 .319 r
.25575 .22496 .26059 .22177 .26582 .23181 .26051 .24056 Mtetra
.573 .173 .246 r
.26051 .24056 .26582 .23181 .27151 .23714 .26638 .24393 Mtetra
0 0 0 r
.26638 .24393 .27151 .23714 .27681 .24778 .27293 .23959 Mtetra
.538 .546 .811 r
.27293 .23959 .27681 .24778 .28353 .24141 .27918 .23911 Mtetra
.922 .83 .738 r
.27918 .23911 .28353 .24141 .29151 .21848 .28632 .22741 Mtetra
.404 0 .156 r
.28632 .22741 .29151 .21848 .29671 .23184 .29259 .22694 Mtetra
.903 .752 .684 r
.29259 .22694 .29671 .23184 .30346 .22494 .29997 .21185 Mtetra
.601 .493 .703 r
.29997 .21185 .30346 .22494 .31004 .22053 .30639 .20941 Mtetra
.731 .593 .702 r
.30639 .20941 .31004 .22053 .31635 .22007 .31317 .20216 Mtetra
.686 .51 .643 r
.31317 .20216 .31635 .22007 .32295 .21565 .32002 .19387 Mtetra
.529 .382 .626 r
.32002 .19387 .32295 .21565 .32914 .21768 .32634 .19334 Mtetra
.388 .271 .597 r
.32634 .19334 .32914 .21768 .33617 .2068 .33232 .1987 Mtetra
.725 .642 .766 r
.33232 .1987 .33617 .2068 .34267 .20433 .33899 .19352 Mtetra
.801 .634 .674 r
.33899 .19352 .34267 .20433 .34955 .19562 .34607 .18151 Mtetra
.597 .48 .691 r
.34607 .18151 .34955 .19562 .35671 .18179 .35258 .17902 Mtetra
.444 .762 .996 r
.35258 .17902 .35671 .18179 .36312 .18113 .359 .17839 Mtetra
.787 .867 .907 r
.359 .17839 .36312 .18113 .36928 .18593 .36566 .17375 Mtetra
.103 .184 .663 r
.36566 .17375 .36928 .18593 .37594 .18151 .37174 .18074 Mtetra
.91 .516 .245 r
.37174 .18074 .37594 .18151 .38216 .18654 .37721 .20112 Mtetra
.711 .753 .249 r
.37721 .20112 .38216 .18654 .38877 .18404 .38486 .17755 Mtetra
.857 .725 .716 r
.38486 .17755 .38877 .18404 .39608 .16545 .39187 .1664 Mtetra
.863 .996 .803 r
.39187 .1664 .39608 .16545 .40251 .16733 .39871 .15883 Mtetra
.593 .571 .798 r
.39871 .15883 .40251 .16733 .40936 .15928 .40531 .15725 Mtetra
.751 .909 .946 r
.40531 .15725 .40936 .15928 .41615 .15242 .41202 .15324 Mtetra
.316 0 0 r
.41202 .15324 .41615 .15242 .42264 .15435 .41855 .15462 Mtetra
.958 .929 .724 r
.41855 .15462 .42264 .15435 .42925 .15374 .42555 .14282 Mtetra
.686 .574 .723 r
.42555 .14282 .42925 .15374 .43571 .15882 .43231 .13782 Mtetra
.335 .253 .613 r
.43231 .13782 .43571 .15882 .44215 .1665 .43874 .14436 Mtetra
.53 .383 .626 r
.43874 .14436 .44215 .1665 .44903 .15943 .44543 .14375 Mtetra
.167 .181 .63 r
.44543 .14375 .44903 .15943 .45563 .1642 .45192 .1521 Mtetra
.727 .583 .694 r
.45192 .1521 .45563 .1642 .46257 .15525 .45883 .14452 Mtetra
.449 .44 .757 r
.45883 .14452 .46257 .15525 .46953 .14473 .46555 .14589 Mtetra
.901 .986 .747 r
.46555 .14589 .46953 .14473 .47644 .13572 .4725 .13658 Mtetra
.612 .954 .824 r
.4725 .13658 .47644 .13572 .48324 .13312 .47936 .1321 Mtetra
0 .505 .754 r
.47936 .1321 .48324 .13312 .49002 .13442 .48616 .13326 Mtetra
.563 0 0 r
.48616 .13326 .49002 .13442 .49683 .13631 .49294 .13838 Mtetra
.839 .399 .18 r
.49294 .13838 .49683 .13631 .50369 .1367 .49971 .15253 Mtetra
0 0 .079 r
.49971 .15253 .50369 .1367 .51054 .14486 .50674 .13805 Mtetra
.73 .332 0 r
.50674 .13805 .51054 .14486 .51747 .15019 .51363 .15319 Mtetra
.974 .907 .565 r
.51363 .15319 .51747 .15019 .52445 .13797 .52066 .13499 Mtetra
.975 .791 .593 r
.52066 .13499 .52445 .13797 .5314 .12284 .52764 .11127 Mtetra
.103 .202 .682 r
.52764 .11127 .5314 .12284 .53839 .12533 .53463 .11866 Mtetra
0 0 .478 r
.53463 .11866 .53839 .12533 .54552 .14159 .54171 .12893 Mtetra
.05 .148 .647 r
.54171 .12893 .54552 .14159 .55263 .14485 .54886 .13795 Mtetra
.741 .697 .809 r
.54886 .13795 .55263 .14485 .55969 .13935 .55593 .13286 Mtetra
.382 .533 .882 r
.55593 .13286 .55969 .13935 .56674 .13281 .56309 .13419 Mtetra
.825 .99 .729 r
.56309 .13419 .56674 .13281 .57389 .13245 .57014 .12582 Mtetra
.651 .669 .854 r
.57014 .12582 .57389 .13245 .58102 .12977 .57728 .12313 Mtetra
.818 .732 .77 r
.57728 .12313 .58102 .12977 .58809 .12339 .58434 .11521 Mtetra
.544 .564 .825 r
.58434 .11521 .58809 .12339 .59526 .1207 .59155 .11452 Mtetra
.904 .76 .692 r
.59155 .11452 .59526 .1207 .60233 .11397 .59847 .10091 Mtetra
.289 .304 .703 r
.59847 .10091 .60233 .11397 .60952 .11126 .60587 .10624 Mtetra
.878 .799 .768 r
.60587 .10624 .60952 .11126 .6163 .09491 .61289 .09683 Mtetra
.435 .837 .639 r
.61289 .09683 .6163 .09491 .6235 .09218 .62005 .0921 Mtetra
.938 .965 .729 r
.62005 .0921 .6235 .09218 .63028 .07772 .62701 .08145 Mtetra
.239 0 0 r
.62701 .08145 .63028 .07772 .63748 .07497 .63432 .08064 Mtetra
0 0 0 r
.63432 .08064 .63748 .07497 .64447 .06671 .64138 .07294 Mtetra
.45 0 .064 r
.64138 .07294 .64447 .06671 .65193 .06941 .64881 .07412 Mtetra
0 0 0 r
.64881 .07412 .65193 .06941 .65928 .06856 .65602 .06936 Mtetra
.971 .923 .605 r
.65602 .06936 .65928 .06856 .66637 .06197 .66272 .05403 Mtetra
.678 .643 .807 r
.66272 .05403 .66637 .06197 .67352 .05656 .66997 .05034 Mtetra
0 .253 .765 r
.66997 .05034 .67352 .05656 .68066 .05063 .67774 .05623 Mtetra
.432 0 .022 r
.67774 .05623 .68066 .05063 .6883 .05364 .68531 .05727 Mtetra
.514 0 0 r
.68531 .05727 .6883 .05364 .69587 .05472 .69304 .06035 Mtetra
.731 .269 .154 r
.69304 .06035 .69587 .05472 .70392 .06273 .70124 .07045 Mtetra
.258 0 .054 r
.70124 .07045 .70392 .06273 .71121 .05794 .70871 .06762 Mtetra
.97 .653 .336 r
.04674 .32648 .05052 .33548 .05206 .36265 .04831 .3531 Mtetra
.972 .66 .345 r
.04831 .3531 .05206 .36265 .05373 .3897 .04966 .38196 Mtetra
.959 .62 .285 r
.04966 .38196 .05373 .3897 .05837 .39704 .0522 .40353 Mtetra
.969 .933 .646 r
.0522 .40353 .05837 .39704 .06431 .39563 .06038 .38681 Mtetra
.76 .637 .724 r
.06038 .38681 .06431 .39563 .07145 .38591 .06721 .37931 Mtetra
.841 .699 .706 r
.06721 .37931 .07145 .38591 .07838 .37755 .07465 .3674 Mtetra
.843 .655 .649 r
.07465 .3674 .07838 .37755 .08703 .35659 .08302 .34872 Mtetra
.836 .677 .686 r
.08302 .34872 .08703 .35659 .09489 .34116 .0906 .3354 Mtetra
.857 .717 .707 r
.0906 .3354 .09489 .34116 .10201 .33088 .09802 .32311 Mtetra
.682 .623 .782 r
.09802 .32311 .10201 .33088 .10861 .32452 .10424 .31957 Mtetra
.494 .648 .926 r
.10424 .31957 .10861 .32452 .11388 .32826 .11004 .31931 Mtetra
.797 .649 .699 r
.11004 .31931 .11388 .32826 .12048 .322 .11716 .30905 Mtetra
.817 .622 .639 r
.11716 .30905 .12048 .322 .12833 .30582 .12528 .29092 Mtetra
.611 .479 .677 r
.12528 .29092 .12833 .30582 .13499 .29888 .13145 .28784 Mtetra
.668 .556 .719 r
.13145 .28784 .13499 .29888 .14155 .29273 .13777 .2836 Mtetra
.812 .653 .686 r
.13777 .2836 .14155 .29273 .1494 .276 .14503 .27174 Mtetra
.841 .765 .778 r
.14503 .27174 .1494 .276 .15592 .26995 .1518 .26382 Mtetra
.675 .668 .836 r
.1518 .26382 .15592 .26995 .16113 .27518 .15796 .26096 Mtetra
.453 .381 .685 r
.15796 .26096 .16113 .27518 .16724 .27287 .16361 .26254 Mtetra
.421 .421 .754 r
.16361 .26254 .16724 .27287 .1733 .27118 .16928 .26413 Mtetra
.857 .697 .683 r
.16928 .26413 .1733 .27118 .1801 .263 .17676 .25006 Mtetra
.498 .427 .706 r
.17676 .25006 .1801 .263 .18594 .26352 .18259 .25052 Mtetra
.534 .449 .706 r
.18259 .25052 .18594 .26352 .19294 .25349 .18854 .25011 Mtetra
.886 .456 .119 r
.18854 .25011 .19294 .25349 .1967 .27389 .19316 .26231 Mtetra
.664 .548 .713 r
.19316 .26231 .1967 .27389 .20232 .2774 .19959 .258 Mtetra
.515 .383 .639 r
.19959 .258 .20232 .2774 .21012 .25999 .20557 .25806 Mtetra
.636 .875 .986 r
.20557 .25806 .21012 .25999 .21694 .25178 .21183 .25569 Mtetra
.968 .935 .662 r
.21183 .25569 .21694 .25178 .22442 .23687 .21933 .24096 Mtetra
.772 .965 .666 r
.21933 .24096 .22442 .23687 .23047 .23641 .22617 .23269 Mtetra
.882 .786 .751 r
.22617 .23269 .23047 .23641 .23797 .22086 .23317 .22257 Mtetra
.347 0 0 r
.23317 .22257 .23797 .22086 .24421 .21846 .23912 .22356 Mtetra
.542 .083 .111 r
.23912 .22356 .24421 .21846 .24992 .2222 .24496 .22606 Mtetra
0 0 0 r
.24496 .22606 .24992 .2222 .25575 .22496 .25143 .2219 Mtetra
.865 .418 .066 r
.25143 .2219 .25575 .22496 .26051 .24056 .25652 .23347 Mtetra
.714 .312 0 r
.25652 .23347 .26051 .24056 .26638 .24393 .26174 .24439 Mtetra
.789 .991 .884 r
.26174 .24439 .26638 .24393 .27293 .23959 .2684 .23901 Mtetra
.944 .882 .742 r
.2684 .23901 .27293 .23959 .27918 .23911 .27558 .22731 Mtetra
.767 .605 .678 r
.27558 .22731 .27918 .23911 .28632 .22741 .28261 .21707 Mtetra
.649 .56 .741 r
.28261 .21707 .28632 .22741 .29259 .22694 .2891 .21369 Mtetra
.763 .59 .663 r
.2891 .21369 .29259 .22694 .29997 .21185 .29619 .20254 Mtetra
.772 .639 .714 r
.29619 .20254 .29997 .21185 .30639 .20941 .30305 .19424 Mtetra
.698 .535 .663 r
.30305 .19424 .30639 .20941 .31317 .20216 .30985 .18656 Mtetra
.535 .425 .676 r
.30985 .18656 .31317 .20216 .32002 .19387 .31615 .18603 Mtetra
.638 .608 .803 r
.31615 .18603 .32002 .19387 .32634 .19334 .32261 .18355 Mtetra
.73 .612 .726 r
.32261 .18355 .32634 .19334 .33232 .1987 .32933 .17719 Mtetra
.347 .254 .607 r
.32933 .17719 .33232 .1987 .33899 .19352 .33527 .18316 Mtetra
0 0 .568 r
.33527 .18316 .33899 .19352 .34607 .18151 .34108 .1923 Mtetra
.738 .813 .343 r
.34108 .1923 .34607 .18151 .35258 .17902 .34854 .17441 Mtetra
.843 .777 .788 r
.34854 .17441 .35258 .17902 .359 .17839 .35537 .16662 Mtetra
.216 .267 .701 r
.35537 .16662 .359 .17839 .36566 .17375 .36149 .17184 Mtetra
0 .521 .834 r
.36149 .17184 .36566 .17375 .37174 .18074 .36786 .17322 Mtetra
0 .147 .69 r
.36786 .17322 .37174 .18074 .37721 .20112 .37402 .17943 Mtetra
.636 .459 .626 r
.37402 .17943 .37721 .20112 .38486 .17755 .38084 .17299 Mtetra
.818 .783 .82 r
.38084 .17299 .38486 .17755 .39187 .1664 .38766 .16653 Mtetra
.461 .888 .885 r
.38766 .16653 .39187 .1664 .39871 .15883 .39431 .16399 Mtetra
0 0 0 r
.39431 .16399 .39871 .15883 .40531 .15725 .40118 .15662 Mtetra
.88 .961 .848 r
.40118 .15662 .40531 .15725 .41202 .15324 .40803 .14948 Mtetra
.565 .057 0 r
.40803 .14948 .41202 .15324 .41855 .15462 .41436 .15631 Mtetra
.705 .976 .769 r
.41436 .15631 .41855 .15462 .42555 .14282 .4212 .15033 Mtetra
0 0 0 r
.4212 .15033 .42555 .14282 .43231 .13782 .42802 .14488 Mtetra
.42802 .14488 .43231 .13782 .43874 .14436 .43488 .13826 Mtetra
.785 .725 .797 r
.43488 .13826 .43874 .14436 .44543 .14375 .44172 .13208 Mtetra
.202 .263 .703 r
.44172 .13208 .44543 .14375 .45192 .1521 .44826 .13772 Mtetra
.309 .293 .679 r
.44826 .13772 .45192 .1521 .45883 .14452 .45487 .14273 Mtetra
.68 .14 0 r
.45487 .14273 .45883 .14452 .46555 .14589 .46148 .14992 Mtetra
.945 .925 .565 r
.46148 .14992 .46555 .14589 .4725 .13658 .4686 .13366 Mtetra
.914 .854 .768 r
.4686 .13366 .4725 .13658 .47936 .1321 .47557 .12365 Mtetra
0 0 .552 r
.47557 .12365 .47936 .1321 .48616 .13326 .48224 .13336 Mtetra
.769 .263 0 r
.48224 .13336 .48616 .13326 .49294 .13838 .489 .14238 Mtetra
.262 0 0 r
.489 .14238 .49294 .13838 .49971 .15253 .49591 .14172 Mtetra
.544 .499 .757 r
.49591 .14172 .49971 .15253 .50674 .13805 .50286 .14106 Mtetra
.567 .88 .596 r
.50286 .14106 .50674 .13805 .51363 .15319 .50986 .13445 Mtetra
.731 .536 .628 r
.50986 .13445 .51363 .15319 .52066 .13499 .51688 .12205 Mtetra
.731 .578 .683 r
.51688 .12205 .52066 .13499 .52764 .11127 .52387 .11369 Mtetra
.143 0 0 r
.52387 .11369 .52764 .11127 .53463 .11866 .53086 .11289 Mtetra
0 .259 .769 r
.53086 .11289 .53463 .11866 .54171 .12893 .53791 .118 Mtetra
0 .054 .608 r
.53791 .118 .54171 .12893 .54886 .13795 .54505 .12823 Mtetra
.718 .618 .745 r
.54505 .12823 .54886 .13795 .55593 .13286 .55212 .12248 Mtetra
.393 .419 .768 r
.55212 .12248 .55593 .13286 .56309 .13419 .55929 .12483 Mtetra
.795 .661 .716 r
.55929 .12483 .56309 .13419 .57014 .12582 .56633 .11557 Mtetra
.054 .201 .699 r
.56633 .11557 .57014 .12582 .57728 .12313 .57364 .12291 Mtetra
.972 .923 .681 r
.57364 .12291 .57728 .12313 .58434 .11521 .58062 .10938 Mtetra
.807 .757 .806 r
.58062 .10938 .58434 .11521 .59155 .11452 .58771 .10262 Mtetra
.668 .557 .72 r
.58771 .10262 .59155 .11452 .59847 .10091 .59485 .09788 Mtetra
.17 .595 .938 r
.59485 .09788 .59847 .10091 .60587 .10624 .60216 .09917 Mtetra
.492 .574 .866 r
.60216 .09917 .60587 .10624 .61289 .09683 .60946 .09921 Mtetra
0 0 0 r
.60946 .09921 .61289 .09683 .62005 .0921 .61666 .09446 Mtetra
.312 0 0 r
.61666 .09446 .62005 .0921 .62701 .08145 .62404 .09522 Mtetra
.293 0 .212 r
.62404 .09522 .62701 .08145 .63432 .08064 .63127 .09051 Mtetra
0 0 0 r
.63127 .09051 .63432 .08064 .64138 .07294 .63815 .07668 Mtetra
.036 0 0 r
.63815 .07668 .64138 .07294 .64881 .07412 .64545 .07389 Mtetra
.983 .907 .63 r
.64545 .07389 .64881 .07412 .65602 .06936 .6522 .05832 Mtetra
.81 .644 .677 r
.6522 .05832 .65602 .06936 .66272 .05403 .65909 .04657 Mtetra
0 .07 .633 r
.65909 .04657 .66272 .05403 .66997 .05034 .66698 .05577 Mtetra
.697 .228 .135 r
.66698 .05577 .66997 .05034 .67774 .05623 .67491 .06401 Mtetra
.354 0 .086 r
.67491 .06401 .67774 .05623 .68531 .05727 .6824 .06292 Mtetra
.435 0 .021 r
.6824 .06292 .68531 .05727 .69304 .06035 .69005 .06406 Mtetra
.235 0 0 r
.69005 .06406 .69304 .06035 .70124 .07045 .69762 .06322 Mtetra
.649 .656 .844 r
.69762 .06322 .70124 .07045 .70871 .06762 .7051 .06038 Mtetra
0 0 .155 r
.04824 .28306 .04674 .32648 .04831 .3531 .04809 .32026 Mtetra
.926 .718 .23 r
.04809 .32026 .04831 .3531 .04966 .38196 .04617 .37031 Mtetra
.899 .58 .087 r
.04617 .37031 .04966 .38196 .0522 .40353 .04918 .38841 Mtetra
.638 .497 .675 r
.04918 .38841 .0522 .40353 .06038 .38681 .05555 .38413 Mtetra
.906 .78 .711 r
.05555 .38413 .06038 .38681 .06721 .37931 .06333 .37018 Mtetra
.795 .647 .698 r
.06333 .37018 .06721 .37931 .07465 .3674 .07057 .35978 Mtetra
.865 .688 .659 r
.07057 .35978 .07465 .3674 .08302 .34872 .0789 .34152 Mtetra
.861 .692 .672 r
.0789 .34152 .08302 .34872 .0906 .3354 .08689 .3254 Mtetra
.832 .652 .658 r
.08689 .3254 .0906 .3354 .09802 .32311 .09487 .30915 Mtetra
.618 .492 .687 r
.09487 .30915 .09802 .32311 .10424 .31957 .10103 .30598 Mtetra
.647 .515 .688 r
.10103 .30598 .10424 .31957 .11004 .31931 .10735 .30171 Mtetra
.696 .519 .644 r
.10735 .30171 .11004 .31931 .11716 .30905 .11428 .29287 Mtetra
.723 .545 .649 r
.11428 .29287 .11716 .30905 .12528 .29092 .12137 .28269 Mtetra
.699 .62 .765 r
.12137 .28269 .12528 .29092 .13145 .28784 .12769 .27843 Mtetra
.765 .629 .71 r
.12769 .27843 .13145 .28784 .13777 .2836 .13451 .27025 Mtetra
.721 .562 .674 r
.13451 .27025 .13777 .2836 .14503 .27174 .14132 .26211 Mtetra
.682 .585 .74 r
.14132 .26211 .14503 .27174 .1518 .26382 .14764 .25785 Mtetra
.622 .655 .861 r
.14764 .25785 .1518 .26382 .15796 .26096 .15368 .25603 Mtetra
.244 .521 .913 r
.15368 .25603 .15796 .26096 .16361 .26254 .15933 .25759 Mtetra
.13 .451 .883 r
.15933 .25759 .16361 .26254 .16928 .26413 .16493 .25981 Mtetra
.883 .757 .718 r
.16493 .25981 .16928 .26413 .17676 .25006 .17222 .24767 Mtetra
.557 .824 .996 r
.17222 .24767 .17676 .25006 .18259 .25052 .17827 .24618 Mtetra
.494 .683 .95 r
.17827 .24618 .18259 .25052 .18854 .25011 .18423 .24576 Mtetra
.763 .283 0 r
.18423 .24576 .18854 .25011 .19316 .26231 .18926 .25404 Mtetra
0 .161 .695 r
.18926 .25404 .19316 .26231 .19959 .258 .19464 .25953 Mtetra
.567 .935 .817 r
.19464 .25953 .19959 .258 .20557 .25806 .20105 .25567 Mtetra
.883 .842 .8 r
.20105 .25567 .20557 .25806 .21183 .25569 .20793 .24735 Mtetra
.815 .669 .701 r
.20793 .24735 .21183 .25569 .21933 .24096 .21506 .23655 Mtetra
.887 .761 .717 r
.21506 .23655 .21933 .24096 .22617 .23269 .2223 .22437 Mtetra
.841 .677 .68 r
.2223 .22437 .22617 .23269 .23317 .22257 .22964 .21092 Mtetra
0 0 .503 r
.22964 .21092 .23317 .22257 .23912 .22356 .23472 .22089 Mtetra
.893 .471 .159 r
.23472 .22089 .23912 .22356 .24496 .22606 .23952 .23453 Mtetra
.756 .875 .455 r
.23952 .23453 .24496 .22606 .25143 .2219 .24688 .22098 Mtetra
.791 .299 .027 r
.24688 .22098 .25143 .2219 .25652 .23347 .25229 .22901 Mtetra
.758 .282 0 r
.25229 .22901 .25652 .23347 .26174 .24439 .25767 .23799 Mtetra
.851 .718 .715 r
.25767 .23799 .26174 .24439 .2684 .23901 .26483 .22676 Mtetra
.81 .624 .651 r
.26483 .22676 .2684 .23901 .27558 .22731 .27229 .2118 Mtetra
.633 .491 .671 r
.27229 .2118 .27558 .22731 .28261 .21707 .27884 .2075 Mtetra
.845 .666 .659 r
.27884 .2075 .28261 .21707 .2891 .21369 .2863 .19187 Mtetra
.626 .451 .625 r
.2863 .19187 .2891 .21369 .29619 .20254 .29296 .18605 Mtetra
.656 .499 .658 r
.29296 .18605 .29619 .20254 .30305 .19424 .29962 .1802 Mtetra
.591 .476 .691 r
.29962 .1802 .30305 .19424 .30985 .18656 .30603 .1779 Mtetra
.707 .621 .759 r
.30603 .1779 .30985 .18656 .31615 .18603 .31263 .17314 Mtetra
.434 .39 .71 r
.31263 .17314 .31615 .18603 .32261 .18355 .31878 .17502 Mtetra
.734 .637 .751 r
.31878 .17502 .32261 .18355 .32933 .17719 .32547 .16924 Mtetra
.727 .35 0 r
.32547 .16924 .32933 .17719 .33527 .18316 .33094 .18239 Mtetra
.759 .962 .933 r
.33094 .18239 .33527 .18316 .34108 .1923 .33759 .17796 Mtetra
.642 .507 .683 r
.33759 .17796 .34108 .1923 .34854 .17441 .34425 .17353 Mtetra
.148 0 0 r
.34425 .17353 .34854 .17441 .35537 .16662 .35058 .17486 Mtetra
0 0 0 r
.35058 .17486 .35537 .16662 .36149 .17184 .35745 .16718 Mtetra
.51 .682 .943 r
.35745 .16718 .36149 .17184 .36786 .17322 .36393 .1666 Mtetra
.272 .456 .859 r
.36393 .1666 .36786 .17322 .37402 .17943 .37028 .1689 Mtetra
.722 .599 .719 r
.37028 .1689 .37402 .17943 .38084 .17299 .3771 .16249 Mtetra
.357 .386 .755 r
.3771 .16249 .38084 .17299 .38766 .16653 .38349 .16524 Mtetra
.755 .945 .943 r
.38349 .16524 .38766 .16653 .39431 .16399 .39024 .16096 Mtetra
.824 .858 .872 r
.39024 .16096 .39431 .16399 .40118 .15662 .39705 .1552 Mtetra
.316 0 0 r
.39705 .1552 .40118 .15662 .40803 .14948 .40353 .15798 Mtetra
0 0 0 r
.40353 .15798 .40803 .14948 .41436 .15631 .41043 .15066 Mtetra
.527 .643 .907 r
.41043 .15066 .41436 .15631 .4212 .15033 .41708 .15005 Mtetra
.022 .594 .746 r
.41708 .15005 .4212 .15033 .42802 .14488 .42374 .15013 Mtetra
.821 .918 .524 r
.42374 .15013 .42802 .14488 .43488 .13826 .43083 .13734 Mtetra
.909 .942 .816 r
.43083 .13734 .43488 .13826 .44172 .13208 .43776 .12902 Mtetra
.022 .49 .877 r
.43776 .12902 .44172 .13208 .44826 .13772 .4444 .13107 Mtetra
0 .266 .771 r
.4444 .13107 .44826 .13772 .45487 .14273 .45101 .13598 Mtetra
0 .248 .76 r
.45101 .13598 .45487 .14273 .46148 .14992 .45766 .14115 Mtetra
.724 .635 .759 r
.45766 .14115 .46148 .14992 .4686 .13366 .46458 .13568 Mtetra
.934 .964 .672 r
.46458 .13568 .4686 .13366 .47557 .12365 .47162 .12372 Mtetra
.509 0 0 r
.47162 .12372 .47557 .12365 .48224 .13336 .47839 .12744 Mtetra
0 .059 .613 r
.47839 .12744 .48224 .13336 .489 .14238 .48516 .13462 Mtetra
.155 .341 .798 r
.48516 .13462 .489 .14238 .49591 .14172 .49203 .13882 Mtetra
.777 .88 .921 r
.49203 .13882 .49591 .14172 .50286 .14106 .49902 .13418 Mtetra
.539 .603 .866 r
.49902 .13418 .50286 .14106 .50986 .13445 .506 .13351 Mtetra
.962 .906 .716 r
.506 .13351 .50986 .13445 .51688 .12205 .51305 .12099 Mtetra
.91 .951 .813 r
.51305 .12099 .51688 .12205 .52387 .11369 .52007 .11252 Mtetra
.339 0 0 r
.52007 .11252 .52387 .11369 .53086 .11289 .52708 .11563 Mtetra
.174 0 0 r
.52708 .11563 .53086 .11289 .53791 .118 .53413 .11489 Mtetra
0 .216 .671 r
.53413 .11489 .53791 .118 .54505 .12823 .54124 .11942 Mtetra
.732 .643 .761 r
.54124 .11942 .54505 .12823 .55212 .12248 .54832 .11364 Mtetra
0 .005 .581 r
.54832 .11364 .55212 .12248 .55929 .12483 .55556 .12375 Mtetra
.775 .974 .917 r
.55556 .12375 .55929 .12483 .56633 .11557 .56269 .11859 Mtetra
.54 .858 .566 r
.56269 .11859 .56633 .11557 .57364 .12291 .5698 .11185 Mtetra
.834 .654 .659 r
.5698 .11185 .57364 .12291 .58062 .10938 .57678 .09767 Mtetra
.613 .528 .734 r
.57678 .09767 .58062 .10938 .58771 .10262 .58396 .09493 Mtetra
.545 .581 .842 r
.58396 .09493 .58771 .10262 .59485 .09788 .59119 .09417 Mtetra
.726 .838 .934 r
.59119 .09417 .59485 .09788 .60216 .09917 .59838 .09037 Mtetra
.535 .544 .811 r
.59838 .09037 .60216 .09917 .60946 .09921 .60567 .08984 Mtetra
.383 .439 .795 r
.60567 .08984 .60946 .09921 .61666 .09446 .61308 .0921 Mtetra
0 .378 .766 r
.61308 .0921 .61666 .09446 .62404 .09522 .62056 .09512 Mtetra
.933 .969 .735 r
.62056 .09512 .62404 .09522 .63127 .09051 .62761 .08464 Mtetra
.914 .775 .693 r
.62761 .08464 .63127 .09051 .63815 .07668 .63452 .071 Mtetra
.659 .717 .891 r
.63452 .071 .63815 .07668 .64545 .07389 .64183 .0682 Mtetra
.944 .775 .642 r
.64183 .0682 .64545 .07389 .6522 .05832 .64853 .05062 Mtetra
.827 .713 .738 r
.64853 .05062 .6522 .05832 .65909 .04657 .65554 .04137 Mtetra
0 0 .4 r
.65554 .04137 .65909 .04657 .66698 .05577 .66356 .05309 Mtetra
.649 .138 0 r
.66356 .05309 .66698 .05577 .67491 .06401 .67157 .06282 Mtetra
.815 .985 .886 r
.67157 .06282 .67491 .06401 .6824 .06292 .67882 .05671 Mtetra
.743 .733 .843 r
.67882 .05671 .6824 .06292 .69005 .06406 .68614 .05188 Mtetra
.75 .601 .692 r
.68614 .05188 .69005 .06406 .69762 .06322 .69324 .04309 Mtetra
.673 .491 .631 r
.69324 .04309 .69762 .06322 .7051 .06038 .70034 .03442 Mtetra
.914 .512 .178 r
.04382 .27848 .04824 .28306 .04809 .32026 .04739 .29102 Mtetra
.815 .637 .084 r
.04739 .29102 .04809 .32026 .04617 .37031 .04748 .32695 Mtetra
0 0 .031 r
.04748 .32695 .04617 .37031 .04918 .38841 .04651 .371 Mtetra
0 0 .49 r
.04651 .371 .04918 .38841 .05555 .38413 .05063 .38185 Mtetra
.925 .765 .665 r
.05063 .38185 .05555 .38413 .06333 .37018 .05931 .3619 Mtetra
.806 .663 .705 r
.05931 .3619 .06333 .37018 .07057 .35978 .06656 .3515 Mtetra
.869 .681 .646 r
.06656 .3515 .07057 .35978 .0789 .34152 .07528 .33071 Mtetra
.842 .65 .643 r
.07528 .33071 .0789 .34152 .08689 .3254 .08378 .31114 Mtetra
.806 .609 .636 r
.08378 .31114 .08689 .3254 .09487 .30915 .09203 .29298 Mtetra
.512 .401 .665 r
.09203 .29298 .09487 .30915 .10103 .30598 .09773 .2931 Mtetra
.694 .55 .687 r
.09773 .2931 .10103 .30598 .10735 .30171 .10431 .28685 Mtetra
.726 .555 .659 r
.10431 .28685 .10735 .30171 .11428 .29287 .11132 .27734 Mtetra
.587 .458 .671 r
.11132 .27734 .11428 .29287 .12137 .28269 .11738 .27503 Mtetra
.767 .66 .744 r
.11738 .27503 .12137 .28269 .12769 .27843 .12404 .26818 Mtetra
.719 .595 .716 r
.12404 .26818 .12769 .27843 .13451 .27025 .1306 .26207 Mtetra
.774 .652 .729 r
.1306 .26207 .13451 .27025 .14132 .26211 .13736 .2544 Mtetra
.754 .654 .751 r
.13736 .2544 .14132 .26211 .14764 .25785 .14392 .2482 Mtetra
.466 .464 .772 r
.14392 .2482 .14764 .25785 .15368 .25603 .14964 .24896 Mtetra
.351 .477 .847 r
.14964 .24896 .15368 .25603 .15933 .25759 .15529 .25052 Mtetra
.258 .423 .836 r
.15529 .25052 .15933 .25759 .16493 .25981 .16087 .25287 Mtetra
.859 .7 .684 r
.16087 .25287 .16493 .25981 .17222 .24767 .16839 .23884 Mtetra
.82 .661 .686 r
.16839 .23884 .17222 .24767 .17827 .24618 .17566 .22675 Mtetra
0 0 .357 r
.17566 .22675 .17827 .24618 .18423 .24576 .17968 .24333 Mtetra
.809 .321 0 r
.17968 .24333 .18423 .24576 .18926 .25404 .1847 .25163 Mtetra
.39 .754 .992 r
.1847 .25163 .18926 .25404 .19464 .25953 .19072 .25121 Mtetra
.702 .623 .766 r
.19072 .25121 .19464 .25953 .20105 .25567 .1972 .2468 Mtetra
.694 .608 .756 r
.1972 .2468 .20105 .25567 .20793 .24735 .20367 .24243 Mtetra
.839 .752 .768 r
.20367 .24243 .20793 .24735 .21506 .23655 .21056 .2341 Mtetra
.937 .784 .666 r
.21056 .2341 .21506 .23655 .2223 .22437 .21842 .21603 Mtetra
.059 .249 .743 r
.21842 .21603 .2223 .22437 .22964 .21092 .22399 .22065 Mtetra
.29 0 .111 r
.22399 .22065 .22964 .21092 .23472 .22089 .23029 .21823 Mtetra
.498 0 0 r
.23029 .21823 .23472 .22089 .23952 .23453 .23596 .22257 Mtetra
.731 .583 .69 r
.23596 .22257 .23952 .23453 .24688 .22098 .2428 .21471 Mtetra
0 0 .54 r
.2428 .21471 .24688 .22098 .25229 .22901 .24832 .22144 Mtetra
0 .195 .722 r
.24832 .22144 .25229 .22901 .25767 .23799 .25402 .22661 Mtetra
.76 .606 .687 r
.25402 .22661 .25767 .23799 .26483 .22676 .26102 .21731 Mtetra
.846 .668 .661 r
.26102 .21731 .26483 .22676 .27229 .2118 .26855 .2017 Mtetra
.786 .634 .692 r
.26855 .2017 .27229 .2118 .27884 .2075 .27558 .19163 Mtetra
.742 .559 .646 r
.27558 .19163 .27884 .2075 .2863 .19187 .28271 .18015 Mtetra
.624 .524 .72 r
.28271 .18015 .2863 .19187 .29296 .18605 .28914 .17719 Mtetra
.468 .49 .798 r
.28914 .17719 .29296 .18605 .29962 .1802 .29532 .17784 Mtetra
.768 .882 .928 r
.29532 .17784 .29962 .1802 .30603 .1779 .30188 .17367 Mtetra
.786 .786 .852 r
.30188 .17367 .30603 .1779 .31263 .17314 .30851 .16853 Mtetra
.177 .501 .909 r
.30851 .16853 .31263 .17314 .31878 .17502 .31466 .17046 Mtetra
.508 .684 .946 r
.31466 .17046 .31878 .17502 .32547 .16924 .32101 .16989 Mtetra
.143 .686 .721 r
.32101 .16989 .32547 .16924 .33094 .18239 .32742 .16875 Mtetra
.687 .541 .682 r
.32742 .16875 .33094 .18239 .33759 .17796 .33418 .16246 Mtetra
.52 .417 .678 r
.33418 .16246 .33759 .17796 .34425 .17353 .34057 .16233 Mtetra
.011 .141 .653 r
.34057 .16233 .34425 .17353 .35058 .17486 .34653 .16961 Mtetra
.91 .751 .672 r
.34653 .16961 .35058 .17486 .35745 .16718 .3539 .15351 Mtetra
.545 .453 .701 r
.3539 .15351 .35745 .16718 .36393 .1666 .36038 .15271 Mtetra
.3 .29 .681 r
.36038 .15271 .36393 .1666 .37028 .1689 .36659 .15741 Mtetra
.746 .599 .694 r
.36659 .15741 .37028 .1689 .3771 .16249 .37351 .14907 Mtetra
.497 .426 .707 r
.37351 .14907 .3771 .16249 .38349 .16524 .37999 .14955 Mtetra
.476 .388 .677 r
.37999 .14955 .38349 .16524 .39024 .16096 .38647 .15074 Mtetra
.317 .369 .757 r
.38647 .15074 .39024 .16096 .39705 .1552 .39289 .15395 Mtetra
.406 0 0 r
.39289 .15395 .39705 .1552 .40353 .15798 .39935 .15725 Mtetra
.807 .972 .904 r
.39935 .15725 .40353 .15798 .41043 .15066 .4062 .15182 Mtetra
.74 .991 .816 r
.4062 .15182 .41043 .15066 .41708 .15005 .41307 .14596 Mtetra
.785 .808 .871 r
.41307 .14596 .41708 .15005 .42374 .15013 .41992 .14091 Mtetra
.786 .653 .715 r
.41992 .14091 .42374 .15013 .43083 .13734 .4269 .13206 Mtetra
.885 .766 .725 r
.4269 .13206 .43083 .13734 .43776 .12902 .43394 .12068 Mtetra
0 .104 .656 r
.43394 .12068 .43776 .12902 .4444 .13107 .44042 .12807 Mtetra
.675 .157 0 r
.44042 .12807 .4444 .13107 .45101 .13598 .44695 .13608 Mtetra
.116 .668 .757 r
.44695 .13608 .45101 .13598 .45766 .14115 .45376 .13538 Mtetra
.822 .75 .784 r
.45376 .13538 .45766 .14115 .46458 .13568 .46073 .12785 Mtetra
.764 .675 .764 r
.46073 .12785 .46458 .13568 .47162 .12372 .46769 .12135 Mtetra
0 .316 .71 r
.46769 .12135 .47162 .12372 .47839 .12744 .47448 .1245 Mtetra
0 .34 .761 r
.47448 .1245 .47839 .12744 .48516 .13462 .48131 .12775 Mtetra
.192 .4 .837 r
.48131 .12775 .48516 .13462 .49203 .13882 .48818 .13105 Mtetra
.841 .465 0 r
.48818 .13105 .49203 .13882 .49902 .13418 .49492 .15263 Mtetra
0 0 .041 r
.49492 .15263 .49902 .13418 .506 .13351 .50211 .13257 Mtetra
.98 .868 .653 r
.50211 .13257 .506 .13351 .51305 .12099 .50922 .11605 Mtetra
.662 .744 .911 r
.50922 .11605 .51305 .12099 .52007 .11252 .51624 .11336 Mtetra
.955 .951 .691 r
.51624 .11336 .52007 .11252 .52708 .11563 .52328 .10108 Mtetra
.311 .296 .681 r
.52328 .10108 .52708 .11563 .53413 .11489 .53032 .10623 Mtetra
0 .203 .718 r
.53032 .10623 .53413 .11489 .54124 .11942 .53743 .11286 Mtetra
0 .246 .76 r
.53743 .11286 .54124 .11942 .54832 .11364 .5446 .11838 Mtetra
.543 .052 .04 r
.5446 .11838 .54832 .11364 .55556 .12375 .5518 .12161 Mtetra
.938 .898 .761 r
.5518 .12161 .55556 .12375 .56269 .11859 .55889 .11096 Mtetra
.911 .727 .642 r
.55889 .11096 .56269 .11859 .5698 .11185 .56585 .09287 Mtetra
.485 .373 .652 r
.56585 .09287 .5698 .11185 .57678 .09767 .57308 .09408 Mtetra
.227 .6 .95 r
.57308 .09408 .57678 .09767 .58396 .09493 .58034 .09531 Mtetra
.441 .878 .826 r
.58034 .09531 .58396 .09493 .59119 .09417 .58755 .09219 Mtetra
.801 .944 .919 r
.58755 .09219 .59119 .09417 .59838 .09037 .59473 .08686 Mtetra
0 .436 .858 r
.59473 .08686 .59838 .09037 .60567 .08984 .60212 .08975 Mtetra
.421 .867 .867 r
.60212 .08975 .60567 .08984 .61308 .0921 .60941 .08715 Mtetra
.808 .799 .844 r
.60941 .08715 .61308 .0921 .62056 .09512 .6166 .08099 Mtetra
.735 .571 .67 r
.6166 .08099 .62056 .09512 .62761 .08464 .62369 .07167 Mtetra
.829 .633 .638 r
.62369 .07167 .62761 .08464 .63452 .071 .63053 .05582 Mtetra
.594 .475 .687 r
.63053 .05582 .63452 .071 .64183 .0682 .63783 .053 Mtetra
.669 .521 .675 r
.63783 .053 .64183 .0682 .64853 .05062 .645 .04683 Mtetra
.782 .853 .904 r
.645 .04683 .64853 .05062 .65554 .04137 .65224 .04187 Mtetra
.339 .816 .776 r
.65224 .04187 .65554 .04137 .66356 .05309 .65959 .03919 Mtetra
.207 .241 .677 r
.65959 .03919 .66356 .05309 .67157 .06282 .66746 .0467 Mtetra
.619 .483 .675 r
.66746 .0467 .67157 .06282 .67882 .05671 .6748 .04257 Mtetra
.691 .546 .684 r
.6748 .04257 .67882 .05671 .68614 .05188 .68201 .03574 Mtetra
.777 .579 .632 r
.68201 .03574 .68614 .05188 .69324 .04309 .6888 .02169 Mtetra
.566 .415 .635 r
.6888 .02169 .69324 .04309 .70034 .03442 .69624 .0191 Mtetra
.922 .851 .407 r
.03409 .3076 .04382 .27848 .04739 .29102 .04649 .2635 Mtetra
.962 .728 .283 r
.04649 .2635 .04739 .29102 .04748 .32695 .0447 .31103 Mtetra
.977 .694 .302 r
.0447 .31103 .04748 .32695 .04651 .371 .04521 .34471 Mtetra
.769 .592 .023 r
.04521 .34471 .04651 .371 .05063 .38185 .0463 .37541 Mtetra
.886 .704 .65 r
.0463 .37541 .05063 .38185 .05931 .3619 .0552 .3542 Mtetra
.89 .69 .626 r
.0552 .3542 .05931 .3619 .06656 .3515 .06492 .32702 Mtetra
.71 .506 .611 r
.06492 .32702 .06656 .3515 .07528 .33071 .07269 .31279 Mtetra
.622 .466 .65 r
.07269 .31279 .07528 .33071 .08378 .31114 .07903 .30842 Mtetra
.91 .78 .706 r
.07903 .30842 .08378 .31114 .09203 .29298 .08676 .29421 Mtetra
.574 .941 .862 r
.08676 .29421 .09203 .29298 .09773 .2931 .09296 .29078 Mtetra
.896 .815 .76 r
.09296 .29078 .09773 .2931 .10431 .28685 .10011 .28055 Mtetra
.851 .707 .704 r
.10011 .28055 .10431 .28685 .11132 .27734 .1075 .26839 Mtetra
.737 .623 .732 r
.1075 .26839 .11132 .27734 .11738 .27503 .11407 .26214 Mtetra
.765 .593 .664 r
.11407 .26214 .11738 .27503 .12404 .26818 .12132 .25082 Mtetra
.7 .522 .644 r
.12132 .25082 .12404 .26818 .1306 .26207 .12825 .24179 Mtetra
.401 .294 .616 r
.12825 .24179 .1306 .26207 .13736 .2544 .13355 .24536 Mtetra
.796 .648 .699 r
.13355 .24536 .13736 .2544 .14392 .2482 .14061 .23527 Mtetra
.395 .358 .7 r
.14061 .23527 .14392 .2482 .14964 .24896 .14611 .23768 Mtetra
.434 .411 .734 r
.14611 .23768 .14964 .24896 .15529 .25052 .15176 .23915 Mtetra
.293 .319 .718 r
.15176 .23915 .15529 .25052 .16087 .25287 .15719 .24265 Mtetra
.802 .637 .677 r
.15719 .24265 .16087 .25287 .16839 .23884 .16449 .23062 Mtetra
.792 .661 .718 r
.16449 .23062 .16839 .23884 .17566 .22675 .17139 .22178 Mtetra
.801 .345 0 r
.17139 .22178 .17566 .22675 .17968 .24333 .1762 .23122 Mtetra
0 0 .24 r
.1762 .23122 .17968 .24333 .1847 .25163 .18055 .24527 Mtetra
.326 .498 .875 r
.18055 .24527 .1847 .25163 .19072 .25121 .18636 .24681 Mtetra
.83 .77 .796 r
.18636 .24681 .19072 .25121 .1972 .2468 .19315 .23961 Mtetra
.765 .675 .763 r
.19315 .23961 .1972 .2468 .20367 .24243 .19984 .23327 Mtetra
.737 .624 .733 r
.19984 .23327 .20367 .24243 .21056 .2341 .20653 .22695 Mtetra
.766 .677 .764 r
.20653 .22695 .21056 .2341 .21842 .21603 .21321 .22064 Mtetra
.053 0 0 r
.21321 .22064 .21842 .21603 .22399 .22065 .2195 .21821 Mtetra
.65 .854 .978 r
.2195 .21821 .22399 .22065 .23029 .21823 .22581 .21579 Mtetra
.449 .783 .998 r
.22581 .21579 .23029 .21823 .23596 .22257 .23198 .21499 Mtetra
.392 .487 .837 r
.23198 .21499 .23596 .22257 .2428 .21471 .23797 .21631 Mtetra
.084 0 0 r
.23797 .21631 .2428 .21471 .24832 .22144 .24416 .21577 Mtetra
.655 .689 .87 r
.24416 .21577 .24832 .22144 .25402 .22661 .25054 .21332 Mtetra
.746 .58 .669 r
.25054 .21332 .25402 .22661 .26102 .21731 .2576 .2035 Mtetra
.74 .572 .665 r
.2576 .2035 .26102 .21731 .26855 .2017 .26462 .19377 Mtetra
.79 .671 .732 r
.26462 .19377 .26855 .2017 .27558 .19163 .27151 .18556 Mtetra
.871 .728 .701 r
.27151 .18556 .27558 .19163 .28271 .18015 .27876 .17285 Mtetra
.643 .626 .818 r
.27876 .17285 .28271 .18015 .28914 .17719 .28516 .17036 Mtetra
.647 .643 .832 r
.28516 .17036 .28914 .17719 .29532 .17784 .29158 .16786 Mtetra
.144 .258 .724 r
.29158 .16786 .29532 .17784 .30188 .17367 .29745 .17279 Mtetra
.239 .74 .9 r
.29745 .17279 .30188 .17367 .30851 .16853 .30377 .17223 Mtetra
0 0 0 r
.30377 .17223 .30851 .16853 .31466 .17046 .31029 .16914 Mtetra
.857 .928 .874 r
.31029 .16914 .31466 .17046 .32101 .16989 .31705 .16285 Mtetra
.756 .682 .78 r
.31705 .16285 .32101 .16989 .32742 .16875 .32378 .15712 Mtetra
.564 .491 .732 r
.32378 .15712 .32742 .16875 .33418 .16246 .33021 .1559 Mtetra
.763 .699 .791 r
.33021 .1559 .33418 .16246 .34057 .16233 .33694 .15021 Mtetra
.248 .282 .701 r
.33694 .15021 .34057 .16233 .34653 .16961 .34304 .15498 Mtetra
.708 .546 .667 r
.34304 .15498 .34653 .16961 .3539 .15351 .34994 .14696 Mtetra
.431 .551 .876 r
.34994 .14696 .3539 .15351 .36038 .15271 .35633 .14764 Mtetra
.834 .765 .786 r
.35633 .14764 .36038 .15271 .36659 .15741 .36322 .13998 Mtetra
.467 .366 .657 r
.36322 .13998 .36659 .15741 .37351 .14907 .36961 .14153 Mtetra
.734 .664 .781 r
.36961 .14153 .37351 .14907 .37999 .14955 .37638 .13635 Mtetra
.632 .513 .7 r
.37638 .13635 .37999 .14955 .38647 .15074 .38308 .13264 Mtetra
0 0 .444 r
.38308 .13264 .38647 .15074 .39289 .15395 .38886 .14918 Mtetra
.127 .464 .89 r
.38886 .14918 .39289 .15395 .39935 .15725 .39536 .15161 Mtetra
.684 .243 0 r
.39536 .15161 .39935 .15725 .4062 .15182 .40156 .16213 Mtetra
.741 .808 .333 r
.40156 .16213 .4062 .15182 .41307 .14596 .40898 .1436 Mtetra
.941 .848 .722 r
.40898 .1436 .41307 .14596 .41992 .14091 .41612 .13099 Mtetra
.662 .58 .753 r
.41612 .13099 .41992 .14091 .4269 .13206 .42293 .12722 Mtetra
.144 .47 .893 r
.42293 .12722 .4269 .13206 .43394 .12068 .42955 .12962 Mtetra
.384 0 .135 r
.42955 .12962 .43394 .12068 .44042 .12807 .4363 .12891 Mtetra
.722 .204 0 r
.4363 .12891 .44042 .12807 .44695 .13608 .44287 .1361 Mtetra
.703 .981 .896 r
.44287 .1361 .44695 .13608 .45376 .13538 .44979 .13148 Mtetra
.788 .825 .881 r
.44979 .13148 .45376 .13538 .46073 .12785 .45673 .1264 Mtetra
.596 .909 .981 r
.45673 .1264 .46073 .12785 .46769 .12135 .46363 .12374 Mtetra
.367 .795 .611 r
.46363 .12374 .46769 .12135 .47448 .1245 .47057 .11959 Mtetra
0 .198 .713 r
.47057 .11959 .47448 .1245 .48131 .12775 .47737 .12481 Mtetra
.875 .875 .832 r
.47737 .12481 .48131 .12775 .48818 .13105 .48441 .11722 Mtetra
0 .037 .577 r
.48441 .11722 .48818 .13105 .49492 .15263 .49122 .12864 Mtetra
.626 .444 .616 r
.49122 .12864 .49492 .15263 .50211 .13257 .49828 .12191 Mtetra
.871 .673 .632 r
.49828 .12191 .50211 .13257 .50922 .11605 .50542 .10314 Mtetra
.649 .531 .706 r
.50542 .10314 .50922 .11605 .51624 .11336 .51243 .09879 Mtetra
.596 .48 .692 r
.51243 .09879 .51624 .11336 .52328 .10108 .51946 .09608 Mtetra
0 0 .477 r
.51946 .09608 .52328 .10108 .53032 .10623 .52651 .10464 Mtetra
.622 .066 0 r
.52651 .10464 .53032 .10623 .53743 .11286 .53363 .11133 Mtetra
.877 .438 .083 r
.53363 .11133 .53743 .11286 .5446 .11838 .54087 .12936 Mtetra
.728 .758 .252 r
.54087 .12936 .5446 .11838 .5518 .12161 .54791 .10669 Mtetra
.708 .548 .669 r
.54791 .10669 .5518 .12161 .55889 .11096 .55502 .09848 Mtetra
.542 .475 .73 r
.55502 .09848 .55889 .11096 .56585 .09287 .56222 .09773 Mtetra
.487 0 .009 r
.56222 .09773 .56585 .09287 .57308 .09408 .5695 .09994 Mtetra
0 0 0 r
.5695 .09994 .57308 .09408 .58034 .09531 .57669 .09518 Mtetra
.788 .997 .855 r
.57669 .09518 .58034 .09531 .58755 .09219 .58386 .08901 Mtetra
.705 .864 .957 r
.58386 .08901 .58755 .09219 .59473 .08686 .5911 .08549 Mtetra
0 .512 .79 r
.5911 .08549 .59473 .08686 .60212 .08975 .59848 .08691 Mtetra
.924 .887 .777 r
.59848 .08691 .60212 .08975 .60941 .08715 .60557 .07693 Mtetra
.859 .677 .655 r
.60557 .07693 .60941 .08715 .6166 .08099 .6125 .06169 Mtetra
.594 .444 .647 r
.6125 .06169 .6166 .08099 .62369 .07167 .61976 .05804 Mtetra
.682 .545 .692 r
.61976 .05804 .62369 .07167 .63053 .05582 .62694 .0519 Mtetra
.662 .811 .955 r
.62694 .0519 .63053 .05582 .63783 .053 .63426 .04907 Mtetra
.823 .853 .87 r
.63426 .04907 .63783 .053 .645 .04683 .64146 .04298 Mtetra
.579 .782 .976 r
.64146 .04298 .645 .04683 .65224 .04187 .64885 .0412 Mtetra
.85 .993 .838 r
.64885 .0412 .65224 .04187 .65959 .03919 .65602 .03401 Mtetra
.563 .7 .933 r
.65602 .03401 .65959 .03919 .66746 .0467 .66347 .03268 Mtetra
.723 .565 .675 r
.66347 .03268 .66746 .0467 .6748 .04257 .67058 .02418 Mtetra
.581 .442 .656 r
.67058 .02418 .6748 .04257 .68201 .03574 .67798 .02131 Mtetra
.515 .435 .703 r
.67798 .02131 .68201 .03574 .6888 .02169 .68557 .02129 Mtetra
.584 .01 0 r
.68557 .02129 .6888 .02169 .69624 .0191 .69356 .02757 Mtetra
.999 .829 .531 r
.02561 .32805 .03409 .3076 .04649 .2635 .04008 .27141 Mtetra
.828 .501 .434 r
.04008 .27141 .04649 .2635 .0447 .31103 .04238 .29224 Mtetra
.96 .695 .255 r
.04238 .29224 .0447 .31103 .04521 .34471 .04284 .32568 Mtetra
.917 .662 .168 r
.04284 .32568 .04521 .34471 .0463 .37541 .04412 .35464 Mtetra
.475 .345 .624 r
.04412 .35464 .0463 .37541 .0552 .3542 .04966 .35596 Mtetra
.958 .761 .596 r
.04966 .35596 .0552 .3542 .06492 .32702 .06128 .3163 Mtetra
.825 .643 .656 r
.06128 .3163 .06492 .32702 .07269 .31279 .06936 .30007 Mtetra
.3 .299 .691 r
.06936 .30007 .07269 .31279 .07903 .30842 .07454 .30374 Mtetra
.857 .746 .739 r
.07454 .30374 .07903 .30842 .08676 .29421 .08173 .2935 Mtetra
.89 .9 .829 r
.08173 .2935 .08676 .29421 .09296 .29078 .08854 .28587 Mtetra
.855 .74 .736 r
.08854 .28587 .09296 .29078 .10011 .28055 .0957 .27562 Mtetra
.824 .742 .774 r
.0957 .27562 .10011 .28055 .1075 .26839 .10249 .26798 Mtetra
.922 .882 .777 r
.10249 .26798 .1075 .26839 .11407 .26214 .10959 .25803 Mtetra
.899 .75 .688 r
.10959 .25803 .11407 .26214 .12132 .25082 .1174 .24265 Mtetra
.844 .676 .675 r
.1174 .24265 .12132 .25082 .12825 .24179 .12503 .22831 Mtetra
.554 .454 .696 r
.12503 .22831 .12825 .24179 .13355 .24536 .13091 .22726 Mtetra
.606 .453 .647 r
.13091 .22726 .13355 .24536 .14061 .23527 .13715 .22358 Mtetra
.673 .55 .707 r
.13715 .22358 .14061 .23527 .14611 .23768 .14353 .21886 Mtetra
.574 .426 .642 r
.14353 .21886 .14611 .23768 .15176 .23915 .14962 .21648 Mtetra
.121 .076 .529 r
.14962 .21648 .15176 .23915 .15719 .24265 .15414 .22722 Mtetra
.587 .459 .673 r
.15414 .22722 .15719 .24265 .16449 .23062 .16028 .22483 Mtetra
0 .193 .72 r
.16028 .22483 .16449 .23062 .17139 .22178 .16565 .2292 Mtetra
.21 0 0 r
.16565 .2292 .17139 .22178 .1762 .23122 .17184 .22681 Mtetra
.902 .489 .127 r
.17184 .22681 .1762 .23122 .18055 .24527 .17622 .24045 Mtetra
0 .037 .557 r
.17622 .24045 .18055 .24527 .18636 .24681 .18161 .24573 Mtetra
.936 .848 .731 r
.18161 .24573 .18636 .24681 .19315 .23961 .189 .2332 Mtetra
.727 .685 .809 r
.189 .2332 .19315 .23961 .19984 .23327 .19549 .22883 Mtetra
.892 .759 .708 r
.19549 .22883 .19984 .23327 .20653 .22695 .20291 .21576 Mtetra
.795 .625 .671 r
.20291 .21576 .20653 .22695 .21321 .22064 .2102 .20362 Mtetra
.134 .133 .591 r
.2102 .20362 .21321 .22064 .2195 .21821 .2154 .21178 Mtetra
.073 .34 .815 r
.2154 .21178 .2195 .21821 .22581 .21579 .22112 .21519 Mtetra
.56 .914 .962 r
.22112 .21519 .22581 .21579 .23198 .21499 .22747 .21275 Mtetra
0 .504 .839 r
.22747 .21275 .23198 .21499 .23797 .21631 .23345 .21423 Mtetra
.926 .83 .731 r
.23345 .21423 .23797 .21631 .24416 .21577 .24075 .20193 Mtetra
.454 .39 .696 r
.24075 .20193 .24416 .21577 .25054 .21332 .24677 .20337 Mtetra
.717 .603 .728 r
.24677 .20337 .25054 .21332 .2576 .2035 .25347 .19751 Mtetra
.867 .73 .708 r
.25347 .19751 .2576 .2035 .26462 .19377 .26073 .18535 Mtetra
.857 .684 .667 r
.26073 .18535 .26462 .19377 .27151 .18556 .26823 .1701 Mtetra
.571 .45 .676 r
.26823 .1701 .27151 .18556 .27876 .17285 .27457 .16825 Mtetra
.663 .741 .908 r
.27457 .16825 .27876 .17285 .28516 .17036 .28098 .16575 Mtetra
.7 .752 .892 r
.28098 .16575 .28516 .17036 .29158 .16786 .28746 .16259 Mtetra
.722 .267 0 r
.28746 .16259 .29158 .16786 .29745 .17279 .29297 .17206 Mtetra
.217 .73 .881 r
.29297 .17206 .29745 .17279 .30377 .17223 .29931 .1715 Mtetra
.918 .92 .8 r
.29931 .1715 .30377 .17223 .31029 .16914 .30628 .16258 Mtetra
.775 .702 .782 r
.30628 .16258 .31029 .16914 .31705 .16285 .31304 .15637 Mtetra
.421 .549 .879 r
.31304 .15637 .31705 .16285 .32378 .15712 .31933 .15711 Mtetra
.746 .983 .908 r
.31933 .15711 .32378 .15712 .33021 .1559 .32601 .15242 Mtetra
.663 .806 .952 r
.32601 .15242 .33021 .1559 .33694 .15021 .33256 .14986 Mtetra
.89 .959 .837 r
.33256 .14986 .33694 .15021 .34304 .15498 .33943 .14236 Mtetra
.436 .398 .717 r
.33943 .14236 .34304 .15498 .34994 .14696 .34574 .14408 Mtetra
.78 .286 0 r
.34574 .14408 .34994 .14696 .35633 .14764 .35164 .15341 Mtetra
.957 .913 .549 r
.35164 .15341 .35633 .14764 .36322 .13998 .35919 .13458 Mtetra
.587 .681 .905 r
.35919 .13458 .36322 .13998 .36961 .14153 .36575 .13315 Mtetra
.59 .575 .804 r
.36575 .13315 .36961 .14153 .37638 .13635 .37233 .13157 Mtetra
0 .21 .719 r
.37233 .13157 .37638 .13635 .38308 .13264 .37863 .13621 Mtetra
.653 .168 .089 r
.37863 .13621 .38308 .13264 .38886 .14918 .38495 .1415 Mtetra
.636 .258 0 r
.38495 .1415 .38886 .14918 .39536 .15161 .39101 .15352 Mtetra
.621 .091 0 r
.39101 .15352 .39536 .15161 .40156 .16213 .39747 .15813 Mtetra
.956 .762 .601 r
.39747 .15813 .40156 .16213 .40898 .1436 .40521 .1325 Mtetra
.646 .552 .734 r
.40521 .1325 .40898 .1436 .41612 .13099 .41202 .12886 Mtetra
.564 .86 .997 r
.41202 .12886 .41612 .13099 .42293 .12722 .41878 .12687 Mtetra
.769 .262 0 r
.41878 .12687 .42293 .12722 .42955 .12962 .4252 .13559 Mtetra
.147 0 0 r
.4252 .13559 .42955 .12962 .4363 .12891 .43205 .13285 Mtetra
.347 0 0 r
.43205 .13285 .4363 .12891 .44287 .1361 .43883 .1332 Mtetra
.778 .876 .919 r
.43883 .1332 .44287 .1361 .44979 .13148 .44577 .12857 Mtetra
.691 .86 .963 r
.44577 .12857 .44979 .13148 .45673 .1264 .45269 .1254 Mtetra
.258 .752 .909 r
.45269 .1254 .45673 .1264 .46363 .12374 .45956 .12471 Mtetra
.907 .984 .752 r
.45956 .12471 .46363 .12374 .47057 .11959 .46664 .11519 Mtetra
.266 .575 .94 r
.46664 .11519 .47057 .11959 .47737 .12481 .47351 .11651 Mtetra
.793 .678 .738 r
.47351 .11651 .47737 .12481 .48441 .11722 .48056 .10825 Mtetra
0 .013 .588 r
.48056 .10825 .48441 .11722 .49122 .12864 .48738 .11761 Mtetra
.816 .645 .67 r
.48738 .11761 .49122 .12864 .49828 .12191 .49451 .10486 Mtetra
.749 .557 .635 r
.49451 .10486 .49828 .12191 .50542 .10314 .5016 .09216 Mtetra
.432 .43 .757 r
.5016 .09216 .50542 .10314 .51243 .09879 .50859 .09378 Mtetra
.662 .743 .91 r
.50859 .09378 .51243 .09879 .51946 .09608 .51562 .09105 Mtetra
0 .036 .574 r
.51562 .09105 .51946 .09608 .52651 .10464 .52267 .09832 Mtetra
0 .285 .785 r
.52267 .09832 .52651 .10464 .53363 .11133 .52978 .10321 Mtetra
.679 .638 .801 r
.52978 .10321 .53363 .11133 .54087 .12936 .53691 .09944 Mtetra
.551 .373 .593 r
.53691 .09944 .54087 .12936 .54791 .10669 .54406 .09669 Mtetra
.544 .521 .78 r
.54406 .09669 .54791 .10669 .55502 .09848 .55125 .09593 Mtetra
.86 .911 .866 r
.55125 .09593 .55502 .09848 .56222 .09773 .55839 .08912 Mtetra
.079 .266 .753 r
.55839 .08912 .56222 .09773 .5695 .09994 .56571 .09483 Mtetra
.519 .681 .939 r
.56571 .09483 .5695 .09994 .57669 .09518 .57299 .09406 Mtetra
.599 .931 .958 r
.57299 .09406 .57669 .09518 .58386 .08901 .58025 .09089 Mtetra
.319 0 0 r
.58025 .09089 .58386 .08901 .5911 .08549 .58761 .09203 Mtetra
.748 .827 .366 r
.58761 .09203 .5911 .08549 .59848 .08691 .59461 .07596 Mtetra
.76 .622 .708 r
.59461 .07596 .59848 .08691 .60557 .07693 .60176 .06752 Mtetra
.901 .702 .624 r
.60176 .06752 .60557 .07693 .6125 .06169 .60857 .04798 Mtetra
.513 .441 .712 r
.60857 .04798 .6125 .06169 .61976 .05804 .61594 .048 Mtetra
.626 .567 .769 r
.61594 .048 .61976 .05804 .62694 .0519 .62324 .04517 Mtetra
.776 .724 .805 r
.62324 .04517 .62694 .0519 .63426 .04907 .63045 .03905 Mtetra
.521 .508 .783 r
.63045 .03905 .63426 .04907 .64146 .04298 .63788 .03879 Mtetra
.727 .82 .923 r
.63788 .03879 .64146 .04298 .64885 .0412 .6452 .03487 Mtetra
.77 .738 .824 r
.6452 .03487 .64885 .0412 .65602 .03401 .65245 .0292 Mtetra
.811 .813 .851 r
.65245 .0292 .65602 .03401 .66347 .03268 .65969 .02305 Mtetra
.297 .381 .78 r
.65969 .02305 .66347 .03268 .67058 .02418 .66742 .02674 Mtetra
0 0 0 r
.66742 .02674 .67058 .02418 .67798 .02131 .67478 .02251 Mtetra
.22 0 0 r
.67478 .02251 .67798 .02131 .68557 .02129 .68244 .02325 Mtetra
.762 .258 .006 r
.68244 .02325 .68557 .02129 .69356 .02757 .69072 .03411 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15032 .21083 m
.15494 .21549 L
s
[(20)] .14109 .2015 .9907 1 Mshowa
.2751 .16197 m
.2795 .16683 L
s
[(40)] .26628 .15225 .90646 1 Mshowa
.4061 .11067 m
.41026 .11574 L
s
[(60)] .39776 .10054 .82222 1 Mshowa
.5438 .05675 m
.5477 .06203 L
s
[(80)] .53601 .04619 .73798 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(100)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06057 .24597 m
.06342 .24868 L
s
.09013 .23439 m
.09296 .23713 L
s
.12005 .22268 m
.12285 .22545 L
s
.18096 .19883 m
.1837 .20166 L
s
.21196 .18669 m
.21467 .18955 L
s
.24334 .17441 m
.24601 .17729 L
s
.30724 .14938 m
.30985 .15233 L
s
.33979 .13664 m
.34236 .13962 L
s
.37274 .12374 m
.37527 .12675 L
s
.43987 .09745 m
.44233 .10052 L
s
.47408 .08405 m
.4765 .08716 L
s
.50872 .07049 m
.5111 .07363 L
s
.57933 .04284 m
.58163 .04604 L
s
.61533 .02874 m
.61758 .03198 L
s
.65179 .01447 m
.654 .01773 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GR000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3oool?0?ooo`L000000`3oool4000000D0oooo1000002;0?ooo`00o`3ooolB0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0R03oool00?l0oooo4P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
08P0oooo003o0?oooa80oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`280?ooo`00o`3ooolB0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0R03oool00?l0oooo4P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
08P0oooo003o0?oooa80oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`280?ooo`00o`3oool@0?ooo`<0
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`280?ooo`00o`3ooolB0?ooo`030000003oool0oooo00@0oooo100000050?ooo`@0
0000R`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo9P3oool2000008T0oooo003o0?oo
ob@0oooo0P0000000`3oool00000000000280?ooo`00o`3ooolQ0?ooo`<000000`3oool2000008P0
oooo003o0?oooal0oooo0P0000060?ooo`030000003oool0000008L0oooo003o0?oooa`0oooo0`00
00080?ooo`040000003oool0oooo000008H0oooo003O0?ooo`@000001@3oool4000002`0oooo0`00
000;0?ooo`040000003oool0oooo000008H0oooo003N0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02L0oooo0`00000=0?ooo`050000
003oool0oooo0?ooo`000000Q@3oool00=h0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0903oool3000000<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0880oooo003N0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0280
oooo0P00000C0?ooo`040000002E0P00U@80091ZXP800000Q03oool00=l0oooo100000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool3000000h0oooo00@0000009AaY`2D
LJL0U76W0`33@P4010000000U@8009D2002@JZ820?ooo`030000003oool0oooo0840oooo003N0?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo01d0oooo0P00000<0?ooo`80cm3I0P1<HLL20;V@[0<0U76W00D0Pfnc0<=20@33@P40`d810000
0002091ZXP<0oooo00<000000?ooo`3oool0P03oool00=h0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool06P3oool3000000`0oooo103?
d=T0101<HLL0^I2/0;V@[02iT:`309AaY`80Pfnc0P33@P400`000000T6ZR091ZXP030?ooo`030000
003oool0oooo0800oooo003N0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo01L0oooo0`0000020?ooo`030000003oool0oooo00T0oooo
0P35_=830<o@f@@0^I2/0`2DLJL01@23Kk<0aYBQ0<JDX@33@P4000000080T6ZR103oool00`000000
oooo0?ooo`1o0?ooo`00g`3oool4000000D0oooo1000000H0?ooo`800000403oool40<FldP<0T;?^
102iT:`209AaY`@0aYBQ00<00000091ZXP2@JZ801@3oool00`000000oooo0?ooo`1n0?ooo`00o`3o
ool20?ooo`<000003`3oool40;[Ak080aKcB0P3Io]H2092ckP@0^I2/0P2DLJL01@2`Rjl0aYBQ0<JD
X@36U:4000000080T6ZR00<0[7fQ0?ooo`3oool00P3oool00`000000oooo0?ooo`1n0?ooo`00o`3o
ool2000000l0oooo1025P/P30;[Ak0@0fOkF0`2@/nh30;V@[00309AaY`2`Rjl0/8^_00<0aYBQ00@0
0000091ZXP2/OJ40[7fQ1@3oool00`000000oooo0?ooo`1m0?ooo`00o03oool300000100oooo0P36
^Lh308F2b0@0U<Si00H0b=[W0=>f_01Fd<H0E]3603@m[@2@/nh30;V@[0<0/8^_0`36U:4010000000
[7fQ0:amX@2/OJ450?ooo`030000003oool0oooo07d0oooo003j0?ooo`8000000P3oool00`000000
oooo0?ooo`0<0?ooo`@0a[W>0P25P/P20=;JgP<0b=[W0`3C][`00`1Fd<H0=3f]03@m[@0409ik[0<0
/8^_0P36U:4010000000_iVa0:amX@2/OJ460?ooo`030000003oool0oooo07`0oooo003g0?ooo`<0
00004@3oool30:2Aa0<0a[W>103Bf]h00`2[QJ`0b=[W0<SJi`030=>f_00405K@aP0d?Jd0=3f]03@m
[@<0WW^/0`2`Rjl01036U:40_iVa0000002oVK420:amX@D0oooo0`00001m0?ooo`00m03oool30000
0140oooo00@0i[>O08=`]P23L;H0Pg2f0`2PTL@30:W?m080d][N0`2[QJ`30=>f_080cjB]0`0d?Jd3
09ik[0<0/8^_0P2oVK400`000000_iVa0:amX@020:amX@H0oooo00<000000?ooo`3oool0N`3oool0
0?80oooo0P00000D0?ooo`040>JcW`23L;H0Pg2f08=`]P80X9740P2^Rk430:W?m0@0ZhF/00<0lLJT
0=>f_03C][`00P3?Y:d303@m[@<0WW^/0P2`Rjl20;jke`030;nI/@000000_iVa00<0[7fQ1`3oool0
0`000000oooo0?ooo`1j0?ooo`00k`3oool3000001D0oooo0P3V/il308=`]P040:2Aa02^Rk40[X^a
0:j;/@@0V7V_0P2[QJ`20?76Y0050=>f_03?Y:d0cjB]0<nT[@3hk9X00P0d?Jd309ik[0@0_[_G00<0
_iVa0000002oVK400`2/OJ420?ooo`0300000036j^h0oooo00<0oooo00<000000?ooo`3oool0N@3o
ool00>d0oooo0P0000000`3oool000000?ooo`0E0?ooo`80i[>O0`23L;H40:j;/@040=BRX`2HNJl0
V7V_09Qi[`80ZhF/0P3aaZ@40<nT[@030?S/VP2]Y<h0=3f]0080WW^/0P3@o>830;jke`030;nI/@00
0000_iVa00<0[7fQ00@0]2l000000036j^h0a^[^103oool00`000000oooo0?ooo`1i0?ooo`00jP3o
ool3000000@0oooo00<000000?ooo`3oool04P3oool30>JcW`@0V76U0`2^Rk401@3DXZ<0V7V_09Qi
[`2HNJl0ZhF/00<0lLJT00<0nnRQ0<nT[@3?Y:d00P3hk9X20;j`c0@0d?cR0`2n^mL00`2oVK400000
0;nI/@030:amX@80@P0=0P36j^h50?ooo`030000003oool0oooo07P0oooo003X0?ooo`800000703o
ool30>JcW`040=^]Y`2HLJD0V76U09QaY@80[X^a0P3DXZ<309Qi[`050:^5[03aaZ@0lLJT0?76Y03k
j:400P3?Y:d20?S/VP030=[[g`2n/<`0_[3<0080_[3<00L0[hjc0=Rg]`3H]kL0XgVU0;nI/@000000
_iVa00@0YZOH00@0@P0=07B^mP36j^h0a^[^1@3oool00`000000oooo0?ooo`1g0?ooo`00i@3oool3
000001d0oooo103V/il00`3K[JL0V76U09QaY@0209QaY@040:j;/@3DXZ<0e::S0=BRX`80V7V_0`3a
aZ@30?_XX@030<nT[@3hk9X0f^_O0080f^_O0`2n/<`00`2_S[<0f;Ng0=Rg]`020:=iY@030000003i
hX@0m>Jj00<0YZOH0P1d[_H00`0c>:P0a^[^0?ooo`040?ooo`030000003oool0oooo07L0oooo002/
0?ooo`@00000103oool4000002X0oooo0`00000P0?ooo`030<:O]@3V/il0i[>O0080fjfW102HLJD0
1@2^Rk40e::S0=BRX`3DXZ<0V7V_0080Z;OT0P3aaZ@30?_XX@030?S/VP3Jjml0f^_O0080f^_O0`2n
/<`40=Rg]`030:=iY@000000m>Jj0080m>Jj0P1UKlP207B^mP80<cRX1P3oool00`000000oooo0?oo
o`1f0?ooo`00Z`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool09@3oool2000000030?ooo`000000oooo01l0oooo0P32WkD20>JcW`<0fjfW0`2H
LJD40=BRX`@0Z;OT00<0lLJT0?_XX@3kj:400`1ZbOh4097DoP<0Lj?_0`3H]kL00`2SNJD000000?CV
^P020?CV^P80IFo800<09RfR07B^mP0c>:P00P0c>:P60?ooo`030000003oool0oooo07D0oooo002[
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0R0?ooo`<000008`3oool40<:O]@040>JcW`3K[JL0fjfW0=^]Y`80V76U0P2lTZ/30=BRX`070>W6
/@2X]n@0Z;OT0:Rgi03kj:40PXWB08bon0030=[]h00404aWc@2Ae?h0TMCn097DoP<0Lj?_0`3H]kL0
102SNJD0m>Jj0000003di[X207cS_@0306E_b00V;J809RfR00<0<cRX103oool3000000X0oooo1P00
00040?ooo`@00000G`3oool00:/0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0803oool2000002H0oooo00@0_m=M0<:O]@32WkD0`Yne103K[JL0102HLJD0_9:[
0;bBZ`2lTZ/20=BRX`80jLJa0P2LWmH308:9dP@0f^gP0P1<Ild20::1/080PVJY00@0FUVg0=Rg]`3H
]kL0f;Ng0P2lho801`000000O>>m07cS_@1lhkd03S6`06E_b00V;J800`0c>:P70?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0G03oool00:/0oooo00<000000?ooo`0000000P0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool07@3oool3000002L0oooo0P2oded20<:O]@80k>?60`3K
[JL40;bBZ`80e::S0P3Ya[4209bOeP@0`=S[0`3JkN040::1/080PVJY0P1JFKL30;cSlP050;Wik000
0000_jFo000Z/`1lhkd00P0><K0202H]XP0302i>`@0c>:P0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
G03oool00:/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01/0oooo0P00000Z0?ooo`80_m=M00@0`Yne0>cSaP3/hlH0k>?60P3K[JL20<k<f0<0_9:[
00@0e::S0>W6/@3Ya[40_hZM0`2>O[d20<3Hj`80XWRU0`27I:<30::1/0<0PVJY0P1JFKL20;Wik005
0;nU_`000000_jFo0;nU_`00:[<00P0><K0302H]XP0302i>`@3oool0oooo00H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0G03oool00:`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo1000000Z0?ooo`<0_m=M103/hlH0103K[JL0c/cH0<k<f03>c=P30;bB
Z`<0jLJa00<0_hZM0?c9SP2>O[d00P2>O[d30:9hY@<0QfBS0`2RPK03089VZ@0405YI]`2bU[X0/YJj
0;:F^P8000000P2oYKl0103;Yk@002Zc0725f01`QMP2001Ba@80;Tk1203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1L0?ooo`00[@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05@3oool3000000<0oooo00<000000?ooo`3oool09P3oool2054000040;CMm03=lN/0
cO7[0023bP<0k>?6103>c=P30;bBZ`050>kh_03Ya[40_hZM0;n:W@3lbHh00P2>O[d20;B8YP80XWRU
0`27I:<30::1/0<0PVJY0`2bU[X3000000070;nU_`3;Yk@0bjNd038iZ@00:[<0L8GH0<KZkP02001B
a@0305mH/`0^C/40Na<`0080Na<`00<0PIoV0?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1L0?oo
o`00[P3oool3000000<0oooo1000000F0?ooo`800000903oool20=cYg@0301A4`03oool0oooo00@0
oooo0`1A00040<gaj`03001_f`1[gMd0JmgM00<0JmgM0P3>c=P20;bBZ`80k_Rl0`2oRYd00`3lbHh0
SWjm0;B8YP020;B8YP<0XWRU0P27I:<30::1/080PVJY0P2lnNd20;:F^P<000000`3;Yk@2038iZ@80
a^[^0P00D/D205mH/`<0Na<`0P2CN[D30?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0G03oool00</0
oooo0`00000B0?ooo`030;n>XP1^K/40ZKkX00<0ZKkX3@3oool30=cYg@8054C00`3oool209W^m@80
bOoJ0P1`h=<40;WFk`<0R8_?0`1RL</01@3>c=P0_9:[0>kh_03^n;`0jN1b0080_hZM0P3lbHh40;B8
YP<0XWRU0P27I:<30::1/0@0_?W]00D0/YJj09KLQ`1L/_/0G;;k000000030<^W]0<0<SVY0P38^/d0
1000D/D0GeRc05mH/`1OF;<207/C<080TgZe103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo05`0oooo
00390?ooo`800000503oool20;n>XP80KVk1102Y_^P;0?ooo`D0g>WM0P0DA<0308B^l0040<WofP2L
Qk/0W8Nk09b7^`80RiCG0`2ie^l308R;c`80HW3;00@0h<c40>WXPP3^n;`0k_Rl0P3Yh7820;n:W@80
o<V>00@0nmNO0;B8YP2dR:H0]8RV0`2RN:D00`27I:<0XWFP0:9eX00308]`[P050?_XW`08Cl`0_?W]
0;:F^P2Fg8L00P1L/_/010000000bjNd0<^W]03;Yk@40;3ClP030<Rjc@00D/D0GeRc0080GeRc00@0
4`0009=j]@2CN[D0TgZe103oool2000000D0oooo100000050?ooo`@00000G`3oool00<H0oooo1000
000E0?ooo`80_hjR0`1^K/4409Qj/@D0oooo102=GiL308^5a`<0g>WM0P0DA<0307aOYP040=FWZ02L
Qk/0W8Nk09b7^`<0RiCG0P2ie^l308R;c`0407fBg@3Pc<@0h<c40>WXPP80VGfc0P3Yh7820;n:W@80
o<V>00@0nmNO0;B8YP2dR:H0]8RV0`2RN:D30:9eX0<0Rg2^0P3kj9l01P3B/kX0l/:M09J2_02FP[`0
2Sfm00000080bjNd0P38kNd30;3ClP80b;[=0P1OF;<30;jI/@80TgZe0P3oool2000000030?ooo`00
0000oooo0700oooo00340?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`<0_hjR0P1^K/42
0:J7]0<0V7Za00@0001j0?ooo`3oool0oooo0P2]Xld308eOU`80RhG70P2eS:/208Yi^P80jKZT0P1l
GjH20=FWZ0<0W8Nk102[S[P202^Hl080OI;M0P3Pc<@20>WXPP80VGfc0P3Yh7801@2oRYd0o<V>0?c9
SP3lbHh0nmNO00<0]8RV0P2RN:D20;O3h`80XWFP0P2;L:h30?_XW`030=:c^P3b`Yd0UX:l0080UX:l
00<000000<S]k@38kNd00P38kNd30;3ClP@0TGZf0`2nVK4309=j]@D0oooo00<000000?ooo`3oool0
KP3oool00<40oooo0`00000I0?ooo`@0_hjR102VQk@309Qj/@030?Cc/000B<P0[J?=00<0[J?=0`2=
GiL01@2;QLL0]Hb[0;F<Z`2eS:/0RWVj00<0jKZT0P1lGjH20=FWZ080W8Nk0P3>`Lh30:^>^0040>O2
/@19CK<0:iS`07fBg@80h<c40P3Yj8801@2IOK<0jN1b0>WPLP3Yh780_hZM0080o<V>0P3keil30;B8
YP@0]l?S0`2RMJ00102;L:h0nnRO0?_XW`3B/kX20?;2W@<0UX:l00<0000000Xm_@0:?Kd00`2HLJD3
08QVY0<0TGZf0`2nVK4309=j]@H0oooo00<000000?ooo`3oool0K@3oool00;h0oooo0`00000L0?oo
o`050=2UZ`2oSZ80_hjR0;n>XP3N[:400`2VQk@209Qj/@80m?>`00<0Cd^^0018b02]Xld00P2]Xld3
08eOU`@0]Hb[00D0RWVj0>VjY03Y^Z@0jKZT07aOYP030=FWZ00409b7^`3>`Lh0c/7>0<k1cP<0Zhjh
00<0il:a04U=/`19CK<00P3Pc<@30>WXPP0509Um/`000000b[S90>WPLP2oRYd00P3lbHh20?_GW`80
]8RV0P3Jhmd30;O3h`<0XWFP00@0Rg2^0?_XW`3B/kX0d[>j0P3b`Yd209J2_0030:1gY0000000PFBX
0080PFBX0P2HLJD308QVY0<0TGZf0P2nVK420<Cnb@80TgZe1P3oool00`000000oooo0?ooo`1]0?oo
o`00_03oool2000001X0oooo00<0bjfl0?ooo`3oool00P3oool01@3@YJ/0_hjR0;n>XP2oSZ80gZbQ
00<0YXNd00@0V7Za0?Cc/03dlk00m?>`0P1?Bjh00`00B<P0[J?=0:fSc@0308eOU`040;[2@02eS:/0
]Hb[0;F<Z`@0jKZT00@0O5nV0=FWZ03EYjP0eJNX1@3>`Lh0102[S[P0il:a0>O2/@3W`[4204U=/`04
0>3<a03Do[l0KgoC06mod`@0b[S90`3lbHh20?_GW`@0f^?M0`2g`n<30:9eX0040?_XW`3B/kX0d[>j
0=:c^P80l/:M0`2PMj@010000000PFBX085TZ021I:P209QaY@<0R6JT0`2AN[H01P2nVK40a?k90<Cn
b@34o/T002N`09=j]@L0oooo00<000000?ooo`3oool0K03oool00;T0oooo0`0000000`3oool00000
0?ooo`0H0?ooo`80bjfl00<000>F0?ooo`3oool00P3@YJ/30;n>XP80gZbQ0P2VQk@40?Cc/0<0Cd^^
0P2]Xld308eOU`050;[2@02eS:/0]Hb[0;F<Z`3`iL800`3Y^Z@40=FWZ0030?S/[P3>`Lh0c/7>0080
c/7>00@0Zhjh0>O2/@3W`[40il:a0P19CK<30=Cn_`0306mod`2>M[@0b[S90080b[S90P0S<JP20?_G
W`<0^]ob0`2XRK@20;O3h`<0XWFP0P2<O;`01@3B/kX0l/:M0?;2W@3b`Yd0dZ6U0080X7NT00@00000
085TZ021I:P0PFBX0`2HLJD208QVY0<0TGZf00<0ZKkX0<2M]@2DQl<00P2DQl<010009k00b4P00<Q8
001]R=`20:CMn`<0oooo00<000000?ooo`3oool0J`3oool00;L0oooo0P0000050?ooo`030000003o
ool0oooo01D0oooo0`3;[K`20003UP050?ooo`3@YJ/0d:F[0=2UZ`2oSZ800`3N[:430:Vnj@80j??@
00D0^i>^04m;[P1?Bjh0Cd^^000c]`020:fSc@80SEnG0P2j`T001@2eS:/0l>G20?3U`P3`iL80jKZT
0080R]^@0`3EYjP20?S/[P<0c/7>103W`[400`2Jio`0e?jo0=Cn_`020=Cn_`80SWJd0`3:^<T302<a
Z0<0^]ob0P2[VL@20:R9]0040009U@2g`n<0XWFP0:9eX0<0S7bl00D0d[>j0?;2W@3b`Yd0l/:M0=:Q
Y@020:1gY00400000021I:P0PFBX085TZ0<0V76U0P28IZ@30:Vnj080`9fe0P2DQl<20>W=^@03000W
/038B000el;500<0SZWW0P3oool00`000000oooo0?ooo`1[0?ooo`00]03oool3000001`0oooo00<0
j?_004BCl03;[K`00`3;[K`20003UP@0d:F[00H0_hjR0=j/X@3N[:40gZbQ0?[NY`2Y_^T20>Scd0<0
^i>^00<0nLZG01Xc[P00@/@00P2]Xld01@2=GiL0^/900;[2@02j`T00]Hb[00<0l>G200<0a_WZ0<^Y
]`2:fi000P3EYjP20?S/[P80dK_50`2;T=<20>O2/@050=_Wg@36Z[d0aZZm0?36YP3e_i<00`2>M[@3
0<Zhb@@0Y]Wi102[VL@30:R9]0040;O3h`2RMJ00XWFP0>;1]`80S7bl0`3b`Yd20=:QY@80X7NT00@0
0000085TZ021I:P0PFBX0`2HLJD01028IZ@0i??E0>Cce@3TlmD40<2M]@0709B7``3YcKT0jLfi0=O2
a@38B000el;50>cB^@0208jYi`<0oooo00<000000?ooo`3oool0JP3oool007X0oooo100000040?oo
o`@00000;03oool2000001h0oooo0P3Xnl0204BCl0<0bjfl00<0gmoD0003UP000iH00`3@YJ/01@2o
SZ80gZbQ0=j/X@3N[:40n]jW00<0j??@0P2kTjh20?W:U`806S>^00<004;40:fSc@2=GiL00`2kY<83
0?3U`P070<KijP3;ZKL0bjVg00dc/P2:fi00eJNX0?S/[P030=6ka@<0Ri3C0P3Kimd30<JZ_@030?36
YP3e_i<0mKnC0080SWJd00@0d;S208=d^`23M;/0PgBk102KP;D30:^Ia0<0Z8Vd00D0h/6g0:9eX03R
`KL0h/6g08al_0020:Z>^080l/:M0`3BXJD00`2PMj@00000085TZ002085TZ0<0V76U0`3TlmD20;Wi
k@<0`9fe0P3YcKT30=O2a@80k=:i0`2CTLh30?ooo`030000003oool0oooo06T0oooo001l0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`<0
00005@3oool00`1R0280oooo0?ooo`070?ooo`070>Sk`02Hj?/0`jc30<>/``00<[H0A9?`0<^]_002
0=oOe0030009T`000iH0d:F[0080d:F[0`3N[:420?[NY`80m^Ng0`2kTjh20?W:U`<06S>^00<0[J?=
08eOU`2kY<800P2kY<800`000I@0a_WZ0<KijP030<^Y]`803C>b00<0n>b^0=6ka@3A^lD00P3A^lD4
0::Ic0<0aZZm00D0l<JV0?FoT`3e_i<0mKnC08if]0020=2h`P<0PgBk00@0joG:09^0]@2KP;D0Vh2e
0`2[VL@20:R9]080_;SE0`3R`KL40:Z>^0@0dZ6U00<0X7NT00000021I:P00P21I:P406KJe@@0^OW]
0P30WKD20>Sib`030>W=^@000000el;500<0k=:i00@0i?RX09>AcP2CTLh0Ti7>0`00001[0?ooo`00
O03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
903oool200000080oooo00<000000?ooo`3oool04P3oool306808PH0oooo00<0@/3X09SXn`2Hj?/0
0`33[<<00`3_mZ`003:f0=oOe0030=oOe0030009T`3@YJ/0d:F[0080X76M0P3N[:420?[NY`80m^Ng
00<0^hVP0;^C[P2kTjh00P3ibYL01@3]ajd0LeZV07=JYP0007X0SEnG0080^jC20P2gW[h00`1TJl@0
bjVg0<^Y]`020<^Y]`@0YZ_J0P3A^lD20;VK^P<0XYW<00@0a:6e0<JZ_@36Z[d0l<JV0`3e_i<40=2h
`P0308=d^`3[mLX0joG:00<0Vh2e0`2[VL@40;bhe@80h/6g0P2VOJL30:Z>^0070<fV/@3BXJD0dZ6U
0=:QY@2PMj@0f>?N0000000205Ekg080^K7A0P29[nl20:fC^`0307d0002inNd0`9fe00<0j?W;0P1Y
EjX30>cB^@80i?RX0P2CTLh20=Klg@80oooo00<000000?ooo`3oool0J03oool007P0oooo1P000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool300000140oooo102@g?l3
0?ooo`@0HP0R0P3oool30;3LmP<0bM?Q0`33[<<0103_mZ`0jM[40>WJa000El830=oOe0030009T`2P
LId0X76M0080X76M00<0gZbQ0?[NY`3jgZL00P3fikL20;^9X0030;^C[P3ibYL0nLZG0080kLN]0`1c
FZH00`003I/0]ijn0;NN_P020;NN_P80I6_40`3;ZKL00`3CoKX0YZ_J0:J[fP020:J[fP@0^I^j00H0
XYW<0<BQ]@34XKD0a:6e0<JZ_@3`aZH30?FoT`040000003@^<80d;S20=2h`P@0joG:0P2KP;D0103C
cM@0QXW?08J9c`26RLl30;bhe@@0YWfW0P2ZS[P20<fV/@<0dZ6U0P3Hhmh00`000000f>?N0;Vad@03
0;Vad@<0[I>k00<0jlB]05UE/`3XnL/00P3XnL/01@2YQZl0JENZ06UGZP1YEjX0k=:i00<0i?RX00<0
e_cM0;F`e02e/=@00P2e/=@00`3oool000000?ooo`1Y0?ooo`00N@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool3000001<0oooo0`2U
SK/20:VD`0<0a4<00P0U00000`1H0000^3@00;Pd00020<OPj`@0bM?Q0P3B_lP20<>/``050>of[03Y
f/@0jM[40>WJa0003i`00P0aI]H20009T`<0X76M00@0gZbQ0?[NY`3jgZL0m^Ng0`2kRJ000`2kTjh0
nLZG0?W:U`020>g7[@<0LeZV00<0001j000=V`2gW[h00P2gW[h306A[a0040<^Y]`3CoKX0dofj0=?m
^P@0TffT0`2iVkX40<BQ]@80l<JV0`3e_i<00`000000YZOG0:JWe`020:JWe`<0joG:00@0Vh2e0=?=
e03CcM@0dlgD0`26RLl00`2l^=D0ZXfh0:Z=^0030:ImY`040:Z>^03=Y[40cJJa0<fV/@80dZ6U0P3E
b<d0102VZ=P000000:JXf02VZ=P20;Vad@80ZH2X0P2]Tk/0103[a:d0FEFc05UE/`1IEK<30:V6[`80
JENZ0P1dLl<309>;a`030>Kk^02e/=@0]K3D0080d<_D00<0oooo0000003oool0J03oool007T0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0
oooo0P0000060?ooo`@0Ui?=2`3oool40:F=^`040?3I^02YU<00ZIC00<A300809@000P1H00030<OP
j`80/o_U0P39dn430=:ob0030<>/``3_mZ`0jM[40080jM[40P2Lm=8010003i`0<FKF035VeP002I<3
0:1aW@80n]jW00<0m^Ng0;^9X02kRJ000P2kRJ020?W:U`<0kLN]0`1cFZH00`0007X032FU0;NN_P02
0;NN_P<0I6_400<0dofj08Qn`P28O/800P28O/8309=]Y080^I^j0P3ThM430<BQ]@050>ci]`3`aZH0
mKnC0?FoT`3YnK800P11_nP30:JWe`030>KRcP1VH;P0IV2h00@0dlgD0`26RLl30:Z=^0<0YWfW103=
Y[401P3BXJD0eLS=0=G8c@3Eb<d0h/g200000080YZSH00D0^K7A0:V0Z02YP:P0ZH2X0:fC^`030>_4
[@0305UE/`1ML<h0ZHJ_0080ZHJ_0P1YEjX207Ac``80Th_70P3VnkP0102e/=@0d<_D0=3;e03@bm@2
0?ooo`030000003oool0oooo06H0oooo001j0?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`<000001P3oool00`3djH`0UZkW09J^i`0309NC
c@040:63/`2W:aH0Yb/F0:L[5PL0oooo00<0m<>I0:F=^`2USK/00P3`fKP20:VD`080bJNg0`3XlM02
0<Ric0@0/o_U103B_lP20;VR`P030?7/T02Lm=80XYO900<0XYO900<000nL035VeP002I<00`2PLId2
08VJg@80TN6H0`2kRJ000`3ij900nLZG0>g7[@020>g7[@<0LeZV00@000N800`UY@0<9JD0]ijn0P2m
//l20668h@80fN;M0`28O/8309=]Y0040;VK^P3ThM40i>7A0>CQd@80a:6e0P3/nKL30?FoT`80_9B^
00<0CU6e046oj02VYmL00P3Vh/h306IP^0@0WHJj0`2SWLh20:Z=^0<0YWfW00@0dZV_0<fV/@3=Y[40
cJJa0`3Eb<d20>;=`P030000002VZ=P0YZSH00@0ZH2X00H0[I>k0>_4[@3[a:d0jlB]05UE/`1ML<h3
0:V6[`0306UGZP3EYjT0M7?30080M7?300<0Th_70>Kk^03VnkP0103@bm@20?ooo`030000003oool0
oooo06H0oooo001j0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0G0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030?CYS02F[^L0UZkW
0080Ui?=0P2kZLL00`2QPk<0Yb/F0:L[5P070?ooo`030?C3V@2USK/0YHfk0080l=Vh00@0ZIC00<VW
]`39YkL0bJNg0P3BjhH40<Ric080<d>c00@004C501f[`@3B_lP0d[o80P2iX/820?7/T0030>Kl_`34
W[80XYO90080XYO900<0CY7^02MGc0002I<00`2PLId01029V]d0TN6H097QV02AhIP30;^9X0030?WX
T03]ajd0kLN]0080kLN]0`1cFZH00`001hP032FU00`UY@040;fbc`<0fN;M0`28O/8309=]Y0@0i>7A
00<0a:6e0>ci]`3/nKL00P000000103e_i<0_9B^0;bD[P2lU:h204iA]@@0i^;>00<0IV2h0<C;g`34
bml00`2MQ[X30:>McP<0ZXfh00<0YWfW0=:Y[`3BZJl00`3=Y[400`2ak9P0eLS=0>;=`P020>;=`P04
0000002Y^nL0ZK_W0:Vki`<0ZH2X103[a:d00`3@[KH0<Cb^0:V6[`020:V6[`80eJNY00@0aiJR07>>
gP1cS]h0i_^h102:j_030:J8]080oooo00<000000?ooo`3oool0I@3oool007/0oooo0P0000050?oo
o`@000005`3oool3000000X0oooo0P3djH`00`3E`lT0MefX0;^Ya`030;^Ya`80XH>c00<0Yb/F0?oo
o`3oool0103oool20?C3V@040:F=^`3`fKP0l=Vh0?3I^0@0bJNg00<0d^^60:nB^@0000000`38^L`2
03=3/`0304m;[@00?l80^J;200<0^J;200<0lNb@0>Kl_`34W[800P34W[801@2RUlT0WVnL09i_W00W
El`000VC0080X76M00D0a^7[08]o`@2;Ol40G4fW097QV0020;^9X080nNR@0P30hWT20>g7[@<0LeZV
00@000N800`UY@0<9JD032FU0P2m//l208U[ZP<0fN;M0P28O/8309=]Y0050??dZP3ThM40i>7A0>CQ
d@3/nKL00`1JSnX00`000000mKnC0;bD[P020;bD[P<0CU6e0`3Vh/h30<C;g`<0WHJj0`2SWLh30:Z=
^0050:ImY`3BZJl0dZV_0=:Y[`3=Y[400P2ak9P30>;=`P030=[ob@000000f_o90080ZK_W0`2YP:P0
0`000000jlB]0>_4[@020=2]]P03034l[P1Wfn80eJNY00<0eJNY00<0aiJR07>>gP1cS]h00`2d`^@3
06^?i080YXRd0`3oool00`000000oooo0?ooo`1T0?ooo`00V`3oool2000000H0oooo00<0hoGF06mU
]`1_IKL0103oool00`3djH`0eL?90=G3b@0207MMZ0<0^jW70`2QPk<00`2W:aH0oooo0?ooo`030?oo
o`80m<>I0`3`fKP20<S>gP80bJNg0`2_T[T0101E@9`0b;W<0<Ric038^L`203=3/`80Cd^]00D003o2
0;VR`P2iX/80lNb@0>Kl_`040<BN/P<0WVnL0P1fCiL20:1aW@80Rgo10P1LCJL0102AhIP0^hVP0;^9
X03ij9040:BljP<0D/gV00<0LeZV0007R0001hP00P0gJ]L01@2JO[@0RF^Z08U[ZP29JjX0DTJV0080
=9Wb0P28O/8209=]Y080loBZ00<0^o6O04EC_@3:XZl00`2<Pl@30:SCmP<0_9B^0P1>DKD20:^@^@<0
LGg@0`34bml209f6^P030=7;e01lKkX0O6nj00<0ZXfh103BZJl00`3Ua[P0000008ei^00208ei^003
0=[ob@2Uf_X000000080jlbf00<0ZK_W0:V0Z02YP:P00P0000001034]</0d:ff0=2]]P3@[KH30:N9
]@80eJNY0P37UZ800`3jfgP0o<jB0;C2i0020;C2i0<0JhoT0`2VR;@20?ooo`030000003oool0oooo
06@0oooo002H0?ooo`<000001`3oool20>?eeP<0KfFg0P3oool0103djH`0eL?90=G3b@3E`lT307MM
Z080^jW70`2QPk<00`2R@P00oooo0?ooo`030?ooo`80m<>I0P2mcUD40<S>gP040<VW]`2_T[T0[i:i
0:nB^@80ED2L0`27HZ001P0c@k<0Cd^]04m;[@2jUK4003o20;VR`P80LW3100D0/H2O0<BN/P34W[80
a9jb0;:1W`0209i_W080MTnG00@0X76M0;6=[`2;Ol40Rgo10P1LCJL01@00=[X0^hVP0?WXT03ij900
RY[M0080Y;cZ0P36/lL306m^`@<000N80P2JO[@308U[ZP80DTJV0P0dVO800`28O/80TffT09=]Y002
0??dZP0304EC_@3:XZl0bZ:_0080S8?40P0000020:SCmP<0_9B^102[T;T3075md0<0a<_O00<0WHJj
0=7;e03Abm@00`1lKkX307mTZP<0dZV_00<0iLJh0000002=NKP00P2=NKP205RDkP040000003[c;H0
jlbf0:Vki`80ZH2X00<08cF/0<Bdb`34]</00P3@[KH20<6cc080YhVe0P3EYjT20<NFXP030?[KN03l
cY80WHVo00<0WHVo0P1[Sn@30:J8]0040?ooo`000000oooo000006D0oooo002E0?ooo`<000002@3o
ool40>?eeP80KfFg00@0]H^Z0<M9001^SN00KXgP0P3E`lT307MMZ080^jW70`2QPk<00`000740oooo
0?ooo`020?ooo`<0m<>I00<0_LiE0;gmd02moM000`38c]h20?G]^@80[i:i0P1E@9`308MRX00302X^
X@1?Bjd0^YFa0080^YFa0P1bL<420;60W`80a9jb0P2bPIl209i_W080MTnG00D0X76M0;6=[`2;Ol40
/Hf_05a=Y`020;V`d0030;^9X03ij900RY[M0080RY[M0`36/lL306m^`@D0VWjd0`29JjX30596YP03
03BIlP0E::D0TffT0080loBZ00D0AE>m0<ZR[`3:XZl0bZ:_08b3a00209V8_`80YgbT0P2XdoH20;bD
[P040;W_V`2[T;T0Zi2i0:^@^@@0Xmgk0P0fP>L40=7;e080O6nj0`1oI:X20=:Y[`030>G6^0000000
00000080SGVh0`2>PL401P000000jlbf0>_<]P3[c;H0ZH2X0<b`_P<0a;C;1031/l`30:N9]@060=FW
Z@37UZ80aiJR0?[KN03lcY80o=j20`2MRKl00`0Q?KH0JhoT0:J8]0020:J8]0@0oooo00<000000?oo
o`3oool0HP3oool009<0oooo0P0000030?ooo`030000003oool0oooo00<0oooo0`2Yc_<20<>bbP03
03m8/`3SmMH0KfFg00<0]H^Z0P1^SN020=G3b@80MefX0P2nVK4207m]]0<0NF>]0P2R@P020?ooo`80
m<>I00<0c_SW0>7ff@0000000P26Y>P0102dnL@0mNfi0?G]^@3ekKT20:nB^@80ED2L0`27HZ000`0Z
;Z40^YFa0;ZE/@020;ZE/@05079``@2aP9l0/H2O0;60W`34W[800`2bPIl209i_W0<0MTnG0`2aSJl3
0;V`d080djFY0P13D;X2000000<0a[?70P1_K/4509Yn]0<0RF^Z0P1BAZH00`2lVkL0=9Wb01DXY@02
0??dZP030>WIa03:XZl0bZ:_0080bZ:_00<0nNF^09V8_`2WO:@00P2WO:@00`2GMjd0Z=?f0;bD[P02
0;W_V`<0Zi2i00@0SmV60:?Mn`2SgO/0Xmgk0`0fP>L30=7;e080O6nj0`1oI:X01P3BZJl0iLJh0>G6
^031a]h0000008ei^080]ZO90P2>PL4010000000a^?]0<KSk@36hnd20<b`_P80a;C;0P2^W<D30<6c
c0<0YhVe0`37UZ800`3jfgP0o<jB0?cNPP0309f9_`808Cff102MQ;P30?ooo`030000003oool0oooo
0680oooo002@0?ooo`<000002P3oool30;kkj0<0`k;:0P0oB;<40;F;ZP050>S0[02;Lk<0Rg>c0=G3
b@1gGJP00`2nVK4207m]]0<0NF>]00@0DEk1021fh`2N5`00oooo0P3d`iT00`3Qm]T0`>Sb0<3XlP02
0;Cia0030?G]^@2:LK40RW6a0080RW6a00<0[i:i05E0W01E@9`00`27HZ0202X^X@<0^YFa102aP9l4
0;:1W`<0WVnL0P1fCiL409j;_`040;V`d03CYJT0djFY0=>UZ@<0@e2j00@000000<Jca`36/lL0a[?7
0P1_K/4509Yn]0<0RF^Z00@0DTJV0;bK]`2lVkL0_9^g0P0E::D00`3P^K00/9c3000000030<ZR[`03
0?WU[P2WO:@0YgbT0080YgbT0`2GMjd0102nT:H0W7FU0;W_V`2[T;T209EcZ`80PEnQ0P2FLJL205Eh
f@<0dL_D0P1lKkX307mTZP80iLJh102>Q/H20;JWb@80SX710`0000030<b`_P@0[Yc50`31/l`20:N9
]@80/i>e00@0aiJR0?[KN03lcY80o<jB0P3lgX8209f9_`<08Cff0`2MQ;P40?ooo`030000003oool0
oooo0640oooo002>0?ooo`8000002@3oool01036/lP0JhcQ06^<h@2nnnP4091m^`<0`k;:0P0oB;<2
0;F;ZP80j<2/0P2;Lk<00`1<BZh0_YVa0;jI/@020;jI/@80Offd0`1iHjd2055N`@040=;Kg`3d`iT0
m<>I0>7ff@80`>Sb0`3Ba/h2071T]P<0RW6a00@0CTZ]05E0W01E@9`0ED2L0P27HZ0202X^X@<0^YFa
00D0bjZh0;60W`2aP9l0/H2O0?32X@030;:1W`<0WVnL0P1fCiL0103`ekP0WX^o09j;_`2NRkl40=>U
Z@040=:UZ@1nIjh0OVN^000N[0@0Whg100<0AUO008gYmP2=jOH00P2=jOH0101CU>h0RF^Z08U[ZP29
JjX40;bK]`050>k^T@3P^K00h;V`0;2L``0000000P3:XZl00`1@c>80UVVL09IYW0030:MlY080UgN]
0P2nT:H309aeY@80UG>[0`21Gj4209IaY`030;>6Y01kE9P0NeBH0080WfbG00L0O6nj07mTZP1oI:X0
RF6L0000003Ua[P0GeZd00<0SXK60`2fYlT00`2>PL40000008^Si@0208^Si@80c;2n00@000000:jL
a@2^W<D0[Yc50`31/l`40;>C]@030<NFXP3jfgP0o<jB00<0o=j20`2Y]n<2024m]P<0WHBh1@3oool0
0`000000oooo0?ooo`1P0?ooo`00R`3oool3000000X0oooo0`36/lP00`1[S>40`Jk70<6^a`03091m
^`<0`k;:0P0oB;<20;F;ZP80j<2/0P2;Lk<204a:[P<0_YVa0`1oKK@207US[@<0d]_O00@0g?k=0?C3
V@2GT/`0Ui;<103Ba/h2071T]P<0RW6a0P1>BZd205E0W080Qf:P0`0Z;Z400`2jUK40bjZh0<^Z^003
0;60W`040?32X@2bPIl0/X6O0;:1W`<0WVnL00<0MTnG0?3G^03`ekP00`2NRkl01@2hV;L0djFY0=>U
Z@3CYJT0dZFY00<0OVN^00@001j/09n=`@2OSL40Whg10`16El0208gYmP80DiC^0`2;M;@20;bK]`07
0>k^T@3P^K00h;V`0>2i/03:X:d0dYZJ0<ZR[`0208aVX@80UVVL0`2WO:@0102GMjd0_Y2V0;j@YP2n
T:H309aeY@80UG>[0`21Gj400`2FLJL0/hJT0;>6Y00307]DV0<0WfbG0`29HI`205mJ]0<0SXK60`2f
YlT00`2IT//0000008^Si@0208^Si@050<b`_P2SVL/0A5Bn0000002^W<D00P2nYl8308I_/P<0/i>e
00<0aiJR0?[KN03lcY800P3lgX820=W3a0040:Vgh`2k/<l0^k3?024m]P<0WHBh1@3oool00`000000
oooo0?ooo`1P0?ooo`00R@3oool3000000/0oooo1036/lP30<6^a`<0T7fk0`33//X203m8/`040;F;
ZP3X`:`0j<2/0>S0[080Rg>c0P1<BZh30;jI/@<0Offd00@0NF>]0<7al@31lO40`O7a0P3Lo/d309NB
c080hMW>0P3Ba/h3071T]P80RW6a0P1>BZd00`1F?9L0ED2L08MRX0020<^ea@8004G70`3;Z[P30;60
W`040?32X@2bPIl0/X6O0;:1W`<0WVnL00D0MTnG0?3G^03`ekP0l=Nh09j;_`020;RH]`80djFY0P3B
YJT307iW[P040007U`2OSL40Whg109n=`@80AUO00P37cMl209gTo00405>DkP2;M;@0RgBd08]d]080
_9^g0`3P^K020<ZP[@040=:JVP2<IZ40S6JQ08aVX@80UVVL0`2WO:@40;j@YP<0W7FU0P2ELj/3085O
X@0309IaY`2cQZ@0/hJT00<0NeBH0`2OK9L308UQW080GeZd102ORkl209VBb`030<NFY0000000Rj?U
0080Rj?U0P2SVL/204AD_P<0_ZO20`26Kk830;>C]@040<NFXP3jfgP0o<jB0?cNPP<0fL?4102k/<l2
09f4^080K=:J0P2W[M`30?ooo`030000003oool0oooo05l0oooo00260?ooo`<000000`3oool20000
00<0/l3T1@3oool20>_[c080a[?80P3KkMl30<6^a`03091m^`2_RZh0[hZ^00<0QFZ]00<0?dRc0;F;
ZP3X`:`00P3X`:`208]c/`<0C4Z^00<0_YVa0;RI^02hVKP00P1KH/400`31lO40M^?R07KShP040=cn
c@0309NBc03QfLh0hMW>0080XWFQ00@0NenW071T]P1`I;H0L6Bf0P2:LK4204i:[@80ESbG103;]LD2
0015a`80bjZh0P2aP9l20?32X@<0/X6O0`2NKi`40?3G^0@0^9Rg00@0djFY0=:UZ@3BYJT0dZFY0P1n
Ijh010001iL0Whg109n=`@2OSL430<O=g`80PnFk00<0Sk?_0>3:``1CU>h00`2;M;@00`2lVkL0[I>l
0>2i/0030<ZP[@040=:JVP2<IZ40S6JQ08aVX@<0UVVL0P2WO:@01036WJh0_Y2V0;j@YP2nT:H209ae
Y@80WFjK00@0UG>[085OX@21Gj40PEnQ0`2cQZ@307]DV0<0WfbG0`29HI`00`2^N9L0Q5jN08ANWP03
09n;_`80VI;;00@0aiJT0000003CZZh0djZ^0`2SVL/304AD_P<0_ZO20P26Kk830;>C]@030?[KN03l
cY80o<jB00<0fL?40P32V[030;^`c`<0T7Fa0`2W[M`40?ooo`030000003oool0oooo05h0oooo0018
0?ooo`H00000103oool4000002d0oooo0`0000050?ooo`<0ZKgX0`2c`>@0102hA000oooo0?ooo`3o
ool30>_[c0@0fngO0`31[/L30:n:[P<0QFZ]00H00RBW0>S0[03X`:`0j<2/0=O6b@00000208:^l@80
AGCK0`2hVKP305]R`@80dLSA00@0fkVg000000000000<HCZ0P3QfLh30:9eX@80NenW0P1^EJD208Ya
/@80CTZ]0`1F?9L20<^ea@80]8f]00D004G70<^Z^03;Z[P0bjZh0;60W`030?32X@80/X6O102VfOT4
0:Z;]0<0^9Rg103BYJT0101nIjh0]ZS;0;JXb`00D/l30:W5kP80PnFk0P2?/nl30>3:``<0RgBd0P2]
Tk`40<ZP[@040=:JVP2<IZ40S6JQ08aVX@<0UVVL00<0YgbT0<JM[P36WJh00`2nT:H01@2LMJD0WFjK
09e^V`2MKY/0NEJM00@0UFnU0P2cQZ@307]DV0<0WfbG0P29HI`20:ihU`80Q5jN0`2ORkl0102IT//0
aiJT0<NFY00000020=>Z[P<0XiW;0`14E;h30;jW`P80QVnb00<000000:Vmj02Y_NP00P2Y_NP00`2i
/M40i/Fd0=W3a0030<:J/0@0Y7fY0`2@MK420:N]g0@0oooo00<000000?ooo`3oool0GP3oool004P0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0:03oool2000000H0oooo0`2BLjd30:Vmj0<0YJCD00D0^4@00?ooo`3[jl`0jn_<03fmiP02
0<W9fP0402f0j022[o80PZob08:_lP80^j?000<09:nh0:n:[P2_RZh00`25JZd2008TY`040>S0[03G
a/T0elK903M4/`<0PZka0P15M=/30;RI^00305]R`@3Ab=40dLSA0080fkVg0`1Xfn@00`1NYoL0XWFQ
0:9eX@020:9eX@80NenW0`1^EJD208Y`[`0504i:[@1F?9L0ESbG05HlU`3;]LD00`2dSJd01@1B?Y`0
bjZh0<^Z^03;Z[P0/H2O00<0l<:Q0P2bPIl20;RE]0<0UWF/0`2ZRk@20;RH]`80_J:m0`3BYJT40;JX
b`03001Bc`2j/=00^[3@00<0RY[M0`3Pb/<20=jf[P050>o5Y`2]Tk`0[I>l0:fC_02LJ9D00P3:X:d3
0=:JVP80S6JQ0`2FJI`00`2WO:@0aYf^0<JM[P030;j@YP@0WFjK0P1iEYd309E_Y@<0/hJT0P1kE9P3
09m/U`80RF6L0P2^N9L308ANWP80Wh^o0`37UZ@010000000djZ^0=>Z[P3adk8308e]ZP80K66e0`2n
Yl830:FRd`80dJN]0`2i/M400`3VaK@0`YZ`0<:J/0020<:J/0040=V/Z@2TOJT0Y7fY0:AmZ@<0T7Fa
00<0^XnY09Ei/@2ENK400P3oool00`000000oooo0000000;0?ooo`@00000103oool4000004P0oooo
00190?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0U0?ooo`<00000203oool0103K[jX0TW>]099c[@2BLjd30:BPd@<0YJCD00<094:i03fmiP39bMX0
0`39bMX202f0j0@0^j?000@09:nh0:n:[P2_RZh0[hZ^0P25JZd2008TY`@0elK90P0gA;<00`00QMD0
AGCK04Edf`030;RI^080dLSA0`3K^KL20<^da00306]`aP1NYoL0GZOg00<0XWFQ0P1kGjL306iEY@80
RW2_00@0CTZ]05HlU`1F?9L0ESbG102dSJd01@1B?Y`0bjZh0<^Z^03;Z[P0/H2O00<0l<:Q00D0/X6O
0;RE]02hUK@0^9Fd0?3<[00209Ie[0<0ZX^d00@0^9Rg0;fR_@2mX[d0_J:m0P3BYJT20;nH[`<0]ZS;
102j/=0309j:_P80h<[30P3N]Zh20>o5Y`030:fC_02LJ9D0W6RE0080bZ2]0`3BVYX208aVX@<0UVVL
1036WJh20;j@YP040:]oY02MKY/0WFjK09e^V`80NEJM0`2EKjD30;>6Y080NeBH0`2OK9L01029HI`0
[WRG0:ihU`2^N9L308ANWP<0/Yo40P37UZ@0103?/kd000000=>Z[P3adk8308e]ZP<0K66e0`27K:h0
1P2UX]<0dJN]0=6W[@3AYjd0o=VN0;Vad@80i/Fd00D0ilFd0<:J/032V[00`YZ`0=V/Z@030:AmZ@80
T7Fa0P2jSjT209Ei/@030?ooo`3oeHH0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool004X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo
0P0000020?ooo`030000003oool0oooo00D0oooo0P3K[jX3099c[@030=jj/`2TX=40Y:3A00<0YJCD
1034hNd30;BN`P80Kf>e0`2kXl001@2jF@00[hZ^0:n:[P2_RZh0QFZ]00<0Y86^00D0_=1G0=O6b@3G
a/T0elK903M4/`020<WMj0040025e@15M=/0^9Vh0;RI^080XWFP0`3K^KL30<^da080Jg3600@0GZOg
0:9eX@2RMJ40XWFQ0`1kGjL206iEY@80RW2_00D0CTZ]05HlU`1F?9L0ESbG0>Wj/`030;B=[@80DSjL
0P1MGk/40?32X@<0^9Fd0P3`c:`309Ie[080ZX^d102mX[d0103BYJT0_iR_0;nH[`2oV:l20;JXb`80
f^;L102j/=0309j:_P80g[J^0`3_aJL409aXU@040<ZP[@3BVYX0dYZJ0=:JVP80S6JQ0`2FJI`01@3D
[K40aYf^0<JM[P36WJh0_Y2V0080ZgnT0`2MKY/207UFW@<0UFnU0`2cQZ@307]DV080WfbG102^N9L3
08ANWP030=ba[02bWl@0/Yo40080aiJT00@0ck>m0000003adk80lM>b102=KJX206aQ]@<0Qfb^00H0
YJ;C0=6W[@3AYjd0dJN]0?cIWP2i/M420>K5]0030>O5]032V[00`YZ`0080fJbY0`2TOJT0102@MK40
^XnY0;Z?Z@2jSjT309Ei/@050?oEQP3oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool004/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo0`00000<0?oo
o`80fjnZ0P2BLjd20=jj/`<0WhJh0`1gOL`409Mi/080]9k20P1_HkD30;^S`0040;ZL^@2_RZh0[hZ^
0:n:[P@0Y86^00@0_=1G0=O6b@3Ga/T0elK90`39gNP00`0J;jT002F`0:9eX0030:9eX0030;K0?`3K
^KL0fkVg00<0bkC40P1[L<H0101NYoL0XWFQ0:9eX@2RMJ4307]OY`80KUFU0P2:L:l00`3Jgm/0ESbG
05HlU`020>Wj/`<0]8f]0P1B?Y`305eO^`80l<:Q0P2`VL020;RE]080l<b/0`2FMJ`00`2ZRk@0bkg=
0<^mc@030;fR_@@0_iR_103Jh]`40;Z`d080WXZn0P36Y;L01@3N]Zh0klFW0>o5Y`3_aJL0_XnU00<0
W6RE00@0bZ2]0=:JVP3BVYX0dYZJ0P2<IZ4209IYW080e:fa0`36WJh30:]oY0<0WFjK0`1iEYd209E_
Y@<0/hJT0`1kE9P209m/U`@0[WRG0P24GYh20=ba[0<0/Yo400<0aiJT0<nc_@0000000`3adk8308e]
ZP80K66e0`27K:h30=6W[@80o=VN0P3VaK@30>O5]0040<:J/03I[:T0fJbY0=V/Z@80Y7fY102jSjT3
09Ei/@030?oEQP3oool0oooo0080oooo00<000000?ooo`3oool01@3oool6000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`150?ooo`00C03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool2000000h0oooo0`3K[jX01@2B
Ljd0g[Zc0=jj/`3N^[<0_HnU0080WhJh0`1gOL`0102WOjP0UgV`09Mi/02GNK030;BN`P80Kf>e00<0
^j?00;ZL^@2jW;T01032m^h20:B1[P@0V7Z`0P1a`oh20<WMj00301X_Z@009K0002F`00<0XWFP0P2f
`3l0103K^KL0bkC40<^da03;]<@306]`aP<0XWFQ0`1kGjL206iEY@0408Y`[`3Jgm/0f]oK05HlU`<0
jOZc0`2dSJd2058nW0<0GEnk102`VL00102hUK@0l<b/0?3<[03`c:`309Ie[0@0bkg=00<0_J:m0:nF
_P2_U[h00`2oV:l01@3WlIH0N6jl07Q^_01hK[`0@l:_00<0^[3@00D0WXZn0<JT]`36Y;L0aZBg0=jf
[P020>o5Y`80_XnU0`2LJ9D40=:JVP80S6JQ00@0UVVL0=B]/@3D[K40e:fa0P36WJh20;RH]`80ZgnT
0`2MKY/307UFW@80UFnU0`2cQZ@307]DV080WfbG102^N9L208ANWP80g;6/0`2bWl@00`37UZ@0ck>m
000000030?7C/P<0SFfZ0P1/HKD208M/[P80jNW>0P3AYjd20?cIWP030?SS/@3VaK@0ilFd0080ilFd
00@0`YZ`0=V/Z@3I[:T0fJbY0P2TOJT0102]PJH0^XnY0;Z?Z@2jSjT309Ei/@030?oEQP3dbZ<0m<ZS
00<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0A@3oool004P0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool06`3oool3000000l0oooo103K[jX3
0=jj/`80_HnU0`2OQ[P00`1gOL`0YgnX0:MoZ00309Mi/0<0]9k20P1_HkD30;ZL^@<0F46K00@0`_K^
0:B1[P2TPJh0cJ:/0`2HN[000`3hkZ`0VG^a09Uk/@0209Uk/@04091f/P009K00XWFP0:9eX0<0]/0o
0P3kijL30:[hj080LGO:00@0GZOg0:9eX@2RMJ40k?K70P1/KL8206iEY@80f]oK0`3Cc]@00`3Wim00
jOZc0;B=[@020;B=[@80DSjL102NOZl30;2I`0040;RE]03`c:`0l<b/0?3<[080UWF/0P3;_<`30<^m
c@<0[iJn0P2oV:l20>OaUP80N6jl0P3VbKT30;Z`d0@0aZBg0`3_aJL20;j?Y@<0W6RE00H0oLR80=:J
VP3BVYX0dYZJ0??YR`1WH;L40=B]/@@0^9Rg0P2[Oj@309e^V`<0NEJM00<0UFnU09]`X@2KL:400P1k
E9T307]DV00309m/U`2^N9L0[WRG00<0[WRG00H0Q5jN0=ba[03L/J`0g;6/0000003Ve<D20<nc_@03
0;BB]0000000lM>b0080lM>b0P2=KJX209mhYP0306aQ]@27K:h0jNW>0080jNW>00<0dJN]0?cIWP3l
fIh00P3hhk440>O5]0@0fJbY00<0Y7fY0:f1YP2]PJH00`2jSjT209R7_`80omF60`3dbZ<00`3oeXL0
oooo000000070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`150?ooo`00B03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0H0?ooo`@000004@3oool00`3M^[D0fjnZ0=^_ZP020<Z[
^`80g[Zc0P2mSjD309n6^0<0YgnX0`2GNK030;BN`P<0Xi_=0P2jW;T305Q1V`040<;fkP2TPJh0cJ:/
0<fR[080V7Z`0P3hkZ`01P32W[<0VG^a09Uk/@2INk40T7Jb000U/080XWFP0P25M;T20?_WY`80c[S4
00<0mMfc000SZ02Zn>P00P1aMlX00`2RMJ40k?K70>cfa`0306a]`P80H<Cl0`3Cc]@20>OWd0040>Wf
c@2dSJd0]8f]0;B=[@<0SfBL0`2NOZl30;2I`0@0l<b/00@0UWF/0<^lc03;_<`0bkc<0`2Uf_X00`0G
0000[iJn0:nF_P020;nH[`040>OaUP3CZJh0djV^07Q^_0<0i/Vi0`2;T]@30<JT]`030=;cV@3_aJL0
_XnU0080_XnU0`2LJ9D00`3mb8P0dYZJ0=:JVP020??YR`80If2g0`3D[K40103MblL0^9Rg0;RH]`2h
V;L30:]oY080WFjK0`1iEYd309]`X@<0NeBI00<0LdnH07]DV02OK9L01@2^N9L40=ba[0<0i]C50P2d
T[@010000000nnJW08I_/@26Kk4409mhYP0305iAZ`3YjLh0jNW>0080jNW>00<0dJN]0?cIWP3hhk40
0P3hhk400`000000ilFd0>O5]0020<6Y`P<0fJbY102]PJH20;Z?Z@030>OGa@2HQkl0omF600@0m<ZS
00@0omJ70?ooo`3oool000001`3oool00`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0A@3oool004T0oooo100000050?ooo`@000006@3oool2000000@0oooo
00<000000?ooo`3oool03@3oool20=fj]@050=^_ZP3:Zk/0bZ^k0<Z[^`3N^[<00`2mSjD209n6^080
X7>O0`2WOjP209Mi/0040;:8Z@28K:d0R6b]08Q/[@80Xi_=0`2jW;T205Q1V`040000T@2TPJh0cJ:/
0<fR[080V7Z`00<0n>j/0<:N/`32W[<00`2INk401`2@M[8002F`0:9eX02RMJ00O62W08Ed^@3kijL0
0`3>^<@20?GM/`040:^La`1aMlX0LGO:0:9eX@80k?K70P1/KL820;bO^`<0Q8770P3Wim020>Wfc@04
0=J^[`22U]h0PYKN08:FgP80SfBL0`2NOZl406gNf`<0l<b/0`3;_<`20;3Nm`80S7fn00D05`000:nF
_P2_U[h0_iR_0>OaUP030=>Y[P@0i/Vi00<0001Z08^Be02;T]@00P36Y;L20=;cV@@0_XnU0`2LJ9D0
0`3mb8P0dYZJ0=:JVP020??YR`<0If2g00<0e:fa0=g;a`3MblL00`2hV;L30:]oY080WFjK102BJ9h2
09]`X@<0NeBI0P1cCiP60:ihU`030=_JI@3L/J`0g;6/00<0i]C50P3;`]400`2dT[@000000?_VY`03
08I_/@<0WgRV0`1NDJ/20>WYcP040?cIWP3hhk40n>>a0?SS/@80Heni1031ZL820=V/Z@80_9jj0`2]
PJH01@2jSjT0imO50>OGa@2HQkl0omF600@0m<ZS00D0omJ70=KGH@3oool0oooo000000060?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`150?ooo`00
K03oool3000001H0oooo0P3M^[D40<Z[^`@0_HnU102PLil30:MoZ00309Mi/02bR:T0/XRY00<0R6b]
0P2SVld30;ZL^@80F46K103=XZ`00`2HN[00n>j/0<:N/`030<:N/`80VG^a0P2@M[80102RMJ00]/0o
07aPY`25M;T30<jha0<0mMfc00H0kN740:^La`2[W<L0Zic70009V`1XO=@40;bO^`80Q8770P3>dmd2
0>Wfc@<0eZj_0P22U]h308mTW080WWj_0P1@@Z8208io_P@0[^Oi00@0bkc<08^KgP2`g_L0/=kg0`2<
OKh20:nF_P0308GXl@3CZJh0djV^0080djV^00<0d:fe0>K9^@3VbKT00P2]QZ/208^Be0030<JT]`3B
liT0V7N]0080V7N]0`2nSjD209aXU@80oLR800@0dYZJ0??YR`3cjH/0lnV;0`1WH;L30=g;a`<0^9Rg
0`2[Oj@209e^V`040;24Y@2BJ9h0TVRN099XWP80Vg2Q0`1kE9T307=?V0D0[WRG0P3KfVD00`3L/J`0
a>k`0>KDa@030<_2d@030;BB]0000000nnJW00<0QVna0`2ON:H205iAZ`80^iB_102Ki?d20;^=YP80
Heni0`31ZL840;bN^P<0[H6V0`3WelD00`2HQkl0omF60?C:X`020?C:X`80omJ700@0e]MQ00000000
000000001`3oool2000000D0oooo100000180?ooo`00JP3oool2000001P0oooo0`3M^[D01@2mTZX0
bZ^k0<Z[^`3:Zk/0bJ:a00<0_HnU00@0f:ZX0:1cW`2PLil0X7>O0`2WOjP30;:8Z@<0R6b]00H0[h:T
08MQX027HJ00HdFH0;ZL^@1H@I/20;VTa0<0cJ:/00<0aoJV0;69Z`2aRJ/00`32W[<209Uk/@80T7Jb
00D0XWFP07aPY`1lH:L0ZXfg0?cVWP020<jha080mMfc0P3]hL@20:^La`80_oc50P1XO=@30;bO^`<0
c]?M0P3Oo=<20;bJ]P040=J^[`3IZJH0fJVV08:FgP<0SfBL00<0WWj_09EaY`1@@Z800P1@@Z8208io
_P80Ae6i0P2;Vmh20;NXbP0502Q8_@2`g_L0S7fn08am_P25j?400P10>Z800`3hkJh0djV^0=>Y[P02
0=2]]@@0[HJ[00<003Bh0:kdlP2^m?800P2^m?8209Qg[@<0_XnU0P2LJ9D20?g8R0050=:JVP3/g<80
k=c20>cL`P0F7IP00`1b`oh20=g;a`<0^9Rg0`2[Oj@00`2MKY/0/8BU0;24Y@03099XWP80Vg2Q0`1k
E9T307=?V0D0[WRG0P3KfVD20<C^l0@0bl;A00@0]9:d0000003kiZL0nnJW0P26Kk4309mhYP0605iA
Z`2kU:l0^iB_0;^D[`3ieJ<0KmoQ102kSJH206=O^@80`JW20P2^U[d30;bN^P<0[H6V00@0l_Bf0>OG
a@3WelD0omF6103dbZ<20?oFQ`050=KGH@3oool0oooo0?ooo`000000F@3oool006L0oooo0`00000I
0?ooo`<0gKZe0`2mTZX00`3:Zk/0bJ:a0<VR/@030;f?Y@040=RZZ02PLil0X7>O0:1cW`80YgnX0P35
XkH20;:8Z@80R6b]0P2_PZ@208MQX080HdFH0`2iY<@20<fR[0040<OfYP2aRJ/0/HV[0;69Z`<0`Yjc
0`3keil00`09K=d0XWFP0:Z=]`020:Z=]`80o>JN0P3egK<30>gQa00408S/f@2GJI/0UfVK09IbZ0<0
J7cD00D0_9nk0=_/gP3Kk=h0fncN0=old`040;bJ]P040=J^[`3IZJH0fJVV08:FgP<0SfBL0P2ELJL3
0512XP80SWnn0`17DKT30;NXbP80:4Rm0P2<OKh2040jXP80n>f^00D0djV^0=2]]@3@[KD0d:fe0<^K
Y@030:f6Z`<0RF6M0P2^m?8209Qg[@<0_XnU0P2LJ9D20?g8R00508:/l03/g<80k=c20>cL`P0F7IP0
0P10VO<0101H0000ZKkY0:Vnj@2Y_^T306b5fP80M7[:0`2`Q:D3099XWP80Vg2Q0`1kE9T307=?V0@0
[WRG0P3KfVD409?WnP<0bl;A00@0]9:d0000003kiZL0nnJW0`26Kk4209mhYP@0^iB_00<0nMFS0?[U
R`3R/jH00`2kSJH206=O^@@0[YJm0`2lW[X20:f1YP80l_Bf00@0O>G/0:JVeP2VY]H0YZKF0`3dbZ<0
0`3oeXL0e]MQ0=KGH@040?ooo`030000003oool0oooo05H0oooo001U0?ooo`8000000P3oool00`00
0000oooo0?ooo`0F0?ooo`80]iZj0P3M^[D30;fBZP<0bJ:a0P2mSjD20=RZZ0<0X7>O00@0YgnX0<FS
]P35XkH0aJ>f0P2bR:T01028K:d0[h:T0:n2Y02_PZ@208MQX0<0HdFH0P2iY<@00`3=XZ`0aoJV0;69
Z`030;69Z`80`Yjc00@0a;cB0?_GW`3keil0nmNO0P09K=d30:Z=]`80o>JN00@0iOc40>gQa03]hL@0
R>cI102GJI/209IbZ080VWfc0`3Kk=h207M[^00402L0002lV[H0_9Zf0;bJ]P<0fJVV00@0PYKN08mT
W02?I9`0SfBL0`2RUlT308b;c@<0RgRi00<0]8:M01NTcP2gZ<X00P2gZ<X0100XB;d0l;^H08am_P10
>Z830?S][P<0d:fe0P3;VjD30:f6Z`050:ihU`29HId0RF6M00@IV`2^m?800`2HMjd20;j?Y@80W6RE
0P3mb8P20:?GnP807ES?0P0F7IP206QP]P0405P0002Y_^T0ZKkY0:Vnj@80K8GJ0`1dN/X20;24Y@<0
TVRN0`2KL:4207]DV@<0LdnH102^N9L00`000000[Kdl0>[bcP020>;Fb`0604BGlP3;`]40bl;A0<_2
d@3kiZL000000P3kiZL308I_/@0309mhYP2LJiT0W6^I0080^iB_0P3ieJ<00`3jiH/0h[>V0;^=YP02
0;^=YP030;AoVP2;Ij@0RfNT00<0[YJm0`2lW[X0102]PJH0l_Bf0?;d]P3RimH20<j/]`80YZKF0`3d
bZ<0103oeXL0WhVm09n9_@2ORKd30?ooo`030000003oool0oooo05H0oooo001R0?ooo`<000006@3o
ool00`3]e;/0M6>b07AS/P040;NJ^P@0_I:Z00D0f:^Y0<VR/@39X[40bJ:a0;f?Y@020=RZZ0<0X7>O
1035XkH20;:8Z@@0[h:T0P27HJ0306=5V080^JC40P2JO[@0103dcJH0/HV[0;69Z`2aRJ/20<BldP<0
nmNO00<0kOVk0=3:e009K=d00P2ZSKL20?cVWP030>Gla01OH;/0Gf2k00<0VH:i0`2GJI/309IbZ080
VWfc0P1NDJ/207M[^005034TT@2lV[H0_9Zf0;bJ]P34W[800P3IZJH00`22U]h0SfBL08mTW00208ZJ
g@80XYO90`2<Rld208]h^@80]8:M00L0LDN?0;NXbP2gZ<X0]jS:09IdZP3`^iP0;C:T0080n>f^0`2J
N:`20=2]]@80bi^U0P2]QZ/20:ihU`80RF6M00<011VK0:kdlP2HMjd00P2HMjd20;j?Y@0409aXU@3m
b8P0oLR80?g8R0<0XmOj0P30[/P0100F7IP0J62f06QP]P1XH;H30:Vnj@80K8GJ0`1dN/X30;24Y@80
TVRN0`2KL:4307]DV@80LdnH102^N9L00`000000j_;>0>;Fb`020>;Fb`030=g<b01lK[P0YZOG0080
YZOG00@0000008^Oh@2;Wn40RioQ0P1CGl8309a[V@80^iB_0P3ieJ<20>:cYP80^hfV0P2dOiX208]W
Y0<0[YJm0`2lW[X00`3bm;H0h^OF0>;WeP030<j/]`@0/ik40P3oeXL309n9_@@0oooo00<000000?oo
o`3oool0E@3oool005l0oooo0`00000A0?ooo`030<^OZ`3oool0oooo00P0oooo00@0kMBk07AS/P1d
Hk80M6>b0`2gV[X00`2nU:/0_I:Z0;fBZP020=R[Z@<0bJ:a00<0_HnU0=RZZ03HZZP00`2PLil01@33
UjT0aJ>f0<FS]P35XkH0/XRY0080^iNc0`2_PZ@208MQX0<0HdFH102JO[@01P3dcJH0/HV[0;69Z`2a
RJ/0kMRm0<BldP80nmNO00P0kOVk0=3:e03@b]@0d<[D00U/g@2ZSKL0o>JN0>Gla080Gf2k0P2fV;P2
09V2^@<0UfVK0`2FLZP209Ym/`80GU6[0P1gJkP2034TT@030;bJ]P34W[80a9jb00<0fJVV0P2?I9`2
08ZJg@<0XYO90P2<Rld208]h^@80]8:M00@0LDN?09IdZP2FM:X0UWBZ0P3`^iP0100]<Z@003k2000n
`P00?/8209Yh[0040=2]]@3;VjD0bi^U0<^KY@80[HJ[0P2^N9L308UQW@0400@IV`2HMjd0V7N]09Qg
[@80_XnU00D0W6RE0?g8R03mb8P0h:jR0?k@S`03056BkP80`:k800<05QfH06QP]P1XH;H00P1NK<P0
0`0fAkL0;k?S04IYd@0307AjbP<0/8BU0P2BJ9h309]`X@<0NeBI0P1cCiP30:ihU`030?OHZ`3Zl/h0
h]K;0080h]K;0P3Mc<P207a^^080YZOG00@0000008^Oh@2;Wn40RioQ0`1CGl8209a[V@040;^D[`3i
eJ<0nMFS0?[UR`80h[>V0P2kSJH20;AoVP<0RfNT00<0[YJm0;b`c@2l/<d00P1NTNT20;7Pm`@0cZbg
00H0eZna0;>Na02cW/@0/ik40<JT]P3Se5d309n9_@D0oooo00<000000?ooo`3oool0E03oool005d0
oooo0P00000C0?ooo`80bin[00<08R:G0?ooo`3oool01P3oool20>gD^`<0M6>b0P2gV[X20;jDZ`80
_I:Z0P3HZjT30<VR/@<0f:ZX0P2PLil20<>GZ@<0aJ>f0`2kUk<30:n2Y080Qf6P0`1SAIP00`32UZT0
VWjd09Yn]0020?C=YP80/HV[0P3]f;d20?_GW`<0HU2X00@0d<[D0;>3X@2cPj40ZXfg0P2YWLX40;JH
^080VH:i0`2GJI/309IbZ0<0R5fI00<0OU^O07M[^01gJkP00P0a99440<BN/P040=VYYP3ng9T0SfBL
06QJ[`80RY[M0`2RUlT208b;c@0408]h^@2dPYd0]8:M0;B2W@80LDN?0P2FM:X20?2kV080;C:T0P00
?/8209Yh[0@0bi^U00@0[HJ[0:ihU`2^N9L0[WRG0`29HId00`046I/0ajNi0<NW^@0202h000090;j?
Y@2LJ9D0oLR80?g8R03P[Z80o]2?0>>^W@1fEId0DI;^00<0`:k80P1XH;H205i/b080=TNg0P16JM42
07AjbP<0/8BU0P2BJ9h309]`X@<0NeBI0`1cCiP20:ihU`040?OHZ`2TWLh0Y9g>0>;Fb`<0gLc80`1l
K[P01@2DJ9d0000009AXW@1UI;`0RioQ00<0Deo20P2LJiT0102kU:l0nMFS0?WEX`3jiH/20>:cYP04
0;^=YP2dOiX0]7nJ0;AoVP<0RfNT102l/<d20;7Pm`80XXNh0`3>[;L00`3F[k40/ik40;>Na0020<JT
]P80hmAM0P2ORKd50?ooo`030000003oool0oooo05@0oooo001J0?ooo`<000005@3oool20<^OZ`03
028RU`3oool0oooo00H0oooo0`3]e;/207AS/P050;NJ^P2nU:/0_YB[0;jDZ`2mTZX00`3HZjT40:9m
Z`80f:ZX00@0X7>O0<>GZ@33UjT0`iNY102IO[<20;^G/`<0[h:T0P27HJ0206=5V080`YJY0P2JO[@2
0?C=YP80/HV[0P3]f;d20:j3YP<0HU2X102cPj400`3KYIh0QF:R08ERXP030;JH^080VH:i0`2GJI/2
09IbZ080X76M0P28GIT207iKW`80Mf^h0P0a99430<BN/P030=Nk_P3ng9T0SfBL0080J5Z_00<0OF6W
09IcZP2FLjX00P2FLjX00`1hDYT0]8:M0;B2W@020;B2W@80LDN?0P2FM:X20?2kV0<0XWbZ00@003k2
09Yh[02JN:`0knC30`3;VjD40:ihU`<0RF6M0`37YkT0103[lIP0;P0003HjZ02LJ9D20?g8R0030>2^
XP3nd8l0hjjM0080MUFM0`30[/P307>oo@0404eG_01NK<P0=TNg03I7]`80LWc>00D0M7[:0;24Y@2`
Q:D0/8BU099XWP020<CFi`0306eO/P2KL:40NeBI0080NeBI0`1cCiP20:ihU`030?OHZ`2TWLh0Y9g>
00@0gLc80P1lK[P209Y^W`040000002DJ9d0IFBl06ET_0<0Deo20P2LJiT30?WEX`<0h[>V102dOiX3
08]WY0030>O;^P2l/<d0_;3=0080eOkH0`2RQkP20<j/]`80eZna00<0/ik40<JT]P36Y;H00`3Se5d2
09n9_@H0oooo00<000000?ooo`3oool0D`3oool005P0oooo0P0000030?ooo`030000003oool0oooo
0140oooo0`3;Wj/2028RU`06019Gd03oool0oooo0?ooo`1:01`0oooo103]e;/207AS/P@0_YB[00D0
_I:Z0=R[Z@3HZjT0f:^Y0<nOYP030:9mZ`80f:ZX1033UjT0103W`:l0VGjc09Un/`2IO[<30;^G/`80
[h:T0P27HJ001@1SAIP0`YJY0<:FZ@32UZT0VWjd00<0m<fV00@0/HV[0>gH_@3]f;d0Rg2^0`2^PjH2
069@Z0050:MgW@2cPj40/h>Q0;>3X@3KYIh00P25HZ830;JH^080VH:i0`2GJI/40:1aW@80R5fI0P1n
Fil0100_8i80Mf^h034TT@0a99420<BN/P80ek^n00@0o]bI06QJ[`1XFZl0J5Z_0P1mHJL309IcZP80
N5:I0`2dPYd20757S`0509IdZP3`^iP0l;^H0?2kV038Tih00P2RO:X01000?/80VWR/0>oT``3_i<<3
0<^KY@040<VLZ@2^N9L0[WRG0:ihU`<0RF6M00H0`Y:U0<NW^@37YkT0jo6H02h0000f>ZP20?g8R080
h:jR00<0o]2?0>>^W@1fEId00P1fEId206nIjP030:F3/01c_od0Lkom0080CENl0P0fAkL3079lcP<0
/8BU0`34e^L206eO/P<0NeBI0`1cCiP0102^N9L0mmR[0=7Kh02TWLh30=;;dP80gLc8102JKYl00`00
0000U6RM09AXW@0206ET_080Deo20P2LJiT207AmcP80hMC;0P3R/jH01039Y[D0]7nJ0;AoVP2dOiX2
08]WY080il^j00<0eOkH0:Z<]P2ZS;H00P2ZS;H30::7^0030<j/]`3F[k40eZna00<0aZBf0P3Se5d2
0;FG^@80T76/103oool2000005D0oooo001E0?ooo`<000001P3oool00`000000oooo0?ooo`0?0?oo
o`@0bin[0P0R8YL3019Gd0<0L/So00@0I7cF0>gD^`3]e;/0kMBk0`2W/=h30;jDZ`<0f:^Y0P3?WjH3
0:9mZ`<0YXnm0`33UjT0103W`:l0VGjc09Un/`2IO[<30;^G/`80[h:T0P27HJ040<:FZ@0409Yn]03d
cJH0m<fV0?C=YP80kMRm0P2;L:h30:j3YP03069@Z02WMid0YgNM0080/h>Q0P3KYIh308ERXP040;JH
^02HJY`0V6ZL09V2^@<0UfVK00@0`i6R0:1aW@2PLId0X76M0P28GIT207iKW`80;b>B0P0a99400`34
W[80ek^n0=Nk_P020?kLV@<0J5Z_0P1mHJL309IcZP80N5:I0`2dPYd20757S`0509IdZP3`^iP0l;^H
0?2kV038Tih00`2RO:X01@2JN:`0knC30>oT``3_i<<0bi^U0080bIbY0`2^N9L208UQW@80`Y:U00@0
ajNi0>_aV03K^KH0fkVf0P0f>ZP20>2^XP030?k@S`3S[Yd0hjjM00<0MUFM0`2UPk000`0008H0Lkom
04eG_00204eG_00403I7]`1bO<h0LWc>079lcP@0V:7J0P34e^L306eO/P80Df[<0`1cCiP00`2^N9L0
mmR[0=7Kh0030=;;dP80XgJQ0P2;HI/309Y^W`030000002DJ9d0U6RM0080IFBl0P1CGl8209a[V@05
07AmcP3Qe</0hMC;0>7Db`3R/jH00P39Y[D30;AoVP0608]WY03WbkX0il^j0>O;^P3/i<L0m>Nj0`2Z
S;H30::7^0<0eZna00<0eJna0<JT]P3li8l0102eUkT3091a[0D0oooo00<000000?ooo`3oool0DP3o
ool005<0oooo0P0000050?ooo`<0TVfT4`3oool0103T`[D0bin[0<^OZ`3;Wj/2028RU`@0Y][j0`1b
b?l0101TO=H0^iF`0;^E/02kUK020:N`gP<0_YB[00<0`Y^_0=R[Z@3HZjT00P3?WjH30:9mZ`030<BJ
[@2VSkd0YXnm0080`iNY0`3W`:l209Un/`<0^iNc0`2o_]T2055gf@<0`YJY0`3dcJH00`2lnl40YXjl
0:J>_00208]`[P<0[X>V0`2WMid20;>3X@80fjFN0`25HZ8309QZW00309V2^@2GJI/0UfVK0080`i6R
0`2PLId208QMV@80OU^O0P0_8i82034TT@<0ek^n0P3ng9T306QJ[`80OF6W0`2FLjX207QBV@<0]8:M
0P1aAhl00`2FM:X0l;^H0?2kV0020<RCWP<0XWbZ103_i<<00`3;VjD0bIbY0<VLZ@030:ihU`0408UQ
W@32TZD0`Y:U0<:BY@80000000<0fkVf0?_VYP3kiZH00`3P[Z80103nd8l0hjjM0>>^W@3S[Yd207IE
W@050<NDX@2UPk00YH>`0:F3/00c?jl00`1=Ek`206aJ[080n=:U00<0/hRX09RQfP2HXMX00P36i>d2
0<CFi`80KEnb0`1CJ/`01000@L80LdnH0:ihU`3gf:/209B4`0040=;;dP2SMZ40XgJQ0:=fX@80Rf6K
0`2JKYl00`000000U6RM09AXW@0206ET_080Deo20P2LJiT40>7Db`<0bJJe0`2dOiX30>O;^P030>cT
a`3dikX0m>Nj00<0ZXbf0P2RQkP20<god@060=J_/@3E[k40eJna0<JT]P3li8l0n=Yc0`2eUkT3091a
[0030>;cVP3oool0oooo00<0oooo00<000000?ooo`3oool0D@3oool00500oooo0`0000060?ooo`80
[8bd0P2BKJ@B0?ooo`80i<:e0`3;Wj/20<B]``030>o8ZP0??kh0ejf^0080ejf^00<0002007l0002k
UK000`2kUK020:N`gP80_YB[0P32Vjl0103HZjT0cinV0<nOYP3?WjH20:9mZ`80a9Z]0`2VSkd01@33
UjT0il2_0>O0[`3W`:l0VGjc0080aO;_0`28UMT30;nnf@04055gf@32UZT0`YJY0<:FZ@80/Mef00@0
b:Bd0:J>_02VS[`0YXjl0P2;L:h20:j3YP80[H6T0P2WMid20;>3X@80fjFN0`25HZ80102WM9X0V6ZL
09QZW00N5hd209MYV`80`i6R0`2PLId208QMV@<0OU^O0P0_8i8208UYY`80ek^n00<0o]bI0:mmWP2_
OIh00P1XFZl207eQY`<0UW>Z0P1hDYT30;B2W@80LDN?0`3`^iP30<RCWP030:9lZP32Uj/0`YN[00<0
knC30`39W:T30:ihU`@0`Y:U00@000000=^i]P3K^KH0nnJV0P3NfM820>2^XP040?k@S`3S[Yd0hjjM
0>>^W@80MUFM00@0aiBQ0:F3/02UPk00YH>`0P0c?jl204eG_080K5Z/0P3hdZD0102cR:P0a^C]0<KT
k@36i>d20:6<_P030<CFi`1]Gk80KEnb00<0Df[<0P00@L820?OHZ`80U8C0102SMZ4208]QV`<0VVjO
00L0U6RM0000002DJ9d0hJnS07IKY@3^h/<0Deo20080W6^I00<0Y8>a0>7Db`3Qe</00P2e/]H20<VV
]@<0]7nJ00@0_o;a0004U@3/i<L0k>C70P3dikX30:Z<]P@0cOoA00H0eZna0=F_/@3E[k40o>B?0?GM
MP3hfW<30;FG^@80T76/00<0h_>J0:n2Y02_PZ@0103oool00`000000oooo0?ooo`1A0?ooo`00C@3o
ool300000080oooo00<000000?ooo`3oool00`3oool30:b<]080TVfT00<07Q>70?ooo`3oool0103o
ool00`0e0000oooo0?ooo`080?ooo`<0i<:e00<0bin[0<B]``34[L<00P3_b:X40=N][P80hLW000L0
O`000;^E/02kUK00^iF`0:;Oo02W/=h0_YB[00<0`Y^_00D0f:^Y0<nOYP3?WjH0cinV0:9mZ`030<BJ
[@<0YXnm00@0`iNY0>O0[`3W`:l0il2_1035l^l208REf@@0VnKl00<0DGOI0<:FZ@38Y;@00P38Y;@0
103T^J/0YXjl0:J>_02VS[`208]`[P040:j3YP2]PJ@0[H6T0:f1Y080YgNM00@0/h>Q0=^UWP3KYIh0
fjFN0P25HZ820:MdVP80V6ZL00<07QN=09MYV`33TJ800P33TJ830:1aW@80R5fI0`1nFil202lSTP<0
RFVW00H0o]bI0:mmWP2_OIh0[gfN05Q3W`1XFZl207eQY`<0UW>Z0P1hDYT30;B2W@80LDN?00<0iKFS
0?2kV03`^iP00`38Tih0102RO:X0`YN[0<:GZ`0_:YX306F6gP80bIbY0`2^N9L0103kiY<0`Y:U0<:B
Y@32TZD20:>1[`030?_VYP3NfM80g]WB0080g]WB00<0h:jR0?k@S`3S[Yd00P3S[Yd01P1fEId0aiBQ
0<NDX@37U:40YH>`0<NGY@<0<cn_00<0CENl06aJ[03hdZD00P3hdZD20;>8Z080f?cL0P2QS;h00`2R
U<L0Z;oZ0:RojP020:RojP80hKfd00@0ZO6_06_2oP2DQ<00U8C00P2iUk<30:=fX@80Rf6K0`2JKYl0
102DJ9d000000>6_X`3Q[j<207IKY@0405=O`P2LJiT0Y8>a0:B3/@@0]K;F0`39Y[D20;AoVP80SG6_
00@000BE0?CW^P3dikX0m>Nj0P2ZS;H00`35k_0000000000000202N<k@<0eJna00@0cjRb0?GMMP3h
fW<0n=Yc0P2eUkT00`2@LJ`0h_>J0:n2Y0020:n2Y0D0oooo00<000000?ooo`3oool0D03oool004/0
oooo0P0000080?ooo`@0Vg>U0P2/S;@2099]Y00401hCQ`2FMJ`0UWF/09Ie[080oooo0`0e00080?oo
o`@0i<:e0`34[L<20>o8ZP030>?2]`3G[Jh0ejf^0080hLW000@0eZRX07l0002kUK00^iF`0`3Gnmh4
0<:K[`@0cinV1034VZd30:J?_@<0il2_0`36XK<00`3XcKX0BV3704YPa`0208nBdP060;^R`02Ki_`0
VnKl008LW`32UZT0i_JQ0P38Y;@20>BiZ`<0J8?J00<0L7G80:f1Y02]PJ@00P2]PJ@20:MgW@050;>3
X@3KYIh0fjFN0=^UWP25HZ800`2WM9X209QZW00301hGS@33TJ80`i6R0080`i6R0`2PLId208QMV@<0
OU^O0P0_8i8308UYY`@0[gfN0P1H@il207eQY`<0UW>Z0P1hDYT30;B2W@80LDN?0P3U]J<40<RCWP@0
`YN[00<0;bZJ06F6gP1UQ]h00`39W:T20:ihU`040?_VT`32TZD0`Y:U0<:BY@80Xh6_00<0l=^k0>_^
S`3NfM800P3NfM800`3nd8l0hjjM0>>^W@020>>^W@0507IEW@37U:40aiBQ0<NDX@2UPk000P37UjD0
102KOK80f[2]0=Z`[@1/FZ`30?SBY@040;>8Z03Ho=`0f?cL0=Slg080XHbn00T0XYC70;NG]P2gUkH0
]iNf000000180140hKfd0:Wa[`0n@jh0102iUk<30:=fX@<0Rf6K0P2JKYl0102DJ9d000000>6_X`3Q
[j<207IKY@0505=O`P2LJiT0Y8>a0:B3/@3O]J`00`2e/]H30<VV]@060;AoVP2=LJl0SG6_08ea[`00
5Z<000BE0P3dikX20<G^l0040;AnV@1lH:L0j;RR0>RhXP809hc]00<0eJna0<nX/P3?Z;800`3hfW<2
0;FG^@030>;cVP2_PZ@0[h:T0080[h:T1P3oool00`000000oooo0?ooo`1?0?ooo`00B03oool30000
00P0oooo00<0f:f/08ed/P2=M;800`2KLjD20:b<]080TVfT0P0N4hL309Ie[0@0bZVg00<0cEP00?oo
o`3oool0103oool40>C2]@80_9nk00<0a:g30>o8ZP3_b:X00`3S`[L00`3G[Jh0hLW00>79`0020=JX
Z080^iF`0`2LMJH01@00<KP0`Y^_0<:K[`32Vjl0fKNg00<0cinV00H0lN6m0<BJ[@34VZd0a9Z]0>cD
_03id9h20>ngU@030>O0[`3O[Z@0aZ6c0080aZ6c00@0j<fj04YPa`1:H<L0BV370P2NRkl00`2kX/00
VnKl008LW`020>KfX@050<RT]03T^J/0i;V[0>BiZ`3ch;T00P1XPmX2071eb0<0[H6T0P2WMid40=^U
WP@0YgBJ0P2HJY`201hGS@<0`i6R0`2PLId208QMV@<0OU^O0P0_8i8208UYY`030<jFVP3ndY40[gfN
0080[gfN0`1H@il0101dEIl0[hN[09IcZP2FLjX207QBV@<0]8:M0P1aAhl20>FeX`050<fFV`38Tih0
b9>N0<RCWP3kfJ400`32Uj/202lZVP0406F6gP39W:T0bIbY0<VLZ@80[WRG00<0nnJC0<:BY@32TZD0
0P2SPJl0103`fk/0jnj?0>_^S`2bRJX3095o_0040=6Y[`3S[Yd0hjjM0>>^W@@0aiBQ0`37UjD30=Z`
[@@0n=:U103Ho=`20:6<_P@0]iNf0P3FoM/0103Q_K@0ZO6_03i3[P0n@jh30;VG/`<0XgJQ0`2;HI/2
09Y^W`0409AXW@000000hJnS0>6_X`80MU^U00@0mm^_09a[V@2TPk40Y8>a0P3O]J`20;FbeP<0bJJe
00@0]7nJ0>Fo[`2=LJl0SG6_0P005Z<00`0bHm<0]7jI0;AnV@020;AnV@0607aPY`3X^:80j;RR0>Rh
XP0WS>d0eJna0P3?Z;830?SJL`040000001jVN@0/hna0;>?/@<0[h:T1P3oool00`000000oooo0?oo
o`1?0?ooo`00AP3oool2000000X0oooo0P3H[J`208ed/P<0Vg>U0P2/S;@2099]Y0807Q>70`2FMJ`0
1@3=Xjd0bZVg0<ZY]`3AZJl0iWdP00@0oooo102j[ll40;bO^`030<B]``3_b:X0klRZ00<0hl:g0P3Q
bL030=JXZ0030;^E/02ILZD0VG:U00<0W7FV0P32Vjl20=Vg]`80cinV0P3ahKd20<BJ[@80k=Bl00D0
nM2N0>ngU@3_]iD0kkNE0=n^Y0020<JQ/`<0j<fj0P1:H<L209j;_`030;^R`034k_000QbO0080i_JQ
00@0b:Bd0>BiZ`3T^J/0i;V[0P3ch;T00`1XPmX0L7G8071eb0030:f1Y080YgNM00D0/h6M0=^UWP3K
YIh0fjFN0:mjV0030:MdVP80V6ZL0P0N5hd30<>AXP<0X76M00@0R5fI0;2:[P2`RZh0/8Z^0P3lbhd0
1@0_8i80RFVW08UYY`3>UYX0o]:A00<0[gfN00L0o<b?05Q3W`1dEIl0M5FO0:n7Z`3B[[D0UW>Z0080
N5:I0`2dPYd01@1aAhl0iKFS0>FeX`3U]J<0cIJK00<0b9>N00@0nmVQ0<:GZ`32Uj/0`YN[0P0_:YX0
1@009:l0bIbY0<VLZ@39W:T0[WRG00<0nnJC00D0`Y:U0:>1[`2SPJl0l=^k0>_^S`020;:9ZP<0TGnl
00<0dJV_0>>^W@3S[Yd00P2YOJ@30<NDX@040?75Y037UjD0aiNU0=:TZ080f[2]0P2iQIh307eGV`03
06e@W`08=KH023Ff00<0^?[Z0`2gUkH409A[X@80?T>^0`2iUk<30:=fX@<0Rf6K0P2JKYl0102DJ9d0
00000>6_X`3Q[j<207IKY@030?OK[`2LJiT0Y8>a00<0gkF/0`3KcL/01@2TRKP0bJJe0;AoVP3U_jl0
SG6_0080hOWF00<001JS039Sd`0bHm<00`2dOYT40>RhXP0405Q2W@3?Z;80cjRb0?GMMP80n=Yc0P00
00030;>?/@<0[h:T1`3oool00`000000oooo0?ooo`1>0?ooo`00@`3oool4000000/0oooo0P3H[J`2
08ed/P<0Vg>U0P2/S;@2099]Y0807Q>70P2FMJ`20<fS[@040<ZY]`3AZJl0dJV_0>Im80@0oooo00<0
kmVk0;Z_c`2j[ll00P33[<<30;bO^`80klRZ0`3S`[L20<GgZP@0eZRX00<0^8FN09UbY@2ILZD00`2L
MJH00`0;7il0`Y^_0=Vg]`020=Vg]`060<nOYP3ahKd0lN6m0?7Q_@34VZd0k=Bl0P3id9h20>ngU@<0
gjjT00@0aZ6c0>S=^P3XcKX0j<fj0P1:H<L209j;_`050<C^l03So;P0ajFg0<NU]`1hIK000`3T^J/2
0??P^@80mNnh0P1`MLP30:f1Y080YgNM00D0/h6M0=^UWP3KYIh0fjFN0:mjV0030:MdVP80V6ZL0P0N
5hd30<>AXP<0X76M102`RZh30?c;S@0408UYY`3>UYX0cYJJ0?kBT@<0[gfN00@0o<b?05Q3W`1dEIl0
M5FO0P2_Qj/0102`Q:H0WXZn09j:_P2NR[h20;B2W@030757S`3U]J<0iKFS0080cIJK0P38Tih20?_I
X@<0`YN[0P0_:YX01@3J/:h0bIbY0<VLZ@39W:T0[WRG00<0nnJC00@0`Y:U0:>1[`3`fk/0jnj?102b
RJX0102AOk`0dJV_0=6Y[`3S[Yd30:UmY080aiBQ0P3aaJ@20<NGY@80dZBX00<0f[2]0;V5WP2iQIh0
0`1mEi/206e@W`8023Ff00H0/Yo50;SjjP2gUkH0]iNf06UFZ@2bOid309A[X@<0?T>^0`2iUk<20:=f
X@<0Rf6K0P2JKYl01@3Q[j<000000>6_X`3Q[j<0MU^U00<0mm^_00@0Y8>a0=ne[03O]J`0I77;0`3K
cL/40>Fo[`<0hOWF00<0002@000FX`0bHm<00`2dOYT02P3mfG/0j;RR0>RhXP3X^:80F4:M09L<003?
Z;80mMef0?SJL`2>Kj/308mj^080/hna0`2_PZ@70?ooo`800000C`3oool00440oooo0P0000040?oo
o`030000003oool0oooo00L0oooo0`3H[J`208ed/P<0Vg>U00@0bjFb06EK/`2BKJ@0TVfT0P0N4hL2
09Ie[080cJ>]0`3AZJl0103VOB00oooo0?ooo`3oool20>oI^`040;Z_c`33[<<0`jc30<>/``80_9nk
0`3F`<@00`3@Zk<0hl:g0<GgZP020>S`T`050;>6Y@3FZ:P0eZRX0=JXZ02hQIh00P2ILZD309aeYP03
00/OW`3I]kL0fKNg0080fKNg103ahKd20>cD_080nM2N0P3_]iD30=n^Y0<0j<fj00<0V7^a065K]@2[
T;X00`34k_030<NU]`80N6F`0P3T^J/00`3ch;T0mNnh0?G_^0020<NX^`05071eb02]PJ@0[H6T0:f1
Y02WMid00`2cPId00`3KYIh0[gZH0:mjV0030:MdVP80V6ZL0`0N5hd20<>AXP@0UG6X0P2`RZh01@3[
`:P0o<^=0?c;S@3lbhd0gZnU0080cYJJ00<0o]:A0:mmWP2_OIh00P3lc8l0101H@il0M5FO07AEW`2_
Qj/20;24YP060:F2[`2NR[h0WXZn06=1T`2dPYd0LDN?0P3U]J<20<fFV`80b9>N0P3kfJ420<:GZ`80
a=GV00H0PZc`0=Z`[P3J/:h0f[2^0<VLZ@2^N9L30?_VT`050:J2[@3`fk/0l=^k0:c7CP39WZd00`2b
RJX00`2AOk`0dJV_0=6Y[`040:UmY080aiBQ0P3aaJ@01037UjD0dZBX0=:TZ03BY:P30;V5WP<0OENK
0P1]D9l01P1/C9X023Ff0;:Oa@2bWlD0^?[Z0;NG]P80/WnM0`2DJj400`1QBj4002BM03i3[P030;VG
/`80XgJQ0`2;HI/3097WnP030000003Q[j<0hJnS00@0mm^_0`3O]J`209Ag/0<0Sgbj0P3U_jl20;V`
d080hOWF0P0009001@0bHm<0]7jI0;AnV@2dOYT0oMUk00<0j;RR00@0F4:M0:MlY03?Z;80n=Yc0P2>
Kj/308mj^0<0/hna0P2_PZ@60?ooo`030000003oool0000004l0oooo000n0?ooo`<00000403oool3
0=R][080SGBb0P2KLjD20<^U/P80IE^c0P1_JK/00`0N4hL0UWF/0<fS[@020<fS[@030=^c[`3AZJl0
dJV_0080iWdP0P3oool20>oI^`@0`jc300@0_9nk0=K0a03F`<@0e/340P3@Zk<20?O_Z@030>S`T`2c
QZD0/hJU0080eZRX0P2hQIh209UbY@<0W7FV0P0;7il20=Vg]`80bOgR1029Rll20?W@WP80kkNE103O
[Z@0103EgV`0V7^a09Qk/@2HNk430:^@^P0301<k^@37YKL0ajFg0080ajFg0`1hIK000`3ch;T0mNnh
0?G_^0030<NX^`05071eb02]PJ@0[H6T0:f1Y02WMid00`2cPId00`3KYIh0[gZH0:mjV0030:MdVP06
09QZW03Ujm@0iN_D05m1UP0N5hd0`i6R0P2QLil309EaZ080/8Z^00H0jl2X0?c;S@3lbhd0o<^=0=j_
Y@3>UYX30?kBT@040:mmWP3lc8l0o<b?0?c<S`80M5FO102`Q:H209j:_P80Hd6C0`3U]J<20<fFV`04
0<RCWP3kfJ40nmVQ0?_IX@@0a=GV103J/:h01@35UjL0c:^h0<b[^03<ZkP0YX:]0080/8nd00<0[<M>
0<VN[@39WZd00`2bRJX30=6Y[`050=J`/`2YOJ@0ZGfT0:UmY037U:400`3aaJ@01@37UjD0dZBX0=:T
Z03BY:P0dIjR00<0^HFN0P1mEi/206e@W`80K4bJ0`2bWlD00`1YEZT0/WnM0;9oW@0309A[X@80HD^Q
00@0IVBl0;VG/`2iUk<0^INc0P2SMZ4208]QV`80/9W00P2AioX010000000hJnS0>6_X`34Yk`40:>L
c@040=ne[02MNZ`0U7N`09Ag/0<0Sgbj0`2i/=020;jDZ`80QhcA00<0GFG2039Sd`2dOYT00P2dOYT0
103mfG/0j;RR0>RhXP3X^:830:MlY0<0SVn[0`2?N[P30;>?/@80[h:T00<0]Y>d0?ooo`3oool01P3o
ool00`000000oooo0?ooo`1<0?ooo`00>`3oool300000180oooo103H[J`00`2cQJ@0SGBb09]cY@03
0<^U/P80IE^c0P1_JK/0101;DKL0cJ>]0<fS[@3=Xjd20=^c[`<0dJV_00@0iWdP0?ooo`3_fK/0kmVk
0P3DaL/30<>/``<0e/340`3@Zk<00`3gkjT0j?2C0;>6Y@020;>6Y@040000O03FZ:P0^8FN0;R5WP80
VG:U0P2LMJH20>_bc@06069J]039oN80bOgR0?3R_`33o]L0RWk10`29Rll0102no<<0anG/0<OUk03_
]iD40=n^Y0030>?5^P2YU<00ZIC00080ZIC00`2[T;X0100C>kT0ajFg0<NU]`37YKL207QU/080/Xb^
00<0/LA60>?KcP3Sflh00P37Z;/0103Jo/40[H6T0:f1Y02]PJ@40;>1W@<0[gZH0`2WM9X30>G[e080
Gd6F0`2QLil309EaZ0030;2:[P3[`:P0o<^=0080o<^=0P3N[jD01@3>UYX0o]:A0?kBT@3ndY40[gfN
00<0o<b?0`2SOZ`30;24YP80WXZn0`1S@I<01@3U]J<0cIJK0<fFV`3=UY/0b9>N0080nmVQ0P3Hk>84
0;2dg080f[2^0P35UjL30<b[^0<0/8nd0`39WZd30;:9ZP040<ZNZ`3AZJl0e[2c0=J`/`<0ZGfT00@0
aiBQ0?75Y03aaJ@0lLFT0`3BY:P20=6NXP<0^HFN0P1mEi/206e@W`<0K4bJ0P1`EZ@30;9oW@<0U6^Q
0P1QBj4306IT_00306P0002SMZ40XgJQ00@0/9W000@0k_>N059C]@000000hJnS0P34Yk`01P31fVP0
Xic=0:>Lc@2SW<d0gkF/09ej[0<0U7N`00@0Sgbj0;:@/P2bT;80^K3@0`2nU:/308N<d@0605eU`P2d
OYT0]7jI0;AnV@3mfG/0nn>W0`2>Tm<30:MlY080SVn[0`2?N[P30;>?/@030:n2Y02fTk@0]Y>d00T0
oooo00<000000?ooo`3oool0B`3oool003T0oooo0`00000D0?ooo`030>Jo/03H[J`0f:f/0080/hFT
00<0IT^M0<^U/P3;YK800P3;YK8206EK/`80KfVk0P1;DKL20<fS[@<0fk>_0P3AZJl00`0005/0kmVk
0>oI^`040=C5b`@0/I_10`3@Zk<20?O_Z@@0/hJU102hQIh209UbY@0409aeYP3[l/d0jo;=0>_bc@80
HUZd0P3`h[l01@272@00ZKkY0:Vnj@29Rll0__c300<0anG/103O[Z@309O9n@<0ZIC00`2[T;X01@0C
>kT0ajFg0<NU]`37YKL0N6F`00<0/Xb^0`3Sflh00`37Z;/0f_k108o>o@0409Qh[P<0/h6M00<0bY:J
0:mjV02_NYP00`2WM9X00`000000iN_D0>G[e00305m1UP80XG>O0`2ELJP00`2`RZh0jl2X0?c;S@02
0?c;S@80gZnU00D0cYJJ0?kBT@3ndY40o]:A0:mmWP020?c<S`80[hR/0P2SOZ`30;24YP80WXZn0`1S
@I<01@3U]J<0cIJK0<fFV`3=UY/0nmVQ00<0f>cR0P2bWl@30;2dg0040=Z`[P35UjL0aINW0<FGY`@0
Tf^R0P2`Sk@30<VN[@80/XVZ0P3:WZ/00`3AZJl0e[2c0=J`/`030:UmY0@0lLFT00<0fLC50=:TZ03B
Y:P00P3AWZ830;V5WP80OENK0P1]D9l306a<VP<0L5JT0`2bOid209A[X@<0HD^Q0P1VI;`206P00080
SG6_0P2`VL020>kcWP8000000`34Yk`20<7JJ080Xic=0P2MNZ`309Ag/0<0/Y2b102nU:/01P3edJX0
Lfjn07=^_P1MIL80<V?C0;AnV@80oMUk00@0nn>W08jCd`2>Tm<0SY?C0`2WO:@208i_Z`<0SgZh0`2c
Sk440;JC]0P0oooo00<000000?ooo`3oool0B`3oool003H0oooo0`0000030?ooo`030000003oool0
oooo0100oooo0`3V_k000`3H[J`0/hFT0;>5Y00206I;W@<0bjFb0P1UFk<206mY^`80Be6g00<0cJ>]
0=^c[`3K/jl00P3K/jl308kBoP0307j^l`1COml0DgoO0080e<G;0P2cWl@30;6K`@060>;Gc03@Zk<0
d:^c0?O_Z@3:Zk/0h:fQ0`2cQZD0103N]Jh0^8FN0;R5WP2hQIh209UbY@@0jo;=00@0HUZd0?3R_`3`
h[l0l]:`0P2=JJ@20:Vnj@80Y:WK0`29O;h30=n^Y080X8^m00@0UlWi0:VD`02YU<00ZIC00P2[T;X2
0:n</@0301<k^@37YKL0ajFg00<0/Xb^103Sflh30;S6i00408o>o@2HN:h0V7R^09Qh[P<0/h6M00<0
bY:J0:mjV02_NYP00P2WM9X20:G]n0030<;2fP3Ujm@0Gd6F0080Gd6F0P2QLil309EaZ080jl2X0P3l
bhd30=j_Y@060<jFVP3ndY40o]:A0?kBT@2_OIh0o<b?0`2_R:`20:=n[0<0/8BV00<0hL>i09j:_P1S
@I<00P1S@I<40<fFV`030>WNK`3;hG@0bn5d00@0/Yo40P2`]=`40<FGY`060;Z3V@2CJj80Tf^R09=[
XP2`Sk@0cYnW0`39WZd0102bRJX0bYj[0<ZNZ`3:WZ/40=J`/`80ZGfT00<0k>?70?75Y03aaJ@00P3I
a<D0103BY:P0dIjR0=6NXP3AWZ830;V5WP80OENK0`1]D9l206a<VP<0L5JT0`2bOid209A[X@<0HD^Q
0P1VI;`00`0006h0J00008ea[`0208ea[`<000000P1BDkD00`000000a:Nl0<7JJ0020<7JJ080/Xnb
0P2MNZ`209Ag/080/Yo40P2bT;801@2ePil0_YB[0;jDZ`2nU:/0mM6Z00<0Lfjn00<0<V?C0;AnV@3m
fG/00P3khjL308jCd`<0YgbT00<0SVn[0000000000000`1[`_h308fIf`<0]Y>d2@3oool00`000000
oooo0?ooo`1:0?ooo`00=03oool2000001T0oooo0`3V_k030;>5Y0<0IT^M00<0bjFb0<6W`031Yl00
0P1gM/D0101IN]P0Be6g04]A]`3=Xjd40=^c[`040>;1]`3K/Zh0Offd07m]]0<0DgoO0`2cWl@20;6K
`@80h]O<00D0d:^c0?O_Z@3:Zk/0bZ^k0>2]X@030;>6Y@040=je[P2hQIh0^8FN0;R5WP<0bM_W00<0
kmZl0<NW^@37YkT00P3`h[l00`2IMZ/0l]:`08eYY00208eYY0040<nOY@00C<T0Y:WK0:BYf`80RGbn
0P3O[Z@30:2;_@040;>5X`2GbOT0ZIC00:VD`0@0[hba00@0FTRS0::9^`2RRK/0XXVk0P2bS:h0102Z
R[<0J5:U06QBY@3Q^Jh20;S6i080^ZW80`2HN:h20;>1W@80bY:J0P2_NYP20:MdVP<0`/;J00@0iN_D
05m1UP1O@IH0Gd6F0P2QLil209EaZ080Wg6M00<0jl2X0?c;S@3lbhd00`3N[jD01@3>UYX0o]:A0?kB
T@3ndY40o<b?00@0[hR/0P2SOZ`20;24YP80hL>i0P2NR[h206=1T`080?O/V@3=UY/0cIJK0<fFV`3Y
gVl0bn5d03dmY`0:00420;:Oa080_I^f0P29GIT30<FGY`060;Z3V@2CJj80Tf^R09=[XP2`Sk@0cYnW
0`39WZd40<ZNZ`050>:k[`3F/;<0e[2c0=J`/`2YOJ@00`3/hlL30=W4a@040=:TZ03AWZ80dIjR0=6N
XP<0^HFN0`2LPkL206e@W`80K4bJ0`1`EZ@30;9oW@80U6^Q102PS/400`0hK]X0001^06P000030000
00<0k_>N0P1BDkD010000000a:Nl0?oFP03]^9X30;:?/P80WGZ/102bWl@20;:@/P030;F3W`2nU:/0
_YB[0080mM6Z0P1cK[h20<Vba0050;AnV@3mfG/0nn>W0?_SY`0000000`2>Tm<20:MlY0<0YW^T0`2S
Rk/308fIf`80]Y>d0P3Vo<D90?ooo`030000003oool0oooo04T0oooo000b0?ooo`8000006P3oool4
0>Jo/0030<>GZ@2cQJ@0/hFT00<0IT^M0`31Yl0307Mfa@0305Ujf012K=H0fk>_00<0fk>_0P3R`KL0
1@3K/Zh0Offd07m]]01oKK@0R7:d0080Hl7m0P2cWl@01`2aVl40h]O<0>;Gc03Rel`0d:^c0:;Oo03:
Zk/00P3P[J420;>6Y@80g[F^0`2hQIh20?[TZ@030?O_Y037YkT0ajNi0080ajNi00<0VGJ[0?;B/03b
d[000P2=JJ@20<nOY@0305m9X02mc>D0_LcU00<0RGbn00<0gjjT0:2;_@2PRkd00P2cQJ<0101]BiP0
YJ;C0:FRd`2UX]<30:n</@80FTRS0P2RRK/20;:<[P030:Z:/`1XDZD0J5:U0080hKV^102jZLP209Qh
[P80/h6M0P3:TYX20:mjV0040:MdVP2hVKL0k/Z^0>k:[P80`/;J00<0iN_D05m1UP1O@IH00P2QLil0
102ELJP0Wg6M09maW@2OLId20?c;S@@0gZnU00<0o]:A0:JZf@2VZ]T00P2VZ]T0103Oc<D0[hR/0:n8
[02_R:`20:=n[0060;24YP3Q`kT0hL>i0>73^@2=P<40WXZn0P1S@I<01P3gk9T0cIJK0<fFV`3=UY/0
`I2S0?gIV`80?CfW00@0/Yo40;fK]P2mVkH0_I^f0P29GIT20<FGY`80^X>I0`2CJj830<jOY`80bIj]
00<0_inh0<ZNZ`3:WZ/00P3R^jl30=J`/`030:UmY03/hlL0k>?70080^IJc0P3Ia<D40=6NXP80^HFN
0P2cT;8209b3]`040000N@1]D9l0K4bJ06a<VP<0L5JT0`2bOid30:V<]P<0X8k10`00000208ea[`80
fnOM00<0]=mh07=lc@1cO<d00P1QRn@00`000000omJ00>fhVP030;:?/P<0^Jo?0`2bWl@01@2bT;80
]H>O0;F3W`2ePil0_YB[0080mM6Z0`39//@01`3^bjh0]7jI0?_SY`3khjL0VVfN09IaY`0000000P2>
Tm<20:MlY0<0YW^T0`2SRk/208Ma/`0508fIf`2fTk@0i_c50>Kla@2jn[l00P3Hf]T70?ooo`030000
003oool0oooo04T0oooo000b0?ooo`<00000603oool40>Jo/080`iNY0P2cQJ@206I;W@80aZJj0P31
Yl0307Mfa@80FG[H00<0@VcF0=^c[`3K/jl00P3R`KL30=^b[P80Offd0P28L[@00`1S`Od0/io40;>O
a0040>;Gc0030:;Oo03:Zk/0bZ^k00<0h:fQ00<0/hJU0=je[P3N]Jh00`2hQIh20?[TZ@80dJnh0`37
YkT00`2IMZ/0l]:`0?;B/00208eYY080cinU0`1OBJ001@2mc>D0RGbn08Ul_P2NT/L0X8^m00<0/hFS
0P1]BiP20:FRd`<0[hba0P1JB:<20::9^`040;:<[P2ZR[<0ZXZc06QBY@<0hKV^00@0n]jX0;ZYb02j
ZLP0YgZS0P2HN:h20;>1W@80bY:J0P2_NYP20;RI]`80k/Z^00<0nNb/0<;2fP3Ujm@00P1O@IH20:5c
W`@0Wg6M0P37aT@00`3gl:`0gZnU0=j_Y@020;27Z@030?[OP02VZ]T0YZ[I0080glc50`2_R:`20:=n
[0@0hL>i00<0d;Bo09j:_P1S@I<00P3gk9T20<fFV`030>WNK`31T:<0oMVK0080?CfW102mVkH308UM
V@030<FGY`2jPiT0^X>I00<0Tf^R0`3>WjL00`39WZd0_inh0;nO^0020<ZNZ`80h[^_0`3F/;<20>cS
a`<0^IJc0`2KOk<30=6NXP040;V5WP2cT;80/i2b0;>@/P80W8>g0P0007T206a<VP<0L5JT0`2bOid0
0`3cg[P0ZHbf0:V<]P03000000040;2<[`1XH[T0J6:i08ea[`80fnOM0P2dggP307=lc@040>B]V`3o
eX0000000>fhVP@0YZOF0P2i[ll30;:Oa0050;:@/P2ePil0]H>O0;F3W`2nU:/00P3edJX0103Vl]<0
bK;40<Vba03^bjh20;N3W@80VVfN0P2FLJL0103?UiX0SY?C0:MlY01eE9d30:IkY0<0Xh^k0`27LK<0
0`3Vo<D0^_Zo0;kgkP040=SJf@D0oooo0`00000;0?ooo`@00000103oool4000003<0oooo000b0?oo
o`<00000603oool00`3/hLH0i[n`0>Jo/0030<>GZ@80/hFT00D0IT^M0<JV^P36Y[X0aZJj0<6W`002
0:jE_@<0WjOL0P0nQNT0100QLn80h/6g0>;1]`3R`KL30=^b[P80Offd00@0R7:d0=:`]`3B/;L002Va
0P2YS;H308=RX`<0bZ^k0`3P[J400`2cQZD0g[F^0=je[P020;R5WP80n^BY0`3A[kP30<NW^@<0l]:`
00@0SFVT0<nOY@3?WjD0cinU0`1OBJ00102^OIh0OEbQ09jBa`2NT/L40;>5X`80KD^H0P2UX]<30:n<
/@80FTRS0P2RRK/0102bS:h0ZXZc0:Z:/`1XDZD20>6i[P80n]jX0`2WNZ<209Qh[P040;>1W@3:TYX0
bY:J0<ZBVP80[gZH00<0^9Vg0>k:[P3^bZh00P3ik:`01032`]X0RV:N05m1UP1O@IH20:5cW`050?G/
^@2OLId0Wg6M09maW@37aT@00P3gl:`0103N[jD0/8NY0;27Z@2`QjT20?[OP0<0glc50`2_R:`30:6C
a@80hL>i0P2OLIh00`3@];l0Hd6C0?O/V@020?O/V@070<fFV`31T:<0`I2S0?gIV`3=WZL0?CfW0000
Q0030;fK]P<0REfI00<0aINW0;Z3V@2jPiT00P2CJj80102efg00cYnW0<jOY`3>WjL30;nO^0050<ZN
Z`3R^jl0h[^_0>:k[`3XbKL00`2:W^440;VF/`030=nh/02KOk<0Vgnc00<0dIjR102cT;8209b3]`04
0;F9Y`0007T0K4bJ06a<VP<0L5JT0P2bOid20??N^0800000102`S:l206QR^@80fnOM00@0kOK60<nM
XP34/bP0nn><0`3T[I/0103oeX00kKRJ0000003SgF/30:JWeP80^Jo?0`2bWl@40;F3W`80mM6Z0P3V
l]<00`39//@0k/^^0>k;[P020;N3W@<0VVfN00<0UW6W0<nGVP3?UiX00P1eE9d30:IkY0040:ihV02<
Kjh0S6n^08a_[P80Ug2U0P1CB:P203M6]@<0f=[I203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0`0?ooo`00
<P3oool010000000oooo0?ooo`00000F0?ooo`<0k>761033UjT20;>5Y0@0aZJj102^UKd209nWg080
?XGY0P0QLn820>;1]`<0fk:^0P1oKK@00`28L[@0d[2g0=:`]`030:V<]P<0Pf:S00<0c9VR0<Z[^`3P
[J400`3P[J430=je[P80^8FN0P3ji:T30=6_^0@0R9OK0P3bd[00102=JJ@0cinU0<nOY@3?WjD205m9
X080[WfN0P1mG:4208UTXP<0/hFS0P1]BiP00`2XbeH06ecC0:n</@020:n</@80FTRS0P2RRK/30:Z:
/`0306QBY@3Q^Jh0hKV^0080n]jX00H0j>7;0:MjX`2WNZ<0YgZS09Qh[P2cPId30<ZBVP80[gZH00<0
^9Vg0>k:[P3^bZh00P3ik:`01@32`]X0RV:N05m1UP1O@IH0XG>O0080mNbi0`2OLId00`37aT@0mo2/
0?O`[0040;27Z@80n]n000<0gkbe0=o<a@3Oc<D00P2_R:`20;ZQ_`<0XI?5102OLIh01P1S@I<0mnbI
0?O/V@3gk9T0cIJK0<6@X`80oMVK00<0cIjW03dmY`0008@00`2mVkH308UMV@<0^X>I0P2CJj840<jO
Y`030>Bk[02oWkP0_inh00@0h[^_0P3XbKL30;2I_`80^IJc0P3O^;0309]o/`80dIjR00D0_iR`0;>@
/P2cT;80/i2b09b3]`020;F9Y`040001SP0007T0SX;108j2`@80L5JT00@0/WnM0000000000000000
0P2YS;H0102VNj@0/8b_0;2<[`2`S:l306QR^@060>gfaP3?WJ80cifR0?_SS02cWl@0l/j[0P3T[I/0
103oeX00kKRJ0000003SgF/30:JWeP<0Z<cc0`2@O[`30;F3W`040000003Vl]<0i_;C0>Kbd`80k/^^
0`2gPid309Y]WP0309IaY`3?UiX0ciNJ00<0MEBM0P2VNj@01@2^N9P0S6n^08a_[P2<Kjh0aiVX0080
Ug2U00<0DdRX03M6]@0gA[D0102SU/L70?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0300oooo000V0?ooo`@0
00001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo0P3/hLH20;bO^`<0
`iNY00<0/hFT0;RH]`2hV;L00`36Y[X0102hSj`0[YFm0:jE_@2^UKd30:b[eP80Lf6_0P1[Jl430=^b
[P80c[6n00<0OVjf0=:`]`3B/;L00P3eejh20:V<]P<0Pf:S00<0c9VR0<Z[^`3P[J400`3P[J40103i
iZl0g[F^0=je[P2hQIh20?[TZ@050<:Z`P3A[kP0dJnh0=6_^03;Z[P00P28Um/20;:A]00307AEX03?
WjD0cinU0080cinU00@0GdVP0:imWP2^OIh0[WfN0P1mG:4208UTXP<0/hFS0P1]BiP20:S;EP0409SW
XP38b=X0b<SJ0<S8fP80Ei?]0P1oNL<207Yja`80hKV^0P3jgZP20>SQb`<0YgZS00<0ETbZ0<ZBVP3:
TYX00P3:TYX0102_NYP0OG6k0>k:[P3^bZh20?W/[080UhW200@0RV:N05m1UP1O@IH0XG>O0P3ek;T3
09maW@040?O`[02[^^@0Zk[T0:^ji0<0/8NY00D0n]n00=nl]@3O_;D0m_2T07iUZ`040;ZQ_`80XI?5
0P2WO:D309maWP070?K8V`3Q[j80iKZZ0?O/V@3=UY/0`I2S0?gIV`020<fNY`030:j7[00008@00024
0080_I^f0`29GIT01P3kj9X0^X>I0;Z3V@2CJj80^l4o0>k6Z@80cYnW0P3T^j`00`2oWkP0d_;W0=;b
i`020>:k[`<0j<Vg00<0e_:H0;2I_`2`VKl00P2iU[<20=nh/0<0Vgnc00<0dIjR0;nH/02oV;000`2c
T;840;F9Y`030000N@2>P/40SX;100<000000`3cg[P00`2YS;H0YW^T0:IkY0030;2<[`80J6:i0P36
h^d01@3Ge]L0cifR0;>Oa02cWl@0l/j[0080i:fK00D0omJ00>fhVP3]^9X000000:OXV0030:RagP80
Z<cc0`2@O[`30;F3W`80emOH0`2Y_^P40;N3W@<0VVfN00<0UW6W0<nGVP3?UiX00`1eE9d00`2VNj@0
[WRH0:ihV00308a_[P040<NIZ02GL:D0Ug2U08MVY`<0=dJe0`2SU/L00`0g01P0oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0<03oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`070000003oool000000?ooo`3CP6l0oooo0000000C0?ooo`030>cQaP2lWk/0_9nk0080_9nk0`33
UjT40;RH]`030<JV^P2hSj`0^8n/00<0[YFm00<0el?70:b[eP2/ZmH00P1cHJl306][`@040=^b[P3>
/Kh0c[6n0<ja_P80OVjf00<0d[2g0?GG[P3eejh00P2YS;H208=RX`80c9VR103P[J420?WV[`80g[F^
00<0^8FN0?[TZ@32Z/800P32Z/80103A[kP0bjZh0<^Z^03;Z[P30;:A]080M5FP0`3?WjD40:imWP80
OEbQ0P29I:830;>5X`0306e;V03Rakh0h/Nn0080l^Ro0P38b=X20;VN_@0305NCk@1oNL<0OgW300<0
NW[700<0hKV^0?[NZ03jgZP00P3XhL/20:MjX`030>k1Y@1FC:X0ETbZ00<0bY:J00<0[gZH03jljP0n
_>X00P3ik:`00`160000k?3;09N9`P0208YRWP04091PUP3ek;T0mNbi0?G/^@80Wg6M00<0Pg_206QY
`01XJL000P2[^^@20;27Z@030?[OP03O_;D0gkbe0080m_2T0P1nIJ/30;ZQ_`@0YgbU0`2OLIh00`3f
b9/0hJnR0>FjZP020>FjZP030<6@X`3mfI/0cIjW0080cIjW0P0008@20;fK]P80REfI0P3kj9X20;Z3
V@030;_1?`3^aZT0k/JY0080cYnW0P3T^j`40=;bi`030>:k[`3XbKL0j<Vg0080e_:H0P2`VKl0102i
U[<0gkR`0=nh/03O^;0309]o/`@0_iR`00<0/i2b0;nV_`2oY[l00`2eRJL300000080DDRY103cg[P4
0:IkY080/8b_0`36h^d20=OFe`030<nMXP2cWl@0l/j[0080l/j[00L0i:fK0>fhVP3]^9X0hme[0:OX
V0000000YnRH00<0`/KN00@05e7;0:S<l`2@O[`0T7jl0`2ePil00`3GemP0/HFV0;65YP0309QbY`<0
]h>M0`2JKIh30<nGVP<0MEBM00D0YW^T0:ihV02^N9P0[WRH08a_[P020<NIZ080Ug2U0`27IZL00`0g
A[D0XiK70:>Fa`030729g0L0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`009@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000030=>0K`80oooo00<000000?ooo`3o
ool03`3oool20=:maP040=Vd]02lWk/0_9nk0;bO^`80`iNY0P34Z;h30;RH]`@0^8n/00@0[YFm0=O3
a`3G`lL0el?70P2/ZmH207=Q[`80Jf_1103>/Kh207i^]P<0mMN^0P2YS;H208=RX`80c9VR00@0oN6A
0>2]X@3P[J40h:fQ0P3iiZl206j>h@80_jK00`32Z/840<^Z^0030>79`02bTK@0/Y6d0080M5FP0`3?
WjD0102WMY`0[WfN0:imWP2^OIh207eLX@80RFBR0`2cQJ<01@1]BiP0h/Nn0>;7_P3bj;l0gocB00@0
^Ijm00@0IF:j05NCk@1oNL<0OgW30P1jN/L20?[NZ0<0j>7;0P2WNZ<00`3^`JD0ETbZ05I<ZP030<ZB
VP030:mjV01`S=h0L8cN0080RJCV0`3/l</208YRWP<0T62F0P3ek;T0102OLId0Pg_206QY`01XJL02
0:^ji080/8NY0`3O_;D20?K`Y0<0OVF[00<0^Z6o0;^U``2kYL<00`2WO:D209maWP80m/RK103U^ZX0
0`31T:<0cIjW0<fNY`020<fNY`<0002400<0_I^f08UMV@29GIT00P3kj9X20;Z3V@040;_1?`3^aZT0
k/JY0<jOY`<0i;^/00@0m^ne0=;bi`3Bl^L0d_;W0P3XbKL30=KbV080/9Vo103O^;0409f5^@<0_iR`
0`2oY[l3000000040001SP2>P/40SX;108j2`@80DDRY102AI9X30:IkY0040;2<[`2eSjh0]Hn^0;F?
[P<0emKG00<0cifR0;>Oa03bcZ/00P3bcZ/20;JD]0030>fhVP00000000000080000000<01iW40<;6
gP32a]h00P0GDL/3091n_0030;F3W`3GemP0/HFV0080/HFV00<0ik:M09QbY`2HLZL00`2gPid309Y]
WP030:QcV03?UiX0ciNJ00<0MEBM102^N9P00`2<Kjh0aiVX0<NIZ00309M`Y@<0QfJW0P1iHjh40:Vn
j@H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0<03oool002D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0omB70080dh1_0`3oool2000000h0oooo0`3B_LH01@3I];@0
_9nk0;bO^`2lWk/0`iNY00<0a:Rn0P2hV;L20<>Q]@<0^8n/0`3G`lL20=KIfP030:b[eP1cHJl0Lf6_
00<0UMCm0`3>/Kh01@1nK[H0]9Zm0;BJ_@2dV[d0a9>S0080ZHbf00D0Pf:S0<bIXP3<VJ80c9VR0?gQ
T@020>2]X@80nNJ_00<0e][J06j>h@2oY/000P2oY/020<:Z`P80b;G80P3;Z[P20>79`080/Y6d0`1d
EJ000`3?WjD0YgJL0:MfW0030:imWP80OEbQ0P29I:830;>5X`80h/Nn0P3bj;l20:N[f@<0^Ijm0P1U
H[X207mi``80Tgji0P2ZT;X20;fcd0040>SQb`2WNZ<0YgZS0>k1Y@80ETbZ0`3:TYX20:I_U080L8cN
103/l</0103LL`00RV:N091PUP2@H9H20>kH_0030?G/^@2OLId0Pg_200<0J6W00P2[^^@00`2`QjT0
NG_80=nl]@030?K`Y0<0OVF[0`2kYL<30:MlY@80Wg6N0P3fb9/0103]a:T0iKZZ0>FjZP3U^ZX20:fB
^`<0cIjW00D0`LCM0>?Mc`3SgLl0_I^f08UMV@030?_XVP80^X>I0`3^aZT30>Bk[080m^ne00@0]I>c
08f1`@2=PL40SH710P2ZS[P00`063Xd0;P0@0:GFn@020:GFn@80gkR`0P37[l8309f5^@80_iR`00@0
_YVa00000000000000000`2eRJL01@3Vb[X0006>03QA`02>P/40DDRY0080d/G>0`2AI9X30:IkY0@0
]Hn^00@0nmRO0=OFe`3Ge]L0cifR0`3bcZ/30;JD]0060>fhVP1SCjD0HdnU089[/000000004Bd0`2V
Y]H209ZAb@80T7jl00<0]H>O0;65YP2aQJH00P2aQJH00`3W/Yd0V7:W09QbY`030;N3W@80VVfN0P2X
LiP20<nGVP@0U7:Z0`2^N9P40<NIZ080Ug2U0`27IZL00`1iHjh0^9Vg0;RI]`040:NWePH0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0<03oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0omB70080dh1_1@3oool00`000000oooo0?ooo`0:0?ooo`<0d[g60`3I];@2
0;bO^`@0a:Rn00@0^9Rg0<>Q]@33XKD0`j6e0`2hSj`00`3?Yjl0e]WJ0=KIfP020=KIfP03000Z/P2R
UlX0XYO:0080XYO:0P2Ee?d20<ja_P<0]9Zm0`34Tj<0102YS;H0Pf:S0<bIXP3<VJ830?gQT@040>2]
X@3iiZl0e][J0=KJfP@0_jK01038]LP0103;Z[P0hLW00>79`03QbL020;:A]0<0M5FP0`2WMY`30:im
WP80OEbQ0P29I:8200000080h/Nn0P3bj;l00`2mYL80Yj_I0:N[f@030;VN_@0306ER^P3HaLL0f<G7
00<0Tgji00H0ZY2j0<S=g@38cMd0_K?@0>SQb`2WNZ<20>k1Y@80ETbZ0`3:TYX20:I_U0030=O2?`2i
[/h0^Jk>0080^Jk>0P1AYoP00`2:HYh0T62F091PUP020>kH_0040?G/^@2OLId0PGBl085d_0<0RfRU
00@0Zk[T0;27Z@1iNlP0gkbe0`3fl:@207iUZ`80_oc50P2kYL<30:MlY@80Wg6N0P3fb9/00`3]a:T0
iKZZ0>FjZP030:fB^`<0cIjW103SgLl01029GIT0nnRJ0?_XVP3kj9X20;Z3V@<0k/JY00H0dkRo0>Bk
[03T^j`0m^ne00H>SP2M3@0308f1`@80ZXjh00<01Pj=02h0401BD;800`2Ue_T30<N_`P<0WHFi0`00
00000`2nVK40_jJo0;nV_`020;F9Y`80i/Zj00<0?cNP03QA`00hDL000`3BaLh3095TVP<0YW^T00<0
e:Z^0;F?[P2eSjh00P3kf9l01P3kgj@0mn2a0?OP/@2kW;T0l/j[0?KQ]0<0]YBd0`1SCjD2089[/004
00000000A;@0YZKF0:JVeP<0VY7900<0T7jl0;F3W`2[S[L00`2aQJH00`3W/Yd0V7:W09QbY`030;N3
W@0409Y]WP2XLiP0Z7>H0:QcV080ciNJ00@0]hJQ09AbZP2DLZX0U7:Z0`2^N9P0103fcE`0aiVX0<NI
Z037VJP209M`Y@<0QfJW0`2hVKL0103cfKD0YjOF0:NWeP2WYmH70?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300
oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000030?oD
Q`3CP6l0dh1_00H0oooo00<000000?ooo`3oool02@3oool00`3J_K`0d[g60=:maP030=Vd]0<0UWF[
0`34Z;h40<>Q]@80^8n/0P3?Yjl20?;A[P80e]WJ0P00:[820::GbP80a::f00@0IE^c09b5^P2LQKX0
W8Fj0P2dV[d0103DWil0a9>S0<BCX`0006430<bIXP<0oN6A0P3SdL@30:W3k0<0_jK000@0gN?I0<Re
b038]LP0b;G8103QbL020;:A]080M5FP0P3@c=H20:MfW0<0[WfN0P1mG:430:gQn@80gNSL0P3bj;l2
0;fU`P<0Yj_I0P2iW[d40=S5a`80Tgji1038cMd01P2m/m00YgZS0>k1Y@3^`JD0k]2d05I<ZP80bY:J
0`2VKi@0103G`Sl0o>JJ0;V^cP2i[/h20<bd``03056Wn00C7IT0T62F0080k]Rl00<0dj>V0>O<^P2O
LId00P21M;`308]XY@04040lYP1iNlP0NG_809KWn`80^9Vh00<0EU2^0;ola@2oo<D00P2oo<D30;^U
``80YgbU00<0Wg6N0?K8V`3fb9/00P3]a:T20?3>[P030?kPU02]T[/0[I:k0080cIjW00<0nNbP0;7X
S`2aj8l00P3SgLl40?_XVP040;Z3V@3^aZT0k/JY0>k6Z@80dkRo00P0i;^/0?K_]@3M/Z`01Pj>0?[N
Z@2eTk<0SH7103h0>@<0ZXjh00<01Pj=059@/P1BD;800`1lK;D20<N_`P<00000102nVK420;nV_`04
0;F9Y`3Vb[X0i/Zj0>K:^P80?cNP0P0hDL020=;5cP<0TFBJ0P2VNj@20=BZ[P80]Hn^00@0nmRO0?_O
Y03gh;40mn2a0P2kW;T00`3>i7T0m^6d0;JD]0020;JD]0<0HdnU0P22Jk00101DBJP000000:JVeP2V
Y]H409b0/`80Zhjg0P2aQJH20>NbW@<0V7:W0P2gPid40:QcV0030<nGVP2gQZ40]hJQ00<0U7:Z0`2^
N9P0103fcE`0aiVX0<NIZ037VJP209M`Y@@0WH>f0P2hVKL0103cfKD0YjOF0:NWeP2WYmH60?ooo`80
0000203oool3000000<0oooo1000000c0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo0P000000103oool0omB70=>0K`3CP6l70?ooo`030000003oool0oooo00L0
oooo0`3J_K`30=Vd]080^HjX0`2FMJ/00`34Z;h0/Yk30;:N``030<>Q]@030;R?[03?Yjl0cjN_00<0
l]6^00D0n>Ja08NKg`27Vml002Zb0::GbP030<BR]P80IE^c0P2LQKX00`2dV[d0/Yk40=BOW`030<BC
X`030000H@3<VJ80c9VR0080oN6A0`3SdL@20>KCa080ZL?/00@0_jK00=gSf@3MhmT0gN?I1037j>d3
09j:_P030;:A]01dEJ00d<cF0080d<cF0P2WMY`30:imWP040=fg/@1VN=40IWSA06Ihd@80gNSL0P2I
Nk00103>XJT0_JG20;fU`P3Ri=@207:BhP<0Z9c90`3HaLL30:Vmj080M>?K0P37n^P30>k1Y@040>k@
]01FC:X0bY:J0<ZBVP<0YVnD00<0el8o0?cVVP2i[/h00`3<]<<01@1AYoP04afI0>kH_03^f;`0dj>V
0080ilbj00<0a9NX085d_021M;`00`2;J:D2040lYP@0^9Vh0`1FD:h00`3F/kH0>FcI0;^U``020;^U
``80YgbU00<0Wg6N0?K8V`3fb9/00P3]a:T20?3>[P050?kPU02]T[/0[I:k0<fNY`3ik:000P2nan42
0<Fcb00309RBc00J0000b:Rj0080nnRJ00<0^X>I02MGc00WEl`00`3C^;l0101ECjl0gK:/0=fb[006
3Xh30?[NZ@050<bT/02ZS[P0ZXjh0:Z>^0063Xd00P1BD;8207a/]@<0000000@0ajo20:6Aa02QTL@0
XI740`2nVK400`3BkXd0IXGM0>K:^P030>K:^P80?cNP0P0hDL020=;5cP<0TFBJ0P2VNj@20=BZ[P05
0;F?[P3kf9l0nmRO0?_OY00000P00`2kW;T30?KQ]0030;JD]02DKJ<0HdnU0080HdnU0`22Jk001000
0000E4VX08mh]@2?N;D309b0/`80Zhjg0P2aQJH20>NbW@<0V7:W0P2gPid01@32Uj/0Z7>H0:QcV02X
LiP0ciNJ0080]hJQ0`2DLZX30:ihV0040?K=G037VJP0aiVX0<NIZ0<0Wgn`0`2MPkH0102hVKL0lmVe
0??I]@3J`L030965``<0oooo0P0000020?ooo`030000003oool0oooo0480oooo000U0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?oDQ`3oe8L20=>0K`03
00009`3oool0oooo00D0oooo00<000000?ooo`3oool01@3oool40=Zm_0030>G@`P3I];@0^HjX0080
^HjX0`2FMJ/30;:N``<0`j6e0`3?Yjl20?;A[P80n>Ja0`2XR;@40<BR]P80IE^c0P2LQKX00`2bW/@0
e9nO0=BOW`020<BCX`030?70W@000640c9VR0080oN6A0`3SdL@20>KCa080dk[200<08HOZ0=gSf@3M
hmT00`2TW]0409Ul/@80WXZn00<07E?;0=3<eP3@c=H00P3@c=H20:MfW080[WfN0P3M]k4206Ihd@80
M]^[0P2INk020<jQZ@040;fU`P3Ri=@0h^CD0>;Te080LY;R00<0Z9c90=SGe`3HemL00`25/?440:n`
f080k>W:00<0eKJk05J3hP3^d;@00P3^d;@00`3:TYX0YVnD0:I_U0020:I_U080o>JJ0`3<]<<20=jk
]P804afI00D0dj>V0>O<^P3Wc;X0ilbj0<BGZ003085d_080RfRU00<0@3bV0>3Xf@3Pj=T00`2hVKP2
05I@[P80e[>f0`0iK=T01@2kYL<0YgbU0:MlY@2OLIh0m/RK00<0kLBY00<0l<j^0?kPU03nh9@00P2]
T[/00`3ik:00mnZc0<Fcb0030<Fcb00609RBc03Fal`0b:Rj0:FNcP3kj9X0^X>I0`1RQ=h20=>h_`03
05E?[`3M/Z`0gK:/0080n]jY0`2QS/4209Yk/0040:Z>^0063Xd01Pj=059@/P80000000<0O6be09Uj
[`2INZl00P2INZl20:6Aa080_YVa0P3BkXd306J5g@80i/Zj0`0o=j0208AY[0050=;5cP2AI9X0TFBJ
095TVP2VNj@00`3DZZh0102eSjh0nmRO0?_OY03kgj@20=?3b`030;^L^@3>i7T0m^6d0080m^6d00<0
]YBd0;2H_`2`V;l00P1dKKd3089[/00405A9Z0000000SgRe08mh]@<0W82c0`2[S[L00`2aQJH0ik:M
0>NbW@0309QbY`030;N3W@32Uj/0`YN[00<0Z7>H102gQZ4209AbZP<0[WRH00<0m/eL0:^=]P2[SKH0
0P2[SKH209mo/0<0WH>f00@0^9Vg0??I]@3J`L00f/700`2AQL<80?ooo`030000003oool0oooo0440
oooo000V0?ooo`@000001P3oool010000000oooo0?oDQ`3oe8L20=>0K`0300009`3oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool40=Zm_080iM32102iSZP209IeZ`80^H^V0P2bW/<20<>Q]@80
Zhjh00@0cjN_0?;A[P3bdJh0l]6^0P3hi[401032Z/80Z8Rd0:R8]02XR;@30<BR]P80IE^c00<0W8Fj
0;:Na02bW/@00`3DWil01@34Tj<0lL2M0?70W@3<VJ80oN6A00<01QfO0P3Vdl@30=>j`P040=Ri^P29
KZh0RFj^08U^[P80Y9k@00@0_IVb09Ul/@2IO;40VGba0P2NR[h301eCb`80d<cF0P2WMY`20:imWP80
gKNa00@0^N1h0=k4_P3Na;h0g/Bn0P2INk020<jQZ@<0h^CD0P2NOk400`00HLL0f=OG0=SGe`020=SG
e`<0SY7B0P2_/=P20>cYbP80eKJk0P1FPn830<F_a@<0YVnD00@0el8o0?cVVP3liYX0in3;0P3<]<<2
0=jk]P80L5ZY103Wc;X01034UjP0i_;C085d_021M;`208]XY@<0h>SI0`2hVKP01P1FD:h0e[>f0=Jc
]P3F/kH0fkRf0=VWXP80S8W;0P2WO:D20?K8V`80kLBY0P3`cZh20?kPU0050?[TZ@3liYT0m_2/0?OZ
/`3Ylll00`35/lP40=K7c0030;?6j02jPiT0HXCN0080HXCN00<0dkRo05E?[`1ECjl0102KNZd01P3X
^jL0XHk10:6>`@2JNk00c:B`0>?8_0<0000000@0DU2b07a/]@2aVl40/I_10`2INZl20:6Aa0040;jI
/@3BkXd0d^j=0=;^S@@0SG>a00@0i/Zj03lgX00o=j00?cNP0P24JJ`20=;5cP80TFBJ103DZZh20?_H
W`80nmnT0P3C`l/00`2kW;T0m^6d0?KQ]0020?KQ]0<0/9Ro0`1dKKd204e`e080E4VX00<0000008mh
]@2?N;D00P2LP;<30:^>]`030;65YP3W/Yd0ik:M00<0V7:W00<0]h>M0<:GZ`32Uj/00`2XLiP0103d
d640]hJQ0;N6X@2gQZ4209AbZP<0[WRH00<0m/eL0<cII@2[SKH00P2[SKH209mo/0<0WH>f0P3cfKD3
0=[1`080THG3203oool00`000000oooo0?ooo`110?ooo`00<03oool200000080omB70P3CP6l00`00
02L0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0hnKD0=Zm_03J_K`00`3Ud<801@2a
S:l0^HjX0;V>Z02iSZP0UWF[00<0^H^V0P2bW/<40:^>^0030<nW[`3bdJh0l]6^0080n>Ja0P32Z/83
0:R8]0<0a::f0P1UFk<30;:Na0<0e9nO00D0a9>S0?70W@3GZ:L0c9VR0=NXY`040:JWe`<0dk[20P3H
^KX308U^[P030:BNd02mVK80_IVb00<0VGba00<0WXZn0=?ii03CnN@00`22N;l0103@c=H0YgJL0:Mf
W02^OIh30=fg/@@0g/Bn00@0VG^`0<jQZ@3>XJT0cZ6Y0P3WjH<309io/@030=FZ[01cGZ`0Lej/00<0
YGjZ0`2>TM820>cYbP<0eKJk00<0co>L05J3hP14C;D00P35[lD30:I_U080o>JJ0`3Wh</30=jk]P<0
ZL_b0`3Wc;X30>Kbd`04085d_02;J:D0VLgj00B5gP<0h>SI0P2hVKP30=Jc]P80fkRf0P3IYj8208b9
b`80Q[7a0`3]a:T01`3`cZh0o^2D0?kPU03ji:T0o>JI0?K`[03gj[<00`3Ylll00`35/lP0`LCM0<74
g@020=K7c080a^K^0P2ca^P0100[?K80EV[;05IZb`1FJ//2096@c`80VgZ]0P3X^jL20:6>`@<00000
0P3`hKl2000m`@<0/I_10`2INZl20:6Aa00306jnoP00000000000080V8>k0`2=Lk40101hGZL0?cNP
03lgX00o=j0208AY[0050000O`3BaLh0TFBJ095TVP3FZZ/00`3DZZh00`2fk9D0nmnT0?_OY0030=?3
b`80WG:Q0P2<Kj`200LNX0<0/9Ro0P1dKKd304e`e00505A9Z02?N;D0000008mh]@2LP;<00P2OMZD2
08=Y[0<0ik:M00<0[G^M08EWZ025IjP00`32Uj/30:QcV0040?C@H@2gQZ40]hJQ0;N6X@<0U7:Z00@0
[WRH0?K=G03fcE`0c=UU0`2[SKH209mo/0@0^oS]103J`L020965``T0oooo00<000000?ooo`3oool0
@03oool00300oooo00@000000?ooo`3oe8L0k=UX0P3CP6l00`3@XaD0oooo0?ooo`080?ooo`030000
003oool0oooo00<0hnKD0`3Ud<820;6<[`<0^HjX102iRjH309aj[@<0Zhjh0`3bdJh00`3hi[40`Z[2
0<:Z`P020<:Z`P80Z8Rd102bWl@2081NXP030;:Na03DWil0e9nO0080e9nO0P3a`9d30=NXY`030=N]
[@2VYmL0YZOG0080dlgC0P3C^/820=Ri^P<0RFj^102mVK8209Ul/@<0doWT0`22N;l00`3@c=H0YgJL
0:MfW0030=fg/@030<WQj@0O=k007cN`0080g/Bn0`3>XJT20>OYP`80`?BV0P2NOk40103EZZ`0Lej/
07=N[01cGZ`20:EnZP@0YZOG0`3E][/20<ocW0040000M014C;D0A4be0<F_a@<0YVnD00<0o>JJ0>OP
b`34c^800`34c^800`3N^kH0iMO80>GGb0030:W;lP03087IoP000000[KCN0080[KCN0P2IcOX20>OB
`P0300B5gP1UO]L0IGkG00<0Z;CQ0P3F/kH20=^h]P80fJNR0P2<RL/40:JWe`80l<j^00<0o^2D07iO
Y@3liYT00P3fl:`40>Wcc`<0`LCM1036i^h20;?6j00402/m/P1FJ//0EV[;05IZb`80TI3?0P2KNZd0
103X^jL000000000000000030>?8_080l>6o00<0^YZg000m`@00?L400P2aVl4309Uj[`030>OYd01^
__h0Cd2P008000000P2HPk/308ec/@80N5jW0P0o=j0308AY[0030=;5cP2AI9X0TFBJ0080eZZ[00D0
e:Z^0?cCV03c_YH0SWVh0;fd:`0207IJY@030:ihV02MLZ40WG:Q00<0S6n/00@01ajP0;2H_`2`V;l0
/9Ro0P1dKKd304e`e004031Od@2?N;D0000008mh]@<0WgJU0`23JJ`00`3W/Yd0[G^M0:ekW@0308EW
Z080`YN[0`2XLiP01@3dd640]hJQ0;N6X@2gQZ40aIBT0080U7:Z00@0[WRH0?K=G03<fFD0c=UU0`2[
SKH00`2OOk00cnWX0<oYj0040:S9l@80f/700P2WPZd208m/YPT0oooo00<000000?ooo`3oool0?`3o
ool00300oooo00L000000?oDQ`3oe8L0oooo0?Fa@@3CP6l0d:<E00/0oooo00<000000>?Ve03Si]@0
102Bl=`30;6<[`<0^HjX00D0/XBT0;V;YP2iRjH0^H^V0=6OX`0209aj[@<0Zhjh0`3Kl=l20<^Y]`<0
`Z[20P2XR;@0100007d0/Yo40;:Oa02bWl@2081NXP030;:Na03DWil0e9nO0080e9nO00<0o>JL0=NX
Y`3GZ:L00P3GZ:L20=N][@@0dlgC103H^KX208U^[P050;nJ/P2mVK80_IVb0;fI/P2IO;40102i[m00
103CnN@0PWRo0:;^[@3@c=H20:MfW0040;kVPP3M]k40gKNa06i?W0<0SGfl0P2>OKd20<jQZ@80jMK1
00<0d:2V0<3dYP2NOk400P3EZZ`307=N[080YGjZ00P0n>Zb0:JWe`2VYmL0YZOG0=c=bP3E][/0V^je
0=kKe080SHo@0P14C;D01@21GIl0YVnD0:I_U02VKi@0Gd^R0080ZLW`0`34c^830>GGb080fn[N00<0
5f;H02n@k`0_T>l00P2]]=h00`2TP[00A5O10>OB`P020>OB`P0400df]P04QMh0IGkG06Ene`<0Z;CQ
0P3K^;H30=VWXP030?CQN`32S9`0O5ZO0080YZOG0P35f>P00`3nh9@0Xgj[07iOY@020?K`[0800cjo
00@0UYgH0<bY]`3<ZKL0:6GG102gYlX0102fRZL0XHo20:6?`P00@kh202/m/P80LVJf0P2AT<l30000
00030>RkY`3be;80YZOF0080YZOF0`3`hKl20<fU/003000m`@2aVl40/I_10080VGZ_0P3WjM00103K
[j`0Cd2P04m0X000000209R3^`<0SG>a0`1hGZL01P0o=j00Q6V/08AY[024JJ`0001o095TVP<0eZZ[
00H0jlRa0?cCV03c_YH0SWVh0;fd:`1fFZD20:ihV080WG:Q0`2<Kj`00`05;k40Y]Ch0:KDn0020:KD
n080UW>Y0P1lHJP2031Od@0308ma[@000000Sg6]0080WgJU0`23JJ`00`3W/Yd0[G^M0:ekW@0308EW
Z080`YN[0`2XLiP20?C@H@80]hJQ00D0aIBT030`X02DLZX0[WRH0?K=G0020<cII@<0Zhff0P3?jNP2
097QU`<0Z<Wa102WPZd208m/YPH0oooo00@0fkRe0?ooo`3oool00000@@3oool002l0oooo00P00000
0?ooo`3oe8L0omB70?ooo`3e/D40dh1_0=2S5@`0oooo0P3K_[d20>S7]0030<jKXP23IZX0PfJZ0080
/Hb_0P2iSZP20;:4Y0<0^H^V00D0dInS09aj[@2LNZd0W7Z]0:^>^0030=_`g`<0bjVg0`32Z/820:R8
]080001m0P2bWl@2081NXPD0e9nO00@0o>JL0>of[@3GZ:L0ejRW0`3G[Jd00`2nef<0dlgC0=?=d`02
0<OUk0<0f;Vj00<0RFj^0;nJ/P2oV[800`2mVK800`2Vl;00:Ik_0;V_d0020;V_d080aYf^0P2XSKT0
102WMY`0[7bP0:alX02/O:0306i?W080SGfl0P2>OKd00`3>XJT0inV30>WF`@020=2PYP0303`_V02N
Ok40eJZ/0080eJZ/0P1cGZ`20:EnZP80n>Zb00@0YZOG0=c=bP3LcLX0V^je0P3Nfm@308f?d00604A<
]@21GIl0YVnD0:I_U01OBj80g^SK0`2YbO030::Ca@80fn[N0`2Y_^P30:c7k@80Y8:`0`14El420=Zl
^`0300df]P1UO]L0IGkG00@0H/7m00L0fkRf0=VWXP3IYj80fJNR0?CQN`32S9`0O5ZO00<0aMSX00<0
[8Za0:=nZ`2SOZ/00`2hSZT00`3ccj/0UYgH0<bY]`020<bY]`80:6GG0P2gYlX20;J:Y`80XHo200@0
g<_907>3e@0[?K80LVJf0`0000001@2KNZd0j;^W0>RkY`3X^jL0l]Bb0080YZOF0P2^Tk/309]m/@80
cJF`0P2aVl400`2INZl0inW@0>OYd0020=^_[0<0Cd2P0P2HPk/308ec/@<0N5jW00H002Z_08AY[024
JJ`0Q6V/0000O`2AI9X30=JZZ`060>_8/@3ldiP0lkjF08ii^02m]2/0MUZU0P2^N9P209ebX@80S6n/
0`2nV[830:KDn080UW>Y0`1lHJP0100`Gm40Sg6]08ma[@00000309mfY@80PfV/102]Nid308EWZ080
`YN[00D0Z7>H0?C@H@3dd640m=1Q0;N6X@020<FDY006030`X02DLZX0[WRH0?K=G03]]IH0Qg2b102?
eOl20:S9l@80Skkf0`2@NKD30:N2[@80SfbV1@3oool00`2Q4@00fkRe0?ooo`020?ooo`030000003o
ool0oooo03h0oooo000_0?ooo`080000003oool0omB70>cIJ03oool0mK510=>0K`3@XaD;0?ooo`80
fkjm0P3Xak@20<jKXP80PfJZ0P2aS:l0102iSZP0/XBT0;:4Y02bQ:@20;V;YP80dInS0`2LNZd30=_`
g`@0bjVg00L0gL:n09B@c@2DT<d0U93=0<VX^0150000FfC20080/Yo40P20GZ801@3O`[/0e9nO0=BO
W`3DWil0o>JL00<0koJ]00<0ejRW0=N][@3G[Jd00P2nef<40<OUk0<0f;Vj0`2oV[820;fI/P06061F
[`23/?80^Jo@02VNk`2i[m00a;?90`36WJh00`2XSKT0YgJL0:=hX`020:alX0<0KTnL0P2=OK`208im
_@030<jQZ@3Ye/40jMK10080d:2V00<0?2nH0=FZ[03EZZ`00P3EZZ`207=N[0040:EnZP3hj[80n>Zb
0?SZ/P80g<g:00@0V^je0=kKe03Nfm@0g]_D0`2=Sm001@14C;D0PEfO0:I_U02VKi@0Gd^R0080VGN/
0P2NOk420::Ca@80WG>S0P2;JJL30:Vnj080[<O]0P2TP[0409Yl/@030=Zl^`0==[H03CJf0080S8G7
0P2mVkH01@1R`Od0fkRf0=VWXP3IYj80m>5k0080`XbL0P1lFYl309OVo080[HR^0`2hSZT00`3ccj/0
c:Vg0<bY]`020<bY]`030>C6^@0XIML0]jO:00<0]XZW00<0XHo20=c;b@3LblT00`000002079V]P04
03=2/`3X^jL0j;^W0>RkY`80l]Bb102^Tk/0103;WZX0Vgfa09]m/@3=YK030=g3_`80inW@00<0:46f
0=^_[03K[j`00`1?@:000`0007L0Z86Z08ec/@0208ec/@80N5jW0P3FoMX01000:Zl0R:7T08RQi028
XN@30=JZZ`80jlRa00@0o=>H0?>nUP2>NKP0MUZU0`2^N9P209ebX@0308a_[02nV[80_YZb0080_YZb
00<0cJ2Z0:KDn02Ve?P00P2FLjT307aQZ00502PYW@2?LJd0Sg6]08ma[@0000000P2OMZD00`23JJ`0
YgfV0:MmYP030:ekW@<0QFNX0P32Uj/01@2XLiP0m=1Q0?C@H@3dd640]hJQ00<0aIBT00@0<32P0:ih
V02iTJd0kKFF0P27L;800`3N_;H000000:S9l@020:S9l@80Skkf0`2@NKD30:N2[@<0SfbV103oool0
0`2Q4@00fkRe0?ooo`0300000400oooo000_0?ooo`80000000H0omB70?ooo`3oool0mK510=>0K`3@
XaD70?ooo`030=>TY`3oool0oooo00<0fkjm0P3Xak@20<jKXP80PfJZ0P2aS:l40;:4Y080^H^V0P3A
Wj<209aj[@<0_Yjh00@0m]Z`0??I]03;ZKL0bjVg0`3M`[h0102DT<d0bJRh0<VX^015000205]T`P04
0;:Oa020GZ80gl:k0=o2^`<0e9nO00@0o>JL0>of[@3_mZd0koJ]0`3G[Jd20=BUYP<0P5fP0P27V]l3
08^dl@80_iZb00<0[XR]061F[`1PEZl0102i[m040<JM[P<0XgRS0P2/O:0306i?W080SGfl0P2>OKd0
0`1]`oh0jMK10=2PYP020=2PYP80?2nH0`3EZZ`207=N[0030:EnZP3hj[80n>Zb0080dM3H00<0ThK3
08Jfm026]_@00`2PYm`208mn_@0404A<]@21GIl0YVnD0:I_U0<0VGN/0P2NOk4409ecX`80RfVW102U
TL00102/and0Y8:`0:B2/03XjLl309Yl/@80d^WU00<03CJf08b5a`2mVkH00P2mVkH01@1KG[/0fJNR
0=VWXP3IYj80m>5k0080`XbL0P1lFYl20<[h[0<0[HR^0P2hSZT20???Z`030?7K^@3<ZKL0c:Vg0080
i<Ji00<003^l0;J:Y`2fRZL00P2fRZL3000000030<C1e`35/lP0aK?80080LVJf0P0c@[<20>RkY`80
l]Bb00<0j?Zc0:jC^`2^Tk/00P3;WZX209]m/@<0gL>o0P3E[[401@31S9h0_8jV0;b>YP2lSZH0/XJV
0080?9;`00<0001g0:R1ZP3FYJD00P3FYJD01@3FoMX0f=cJ0=SLfP2/PjP0nN:]00<0R:7T00D0001o
0=JZZ`3FZZ/0jlRa0?cCV0020?>nUP030;fd:`1fFZD0[WRH0080[WRH0P2MLZ400`3?YZh0o]:=0;jJ
/P020;jJ/P030<fPZP1^SN00Y]Ch00<0UW>Y0P1lHJP01@0X:Id0<5oA08ma[@2?LJd000000080WgJU
0`2WOJH30:ekW@80QFNX0P2MLZ800`32Uj/0Z7>H0?C@H@020?C@H@@0aIBT0P0`<:000`2iTJd0kKFF
08M`/P020=jl]P030000001mdH80WhRk0080WhRk0P2?__H2091i]@<0Yh:]0`2?K:H30?ooo`80XA40
0P3K^;D30?ooo`030000003oool0oooo03d0oooo000_0?ooo`030000003oool0omB70080oooo00<0
mK510=>0K`3@XaD01P3oool20=>TY`0404a</03K_[d0fkjm0=^n_@80j<Nd0`3>Vj8208=VZP<0YH>`
0`2bQ:@0102iRjH0dInS0=6OX`3AWj<40;jN^080m]Z`0P3cfK@0103;ZKL0gL:n0=g2_P3M`[h40<VX
^080FfC200<000RH081NXP3O`[/00P3O`[/0103DWil0o>JL0=c>b`3Lc//305=og`040=N][@3DYJH0
e:FV0=BUYP<0P5fP00<0YGVS08NJg`27V]l00P2;]?420;nJ/P040:j8[@1PEZl0b[[;0<Zjb`80^Jo@
0P2VQK430<JM[P030;R9Y02SN:<0XgRS0080[7bP0`1^Ci`408a/Z@80jMK10`3@X:H203`_V080eJZ/
0P3SjmL00`17I/l0n>Zb0=7@f0020=7@f00309>6``3=^/P0cK[80080ZL_b0P2PYm`308mn_@03085M
W`2VKi@0YVnD00<0VGN/0P2NOk40102eS:/0WG>S09ecX`2MLj<208]YY`060>2h[P2UTL00YI700:FA
`03VlM<0Y8:`0P3XjLl309Yl/@80_]W]00<001j[0;fK]P2mVkH00P2mVkH205]N^`80fJNR0`32S9`0
0`1lFYl0VGJ[09UfZ`0206iDX`<0[HR^00D0^8jY0???Z`3ccj/0lM^i0<bY]`030>C6^@030>W>^`00
>k`0000000<000001034`ML20<Fcb00407Yja`0c@[<0<d:c03=2/`80l]Bb0P3Xn[<0102^Tk/0bijZ
0<^NZP3;WZX209]m/@030;>=[P3M`kl0gL>o0080eJja00D0`HbN0;b>YP2lSZH0_8jV0;J4W`020;:6
YP0303bBl02XPJX0eZFU0080eZFU0P3<_<X0103Hg=X0[8>X0?WR[@3ihZd208RQi00501@PW03FZZ/0
jlRa0>_8/@3ldiP00P3c_YH00`2AI9X0[WRH0:ihV0020:ihV080WG:Q00@0cjJ^0?kBS@2nV[80_YZb
0P3=X:X00`32bDX0Y]Ch09IcZ@0209IcZ@80O66X0P0X:Id208ma[@0409mfY@000000/hVZ0;>9ZP80
YgfV0`2]Nid409ebXP040<:GZ`2XLiP0m=1Q0?C@H@80YhNb0`35U:@01@0`<:00^I6]0;VA[@3]]IH0
Qg2b0080g[bf0P1mdH8309n8^`0403E5]P2?__H0T7Ve091i]@<0Yh:]0`2?K:H20?ooo`<0XA400P3K
^;D40?ooo`030000003oool0oooo03`0oooo000_0?ooo`030000003oe8L0oooo0080oooo00<0mK51
0=>0K`3@XaD01P3oool20=>TY`<0C4b`0`3Xak@30<jKXP0308=VZP2NOJl0WWf_0080YH>`0`2bQ:@0
1@2iRjH0dInS0=6OX`3AWj<0h[V]00<0_Yjh00@0m]Z`0??I]03cfK@0lmVd0`3M`[h20<o4d0<0bJRh
0P1KI<800`0029P0gl:k0=o2^`020=o2^`030=BOW`3ihZ`0[Maf0080hkjb0P1COml0103G[Jd0im70
0=BUYP3DYJH2081MX080UfbO0P2UNJ<00`29IZ<0RkCa0;nJ/P020:j8[@@0b[[;0`2VQK420<JM[P80
^8VT0P2SN:<20:alX080KTnL0P2YNj4308a/Z@030<>AXP3@X:H0d:2V0080d:2V0P0l;iP01P3EZZ`0
hn_G0>?[e`3SjmL0AfK?07]Y/`80_[7=00@0ThK30<fjb03=^/P0cK[80P2Ybo830:2Wg080Sgjm00@0
PEfO0:I_U03>Y:h0cZB^0P2IMj`00`2NOk40]Hb[0;F<Z`0309ecX`80RfVW0P3P^:h00`2UTL00i_7C
0=KNg@030>SYc`80VWba102nfNd010007Z/0_I^f0;fK]P2mVkH205]N^`030=VWXP3dhG/0`XbL0080
`XbL00<0000009UfZ`2IMZ/00P1^E:<30:f8[P040;R>Z@3ccj/0lM^i0?7K^@<0i<Ji00<0jLjk0000
000000000P2fRZL30:R_g@<0a<7G0P1hg_H207Yja`<0LH7C0`3Xn[<40<^NZP0409]m/@2cSJh0/hf^
0;>=[P80eJja0P31S9h30;b>YP050;J4W`2bQZH0/XJV0=^[Y@2XPJX00P3FYJD01032V:`0c;c:0<bl
bP3HalT40?WR[@0308RQi00D89`0eZZ[0080jlRa00D0o=>H0?>nUP3c_YH0TFBJ0=Z]Z@030:ihV003
09ebX@3?YZh0cjJ^0080o]:=00<0_YZb0<fPZP3=X:X00P2a]M/309IcZ@80O66X0P0X:Id208ma[@04
09mfY@2cRJX000000;>9ZP80YgfV0`2]Nid01P2hPYX0WG:R09ebXP2MLZ80DD:R0:QcV0@0YhNb0`35
U:@20;VA[@80kKFF0P3N_;H010000000lOFh05mD[P1mdH8209n8^`80=DFf0P2@NKD30:N2[@80SfbV
0P2[S[L0102fC000egiT0=MnI02Q4@020=^h]@@0oooo00<000000?ooo`3oool0?03oool002l0oooo
00<000000?oDQ`0000000P3oool00`3e/D40m[Y80=2S5@050?ooo`<0djBW0P1<C;0309mgYP@0cY^R
0`2NOJl20:F3/0<0/XBT0`3AWj<20>:i[@80_Yjh0P3ff[020??I]080gN_M00@0gL:n0<o4d03?a=00
clC@0P39Z;P20<>]a00308Ul_P0029P000RH00<0gl:k0P3ihZ`00`2]g7H0hkjb0?KK/0020?KK/080
im700P3DYJH409M/W`80YGVS0P29IZ<20:j8[@80^o_10P3:^//20:1dX@80YXFa00@0aYf^0;R9Y02h
RJ@0^8VT0P2SN:<20:alX0@0ZG^Q0P2<K:T20<>AXP040>F_V`3@X:H0d:2V0=2PYP80?2nH103SjmL2
07]Y/`80_[7=103=^/P00`34X;<0R6f^08Q][P0202eSe080Sgjm00@0cZB^0:I_U03>Y:h0cZB^0P2I
Mj`30;F<Z`<0WG>S00D0RfVW0>2h[P3P^:h0h;R^0>Kad`040=KNg@030>SYc`2JO;40h=3800808Dc4
0P2n`mh010007Z/0_I^f0;fK]P2mVkH205]N^`030=VWXP3bihH0`XbL0080`XbL0`2IMZ/206iDX`<0
[HR^0P3ccj/00`3afkT0c<KD0<c6e003000000050>W>^`2Fk_40]XZW0;J:Y`2Fk_400P2X[md40:J?
_0030;R7X@1jN/L0NW[70080LH7C00<0:cjb03Q<^P0hC;X00P20J:h30<^NZP@0/hf^00<0_X^O0=F^
/@31S9h00P31S9h0102lSZH0]XBO0;J4W`2bQZH20=^[Y@040:dU003FYJD0eZFU0<:H[0@0f<O900D0
0473001Ia000FL@000FH01@PW0030>_8/@050?cCV03c_YH0lkjF095TVP3J[JT00`2^N9P00`2MLZ40
cjJ^0<nV[P020?kBS@<0cJ2Z0P2a]M/20:R/fP80UX_600D0V8No02PYW@0X:Id0:2VM07ER/0030;>9
ZP040000002WOJH0YgfV0:MmYP80[G^M00@0^8:J09ebXP2MLZ80WG:R0P1A@Z80103>WZH0YhNb0:N7
/P2WQk830<FDY0060<>GZ@2iTJd0kKFF0>feUP3ngXX0g[bf0P3amKP205mD[P80WhRk0`0eAKH208A/
/080QH77102[S[L0102fC000egiT0=MnI03GOV@309QbYP@0oooo00<000000?ooo`3oool0>`3oool0
02h0oooo0P0000001`3oe8L0oooo0?ooo`3oool0mK510?ZaC@3@XaD01@3oool30=>TY`D0WgNV00D0
ejJT0<jKXP3>Vj80cY^R0=BVZ00209im[`80YH>`0P2bQ:@20<bV/P80dInS0`3R^Jd00`2nW[P0m]Z`
0??I]0040=g[g@@0clC@1033[L@208Ul_P060>KB`P11`mh0@L?N0<NGYP3ihZ`0[Maf0P3S_[820?KK
/0<0im7000<0e:FV0:MlY02WO:@00`2GK9l20:EiX`80RFJS0P2fU;@00`3>VZ00P5NH0:1dX@030:1d
X@80YXFa102hRJ@20:=hX`80[7bP00@0[7nS0:UkX@2YNj40ZG^Q0P2<K:T20<>AXP030>F_V`3@X:H0
d:2V0080hMW>00<0m=nf0=Bj`@3D^/400P3D^/400`1kJK<0a[G90<Jeb@0209JYh`80cK[80P34X;<3
08Q][P80;F?D0P2;T=<00`2VKi@0cZB^0<jT[P030;khkP80]Hb[0`2MLj<01P2;JJL0h;R^0>2h[P3P
^:h0l>6o0?3f[`<0e]kM0`3Pd<P40;k3gP0408Fln02mVkH0_I^f0=GBeP80^I>_0P3bihH20<:<W004
0?3I^P2IMZ/0VGJ[09UfZ`80KUBS0P2]R:h20<W6e`050?7K^@00000000000000003<a]@00P3Yc[/2
09Q[W@030;J:Y`2HJid0QURD00<0WGZ[0P2VSk`20;R7X@80NW[70P2KRl8202/n/P0303Q<^P20J:h0
P6R^00<0bijZ00<0[gnP0;>=[P2cSJh00P2nRil01@3E[[40`HbN0<6<WP31S9h0_8jV0080]XBO00D0
/XJV0=^[Y@3KZjD0fj^U0=JUY@020<:H[0030>RlY`3HalT0f<O90080[hZ^00<00473001Ia000FL@0
0`0D89`20?cCV0040?>nUP3_hWP0fZfY0=Z]Z@<0[WRH0P3?YZh30?kBS@030>:j[P3=X:X0WWna00<0
WWna00D0R72b09J;aP2FRlH0UX_609R7_`0202PYW@80MF:`0P2cRJX01@000000YgfV0:MmYP2WOJH0
[G^M0080^8:J0`2MLZ820552XP040<jNYP2WQk80YhNb0:N7/P80aIBT0P33UjT01@2iTJd0kKFF0>fe
UP3ngXX0g[bf0080lOFh0`1OE:h20:>Fb080=DFf0P24K;0308F1a`<0Zhjg00<0]T`00=MnI03GOV@0
0P3GOV@209QbYPD0oooo00<000000?ooo`3oool0>P3oool000P0oooo100000060?ooo`8000001@3o
ool6000000@0oooo100000070?ooo`030000003oool0oooo00<0oooo00<0mK510?ZaC@3@XaD0103o
ool40=>TY`040;F1W02OMjH0WgNV09mgYP80ejJT0P3>Vj820=BVZ080WWf_0P2UPk001@2bQ:@0c:Jb
0<bV/P3<Y[80dInS00@0h[V]0P3dj[/30<KFiP@0YYK40`2HN[030<>]a00508Ul_P3Vd/80i];20>KB
`P37UjH00P3ihZ`20=g>bP80m]^`103WdL030:MlY0<0UfbO0P2UNJ<01@29IZ<0]YBd0;JD]02fU;@0
cYZP0080P5NH0`2PM:420:J5/@040:n:[P2hRJ@0^8VT0;R9Y080XgRS00<0[7bP0:aoX`2/Oj<00`2Y
Nj401P2<K:T0`i6R0<>AXP33TJ80iJnK0=2PYP80hMW>00<000000>c?]`3TjhL00`3D^/440<Jeb@80
UZWS0`34X;<208Q][P80/8BU00D0;F?D08^@d`2;T=<0YVnD0<jT[P0309JBcP030;khkP2eS:/0]Hb[
00<0WG>S0`3P^:h0103`hKl0l?J_0?3f[`3Om]X308ndk`@0_L?N0`32f>X30=GBeP0409^^i02iTjl0
l^N60?;WQP80`XbL00@0LVFe09UfZ`2IMZ/0VGJ[0P1^E:<20<W6e`<0000000@0fn3I0<c6e03<a]@0
W_GJ0`2DJj0309Q[W@80QURD0`2MNZ/00`2VSk`0^8NQ0;R7X@0201Xl]`<0S7Rh00<0:cjb03Q<^P20
J:h00P20J:h00`3;WZX0[gnP0:moX0020;>=[P80_X^O1031S9h30;J4W`050;:6YP3KZjD0fj^U0=^[
Y@3FYJD00P32V:`00`3X_:L0[hZ^0:n:[P020:n:[P040;^7WP003Yh005W407Qlb`<0GHWT0P3c_YH0
0`2AI9X0fZfY0=Z]Z@030:ihV00400000@3?YZh0o]:=0?kBS@80h[Z^00<0cJ2Z0>Fn[`2NOk400P2N
Ok4208Q`/P80KEna00<0]i2^0009V`0X:Id00P1eH[030;>9ZP040000002WOJH0YgfV0:ekW@80^8:J
0`2MLZ80101A@Z80cYjV0<jNYP3>WZH20:N7/P050<FDY033UjT0`iNY0<>GZ@2iTJd00P3]]IH0103n
gXX0lOFh0?7e^03amKP305mD[P80XiK800<00B:U03E5]P24K;000P24K;0208F1a`<0Zhjg00<0O3Q^
0=MnI03GOV@00P3GOV@209QbYPD0oooo00<000000?ooo`3oool0>P3oool000L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oe8L0
oooo00<0oooo00<0mK510?ZaC@3@XaD0103oool01@3e`YP0djBW0=>TY`3CY:L0]H6L00<0WgNV0P3G
YZ@20<jKXP80e:JX0P2NOJl20:F3/0@0c:Jb00<0dInS0>:i[@3R^Jd00P3R^Jd0103dj[/0a]KV0<KF
iP36e^H20<B^a0<0YYK400@0^iRc09Qj/02HN[00V7Z`0P33[L@40>KB`P030<NGYP3ihZ`0gLk:0080
gLk:1026j?4309Qh[P80YgbT0`2GK9l20:EiX`<0]YBd0P3>VZ02081GV0<0X7BQ00<0YXFa0:n:[P2_
RZh00`2hRJ@20:=hX`<0[7nS0`2YNj400`2<K:T0`i6R0<>AXP020>F_V`<0hMW>0P3/ckL20>C[Q`<0
SGNf0P36]LT20:n8[080TgZe0P34X;<01@28KJh0/8BU0;24Y@2`Q:D0HeB[0080Ri3C0`2DJId00`2F
T/h0bJRi0;khkP020;F<Z`80WG>S0P2hVKP0103P^:h0l>6o0?3Q_`3`mZl30=offP<0Y;GU102?k]03
0;BffP<0VjkT00D0^I>_085Y[`3bihH0`XbL09Yj[P02079U]@<0LWg?0`0000001@3Sl=L0fn3I0=_P
f@3Kh=T0W_GJ00<0T6ZS0P2DJj0309Q[W@80QURD0`2MNZ/30;R7X@030;ImUP0J?;L0S7Rh0080S7Rh
00<0:cjb02T[WP20J:h00P20J:h30:moX0050;>=[P2nRil0_X^O0;j;W`3LXiT00`31S9h00`3OZil0
]XBO0;J4W`040=^[Y@050<6BY@32V:`0j;bW0>RlY`3JZ:<00`2_RZh0102kQih0WGV[09eiZ`2MNJ/2
02eKcP80dlC;00@0lkjF0=Z]Z@3J[JT0fZfY0`2^N9P010000040cjJ^0?kBS@3ndXd20>:j[P030<fP
ZP3U_Zl0WWna0080WWna0P28L;8306eO/@8000000P1eH[030;>9ZP040:MmYP000000YgfV0:ekW@<0
^8:J0P2MLZ80101A@Z80cYjV0<jNYP3>WZH20:N7/P@0`iNY0P3]]IH20?kNRP0308Mj_P0KHML06f7G
00<0GeB^0P2SU/P2004RY@<0Q6b`0P25PLL20:^>]`80^k?B103GOV@209QbYP@0oooo0`00000k0?oo
o`001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`040?ooo`030000003oe8L0000000<0oooo00<0mK510?ZaC@3@
XaD0103oool00`3e`YP0djBW0=>TY`020;F1W080WgNV0`3GYZ@01@3>Vj80e:JX0=BVZ03DYZP0WWf_
0080[Yo80P1nYNd30<bV/P@0h[V]0P3dj[/20>KA`P@0a:k400<0YYK40;^H/`2kV;<00`2HN[040::G
b@80i];200@0lN:o0=g>bP3Mc/X0gLk:0P2TWm00103Uf<T0R9;G08RBe`28T]L209Qh[P80YgbT0`2G
K9l20:EiX`030;bN^`2fU;@0]YBd0080cYZP0P20EiP30:1dX@<0[hZ^0`2hRJ@00`2SN:<0Xgj/0:=n
[0020:aoX`<0ZG^Q0`33TJ820>F_V`80g=EL0P3/ckL40;S8i`80SGNf102_R:`209=j]@80a:2c102`
Q:D206=DZ`040:A`U`2DJId0U6VM09AYW@<0bJRi0P2eS:/40;RI^080l>6o00<0l?J_0=offP1cg_80
0`2aanX00`18aK<0XI330:6@``020:6@``80S6NS0`2d]]X209^^i080PFV_00<05fWL0<:<W02JNZh0
0P1bIKD3000000<0]l3Q0P3MgmL0102SjYl0gok60;26Z02`QZP2091ZX`80U6^P0`2HJid208IHU0<0
WGZ[00H0YgNM0;R7X@2hQj40]WfF07=:TP0J?;L208ah^0030000I@0Y:ih0VWZ^00<0VWZ^0P2_Oj00
1@2cSJh0_X^O0;j;W`2nRil0g:>I00<0`HbN00@0gj^O0;J4W`2fQ9l0i;NW0P3KZjD20<6BY@040<:H
[03X_:L0j;bW0=ZXX`80[hZ^0P2kQih309eiZ`040;f=X`2;NKX0d9bP0=?4b`80=bfI0P3J[JT30:ih
V00300000@3?YZh0o]:=00<0h[Z^0`3U_Zl209io/@<0R72b0P1]Gk420;N@[P<0MF:`0P2cRJX00`2W
OJH000000:MmYP040;R2VP80WG:R103>WZH309b0/`<0`iNY00<0g[bf0>feUP3ngXX00P27N[h20:J4
/00501]Qe`1j[_@0NZkd07Z^m02bmk/00P018ZD40:^?^00306iba`2k/m80^k?B0080^k?B00@0^S`C
0=MnI03GOV@0egiT0`2HLZH60?ooo`030000003oool0oooo03P0oooo00070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00@0oooo0P0000040?ooo`030?Fa@@3j/Dd0d:<E00@0oooo0P3e`YP00`3CY:L0]H6L0;F1W002
09mgYP<0ejJT00@0cY^R0=BVZ03DYZP0e:JX102^WlP01@1nYNd0c:Jb0<bV/P3<Y[80eM?F0080h[V]
0P3dj[/30>KA`P040;F7Y@34[/@0a:k40<B^a0<0^iRc0P2HN[020=_3`@80XYO90P3ViM020?7R_`80
k>c;00<0f>GO0:BOd03Uf<T00P3Uf<T208RBe`80V7R^0P2WO:@309M/W`040:EiX`2lW[/0_9jk0;JD
]0<0cYZP0P20EiP30:1dX@030<^MZ@2_RZh0[hZ^00<0^8VT0`2SOZ`20:aoX`<0ZG^Q00<0[gbM0<>A
XP33TJ800P3U[i/20=cEG080k<ng0P3ce[820;S8i`80SGNf00@0_Ibg0:n8[02_R:`0[hR/0P2CN[D3
09Q^X@<0/8BU00<0HeB[0:A`U`2TL9L00`2DJId00`3?VYl0bJRi0<VX^@0309k@n@<0^9Vh00<0k_No
0:B5/`0000000`2V_NT0101[fn`0[j?;0:nSb`2_Xl/30:6@``80S6NS102iioD01@2K[^@0PFV_085Y
[`0007L0VWZ^00D000000P1X`Oh0102g`>40gMoG0=gOe`3MgmL40;26Z080T6ZS0P2DJj0309Q[W@80
QURD0P2MNZ/20:MgW@80^8NQ00@0]WfF07=:TP1cBY80S7Rh0P2LL:0202T[WP<0VWZ^0P2_Oj040;j;
W`030=bSV@31S9h0`HbN0080gj^O0P2fQ9l00`3T]jL0fj^U0=^[Y@020<6BY@030<:H[03X_:L0fZRS
0080fZRS00<0[hZ^0;^7WP2kQih00P2MNJ/20;f=X`0308]i^P3@W:00d9bP0080=bfI0`3J[JT20:ih
V00300000@3ndXd0h[Z^00<0h[Z^0`3U_Zl209io/@<0R72b0P1]Gk420;N@[P80T7:^00L0MF:`0;>9
ZP1Nc9d0G/bM08B^l0000000Q:k`00<0^8:J00<0WG:R0=?<d`3Cc=<00`3>WZH00`3L/jh0W82c09b0
/`030<>GZ@030=jl]P3]]IH0o]j:0080QgZn0`2VQ;02059<[0<0[WnQ0P018ZD30:^?^080KW;70`2k
/m80102j?1<0egiT0=MnI03GOV@309QbYPH0oooo00<000000?ooo`3oool0>03oool000L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030?Fa@@3j/Dd0d:<E00<0oooo0`3e
`YP30;F1W00309mgYP3GYZ@0ejJT0080ejJT103DYZP00`3K]k@0[Yo80:jOb0020<Vfb00307jUk@3<
Y[80eM?F0080eM?F0P3dj[/30>KA`P80]HNU102]T[X20;^H/`0509Qj/03K`l40fl?10=_3`@2RUlT0
0P3ViM020?7R_`80k>c;0P3HiMl30>GHb@80^oCa00<0R9;G09Qh[P2HN:h00P2WO:@309M/W`<0_9jk
00@0]YBd0<jJX03>VZ00cYZP0P20EiP20:1dX@80bifY0P2_RZh20;R9Y080bJZk0P2SOZ`20:aoX`80
ZG^Q0P2_O9d20<>AXP80iJnK00@0g=EL0>gA]`3]dKL0i_>K0P3ce[800`3`mZl0^<SW08eg]P020;fL
]`<0[hR/00<0TgZe09ATUP2DI9H00P2HKZ430;24Y@0306=DZ`2TL9L0Y72G00<0U6VM00<0ciZO0<VX
^@2jRj<00P2jRj<0102Nd?T0^9Vh0;RI^03^mkl20:B5/`0405]C/02_`nT0[l?Y0:o3j@80e=7F0`2_
Xl/20:6@``80S6NS0P3[a:d0103ZiG`0XlWd0:?9m021JJl300000080Rn_40P2m_MT20=Vd/`06085T
Z03MgmL0gMoG0=gOe`1CE;D0^iB_0`2`QZP2091ZX`80U6^P0`2HJid208IHU00409ejZ`2WMid0YgNM
0:MgW@80^8NQ00<0]WfF07=:TP1cBY800`2LL:0202T[WP<0VWZ^0P2_Oj001@3<Uil0_X^O0;j;W`2n
Ril0g:>I0080`HbN0P3OZil0102fQ9l0i;NW0>BgY`3KZjD30<6BY@80j;bW0`3JZ:<0102_RZh0^hNN
0;^7WP2MNJ/30;f=X`0308]i^P3@W:00d9bP0080=bfI0`3J[JT00`2^N9P0<D>e09fik0020=G^i080
h[Z^103U_Zl209io/@<0R72b0P1]Gk420;N@[P80T7:^0`24QL`0102`P:40Q:k`08B^l00000030;R2
VP<0dlcC0P3>WZH20=bc[P<0W82c00@0`iNY0=jl]P3N_;H0kKFF0P2EN;001027N[h0YXB`0:J4/02V
Q;02059<[0<0[WnQ00<0FTRR004RY@2[SkP00P2[SkP306iba`80^k?B00@0R1/]0=MnI03GOV@0egiT
0`2HLZH70?ooo`030000003oool0oooo03L0oooo00070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`@000001`3oool00`000000oooo0?oo
o`040?ooo`030?ZaC@3@XaD0oooo0080oooo0`3e`YP30;F1W00309mgYP3GYZ@0ejJT0080ejJT00<0
g;6/0=BVZ03DYZP00P3K]k@01@2^WlP0bKK80<Vfb039]/P0;4k200<0eM?F0`2j^mX20>KA`P<0]HNU
00@0k/BX0:fB^P2]T[X0[I:j0P2kV;<40=_3`@80i^G@0P3ah[l0103/k</0XWj/0:9n[02ROZ`20=SU
g`050001U02km?40a_oK0<Kof`1lM;l00P2HN:h20:MlY080UfbO0P33Zl820;bN^`@0cYZP0P20EiP2
0:1dX@80bifY0P2_RZh0102hRJ@0bJZk0<VZ^`39Z[/20:=n[080[7nS00D0ZG^Q0:mlW@2_O9d0[gbM
0<>AXP030>F_V`030;K=E03]dKL0kM6g0080lmJb00<0l?J_0:J5/P2VQK800`2mW;L30:n8[0<0U6BF
0P2HKZ430;24Y@<0Y72G0P2DJId20<nJW`@0^X^S00@0b]9H09k@n@2hVKP0UW>Z0P2TQK<305]C/0<0
e=7F0`2_Xl/20:6@``80S6NS0P3[a:d01@3ZiG`00000000000000000Z<gc0080fLK70`1dKKd40=Vd
/`80PFBX00<0DeBe0;^D[`2kU:l00`2`QZP2091ZX`<0U6^P0P2HJid208IHU0@0YgNM00<0^8NQ0;Im
UP2fOIH00`1cBY8209a`X003044eW00Y:ih0VWZ^0080VWZ^0P2_Oj000`3<Uil0_X^O0;j;W`020=bS
V@050<6<WP3OZil0gj^O0=n[W`2fQ9l00P3T]jL40<6BY@030=6PY@3X_:L0fZRS0080fZRS0`2kQih4
0;f=X`<0d9bP0P3:VZD30=Z]Z@030:ihV02QOJ`0eNkT00<0eNkT0P2HR/<20>Fn[`80ZH:[0P2JNk00
103ng9L0ZHZe0:V:]@2YR[D30;N@[P04091b[P24QL`0Q8G<08B5c080/82Q0P24[_0010000000^8:J
0;R2VP0000020=?<d`040<jNYP3L/jh0g;>^0=bc[P<0W82c00@0`iNY0=jl]P3N_;H0Zmil0P2EN;00
0`1kHj`0VGBW09UdY`0209UdY`04059<[02^Oj40[WnQ0:ioX@80FTRR00<00B:U0:^?^03Fe]P00`3F
e]P20=2RZ0040:j2Y@286bd0egiT0=MnI0<0V7:V103oool01@3Wb;L0oooo0?ooo`3oool0000003P0
oooo00070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
000000050?ooo`030?ZaC@3@XaD0oooo0080oooo0`3e`YP30;F1W0@0ejJT0P3L/J`0103DYZP0fkNd
0=^g]03K]k@40<Vfb0<0;4k20`2j^mX20=W3``@0]HNU00D0k/BX0:fB^P2]T[X0[I:j0;^H/`020;FS
aP80fl?10P3;`m<30:CKn`@0XWj/0P3dkI<01@3Wmll0WHJj07ad_`1lM;l0gmkE0080V7R^0P2WO:@4
0<>[`P030;bN^`2SOZ`0Xgj/00<0cYZP0P20EiP0102PM:40bifY0<^MZ@3;WJT20:n:[P@0bJZk0P2S
OZ`20:aoX`@0[gbM00@0`i6R0>F_V`3U[i/0]/eD0P3]dKL00`3Vli/0lmJb0?3f[`030:J5/P0309hB
002mW;L0_Ibg0080[hR/0P3D_/@209ATUP<0V6jQ0P2`Q:D00`2`Oil0Y72G0:A`U`0209AYW@80ciZO
00H0lmaa0;Z;X`2jRj<0^X^S0<[BF02YR;8209IcZP80Y8Fc0P1KDk020;n`b`80e=7F102@bo`0102Q
T<<0S6NS0>_4[@3[a:d2000000030:oXT02SbO@0>cVU00@0fLK700<0M6fm0<74g@31a=d00`3I];<2
085TZ0<0^iB_0`2`QZP2091ZX`<0U6^P0P2HJid208IHU0050=JNV`2WMid0YgNM0:MgW@2hQj400P2f
OIH307=:TP80W72P00<0@CFL0000P00Y:ih00P2JNZh00`2_Oj00c9NO0<bGW`020;j;W`80g:>I00D0
`HbN0=n[W`3OZil0gj^O0;J4W`020>BgY`050=6RZ031TZD0`I:U0<6BY@3AX:D0103JZ:<01038UZ<0
^hNN0;^7WP3<UYh30;f=X`040>2_X`3@W:00d9bP0<NFX`80bYZU0P3J[JT00`2^N9P0XGf/0<>FZ003
09IaYP80V8[3102YPZ/00`2JNk00o]bG0?kLU`030:V:]@80_iB[00<0G000091b[P0E5i400P24QL`2
0;20X@80Q:k`00@000000;R2VP2hPYX000000P3Cc=<40=bc[P<0W82c0`3N_;H309Eh/080Nf>/0`2I
M:L0101BC:`0[WnQ0:ioX@2^Oj4409^[hP0501Tj]P3Fe]P0e]KH0=KFf03@XZP00P2^PZD0103T/Z40
^S`C0=MnI02bS[0206E_b0<0oooo00<0MMfb0>O8]`3oool00P3oool00`000000oooo0?ooo`0f0?oo
o`001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P0000060?ooo`03
0?ZaC@3@XaD0oooo0080oooo0P3e`YP01@3S/:00]H6L0;F1W02ePI`0gZjU00<0ejJT0P3L/J`40=^g
]0040>od`P39]/P0bKK80<Vfb0@0Wi7500D0^[_J0=W3``3I`l<0fL?30;f@Y`020;F7Y@<0k/BX0P2]
T[X40;FSaP80bl?C0`2hV;L206IDZ@80XWj/0P3dkI<0103Wmll0WHJj09f6^P1lM;l30=oNe@040;JU
b02TWm00Y9o@0:BOd0<0`j_20`2SOZ`30<jJX080P5NH103;WJT00`3LliP0YjcK0:N/f`030<VZ^`80
Xgj/00<0[7nS0:IkY@2VNjD00`2_O9d01033TJ80iJnK0>F_V`2fcE@20>gA]`030??F/P2AMK00TGF`
00<0YXFb00@0XiO80;fL]`2mW;L0[hR/0`3D_/@209ATUP<0V6jQ00<0/8BU0;1oW`2`Oil00P2TL9L2
09AYW@80ciZO00@0lmaa0;Z;X`2jRj<0^X^S0P2YR;8209IcZP80Y8Fc102o/</0103Xl=40X]kl0:;N
o02Rg_`207_>o`060:6@``00000000000000003ZiG`0YXjk0P2>Mk@203/iY@<0fLK70`31a=d30=Vd
/`03085TZ02cW/<0/ik300<0^iB_0P2`QZP2091ZX`<0U6^P0P2HJid208IHU0050=JNV`2WMid0YgNM
0:MgW@2hQj400P2fOIH307=:TP80W72P0P11=I`010000800VWZ^09Yj[P2_Oj030<bGW`030;j;W`3L
XiT0g:>I00@0gj^O0`3T]jL00`3AXZP0`I:U0<6BY@020=6PY@050<jGV`3JZ:<0fZRS0=ZXX`38UZ<0
0P2kQih01@3<UYh0_HfS0;f=X`2mSJ<0h:nS0080d9bP00H0aiJS0<ZJY@3:VZD0dZ:U0=Z]Z@2^N9P2
0<>FZ0<0UW6V00<0V8[30:^:/P2[R[800`2YPZ/00`2JNk00o]bG0?kLU`040:JRdP80_iB[00/0G000
059Xb`0005h0Q8G<0;20X@3?bTX0_OkI08B^l02hPYX000000;R2VP0200000080IhWO0`3L/jh01P0P
02X0YZOF0:JWeP2VYmH0g[bf07Y[]P<0UGR`0P1kHj`309UdY`0502HZW`1BC:`0[WnQ0:ioX@3ck[d0
0`2KZn80101_KL40e]KH0=KFf03Fe]P30:j2Y@040;:>/02j?1<0egiT0;:>/080IFo80`3oool0101e
gK80ilRg0?3eZ@3F[k420?ooo`030000003oool0oooo03D0oooo00080?ooo`@000003P3oool40000
00D0oooo1@0000050?ooo`030000003oool0oooo00D0oooo00@0n[5=0=2S5@3hYeH0oooo0`3e`YP0
1@3S/:00]H6L0;F1W02ePI`0gZjU0080ejJT0`3L/J`00`3F[Jl0fkNd0=^g]0030>od`P<0[jO?0`2O
TLD30=W3``80_I2W0P2eQjD30>k4Z0<0YX^h0P2eXlH20=;n_P80QHO>0P2hV;L206IDZ@80XWj/00<0
m>fC0>Ogc`2MQ;P00P2MQ[X20=oNe@<0Y9g>00@0]ZG80:BOd02TWm00Y9o@0`37g^X20:=n[0<0cYZP
00<0P5NH0:=fX@2SMZ400P3;WJT20=ccV0<0YjcK0P39Z[/20:=n[0<0YW^U0`2_O9d30>F_V`80kM6g
0P2WM9X2095e/080YXFb0P3A/KX20;fL]`@0e;k40P2DI9H309Q^X@030;24Y@2`Oil0/7nO0080Y72G
00D0U6VM0<nJW`3?VYl0ciZO0??LL@020;Z;X`<0ZHRb0P2FLjX30:2<_P80_k3;00D0j?3A0=cfg@3L
m]d0g?KM0:VkiP030000000308aWX`3[a:d0j^El0080YXjk0`2>Mk@309^5^P80Q]7o0P31a=d30=Vd
/`<0/ik30`2kU:l20;26Z080T6ZS0`2DJj0209Q[W@80QURD00D0eYjK0:MgW@2WMid0YgNM0;R7X@02
0;ImUP<0LdZB0P2LL:02044eW0040000P02JNZh0VWZ^0:moX0<0c9NO00@0_X^O0=bSV@3LXiT0hZjP
0`3OZil00`2iS:L0i;NW0=6RZ0020=6RZ0040<6BY@3AX:D0dJ2U0<jGV`80fZRS0P38UZ<20;^7WP06
0<bFWP2mSJ<0_HfS0;f=X`3P[j<0d9bP0`37UZ<0103:VZD0dZ:U0=:RY@2QOJ`20<>FZ0<0UW6V0`2[
R[830:V2Z`0409Yk/03ng9L0g=SD0=cHe0<0YZ;B0P2oU:/01@2Ea_P0DVS;059Xb`24QL`0/82Q0080
_OkI0P24[_00102hPYX0000006b5fP2VPjl306N9g`030=bc[P2:O/40800Z00<0YZOF00<0983X07Y[
]P2EN;000P2EN;0207]S[0<0VGBW00<09RZO059<[02^Oj400P3ck[d309^[hP80Kfg10`24LkP20:j2
Y@070;^5VP2bS[00egiT0;:>/03_gKl0n^NA00:8f`02070000040>O8]`3`mJT0eZna0=J_/@80oooo
0P00000:0?ooo`@000001@3oool4000001l0oooo000]0?ooo`030000003oool0oooo00D0oooo00@0
n[5=0=2S5@3hYeH0mJ=N0P3e`YP20>>`X080]H6L0`3N[ZD00`3GYZ@0g;6/0=ba[0030=J][`030=^g
]03_m<80Y]?g0080Y]?g0`2_Yll0102OTLD0f=[I0=SJf@3I`l<30;f@Y`80]HNU0`3^a:P01`35V:P0
YX^h0:J;^02eXlH0hNCE0;7LL`3WeL@00P25Qlh20;RH]`80IUBY00<0XWj/0?C]T`2AJZ400P2MQ;P0
0`3^m<H0SgFb08me/P0208Qe]`80Y9g>00<0]ZG80000000000000P0000020<ONjP80Xgj/0`3>VZ03
0:=fX@80bifY0P3LliP408^0`P80Rh_>0P2;Kjh20:IkY@<0[gbM00<0nMNU0>F_V`3U[i/00P3ZlLd2
0:MdVP80TGF`00@0YXFb0=6a^P3A/KX0dK6j0P2SUlP20:V>^@80e;k40P2DI9H309Q^X@<0/7nO0P2T
L9L0102DJId0ciZO0<nJW`3?VYl20??LL@050;Z;X`3Fl^@0ZHRb0:V8/P2FLjX00P3Jmml30:2<_P03
0>S`d@3Lm]d0g?KM00<000000P2Y^nH0102l]=80jlB]0>_4[@2l]=820:J>^`80SWNd0P3C][d209^5
^P0409:6``3C][d0dkJm0=>f_@80CGcO0P22[_420;>N``<0^iB_0`2Gf?d01023HjD0U6^P09A[X02D
Jj0209Q[W@80QURD00@0eYjK0:MgW@2WMid0YgNM102fOIH207=:TP80W72P0P11=I`00`0249800020
05MK^`040<bGW`040;j;W`3LXiT0g:>I0>:^X080gj^O0P2iS:L01@3T]jL0dJ:X0=6RZ03AXZP0`I:U
0080dJ2U0P3>Ui/0103JZ:<0b9JS0<RFX`2kQih30<bFWP040;f=X`3P[j<0h:nS0=2LX0<0aiJS00<0
bYZU0=:RY@3BXZD01033UZP209IaYP030000002[R[80ZhZb00<0ZH:[00<0o]bG0=cHe03Lf=@00P3L
f=@20:JRdP80_iB[0P3QoL0209G6n0090;20X@2IKj40SGBb0>kG^`24[_00^8:J07^0c@000000Xh:`
0080YX>_0`2:O/420<RO[P040;>Pa@0TP>P0983X06mQ/`<0UGR`0`1kHj`209UdY`809RZO00@0[WnQ
0??^_@2oYKl0_jFo0P1lHj`206m]`@<0Q7>h0P2^PZD02`2kQIX0/Xj`0=MnI02bS[00kmfo0?[WT@39
ffT0c;O60>Jn[P3Wb;L0l?FY0080eZna00@0oooo0000003oool000002@3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0L0?ooo`00;@3o
ool00`000000oooo0?ooo`050?ooo`040?ZaC@3@XaD0n:MF0?FSGP80mL:H0P3S/:020;F1W0<0gZjU
0`3L/J`30=J][`80m_2V00@0j<jl0:KCm`2VdoL0Y]?g0P2_Yll30=SJf@@0_I2W00@0]HNU0>k4Z03^
a:P0k/BX0P35V:P20:J;^080hNCE0`3WeL@00`1hI[80^9Rg0;RH]`0206IDZ@040:9n[02AJZ40TFZQ
0>?fX@80k_C60P2?MK8208Qe]`80Y9g>0P2fYLP2081JW@80ESbF00<0amkZ0:=n[02SOZ`00P3>VZ02
0=GCe`80XgJQ00D0bifY0:R7/P2XQk8043bj08>mnP0308^0`P80Rh_>0P2;Kjh20:IkY@<0[gbM0P3i
ejD00`3U[i/0j_7=0:MdVP020:MdVP80TGF`103A/KX20:>Gb0<0]Y^m00<0e;k409ATUP2DI9H00P2H
KZ420>7Fc080/7nO0P2TL9L40<nJW`80lmaa00@0^X^S0?cIW`2YR;80ZHRb0`3Jmml20:2<_P050=WN
f`00000000000000002BR<H00P2aX/P30::A``<0_;CB0P2VS[/0102>Mk@0dkJm0=>f_@3C][d209^5
^P<0dkJm0P2^P:8208iYX`0308:^l@2cW/<0/ik300@0Mmf^0P2Gf?d208=SY@<0QF:R00<0V6^M08IH
U03FWY/00P3FWY/20:MgW@040:miV02fOIH0]WfF0;ImUP80LdZB0P2LL:03044eW0030000P01GFk/0
Ee^k00<0c9NO0`3LXiT20>:^X0030=n[W`2iS:L0^HbW00@0dJ:X0P3AX:D30<jGV`<0b9JS00D0^hNN
0<bFWP3<UYh0c9JN0;f=X`020>2_X`@0aiJS0`3BXZD01@2kS:@0`iJX0<>FZ033UZP0UW6V00800000
0`2[R[820:V2Z`80P>Ga00H0DlRU09ecX`2MLj<0VFnQ0:JRdP2oU:/20>7m`080TfRN0`2IKj420>kG
^`0508B^l02hPYX0Xh:`0000002SP[000P2VPjl209Bil@<0b9n^0P2TeoX00`0TP>P0Kf6c06mQ/`02
089f_@<0Nf>/0P2IM:L202HZW`040??^_@2oYKl0_jFo0;nU_`<0O6>/00@0GUjj06m]`@24LkP0Q7>h
0P2^PZD20;^5VP040;Xl4`3_gKl0n^NA0?[WT@80c;O600<0i[j^0?3eZ@3F[k400P3F[k440?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0703oool002d0oooo0P0000060?ooo`040?ZaC@3@XaD0n:MF0?FS
GP80mL:H0P3S/:000`2ePI`0gZjU0=j^Y@020=j^Y@030=f`Z03L/J`0eZf_00<0eZf_00@0m_2V0>S>
_03Xc[`0_HnV0`1bGjd20>W=^@<0Xgn]0`2mT:L0102eQjD0k/BX0>k4Z03^a:P20<FHZ0050:J;^03Q
i=D0hNCE0;7LL`2Fl]<00P3WeL@30=Be^`80XWNS0`2AJZ430>kdaP80SgFb0P28MKL309b3]`030;JU
b020FYd0P5ZM0080ESbF00<0amkZ0:=n[02SOZ`0103EdmL20:=fX@060:5bWP2XQk80Z8Nb0:R7/P2i
QYh0Pkgj0P2;P<8208^;cP80Rfn^0P2VNjD20:mlW@<0nMNU0P3`hKl30:MdVP<0YJ;B0`3A/KX00`3H
a<L0R6n`08Q_/0020;JK_@030=Bna02DI9H0U6BF00@0hMK<0P2`Oil20:A`U`030??7XP3?VYl0ciZO
00<0lmaa00D0^X^S0?cIW`26L;@0QW2d0=Jh_00207j5d0<0000000D0jMc609:8aP2BR<H0TXS60;6R
b0020<>W_@<0XY730P2l]=820:J>^`@0dkJm00@0VhFj0;:[d@2bZm40dkJm0`2^P:8208iYX`80WG>S
0`2?IYl208UQWP0409IVV02Gf?d0Pf>U08=SY@<0QF:R00<0V6^M08IHU03FWY/00P3FWY/20:MgW@04
0:miV02fOIH0]WfF0;ImUP80LdZB0P2LL:00102/Oj<0KdjJ044eW002498205MK^`<0c9NO00<0cinV
0=bSV@3R[Z000P3R[Z030;V<Y`060=ZWXP3AXZP0dJ:X0=6RZ02hRjH0dJ2U0`3>Ui/0103AUYL0b9JS
0<RFX`2kQih30<bFWP040;f=X`3P[j<0h:nS0<:CY@<0aiJS00@0gJjV0=:RY@3BXZD0^hbT0`33UZP0
0`2FLJH0nN6[000000030:^:/P050:V2Z`1bL<80LW32076bn@3KmId00P2MLj<209U_X@030>7m`02B
LJX0TW6Z00<0TfRN0P2IKj420>kG^`0507eb^`2hPYX0Xh:`0:>2/00000000P2VPjl00`3A]Kh0b9n^
0<RO[P020<RO[P030>Fn[`2QV</0XIS;0080Kf6c0`22M[d00`1EFk`0Nf>/09UdY`020:nH_P<0Th2k
0P2oYKl307aS[080GUjj0P24LkP01`2^PZD0^hFJ0;^5VP2kQIX0/Xj`0>oM_`3jii400P3<]lH20>Jn
[P030=RXY`3//iH0eZna0080hm_>00D0j]G00?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01`0oooo000/
0?ooo`030000003oool0oooo00H0oooo00<0jZT[0=2S5@3hYeH00P3e`YP30>>`X0030;F1W03N[ZD0
gZjU0080gZjU00<0gK2X0=J][`3F[Jl00P3F[Jl00`3fl:H0j<jl0>S>_0020;f?YP<0LUn]0P3YcKT0
0`3DZjl0Xgn]0:=o[@030;f@Y`<0k/BX0`35V:P30>7Te@030:V4[@2?M;40SgBa00801W[P0P3D]K/2
0:9gX`80TFZQ00@0JmOf0;^jf02k^]P0k_C60P2?MK830=3ViP80W8>g00<0]ZG8081JW@20FYd00P1F
?9H00`2CJj40Xgj/0:Ohf`020:Ohf`80eM?G0P2SMZ420:5bWP030:R7/P2iQYh0^HJN00<0SfbV00@0
YGjX08^;cP2;Kjh0Rfn^0P2VNjD20:mlW@<0nMNU00<0l>6o0:YfVP2WM9X00P2WM9X01@3a`9h0YJ;B
0:FRdP2UX]80dK6j0080f<C70`28Kk00102fVkd0e;k409ATUP2DI9H200000080hMK<0P2`Oil20:A`
U`030??7XP3?VYl0ciZO00<0lmaa0P3lfIl00`26L;@0e[Rl000000020000000307j5d00?>;L0jMc6
0080jMc60P2BR<H30<>W_@80XY730P3:_/l207n7d@80Shg=0`3C][d30;:[d@@0[X2R0P2>JJ<209ec
X`<0SfJO0P29HIh0102]N9P0UmSm08=SY@23HjD308ERXP03040cVP26F9@0eYjK0080eYjK00<0YgNM
0:miV02_NIP00`2fOIH207=:TP0309a`X02/Oj<0[7nS0080KdjJ00<00Q2B05MK^`1GFk/00P3<Uil2
0<nOYP050=bSV@3R[Z00hZjP0>:^X03LZ:400P2iS:L00`3JYj80dJ:X0=6RZ0020;R;YP050=6PY@3>
Ui/0cYNK0<jGV`3AUYL00P38UZ<40<bFWP<0h:nS00H0`Y>U0<NFX`37UZ<0aiJS0=f^YP3BXZD30;^<
Y080`iJX00<0en_R0=j[X03NZj000`2[R[800`2]Tk/0LW32079``P020=_eW@<0WG>S0P2IKj43099a
ZP80TfRN0P2IKj420>kG^`<0OG:k0P2SP[0010000000dKFn0=6e_P3O_kP30<RO[P030>Fn[`3kiHh0
XIS;00<0Kf6c0P22M[d205EK_0<0[iRn0`2CP;/30;nU_`80O6>/0`1NG[X00`24LkP0[X:U0;^5VP02
0;^5VP80kmfo00<0n^NA092Lf`3<]lH00P3V_Zh0103HZ:L0k;>F0>?KcP3Sflh20>[E`0<0oooo00<0
00000?ooo`3oool01P3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0L0?ooo`00;03oool00`000000oooo0?ooo`060?ooo`030>ZY:`3@XaD0n:MF0080mL:H0`3S/:04
0=j^Y@80gK2X00@0ejNV0=J][`3F[Jl0eZf_0`3Xc[`30;f?YP03079O[@3YcKT0jLfi0080e:^_0`2S
Ojd20;f@Y`80ckBo1035V:P20>kA]@80ZHB]0P2?M;40103_mkH01W[P0=Be^`3D]K/20:9gX`03095Z
X@2X[md0^k[H0080^k[H00<002N`0:R`gP2X/=h00P2X/=h0103@i^H0W8>g09b3]`2LPkL2081JW@80
ESbF0P2CJj430:1fX`0409ieY03EdmL0XgJQ0:=fX@80XG:N00<0Z8Nb0;V6WP2iQYh00`2?K:H0102U
OZP0_hnS08]_[P2;Kjh20:IkY@050:mlW@3iejD0nMNU0?WGY@3`hKl00P2ZMYX30:MdVP80lL2N0P2U
X]830=S4a`<0R6n`00@0bJBc0=Bna02DI9H0U6BF0`2oT:D00`3Qe/`0/7nO0;1oW`020:A`U`040??7
XP3?VYl0ciZO0;>6Y@80]8b[00D0o=VO00000000000000000=Jh_0020>G_e00306QjdP3Yg<H0jMc6
0080jMc60`2WZ=L20<>W_@@0b[k?0P1oQm4208n=c@@0/Ic200<0/Z_A09]bX`2KLZ<00`2^P:8208iY
X`80WG>S0`2?IYl208UQWP040:ehV02Gf?d0Pf>U08=SY@<0QF:R00<0@3>J08IHU03FWY/00P3FWY/0
0`2WMid0[gVH0:miV0030;ImUP80LdZB0`2/Oj<306m>VP04008@TP1GFk/0c9NO0<bGW`80cinV00D0
g:>I0>:^X03R[Z00hZjP0=bXX@020;V<Y`030=ZWXP3AXZP0^8^V0080^8^V00D0dJ2U0<jGV`3>Ui/0
cYNK0=6FU`020<RFX`060:enX@3<UYh0c9JN0<bFWP3LZJ80h:nS0`32TjD01037UZ<0gJjV0=f^YP3B
XZD30;^<Y0030<>FZ03Gjn80nN6[0080gZ^P00@0oMb20:fC^`2]Tk/0[I>k0P2>KJP20=_eW@<0WG>S
0P2IKj43099aZP80TfRN00<0VFnQ0>3[Q@2VT/400P2VT/401P1EHL80OG:k0:>2/02SP[0000000=6e
_P80gknh0P38Wjh20>Fn[`030?_USP2QV</0UW>Y0080UW>Y0P22M[d305EK_080[iRn0`2CP;/30;nU
_`80O6>/0`1NG[X00`0JAKl0[X:U0;^5VP020;^5VP040=Jk=@3jii40T9cK092Lf`80i[j^0P3HZ:L0
0`3//iH0b;P_0>?KcP020>[E`0@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0L0?ooo`00;03oool0
0`000000oooo0?ooo`060?ooo`040>ZY:`3@XaD0n:MF0?G2V0@0hk2P00@0cZVd0=j^Y@3N[ZD0gZjU
0P3M/:P20=NWYP040=J][`3kj9X0mmR[0?OHZ`@0_HnV00<0LUn]0>W=^@3YcKT00P3DZjl30:=o[@05
0;f@Y`3?];l0ckBo0<nd_`30TZH00P35V:P30>kA]@80ZHB]00@0SgBa0>og]P3_mkH0koNf0P3D]K/2
0:9gX`030:R_g@32Y[d0`ZJm0080^k[H0P009k020:R`gP80aK7600<0d>KV09b3]`2fX/@00P20FYd2
05HlUP80Tf^Q0`2PMZ<00`2QLYh0eM?G0:=fX@030:5bWP<0^HJN0`2?K:H20;n?X`80Rfn^0P2VNjD0
102_O9d0nMNU0?WGY@3`hKl30:YfVP<0YgBJ0P3a`9h00`3nh9H0Y9[;0:BJb`020=S4a`80R6n`0P2a
T[H00`39Y;<0U6BF09ATUP030;n@Y@040>7Fc02`Oil0/7nO0:A`U`<0llNR00<0ciZO0;>6Y@000000
0P0000020<c5d`040=Jh_03Ukm@0iNoD0>G_e080J7[B102Y_NP20:NXe`050<>W_@2jWkd0^Ynm0;ZO
_@2@k^`00`2/h_T30:JTe0<0/Ic20`2KLZ<30:j0XP80SVVS0P2MLj<308mVW`0408UQWP2]N9P0[GRH
09IVV0<0Pf>U0P25HZ800`10<iX0eYjK0=JNV`020=JNV`<0[gVH0`2fOIH207=:TP030;fAZ@2/Oj<0
[7nS00<0KdjJ00<00Q2B02/bY@3<Uil00`3?WjH00`3LXiT0hZjP0>:^X0020=bXX@030;V<Y`3JYj80
fZNR00@0^8^V0`3>Ui/20=6FU`030<RFX`2]OZ40[GjQ00<0c9JN00<0g:VR0>2_X`32TjD00P32TjD0
0`37UZ<0gJjV0=f^YP040;^<Y080en_R00@0nN6[0=j[X03NZj00oMb20P2o_mX01@2/a4P0SVfX08i]
Z00l<id0foFM00<0WG>S0P2IKj400`2GcFD0TW6Z099aZP0209=XWP0309U_X@2bRJ/0/XV[0080YY;1
0P1EHL830;WDkP060000003O_kP0gknh0=no^038Wjh0iKj_0P3kiHh20:9mZ`80UW>Y0`2?L:`01001
F]@0EE^l0:nH_P2_V;h40;_5hP80O6N`0`2UZ=P00`3cg;L0<@0001Y5_`040;^5VP030=Jk=@000000
T9_K0080T9_K00D0i[j^0=RXY`3HZ:L0k;>F0<Rh;`030>[E`0D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0L0?ooo`00;03oool3000000H0oooo00D0jZT[0=2S5@1iF9l0NERO0>:dYP020>>`X080cZVd
0P3N[ZD20=f`Z0<0ejNV0P3kj9X20?OHZ`040=BXZ`2mSjH0_HnV0;f?YP80jLfi0`3DZjl30:=o[@<0
ckBo0P30TZH20<FHZ080k]6e0`2YQ:d00`2?M;40koNf0:N_g@020:N_g@80YZGE1032Y[d01032ZL80
QVnb08I_/P2RQ;@40<FaaP03000IY@2fX/@0]Z;40080P5ZM0P1F?9H209=[X@80X7JS0P2KJiX00`2Q
LYh0XgJQ0:5bWP020:5bWP030=BSY@2iQYh0^HJN00@0UVjS0P2oSj<00`3O[jD0YW^U0:IkY@020?WG
Y@030<jY]03W_J/0^X>I0080ZWJJ0P2WM9X30?70WP050?kPUP2TV//0[hb`0:n</01fHk00102aT[H0
0`39Y;<0U6BF0<FP/`030;n@Y@040<RT]02`Oil0/7nO0:A`U`<0llNR0P0000000`2dS:/0o=VO0<c5
d`020<c5d`@0iNoD102nm?420:Vmj080YjSG102jWkd00`3?[KP0nnVM0:cRn@020:cRn@<0YZCD00<0
/Ic20;VJ^02iV[P00P2KLZ<30:j0XP80SVVS0P2MLj<308mVW`0408UQWP2]N9P0[GRH09IVV0<0Pf>U
0P25HZ82040cVP<0eYjK00<0/7bK0:miV02_NIP00`2fOIH00`1cBY80_I6Y0;fAZ@020:aoX`<0KdjJ
00<0>c2J02/bY@3?WjH00`3?WjH30>:^X080g:RQ00@0^HbW0=ZWXP3JYj80dYjP0`2hRjH00`2cP9`0
cYNK0<jGV`020=6FU`030<RFX`2]OZ40[GjQ0080c9JN0P3LZJ840<:CY@<0gJjV00H0h[Z_0;^<Y02k
S:@0^hbT00001@3ihJ/20=j[X080oMb200<0g;nl0;nofP2/a4P00P2>KJP00`0l<id0foFM09ecX`02
09ecX`0509U_X@2GcFD0UleU000T[02BLJX00P2CJ9h30;:9Z`80YY;10`1EHL820;WDkP040=no^000
0000gknh0=no^080iKj_00@0nnF>0:9mZ`2ROJ/0XWf[0P2FLjT308m`[00506A?Y@0F>kP0QP8007B;
f`0000000`2kaN8307aW/0060:FXf03cg;L0k/b_0>k<[`0a00006TFo0`2kQIX00`3F^cD0Mg[907Mj
b@02092Kf`80f:RW0P3//iH01038^2l0oMbN0>[E`03ZeL050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0703oool002`0oooo00<000000?ooo`3oool01`3oool307UHW`030>:dYP3S/:00cZVd00<0cZVd
00<0gZjU0=f`Z03M/:P00`3GYjH00`3kj9X0mmR[0?OHZ`020=BXZ`<0_HnV00<0joN[0=B[[`3DZjl0
0P3DZjl20:=o[@80/io400D0ckBo0<2BYP30TZH0`9:V0<FHZ0030>kA]@040=6QY@2YQ:d0ZHB]0?CV
^@80Z:oM0P2W[md30:nUcP80`ZJm0P32ZL8208I_/P80XXBd0P35/LH00`000000Y9c=000IY@020;JR
a080OUfR00<0ESbF09=[X@2CJj40102KJiX00`2QLYh0XgJQ0:5bWP020:5bWP040=BSY@2iQYh0^HJN
0=f^Y`<0UVjS0P2oSj<20=n_Y@<0QY3E0P3W_J/00`2jPiT0ZWJJ0:YfVP020:MdVP80lL2N0P3nh9H3
0:n</080MV>`0`2aT[H00`35X;<0U6BF0<FP/`030;n@Y@040=2[/`2`Oil0/7nO0:A`U`<000000P2c
QZD00`3HjhD0e]cL001Oe@020;ggkP80a=g[0P3HfMP307fNj080NL?n0P1a`oh208mj^080^Ynm0P3?
[KP0103kjId0koJ[05YQ_`1JHKl30:JTe0<0^IZh0P2KLZ<30:j0XP80SVVS0P2MLj<308mVW`0408UQ
WP2]N9P0[GRH09IVV0<0Pf>U0P25HZ82040cVP80eYjK0P2`O9/20:miV0<0]WfF0`2mTJT30:aoX`80
KdjJ00<0>c2J02/bY@0[<ZD00`3?WjH00`3ijJl0hZjP0=bXX@020=bXX@040;V<Y`3JYj80fZNR0=:N
X0<0^8^V00<0/h2L0<jGV`3>Ui/00P3AUYL40:enX@040<bFWP3LZJ80g:VR0>bkX0<0`Y>U00@0h;Za
0=f^YP3M[ZH0h[Z_0P2kS:@209ifY@80:P0000H0gZ^P0?gLPP3L_k`0g;nl0:f5ZP2/a4P308i]Z007
03`cW@2MLj<0WG>S09ecX`2WY]D0VG>V07YFV`02000T[080aNW_0`2bRJ/30:cIm`<0SM;n0P2;U]P0
1P3O_kP000000<k6d`3>a]<0iKj_0:f0X`<0XWf[0`2FLjT208m`[00506A?Y@0F>kP05S^h000RZ01d
Rm/00`2kaN8307aW/0060=GTh@3=b]L0cL[G0>k<[`3G]KL06TFo0`2kQIX0103F^cD0Mg[907Mjb@1g
N/T209:>b`060=RXY`3//iH0k;>F0<Rh;`3mg9h0dMYV0P2?W=`20?ooo`80000000<0oooo0000003o
ool0103oool4000000D0oooo1000000O0?ooo`00;03oool00`000000oooo0?ooo`070?ooo`80NERO
0P3R]:H50<jY]080gK2X103GYjH00`3kj9X0mmR[0?OHZ`020=BXZ`80_HnV00<0joN[0<gMi@3=gND0
0`3DZjl40;>Oa0@0`9:V00<0aIRX0>kA]@3^dKD00P3AXJD00`2YQ:d0m>Ji0?CV^@0309]o]080UXW3
0`2_YLh00`32Y[d0`ZW20<:Y`P0208I_/P80XXBd102KM:H00`2TW<d0]Z;4077GY00207iMXP0406I8
VP2GJ9X0UfRJ09MXVP<0Vf^J102QLYh20=BSY@80^HJN00D0gJjW09I^X`2FKZ<0UVjS0;n?X`030=n_
Y@040<jY]026T=D0cZVd0>NmZ`80^X>I0P2ZMYX20:MdVP80lL2N0P3nh9H00`33VZh0[hb`0:n</002
07IS/0<0/I:f00<0]i:a09ATUP35X;<00P2oT:D20=2[/`<000000P3caj800`3DaL/0/hJU0;>6Y@02
0=KLg0@0LL;n0`3HfMP40:FMc@80U9GA00@0LL?n08mj^02?N[P0^Ynm0P3?[KP00`3kjId0koJ[0>of
Z`0305YQ_`<0SHg>0P2iV[P309]bX`80[X2R0P2>JJ<209ecX`<0SfJO0`2]N9P309IVV0030:IdV`25
HZ80QF:R0080@3>J0P3FWY/20;1lV`80[gVH0`2fOIH00`3lhZ@0_I6Y0;fAZ@030:aoX`80KdjJ00<0
>c2J02/bY@0[<ZD00`3?WjH00`3ijJl0hZjP0=bXX@020=bXX@<0fZNR00<0dYjP0;R;YP2hRjH00P2c
P9`20<jGV`80dIJG00D0m;Z=0:enX@2]OZ40[GjQ0<bFWP020=bYXP030>bkX032TjD0`Y>U0080h;Za
00<0gJjV0>:j[`3R^Zl00P2kS:@209ifY@0402hdYP0Z0000gZ^P0?gLPP80g;nl00<0[HFZ00HYZ`2>
KJP00P2>KJP0100l<id0YjKE0:NVe@2WY]D209UcYP80NUJK0`2PN:L30;:9Z`060<^NZ@2bf_D0/][e
0;;Jm@1NO=T0aif]0P2;U]P0103>a]<000000<k6d`3>a]<20:f0X`<0XWf[0`2FLjT208m`[080I4nU
0P2<L[4010008ZP0MF^j07E[^P2kaN8207aW/0040=GTh@3=b]L0cL[G0<g:e`80ekFg00D06TFo0;^5
VP2kQIX0^hFJ09ak[P0307Mjb@80TXk;00<0f:RW0>bcUP38^2l00P3mg9h00`3AfVH0SicL08nLg006
0?ooo`030000003oool0oooo02h0oooo000[0?ooo`030000003oool0oooo00P0oooo0P1iF9l20>:d
YP040>c3ZP3>ZK@0cZVd0<jY]080bjFb00D0gK2X0=NWYP3GYjH0ejNV0?_XVP020?OHZ`<0e:R[0P2m
SjH40<gMi@030=B[[`37/lH0ak?600<0/io400@0clC?0<2BYP30TZH0`9:V0P3^dKD30=6QY@040=GX
O`3di[T0]9>e0;BC]@80Vgnd0`2FRL<20:nUcP030<;Ci`32ZL80`ZW20080QVnb00<0XXBd0:EkY@2U
NjD00`2KM:H30;NC/`80OUfR0P1VB9X209MXVP<0Vf^J102QLYh20=BSY@80^HJN00D0gJjW09I^X`2F
KZ<0UVjS0;n?X`030=n_Y@040?_TY@3>ZK@0ikf[0>NmZ`80^X>I0P2ZMYX01@2WM9X0lL2N0?70WP3a
`9h0o^2F0080`iZ^0P2_S;0307IS/0030;6B]P2gT[40]i:a0080aJ2c00@0_i2U0000000000000000
0P3E_l@20??7XP80e<G;00<0/hJU04ZCl034f^T00P34f^T20;R^c`80R[;a0`2l`]l30:FMc@80U9GA
00<0002708mj^02?N[P00`3?[KP0103kjId0koJ[0>ofZ`3_mZ/205YQ_`0304=6[`2=SLh0SHg>0080
^IZh0`2KLZ<20:j0XP030:j2Y@2>I9d0SVBM0080S6BN0`2=HY/20:ehV0<0UVJH0P2VM9/0102_OId0
N0dX040cVP3FWY/30;1lV`80[gVH0P2fOIH20?cRY080_I6Y0`2/Oj<206m>VP80>c2J0P0[<ZD00`3?
WjH0nNV_0?WY[`040=bXX@030<jNYP3JYj80dYjP0080dYjP00@0^8^V0;>0W02cP9`0cYNK0`3AUYL0
103d^Xd0[GjQ0:enX@2]OZ430=bYXP030>bkX032TjD0`Y>U0080h;Za00D0gJjV0>:j[`3R^Zl0^hbT
0=RSX00309ifY@0402hdYP3NZj00g;nl0=bo_080[HFZ00@0WgRX08i]Z02>KJP0SVfX0P0l<id0102W
Y]D0Si[J09UcYP2ILjH307YFV`80X7RW0`2bRJ/0103;WZT0fjFM0;;Jm@2bf_D40<NM[@80cj>[00<0
00000>_5[P2]P:<00P2]P:<20:9mZ`<0UW>Y0P2?L:`206A?Y@<0S7:a00<002:X08nXiP2?Z>H00`2E
R<<01P0c03T0cL[G0=Gai03ElN@0ekFg0>K6]`80^hFJ00<0e[/e09ak[P3/h/H00P0^V?4209:>b`05
0=RXY`3//iH0b;P_0?gLWP3AfVH00P2<hZ8208nLg0D0oooo00<000000?ooo`3oool0;P3oool002/0
oooo100000070?ooo`80NERO0P3R]:H20>c3ZP040<jY]03;YK80bjFb0<^U/P@0ejNV00<0nnRJ0?OH
Z`3DZ:/00`3DZ:/00`2mSjH0oooo0?ooo`030?ooo`@0ak?600<0/io40<o4c`3?a<l00`30TZH20?SY
/P<0dJ6U00@0m>Ji0;BC]@2dTkD0]9>e0P2KOk@209J9``80bifW0P32dnL20<:Y`P80QVnb0`2UNjD3
09]dYP030=6TZP2gTk<0]i>c0080OUfR0P1VB9X209MXVP<0Vf^J0`2QLYh30=BSY@030;V6WP3M[ZL0
gJjW00<0UVjS00<0_hnS0=n_Y@3O[jD00P3ki:D00`3>ZK@0ikf[0>NmZ`020;Z3V@80ZWJJ00<0YgBJ
0?70WP3a`9h00P3nh9H20<>J[P80[hb`0`1fHk030;NB/@<000000`3@Zk<30=Foa00404iOa02Ve_P0
e<G;0;>6Y@80L<;n102h[/l30:S@m0<0_<;O0P2UWLd308VZj`<0^K7B0P3?[KP20;6=/080Ngo<0P1J
HKl00`13AZl0SHg>08f=cP020;VJ^0<0Vg:S00<0[X2R0:j2Y@2^PZD00P2>I9d208aTWP<0SF:K0P2]
N9P309IVV0050:IdV`2_OId0[gfM0:IdV`1<Ck@0102`O9/20:miV080]WfF0P3lhZ@20;fAZ@<0[7nS
0P1_CYX203/`VP0402/m/@0[<ZD0cinV0?WY[`80[i_30`3LZ:400`3>WZH0fZNR0=:NX0020=:NX004
0;R;YP2cP9`0/h2L0<jGV`<0dIJG00H0m;Z=0:enX@2]OZ40[GjQ0<ZLZ03LZJ820>bkX0040<:CY@3P
^[40h;Za0>2j/@<0h[Z_00<0^hbT0=RSX02NMZD00P2NMZD0100^=:H0g?;N0=cbgP3L_k`20:f5ZP04
0;B3X02ON:P0WgRX0>bkX080?3>M00@0b^G[08nJfP2?V]X0VG>V0`1jEY/30:1hY`050;:9Z`3;WZT0
bijY0=^UW@2l[B400P20S=H30<NM[@040=no^03?Xj/0cj>[000000<0[H2S0P2ROJ/409YdY`0408m`
[01TCjD0I4nU06A?Y@80S7:a00L0HfO208nXiP2?Z>H0SjSV09F8``2OQ;L0NFfi00<0eO7T0P3Va[L0
0`0JAKl0^hFJ0=Jk=@020>cRaP80h/>i00@0BFcB03:Hl@3//iH0k;>F0P3mg9h01@2`V;h0QW>f08Ic
]P00?l40SicL00H0oooo00<000000?ooo`3oool0;@3oool002/0oooo00<000000?ooo`3oool0203o
ool00`1iF9l0h[BV0>:dYP030>c3ZP@0bjFb00@0ek:d0=NWYP3GYjH0ejNV0P3/jHH0103?ZK<0e:R[
0=BXZ`3DZ:/70?ooo`<0ak?60`3?a<l20<2BYP80n>Vb00<0K@000=6QY@3AXJD00`2>K:L20;BC]@80
Vgnd0P3=aM<20<^MY`030>2^XP19[_T0BJki0080QVBT0P2>J:820:EkY@80VgBV0P3AY:X20;NC/`80
OUfR0P1VB9X209MXVP<0Vf^J0`2QLYh30=BSY@030;V6WP3M[ZL0gJjW00<0UVjS00<0_hnS0=n_Y@3O
[jD00P3ki:D20>NmZ`<0^X>I0P2ZMYX0102WM9X0lL2N0?70WP3nh9H30<>J[P030:n</02SOZ`0Xgj/
0080TFfV0`00000309QdZ@80d:^c0P3ekkH0103:Z;L0`^ka04iOa01>Gl@309;WnP80RJSY0P2h[/l2
0=W[h0<0Z=3d0`2BS<X20:VfhP<0RJ[[0`2i/M840;6=/080Ngo<00<0FV6o04=6[`13AZl00P0YS^h0
102iV[P0Vg:S09]bX`2KLZ<30:j2Y@80SVBM0P2<I9h308eRV`80[GRH0`2FIYP0102VM9/0[gfM0:mm
W@2VM9/204a?]0<0/7bK0P2_NIP0102fOIH0o>:T0?cRY03lhZ@20;fAZ@<0[7nS0P1_CYX303/`VP03
02/m/@3ijJl0[i_30080[i_30P3LZ:420<jNYP040=ZWXP3BWZ00dYjP0=:NX0<0/h2L00D0cYNK0=6F
U`3AUYL0dIJG0?BjS@020:enX@80bYbX00<0g:VR0>bkX03/^j000`3P^[420>K>_P80h[Z_0P3HXj03
09ifY@<0g?;N00@0ikVU0:f5ZP2dPj00]8>P0P2ON:P20>bkX0050<[Uj`2k/<l0^k3?08nJfP2ILjH0
0`1jEY/30:1hY`050;:9Z`3;WZT0bijY0=^UW@2l[B400P20S=H20<NM[@80gknh00@0cj>[0>_5[P3[
aJh000000P2]P:<309IYW@<0VWBW00D0NfNa06A?Y@1TCjD0I4nU08ab/@020:N6/@<0UWbd0P2OQ;L3
07U]^@80TWF_00H0i/Jg01Y5_`2kQIX0W7^^0>cRaP33kI020>;3^@040>?=`P2FW]X0<YSa0>bcUP<0
/9Rn0`26LkH00`1LH;d0oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo000>0?ooo`@00000
1P3oool2000000H0oooo100000070?ooo`030000003oool0oooo00P0oooo00<0NERO0>:dYP3R]:H0
0`3/`jX00`3WakH0bjFb0<^U/P020=Nb]080ejNV00@0nnRJ0>cYQP3?ZK<0cjVc0P3DZ:/<0?ooo`80
clC?0P30TZH00`3hjK80DTVY06d000020=6QY@030<Z[^P2>K:L0SVbW0080]9>e00<0Vgnd0<g5d`3=
aM<00`3;WJL00`3P[Z80mlZL04V^n@0208ITY080SVRR0P2UNjD209]dYP80dJBZ0P2gTk<207iMXP80
ITRJ0P2GJ9X309][VP80XG:N103DXjD00`2iQYh0gJjW0=f^Y`0309I^X`80gjnU0P3ki:D20<kod`04
0>NmZ`2jPiT0^X>I0;Z3V@80ZWJJ0`3a`9h20<>P]@80`iZ^0P2SOZ`300000004095]YP2gT[40]i:a
0<ZW]P<0V7BY00H0d:^c0?G_]P3:Z;L0bZRg06=K]02UkOP40;6ih0050021f`29Z>T0RJSY0=W[h00^
Y?000P33bMl309F0^P80TXc:0`2KNZh2046=kP80fmgH0P2`XLP30;6=/080WlOd00H0ZKkX0:bLaP2/
W<H0[9c602V>kP0@AL<40:^=]`80[X:U0P2>I9d208aTWP<0SF:K0P2]N9P309IVV0<0[gfM00<0YWBK
04a?]01<Ck@00`2`O9/20:miV0040;ImUP3lhZ@0o>:T0?cRY0@0_[cG0P16YOL208mi]`80DWKH0`2W
RKD30:nK``030=bXX@3>WZH0cYjV00@0dYjP00<0e:>U0;>0W02cP9`0103AUYL00`3d^Xd0[GjQ0:en
X@020<ZLZ0050=bYXP3/^j00k;^P0<fS[@3P^[400`3Vc[h20>:n/P80f:>P0P2NMZD20=_2`@<0ikVU
00@0[HFZ0;B3X02dPj00WgRX0`3/^j00103ofi40c]5F0;^`c`2k/<l209UcYP<0NUJK0P2PN:L20<^N
Z@80fjFM00D0_:dQ082<eP20S=H0P8cF0<NM[@020=no^0040<nSZ`3[aJh0jlF^00000080[H2S00<0
/GjM09IYW@2FJId00`2JM:L207]W/@80N6Vf0`2WQ[4309Il]080WhBg0`1iKKT2099e[`80i/Jg00<0
^hFJ0>cRaP3/h/H00P3R`kT20>?=`P0409JNfP3Gl^<0k;>F0=oaf`<0/9Rn0P26LkH205aP_@H0oooo
00<000000?ooo`3oool0;03oool000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool30>:dYP80k<>Z0P3WakH20<^U/P<0ek:d00<0ejNV0=S4aP3?ZK<00P3?
ZK<00`3DZ:/0oooo0?ooo`0<0?ooo`040<o4c`30TZH0n>Vb075GY080l<j_00<0dJ6U0<Z[^P3:ZkX0
0P2>K:L20;BC]@<0cLGC0P3;WJL20>2^XP040?O:W019[_T0QVBT08ITY080SVRR0P2UNjD0102KM:H0
dJBZ0=6TZP3AY:X20;NC/`80OUfR0P1VB9X209MXVP<0Vf^J00<0XG:N0:^3Z@2[PjT00`3DXjD30=f^
Y`80UVjS0P30Yl000`3O[jD0nnBU0<kod`020<kod`@0^X>I0P2ZMYX20?7M^`<0`j2e00D0`iZ^0000
0000000000000:=n[003095]YP030;NB/@3:YkH0bZNf00<0V7BY00@0mNnf0<ZX]`3:Z;L0bZRg0P1S
Fk@00`3?nk<0/KWP0;6ih0020;NN_`80Offd0P2=Sm020<?9g`<0UH2j0`2WQk8309]j[P80@Hg^0`2`
XLP30;6=/0040;WRO03@gN80d=gR000CX080[9c600<0EDn_0115``0@AL<00`2[SKL20:j2Y@80SVBM
0P2<I9h308eRV`80[GRH0`2FIYP0102aOih0[gfM0:mmW@2VM9/204a?]0<0/7bK0P2_NIP20?cRY003
0;9nV`2aNYP0/GZH0080_[cG0P36S9L00`16YOL0SgVg08mi]`03059ff080YhVe0`2_Vl<30<jNYP05
0?_NX`3BWZ00dYjP0=:NX03DXjD00P2cP9`01P35SIX0dIJG0=6FU`3AUYL0m;Z=0:enX@<0bYbX0P3/
^j020<fS[@@0i/jn00D0bJ>b0>:n/P3HXj00f:>P09ifY@030=_2`@<0ikVU0`2dPj001P2ON:P0k;^P
0>bkX03/^j00om^A0<kAEP80[8ff0P2ILjH307YFV`80X7RW00H0]Xj/0<^NZ@3KYId0fjFM0;b]8@00
000204iPa@<0gknh103[aJh00`000000/GjM0;5nW@0209IYW@<0VWBW0P1kIk4307QY]P80YhJa0`2F
O;@209n4]`<0NFfi0P2BMJl01`34V:X0UXg80;^5VP2FSLP0f]OD0=J^/03R`kT00P3ScL80103Gl^<0
go7K0=oaf`3OlM/30;2H_P80QW>f0`1LH;d60?ooo`030000003oool0oooo02/0oooo000=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`80
00002P3oool0103R]:H0k<>Z0>c3ZP3/`jX20>O7]P030<^U/P3G/[@0ek:d0080ek:d00<0f<C60<nY
/`3?ZK<00P3?ZK<B0?ooo`80LENT103:ZkX208i/Y`@0Y82]0`3;WJL20>2^XP040?O:W019[_T0QVBT
08ITY080SVRR0P2UNjD40=6TZP040>[;]P28V]h0R9[N07iMXP80ITRJ0P2GJ9X309][VP<0Zh>Y0P3D
XjD20>G`e@80gJjW1030Yl0309g5m003000?U@2;Hih0Rf>N00<0^X>I00<0ZWJJ0?7M^`3agK/00P33
X;D300000080j^g>0P2SOZ`3095]YP<0bZNf0`2HM:T40<ZX]`0406=K]03?nk<0co^c0<ok/`<0]ijo
0P1oKK@208f?d0<0`lWO00<0UH2j0:Ao[02TOj`00P2WQk8309]j[P030=Zc/@2?LJh0Sg6^0080/:78
0P2aSK001@1niNh0d=gR0=3MhP3@gN80ZKkX0080[9c60P1ECjl0100@AL<0Zhfg0:^=]`2[SKL20:j2
Y@80SVBM0`2<I9h208eRV`80[GRH0P2FIYP20;5oWP80[gfM0P2VM9/0101<Ck@0/7bK0;1lV`2`O9/2
0:miV080_HFH00<0/WjK0;5jV02aNYP00P33RIH20<J<U`0404JUm`2?NKL0SgVg0<k3c`80DWKH0P2W
RKD409f@aP80cYjV00<0nmjS0=:NX03BWZ000P3DXjD20;>0W0030<F=VP3AUYL0dIJG0080m;Z=103:
W:P01@3bjX`0k;^P0<fS[@3=Xjd0k/N[0080i/jn0P39Xk830=RSX0<0fl;1103W^JD0102/OZ<0]8>P
0;B3X02ON:P30>bkX0030<kAEP3Km=l0foCO0080[8ff00D0VG>V07YFV`1jEY/0NUJK0:1hY`020;J>
[0030<^NZ@3KYId0fjFM008000000`1>H<D00`3O_kP0e][K0=KJf`030>_5[P030:f0X`000000/GjM
00<0UVVM0P2JM:L207]W/@<0N6Vf0P2WQ[4309Il]080WhBg0`1iKKT00`2BMJl0a9RZ0<BHZP0209J=
b0030=[Ge03F[[00eZj`0080hlg20P2Hh_d30=oaf`<0/9Rn0P26LkH305aP_@@0oooo0P0000000`3o
ool000000?ooo`0[0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030>:dYP3/`jX0k<>Z00<0
ilNf103G/[@20=S4aP040?ooo`3?ZK<0cjVc0<nY/a80oooo0P1aEj@0103]lIX0bZ^j0<Z[^P3:ZkX2
08i/Y`050<fc`02TP:d0Y82]0:B0[@3dfk@00P3;WJL0103P[Z80mlZL0?O:W03S/Z@208ITY080SVRR
00<0YG^U0;JF]P2fU[H00`3AY:X20>[;]P80R9[N0P1VB9X209MXVP80Vf^J0P3H^KX20:^3Z@050=BS
Y@3Ul=D0iO3E0>G`e@3M[ZL00P2jo</20<2W`0<084>l0P2Jg?d208]SWP<0^X>I00<0ZWJJ0?7M^`2T
Oj`00P0000020<>P]@<0j^g>0P2SOZ`2095]YP80g<O50P3:YkH209QdZ@80_Z>m0`3:Z;L00`31_mT0
bj:_0<^R[`0208f^k080]ijo0P1oKK@30:Ao[080M5bX0`2TOj`20:N7/P80VgZ^0P3J/k4208ma[P80
/:7800@0/Hf`0:2jj`3;aM@0blGD0`2c[=420:bLaP80EDn_00@0=3BS0:^=]`2[SKL0Zhfg0P2^PZD2
08iTW@<0S6BN0P2=HY/20:ehV00409IVV02aOih0/GnN0;5oWP80[gfM0P2VM9/0101<Ck@0/7bK0;1l
V`2`O9/20:miV080_HFH0`2aNYP20<>9UP80aXbG00<0^86I08mi]`3>`ll00P3>`ll0101BM]P0YhVe
0=oLd`3Og=<309f@aP050<jNYP3kgZ<0nmjS0?_NX`3BWZ000P3DXjD20;>0W0030<F=VP3AUYL0dIJG
0080m;Z=00D0h:fP0<ZLZ03:W:P0bYbX0?;ZS0030<fS[@80k/N[0`39Xk801`36UjH0f:>P0=RSX03T
`[D0fl;10:VkiP3Qe<X00P3W^JD20:anX`80]8>P00@0WgRX0>bkX03/^j00om^A0`3Km=l20:b=]P04
09UcYP1jEY/0NUJK07YFV`<0]Xj/00D0bijY0=^UW@2l[B40_jBn08=c^@0304iPa@<0e][K0`3[aJh2
0;5nW@040000002FJId0UVVM09IYW@80VWBW0P1kIk4307QY]P80YhJa102QT/D20:6:_00306YI[@1i
KKT0TWF_0080a9RZ0P3Jem@30=J^/0030=kPL0000000Sh_;0080Sh_;0`1aX^l308bTi080UJWT0`2Y
]^860?ooo`030000003oool0oooo02X0oooo000=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0`3/`jX3
0>O7]P030<:S^@3G/[@0ek:d00<0f<C600<0oooo0<nY/`3?ZK<04`3oool2075GY080kO6J0P3:ZkX0
0`2>K:L0cK?00<fc`0020:B0[@80m=^d00<0bifW0>2^XP3P[Z800P3gbY`00`3S/Z@0QVBT08ITY002
08iXXP<0]YJf0P3AY:X30>[;]P80UXBm00D0^I2]06I8VP2GJ9X0UfRJ09][VP030=Ri^P80Zh>Y103U
l=D00`3NclT0_9Na0;bG/@020:^4Z`030?;Q_02<W=d0S9cM0080bOC/0P2;Hih30;Z3V@<0000000<0
Y7n/0<>P]@33X;D00`2ennL0103ZkLh0Xgj/0:=n[02AKJH30=c7a@80bZNf00<0V7BY0;jS_@2nXkd0
0P2nXkd20<6of@<0bj:_00@0hkR[08f^k02gW[l0]ijo1@2TOj`307ALZ080Y7n/0P2WQk80102KNZh0
f[>a0=Zc/@3J/k4208ma[P030<6gd03=WZP0OG2j0080blGD0P3;//830;>/d@0402IEbP1ECjl0EDn_
03@dX`<0Zhfg0P2^PZD208iTW@<0S6BN0P2=HY/20:ehV0@0/GnN0P2_OId20:IdV`050;Z6W@1<Ck@0
/7bK0;1lV`2_NIP00`2mQIP00`2oQYP0/GZH0;5jV0020<>9UP80aXbG00<0^86I0<k3c`3>`ll00P3>
`ll00`008Z`0gmcC0=oLd`020=oLd`80WI3600D0cYjV0?_NX`3kgZ<0nmjS0=:NX0020=BSY@030;>0
W035SIX0aHfJ0080dIJG0P3d^Xd00`3P[J00bYbX0<ZLZ0020?;ZS0030<^ha`3=Xjd0k/N[0080k/N[
0`39Xk801@36UjH0f:>P0=RSX03T`[D0ZK_V00<0hMC:0`2/OZ<20;B3X0<0k;^P00@0om^A0=_dg`3K
m=l0foCO0P2/SKH00`002YL0NUJK07YFV`02087DQ`80]Xj/0P3KYId20;nT_P80Pg>i0`1QS^L30;2H
_P<0QVj`00<0/GjM0000002FJId00P2FJId00`2JM:L0Yg^T0:MkY00208Q/Z`80NfJ_0`2o_mT30:6B
a@80XHZl0P1ZFJd30<BHZP030?;=Z@3F[[00eZj`0080eZj`00<0g^1`0>^dV02?Rl/00P2?Rl/00`00
4j40OH7<07f1c00308bTi0<0XZcN00@0ZKKR0:FLc02UW<`0YIc<1@3oool00`000000oooo0?ooo`0Y
0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo100000060?oo
o`030000003oool0oooo00X0oooo0P0007d30>O7]P<0`Z>i0`3Ha<H30?ooo`030<nY/`3oool0oooo
0140oooo00<0LENT0>gaVP3oool00P3oool01000K=<0cK?00<fc`03=/l020:B0[@80m=^d00<0bifW
0>2^XP3P[Z800P3gbY`0103S/Z@0QVBT08ITY02>J:820;Rfe`<0]YJf00D0dJBZ0>[;]P3ZbkH0VWJY
09J4_@020;V@[@0306I8VP2GJ9X0UfRJ00@0f;Vj0P2[PjT0103Omj<0fncO0=_/g`3Kk=l30;bG/@05
0:^4Z`3bhK`0l^6l0?;Q_039m>`00P2XP:P208]SWP<0000000<0cMAK0=6b^`2TOj`00P2TOj`00`35
UjP0ZXRa0:Z8/@020<OOjP80Xgj/103LalD20<ZW]P0704I9/03PoK/0_Z>m0;jS_@2[Q:`000000<6o
f@020<^R[`80hkR[00@0IFBl08f?d02=Sm00SHo@102TOj`307ALZ080Y7n/0P2WQk840=Zc/@0408ma
[P31]m00cIjX0<fNZ080OG2j103;//830:Vmj004081e_@1ECjl0=3BS03@dX`80GF_80P2^PZD208iT
W@<0S6BN0P2=HY/20:ehV0040;Z;X`2aOih0/GnN0;5oWP80[gfM00@0YWBK0;Z6W@2jQYd0C4nd0P2`
O9/01@2_NIP0_HFH0;f5V02mQIP0_hJH0080/GZH00H0`hVF0<J<U`36S9L0aXbG0;R1V@3MX9<409ak
[@0407iQYP3Og=<0gmcC0=oLd`80WI3600@0cYjV0?_NX`3kgZ<0nmjS0`3DXjD01@2cP9`0aHfJ0<F=
VP35SIX0dIJG0080m;Z=0P3P[J001@3:W:P0l^Z<0<^ha`3;^<L0cJ>]0080k/N[00<0m>Z=0<VS/P39
Xk800P36UjH00`3HXj00i<:e0>C2]@030>7DbP80WgBQ0P2/OZ<20;B3X0030=^]Z03/^j00k;^P00<0
Y7jZ00H0f:FR0::=_`2RSKl0XXfo0:JEa0160002087DQ`80]Xj/00D0h/Vn0=^UW@2oY;h0_jBn08=c
^@0207eIW@03099n^P04UkD019Ne0080/9Rn0`26K[020;5nW@030000002FJId0UVVM00<0Yg^T0P28
K:/307]V[`<0_koI0P2QT/D30:6:_080JUV]0P34V:X02@3bcJT0a/mD0=J^/03F[[00lL^[09A[X@3[
]9P0nME]08RPh`020=:b^P03000CX@1mPL`0OH7<00<0ThO40P2R[=h0102QS;d0000Q0:FLc02UW<`2
00D000040:V`g@3oool0oooo000002/0oooo000=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000X0oooo102SOj`4
0<:S^@030>_i``3Ha<H0f<C601L0oooo00<0LENT0?ooo`3oool00`3oool01000K=<0cK?00<fc`02T
P:d30?CK]080h:jR0P3gbY`20>>bY080fj^U0`2h]]L30;JF]P80j/^f0P2JMZT40;V@[@0309MXVP37
j^h0an[^00<0f;Vj00<0Zh>Y0;68Z@3Kk=l0102fYLP20;bG/@030:^4Z`3bhK`0l^6l0080_J>o00@0
^8NQ00000000000000000`2jPiT20=6b^`80Y7n/0P35UjP00`2ZR;40eJf`0=F]/00308Ib]P80DKoh
00@0/ik309Yk[`2JNjl0ATV`0P3PoK/30:^4[004061BZ`3;XZl0bj:_0<^R[`80hkR[0P1UI;`208f?
d0D0Y7n/0P1dG:P20:Ao[0<0R^Og0`3J/k420<6gd080cIjX00<0OG2j0:f7[@2]Qjd00P3;//820<bc
`P80ZKgX0P20MKd303@dX`80GF_800H0MG_;09Yi[@2JNJd0VWV]075HY@2<I9h208eRV`030:ehV02j
Rj<0^X^S00<0/GnN0P2_OId30;Z6W@0404a?]02`O9/0/7bK0;IoVP80_HFH0P2oQYP20;5jV0050<>9
UP36S9L0aXbG0<J<U`2hPIT00P3MX9<309ak[@80OV6V0P2GQ;d20>S2[`030?_NX`2NO[00WWj`0080
WWj`0P3DXjD01P2cP9`0aHfJ0<F=VP35SIX0dIJG0?BjS@<0h:fP00D0bYbX0<^ha`3;^<L0bkS70<fS
[@020>k7Z`80m>Z=00L0bJ>b0<JGYP36UjH0f:>P0>C2]@3^eV@0nNbR00@0WgBQ0P2/OZ<20;B3X080
fjfX00D0o>><0<RFX`2TOZX0Y7jZ0=RUXP030::=_`80YYG400<0AP00087DQ`2fSZ`00P3RbKh00`3K
YId0_jBn0;nT_P0307eIW@80TWjj00<019Ne0;2H_P2`V;h00`26K[030;5nW@030000002FJId0]86M
0080Yg^T0P28K:/307]V[`<0_koI0P2QT/D30:6:_080JUV]00<0a9RZ0?;=Z@3bcJT00P36ce@01@3F
[[00lL^[0>^dV03[]9P0nME]0080d[:j00@0aINW000CX@1mPL`0OH7<0P2CQl@20:AoZ`80XHbm00@0
000Q0000001IRNH0FHWV0P2Y/=d30?ooo`030000003oool0oooo02P0oooo000=0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`800000303o
ool30:=o[0030?S^Y@32XkT0`Z>i00<0joW37P3oool00`2QNjT0cK?00<fc`0020?CK]0<0I]Ka00<0
h:jR0?O:W03gbY`00P3S/Z@20=^[Y@0309=TV02h]]L0^;KG0080]YJf0P3;oll0102eRjX0VWJY09Yf
Z@2nUZh30;V@[@@0an[^0P3H^KX0102[PjT0/HRY0>G>`03?Yjl30;JUb080_9Na0P3bhK`01@2mXkl0
0000000000000000Z82X0080Rf>N0P2jPiT0101WFk40dK:k0=6b^`2TOj`30<FGZ0040:Z8/@3E[K00
eJf`0=F]/080QW:f0`2cW/<209Yk[`0408=f_02FLjT0UW>Y09IcZ@80ZhB/0P1PDZ/0103;XZl0hkR[
0>>hZ`3S^:/206ET_080SHo@1@2TOj`207ALZ0070:Ao[02RTlD0XY?50::Ca@1<HLL0R^Og0=Zc/@02
0<6gd0<0cIjX0`2]Qjd40<bc`P070;_YS02Y_NP0P7Fm0::Xf`000000:VSI02M3^@0205e[b080MG_;
0P2JNJd2075HY@80SF:K00<0[GRH0;Z;X`2jRj<00`2aOih20:mmW@0409i]V@2jQYd0^XJM0;Z6W@80
/7bK00<0]WnJ0;f5V02mQIP00P2oQYP20;5jV0070<>9UP36S9L0aXbG0<J<U`2hPIT0gJ2C0>NYT003
09ak[@80OV6V0P2GQ;d20>S2[`80MeVR0`2NO[020=BSY@060;>0W035SIX0aHfJ0<F=VP3AUYL0m;Z=
0`3P[J00103X^ZH0omF40<^ha`3;^<L20>k7Z`<0m>Z=0`36UjH20>C2]@030>kFI03ik:80[GfP00<0
WgBQ0P2/OZ<01P2dPj00fjfX0=^]Z03K[JP0o>><0<RFX`80Y7jZ0P3HYJ800`2RSKl0YHFb0:F5/P02
09Mj/@0502IDb@2fSZ`0h/Vn0>;9_P3KYId00P2CI9P307eIW@03099n^P2`QjT0/8NY0080/9Rn0`26
K[030;5nW@030000002FJId0]86M0080Yg^T0`28K:/207]V[`040;jM]`2BOk`0TWnl099o_080TXO5
0P1eJ;L206YI[@030<BHZP3bcJT0a/mD0080a/mD0P3abj/20>^dV0030?WEK@3GYJ@0d[:j0080aINW
00<001>Q08=Z[`2TOj/00`2TOj/00`2QS;d0g>_N0=o?b@030:NVe@<0X8Jh0`3oool00`000000oooo
0?ooo`0W0?ooo`003P3oool4000000h0oooo1@0000050?ooo`030000003oool0oooo00/0oooo0P2S
Oj`20?S^Y@030<:S^@3[nL<0oooo0240oooo0P2QNjT01`27io<0X9O;0:2Gb`2PUl/0I]Ka0>2^XP3g
bY`00`3S/Z@20=^[Y@0309=TV02h]]L0^;KG00<0dJjg0P2eRjX00`2JMZT0_YJ^0;jF[P030;V@[@80
VW6S00<0VG6T0=6X[P3AZ:h00P2aR:T0103Uc/00cjN_0<nW[`3?Yjl20;JUb0030;bG/@2IKId00000
0080000000@0_J>o0;R7X@2hQj40Z82X0P2;Hih20;Z3V@0306MK/@3A/[/0dK:k00@0aINX103E[K03
09]j[@80e;Jl102UPJ`209IcZ@80ZhB/0P1PDZ/01@3;XZl0hkR[0>>hZ`3S^:/0`iRZ0080Sg>_00<0
SHo@0:Ao[02TOj`00`2TOj`207ALZ080YZ7A0`2RTlD00`1<HLL0^9>a0;RC/@040<fNZ0040>O2[`2]
Qjd0[HN]0?7`VP80c;?20`2QQ[L30::Xf`<0]:[>00<08g?R07Ekb`1eNl/00P2JNJd3075HY@0407iI
W02jRj<0^X^S0;Z;X`<0/GnN00<0[gfM09i]V@2NKIT00`2jQYd00`2`O9/0]WnJ0;IoVP020;f5V080
_hJH0P2aNYP40<J<U`80gJ2C00@0ijV@09ak[@2LNjd0W7^]0P1nHJH0102GQ;d0j<:_0>S2[`3X`Zl2
07MIXP<0WWj`0P3DXjD40<F=VP80m;Z=0`3P[J000`3X^ZH0omF409QdZ00209QdZ0030<[CFP2PNj/0
X7^[0080X7^[0P36UjH00`3GZ:P0k]IT0?W/XP020:emX0<0WgBQ0P2/OZ<0102dPj00fjfX0=^]Z03K
[JP20<RFX`040:AnZP3HYJ80f:FR0=RUXP<0YHFb0P2GN[401@2RQ;<0h/Vn0>;9_P3RbKh0YgZR00<0
TfBH0P1mFId30;27Z@80X6fG0`26K[030;5nW@0309IYW@000000]86M0080Yg^T0`28K:/00`1kIZl0
_Yfg0;jM]`03099o_080TXO50`1eJ;L00`27IJ@0l/fY0?;=Z@040;WWm@0509A[X@3[]9P0jkBH0?WE
K@3GYJ@00`35UjL00`004j40PfZ_08=Z[`030:AoZ`030:6<_@3OclT0glo900@0]M[c0P2PQ[P30?oo
o`030000003oool0oooo02L0oooo000Z0?ooo`030000003oool0oooo00/0oooo0P2SOj`20?S^YB@0
oooo0P2QNjT205U9Y080X9O;0`1@@J400`3UlYH0hk:T0=^[Y@020=^[Y@80TfBH103A[[L20;F;ZP@0
_YJ^0P2iT:d209YaX`<0dJR^00<0/HRY0>G>`03Uc/000`3?Yjl0102fYLP0000000000000000309U]
W@040;fS_`2hQj40^8NQ0:R0Z080Rf>N0P2jPiT20:^A^`80SW^j0`35UjP00`3F[Jl0eJf`0=F]/002
0;jK]080VgZ]0`2VQK030:F1[080UW>Y0P2[Q:`2061BZ`<0hkR[0P33V:X208mc[`03000NY`2TOj`0
g_k=0080a:Fj0P2WNj<00`0008H0YZ7A0:JQd@030::Ca@<0^9>a00<0g;F`0<fNZ03=WZP00P3W`Zl2
0:f7[@80lO2J0P3Nmm/20:66]`@0_L;N0P2dZ/h202=chP0407Ekb`2JNJd0VWV]09Yi[@80LERU0P1n
FI`30;Z;X`80/GnN0`2NKIT30;Z6W@040<jJX02fOiX0]WnJ0;f5V0<0_hJH0P2aNYP01P2kPYP0aXbG
0<J<U`36S9L0e9^I0=fPT`80ijV@0P2LNjd207iQYP@0j<:_0P1gFJ8309in/0<0V7>W0`35SIX0103c
`i/0m;Z=0>2]X03P[J020>RjYP060?oEQ03LZJ80V7BX09QdZ03aa:80eYfJ0`2PNj/20<JGYP030=NX
Z03^eV@0nNbR0080[GfP0`2OM:420:anX`<0fjfX00@0o>><0<RFX`38UZ<0Y7jZ0`3HYJ800`3jd9/0
YHFb0:F5/P0309Mj/@80XXBc0P2WNZ8309=TV080OEVM00<0ilBc0;27Z@2`QjT00P2PKIL00`3n`Fl0
QVj`08I^/0030;5nW@0309IYW@2dPId000000080Yg^T0`28K:/30;jM]`<0TWnl0P2BQlD307EX]`80
QfFT00<0l/fY09edY00j_lX00P2[OZ<00`2DJj40jkBH0>^dV0020=NUY0040?oIQ@35UjL0aINW0000
0080PfZ_0`2TOj/20=o?b@80akC80`2ef_<20:26^080oooo00<000000?ooo`000000:03oool002T0
oooo00<000000?ooo`3oool0303oool00`2SOj`0n>jU0?ooo`0U0?ooo`80XG^Y0`1IBJ@00`2PUl/0
D46Q0511X@020>GbUP040>>bY03KZjD0fj^U0=^[Y@80TfBH00D0g>Qn0=6^]`3A[[L0dJjg0;F;ZP02
0<6X`0<0_YJ^0P2iT:d30:b?^080dJR^0P3Uc/020<nW[`<0000000<0RWo20=Bd^P3D];X00`2IKId3
0;R7X@040:R0Z02;Hih0Rf>N0;Z3V@<0Zi6k0P2>NkX30<FGZ0030=J][`3E[K00_Y^d0080_Y^d0P2K
NZd00`3`gK`0YXF`0:J5/0030:F1[080UW>Y00<0ZhB/0;:A]@2bTKD00P2@TM420>>hZ`80`iRZ0P2?
Ljl20=knc@<0a:Fj0P2WNj<00`0008H0YZ7A0:JQd@040:>Gb080^9>a00<0g;F`0<fNZ03=WZP00P3W
`Zl00`2]Qjd0lO2J0?7`VP030=kgf`80XHJg0P3Te/P30:f]e`040<6`bP0007D08g?R040kY0<0VWV]
0P1aF:D207iIW0<0^X^S0P2aOih00`2TLYT0WVfI09i]V@030;Z6W@040<jJX02fOiX0]WnJ0;f5V0<0
_hJH0P2aNYP01P2kPYP0aXbG0<J<U`36S9L0e9^I0=fPT`80ijV@0P2LNjd00`1nHJH0boo?0<_oc`03
0>S2[`80MeVR0P2NO[020:1dX080V7>W0`35SIX0103c`i/0h:fP0>2]X03P[J020>RjYP060?oEQ03L
ZJ80V7BX09QdZ03aa:80eYfJ0`2PNj/01036UjH0ejRX0=NXZ03ik:830:emX0<0WgBQ0P2/OZ<01034
Y[/0fjfX0=^]Z03mgh/20<RFX`050:AnZP3HYJ80f:FR0=RUXP3jd9/00P2UQK8309Mj/@80XXBc0P2W
NZ8309=TV080OEVM00<0ilBc0;27Z@2`QjT00P2PKIL20?k1K`0408I^/02aOYd0/GjM0;5nW@<0]86M
00<000000:MkY03Uc;h00`2BQL820;jM]`<0TfbR0P2_OYh307EX]`80QfFT00<0UFfQ09edY02MM:@0
0P2[OZ<30>^dV080ejFT00@0omV50<FGY`3Ad5D000000P23JZl30:AoZ`0709Ak]P37]<P0akC80<Nd
b03F]k/0j>1b0;GJl`020:26^0D0oooo00<000000?ooo`3oool09@3oool002T0oooo0`00000<0?oo
o`030:=o[03oool0oooo02D0oooo0P2QNjT205U9Y080[iNn0P1@@J420>GbUP@0fj^U0P2CI9P20=cX
OP80dJjg0`31Z<020;jF[P80c[>o0P2<P<420:b?^0030=6X[P39]lT0bKO900<0000000@0cjN_0>c=
]@3/cKD0RWo20P3D];X309U]W@030?K=XP2hQj40^8NQ0080mM:[00<0Rf>N0;Z3V@34d><00`2[TK/2
08ik^P030<FGZ03F[Jl0eZf_00@0_Y^d0P2KNZd00`3`gK`0YXF`0:J5/0030:F1[080UW>Y0`2bTKD3
092Ad@<0`iRZ00<0Sg>_0:5iY`2QNJL00P2QNJL20<BU^P80Yg^S00@0ln:j051kg@1@Nmd0PZob0`2S
UlP0102hTk40g;F`0=be/03=WZP30>O2[`030:f7[@3gh;00mn2`0080amGT00@0g_OK0:66]`3Te/P0
i=K80P2kV;@20:f]e`0400H^/031/<X08g?R040kY0<0VWV]0P1aF:D207iIW0<0^X^S00<0/GnN0:Ab
V@2TLYT00`2NKIT20;Z6W@040<jJX02fOiX0]WnJ0;f5V0<0_hJH0P2aNYP01P2kPYP0aXbG0<J<U`36
S9L0e9^I0=fPT`80ijV@0P2LNjd40<_oc`80j<:_0P1gFJ840:1dX080V7>W0`35SIX00`3c`i/0dY^M
0>2]X0020>RjYP80omF400D0g:VR09QdZ03:deX0lLBR0=JMVP030:1kZ`050<JGYP3GZ:P0ejRX0;VA
[@3GXId00`2]OJ0209mdX@050:anX`34Y[/0a:Jk0<BV^`3K[JP00`38UZ<40=RUXP030?[@V`2UQK80
YHFb00<0UgZa0P2RQ;<20:MjXP<0TfBH00<0OEVM0>O4/`3Wa;<00P2`QjT20:1]U`80o/5_00<0QVj`
0;5nW@2aOYd00P3Mc<L20;B1W@040000003Uc;h0iLbn0>G<_P80TXG200<0_Yfg0:UoYP2CK:800P2C
K:820:mnWP030;j<X@1eJ;L0MFRg0080QfFT00<0UFfQ09edY02MM:@00`2LNJ`20>^dV080ejFT00@0
omV50<FGY`3Ad5D0100f0`23JZl01@2TOj/0U7^f09Ak]P3?[[P0akC80080e[Nk00<0j>1b0?7R_@2f
/=800P2f/=840?ooo`030000003oool0oooo02D0oooo000Y0?ooo`030000003oool0oooo03@0oooo
0P2QNjT40:nG_P030511X@000940_iV`0080S6bX0`3KZjD01`2CI9P0g>Qn0=cXOP3Lj7h0`i^_0:V=
^01LeLl00P31Z<00102nUZh0c[>o0<jc_`3>/kl208b0`@80[8nh00<0bKO90000000000000P35XK<0
103?Yjl0k<fe0>c=]@3/cKD30=Bd^P<0VFfM00<0m/fR0;R7X@2hQj400P3gkI`00`3Tmj@0a=3S0<C@
h`030:^A^`80SW^j00@0aINX0=J][`3F[Jl0f:n_0`2nVk@00`2KNZd0l=fl0?3M_0020:J5/0<0YH6/
00<0UW>Y0;:PaP2bX<H00P2bTKD40:NWeP80`iRZ0P2[RK430:5iY`80a:Fj0P2WNj<20??R^P80D7_M
00@0PZob0:>Gb02SUlP0^9>a0P3L]K001P3=WZP0il:_0>O2[`3W`Zl0_k?>0?OP/0<0amGT00<0@UBo
0>CFb03Te/P00`2kV;@20:f]e`0300H^/031/<X0`K3:0080@3^T0P25HJ02075HY@80OUVL0`2jRj<3
0:AbV@<0WVfI00<0^XJM0<jJX03>VZ000P2fOiX40;n6V0030;5jV02kPYP0^h:H00<0aXbG00<0e9^I
0=fPT`3WZI000P3WZI00103<TYL0f9^C0>N[TP3WZi820=2DU@040=VKTP2QOZd0XGj]0:5n[@<0X7BP
0P2HLjL20<F=VP80ll>K00D0dY^M0>2]X03X^ZH0j;ZV0?oEQ0020=bYXP0309QdZ031a4<0lLBR0080
eYfJ0P2PNj/20=NXZ080^I6]00@0ej6M0:emX02]OJ00[GfP0P2OM:440<BV^`050;6M``3BYJT0b9JS
0<RFX`3_c:l00P3HYJ820?[@V`80ZKcW00D0hkf_0=oHHP2gg700]ma`0::4/`030:MjXP80TfBH00<0
OEVM0>O4/`3Wa;<00`2`QjT01@2PKIL0o/5_0?k1K`3hcV80/GjM00<0gLc70P2dPId0103Uc;h00000
0>G<_P3Uc;h209:5`P80ZGnV0`2CK:80102_OYh0_XbQ0;j<X@2fQZ8207EX]`0308MUY02EKJ40ZHF^
0080ZHF^0`2LNJ`01@3[]9P0ejFT0?oIQ@3ofHD0aINW0080Ofbd00D0>FKC001/d`23JZl0Y7n[09Ak
]P020<n^^080e[Nk00@0j>1b0?7R_@3ah[d0Ub@00P2f/=850?ooo`030000003oool0oooo02@0oooo
000Y0?ooo`030000003oool0oooo03L0oooo0`2_Ukh00`000940_iV`0;nI/00308a/Z080fj^U00<0
TfBH0=cXOP3fkil00P33Vjl20:V=^080`JS0103>/kl208b0`@<000000P39]lT20<FQ/`<0k<fe0P3H
hMd20=Bd^P80VFfM0P3fcJ820;R7X@050?O]W02dY//0]:K;0;BVb`1UIKh0102STL80101lJK<0eZf_
0=J][`3F[Jl20=R_[`80_Y^d00<0VgZ]0?3M_03`gK`00P2VQK030:F1[0<0/Z360P2bTKD0103La<80
YjOF0:NWeP2WYmH20<>HZP80ZhVa0`2QNJL20<BU^P040:MkX`3ch[X0ln:j0??R^P80D7_M00<0G6?0
0:>Gb02SUlP00`3L]K030>O2[`80_k?>00@0mn2`08RimP37eN@0amGT0P12E;l40;^H]0030>cC^P20
O/L0`<WQ0080`<WQ0P10>j@308EQX003075HY@1nFI`0OUVL0080^X^S0P2MKY/20:AbV@<0WVfI00<0
^XJM0<jJX03>VZ000P2fOiX01@2aNiP0_hJH0;n6V02oQYP0/GZH0080^h:H0P36S9L20=BKV@060=fP
T`3WZI00ijV@0>NYT03<TYL0f9^C0P3WZi820=2DU@040=^LT@240000XGj]0:5n[@<0X7BP0`2HLjL0
1035SIX0ll>K0??3V`3BVid30>RjYP050?oEQ03LZJ80g:VR09QdZ03aa:800`3FWIX0102PNj/0^Y^h
0;ZK^03GZ:P20;VA[@040=NQW@2]OJ00[GfP0:emX080WgBQ00@0inG>0<BV^`34Y[/0e<gB0P3BYJT2
0<RFX`030>o<[`3HYJ80f:FR0080n]2K00L0g<C10>>m[`3S_Jl0gmQR0=fd[P2gg700Q6R[00<0YgZR
0P2CI9P30>O4/`<0/8NY00@0X6fG0?k1K`3n`Fl0n<iR103Mc<L20;B1W@0300006P3Uc;h0000000<0
RFf]0P2YOjH309=/XP040:mnWP2nS:40_XbQ0;J6XP80MFRg00<0QfFT0:f;/@2]Rk400P2YQJh309ai
[0050?kKQ03GYJ@0omV50?oIQ@3Lo//00`1oK;@00`0iI]<0MfJc07MV/`030<n^^0030<nX/P3F]k/0
lN:m0080lN:m00@0002;0;J`dP2f/=80][3B1@3oool00`000000oooo0?ooo`0S0?ooo`00:@3oool0
0`000000oooo0?ooo`0g0?ooo`030000IP2_Ukh0[iNn00<0_iV`0`2<K:P20=^[Y@0309=TV03fkil0
`i^_0080`i^_0P2YSKP00`2WZMP0VKW^09VikP020<jc_`<00000103KiM`30<FQ/`80e?NU0`3HhMd2
0=Bd^P80VFfM0P3fcJ80102hQj40mnfL0?O]W00VGM420;BVb`80IFFn0`2STL8207aY/`040=J][`3H
[jl0f:n_0=R_[`80_Y^d0`3`gK`404g;`@80RnOg0P2bX<H0102bTKD0g<C20=c4`P3La<820:NWeP04
0<>HZP1iL;d0ZhVa0:^9/@<0XGVW00<0eJZ/0<BU^P2WNj<00P3ch[X20;Si_@03051kg@1LHl00G6?0
0080NG?000@0g;F`0:WTR`2Yi8/0ZNB;0P2o/lh01@3gh;00d:B[09Mh[P2GN:h0O6Ra00<0X8Vl0P2k
V;@20>cC^P80P7k70P30bN42040kY0<0QF6P00@0LERU07iIW01nFI`0^X^S0`2MKY/20:AbV@<0WVfI
00<0^XJM0<jJX03>VZ000P2fOiX01@2aNiP0_hJH0;n6V02oQYP0/GZH00<0^h:H00@0aXbG0=BKV@3D
ViT0gJ2C0P3WZI020<bBU`030=RKT`3WZi80d9BE0080d9BE00@0fibA08@0002QOZd0XGj]0`2PM:03
09QcY`050<F=VP3c`i/0dY^M0=:KW@3megX00P3X^ZH01@3oeH@0g:VR0=bYXP3VcKd0lLBR00<0eYfJ
0`2jVkP0103GZ:P0^I6]0=NQW@3GXId30:emX00609mdX@3WiLh0inG>0<BV^`3DcM80/Ig30P3BYJT0
1P38UZ<0klb_0>o<[`3_c:l0f:FR0?[@V`80g<C100D0eKJk0>>m[`3AgV`0gKB^0;OLL00208AXZ`80
YgZR0P2CI9P00`0008T0ilBc0>O4/`030;27Z@050:1]U`3n`Fl0o/5_0?S>HP3CbDT00`3Mc<L20;B1
W@0400006P2RP:l0Z7jV00000080>G;M0P2YOjH309=/XP<0_XbQ0P2fQZ80101eJ;L0QfFT0:f;/@2]
Rk420:V5[P80W7V/00H0e[6d0?kKQ03GYJ@0omV50=cnb`3W/Y`307m/]00502/gZP1gI[<0MfJc07MV
/`3?[[P00P3?Z;801P3hgjl0000=0?7R_@3ah[d0002;09LT0080Pffb1@3oool00`000000oooo0?oo
o`080?ooo`L000000`3oool4000000D0oooo100000040?ooo`00:@3oool2000003P0oooo00@0001V
0:bG`@2/Ul40[9O10P2oVK0208a/Z0060>c_bP3cdJh0lm6^0>Oj/03fkil0i;RX0P33Vjl309j3]P04
0:NYf0000000000000000080anG]00@0001j0;JXbP2fZ<X0fMCD0P2OhOd00`35XK<0e?NU07cUb002
07cUb004091o_03I`<40aZNj0=Bd^P80VFfM0P3fcJ80102hQj40mnfL0::Ca@0VGM430;BVb`80IFFn
0P2STL8207aY/`070=J][`3H[jl0f:n_0=R_[`2MQ;P0][SJ09QdZ@020?CI/P80;DFh0P2VR;@20;Rb
d`80/Z360`3La<8207QBV@030:NWeP33V:X0NG2m00<0ZhVa0P2QNJL00`3EZZ`0GdnX0??R^P020>33
_0030?SJZP18Hl/003:g0080G6?00P1iLl000`2Kh_d0ioCB08mk^@0208mk^@030;nccP3gh;00d:B[
0080UgR^0P1lJ;430:29_0030;^H]03/dkX0k=>j00<0]ZG800<0J7370000T@10>j@00`25HJ000`1^
AI00OUVL07iIW00409e^V`80Y7:I0`2NKIT30<jJX080]WnJ00D0/G^H0;n6V02oQYP0_hJH0;5jV003
0;^2V0030<J<U`3DViT0e9^I00<0ijV@0P3<TYL00`3HVi<0ij^B0=2DU@020=2DU@040=^LT@3IVi80
XGj]0:5n[@<0X7BP0`2HLjL01035SIX0ll>K0=:KW@3BVid20?gGNP060?oEQ03LZJ80g:VR0=bYXP3V
cKd0lLBR0`3FWIX01@3mchh0^Y^h0;ZK^03GZ:P0^I6]00<0ej6M0P2]OJ030>OUcP80e<gB0`3BYJT0
1@38UZ<0klb_0>o<[`3_c:l0n]2K0080g<C10P3E][/0103/n;40gKB^0=fd[P3=W:D208AXZ`80YgZR
0P2CI9P0101dF:<0002909n=`@2OSL420;27Z@060:1]U`3n`Fl0o/5_0?S>HP3CbDT0hk2P0P3Mc<L2
0;B1W@040::0[`2XOZH0^nnJ000000<0>G;M0P2DP;/3099[XP80_XbQ00@0]XJR0:j7[02^Qj`0QfFT
0P2]Rk420:V5[P0809ai[03F/K@0e[6d0?kKQ03GYJ@000000>SVc@3W/Y`307m/]080:cNZ0P1gI[<0
2@3?[[P0cjRb0<nX/P3hgjl0Hg?>01405@1eUN@0002;09LT000308=]/P<0oooo0`00000<0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00@3oool002P0oooo00<000000?ooo`3oool0>03oool20000IP80
[9O10P2oVK00102<K:P0k>o:0>c_bP3cdJh20>Oj/0050?KM/03T^:P0`i^_0<>K[`2mTZ/00`000002
0:NYf080HVBo00<0E7OH0000NP2fZ<X00P3Ie=@00`2@gY40Wn7m0<FQ/`030<_3dP06091o_03I`<40
fL310<JW^P3D];X0VFfM0`3fcJ80102hQj40XY?50::Ca@2RTlD30;BVb`80IFFn0P2STL8207aY/`<0
f:n_0P2MQ;P0100=7I`0V7BY0?CI/P3dfK8202e5^080YXRd00<0k_Rj0?K]]@3fkKD00P1V`_h2091W
W`80N5:I00<0L5JT07U`_@1iL;d00`2[RK400`2QNJL0eJZ/0=FZ[00205m?Z0030>33_03hfZX0n=ZZ
0080B6?;00@003:g03mQc02Kh_d0Vn;m0P3Wm=8308mk^@030?OP/03@Y:/0d:B[0080UgR^0P1lJ;43
0:29_080k=>j0P2cUKT20;JUb080J7370P10>j@208EQX00406i5T01nFI`0Y7RR0:AhXP<0WFjK0P2T
LYT309i]V@040<B?WP3>VZ00cYZP0;IoVP80/G^H0`2oQYP40;^2V0040<J<U`3DViT0e9^I0=VQVP80
ijV@0P3<TYL20>N[TP<0d9BE00<0fibA0=VKTP2QOZd00P2QOZd20:1dX0030>K9^P1nKKD0OVfe0080
ll>K0P3BVid20?gGNP80clOB00@0g:VR0>K=_@31a4<0lLBR0`3FWIX01@3mchh0^Y^h0;ZK^025LKH0
^I6]00<0ej6M0P2]OJ000`31o]d0h[Z^0<RIYP03081QY@80dZFY0`3_c:l0103IfML0e/;60=K2aP3L
a<420=Ff^`040>ch/@3M]:h0gKB^0<fLY@<0Q6R[00D0YgZR09=TV02kRZ80M5RS0000R@0209n=`@80
/8NY00D0X6fG0?k1K`3n`Fl0n<iR0=?9B@020=Jc]`040=g<a`2dPId0W4IO0::0[`80Qfna00@0WJgR
0000000iL]d0>G;M0P2DP;/3099[XP80_XbQ0`2^Qj`30:f;/@80ZHF^0`3F/K@00`3nfh@0b_6H0>SV
c@020>NbW0030=f^YP1`N/d0L7[=0080:cNZ0P1gI[<30<nX/P030=onc@1SLlh0Hg?>0080MIGT00@0
002;08=]/P23KK80Pffb1P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00@3oool002P0oooo00<000000?ooo`3oool0>03oool20000IP80[9O10P2oVK020>c_bP040<Kg
[035l>l0ioZ`0?KM/080i;RX0`00000209j3]P030:=bV`23EiD0PeNE0080HVBo0P2?K:H20=WDe003
06YT^@3Q_kD0Si3@0080Si3@0P3;`m800`2@Ok`0fL310=W0`@020=gagP0709U]W@3fcJ80m/fR0?K=
XP3F`/L0]OCc0::Ca@020964`P<0R8W=0P1jML801P0`O^L0]JC70;FTa`2eY<L0f:n_0?gQT`80WHBh
00<03AfL0?CI/P34ko000P34ko00100]AKP0YXRd0>kh^P3^n;X30;>Zc`030::Jc@2@Iil0T6NO0080
N5:I0P1`EZ@01@1fFjD0ZhVa0:^9/@2[RK40XGVW0080eJZ/00<0GdnX0>33_03P`k`00P3hfZX00`3>
cmX0f]7@0=[Ad00203mQc0@0ioCB00<0Sg^i09Qg[@3@Y:/00P3@Y:/209Mh[P80O6Ra102WY]H30;>E
^@80]ZG80P1XL<L01@0Q:J00@3^T08EQX025HJ00KTF@00<0Y7RR0`2MKY/20:AbV@80WVfI0P34Sih2
0<jJX0030;IoVP2aNiP0/G^H00<0_hJH00D0^86I0;^2V02kPYP0^h:H0<J<U`020=BKV@030=VQVP3W
ZI00ijV@0080c9:G00<0k[BC0>N[TP3@U9D00P3@U9D00`3KW940fI^B0:5n[@020:5n[@80X7BP00D0
i/Vj07i]]@1nKKD0OVfe0??3V`020=:KW@80oMMj0P3?am80103LZJ80i/fm0?74XP3aa:830=JMVP04
0?g?SP2jVkP0QG6f08Ea]P@0ej6M00<0[GfP0<7ng@3R^Zh00P38VJH3081QY@80dZFY00<000000=WI
e`3IfML00`3F`/H20=Ff^`030>ch/@3M]:h0gKB^0080cIbU00H0002706aM/024J:/0YgZR09=TV02k
RZ8207AHX`80Whg100D09anA0;27Z@2PKIL0o/5_0?S>HP020=?9B@060=_oc@3F/kL0gLc70;B1W@3V
o<D0XX2_0P27Kk40103ih:d0[X>W0000000iL]d209B0^`<0TV^R0P2nS:401036UZD0[XN/0:j7[02^
Qj`20:f;/@<0VgR[0P3F/K@00`3nfh@0j>K=0>SVc@020>NbW0040=f^YP1`N/d0L7[=071jc@80:cNZ
0P2VXM000`3?Z;80n=n_0=onc@030<78g`0406]bb00008T0Pffb08=]/P80aJo500<0TCeN07J<f`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00@3oool002P0
oooo00<000000?ooo`3oool0>@3oool00`1nH:D0[9O10:bG`@030:Rch080aO3_0P3RclD3000000<0
_I:[00<0WX>f0:=bV`2SLY/00P23EiD308eRV`80SfbV00@0JVBi0>6o]@3Q_kD0hKne0`2[S[P00`1G
S^T0fL310=W0`@030;VO_@80m/fR0P3F`/L20=B^/@80THC20P2[Q:/208R9c@80NWG20P0`O^L20;FT
a`80oN6C0P2MQ;P0100=7I`0ZKgX0:Vmj02Y_NP209n6^@80k_Rj0P2[Z]H20;>Zc`030::Jc@2@Iil0
T6NO0080N5:I0P1`EZ@207IKY@80RV^Z0`3EZZ`20>33_0<0n=ZZ103JdM0010003I80XWVV0=>VZ@3C
YZT20:f8[@@0d:B[0P2GN:h309fCb@80YjKF0P2YOjL20;>E^@<0VgV/0P1XL<L00`10>j@0QF6P08EQ
X00206i5T080Y7RR0`2MKY/20:AbV@80WVfI0P34Sih20<jJX0040;IoVP2aNiP0/G^H0;5kV080_hJH
00@0^86I0;^2V02kPYP0^h:H0`3DViT20=VQVP050>NYT03<TYL0c9:G0>jdT`3WZi800`3@U9D00`3K
W940fI^B0:5n[@020:5n[@040:1dX03VbKX0i/Vj0>K9^P80OVfe0P3BVid20?gGNP0308V7b`3?am80
clOB0080i/fm00<0l<FU0=JMVP3FWIX00P3FWIX00`3mchh0i:RD0?6gT00208Q[Z`<0ej6M00<0l=>d
0<G>D@3R^Zh00P38VJH3081QY@040=:UZ@35`Sl0S7Bc08ad/`@0e/;600D0i=g>0=Ff^`3/n;40alOI
0=fd[P020<fLY@060000Q`1/GK00K5f`0;^:XP2CI9P0^hZR0P1dF:<209n=`@0602LOT@2`QjT0/8NY
0?k1K`3hcV80dlU90P3Kold01@3F/kL0QJk`0;B1W@3Vo<D0XX2_0080Qfna00@0cj^d0:j3Y`000000
PVFY0P2DP;/3099[XP80_XbQ00@0aYJU0:j7[02^Qj`0[XN/0`2NMZD309]hZ`030=Ja]027NKd0QgVm
00<0ik:L00<0gJjV09a^W@2LKYd00P2LKYd01@0[=jX0YZ7@0:JQd03?Z;80n=n_0080RJg]0P31b=l2
06]bb0@0aJo500<0TCeN07J<f`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00@3oool002P0oooo00<000000?ooo`000000>@3oool207iPY@<0UH:l00<0c[_7
0?O_XP0000000P0000030>BhZ0030=2U[02mTZ/0_I:[00<0Xg:K0P23EiD308eRV`80SfbV00D0JVBi
0>6o]@3Q_kD0hKne0<FO/P020:^>^080EhkY102iWkd0103fh[H0e/;70=K2a`3F`/L20=B^/@@0ZhB[
0P28RLd30<GNj`03031ni`2eY<L0Z8fi0080oN6C0P2MQ;P20:noi@80ZKgX0P2OQ[T205iXa@80Zj[F
0P2cZ/l00`2RV/d0T6NO091WW`0207QBV@80L5JT0P1fFjD308Y[ZP80eJZ/00@0f_WM0>33_03hfZX0
n=ZZ0P2cWl@01@3Uc/00f]7@0=[Ad0003I80XWVV0080djJY0`2TOZ/30=2TZ`030<>M/P2QRkd0XH^m
00<0WI?90`2YOjL00`2cUKT0[7nS0:aoX`0209]i[00304@oYP1XL<L08BVP0080QF6P0P1^AI020:Ah
XP<0WFjK0P2TLYT0102NKIT0a8nN0<B?WP34Sih20<jJX0@0/G^H0P2oQYP01@2hPIT0^h:H0;^2V02k
PYP0eYfJ0080e9^I0P3IXIX30<bBU`030>jdT`3WZi80d9BE0080d9BE00H0fibA0=VKTP3SYI40hjFA
0:5n[@2PM:030>K9^P0407i]]@3PhMD0h>7E0=:KW@80oMMj0P2NMZD208n3`P030>K=_@3`aJD0bIFP
0080eYfJ0P3mchh0103TZ9@0lKN@08Q[Z`28Jj/30=NQW@030<G>D@3hd:40b9VV00<0b9VV0P20HJD0
1@39Zk`0aL8o08ad/`2<M;<0f[^j0080e/;60P3TgLh0103/n;40alOI0<O7f@3M]:h20<fLY@800027
0P1/GK020;^:XP80M5RS00L0ffL@09n=`@0W7i409anA0;27Z@3n`Fl0n<iR00<0foo=00H0S^g80;^D
[`2kU:l0^iB_0::0[`27Kk420<n[]080[X>W00@00000089UZ@2DP;/0U82k0P2BJj800`2nS:40aYJU
0<JFY@020:j7[080ZG^Q0P2NMZD309]hZ`80QgVm00H0^IBa0=j^YP3W/Y`0ik:L0=f^YP2hPi`309a^
W@0503LmZ`2VXM00YZ7@0?SO[`2GZN<00`2FMjh206VanP80IY7W0`35[lD00`2A?Eh0SFfY08e]Z@04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`00:03oool2
000003X0oooo0P1nH:D209F2_0<000000P3RclD00`3fgK00i;RX0>BhZ0020=2U[080_I:[00<0/X:Q
0:=bV`2SLY/00P23EiD308eRV`80SfbV0`3Q_kD20<FO/P80Zhjh0P3G^K`0101RX_@0^Inm0;VO_@3f
h[H30<jmbP<0e:ja00D0`YZ^0:^4Z`2[Q:/0ZhB[01@RWP0202Eoj080aMk[00<074[30:R=^@2XSKT0
102QSKl30:b/e`030:Vmj02OQ[T0WhJi0080GVS50`2PR[`0102cZ/l0;1f;091WW`2@Iil207QBV@80
L5JT0P1fFjD308Y[ZP030=FZ[03JnMd0f_WM0080n=ZZ0P2cWl@20>G>`0030;i0000QDLP000fB00<0
djJY00D0^H^V0:AnZ`2TOZ/0Y7j[0=2TZ`020<>M/P80XH^m102MM:D20:UoY`<0[7nS0`2KNJ`01014
?jH08BVP08EQX025HJ0206i5T080Y7RR0`2MKY/20:AbV@0409i]V@34Sih0a8nN0<B?WP<0UfRI0`2a
NiP00`2oQYP0^86I0;R1V@030;^2V0030=JMVP3DViT0fJ6J0080fJ6J00@0bi6H0<bBU`3<TYL0k[BC
103@U9D01@3KW940fI^B0>>UT@3SYI40hJJE00@0i/Vj0`3PhMD00`3BVid0oMMj09ifY@0209ifY@80
Sh?20P3`aJD00`39UJ00eYfJ0=JMVP020?g?SP040>BXU03a]i00R6^[08Q[Z`80ej6M00@0l=>d0?S@
X@3hd:40fZj[0`38VJH2081QY@030<V[_035`Sl0S7Bc00<0f[^j00<0i=g>07AFX@0<7Yh00`37amT3
0<fLY@040=BYZ`0008L0K5f`06aM/080^hZR0P1dF:<01`32VJh0Whg109n=`@0W7i40/8NY0?k1K`3h
cV800P2nXkh308j1`080^iB_00@0kOR`0>C;_P3?Zk@0cj^d0P2^PjL0102WOJD000000008V@2DP;/2
099[XP040;j<X@36UZD0aYJU0:j7[0<0ZG^Q0P2NMZD309]hZ`<0^IBa0P3N[ZH00`3W/Y`0gJjV0;R3
W00309a^W@0303LmZ`37o]d0TI?B0080UjWS0`2FMjh0102cPIh0RfbZ0:O=m02WcO@30<F_a@0307L0
002=KJT0SFfY00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0040
oooo00020?ooo`@000001P3oool2000000P0oooo00<000000?ooo`3oool0103oool4000000L0oooo
00<000000?ooo`3oool0>@3oool207iPY@80000000D0c[_70?O_XP3RclD0h/o50?KM/0030>BhZ080
d:F/00<0_I:[0;:2X@2bPZ400P2SLY/208=GU@<0SF:K0P2?K:H00`3=/kl0hKne0<FO/P020<FO/P07
0:^>^03G^K`0ekVl0=Ni_03ail40HZ;d0;VO_@030<jmbP80dl;900<0e:ja0<:J[P32VZh00`2[Q:/3
0?7e^@80LV^k00@0E/oW0:R=^@2haN@0d:ff0`2QSKl0103IbLT0[:cG0:b/e`0fC[d30;BPa080SIgN
0P2PR[`0102cZ/l0;1f;091WW`2@Iil207QBV@80L5JT0`1fFjD208Y[ZP040;VA[P3^`JD0XiK80:>F
b080YH>_00@0/io40>G>`03Uc/00g<?10P0QDLP010003I80djJY0;V;YP2iRjH30:AnZ`<0`ifb00<0
XH^m0:=mZP2SOJX00`2MM:D20:UoY`030<2@Y02/Oj<0[7nS00<0VgV/0P14?jH0102YE`00QF6P06i5
T01^AI020:AhXP<0WFjK0P2TLYT40<B?WP030;f6V@2GJ9T0UfRI00<0/G^H00<0_hJH0;R1V@2hPIT0
0`2kPYP00`3FWIX0e9^I0=VQVP020=VQVP050<^AV03<TYL0c9:G0>jdT`34RYH00P3@U9D20=^LT@80
hjFA0`3QYYD0103SYI00olM^0000R00o;iD20>3Qe@030=:KW@3megX0WWJU0080WWJU00<0Sh?20=?>
e03`aJD00P39UJ020=JMVP040?g?SP3TZ9@0i:RD0?6gT080R6^[00<0ej6M0?3C]03T]:<00P3hd:40
1P3J[Z/0b9VV0<RIYP38VJH0P66U0<V[_080aL8o0`3J^kX01@3[mZ@0`8bN07AFX@1dEZ4031jN00<0
X8k10P3=W:D0103DZJ/0002706aM/01/GK020;^:XP0507AHX`32VJh0`YV^0000PP2OSL400P0W7i40
103n`Fl0_Z>n0;jS_P2nXkh308j1`0040;^D[`3]n;00i<^n0>C;_P80cj^d00H0[X>W0:^3Z@2[PjT0
YgfU0000002DP;/2099[XP<0aYJU102YNj4309ifY@0309]hZ`2QP[80XH:b0080^IBa0P3N[ZH20=f^
YP050;R3W02LKYd0W6jM09a^W@0001`00`2JY]h01@2GZN<0UWN^09Ig[P2FMjh0/h6N0080RfbZ00@0
00000?CD[P2RSKh0001K0`2=KJT40?ooo`8000001P3oool3000000D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00@3oool000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool00`3oool2000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
>@3oool3000000<0c[_700H0n^VW0?[RZ@3CkXl0dnj?0=cHd`3T^:P30=2U[0030;fBZ`2bPZ40/X:Q
0080Xg:K0P23EiD308eRV`0308m/YP3=/kl0cK>o00@0aInb0`3G^K`20?7W`@040=6d_@1GLM80Eg7B
0<jmbP<0dl;900<0e:ja0<:J[P32VZh00`2[Q:/00`3NaL00gkJ]079U]@02079U]@030;S5i02XSKT0
d:ff0080d:ff00<0XHfo0=W9b@3IbLT00P2/[=L203I>_@80]:340P2=WMh20:2:_0050;>Zc`0/7H/0
T6NO091WW`1hDYT00P37/lL01@1`EZ@0MU^U07IKY@1fFjD0RV^Z0080^I6^00<0k/6U0:>Fb02UPjl0
0P2UPjl20>G>`080g<?100@0_T00025Ab00o@:/0djJY0P2iRjH30:AnZ`030=o4_P33WK80`ifb00<0
XgfZ0`2MM:D20:UoY`030<2@Y02/Oj<0[7nS00<0VgV/0P14?jH0102YE`00QF6P06i5T01^AI020:Ah
XP<0WFjK0P2TLYT01@2aPj@0a8nN0<B?WP34Sih0_HJI0080UfRI0`2aNiP00`2oQYP0^86I0;R1V@02
0;^2V080eYfJ00H0e9^I0=VQVP3IXIX0fJ6J0<^AV03<TYL20>jdT`030<B:UP3@U9D0d9BE0080fibA
00<0iZN@0>>UT@3QYYD00P3QYYD0203SYI00olM^0000R00008P0<BBB0>3Qe@3BVid0WH:f0`2NMZD2
0=?>e0060?35Y@39UJ00bIFP0<VEX03FWIX0oLn>0P3TZ9@00`3a]i00R6^[08Q[Z`020?3C]0030>Bd
X`3hd:40fZj[0080fZj[0P38VJH20<V[_0050?_QY@1G^o`0Ek_l0=Zk^P3[mZ@00P30S9h207AFX@05
04a7ZP0<7Yh0X8k10:2>`@3=W:D00P3DZJ/00`0o<9L0002706aM/0020;^:XP<0`YV^00H0002209n=
`@0W7i409anA0?k1K`2l]M<20;jS_P<0SX7000@0^iB_0>gh/03Tbkh0i<^n0P3?Zk@30:^3Z@040:Mm
Y@00000000RI099[XP80ZGnW0P36UZD0103I[jd0ZG^Q0:UkX@2YNj4309ifY@0309]hZ`2QP[80XH:b
0080^IBa0P3N[ZH00`3=Vj<0gJjV0;R3W00309a^W@070000701mW>H0VZKN09ZVgP1FCZd0UjWS09Ig
[P020;>1WP80RfbZ0P3de:h00`3H[Zh0001K0;kli@0208e]Z@060=:c^P00000000000000003oool0
0000203oool00`000000oooo0?ooo`040?ooo`@000001@3oool4000000@0oooo00000`3oool00000
0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03H0oooo0`0000000`3oool0OV2U0:b5Z`020:b5Z`80n^VW
00@0n^:Y0=?^S`3Lf=<0g=SC103@YJ`30;:2X@80Xg:K0P23EiD308eRV`<0cK>o00H0/XBT0<FO/P35
Wk80aInb0<^/^P3G^K`20?7W`@80dKBm0P1GLM840=?2b@<0`YZ^0P2[Q:/20=k5`0030=nf[@1bIKD0
LVFe0080ZWbQ103@[KH20=W9b@80]iZj00@0IXcS03I>_@0fC[d0]:340P2gV;P0101UF[40X8Zl0:2:
_02PR[`202`MR`05000f^`37/lL0ak?70<Nca`1>Fl000`1fFjD30;VA[P040>k1Y@3D^Kh0YH>_0:F3
[`80`iZ^0P3L`l40103InZh0/j;7025Ab00o@:/30;V;YP80Y7j[0P3Oa;h20<>M/P030<2J/@2SOJX0
XgfZ00<0WGBU00<0ZGnW0<2@Y030T:@00P2/Oj<40:>Fa`0304@oYP0D:ZL0QF6P0080KTF@0P2TN:83
09e^V`030:AbV@2aPj@0/H>T0080a8nN0P2mQYT209MXV@<0/G^H0`2hPIT20;^2V080eYfJ00<0e9^I
0=VQVP3IXIX00P3;TIP0103<TYL0k[BC0>jdT`34RYH20=2DU@80fibA00<0iZN@0>>UT@3QYYD00P3Q
YYD0103SYI00olM^0<Rba00008P2034TTP80WH:f0`2NMZD00`3ekYT0l<FU0?35Y@030<VEX0050=JM
VP3mchh0i:RD0>BXU03a]i000`2RT/<00`3S`kL0n=2Q0?S@X@030=Z^Z`080<RIYP2gV[X0]iZj0<V[
_03khJD0hKZ`0?oBN03[mZ@30<2<WP80M5JQ0P1<AjX20:2>`@060<fLY@3DZJ/0e:V[03l`U`0008L0
K5f`0P2kRZ800`34X[H0`YV^0<:I[P020=jaZ@809anA0P2l]M<01P2nXkh0LUJR0:Vnj02Y_^P08eW?
0>gh/080i<^n0P37/lL209=d[P80Zh>Y0P2WOJD010000000ZGnW0:UoY`2YOjL20<JFY@040=V_[@2Y
Nj40ZG^Q0:UkX@<0WWJU00D0M7300:62/P2QP[80XH:b0;VD/@020=j^YP040<fKX`3M[ZH0^8>L0;R3
W080W6jM0`22S=D0102JY]h0ETj]05I>[@2FMjh20;>1WP80RfbZ00H0m=B^0=R^[P3H[Zh0XXfn0000
F`2=KJT20=:c^P<0`ee=00<0oooo0000003oool07`3oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0`00
000c0?ooo`<00000103oool40:b5Z`030?[YY`3jhZT0dnj?0080g=SC0P2WQK030=2U[0030<^V]02b
PZ40/X:Q0080Xg:K0P23EiD308eRV`030<NN[P3=/kl0/XBT0080/XBT00<0aInb0<^/^P3;[;X00P3a
il430=6d_@040;68Z`2?L:/0Sg2[08m`Z`<0Zhjh0P32VZh00`2[Q:/0g/G00=k5`0020=nf[@05079U
]@2ZO:40ZWbQ0:YlX@3kdYT00P3@[KH20=W8b@<0]iZj0P1VS><0101MIl@0]iRh0;NH^02gV;P206EJ
/@80YjWH00@0;1f;00000000000003Jk0`37/lL01@1>Fl00N72m07Q`_@1hL;d0^I6^0080k/6U00<0
e;Vn0:F3[`33VZh00P33VZh01@3mhi`000000=G_i@3EknD0001]0080?d2[0P2iRjH01@2TOZ/0glBn
0=o4_P3Oa;h0`ifb0080`9Za0P2SOJX309edY@030:UoY`30T:@0`92T0080[7nS00L0k]:f0:>Fa`2S
U/L0XiK703MHa`0D:ZL0QF6P0080KTF@0P2TN:8309e^V`030:AbV@2aPj@0/H>T0080a8nN0P2mQYT2
09MXV@<0/G^H00<0_hRJ0;R1V@2hPIT00P2kPYP20=JMVP<0fJ6J0P3;TIP0103<TYL0k[BC0>jdT`34
RYH20=2DU@80fibA00@0iZN@0>>UT@3QYYD0hJJE0P3SYI001@3oafh0b;;40040N00008P0<BBB00<0
WH:f0P2NMZD00`3ekYT0ZgbQ0<VEX0030<VEX0030?g?SP3bm;L0i:RD0080lKN@00D0mlJG0::B``2R
T/<0hl>g0=o:``040=Z^Z`<0]iZj0P3khJD0103odWP0iK:N0>FbWP3`d[<20<2<WP80M5JQ0`1<AjX0
1021N<00e:V[0=BYZ`3DZJ/203l`U`0404]7Z`2kRZ80a::f0<BR]P80`YV^0P3N/JT200]NeP80_;GC
0`1bEZ82096>c0808W?R0`37/lL209=d[P<0Zh>Y00<0YgfU0008V@0000000P2YOjL00`36UZD0fJn]
0=V_[@030:UkX@80WWJU00<0YWnY07A``02QP[800P2QP[820=j^YP80cI^S0`2hPi`209a^W@<0PXcE
00<0VZKN05I>[@1FCZd00`2cPIh00`2;K:X0m=B^0?CD[P020=R^[P80WW:P0`3B/kX30<=MC@030?oo
o`000000oooo01l0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo0`00
00080?ooo`80[8F[0P3jjJL00`3jhZT0oooo0?ooo`040:N5/0030=2U[03;Y[@0bjJd0080/X:Q0P2S
LY/208=GU@80SF:K0P37WZh40;:4Y0<0bjbj0P3>ZK@0103jfjL0dKBm0;68Z`2aR:/308m`Z`030>6o
]P2[S[P0Zhjh0080`YZ^0`3NaL020=nf[@@0ZWbQ00<0nm:I0=2]]P3Ib<T00P3Ib<T01@2gSjd0]iZj
0;NJ^P2jTJ/0IXcS0080GFO40P2gV;P306EJ/@<0Y8:^00<01F[L01I7``37/lL00P37/lL204iK`080
N72m00@0^I6^0>k1Y@3^`JD0e;Vn1033VZh01@3mhi`0eNoU0=G_i@3EknD0/j;70080?d2[0P2iRjH4
0=o4_P<0`9Za0P2SOJX309edY@<0`92T0P2/Oj<20>kB]P80XiK70P0gF<L00`25HJ00KTF@06i5T002
0:AhXP<0WFjK0`2aPj@20<B?WP80_HJI0P2GJ9T30;5kV0040;n8VP2hPIT0^86I0;^2V0<0eYfJ00<0
bi:I0=VQVP3IXIX00P3;TIP00`3<TYL0k[BC0>jdT`020<B:UP050=2DU@3KW940fibA0>JWT03SYI40
0P3QYYD20>>UT0050?o7KP38//@00@1h0000K@1;HLL00`2MP[H01@2NMZD0mNjI0:]lX@2[O:40mlBD
00<0bIFP00<0o>>?0>BXU03TZ9@00P3a]i000`3gaYL0XY;30>?3]`020=o:``030>S?_03J[Z/0fZj[
0080d:nh0P2gV[X00`3khJD0hKZ`0?oBN0020>FbWP030?3B/`30S9h0`8bN0080M5JQ0`1<AjX2085h
`0<0e:V[00<0?c2G04]7Z`34X[H00`34X[H01@32VJh0g[6Y0=jaZ@3IjMl02ekF00<0/h^[00@0LUJR
0:F?_P2AS/`0THk<0P1MLm000`0RLn80ak?70<Nca`0209=d[P<0Zh>Y0P2WOJD0100029T000000:Uo
Y`36UZD20=V_[@<0ZG^Q00@0WWJU0:IoZ@2VOjT0GU^f0P2QP[820<gXj@040=j^YP3=Vj<0cI^S0?WI
M080^8>L0P2LKYd0101l]_P003Nj08:<e@15CKD305I>[@80/h6N00<0RfbZ01@0D03H[Zh00P3H[Zh0
0`2mT:P0WW:P0000F`020=:c^P<0`ee=0P3oool00`000000oooo0?ooo`0M0?ooo`0000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo100000060?oo
o`030000003oool0oooo02d0oooo0`00000;0?ooo`80[8F[00<0n^VW0?[RZ@3oool00`3oool30:N5
/0<0bjJd0P2bPZ420:=bV`80PeNE00D0SF:K0<NN[P37WZh0aij^0<ZKYP030;:4Y0040<RFX@3;[;X0
cZVd0<jY]080n]^W0`2aR:/208m`Z`80hKnf0P2[S[P01032VZh0c/?@0<k3d03>`m030=nf[@050;23
Y@2ZO:40ZWbQ0:YlX@3kdYT00`3Ib<T20;N?[@040;NJ^P2jTJ/0^Y6[0;ZAZ`80GFO40P2gV;P40:1j
Z@80Y8:^00@0CTV/0;R^c`2h[/l0^:k?0`2TVLX207Q`_@030;VA[P3^`JD0cJVe0080S8_=0P33VZh0
103mhi`0koNk0>og^`2]PZH207n6d00402ibg`0o@:/0^H^V0;V;YP80m>Bj0`2n^MD20<2J/@80XgfZ
0P2MM:D20=_Xg@80`92T00@0[7nS0>kB]P3^d[H0k]:f0`1Xfmh01P1kTMh0001206i5T01^AI00mMB/
06]W^`@0XGj]0P2aPj@01034Sih0_HJI0;f6V@2mQYT309MXV@80/G^H00@0_hRJ0;R1V@2hPIT0^h:H
0`3FWIX00`3;TYT0fJ6J0=VQVP020<^AV0030<bBU`3^]9<0a8ZF0080a8ZF00D0d9BE0=^LT@3KW940
iZN@0>>UT@020>6VU@80hjF@00@0olM^02HFQP0107P0000Q0P1;HLL00`00@lD0WH:f09ifY@030:]l
X@030?O4U039UJ00bIFP0080o>>?00P0_XZN0>BXU03a]i00lKN@0?O6U`3`hWT0hl>g0=o:``80j<nl
00X0fZj[0=2_^03@[kP0d:nh0;NJ^P3So<`0nn6U0>6j/03odWP0iK:N0P3`d[<20<2<WP<0Y:oO00@0
K00004a7ZP21N<00PGS00`3DZJ/00`0o<9L0BdN[04]7Z`030<BR]P80g[6Y0P3IjMl01@0;G]H0/h^[
0;>;Z`2cRj/0LUJR0080aloP0`2`foH00`29PlH0ak?70<Nca`0309=d[P80Zh>Y00D0YgfU0=o<aP00
29T000000:UoY`040=V_[@80ZG^Q0`2VOjT00`1NFkH0cNSY0<gXj@020<gXj@040=j^YP3=Vj<0cI^S
0?WIM080^8>L0P2LKYd208bAd`03000g^P15CKD0ETj]0080ETj]0P2cPIh0100000@0U8g:09B=bP3H
[Zh20;f@Z080WW:P0P3B/kX209<mG0040<=MC@3oool0oooo000001l0oooo00000`3oool000000?oo
o`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02X0oooo0`00000>0?ooo`030:b5Z`3jjJL0n^VW00D0oooo0P2W
QK020=k@b`80bjJd0P2bPZ420:=bV`80PeNE0`37WZh20<ZKYP<0/XBT00@0b9JQ0<^/^P3>ZK@0cZVd
0P3jfjL00`3[el40/HR[0;68Z`0208m`Z`80hKnf0P2[S[P30<k3d080]iBd00<0gkJ]0;23Y@2`PjD0
0P2ZO:420?_BV@80nnNT0`2gSjd40;ZAZ`030195`P1/G[40W7jb0080W7jb0`2PNZT20:B2[P80CTV/
0P2h[/l20:BIbP80a9NY00<0N72m0;VA[P3^`JD00P3=ZKD01@2<Rld0`iZ^0<>J[P3mhi`0koNk0080
[H:V0P1oQ]000`2AO[/0?d2[0;V;YP020?CT^P80j??@0P2n^MD20<2J/@80XgfZ00@0WGBU0=_Xg@3K
j=d0fnSM0P30T:@02@2/Oj<0k]:f0>kB]P3Koll0/8ba0;jS_P0XH]@0Ni7N0000@P0206i5T0030?GD
[01[Ik/0JfNk00<0XGj]0P2aPj@01034Sih0_HJI0;f6V@2mQYT309MXV@030;5kV02oR9X0_hRJ0080
^86I00H0^h:H0=JMVP3FWIX0eYfJ0<^BV@3IXIX30<^AV0030<bBU`3^]9<0a8ZF0080a8ZF00@0d9BE
0=^LT@3KW940iZN@0`3QYYD20>>UT0060611U@0V5XH00@1h00008@000840N7W7102QS;d20:]lX@04
0?O4U039UJ00bIFP0?cSS`80_XZN00D0i:RD0?6gT03a]i00mlJG0?3RN@020=o:``80j<nl103@[kP0
1P3So<`0nn6U0>6j/03Q^[00om9h0>FbWP80l=:c0P30S9h01@0002L0TXc909:<b@000000KHSL0080
PGS00`3DZJ/203l`U`0304]7Z`34X[H0a::f0080enoS00@0g[6Y0>K]d`3<]L<0VHFl0`2cRj/0101b
EZ80aloP0<bmc@3<_Ld20;3KmP80RH?600@004:]09=d[P2CM:h0TgB^0P2[PjT20=o<aP040008V@2Y
OjL00000000090<0fJn]0P2YNj430:IoZ@0305iK]P2cW/80DP0`0080JhoT0`3=Vj<01@3ifG@0^8>L
0;R3W02hPi`0W6jM0080S97C00<0?4Vg000g^P15CKD00P1FCZd20;>1WP<0U8g:00<0f:j^0;f@Z02m
T:P00P2NLZ030:n[d`0509<mG02E2000VgJW0?ooo`0000007`3oool000030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool2000002P0oooo0`00000A0?ooo`030:b5Z`3jjJL0oooo00D0
oooo00@0YhF`0=k@b`3Nd</0g]3;0P3;Y[@20;:2X@80Xg:K00<0PeNE0;jS_P2nXkh00P37WZh20<ZK
YP80/XBT0P38UZ420<jY]080n]^W0P3[el420;68Z`0408m`Z`3Q_kH0hKnf0>6o]P@0ZI:m0`2gU;@3
0;23Y@80ZWbQ0P3kdYT00`3kij@0c:Re0<bX]@020;N?[@050<6DZ02jTJ/0^Y6[0;ZAZ`3de[000P1/
G[4209an/P<0X7ZY0P2TPZh204i9[0<0Xi?50P2UX=020<BGZ@80k/6U0P3=ZKD208b;c@030<>J[P3_
mk/0[H:V0080[H:V0P1oQ]02095n^`030;V;YP3di;X0j??@0080j??@0P2n^MD20<2J/@80XgfZ103K
j=d20<2@Y0030>kB]P3Koll0foo?0080/8ba00D0]HZX02QRe00XH]@06GCR06i5T0020?GD[080JfNk
0`2QOZd20;63Y0040<B?WP2mQYT0_HJI0;f6V@<0UfRI00<0/G^H0;n8VP2oR9X00P2hPIT40=JMVP03
0<^BV@3IXIX0bi6H0080bi6H0P3^]9<30<B:UP050=2DU@3KW940fibA0>JWT03][hh00P3QYYD01`3S
YI00olM^0611U@0V5XH00@1h00008@0008400P1hNLL30:6<_@80ZgbQ00@0mlBD0<VEX03lhhl0o>>?
0P2nRYh01P3TZ9@0lKN@0?O6U`3gaYL0lln[0:g8D080j<nl0P3Llmh20=2_^080Z;gX0P2hVKP00`3Q
^[00000O0?3B/`020?3B/`80`8bN00@0YZ7@09:<b@2BS<T0AfkF0`1]R=`208VGf`040=BYZ`0o<9L0
?c2G03aag0@0enoS00@0i^gC0<be``3<]L<0VHFl0`2cRj/01P20M;`0c;g=0<bmc@3<_Ld0hM77065b
c@80`lcR00@0_YN`0012[@1hYo00N:O`0`2]_nP20=o<aP040:UoY`2]T;P0000000009080fJn]00<0
ZG^Q0:N5/02VOjT00P2VOjT20;>N`P050=V]Z`1[Sn@0JhoT06^?i03=Vj<00P3ifG@30;R3W00309a^
W@000000S97C0080?4Vg00<0F7?C0000CP1FCZd00P2cPIh309B=bP<0_I2X0`2NLZ020:n[d`0509<m
G02KMZL0VgJW0?ooo`0000007`3oool00080oooo1000000=0?ooo`H00000103oool5000000@0oooo
00<000000?ooo`3oool09@3oool3000001`0oooo103Nd</20<^V]080/X:Q0P2SLY/30;jS_P040<NN
[P3:VjH0bY^V0<ZKYP80/XBT0P38UZ400`3Le5X0cZVd0?[KY`030>_G`@80/HR[0`3Q_kH20:f6[080
ZI:m0P3A];`20;ND]0030;V;Y@2`PjD0/8>U0080ZWbQ00<0nm:I0?_WY03<Z;D00P3<Z;D00`2gSjd0
`IBX0<6DZ0020;ZAZ`80m=J`0P1/G[4209an/P<0X7ZY0P2TPZh30:Vnj@<0Xi?500<0YJ3@0<BGZ@34
UjT00`3=ZKD20>[j^P@0_m3W0P2]PZH01@3]a:T0<ES:095n^`2AO[/0m>Bj0080j??@0`2f`^<00`1P
Pmh0]>7f0;JUb0030=CIg080Ymkj00@0fnSM0<2@Y030T:@0glFn0P2KN:/0102`S;40]HZX0;F:Z02e
RZP20;jS_P0306i5T03ee:`0mMB/00<0JfNk0P2QOZd20;63Y0@0_HJI0`2GJ9T00`2aNiP0_hRJ0;n8
VP020;R1V@030<2<W@3FWIX0eYfJ0080bi:I00H0fJ6J0<^AV03;TIP0bi6H0>bfV@3^]9<30<B:UP<0
fibA00/0iZN@0>f_SP3QYYD0hJJE0>>UT03oafh0H46E02HFQP0107P0000Q0000P@0207Qia`<0XHbm
00@0ZgbQ0?O4U03ga9@0bIFP0P3lhhl20;j:WP040>BXU03a]i00mlJG0?O6U`<0Sng9103Llmh20;BG
^@<0^9Vh00<0i?RY0;KOm02fgo@00P3`d[<00`30S9h0YZ7@0:JQd0030::=_P0404M^eP1dQ=D0M8CE
07B4e@<0^k;A00<0^iB_04VBk`3bdk000P3bdk001025R<h0c;G30<be``3<]L<309V5_004081d_039
om/0bOoK0<bmc@80hM770P1QL/d30;jG/0<0N:O`00P0YI[:06QP]P1XH;H0b[[;0:UoY`2eTk@00000
0=fk]P80fJn]00<0ZG^Q0:N5/02WQK000P2VOjT30:Vgh`040=V]Z`1[Sn@0JhoT0<fKX`80nMUd0`2h
Pi`00`2LKYd0000007eW[`0203a9]`80F7?C0P1FCZd00`2cPIh0o]bC09F1^`0209F1^`80_I2X0`2N
LZ000`1nHZP0c9JM0<bFW@0209]fY`030?ooo`000000oooo01h0oooo000V0?ooo`030000003oool0
oooo02<0oooo0P00000T0?ooo`030<^V]02bPZ40/X:Q00<0Z;gY0P2nXkh01@37WZh0bY^V0<ZKYP3:
VjH0/XBT00<0b9JQ00@0g=AJ0<g/j`3=k>/0fOfl0P3[el40102aR:/0_Z>n0;jS_P2nXkh30:f6[005
0:VB_@3A];`0dKBl0=6d_02gU;@00P2iRjD20;23Y@030:YlX@3kdYT0nm:I00@0c:Re00<0]hn]0<6D
Z031U:P00P2jTJ/00`3de[00cj6Y06aN/@0206aN/@80W7jb0P2PNZT30;_hk`80ZKkY0`2STlD20:FP
d0030<BGZ@32bn40cJVe0080j_Zj0P2YRkH00`1eK;/0_m3W0;o@i`020:f2YP030>g4Z@0aF<X0<ES:
0080G;ol0P3@Y:/00`3F[:h0]/;S0;K2h`020=2a^`<0e=WL0P2no<@00`2Wg_X0001/0<2@Y0020=o5
_P80VgR[102eRZP0103R]jX0TGbh06i5T03ee:`20=WbhP0406i?W@1[Ik/0XGj]0:5n[@80/H>T00@0
/XRX0;f6V@2mQYT0_HJI0`2GJ9T00`2aNiP0_hRJ0;n8VP020;R1V@030<2<W@3FWIX0eYfJ0080bi:I
103;TIP00`3/]YT0k[BC0<B:UP020<B:UP040=BHU@3KW940iZN@0>JWT080kJn>00@0hJJE0>>UT03o
afh0/8BV0P0V5XH0100107P06@]o0000P@1hNLL30:6<_@030:]lX@3ga9@0mlBD0080o>>?0`2nRYh2
0?6gT0060?O6U`3`hWT0NgW507]ia@2;e7`0TigJ0P0hCK`30;BG^@050>G8^P2hVKP0^9Vh0?cKO@3N
igd00P28S=000`3`d[<0`8bN08Njm`0208Njm`80XXfn00<0KFJj0:RZf@2XZ]T00P2XZ]T00`2k/]40
^iB_0;^D[`0204VBk`80fMOF0P25R<h20<be``<0VHFl0`39om/20>7Aa`80`lOM0P2FPKX30;jG/0<0
YI[:0P1XH;H20<Zjb`80gK^f00<000000=fk]P2ha><00`2WQK000`2VOjT0clC?0:Vgh`020:Vgh`04
0=V]Z`3^n;H0JhoT0<fKX`<0nMUd0P2hPi`200000080OFN_0P0lBKL209Al]@0305I>[@2cPIh0o]bC
00<0UH6k0`2mT:P209ibX0<0c9JM00@0gJ^Q08i[YP3oool000007`3oool002H0oooo00<000000?oo
o`3oool0803oool3000002L0oooo0`2Sf_/20:Rmj@80_Z>n103:VjH0102bQ:@0b9JQ0<RFX@38UZ42
0<g/j`80RfbY0P21HjL40;jS_P030<RS/`2]QZ`0[HJ/00@0dKBl00<0]iBd0;V;Y@2iRjD00P2`PjD0
102ZO:40nm:I0?_BV@3Xk]030<bX]@<0`IBX00@0^Y6[0?CF/03de[00cj6Y0`1/G[4209an/P030:1j
Z@3Om=X000000080000000<0SmOo03Rjh`1WI[d00P2o`]`206EDZ@80`/_Q0P3Zn[X30:V;]P0407E/
^`30UZ`0_m3W0:f2YP80kLBY0P2EKjD00`20K;<0G;ol0=2TZ`030=J/[P<0d;6k00L0`ind0>O0[`3W
`:l0o=VM0;kla01B@J00Q6jb0080glFn00@0Zh>Z09]hZ`2YP:P0ZH2X0P2eRZP20>:gZP03095l^03e
e:`0fO;R0080fO;R0P1^Cid20:5n[@030;63Y02bR:P0/XRX00<0_HJI0`2GJ9T30;n8VP030;R1V@30
S9d0`8bM0080eYfJ0P3;TYT01@3MXiL0bi6H0<^AV03;TIP0k;JI00@0a8ZF00@0e9RE0=^LT@3VYi00
iZN@0P3][hh0103QYYD0hjF@0?o7KP2`Q:H202HFQP040040N00006d0002107mSZ0<0XHbm00<0ZgbQ
0?O4U03ga9@00P3M][030;j:WP050>jjVP3a]i00mlJG0=79dP1kNLD00P23NL000`2bT;80<c>R03Q=
_0020;BG^@80iLRj00@0^9Vh0>ChZ@3lfgd0g^Mm0P3KiMd01@000000QWk308In``1YGK40Qk[g0080
XXfn0P1]I[X30:RZf@<0^iB_0P3J`<020?7cY080QHS>0`2YgOT20<CVk`80aMKW0P1QZoT30<?7g@80
UX6j0`2nUk000`16@ZP0Ni?O001We00309YeZ080U93<0P3M^kH00`000000XGVV0:N5/0020:N5/003
0<o4c`3Lk=h0g>cN0080B9C`00@0k_Rf0:^_fP2[[mX0cI^S0`3ifG@20;R3W080000000@0OFN_0<^R
[P3;XZh0?4Vg0P2DO;D00`1FCZd0/h6N0?kLT`0309F1^`<0_I2X0P2NLZ00103?YJd0c9JM0<bFW@3M
Zj4208i[YP030000003oool0oooo01d0oooo000V0?ooo`8000007P3oool3000002d0oooo0P1C_OX3
0:F8]@<0bY^V0`38UZ420<g/j`030;jL]02;K:T0RfbY0080PF>W00<0P7No0;jS_P2nXkh00P38Xk<2
0:f6[0040=k1^`3A];`0dKBl0=6d_0<0^H^U0P2`PjD00`2ZO:40nm:I0>S^d0020>S^d0030<bX]@3:
l^`0b_;/0080`IBX0P3de[020<nQZ@80kL6U00D0n]>Q09an/P2LO[80goCJ0:fMa`030:C2kP0502Ag
i02Yb?00IfJm06MV_@2o`]`00P1UE:T0103D_/D0dn[U0=?Zi@3Cj^D30:V;]P0407E/^`30UZ`0_m3W
0:f2YP80kLBY0`2EKjD00`20K;<0eZb^0=J/[P020=J/[P040;b>YP3@/K/0`ind0<>O]080il2_00<0
o=VM0;kla01B@J000P24K[800`3OaKh0Zh>Z0:V0Z0020:V0Z080]HZX0P3R]jX01@2AO;P0[hZ_03@P
RP0d88X0fO;R00<0KTnM00@0S6>M0;:8Z02bR:P0/XRX0`2mQYT209MXV@80W72P0P2oR9X01@2hPIT0
`8bM0<2<W@30S9d0eYfJ0080bi:I00H0gJ>G0<^AV03;TIP0bi6H0>bfV@3;TIT30<B:UP040=BHU@3K
W940iZN@0>JWT080kJn>0P3SYI000`3oafh0/8BV09Z1]`0209Z1]`040000K@000840Of>X07mSZ080
XHbm00<0ZgbQ0?O4U03ga9@00P3M][030;j:WP050>jjVP3gaYL0mlJG0=79dP3VbK/00`23NL0203<c
XP070;BG^@3Ub;X0iLRj0>G8^P3Tn:T0djfa0:K^n0020=_Ug@80Xi;20P26O/<206UM/@80XXfn0`1]
I[X309aj[@80^iB_00<0L8cN0;K;jP2fbnX00P2fbnX30;71iP80V8W20P35e^L20:nF_@80A9_d0P33
amd309J1^P80_YN`00@0k>?70<Rnd@00Im@006OD0P2JMJP209B@c0<0gK^f00@000000:gii02]nN@0
[OWT0P3Lk=h20<;jj`<0`/WP0P2jZ<P0102QOjh0nMUd0?WIM02hPi`20:?3l0050000001mIjl0bj:^
0<^R[P3Db4P00`2DO;D01@2cPIh0o]bC0;B;Z`27IjL0UH6k00<0_I2X00<0WW:P0<nU[@3?YJd00P3<
UYd0103MZj40SV^V08i[YP00000O0?ooo`009P3oool00`000000oooo0?ooo`0J0?ooo`<00000<@3o
ool2066lo@80YHRe0`3:VjH0103J`L00b9JQ0<RFX@3Wc[h20;jL]080RfbY00@0PF>W0:Z2Z@2ZPZT0
P7No0`38Xk<0102]QZ`0g/6k0=k1^`3N`K/30:jC^`80^H^U0P2`PjD20;n/a`<0j>k@0`3:l^`20<6D
Z0040>cfYP2hTJh0^96^0<nQZ@80kL6U00<0n]>Q0?[OZP3jgjX00P3D`lX00`3N^[D0Y<;^0:C2kP02
0;^ed`80IfJm00@09c6V06EDZ@3D_/D0e;k50P0000001026[Nh0EFS:0:V;]P2YRkH30<2F[0030:f2
YP3]a:T0WWFT00<0UFnU0P20K;<20=J/[P80_8jV0`33Wk@0103W`:l0o=VM0?cIW@2no<@20591X004
08A^/P2[PjX0[8N]0:b7[@80ZH2X00@0]HZX0>:gZP3R]jX0h[NZ0P2_RZl203@PRP040=WbhP1^Cid0
KTnM06i?W@80S6>M0P2bR:P30;f6V@@0W72P0P2oR9X01@2hPIT0`8bM0<2<W@30S9d0eYfJ0080bi:I
00H0gJ>G0<^AV03;TIP0bi6H0>bfV@3;TIT30<B:UP040=BHU@3KW940iZN@0>JWT080kJn>00<0kk>?
0>>UT03oafh00P2`Q:H209Z1]`0800008@0I2gl0Of>X07mSZ00/=ZT0XHbm0:]lX@3ga9@20=ff/008
0>RdW@2nRYh0_XZN0;j:WP3^^YX0k]IT0>7SMP2^OZ020>K9^`80PgW000<0/Y2b0=>RY@3Ub;X00P3U
b;X00`3@nND0djfa0=>]/@020:N9]@030>c;/P3>W:80Xi;200<0QWk30P1YGK4209=_Y`<0XI;50P2L
NZd0102kU:l0QH_A0=2ja03@^/@409OSo@80/L7V00<0V8W20<gj[`3=nZl00`2_U[d0103QmYl0A9_d
04BKm01mKkP309J1^P060;gVl`3/hlL0_JG10;fU`@38_]4006OD0P2JMJP308oTo080AgOL00<00000
0=S6A@2L6`000P2DMZl01032n^/0ZHji0:V>^@2YS[T20;:A]0<0[YS000<0XGn^0?WIM02hPi`00`3o
ool20<^R[P80e<Q80`2DO;D00`2iS:L0]8^[0;B;Z`0208MWY`<0_I2X00@0WW:P0<nU[@3?YJd0c9JM
0P3MZj4308i[YP030000003oool0oooo01`0oooo000V0?ooo`030000003oool0oooo01L0oooo0`00
000f0?ooo`<0YHRe00<0bY^V0=[1`03J`L000P38UZ400`3Wc[h0_Ybd0;jL]00208]/Z@<0ZX:Y00D0
A42W0008S038Xk<0b:>c0:f6[0020=k1^`80j=o90P2^Tk/20;V;Y@030;23Y@2o[<L0_jc700<0Z>kh
0`2QNJL00`3:l^`0`IBX0>cfYP030;RA[P050<nQZ@3]`JD0n]>Q0?[CX@3jgjX00P3D`lX20=jj]@03
0?OU/P2ITLX0VI7:0080^kGC00@0IfJm02LaYP3D_/D0e;k50`2/T[/00`26[Nh073Ze0;6J`0020;6J
`0050<2F[03N/JT0kLBY0>g4Z@2NMJ@00`2EKjD2081//`0600hBS`3F[:h0_8jV0;b>YP38Tih0`ind
0P3W`:l20?cIW@040000001B@J00DT6P05YS`P<0[8N]0P2YP:P01P2eRZP0h[NZ0>:gZP3R]jX0`iV/
0:n:[`<0=22:00<0fO;R06i?W@1^Cid00P2<Hid20;:8Z0<0_HJI00@0b9BQ09a`X02LL:00W72P0P2o
R9X40<2<W@<0bi:I00<0gJ>G0<^AV03;TIP00P3/]YT01P3;TIT0a8ZF0<B:UP34RYH0e9RE0=^LT@80
iZN@0P3][hh02@3_/hl0hjF@0?o7KP2`Q:H0Tgfg09Z1]`2KMZP0000Q01T;O`0307mSZ00302`fZ@3g
a9@0mlBD0080gKJ`00P0j;BM0;j:WP2nRYh0_XZN0>jjVP3^eV@0RF6M0:inX080i/Vk0P23NL00202b
T;80dj:U089i`022NL00d?WU08aVXP0:0000djfa0P2WRKD01P3/bk80cYbR0:>B`P2ST/8002jc08In
``80JEfa0P2CKjL30:6Ba@80W7Z]00H0^iB_0=2ja03@^/@0d;[40<RS/`36Tj43099`Z00308=_]@3=
nZl0WgNU0080WgNU00D0[iJm0>7fW`3QmYl000ZL04BKm00207e_^080H/7m00H0k>?70;fU`@2mYL40
_JG10;BG^@00Im@209YeZ0040<RHY02m_=T0_KcI08mXXP80l;jK00H0000009`K002DMZl0U7J_0:J6
/`2>20020:V>^@80/Y6d00<0e[Fh0:jH`02^V<000`2QOjh30?ooo`0309PA003;XZh0e<Q800@0oooo
0`2dRj/308MWY`80QFf`0`3?YJd00`3<UYd0gJ^Q0=f[X@0308i[YP030000003oool0oooo01`0oooo
000U0?ooo`030000003oool0oooo01D0oooo0`00000i0?ooo`<0YHRe0`3J`L001038UZ40Y8>a0:B3
/@2TPk4208ia[P80PFfc0P2ZPZT01014@:L000R<0<RS/`38Xk<20=k1^`<0j=o90P2^Tk/20;V;Y@<0
_jc70P3]ek`205JKlP80XGVW00<001BN0<6DZ02hTJh00`2hTJh0103?XJT0kL6U0?[CX@3jdj420=C3
bP<0g[Ze00H0mnFb09VAbP2UPZh0YH:^08Eb]P2m`]h202LaYP80d=oS0P2/T[/00`1TEjh073Ze01`j
]@020;6J`0030<2F[03N/JT0g[6Y0080WWFT0P2EKjD20=_6a@03081//`0>4Xl0_8jV0080_8jV00L0
b9>N0<>O]03W`:l0il2_0?cIW@000000H5fh0080DT6P0P1JHl820:b7[@80ZH2X0`3R]jX20<>I[005
0:n:[`0d88X0=22:03@PRP3Il^800P1^Cid208aSW@<0/XRX0P2mQYT01038U:40W72P09a`X02LL:02
0;n8VP050;n:W030S9d0`8bM0<2<W@3AVid00P3;TYT20=fSU`040<^AV03/]YT0k;JI0<^AV@<0a8ZF
00<0e9RE0=^LT@3VYi000`3][hh00`3_/hl0hjF@0?W8F`0209=m]`0409Z1]`2KMZP0000Q01T;O`<0
Of>X0P0/=ZT30=ff/0030>RdW@2nRYh0_XZN0080k[ZJ00<0k]IT08UQW@2^OZ000`2/Rk801@21Ijd0
dj:U0=>RY@3CXZD0PWW00080S6JR00@0[hFW0?cKO@2WRKD0k<^b0P3>W:8309egY`0308J5b`1YGK40
JEfa0080TfnW0`2QT/D209aj[@030=jk]@3Yn:/0d;[40080b:>c00@0aY>Q099`Z02BL:P0TW2X0P23
KkD0103<XZd0WgNU09mgY@2_U[d300000007000:W01mKkP0cKK30<ff``2CS//0i]W80380;0020;fU
`@030<:M/`2dUkT0VWFX0080b9RT00<000280;flf@2?J:800P3`_Y/02@3HaTD0000009Af[`2DMZl0
000608h8002YS[T0m>V;0;:A]0020=Je^0<0[YS000<0XGn^0?ooo`3oool00`3oool00`3;XZh0oooo
0?ooo`030?ooo`030:8_;02dRj/0]8^[00<0QfNW0`25KK020<nU[@030<bFW@3MZj40gJ^Q00<0SV^V
00<000000?ooo`3oool0703oool002D0oooo00<000000?ooo`3oool04P3oool3000003`0oooo102X
_^T20=[1`0040<RFX@2`S:l0Y8>a0:B3/@80SW6^0P21KK<20:Z2Z@80A42W00<0b:>c0;chk@2ln>d0
103XglT20:jC^`80^H^U00<0^nN60;n/a`3XiG`00P3]ek`01@2SR[X0EY_b0:5iY`2QNJL001BN0080
f_WM0`2hTJh00`3]`JD0n]>Q0?[CX@020<KOj`<0g[Ze0P3giK830:F2[P80QG:f103@gn<20:bB^`80
I5N^00@073Ze0;6J`02aV/00`9J/0P3N/JT209ieY00509E_Y@3Ka/D0flK50=_6a@30X;P00P0>4Xl2
0;b>YP030<RCWP3W`:l0il2_0080o=VM00@00000061M^01B@J00DT6P0P1JHl820:b7[@80ZH2X00<0
f/O70>:gZP3R]jX00P33VJ`01@2_RZl0=22:03@PRP0d88X0001U0080KTnM0P2<Hid30;:8Z0030;f6
V@38U:40b9BQ00<0W72P0P2oR9X01P2oRY`0`8bM0<2<W@30S9d0dI^M0<^BV@<0gJ>G00@0bi6H0>bf
V@3;TIT0bi6I0P34RYH20=BHU@030=^LT@3VYi00kJn>0080kJn>00<0kk>?0>>UT03kjIh00P2COKL3
09]fZ00301T;O`2LOK40W7fa0080W7fa0P2CPkl01@3M][00j;BM0>RdW@3X]9d0_XZN0080k[ZJ00<0
hN=f08UQW@2?UmL00`2/Rk82085W[@80dj:U00L0PWW008aVXP2<IZ80[hFW0<:;VP2WRKD0k<^b0080
cYbR00<0d9ZM09egY`2MMjL00P26QL/0201YGK40TfnW09=_Y`00FKX0RJSY0:6Ba@2LNZd0g[^e0P3Y
n:/20<RS/`80aY>Q0`2BL:P00`23KkD0c::]0<bR[@0209mgY@030000003Yn[<0cJVd0080Rfj]0`3=
]/<20>KIb0030=Bk`P2mYL40`Yfc0080`Yfc00P0VWFX0<RHY038V:@0e/e?0;flf@2?J:80l;jK0=S6
A@80/H>S00L000000:1_VP0000H0YXJc0:V>^@3djH/0/Y6d0080e[Fh0`2^V<000`2QOjh0oooo0?oo
o`0:0?ooo`<0]8^[0P27IjL308E]/080cjF]0`3MZj4208i[YP030?ooo`000000oooo01d0oooo000U
0?ooo`<000003`3oool300000400oooo00<0^I:_0:Rnj@2X_^T00P3J`L001038UZ40/8b_0:B3/@2T
Pk4208ia[P80PFfc0P2ZPZT204A0Y`80Kg_?00<0c/??02F]fP0U[MX00P3XglT20:jC^`040;V;Y@39
W:X0bIbZ0>SUO0<0kMNl00@0_LkW05JKlP2QNJL0XGVW0`3JnMd30;RA[P030>gQa@3BYZ/0ACFI00<0
Z;7O0P3N^[D30<:jdP80YH:^0P25L[H20<FV^P80d=oS0P2/T[/206AG[P0304aA]P2aV/00/I[000<0
g[6Y0P2NMJ@30=_6a@80`:2h00<0001^00hBS`2lSZH00P38Tih01@3YdU/0il2_0?cIW@2GOkL0FU6^
0080H5fh00<0LERV0:J8]@1JHl800P2/Qjd0102YP:P0f/O70=[7a`3JalL30<>I[0050:n:[`3G^K`0
ekVl0=:oa`0k00000P1^Cid208aSW@<0/XRX00<0_HJI0<RDX@38U:400`2LL:020;n8VP030;n:W030
S9d0`8bM0080dI^M00H0bi:I0=fSU`3MXiL0gJ>G0<^AV03/]YT30<^AV@050<B:UP3DV9D0e9RE0=^L
T@3VYi000`3][hh00`3_/hl0o]9h0?_YWP0309=m]`80VgJX0P0I2gl309am/@80Th>o00P0gKJ`0>Rd
W@3X]9d0j;BM0;j:WP3^^YX0k]IT08UQW@80SiOG0`2/Rk82085W[@80dj:U00D0PWW008aVXP2<IZ80
[hFW0<:;VP020>c;/P80cYbR00<0d9ZM09egY`2MMjL00P2KMJL00`1YGK40TfnW06U/`P030<_ob@03
000?V03N^kD0Y86^0080Y86^00@0b:>c0<JCX@36Tj40aY>Q0P2BL:P00`23KkD0c::]0<bR[@0209mg
Y@030>Wj/`3=ZK@0cJVd0080Rfj]00@0P6N]0<ff``3VfLP0i]W80P3D^l840<:M/`<0b9RT00D0e/e?
0;Z@Z`2?J:80l;jK0=S6A@020;63X`040000002PKiX000060:J6/`80m>V;0`3F]KP@0?ooo`030:8_
;02dRj/0]8^[0080QfNW0`25KK020?ooo`0305d:AP3MZj40gJ^Q00<0oooo00<000000?ooo`3oool0
703oool002D0oooo00<000000?ooo`3oool0303oool3000004<0oooo00@0^I:_0?CL]@3oool0oooo
0`2`S:l20:B3/@80SW6^0P21KK<20:Z2Z@030<6N]@2>JjH0SV^V0080X]cl0P3^dkP30=Zd/P050<2C
Z039W:X0bIbZ0<VLZP3XiG`00`2UPZh0103]aj`0EY_b0:5iY`2QNJL30>S>^`030=[ig@2hTJh0kN75
0080dZJ[0P15=IT30:Rag`80N=f_0P32^]820:F2[P0408Eb]P35Y[X0aJJj0<FV^P80PFbb0P2/T[/2
06AG[P80C56f0P2?Q/H20=jaZ@@0^[3?0`30X;P00`0006h03Q:?0;b>YP020<RCWP040>WBF`3Nigd0
g^Mm09Mo]`80FU6^00@0H5fh075HYP1aF:H0YXRe0P2/Qjd30=[7a`80cL?@0P33VJ`20=Ni_080d[o7
00<0>`0006i?W@1^Cid00P2<Hid01035VJ/0MeJN0;:8Z02mQYT20<RDX@<0W72P00<0_hRJ0;n:W02o
RY`00P30S9d20=6KW@060<^BV@3MXiL0gJ>G0=fSU`3;TIP0k;JI0`3;TIT00`34RYH0e9RE0=BHU@02
0>JWT0<0kJn>00<0kk>?0?kBN02XYmH00P2NQKP00`2COKL0VgJX09]fZ00201T;O`<0W7fa0P2CPkl0
1`2=LJh0j;BM0>RdW@3X]9d0_XZN0>jjVP0000X00P1kbOl0101OF[D0SiOG0:b;/P2/Rk82085W[@03
0=>RY@2_T[P0[i:h0080S6JR0P32RiX01@000000cYbR0<jLXP3>W:80d9ZM0080WGNW00D0g[F^09]e
Y`2KMJL0TfnW06U/`P020:n9[@040000>@000000000009HZ=P80Y86^00@0b:>c0<JCX@36Tj40aY>Q
0P2BL:P30<bR[@80WgNU00<0B`000<fY]03=ZK@00P2;KZd3081W[@<0e;_200D0ASfS0<:M/`32WK<0
`Yfc01L0:P020<RHY0040=K=C`3RdlL0l;jK0?2nV`<0/H>S00<0X6nJ0000000000H00P3oool206gM
i`030=Je^03oool0oooo0100oooo0P2dRj/208MWY`030000003oool0oooo00<0oooo00<0gJ^Q0?oo
o`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`009@3oool00`000000oooo0?ooo`0:0?ooo`80
0000BP3oool30;2<[`80Y8>a0P2>LJh2085]/`030:Z2Z@31W[D0`Ije0080SV^V00<0n^ZO0?C/T`3U
o<400P36[l<20=Zd/P@0bIbZ0`2UPZh20>g7[0040?W/WP2QNJL0^ZK5000GX`80j<jk00<0XXo00>gQ
a@2RSl000P3BYZ/204DeV@80Q>Kd00<0eK_00=CRM000Im400P32^]820:F2[P<0aJJj00<0`K;<085/
/P21K;800P2FKj@208I][`80C56f0P2?Q/H30;gFk080^[3?0P3GfMT20<2P^0030000F0075YH0_8jV
0080b9>N00@0jM9K0=kWO@2GOkL0Ugng0P1JDJh0101PGKP0LERV075HYP2VR;D30:Vnj@@0cL?@0P33
VJ`01`3WnkP0ekVl0>cF_@3/e[d0>`000000I@1^Cid00P2<Hid00`35VJ/0MeJN07MFWP030<RDX@<0
W72P00<0_hRJ0;n:W02oRY`00P30S9d20=6KW@040<^BV@3MXiL0gJ>G0=fSU`80k;JI0`3;TIT01@34
RYH0e9RE0=BHU@3VZi@0iZN@00<0kJn>00<0kk>?0?kBN01QK<L00`3Qh=<209]fZ0806@]o00<0001_
09am/@2LOK400P3BWIl0102=LJh0j;BM0>RdW@3X]9d20>jjVP0300002P1FOMd0NlWo0080GeZe0P2/
Rk82085W[@<0[i:h00L0S6JR0<^IXP32RiX0`X^J0000003cgWH0cYbR0080d9ZM0P2MMjL00`3N]Jh0
VgFW09]eY`040:n9[@040000>@009JT000000000Q`80Y86^1036Tj400`2BL:P0XWFP0:9eX0020<bR
[@0309mgY@18[OP0B:gh0080cJVd0`2;KZd2081W[@0:0000003D^l80e;_204HmX`3YbKH0`Yfc0?gL
W@0G02X0b9RT0=K=C`80h]?700<0^Y2[0?2nV`001I800P2aPj<20:1_VP030000003oool0oooo01D0
oooo0P2dRj/=0?ooo`030000003oool0oooo01`0oooo000U0?ooo`030000003oool0oooo00L0oooo
0`00001=0?ooo`80/8b_0`2EM:`209I^X`0406iDX`31W[D0`Ije0<6N]@80SV^V00<0n^ZO0;N;Y`00
00000P36[l<30;b^b`80bIbZ0P2?I9`20:F2[P040>g7[03ik9h0nNbN0:5iY`80a[C800<001NS08f?
d@2=Sm400P2RSl020=:VZ`0504DeV@3Bbm<0d/_C0=;;d`3E^l000P30/L/00`00Im40`[[B0:F2[P02
0<Vib`80aJJj00<0`K;<085//P21K;800P2FKj@208I][`80WGnb0`2Vd_L20;gFk0@0emWI0P30X;P0
0`0005P01aJF0;b>YP020<RCWP040>WBF`2DO;H0U7bf07ig`@80FU6^00@0002;075HYP1aF:H0YXRe
0`3Tfld01@1UG[D0YjKE0<g3d03=`m00`iV/0080io^h0P3/e[d01@2]Oj<0001V0000NP1^Cid0S6>M
0080aIV[0`1gEYh20<RDX@<0W72P00@0_hRJ0;n:W02oRY`0`8bM0`3AVid01P3;TYT0gJ>G0=fSU`3M
XiL0fJ>M0>bfV@<0bi6I00D0a8ZF0=BHU@3DV9D0iZ^D0>JWT0020>f_SP80kk>?00<0o]9h065/a`1Q
K<L0102j/M001@0002406@]o0000K@2LOK40dOoH0080dYfO103X]9d01@2]OZ40k[ZJ0;SKlP1FOMd0
NlWo00<0GeZe0P2CMk420:6:^`<0[i:h00H0biVR0<:;VP32RiX000000??NMP3>W:820=2JW@0309eg
Y`3N]Jh0g[F^0080VgFW00D0/h:P0:n9[@2_RJd0[hV]07US[@02000UZ@040000Q`2TPJh0Y86^0>G@
`P<0aY>Q0`2RMJ020<bR[@0309mgY@1DFK/0B:gh0080cJVd0`2;KZd02`20Ijd0ThW509>9a@2CRLD0
e;_204HmX`3YbKH0oMbM0?kMUP0G02X0b9RT00<0h]?700<0^Y2[0<RDX0001I800P2aPj<20:1_VP03
00001P000000oooo02@0oooo00<000000?ooo`3oool0703oool002@0oooo00@000000?ooo`3oool0
0000103oool300000500oooo00<0/8b_0:b4ZP2/Q:X00P2EM:`209I^X`80KUBS0P31W[D01@2>JjH0
n^ZO0?[ZW`2gRjL003g100<0YjSG0P2l[//20<VLZP80SfBL00<0YH:^0>g7[03]aj`00P3ik9h30<Jd
b00304m4Y@2=Sm40SHoA0080XXo00P3BYZ/30=;;d`060=Fk`03gj;<0`;7;0<2ab`3=^lT003Nm1039
^L/0102KPkT0Lf:`085//P21K;8209I_Y080QVf_0P2MOk80100049H0ZKOS0:Vgh`2Y]n<309:3_`80
emWI0`2VTKl01@075YH0b9>N0<RCWP38Tih0TFRO0080U7bf00@0OWO10;^@ZP2kT:X0002;0P1aF:H4
0>CKc@80IEje0P2WY]D205MTa080k=Jm0`2]Oj<00`0007X09c:W08aSW@020<FIZ`<0MeJN0P38U:43
09a`X0<0_hZL00D0`8bM0=6KW@3AVid0dI^M0<^BV@030=fSU`030=VSW@3;TIT0bi6I0080bi6I00D0
a8ZF0=BHU@3DV9D0iZ^D0>JWT0020>f_SP80kk>?00<0o]9h0:1m[02POJ`00P2POJ`209meX`040000
8@0I2gl0001]0=7of0<0dYfO00<0fjVS0>RdW@3X]9d00P2]OZ40103beVH0^=_b05Img@15A:`305mJ
]@80TgNa0P2QR[/30:nB^0060<^IXP32RiX0`X^J0000003cgWH0cYbR0P3@VYd00`2MMjL0g[F^0=je
[P0209]eY`040;>2X02_RJd0[hV]0:VPc@80NF>]0P009JT00`2TPJh0iM320>G@`P030<JCX@030;N5
W`2RMJ00XWFP0080c::]0P3PlmX0101DFK/0/Xj`0;:>/027M;L30:f@^080ThW50P3QimL20>W9]P04
0?gLW@3ngIH0o]fF0<RHY0<0h]?700<0^Y2[0<RDX0001I800P2aPj<20:1_VP030?ooo`000000oooo
02D0oooo00<000000?ooo`3oool06`3oool002@0oooo0`0000020?ooo`<00000D`3oool30:b4ZP80
UGB/0P2FKZ<206iDX`80`Ije00L0SV^V0?[ZW`2gRjL0]h^W0<NDX@00?L40YjSG0080e>kU0P2l[//0
1P39W:X0SfBL08mTW02UPZh0kLN/0?W/WP<0d>GV0P36]<P204m4Y@0408=WZ`2GKj<0UfnS09M_X`<0
WH2c0P3E^l020?OX/`<0cK_90P2OOJh00`3cg;L0Vh>i09^3^@0207=R/003085//P2FKj@0UVnT0080
QVf_0`2PRK/207A__`80ZKOS00<0TX>o0>7m``3QoL<00P1/Y_<20:JA_`801aJF00<0b9>N0>WBF`2A
J9l00P2DO;H01@1nMl40^i2Z0;^@ZP2kT:X0002;0080X[KV0P0000000`1kK;H0IEje06EN]@050:NV
e@@0[GnS00<0001j02LbY`35VJ/00P35VJ/307MFWP80b9BQ102EK:420;n:W0@0dI^M0`3MXiL20=VS
W@040=^RV03;TIT0bi6I0<^AV@<0e9RE00@0iZ^D0>JWT03][hh0kJn>0P3_/hl208aYY@<0X7f/00L0
aYRW09meX`2OMJ<06@]o02DCP`15;i80001_0080dYfO0P3KZJ<30:enX@040?;FIP2BT<h0TY3>04E4
[0<0GeZe0P2CMk420:6:^`<0[i:h0`32RiX20??NMP030<jLXP3@VYd0d9ZM00<0g[F^00H0VgFW0;>2
X02cPZ00/h:P0:n9[@2YX<d207US[@8002FY0`3Ud<830<JCX@050;N5W`2RMJ00XWFP0<>j<`20KK<0
0P1eM/H30;:>/080QgBg0P2]T;P40>7We`0404E@^@3YbKH0oMbM0?kMUP80oooo00<09c>X0728f`1`
R=/00P38U:001@001I80/H>S0;63X`2aPj<0X6nJ0080oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0K0?ooo`00603oool7000000D0oooo00<000000?ooo`0000000P00001G0?ooo`80
[8BZ0P2EM:`209I^X`80KUBS0P31W[D01P2>JjH0anS^0;N;Y`2gRjL0aiBQ04MF_@@0e>kU00@0h>[I
0>_ac@2?I9`0SfBL0P3]aj`205A;ZP<0V8W200<0a[C804m4Y@1?A:D00P23Ij/209M_X`<0WH2c00<0
joJT0?OX/`3gj;<00P36//H20<fkb@0309mm[P3cg;L0lmbg0080Vh>i0P1cH[001021K;80UVnT09I_
Y02YNj42091_Z@80X8Vk0`1dKkl00`1@J<`0hOg309eiZ`0209eiZ`0606bVl`2VTKl0YY6o04]?]007
5YH0b9>N0P2AJ9l209Al]P@0^i2Z00D0mmBX03QA`02ooLd0_og=0000000207]/]P80YjKE0P28M;D0
0`2WY]D0/Hb_0;6<[`030:eoX`030000IP0W<ZL09c:W00<0aIV[0P1gEYh20<RDX@040;bBZ`2EK:40
UFbQ09E/X@80_hZL00D0jkfS0=6KW@3AVid0dI^M0<ZHXP020=fSU`80fJ>M00D0fj:H0<^AV@3;TIT0
bi6I0<:<W0020=BHU@060>J[U03][hh0kJn>0>f_SP3_/hl0o]9h0P2<JJD30:1m[0080<JHY`2OMJ<0
WgFS01T;O`0U4h<0ABnB0000K`3BWIl30=^YX`060<RBW02]OZ40[GjQ0:R8/`2BT<h0ak?60`15A:`0
0`1OF[D0TgNa09=g/@020:9kZ00409In]`1m[?40OJca07f/l@80`X^J0P3cgWH30=2JW@040>[II`3N
]Jh0g[F^09]eY`<0/h:P00L0[hV]01<n_01iHjd0NF>]01HNV@009JT0GU6[00<0iM3200<0aY>Q0;N5
W`2gQIl00P2RMJ000`3D`Sh0P6fc07EfaP0207EfaP80/Xj`0P27M;L00`2]T;P0dLWB0=79dP030>7W
e`0304E@^@3mg9d0o]fF00@0oooo0`1`R=/20<RDX0<0/H>S00D0X6nJ0?ooo`3oool0oooo0000000T
0?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo00H0oooo0P00001J0?oo
o`80[8BZ0P2EM:`209I^X`0306iDX`37]/T0akK90080anS^00@0biJN0;N;Y`2gRjL0aiBQ102cV;/0
0`3^f;d0gknh0>_ac@0208mTW00308f@dP3Eg=d0E4^Z0080cKC20`2HRL8204m4Y@80PfN[0P2GKj<2
09f0/`80^]C]1036//H20<fkb@0309mm[P3cg;L0lmbg0080Vh>i0P1cH[00101=?Yl0UVnT0:UkX@2Y
Nj43091_Z@80X8Vk0P1dKkl00`1@J<`0]YBd0;JD]00209eiZ`060;nmf02VTKl0YY6o0<fKY0075YH0
b9>N0P2AJ9l309Q[W@80^i2Z0P3ge:P20;>_e0040?7G]`000000Nfbf07]/]P80YjKE0P28M;D30;6<
[`<0[GnS00<0nMVX0000NP0W<ZL00`35VJ/207MFWP030<RDX@2lTZ/0_9:[00<0UFbQ0P2oRY`01@3[
_J<0dI^M0=6KW@3AVid0bYRR0080gJ>G0P3IXid01@3KXYP0bi6I0<^AV@3;TIT0`XbL0080e9RE00H0
iZ^D0?kCN03][hh0kJn>0>ncS`3ndWP308aYY@030:1m[036V:L0aYRW0080WgFS00D06@]o02DCP`15
;i80ABnB0=:MW`030=^YX`040<RBW02]OZ40[GjQ0:R8/`<0ak?60`2GN:h01P2cW/<0XW^X0:9kZ02R
NjP0cJRd000CSP80OJca0P32RiX201i3_00401`0003@VYd0d9ZM0>[II`80g[F^102cPZ000`3W/Yd0
4cjl07US[@0207US[@03000UZ@1NDJ/0iM320080iM3200<0aY>Q0;N5W`2gQIl00P2RMJ02081]/`<0
MGK60P2bS[0208Md]`80dLWB303oool20728f`030<RDX03oool0/H>S0080/H>S00D0X6nJ0?ooo`3o
ool0oooo0000000T0?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0F03oool20:b4ZP80UGB/0P2FKZ<30<Nfb@80jMO300D0biJN0;N;Y`37
U:40aiBQ0>jnW`020;>H^`040>kH_@3O_kP0gknh0>_ac@80SfBL0P34_M@40<fd`P0409R9`P3Md</0
gM3;04m4Y@80PfN[0P2GKj<00`2MP;<0j?JS0<_YQ00207NFi080a[;60P31X[T00`00Em80lmbg0<_Z
Q`0208]g^00407ad_`1cH[00Lf:`04dnW`<0ZG^Q0`2@KjT20:29^`80M6no0`2fU;@209eiZ`060>:n
/`3=Vj@0cI^T0<fKY0075YH0b9>N0P2AJ9l00`2`OI`0V6^M09Q[W@020;^@ZP80mmBX00D0mNZh0?7G
]`3aekL0`YFY07]/]P020<KVk@040:NVe@28M;D0^IZi0;VJ^@80/Hb_0`2]Oj<00`3ifJP0:32T000N
ZP030<FIZ`80MeJN0`2lTZ/309E/X@80_hZL00<0jkfS0=6KW@3AVid00P3:V:801@3MXiL0fJ>M0=VS
W@3IXid0fj:H0080bi6I0P32S9`0103DV9D0iZ^D0>J[U03ndgP20>f_SP030>ncS`3ndWP0S6VU0080
S6VU00<0X7f/0<JHY`36V:L00P2OMJ<01@0002H09A>304D_TP15;i80dYfO0080fjVS0P38TY`20:en
X@040:R8/`2iT:`0ak?60<NcaP<0UgR^00H000000:9kZ02RNjP0XW^X0000003=Z;@207f/l@050<:;
VP30TjP0X7NT01i3_00L00000P3@VYd0103ZfFL0bJFe09IbZ02FLZP30;>2X0060>NbW@1nHJH04cjl
079P[`1iHjd05QjI0P1NDJ/207aU[P<0]hFO0P2RMJ0309io/P03039B``1eM/H0/Xj`0080fnSM0P2@
V]T>0?ooo`030728f`38U:00oooo00<0/H>S00<0X6nJ0?ooo`3oool00P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo00P0oooo0P00001H
0?ooo`050:b4ZP3EdMD0eM7E09Ed[02FKZ<00P34bn000`37]/T0jMO30>WG``020<^FWP030;N;Y`37
U:40aiBQ0080k[jO00<0/iRk0>kH_@3O_kP00P3O_kP00`2?I9`0Qh?708N3a`020<Bme0<0cKC20`3M
d</00`0Q=Zh0PfN[08=WZ`0209M_X`040>SfX`3>omL0T8W80929b080MiKT0`31X[T01@0TFLl0e/;6
0<_ZQ`2;MkP0_ing0080O7Bo00<0Lf:`04dnW`1=?Yl00P2YNj42091_Z@80/HNY0P2PR;X2091n_080
]YBd00@0WGV[0>:n/`3R_[<0b9^Y0P3=Vj@01@3?V9`0b9>N095XW`2AJ9l0/7fL0080V6^M00@0^i2Z
0?ODZ03ge:P0mNZh0P3Co=l20<:EZ@<0a^K]00@0M5bX0;VJ^@2iV[T0^IZi0`2aS:l01@2]Oj<0nMVX
0?WIZ00X<:@001jZ00<0aIV[00<0MeJN0::1/02RPK000P2lTZ/309E/X@050;n:W03[_J<0jkfS0>^m
X`3AVid00P3:V:801@3MXiL0fJ>M0=VSW@3IXid0fj:H0080bi6I0P32S9`00`3DV9D0iZ^D0>J[U002
0?kCN0030>f_SP3_/hl0o]9h00<0S6VU0`36V:L209meX`0400009P0I2gl0001]04D_TP<0fjVS0P38
TY`0102]OZ40l]IV0;V@[02iT:`20<NcaP0408=UZ02GN:h0UgR^0;NH^080XW^X0P0000001@3=Z;@0
OJca07f/l@32RiX0`9>X0080X7NT00<070000=2JW@3ZfFL00P39YKD209IbZ0<0/h:P00<0ik:M07iQ
YP1nHJH00P1bH:l00`0F7YT0GU6[05iAZ`0307aU[P80]hFO00<0XWFP0<>j<`1fGj/00P2NOk82039B
``<0fnSM403oool0101`R=/0b9BP0?ooo`3oool20;63X`030:1_VP3oool0oooo00<0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0K0?ooo`006`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo05D0oooo0`3EdMD0100ZBkl0a<_P0<C;h034bn020>WG``040=N/Z`3;UYh0
biJN0;N;Y`80aiBQ0P3^_Yl01P3^f;d0gknh0=no^03O_kP0e:nc08mTW0<0[YFm00<0aib[0;k_lP2n
ko800P2nko820=g@b`030:;Kn`23Ij/0PfN[0080UfnS00<0j?JS03MQd02g^MX00P2g^MX207>@h005
0<6R^@0TFLl0e/;60=K2aP0A?;X00P2oWkL207ad_`030593XP1=?Yl0CCjO0080ZG^Q00@0T6nY0;67
Z@2aQjT0/HNY0P2PR;X2091n_080]YBd00@0WGV[0>:n/`3R_[<0b9^Y0P3=Vj@00`3?V9`0b9>N095X
W`020;1mW080V6^M00@0^i2Z0?ODZ03ge:P0docO0`2bUk`20<:EZ@0409<D0036i^d0M5bX07ALZ080
^IZi0`2aS:l00`2]Oj<0nMVX0?WIZ00202P`Y003000NZP23IJL0PfFW00<0XX6`0`2lTZ/209E/X@05
0;n:W03[_J<0jkfS0>^mX`3AVid00P3:V:800`3MXiL0fJ>M0=VSW@020=^RV080bi6I0P32S9`00`3D
V9D0iZ^D0>J[U0020?kCN080kk>?00<0o]9h0:F1[@2UPJd00P2UPJd20<JHY`80WgFS00<0000V01T;
O`0U4h<00P15;i820=^YX`80b9:L00/0[GjQ0?;FIP2iT:`0^I2/0<RGX`37/lH0PfFX09Mh[P2gV;P0
i;b^0:9kZ0030:MnY`80_kcG00@0OJca0<:;VP30TjP0X7NT0P3/`ZT0103@VYd0bJFe0<VU]@39YKD2
09IbZ0<0/h:P00@0ik:M07iQYP1nHJH04cjl0P1bH:l00`0F7YT0GU6[05iAZ`0207aU[P80]hFO00<0
XWFP07IOZ`1fGj/00P2NOk83039B`a<0oooo00H0b9BP0?ooo`3oool0oooo0;63X`2PKiX60?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool06`3oool001/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1E0?ooo`80eM7E0P0ZBkl00`2DTm00g?JP0;V]c@020=N/Z`80biJN
0`37U:420>jnW`030?WFX`3S^:X0gknh0080e:nc00D0SfBL0<JQ/P2^UKd0[YFm0<NLZ`0206F5g@03
0017`@2Wco@0Ylod00<0YjKE00@0PfN[09M_X`3XmZ<0`i^_0P0gHM020;NifP80Li3P00@0`J:i0=K2
aP3F`/H0e/;60P0A?;X0102oWkL0O7Bo07ad_`1B@j8204dnW`80ZG^Q102aQjT20:28^P80T7jl0P2f
U;@20>:n/`<0b9^Y00@0cI^T0<nHW03?V9`0TFRO0P2`OI`209Q[W@80mmBX00<0kknQ0?oFT03[^j80
0P2bUk`20<:EZ@040>C2/`36i^d0M5bX07ALZ080^IZi0`2aS:l01P2]Oj<0nMVX0<JS]@2fL`00:32T
000NZP<0PfFW0P2RPK030;bBZ`80UFbQ00@0_hZL0>^mX`3[_J<0jkfS0`3:V:830=VSW@80fj:H00D0
bi6I0<:<W032S9`0`XbL0=BHU@020>J[U080o]=h00@0f:RU0>ncS`1PC:<0H4bS0`2UPJd20<JHY`05
09meX`3Pj]T0h>[I01T;O`0U4h<00P15;i801P3KZJ<0b9:L0<RBW038TY`0[GjQ09idXP80^I2/00D0
b9NS06=DZ`1SE:/0kl^^0;NH^0020>Bl[P090;:3XP2WOZL0YgjW09ihY`2o_=L0OJca0<:;VP30TjP0
X7NT0080k<:Y00@0d9ZM001XfP39YKD0bJFe0P2FLZP20;>2X080ik:M0P1nHJH01P2gV;P0LV2_079P
[`0F7YT0KeJU05iAZ`80O6F^0P2gQIl0102RMJ00MUn[07IOZ`2NOk8L0?ooo`030:1_VP3oool0oooo
00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo05D0oooo0P1_]O/00`2DTm00g?JP0?ooo`020=N/Z`<0
biJN00<0fZBN0<NDX@3^_Yl00P3^_Yl00`3ieZ<0hkRZ0=B_/`020=B_/`80aZ6b00<0[YFm0<NLZ`37
W:/00P3ccj/0101laOh0TGRd095h]00:00020:NVe@060<>K[`2GKj<0`i^_0<>K[`3DZjh0OgW30P3E
Zjd40:nD^`<0/jO=00@04Cbj0;nO]`30W;@0O7Bo0P1B@j80101=?Yl0ZG^Q0:UkX@3:W:T30;67Z@<0
Y9K70P2@NkP208n9b@050>:n/`38VjT0b9^Y0<RKZ@3=Vj@00P3?V9`30;1mW080V6^M0P3Z_ZH00`3_
_j40omJ@0>^kXP020;:G_0040<:EZ@3T`[<0i<:c0000N`80M5bX0`2RSl420664gP060?WIZ036XkD0
aZ>e0<JS]@1KAj40:32T0`23IJL20::1/0<0_9:[0P2EK:401@2oRY`0jkfS0>^mX`3[_J<0[GjQ0080
bYRR00<0dj:U0=VSW@3IXid00P3KXYP01P3;TIT0`XbL0<:<W032S9`0e9RE0>J[U080o]=h0P3HZ:D0
0`3U]Z@0H4bS061<X`030:F1[@80aYRW0P3Pj]T00`2HN:h06@]o02DCP`0204D_TP070=^YX`38TY`0
b9:L0<RBW02]OZ40WWBR0;V@[0020<RGX`0306=DZ`3_bjh0kl^^0080i;b^0P2bPj820:MnY`050<BC
X`2o_=L0OJca0<:;VP30TjP00`3/`ZT0103L[JH0036d0<VU]@39YKD309IbZ0040;>2X03W/Yd0ik:M
07iQYP<0]iRh0P2DOKL206mFY@80O6F^0P2gQIl00`2RMJ00oooo0?ooo`0U0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool06P3oool001T0oooo0`00000?0?ooo`800000F`3oool01P3G
[:/0biJN0<^FWP3;UYh0fZBN0<NDX@80k[jO0P3ieZ<0103S^:X0fjbW0=B_/`3D[k<20<JQ/P030:jE
_@37W:/0aib[0080lln[00@0n^RX095h]02AN;@0TGRd0`2d^Md20<>K[`80e:^^00@0OgW30=F[[@3E
Zjd0l]Vf0`2_U;/0102^gGP0/jO=0;>Wc@1:BJh20<2L]0040=;HH@1B@j80DT>R04dnW`80ZG^Q00D0
bYbY0;67Z@2aQjT0/HNY0=^e/P020:BFa`80T7^h0P2?RLT40<RKZ@<0ciRL00<0fZRR0;1mW02`OI`0
0P2HJid20>ZnYP030>noX@3oeY00jk^R0080/YNl0`3T`[<0103La<40M5bX0;bddP2l]=830::?`@<0
/ik20P36XkD205]7X@03000NZP23IJL0PfFW0080XX6`0`2lTZ/209E/X@<0jkfS0P2]OZ420<ZHXP03
0=>RY@3IXid0fJ>M0080fj:H1032S9`0103DV9D0iZ^D0?kCN03ndgP20=RXY@030>FfY01PC:<0H4bS
00<0YH6]0P2Df?h01@0005`0V7R^09Qh[P27IjH09A>30080ABnB1038TY`00`0000X0WWBR0;V@[002
0<RGX`0506=DZ`3_bjh0kl^^0:9aW03T_:h00P2bPj820:MnY`040<BCX`2NN:L0_kcG0<:;VP80a>g`
00@0k<:Y0<?1f033`MP0g:fV0P39YKD309IbZ0030;>2X03W/Yd0ik:M008000000P2gV;P209Am]`<0
KeJU00@0O6F^0;N5W`2gQIl0i/fm:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01X0oooo000K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F03oool01P3G[:/0
biJN0<^FWP3;UYh0fZBN0<NDX@80k[jO00<0nMJS0>>hZP3S^:X00P3K[:L30<JQ/P80aib[0P3ccj/2
0?[XZ0050000L`2AN;@0]Y2`0;J@/01kGJ@00P2d^Md00`33Vjl0e:^^0=B[[P030=F[[@80l]Vf00<0
[iBk0=J[[@0=QN@00P2cYld204Y9[P060<2L]034mj`0DT>R0593XP0004h0ZG^Q0P3:W:T20;67Z@80
fkFb0P2TU/L2091k^0<0[Y>k0`38VjT0103?Yk40ciRL0<nHW03JZ:820;1mW00309Q[W@3Z_ZH0j[jV
0080kknQ0P3[^j80103lgJ80Shc<08n<c02?S<`20=c4`@<0_;CB0P2RSl420;FG^080/ik20P36XkD2
05]7X@040000F023IJL0PfFW0::1/080/9c30P27J:P309YaX`050>^mX`2]OZ40[GjQ0:enX@3:V:80
0`3CXZD0103IXid0fj:H0=^RV03R[Z030<:<W080iZ^D00D0o]=h0=RXY@3HZ:D0f:RU0>FfY003061<
X`80YH6]00<0/XBT000_]`2Df?h00P2HN:h00`27IjH09A>309edY00209edY0<0b9:L0P2NM:830<RG
X`80kl^^0P2RLI`30;:3XP030:MnY`34Tj<0a9>S0080WWRW00<0`X^J0<C]l034kO000`33`MP01`3L
[JH0036d08Ed^@25M;T0XW^X09IbZ02cPZ000P3W/Yd00`2FNk<000000;NH^0020>Kkb@050;:N``0F
7YT0KeJU06mFY@1lIJh00P2gQIlZ0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
6P3oool002h0oooo00<000000?ooo`3oool0E`3oool30<^FWP80fZBN00D0aiBQ0>jnW`3^_Yl0nMJS
0>>hZP030=^/Y`050?OAYP36XK80aZ6b0<FN/@37W:/00P3ccj/20?[XZ0040000L`2fT;00]Y2`0;J@
/080NefT00H0NV6Z0=B[[P3DZjh0e:^^0=Nc]03EZjd30?;I]P050;^bd03FZjd0ikbX07Qe``00;9d0
0P1:BJh00`30W;@0UfbN09B8a0020:5n[@040:UkX@3:W:T0bYbY0;67Z@<0fkFb0P2TU/L30;:PaP80
[Y>k0P38VjT20<nW/@80ciRL00@0fZRR0;1mW02`OI`0V6^M0P3Z_ZH01@3__j40omJ@0>^kXP3[^j80
o=fR0080Shc<0P3La<420;bC[@80_;CB102eUkP20;>N`P80aZ>e0`1KAj4208=UY`<0/9c30`27J:P2
09YaX`@0[GjQ00@0bYRR0=>RY@3CXZD0dj:U0`3KXYP01`3R[Z00`XbL0<:<W032S9`0i[FS0>J[U03n
dgP00`3HZ:D01@3U]Z@0YGZT08Yb/`1PC:<0YH6]0080/XBT0P00;kL00`0Y?K<002>I08MWYP0202DC
P`80WGBT0`38TY`209idXP040;F3WP38Uj<0b9NS0=R/ZP<0XW6L00@0eKTb0;:3XP2bPj80YgjW0`34
Tj<01@2NN:L0h;6V0>2aYP3li900JMSb0080`l7H0P27i?P00`25M;T0mn^E0:9kZ0020=?<d`040>Nb
W@2FNk<0UW^c05EO`0<0i__90P2bW/<206mFY@03000MYP2gQIl0i/fm02X0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0J0?ooo`00;`3oool00`000000oooo0?ooo`1G0?ooo`80biJN
0P3JY9h01@37U:40k[jO0?WFX`3ieZ<0hkRZ00<0fjbW00L0mm6V0<JQ/P35W[40aIja0<NLZ`3ccj/0
n^RX00<0^Zk=00<0001c0;J@/02fT;000P1kGJ@207YQZP050=B[[P3G/k@0ek>d0=F[[@3bfKH00P2k
/]020=J[[@040>NlZ01hML<0N7G30:QmY@<0UfbN0P2DR<@0102QOZd0bYbY0<ZLZ@3:W:T40=^e/P03
0;V<Y`1DQN<0E8GS0080/Z360P2^Tk/01@38VjT0cjNa0<nW/@3?Yk40ciRL0080fZRR0P2`OI`01P2H
Jid0j[jV0>ZnYP3__j40omJ@0>^kXP80o=fR00<000000;jS_@2nXkd00`2lTjd209N1^@040;:?/P2e
UkP0]INh0;FG^0<0^MW`00@0SWRg05]7X@1KAj40FdNQ0`2e^]d20;2L``<0QfRX0P2JLJ<01@3LZj<0
[GjQ0:enX@2]OZ40bYRR00<0dj:U00@0kLN]0=^RV03KXYP0hZjP0`32S9`00`3V]J<0iZ^D0=RXY@02
0=RXY@80iKJT00<0YGZT08Yb/`2:L[<00`2bQ:@01@3IYIl0MV>_07IS[`0Y?K<002>I00809A>30P2M
M:@30<RBW080WWBR00D0]H>N0<RGX`38Uj<0f:bZ0>RhXP020:9aW0040=Fi<P2bPj80/X>R0:MnY`<0
a9>S00@0WWRW0>2aYP3P/JH0o>B@0P3oool20<2ab`0308OTn025M;T0Febi00<0dlcC00<0ik:M09Ik
/`2FNk<01P3oool00`1_EZD0oooo0?ooo`020>K=_B/0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0J0?ooo`00<03oool2000005L0oooo0P3;UYh20=ZTWP80k[jO00<0nMJS0>>hZP3S
^:X00P3K[:L20?OAYP<0aIja00@0lln[0?kMV@3ngIT0oN>D0P2j[/d00`0007<0]Y2`0;J@/00207]M
Y080NV6Z00<0e:^^0=Nc]03G/k@00P3@[[L01@3CYZT0^k;@0=J[[@3FZjd0ikbX00<0Z7fU0`2GK9h2
09B8a0050:5n[@0004h0bYbY0<ZLZ@3]nKT00P3K]K80102HKj<0^HbW0;V<Y`1DQN<20;:PaP80[Y>k
103?Yk400`3?V9`0fZRR0=ZXXP020;1mW080j[jV0P3__j40103oeY00jk^R0?cMXP3lgJ830;jS_@03
0=Rj^`2lTjd0_9>]0080Uh6i00D0VG2S0;FG^02eUkP0]INh09MaYP020;WIl00508ih]`1KAj40FdNQ
05]7X@10=ih00P2e^]d30;2L``80QfRX0P2JLJ<0103LZj<0[GjQ0:enX@2]OZ430=>RY@80kLN]00<0
fj:H0>:^X03R[Z000`32S9`00`3V]J<0iZ^D0??0V0020=RXY@030>FfY02UNZ@0YGZT00<0XGVV0P2b
Q:@01@3IYIl0MV>_07IS[`2kRJ0002>I00809A>30`2MM:@00`38TY`0]H2K09idXP020;F3WP040<RG
X`3H[:X0f:bZ0>RhXP80XW6L00<0eKTb0;:3XP2bPj801034Tj<00`2NN:L0h;6V0?cTT0040?ooo`03
0<2ab`3oool0QnCh0080Febi0P3Cc=<j0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06P3oool00380oooo00<000000?ooo`3oool0E03oool20<^FWP80fZBN00@0o=JL0?GAZ@3edJT0
jKfW0`3K[:L20?OAYP040=2^]`35W[40aIja0;>9Z@80o]fI00@0oN>D0;Z^c@2j[/d0ZeT00P2fT;02
07]MY080NV6Z0`3G/k@00`3@[[L0djJY0=>VZ@020=J[[@80ikbX00<0dJJ]0:QmY@2XOJD00`2GK9h0
1@3R/Z@0V6fO0:5n[@2QOZd0bYbY00<0kOVi0P2HKj<00`2iS:L0/h^[0;>;Z`020:fB^P0306D08`2M
R[l0WHZo00<0cjNa00<0ciRL0=ZXXP3JZ:800P2`OI`0103^aj`0j[jV0>noX@3__j420>^kXP040?cM
XP39a=D0_Z>m0;jS_@80f;Zk0P2lTjd01@30UZ/0TVnW099_Y`2IL:<0]INh0080Ug6V00<0TW>/0;WI
l02>N;L00`1KAj400`10=ih0]K[M0;Fjg@030;2L``80QfRX0P2JLJ<01@3LZj<0[GjQ0:enX@2]OZ40
djBW0080dj:U0P3]ajd01@3KXYP0hZjP0>:^X03R[Z00`XbL0080i[FS00D0i;Z/0??0V03HZ:D0f:RU
0>FfY0020:EjY0030;F4X02QNJH0XGVV0080/XBT0P3IYIl00`1fHjl0^hVP000SV@0202DCP`<0WGBT
00<0b9:L0;F0V`2NM:800P2ePih01038Uj<0f:bZ0=R/ZP3X^:820:9aW0040=Fi<P2bPj80/X>R0<nR
Z@<0a9>S0P3P/JH00`3li900oooo0?ooo`130?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06P3oool003<0oooo00<000000?ooo`3oool0D`3oool01@3;UYh0fZBN0=ZTWP3JY9h0o=JL
0080mM6Y00<0jKfW0000003K[:L00P3gdJH20=2^]`040<FN/@2cRJT0/hVY0?kMV@80oN>D0`2oU:/2
0;J@/080NefT00@0NV6Z0;:?/@2bSk40ek>d0P3@[[L20=>VZ@050>:dYP3FZjd0ikbX0>NlZ03AYZd0
0P2XOJD309M/WP060>:bY02HKIl0XGj]0:5n[@3:W:T0kOVi0P3CY:H209Q_X`<0/h^[0P2]T[X0101D
BZT0WHZo09f:_`2MR[l20<nW/@030<nHW03JZ:80fZRR0080/7fL00H0k/N/0>noX@3__j40kknQ0?K`
]03lgJ830<W4e@<0f;Zk00<0_9>]0<2FZ`30UZ/00P2BKjL209U`X`<0Ug6V00<0TW>/08ih]`2>N;L0
0P1KAj42040gWP80R8G900D0=4Ri0;2L``27J:P0QfRX09YaX`020=b[X`<0[GjQ00<0djBW0=>RY@3]
ajd00P3]ajd01@3KXYP0hZjP0>:^X03R[Z00`XbL0080i[FS00D0i;Z/0??0V03c`9P0f:RU0>FfY002
0:EjY0030;F4X02QNJH0XGVV0080/XBT0P3IYIl01@1fHjl0^hVP0;^9X01^G:d09A>300<0WGBT00<0
b9:L0;F0V`2NM:800P2ePih20=R/ZP80j;RR0P2RLI`0103E^C80/X>R0<nRZ@3?XZT30<BCX`030>[;
]03P/JH0oooo04H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0I0?ooo`00=03o
ool00`000000oooo0?ooo`1B0?ooo`030<^FWP3JY9h0fZBN0080o=JL00H0mM6Y0>VmY`3Y_JL00000
0=^/Y`3gdJH30=2^]`<0/hVY00<0o]fI0?gSU02oU:/00`2oU:/0102IJi/0HhKO07]MY01kGJ@30;:?
/@80d:jg0`3CYZT00`3R]:H0eZ^]0>NlZ0020=6V[@80Z7fU0P2GK9h20>:bY00309Q]W`2QOZd0XGj]
00@0djBV0P2HKj<00`2fRjT0/h^[0;>;Z`020:fB^P0405A:Z@2MR[l0WHZo09f:_`80cjNa0`3JZ:80
0`2`OI`0k/N/0>k7[0020?;A[`040?K`]03Hgm`0f=oL08bKg0<0VGfd0P3H^[/30<2FZ`80TVnW0P2I
L:<309MaYP80TW>/00<0Y7NQ06E?X`1KAj400P10=ih308R5b@0403A8^@27J:P0QfRX09YaX`<0g:^S
00@0[GjQ0=>TY`3CY:L0dj:U0`3]ajd01@3KXYP0hZjP0>:^X03R[Z00`XbL0080i[FS00<0i;Z/0??0
V03c`9P00P3U]Z@00`2UNZ@0]HBP0;F4X0030:5iYP030;:4Y03IYIl0fJFO00<0^hVP00<0KUb]02DC
P`2MM:@00P2MM:@20;F0V`<0]H>N00@0hliC0=R/ZP3X^:80j;RR0P2RLI`00`3E^C80/X>R0<nRZ@02
0<nRZ@030<BCX`3Zbk@0j/^d04T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`00=@3oool200000580oooo00@0biJN0=ZTWP3JY9h0o=JL0P3edJT0103Y_JL0oooo0?ooo`3o
ool2075fb@080=2^]`3B`//0d/;;0;>9Z@3ngIT0oN>D0:V1Z03N[:820;nDZ`040<6@X`2IJi/0HhKO
06>6g`80T76/0P2bSk40103XbkT0d:jg0=>VZ@3CYZT20>:dYP80ikbX0P3AYZd20:QmY@80UfbN0P3R
/Z@209Q]W`80OX;=0`3CY:H00`2HKj<0]X^Y0;J;Z@020;>;Z`040=J^/024L;D0Q72e07Mfa@80blCD
00<0aZ6b0921_`2@PKl00P3JZ:800`2`OI`0k/N/0>k7[0020?;A[`80f=oL0`2KN:/209Um]0<0X8Ri
0P30UZ/2099_Y`80VG2S0`2GLJH30:=mZ@80IDnS0P10=ih308R5b@80=4Ri00<0QfRX09YaX`3LZj<0
0P3LZj<00`2]OZ40djBW0=>TY`040>g7[@@0hZjP0P3V]J<01`3T^Z`0ll2H0??0V03c`9P0o]bF0>Ff
Y02UNZ@00P2eQ:030:5iYP040;:4Y03IYIl0fJFO0;^6W080^hVP0P1^G:d209edY0<0]H2K00D0nlVA
0;F3WP2ePih0hliC0=R/ZP020>RhXP80XW6L00<0eKTb0<nRZ@3?XZT00P3?XZT00`34Tj<0j/^d0>[;
]01:0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool003L0oooo00<00000
0?ooo`3oool0C`3oool30=ZTWP040?cFW03edJT0jKfW0>VmY`<0oooo0P1aM/T30=;2b`050;>9Z@3n
gIT0ZH6X0:V1Z03N[:800P2oU:/01031T:<0VF^K09U[V`1SQ]l2091a[0030;:?/@3XbkT0j<^i00<0
djJY0P3R]:H0103K[JP0dJJ]0=6V[@3AYZd20:QmY@80UfbN0P3R/Z@209Q]W`0301dFS01nP/d0djBV
0080djBV0`2fRjT00`2cRj/0eZj`0=J^/00208A`]@80MgK50P36XK820921_`80fZRR00@0/7fL0>k7
[03bdJl0l]6_0P3_bZ`0103gjK<0VgR[09]hZ`2KN:/209Um]0030000002PR;T0X8Ri0080`9J[0P2B
KjL209U`X`80Ug6V0P2VNZ@20:=mZ@030000<01UCj<0IDnS0080SFf[0`1]Nm000`0dB;T0FEjl0=b[
X`030=b[X`030:enX@3CY:L0djBW0080m=B]0`2TPZl20>:^X080cJnl00<0i[FS0>Bj[03c`9P00P3c
`9P00`3ng9H0XWVV0;F4X0020;F4X0<0XGVV00@0/XBT0=VUW`3IYIl0^hJL0P2kRJ00102oS9l0KUb]
06iL[@2@K:D30;F0V`040?_9T@2ePih0]H>N0>?>D`@0j;RR00<0XW6L0;6J_`2aV[l00`3?XZT20>[;
]4/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`00>03oool00`000000
oooo0?ooo`1?0?ooo`050=ZTWP3leY`0o=JL0?GAZ@3Y_JL01`3oool20=;2b`060;>9Z@2YPJP0ZH6X
0:V1Z03N[:80_iB[0P31T:<209U[V`0406>6g`2@LJ`0T76/0;:?/@80j<^i00<0ajRj0=>VZ@3R]:H0
0P3R]:H0103K[JP0ejBS0=6V[@3AYZd20:QmY@0409M/WP3R/Z@0h[:T0>:bY080V6fO0P0M5X`0101n
P/d0djBV0:Z2Z@2ZPZT20;J;Z@030;>;Z`3F[[00eZj`0080Q72e0`2f/mH00`36XK80T86o0921_`02
0=ZXXP80k/N/00<0l]6_09g:F`3_bZ`00P3gjK<309]hZ`0309Um]03^c;4000000080X8Ri0P30UZ/2
099_Y`80VG2S102VNZ@20:=mZ@030:AgX@1UCj<0IDnS0080SFf[0`1]Nm000`00;KD0FEjl05UN_003
0=b[X`<0djBW0P3de:d0102lRj80Y8:_0:B2[`3R[Z030<f__0040>JeX`3T^Z`0ll2H0??0V080o]bF
0P2KMjT20;F4X0<0XGVV0`3IYIl01`2kQY`0^hVP0;^9X02oS9l001bR06iL[@2@K:D00`2eP9/01@3k
bI40]H>N0;F3WP3ScU<07Sjg00<0j;RR00<0XW6L0;6J_`2aV[l00`3?XZT00`3XnlL0oooo0?ooo`1;
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool003T0oooo00<000000?oo
o`3oool0CP3oool00`3JY9h0o=JL0?GAZ@020>VmY`L0oooo0P3B`//01P2cRJT0T6VQ0:V1Z02YPJP0
gZbR0;nDZ`80`I2S0P2IJi/00`2hF@00T76/091a[0020>S;^@80ajRj00<0djJY0>:dYP3R]:H00P3K
[JP00`3GY:<0dJJ]0=6V[@020:QmY@0409M/WP3R/Z@0h[:T0>:bY080V6fO0P0M5X`0100lG//0ZX:Y
0:Z2Z@2ZPZT20;J;Z@<0eZj`0`2RSl430;JceP030<JQ/P26X^H0QZ;V0080RYWL00@0l]6_09g:F`3_
bZ`0klZ/0`3gjK<209]hZ`0309b2]`3^c;40002C0080X8Ri00D0`9J[0:jH`02^V<00TVnW09U`X`02
0:^5[@<0YWZT0P2SOJT00`2TMj40IDnS06E?X`0208e]Z`<0KG_@00<002fe05UN_01IG[`00P3LZj<2
0:YoY@030=>TY`3de:d0m=B]0080_8^R0P2TPZl40<f__080i;Z/0P3c`9P0103ng9H0002309]gZ@2K
MjT20;F4X0@0WW:Q00@0fJFO0;^6W02kQY`0^hVP0P2oS9l2000LXP80T6bU0P2eP9/01@3kbI40]H>N
0>?>D`3oool07Sjg00<0j;RR00H0XW6L0;6J_`2aV[l0/IZo0<nRZ@3XnlM?0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool06@3oool003X0oooo00<000000?ooo`3oool0C@3oool00`3J
Y9h0oooo0?ooo`0;0?ooo`80T6VQ00<0ZH6X0=j/XP3N[:800`31T:<209U[V`04071<U`1kh;<0Nn2c
07_P/`<0ajRj0`3R]:H20=^]Z0050=NTX`2KMJP0VgFX09]eZ023K;40103R/Z@209Q]W`807AJ<0P0l
G//20:Z2Z@80]X^Y00@0d:jg0=J^/02nW;H0_Ybf0`2RSl420;JceP030;6I_`26X^H0QZ;V00<0[IJo
00<0WLYK04mG^`1?Ek/00P2CO[T0103gjK<0VgR[0::;_03^c;4204g;`P80X8Ri0`2^V<001022HJ<0
ZhF]0:^5[@2[QJd30:IjY080XgfY00<0Y7NQ06E?X`1UCj<00P2=KJ/01P3QcL@0MHGE07F5e@1eQMD0
02fe07iNY0@0ZWnU00<0djBW0?CD[@3de:d00P2lRj820:B2[`070=CfX`3=[k`0cJnl0<f__03Rel/0
i;Z/0??0V0020?kLUP030000P`2KMjT0VgNY0080]HBP00D0n=BT09ibX@2NLZ40WW:Q0=VUW`020;^6
W0030;^9X02oS9l0_hbO008001bR0P2@K:D0202eP9/0nlVA0?_9T@2ePih0hliC0?ooo`2lIVT07Sjg
0P3X^:801@2RLI`0/IZo0;6J_`2aV[l0j?_70540oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0I0?ooo`00>`3oool2000005/0oooo0P2@JJ40102YPJP0gZbR0=j/XP3FYJD20<6@X`80
VF^K0`1`C9L00`1XC9h0GD>K0<NX^P020:f6[080h[BV00@0fjfX0=NTX`3GY:<0j[ZR0P2KMJP208=/
/@<0h[:T00<0V6fO0:AhX`2TN:<00P2>Ij40100lG//0ZX:Y0:Z2Z@2fRjT20=2^]`<0_Ybf0P2RSl42
0<Vgb@<0/IVo00D0L7oC04/0002]U[l0WLYK0:28^P0204mG^`80Tgji102jUK400`3deJh0000L08N:
c`0208n@d080[YS00P22HJ<20:^5[@<0YWZT0P2SOJT0102TMj40001806E?X`2=KJ/30>7=a080MHGE
00<002fe07iNY01nGZ@00`2ZOjD00`3CY:L0m=B]0;b;XP020;b;XP050:B2[`3DmZ<0e?JS0=CfX`3=
[k`00P3Rel/20??0V0030?kLUP3lfIh0mNZi0080VgNY0P2eQ:001@3he:@0WW:Q09ibX@2NLZ40fJFO
0080^hJL00@0^hVP0;n<W`2oS9l0/hFS0P39VjL01@2@K:D0]H2K0?_9T@3kbI40]H>N0080oooo00D0
_6IY01hn]`0B;:T0j;RR0:9aW01E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
6@3oool003d0oooo00<000000?ooo`3oool0F03oool2091YX@040:V1Z03N[:80gZbR0=JUY@80`I2S
0P2IJi/3071<U`0306Q<WP1M@i/0[HJ/00<0[HJ/0P3K[JP20=NTX`040>ZjXP2KMJP0VgFX09]eZ080
Pfba0P3R/Z@30:AhX`80SVNQ00<0?5k;0:Z2Z@2ZPZT00`3@[[L00`3Ma;l0_Ybf0;jL]P030<Vgb@80
e/740P2aVKl20>;1]P060:fF_`3FgMd0[;kW0:bni`1?Ek/0Tgji0P2[SKH20;ZE/@80m=F^00@0?5W6
0>KRcP2?T=00Si3@0P2^V<02089QX`80ZhF]0`2VNZ@20:=mZ@030:AgX@0004P0Oe^N00<0hLg40P2[
QJd0102HNk4002fe07iNY01nGZ@30:YoY@030?CD[@2lRj80_8^R0080_8^R00@0Y8:_0=CfX`3DmZ<0
e?JS0P3Rel/20<gBg@04059=[@1hF:40mNZi0>_Ma@80VgNY00<0]HBP0?SDY03he:@00`2NLZ430;^6
W0<0_hbO00D0/hFS0<VKY`3ochP0T6bU0;F0V`020?_9T@080;F3WP3oool0oooo0?ooo`1<AJT04RbY
0?ooo`2RLIaF0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool003h0oooo
00<000000?ooo`3oool0E`3oool2091YX@040:V1Z03N[:80gZbR0=JUY@80`I2S0P2IJi/3071<U`03
06Q<WP1M@i/0GD>K00<0[HJ/00D0m>nI0=^]Z03GY:<0ejBS0>ZjXP0309]eZ00308=//@2jVkT0^Y^i
0080WJKL0P2TN:<208iWX@050000P`2ZPZT0ZX:Y0;nO^03@[[L00P3Ma;l0102nW;H0^IFa0;VE/@2i
UK430=K1a0030;6I_`3CcmH0dloF0080e]gM0P00000209NFd0<0Zhff0P2jUK400`3deJh0gmG=0:FJ
b@020:FJb@80/Ic300<0[YS0089QX`22HJ<00`2[QJd20:IjY0040<BK[@2SOJT0Y7NQ0000CP80Oe^N
102[QJd0102HNk4002fe07iNY01nGZ@30:YoY@030=JWZ035SIX0_8^R0080_8^R00<0o=fR0??8X`2>
PL400P2>PL420<gBg@030=N`/P1BCJd0DTf]0080[H>W0P2KMjT00`2eQ:00n=BT0?SDY00309ibX@04
0??9Y02kQY`0^hJL00000080_hbO0P39VjL20?o?R0040;F0V`3kbI40nlVA0;F3WP<0oooo00<0C4FY
0?ooo`3oool0F03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo000o0?oo
o`030000003oool0oooo05H0oooo0P2@JJ420=j/XP80eZFU0P31T:<209U[V`<0L4bG00<0J4bN05e3
V`1M@i/00P2]QZ`20?C_V@040=^]Z03GY:<0j[ZR0>ZjXP<0VgFX0`2jVkT209fVg080Y7RS0P2>Ij40
100008<0ZX:Y0;nO^02oWkP30=g4_`@0^IFa00<0inn@0=K1a03F`L@00P3CcmH20<S3eP060>7`f@36
XK<0aZ6c0000002GU]0001ZV0P2[SKH00`2jUK40m=F^0?CE[P020:FJbP80YI[900<0/Ic30<>R]`2^
V<000P22HJ<30:^5[@060:IjY034Vjd0a9^]07iMXP2HKZ40001>0P1oFih01038Til0ZhF]0:^5[@2[
QJd209Qk/@80OUjT0`2ZOjD00`3FYjP0aHfJ0;b;XP020;b;XP040?cMXP3cb:<0SX7108j1`@80_ijg
00<0f:j^0=N`/P1BCJd00`2]PjL209]gZ@040;F4X03he:@0n=BT0?SDY080WW:Q00@0llVT0;^6W02k
QY`000000P2oS9l0100004@0bI^W0?o?R03ochP30?_9T@050<ZCW@3oool0oooo0?ooo`1<AJT0F`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01P0oooo00100?ooo`800000EP3oool0
102@JJ40[XJZ0:j6ZP3N[:820=JUY@80`I2S0P2IJi/20<^nc`80e?BL0P1M@i/20:f6[080m>nI0P3G
Y:<20>ZjXP80VgFX0P2/PjP20;ZK^@040;bBZ`2MY]`0Y7RS0:AhX`80SVNQ00H0dJje0;nO^02oWkP0
_inh0>_Sb03Ma;l20;BQa080^IFa0P3Wki000`1KFKH0LVJf079V]P020<S3eP050>7`f@36XK<0aZ6c
0<JQ/`1AE[T00P2GU]020:^=]P80m=F^00<0W9?:0:FJbP2UV/X00P2UV/T20<>R]`030:E30022HJ<0
PV6S00<0ZhF]00<0YWZT0<BK[@34Vjd00P1nGJ80100004h0Oe^N07mKWP38Til30:^5[@0309Qk/@2V
OJL0OUjT0080OUjT00@0ZWnU0=JWZ03FYjP0aHfJ0`2lRj800`3lgJ80llRS0;nN]`030;nN]`040=R^
[P3G/;80/YFi0>o>/080[H>W00<0fjRQ07`0003he:@00`3he:@00`2NLZ40llVT0??9Y0020;^6W005
0000002oS9l0_hbO0000A039VjL00P3ochP0102MLIl0mlJH0<ZCW@3:TieO0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0603oool00480oooo00<000000?ooo`3oool0D`3oool30:j6
ZP030=j/XP3FYJD0eZFU0080`I2S0P2@NkP01038gF`0_Iji0;fN^@2mW[T205e3V`030:f6[02hS:L0
3`000080WW^/00<0ejBS0>ZjXP3Z^Z80102/PjP0102jVkT0_9:[0;bBZ`2MY]`20:AhX`0508iWX@3A
[[D0dJje0000P`2oWkP00P3[hlP30;BQa080^IFa0P2knNd01@1KFKH0LVJf00000000NMH0hO3I00@0
aZ6c0P3Xc;T0102gT:h0LM^b077K/P2QRK/209bCbP<0Yj?B0P2OS/820<>R]`<0_k3:0P25K:l30<BK
[@80OUfR00<0001>07mKWP1oFih00P38Til20:^5[@80YWfW0`1nGZ@00`2ZOjD0eZNX0=JWZ0020<F=
VP050;b;XP3lgJ80llRS0??8X`34UjP00`2oW[L0103H[Zh0/YFi0;:E^@3_c[020:f3Y`030=^XX@2a
P9l0/H2O00<0n=BT00<0WW:Q0??9Y03cbJ@00P2kQY`01@000000_hbO0;n<W`28Hj40bI^W0080oln8
00@0WG6O0?O6V03:Tid0bY>MH03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0
oooo00130?ooo`030000003oool0oooo05<0oooo0P2^QZX30=JUY@040?K`/@2@NkP0T7^h091k^0<0
_Iji00<0fZbX05e3V`1M@i/00P2hS:L0100?0000WW^/09ik[03GY:<20>ZjXP040=Jg^P2/PjP0[8>X
0:b3Z0<0_9:[00@0001a0:AhX`2TN:<0SVNQ0P3A[[D00`004il0_inh0>_Sb0020<6V_`80]:7400@0
^IFa0:2Eb03J`/80MHCD0`32X[P00`000000Tg:[09=bZ`030<JQ/`050=kAc02gT:h0]i2^0;N@[P2Q
RK/00P2fW;d209f4^@80Yj?B0P2OS/830;Vee@80_k3:0`25K:l20<BK[@80OUfR00<0V6jQ07mKWP38
Til00P38Til0102[QJd0[hV]0:n9[@2VOJL307iNY0030:YoY@3FYjP0aHfJ0080aHfJ00D0_8^R0?cM
XP3cb:<0llRS0<BGZ0020;nN]`030=R^[P2Y_^T0/YFi0080klj`00<0[H>W0=^XX@3KZ:400P2aP9l0
102mRj00^XVQ0?SDY02NLZ420??9Y0050;^6W000000000000;n<W`2]OJ00103oool0103gaYP0bY>M
0<ZCW@3:TieQ0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool004@0oooo
00<000000?ooo`3oool0DP3oool20:j6ZP040>_;]@3FYJD0m_2a0?K`/@80T7^h00@0_[WD0=W1`P2m
W[T0_Iji0P3J[:P0101hHZd0^8bW0;R<Y`0?000209ik[080j[ZR0P3F]kX30:b3Z0040000002lTZ/0
_9:[0000L@80Y7RS0`3A[[D00`004il0jn?80<6V_`020<6V_`80]:7400<0X9G80=[2`P3J`/801032
X[P01P2]fOL0Tg:[09=bZ`2CLZ/0aZ6c0=kAc080d;O10P2gT:h30;JL_@80WHBi0P2WXm830:25]P80
^KGE0`2o/<X208E/[`80a9^]0P1nGJ800`2HKZ40Oe^N0<RCW`020<RCW`<0[hV]0P2VOJL207B4e@80
eZNX0`35SIX00`2lRj80o=fR0??8X`030<BGZ0040;nN]`3H[Zh0ZKkY0;:E^@80klj`00<0[H>W0=^X
X@3KZ:400P2aP9l00`2mRj00^XVQ0;Z9X@030??9Y0050;^6W02OLj0000000;n<W`2]OJ001P3oool2
0<ZCWF40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H0?ooo`00A@3oool20000
0580oooo00@0[XJZ0>_;]@3[bkD0eZFU0`3fl;401@2@NkP0fL720=W1`P3I`L80_Iji0080fZbX0`2h
S:L0103U]ZD0WW^/09ik[02]OZ430=Jg^P80[8>X00D0@Uo:0000002lTZ/0_9:[0000L@030<C@h`03
0=6^]@36YkX0aZNj0080THG300@0`JJo000000000000hLJn0P3J`/820<2X`@80`Z:h00<0nNfU0=o8
`P00D/T00P2CLZ/0103NdL`0d;O10=2g`@3@]l420;N@[P040>OB`@2fW;d0]Ybm09f4^@80]I2a0P2<
M[D20:25]P80^KGE0P2fSjh00`2o/<X0QFb_08E/[`020<BK[@80OUfR00<0V6jQ07mKWP38Til00P38
Til00`3^_Yl0[hV]0:n9[@030:ImY`80M8CE00D0eZNX0<F=VP35SIX0aHfJ0?cMXP020??8X`<0a9NX
0P3H[Zh01@1]J;`0klj`0>o>/03_c[00[H>W0080fjRQ00<0/H2O0;f;X02mRj000`2jRJ420??9Y004
0;^6W02OLj00Wg>P0;n<W`L0oooo0P3:TieR0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05`3oool004L0oooo00<000000?ooo`3oool0C`3oool01`2^QZX0jl^e0>_;]@3Dg]l0h_V/
0?ooo`1oFih0103I`L830=Z/Z0050;nDZ`2hS:L0iKJU0>FfY@2NNj`00P2]OZ400`2GK9l0e[Nj0=Jg
^P020:b3Z080@Uo:00@0_9:[0>;Ic@3RfLd0X8Ni0P34d><30<JW^P80THG300<0lNK00>76_P3Qa[h0
0P2aSK040<2X`@060<:R^03Ob<80glS20:UkX@2CLZ/0]oCc0P1dYo420=2g`@030;N@[P3Wd/40im;1
0080]Ybm0`2eT;4208af]@80X8Ff00<0]8VX09=]Y02CKJ@00`2fSjh20:jC^P04089`]P1nGJ80OUfR
09Q^X@@0b9>O00<0k[jO0:n9[@2_RJd00`2VOJL207B4e@060=JWZ035SIX0aHfJ0<F=VP3neg/0^KTc
1034UjP0103Y_jX0f:j^06eX_01]J;`20>o>/0040:f3Y`3KZ:40fjRQ0;60W`<0_H^P0P2jRJ400`3A
YZ/0llVT0;^6W00209mcX0P0oooo0P3:TieS0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05`3oool004P0oooo00<000000?ooo`3oool0CP3oool20>_;]@040=CNg`3RnJ`0oooo0?oo
o`<0Oe^N0`2SO:T0103J[:P0_iB[0;nDZ`2hS:L20>FfY@<0[GjQ00L0UfbO0=Jg^P3F]kX0[8>X095/
Y01HAJ40T8C30080h]W=00D0ZYc90:27^@2PQkT0?4B`03T000020<JW^P040<FO/@3XhG<0]iNf0;NG
]P<0/Hf`00@0dJF[0<2X`@30Z<40`:S10P3Ob<820:UkX@80QW2c00@0`YR/0;Odl`3@]l40d;O10P3W
d/420:R8/`80XX^l0P2eT;4208af]@030:25]P2dRJP0]8VX0080TffT0P2fSjh30:jC^P80PW2f00<0
OUfR09Q^X@0004h00P38Til20>jnW`80[hV]0`2VOJL00`3AO000Jeja0<F=VP030<F=VP030?kGN`2i
^C<0aIb^0080a9NX0P3Y_jX01@39a=D0KFRl0<S5e`38aML0RGBf00<0fjRQ00D0/H2O0;f;X02mRj00
_H^P0;Z9X@020=6VZ`030<VIY@2kQY`0Wg>P00X0oooo00<0bY>M0?ooo`3oool0HP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00190?ooo`030000003oool0oooo04h0oooo
00<0e=kO0?ooo`3oool00P3oool307mKWP030;B0W02SO:T0XgbY00<0_iB[00@0^8bW0>FfY@3U]ZD0
d:F/0P2]OZ4209M/W`<0TFbT0P1HAJ420924``80ZYc90P2PQkT0100lA;00aZNj0?K`[P3C/kT30;NG
]P040<RMZ`2aSK00/Hf`0=6UZ`80b_?/00<0n^VM0=6UZP2YNj400P2YNj401@26L;<0`YR/0<:H[000
1iT0001k0080TY3=0`2XR;<20::;_080]I2a0P2<M[D30;B9Z0<0TffT00@0]Xn^0?;4X@2^TkX0nLfK
0P22L;H00`1=CK40V6jQ09Q^X@020<RCW`80k[jO0P2_RJd20:ImY`80_okJ0P1[G[430<F=VP030?kG
N`35W:h0aIb^0080a9NX0P3Y_jX0100kR^d0b<GG0<S5e`38aML208Ud]P80fjRQ102mRj000`2jRJ40
dJJ[0=6VZ`020<VIY@/0oooo00<0bY>M0?ooo`3oool0HP3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01L0oooo001:0?ooo`800000D`3oool207mKWP80]82L0P2SO:T0103O^[80_iB[
0;nDZ`2hS:L20>FfY@030=2U[02]OZ40[GjQ0080UfbO0`2AK:@205Q5X@<0YjKE00<0KhcO0:27^@2P
QkT00P2OP[@20:R7/P050;nE[02gUkH0b9f[0<RMZ`2aSK000P3AYJ/20?GCZ`030?[YW@3AYJX0aY:P
0080ZG^Q00D0QW2c0<:H[032V:`0nM^Y0007V@030;BC]@80Z8Rc0P2RRk`00`2eT;40/Hf`0;6=/002
09=c[080]8VX0`2CKJ@0103A[kL0l/BQ0:jC^P3icI/2089`]P0304e=/@2KMZT0VgJY0080b9>O0P3^
_Yl20:n9[@@0_okJ0P1[G[420<F=VP80o]Mk0P35W:h01034UjP0jKnZ0>VoZP3Y_jX20?ooo`80b<GG
0P29M;H00`3KZ:40/H^]0;6;[@030;f;X0<0dJJ[3@3oool00`3:Tid0oooo0?ooo`1S0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool004`0oooo00<000000?ooo`3oool0D03o
ool207mKWP80]82L0P2SO:T00`3O^[80_iB[0;nDZ`020>FfY@80d:F/0P2]OZ4209M/W`<0TFbT0`2V
XM020:NVe@0307mQYP24KK00Q6f`0080Wh:d00@0Z8Nb0;nE[02oUJ`0]iNf0P38WJ/00`2aSK00dJF[
0=6UZ`020?GCZ`80dJFZ00<0aY:P0:UkX@2YNj400`32V:`00`3ifjT000NI0000N`020;BC]@80Z8Rc
0P2RRk`30;6=/080Tg>/0P2dRJP209=]Y080dJng00<0l/BQ0?;B[`3icI/00P22L;H204e=/@0309]f
Z@38Til0k[jO0080k[jO0`2]a>/20:UnY@030;onfP1[G[40Jeja0080aHfJ00D0o]Mk0<FL[P35W:h0
aIb^0<BGZ0020>VoZP<0oooo00@006Nm069X``29M;H0RGBf0`2aRjd30;f;X0030?O@Y@3AYZ/0dJJ[
07@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`00C@3oool00`000000
oooo0?ooo`1?0?ooo`0507mKWP2dP9`0]82L0;B0W02SO:T00P3O^[820;nDZ`040:QlX`3U]ZD0d:F/
0=2U[080[GjQ0P2GK9l0103<Z[L0Xi?40:>Ca02STl@20:JQd0030:N4[`1oHJH0Of6V0080Q6f`0P2O
P[@30;nE[0<0b9f[0P3AYJ/20?GCZ`040?[YW@3AYJX0dJFZ0<JBX080ZG^Q00H0eZFT0<:H[03ifjT0
nM^Y000@U`0007h20;BC]@030:R8/`2aSK00/Hf`0080TgJ`0P2aSK0209=c[080]8VX00<0TffT0=6_
]`3A[kL00P3ba:420?W=V`060<bJY01gEYl0U7Zc04e=/@2KMZT0b9>O0`3^_Yl00`3@Y:/0ZGjU0:Un
Y@020:UnY@030;onfP1[G[40Jeja0080aHfJ00@0o]Mk0=Rb/P35W:h0aIb^0`3Y_jX40?ooo`80HVS3
0P2HN[020;6;[@<0_H^P00<0mm2U0=6VZ`3oool0M@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01L0oooo001>0?ooo`030000003oool0oooo04h0oooo00D0Oe^N0;B0W02dP9`0]82L
0:=lZ@020=nj/P030;nDZ`2XO:<0Z7bS00<0d:F/0P2]OZ40102GK9l0c:Zg0<bZ]`3<Z[L20:>Ca003
05e2V@2WQ:l0YhB_0080Of6V0P24KK0309YcYP80_iF/00D0dj^_0<RMZ`38WJ/0_Y>Y0=6UZ`020?GC
Z`80dJFZ0P36TZ020:UkX@060=JUY032V:`0nM^Y0?WKZ@0049L0001n0P2dTkD30;6=/080TgJ`0P2a
SK0209=c[080]8VX0`3A[kL20?;4X@030?W=V`3<VZ@0c9ZT0080MeJO00<0CDfa09]fZ@38Til00`3^
_Yl00`3@Y:/0eJ:R0:UnY@020:UnY@030=^UWP0@6YP0Jeja0080aHfJ00@0o]Mk0=Rb/P35W:h0aIb^
0P3?]L050?ooo`80HVS30P2HN[030;6;[@030;f;X03gd:D0mm2U07L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0G0?ooo`00C`3oool2000004h0oooo102dP9`30=nj/P<0Z7bS00<0
bLU90=2U[03@YJ`00P2]OZ440<bZ]`80OenT0P2LNZd2081`^080W7V/0P2BJj8209YcYP80_iF/00D0
dj^_0<RMZ`2nTjT0_Y>Y0=6UZ`020?GCZ`040<>?X03AYJX0aY:P0<JBX080ZG^Q00<0eZFT0?WKZ@2K
L:400P2KL:40100049L0_;GB0;bedP2l]M820;6=/080TgJ`0P2aSK0209=c[0<0/:WA0P3A[kL00`3b
a:40l]:_0?W=V`020<bJY00407MFW`3ndY0001NM09]fZ@<0k[jO0P3@Y:/0203EXZ80ZGjU0:UnY@2Y
OZD0fjFN010JV01[G[40aHfJ0P3neg/00`3H/[80aIb^0<ne`0020<ne`0H0oooo00<0HVS309Qj/02H
N[000`2aRjd00`2mRj00mm2U0?O@Y@1h0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool05P3oool00540oooo00<000000?ooo`3oool0C03oool30;B0W0040=C8A`32[lL0`Zo70<:_a`80
Z7bS00@0bLU90=2U[03@YJ`0[GjQ0P3Bbm<30<bZ]`80OenT0P2LNZd2081`^080W7V/0P2BJj8209Yc
YP040;nE[03CZjl0dj^_0<RMZ`80_Y>Y0P3edj/00`3B[kH0`hnP0=6UZP020<JBX0050:UkX@3FYJ@0
eZFT0<NEX`3PZI/00`2KL:400`0039/0_;GB0;bedP020;6=/080TgJ`0`2OPK8209=cZ`<0/:WA0P3b
a:401`3bdZl0nLfK0<bJY03<VZ@0MeJO0?kBT01>>IT00P2KMZT20>jnW`80d:B[00<0eJ:R0:UnY@2Y
OZD00P3KYIh01015<ID0?W7K0<F=VP3neg/20=Rb/P<0ckG0203oool209Qj/0<0/H^]00<0_H^P0?O@
Y@3oool0N@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo001B0?ooo`03
0000003oool0oooo04/0oooo0`2dP9`0103Db4L000000<:_a`32[lL20:QlX`030<W9B@3@YJ`0d:F/
00@0d/_C00@0c:Zg0;J>[01oGj@0OenT0P2LNZd2081`^080W7V/0P2BJj8209YcYP030;nE[03CZjl0
dj^_00<0_Y>Y00@0kNZ70=:_]P3B[kH0`hnP0`36TZ001@2YNj40eZFT0=JUY037UJ<0h:VK00<0Vg2Q
00@0ZHRa000<V`2l]M80/Hf`0P35k_020:R/f@80Wh6b0`2CLj/309ek[@030?;B[`3icI/0c9ZT0080
c9ZT00<0MeJO0?kBT03oool00`2X_n/20=2TZ`<0eJ:R00H0ZGjU0=^UWP3KYIh0AC6E03iaf`35SIX3
0=Rb/P030;fG/03?]L00oooo00P0oooo0P2HN[030;6;[@030?O@Y@3oool0oooo07T0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`00D`3oool00`000000oooo0?ooo`1:0?oo
o`<0]82L00H0oooo00mQf032[lL0`Zo70:QlX`3b_IL20=BY[0030?cDV@1;P^D0Bh;U0080d/_C0P2f
SZ`207mOY080W7Z]0P20L;P209ai[080TV^R0P2JLjH30=>[[`030;Z@ZP2nTjT0_Y>Y0080dZnf0P33
Sj00103DWYd0aY:P0<JBX02YNj420=JUY0030<NEX`3PZI/0Vg2Q0080Vg2Q00<0cIZR0:V8/@1LIL<0
0`35k_020:R/f@80Wh6b0`2CLj/01P34VJ`0WG^]09ek[@30Sj<0nlZA0?_;TP80c9ZT00<0MeJO0?oo
o`3oool00P1cK;`20:n@]P050=2TZ`3EXZ80eJ:R0=FRXP2YOZD00P3KYIh204DaU@0307ILZ00nLM/0
f;:b0080_IN`S03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo001D0?oo
o`800000BP3oool20;B0W0070=C8A`3oool0oooo0?ooo`32[lL0Z7bS0?:mU`020=BY[080o=BI00<0
[X6S0>:i[@3R^Jd00P2fSZ`207mOY00409aj[@2mX;`0_J2l081`^080W7V/0P2BJj8209YcYP050;fC
[03CZjl0^Y2Z0;Z@ZP2nTjT00`3B[kH20<>?X0030=BNW@36TZ00aY:P0080eZFT0P37UJ<01P3PZI/0
Vg2Q09]`X@2KL:40cIZR0:V8/@80c9VP00@0m<FL00QmhP1m[_<0Z:cI0P2OPK8209=cZ`80a9V/0P2M
Njd00`30Sj<0nlZA0?_;TP020<bJY00307MFW`3oool0oooo00<0Lfbl00<0[i2f0=2TZ`3EXZ800P3E
XZ800`2YOZD0fjFN0=^UWP0204DaU@80MUbX0`2mUk2=0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool05P3oool005H0oooo00<000000?ooo`3oool0A`3oool20;B0W0@0oooo00@0`Zo7
0:QlX`3DZJ`0e:V/0`3le9T00`2^PJ<0h[V]0>:i[@020;J>[080OenT0`2mX;`00`0W?[@0W7V/09ai
[002099[XP0309YcYP2mTj`0_I>/00<0^Y2Z00@0_Y>Y0<FDY03B[kH0dZnf0P33Sj001@3DWYd0aY:P
0<JBX030Sj<0eZFT0080aiFS00<0h:VK09]`X@2KL:400P3=VZ801`2YR;40c9VP0<bIX03daI`0001Y
00QmhP1VF:h00P2OPK801@2CLj/0a9V/0<BI[034VJ`0WG^]0080`8nS00D0nlZA0?_;TP3<VZ@0c9ZT
0:f9/0060?ooo`@0eJ:R0`3KYIh204DaU@<0MUbX0P2mUk2>0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool05P3oool005L0oooo00<000000?ooo`3oool0AP3oool20;B0W0D0oooo00<0
Z7bS0?ooo`3DZJ`00`3le9T30>:i[@030<NZ_@2;UmT0RiOI0080ZKWU0P2mX;`00`2WY]@0`L?K09ai
[002099[XP<0_I>/00@0aiRW0;Z@ZP2jT:X0imC30P35U:@30<>?X0060=BNW@36TZ00aY:P0<2?X`3F
YJ@0aiFS0P3PZI/209]`X@80cIZR0`3<VJ001P3daI`0eZ>R00QmhP1m[_<0IUR^08A`]@@0a9V/00D0
WG^]0<2?X`30Sj<0nlZA0?_;TP030:f9/0H0oooo00D0_Ifh0=FRXP3EXZ80eJ:R0>kB]P020=^UWP<0
AC6E0P1fG:P00`2mUk00oooo0?ooo`2=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool05P3oool005P0oooo00<000000?ooo`3oool0A@3oool20;B0W0L0oooo00<0e:V/0?ooo`3oool0
0P2AOkd0103R^Jd0ajZm0<NZ_@3Lkmh30:^Ja@80Xi;20`31`m/30<?<h@80_I>/00<0aiRW0;Z@ZP2j
T:X00`35U:@01@3KYj00`hnP0<>?X03DWYd0aY:P0080`8nS0P37UJ<20>2YV`0509]`X@3=VZ80cIZR
0<fJXP3T]:<00P3<VJ001@3daI`0eZ>R0<IW000];j40IUR^0080Q72e0`34VJ`30<2?X`80nl^B00<0
mm^/0:f9/03oool01`3oool20=FRXP80k]:f0P3KYIh00`0?02<0AC6E04DaU@0207ILZ0030;fG/03o
ool0oooo08h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`00F@3oool2
000004D0oooo00<0]82L0=C8A`3oool02@3oool2095o_@<0ajZm0P2WY]D20:^Ja@80Xi;20P1eK[d2
0;FRa@80`lcQ00D0_I>/0<NHY`37V:L0^Y2Z0>OD``030<FDY0050=^WX033Sj00e9jM0=BNW@36TZ00
0P30Sj<01@3IYZ80aiFS0>2YV`3PZI/0Vg2Q00<0cIZR00<0i;BS0<bIX03daI`00P3FXj801@0`9iD0
;BnQ06IH[P1VF:h0Q72e00<0a9V/00<0[H>W0<2?X`3kbY400P3kbi800`3gfj`0[HV`0?ooo`070?oo
o`80eJ:R0P3^d[H01@3KYIh0oooo0?ooo`0H@;`0AC6E0080MUbXTP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01D0oooo001K0?ooo`030000003oool0oooo0480oooo00<0]82L0?oo
o`3oool02@3oool30=C?e0040<NZ_@3oool0YjKE0:NVe@80Zi[50P2ST/830;BM`@040;FRa@0]<:80
`lcQ0;fC[080aiRW00<0^Y2Z0>OD``35U:@00P35U:@0103KYj00`hnP0=BNW@3DWYd30<2?X`040=VV
XP37UJ<0h:VK0>2YV`@0cIZR00<0i;BS0<bIX03daI`00P3FXj80100`9iD0;BnQ02d_X@2kUJl208A`
]@060<BI[02]PjL0[H>W0<2?X`3kbY40nl^B0P3gfj`00`2]RK00oooo0?ooo`060?ooo`040=FRXP3^
d[H0k]:f0>kB]YX0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`00G03o
ool00`000000oooo0?ooo`110?ooo`030;B0W03oool0oooo00X0oooo0P3Dcm@50?ooo`80QNCg0P2?
S</20;BM`@<0_jFo0`37V:L0103We<<0aIBT0<FDY035U:@20=^WX0040<>?X03DWYd0e9jM0<nIWP80
`8nS00D0fJJR0<NEX`3PZI/0h:VK0=n`YP020<fJXP80i;BS00D0c9VP0?C5W03FXj80eZ>R030WU@02
065U`00305/0102kUJl0^iF_00<0[H>W00<0`8nS0?_:T@3kbi800P3gfj`00`2]RK00oooo0?ooo`06
0?ooo`<0k]:fV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo0400oooo00<0]82L0?ooo`3oool04`3oool208n<b`030<chj01S0000Sho?
0080_jFo00D0_eI60<NHY`37V:L0mMVa000000020<FDY080fjNP00D0`hnP0=BNW@3DWYd0ciVN0<2?
X`020=VVXP040<NEX`3PZI/0h:VK0=n`YP80cIZR0P3T]:<0203<VJ00m<FL0=JSXP3FXj80<2NE0?oo
o`1QIL0031RF0P2kUJl01P2@?5l0[H>W0:f3Y`30Sj<0nlZA0?_;TP80mm^/Z03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01D0oooo001N0?ooo`030000003oool0oooo05H0oooo0P2[
Rk@208n?c`030;nU_`2gT:h0]i2^0080aiRW00@0001n00000035U:@0aIBT0P3KYj001@33Sj00e9jM
0=BNW@3?VIh0`8nS0080fJJR0`3PZI/20=n`YP040<fJXP3T]:<0i;BS0?C5W0<0eZ>R0`3oool0100<
69H0^iF_0:Ohg`3Lkmh20:f3Y`030<2?X`3kbi80VI390:/0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0E0?ooo`00G`3oool2000005H0oooo0P2[Rk@208n?c`<0]i2^00D0aiRW0?GI
/@0K<Z`000000<FDY0030=^WX0<0e9jM00H0ciVN0<2?X`3IYZ80fJJR0?;;Z03PZI/30=n`YP050<fJ
XP3T]:<0i;BS0?K^]02cQjH00P3FXj830?ooo`0400`HUP2Wn=l0g>oN0=c_gP80[H>W00<0E77C09V@
b@3oool0[03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo001Q0?ooo`03
0000003oool0oooo05<0oooo0P2[Rk@00`1UCZ80Tg>/09=c[0020;N@[P050<NHY`3^aJT06c:/0<][
0035U:@00`3KYj001@3L/:/0e9jM0<nIWP3?VIh0`8nS0080fJJR00<0l/^X0>2YV`3O/:H00P3O/:H2
0>BdX`040?K^]02cQjH0/hNV0=JSXPP0oooo0P2]PjN_0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05@3oool00680oooo00<000000?ooo`3oool0DP3oool20:^;]00406E>XP2CLj`0
Tg>/0;N@[P80k/FY0P39WJX0103KYj40aIBT0=^WX03KYj020=b`Z`030=BNW@3?VIh0ciVN00<0fJJR
00<0l/^X0>2YV`3O/:H00P3O/:H00`3>Y[00i;BS0;>7YP020;>7YP030=JSXP3oool0oooo00H0oooo
00<0[H>W0?ooo`3oool0[`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo
001S0?ooo`030000003oool0oooo0580oooo00D0Zh^d06E>XP2CLj`0Tg>/0;N@[P020>k5Z@80bIfZ
00@0gJfU0=^WX03KYj00fjNP0P3L/:/01@3DWYd0ciVN0<nIWP3Xe5h0fJJR0080l/^X0`3O/:H20<jV
/0040?WR[@3ffZl0/hNV0;>7Y[`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D
0?ooo`00I03oool200000580oooo00@0H5Rb06E>XP2CLj`0Tg>/0P3^aJT30<VMZP030<VKZ03M[JD0
fjNP00<0g;2[00D0e9jM0<nIWP3?VIh0j=AN0=VVXP020?;;Z0030=Nl_`3O/:H0cZJ`0080cZJ`00@0
nN:]0?KJ[`2cQjH0/hNV_03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
001V0?ooo`030000003oool0oooo04l0oooo0P1PF;840:b?]`060;V:Y039WJX0bIfZ0<VKZ03caZ40
fjNP0`3L/:/01P3DWYd0ciVN0<nIWP3Xe5h0fJJR0?;;Z080ekbo103>Y[020?KJ[`80/hNV_@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo001W0?ooo`030000003oool0oooo
04h0oooo0P1PF;801P1LH/00[8ng0:b?]`2/SkL0^HZT0<VMZP80bI^X00<0c9ZS0=b`Z`3L/:/00P3L
/:/30<nIWP040>SDGP3bbjP0ekbo0=Nl_`80oooo0P3>Y[00103ihZd0m]Z_0?KJ[`2cQjJo0?ooo`05
0000003oool0oooo0?ooo`0000005P3oool006P0oooo00<000000?ooo`3oool0CP3oool01023LKH0
G6;00:b?]`2/SkL20;V:Y0050<VMZP39VjP0bI^X0<bJX`3oool00P3L/:/20>;ie@040<nIWP3Xe5h0
aK350<F`a@D0oooo00D0cZJ`0?KJ[`3ffZl0m]Z_0;>7YP300?ooo`040000003oool0oooo000001H0
oooo001Y0?ooo`800000CP3oool208=a]P0405aR`02/SkL0^HZT0;V:Y0<0bI^X00<0c9ZS0?ooo`3o
ool00`3RnMD00`3?VIh0aK350<F`a@3;0?ooo`040000003oool0oooo000001H0oooo001[0?ooo`03
0000003oool0oooo04/0oooo0P23LKH01P1nGJ<0^HZT0;V:Y02iRZ@0e:BU0<VKZ080c9ZS103oool0
103RnMD0ciVN0?ooo`35/<G<0?ooo`030000003oool0000001H0oooo001/0?ooo`030000003oool0
oooo04X0oooo0P23LKH207iMX`80^HZT00@0e:BU0<VKZ03<VZ<0c9ZS103oool00`3RnMD0ciVN0?oo
o`3>0?ooo`030000003oool0000001D0oooo001]0?ooo`030000003oool0oooo04X0oooo00<0Pg6f
07iMX`1nGJ<00P2iRZ@00`3DY:D0bI^X0<bJX`060?ooo`030<nIWP3oool0oooo0<h0oooo0P00000E
0?ooo`00KP3oool2000004X0oooo00@0Pg6f07iMX`1nGJ<0^HZT0P3DY:D20<bJXmL0oooo0P00000E
0?ooo`00L03oool00`000000oooo0?ooo`170?ooo`040000S01nGJ<0OUfS0;V:Y080e:BU00<0bIVT
0<bJX`3oool0eP3oool2000001D0oooo001a0?ooo`030000003oool0oooo04H0oooo00@0002<07iM
X`1nGJ<0^HZT0P3DY:D00`39VJ@0c9ZS0?ooo`3B0?ooo`@000005`3oool00780oooo00<000000?oo
o`3oool0AP3oool0100008`0LXkO0=BTY@3DY:D20<VIY0030<bJX`3oool0oooo0<d0oooo1000000K
0?ooo`00L`3oool2000004H0oooo00@0000007:>g`1bS]l0e:BU0P39VJ@00`3<VZ<0oooo0?ooo`39
0?ooo`@000007`3oool007D0oooo00<000000?ooo`3oool0@`3oool010000000_DHU07:>g`3DY:D2
0<VIY<P0oooo1000000S0?ooo`00MP3oool00`000000oooo0?ooo`120?ooo`030000003oool0@dff
00<0bIVTa@3oool3000002L0oooo001g0?ooo`030000003oool0oooo0440oooo00@000000?ooo`13
CKH0@dff0P39VJC10?ooo`@00000:P3oool007P0oooo0P0000110?ooo`050000003oool0@dff04==
]P39VJ@0_P3oool4000002h0oooo001j0?ooo`030000003oool0oooo03h0oooo00D000000?ooo`3o
ool0@dff0<VIY02j0?ooo`@00000<P3oool007/0oooo00<000000?ooo`3oool0?@3oool01@000000
oooo0?ooo`3oool0bIVT0;H0oooo1000000f0?ooo`00O03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0;@0oooo1000000j0?ooo`00O@3oool2000003`0oooo00<000000?ooo`3oool0
/@3oool3000003h0oooo001o0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3o
ool400000440oooo00200?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0Z@3oool4
000004D0oooo00210?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0Y@3oool40000
04T0oooo00220?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0X@3oool4000004d0
oooo00230?ooo`800000=P3oool00`000000oooo0?ooo`2N0?ooo`<00000D@3oool008D0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`2J0?ooo`@00000E03oool008H0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`2F0?ooo`@00000F03oool008L0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2B0?ooo`@00000G03oool008P0oooo0P00000`0?ooo`03
0000003oool0oooo08l0oooo1000001P0?ooo`00RP3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo08`0oooo0`00001T0?ooo`00R`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo08P0oooo1000001W0?ooo`00S03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo08@0oooo1000001[0?ooo`00S@3oool2000002/0oooo00<000000?ooo`3oool0P03oool40000
06l0oooo002?0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0O03oool4000007<0
oooo002@0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0N03oool4000007L0oooo
002A0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0M@3oool3000007/0oooo002B
0?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000OP3oool009@0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000PP3oool009D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1Y0?ooo`@00000QP3oool009H0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1U0?ooo`@00000RP3oool009L0oooo0P00000Q0?ooo`030000003o
ool0oooo0680oooo0`00002>0?ooo`00V@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo05h0oooo1000002A0?ooo`00VP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
05X0oooo1000002E0?ooo`00V`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05H0
oooo1000002I0?ooo`00W03oool2000001`0oooo00<000000?ooo`3oool0DP3oool4000009d0oooo
002N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3oool400000:40oooo002O
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool300000:D0oooo002P0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool400000:P0oooo002Q0?ooo`80
00005`3oool00`000000oooo0?ooo`130?ooo`@00000[03oool00:<0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0o0?ooo`@00000/03oool00:@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0k0?ooo`@00000]03oool00:D0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0h0?ooo`<00000^03oool00:H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0d0?ooo`@00000^`3oool00:L0oooo0P00000A0?ooo`030000003oool0oooo0300
oooo1000002o0?ooo`00Z@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo
100000330?ooo`00ZP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02T0oooo1000
00370?ooo`00Z`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo0`00003;
0?ooo`00[03oool2000000/0oooo00<000000?ooo`3oool08P3oool400000<h0oooo002^0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool400000=80oooo002_0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000=H0oooo002`0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05P3oool400000=X0oooo002a0?ooo`8000001P3oool0
0`000000oooo0?ooo`0B0?ooo`@00000gP3oool00;<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0?0?ooo`<00000hP3oool00;@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`@00000i@3oool00;D0oooo00D000000?ooo`3oool0oooo000000090?ooo`@0
0000j@3oool00;H0oooo0P0000000`3oool000000?ooo`040?ooo`@00000k@3oool00;P0oooo0P00
00000`3oool000000000000200000?40oooo002i0?ooo`800000m@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {349.313, 0}} -> {-0.0936204, -0.0161904, \
0.00382048, 0.00382048}}]
}, Open  ]],

Cell["Define a Gaussian model function.", "MathCaption"],

Cell[BoxData[
    \(\(Gaussian[a_, {x0_, \ y0_}]\)[{x_, \ y_}]\  := \ 
      Exp[\(-a\) \((\((x\  - \ x0)\)\^2 + \ \((y\  - \ y0)\)\^2)\)]\)], \
"Input",
  CellLabel->"In[22]:="],

Cell["\<\
Compute a nonlinear least-squares best fit for a Gaussian to the \
data.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(xydata\  = \ 
        Flatten[MapIndexed[Flatten[{#2, #1}] &, \ orthogonal, {2}], 
          1];\)\)], "Input",
  CellLabel->"In[25]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(fit\  = \ 
      FindFit[xydata, \ \(Gaussian[a, \ {x0, \ y0}]\)[{x, 
            y}], {{a,  .1}, {x0, \ 50}, {y0, \ 60}}, \ {x, y}]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({a \[Rule] 0.009461295394081177`, x0 \[Rule] 59.05013180079567`, 
      y0 \[Rule] 53.45343503986753`}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["Show contours for the data and the fit.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Block[{$DisplayFunction\  = \ Identity, \ 
            opts\  = \ {Contours \[Rule] { .5}, 
                ContourShading \[Rule] 
                  False}}, \[IndentingNewLine]{ListContourPlot[orthogonal, \ 
              Evaluate[opts]], \[IndentingNewLine]ContourPlot[
              Evaluate[\ \(Gaussian[a, \ {x0, \ y0}]\)[{x, y}]\  /. \ 
                  fit], \ \ {x, 0, 100}, {y, 0, 100}, 
              Evaluate[opts]]}]];\)\)], "Input",
  CellLabel->"In[67]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0141083 0.0238095 0.0140089 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.16489 -0.0125 -6 -9 ]
[.16489 -0.0125 6 0 ]
[.30598 -0.0125 -6 -9 ]
[.30598 -0.0125 6 0 ]
[.44706 -0.0125 -6 -9 ]
[.44706 -0.0125 6 0 ]
[.58814 -0.0125 -6 -9 ]
[.58814 -0.0125 6 0 ]
[.72923 -0.0125 -6 -9 ]
[.72923 -0.0125 6 0 ]
[.87031 -0.0125 -6 -9 ]
[.87031 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .1639 -12 -4.5 ]
[-0.0125 .1639 0 4.5 ]
[-0.0125 .30399 -12 -4.5 ]
[-0.0125 .30399 0 4.5 ]
[-0.0125 .44408 -12 -4.5 ]
[-0.0125 .44408 0 4.5 ]
[-0.0125 .58417 -12 -4.5 ]
[-0.0125 .58417 0 4.5 ]
[-0.0125 .72426 -12 -4.5 ]
[-0.0125 .72426 0 4.5 ]
[-0.0125 .86434 -12 -4.5 ]
[-0.0125 .86434 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.16489 0 m
.16489 .00625 L
s
[(10)] .16489 -0.0125 0 1 Mshowa
.30598 0 m
.30598 .00625 L
s
[(20)] .30598 -0.0125 0 1 Mshowa
.44706 0 m
.44706 .00625 L
s
[(30)] .44706 -0.0125 0 1 Mshowa
.58814 0 m
.58814 .00625 L
s
[(40)] .58814 -0.0125 0 1 Mshowa
.72923 0 m
.72923 .00625 L
s
[(50)] .72923 -0.0125 0 1 Mshowa
.87031 0 m
.87031 .00625 L
s
[(60)] .87031 -0.0125 0 1 Mshowa
.125 Mabswid
.05203 0 m
.05203 .00375 L
s
.08024 0 m
.08024 .00375 L
s
.10846 0 m
.10846 .00375 L
s
.13668 0 m
.13668 .00375 L
s
.19311 0 m
.19311 .00375 L
s
.22133 0 m
.22133 .00375 L
s
.24954 0 m
.24954 .00375 L
s
.27776 0 m
.27776 .00375 L
s
.33419 0 m
.33419 .00375 L
s
.36241 0 m
.36241 .00375 L
s
.39063 0 m
.39063 .00375 L
s
.41884 0 m
.41884 .00375 L
s
.47528 0 m
.47528 .00375 L
s
.50349 0 m
.50349 .00375 L
s
.53171 0 m
.53171 .00375 L
s
.55993 0 m
.55993 .00375 L
s
.61636 0 m
.61636 .00375 L
s
.64458 0 m
.64458 .00375 L
s
.67279 0 m
.67279 .00375 L
s
.70101 0 m
.70101 .00375 L
s
.75744 0 m
.75744 .00375 L
s
.78566 0 m
.78566 .00375 L
s
.81388 0 m
.81388 .00375 L
s
.84209 0 m
.84209 .00375 L
s
.89853 0 m
.89853 .00375 L
s
.92674 0 m
.92674 .00375 L
s
.95496 0 m
.95496 .00375 L
s
.98318 0 m
.98318 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .1639 m
.00625 .1639 L
s
[(10)] -0.0125 .1639 1 0 Mshowa
0 .30399 m
.00625 .30399 L
s
[(20)] -0.0125 .30399 1 0 Mshowa
0 .44408 m
.00625 .44408 L
s
[(30)] -0.0125 .44408 1 0 Mshowa
0 .58417 m
.00625 .58417 L
s
[(40)] -0.0125 .58417 1 0 Mshowa
0 .72426 m
.00625 .72426 L
s
[(50)] -0.0125 .72426 1 0 Mshowa
0 .86434 m
.00625 .86434 L
s
[(60)] -0.0125 .86434 1 0 Mshowa
.125 Mabswid
0 .05183 m
.00375 .05183 L
s
0 .07985 m
.00375 .07985 L
s
0 .10786 m
.00375 .10786 L
s
0 .13588 m
.00375 .13588 L
s
0 .19192 m
.00375 .19192 L
s
0 .21993 m
.00375 .21993 L
s
0 .24795 m
.00375 .24795 L
s
0 .27597 m
.00375 .27597 L
s
0 .33201 m
.00375 .33201 L
s
0 .36002 m
.00375 .36002 L
s
0 .38804 m
.00375 .38804 L
s
0 .41606 m
.00375 .41606 L
s
0 .47209 m
.00375 .47209 L
s
0 .50011 m
.00375 .50011 L
s
0 .52813 m
.00375 .52813 L
s
0 .55615 m
.00375 .55615 L
s
0 .61218 m
.00375 .61218 L
s
0 .6402 m
.00375 .6402 L
s
0 .66822 m
.00375 .66822 L
s
0 .69624 m
.00375 .69624 L
s
0 .75227 m
.00375 .75227 L
s
0 .78029 m
.00375 .78029 L
s
0 .80831 m
.00375 .80831 L
s
0 .83633 m
.00375 .83633 L
s
0 .89236 m
.00375 .89236 L
s
0 .92038 m
.00375 .92038 L
s
0 .9484 m
.00375 .9484 L
s
0 .97642 m
.00375 .97642 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.16489 .99375 m
.16489 1 L
s
.30598 .99375 m
.30598 1 L
s
.44706 .99375 m
.44706 1 L
s
.58814 .99375 m
.58814 1 L
s
.72923 .99375 m
.72923 1 L
s
.87031 .99375 m
.87031 1 L
s
.125 Mabswid
.05203 .99625 m
.05203 1 L
s
.08024 .99625 m
.08024 1 L
s
.10846 .99625 m
.10846 1 L
s
.13668 .99625 m
.13668 1 L
s
.19311 .99625 m
.19311 1 L
s
.22133 .99625 m
.22133 1 L
s
.24954 .99625 m
.24954 1 L
s
.27776 .99625 m
.27776 1 L
s
.33419 .99625 m
.33419 1 L
s
.36241 .99625 m
.36241 1 L
s
.39063 .99625 m
.39063 1 L
s
.41884 .99625 m
.41884 1 L
s
.47528 .99625 m
.47528 1 L
s
.50349 .99625 m
.50349 1 L
s
.53171 .99625 m
.53171 1 L
s
.55993 .99625 m
.55993 1 L
s
.61636 .99625 m
.61636 1 L
s
.64458 .99625 m
.64458 1 L
s
.67279 .99625 m
.67279 1 L
s
.70101 .99625 m
.70101 1 L
s
.75744 .99625 m
.75744 1 L
s
.78566 .99625 m
.78566 1 L
s
.81388 .99625 m
.81388 1 L
s
.84209 .99625 m
.84209 1 L
s
.89853 .99625 m
.89853 1 L
s
.92674 .99625 m
.92674 1 L
s
.95496 .99625 m
.95496 1 L
s
.98318 .99625 m
.98318 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .1639 m
1 .1639 L
s
.99375 .30399 m
1 .30399 L
s
.99375 .44408 m
1 .44408 L
s
.99375 .58417 m
1 .58417 L
s
.99375 .72426 m
1 .72426 L
s
.99375 .86434 m
1 .86434 L
s
.125 Mabswid
.99625 .05183 m
1 .05183 L
s
.99625 .07985 m
1 .07985 L
s
.99625 .10786 m
1 .10786 L
s
.99625 .13588 m
1 .13588 L
s
.99625 .19192 m
1 .19192 L
s
.99625 .21993 m
1 .21993 L
s
.99625 .24795 m
1 .24795 L
s
.99625 .27597 m
1 .27597 L
s
.99625 .33201 m
1 .33201 L
s
.99625 .36002 m
1 .36002 L
s
.99625 .38804 m
1 .38804 L
s
.99625 .41606 m
1 .41606 L
s
.99625 .47209 m
1 .47209 L
s
.99625 .50011 m
1 .50011 L
s
.99625 .52813 m
1 .52813 L
s
.99625 .55615 m
1 .55615 L
s
.99625 .61218 m
1 .61218 L
s
.99625 .6402 m
1 .6402 L
s
.99625 .66822 m
1 .66822 L
s
.99625 .69624 m
1 .69624 L
s
.99625 .75227 m
1 .75227 L
s
.99625 .78029 m
1 .78029 L
s
.99625 .80831 m
1 .80831 L
s
.99625 .83633 m
1 .83633 L
s
.99625 .89236 m
1 .89236 L
s
.99625 .92038 m
1 .92038 L
s
.99625 .9484 m
1 .9484 L
s
.99625 .97642 m
1 .97642 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.95496 .84529 m
.95984 .85034 L
.96366 .86434 L
.96152 .87835 L
.95496 .88778 L
.94085 .88609 L
.93586 .89236 L
.94085 .90242 L
.94354 .90637 L
.95496 .92024 L
.95521 .92038 L
.95629 .93439 L
.95496 .93819 L
.95055 .9484 L
.94085 .96076 L
.94071 .96241 L
.92674 .97229 L
.91263 .97619 L
.89853 .97305 L
.88963 .96241 L
.88442 .95348 L
.88121 .9484 L
.88442 .94204 L
.88791 .93439 L
.89853 .92402 L
.90257 .92038 L
.91263 .90736 L
.91336 .90637 L
.91956 .89236 L
.91833 .87835 L
.92037 .86434 L
.92674 .86182 L
.94085 .85825 L
.94553 .85034 L
.95496 .84529 L
s
.96907 .76287 m
.9708 .76628 L
.96907 .77314 L
.9613 .76628 L
.96907 .76287 L
s
.72923 .72395 m
.74333 .72139 L
.75275 .72426 L
.75744 .72613 L
.77155 .73621 L
.78566 .73597 L
.78963 .73826 L
.79977 .74566 L
.81012 .75227 L
.81388 .75634 L
.81892 .76628 L
.8263 .78029 L
.82798 .78356 L
.83674 .7943 L
.83826 .80831 L
.84209 .81241 L
.8519 .82232 L
.8562 .83123 L
.85817 .83633 L
.86182 .85034 L
.86686 .86434 L
.86899 .87835 L
.86398 .89236 L
.8562 .90437 L
.85464 .90637 L
.84724 .92038 L
.84209 .92327 L
.82798 .92582 L
.81388 .92984 L
.80281 .93439 L
.79977 .93808 L
.78733 .9484 L
.78566 .94955 L
.77155 .95614 L
.75744 .95757 L
.74333 .95333 L
.72923 .95171 L
.71512 .94924 L
.70557 .9484 L
.70101 .94715 L
.6869 .94132 L
.68146 .93439 L
.67279 .92937 L
.66243 .92038 L
.65868 .915 L
.65423 .90637 L
.65504 .89236 L
.65109 .87835 L
.65496 .86434 L
.65868 .85433 L
Mistroke
.66112 .85034 L
.66642 .83633 L
.67279 .82563 L
.67529 .82232 L
.6869 .80955 L
.68747 .80831 L
.6869 .80096 L
.68554 .7943 L
.6869 .78702 L
.68777 .78029 L
.68953 .76628 L
.68791 .75227 L
.70101 .74979 L
.70524 .73826 L
.71512 .73152 L
.72881 .72426 L
.72923 .72395 L
Mfstroke
.09435 .03993 m
.10543 .05183 L
.10664 .06584 L
.10846 .07484 L
.11132 .07985 L
.11928 .09385 L
.12257 .09909 L
.12692 .10786 L
.12257 .11219 L
.11618 .12187 L
.10846 .12969 L
.10105 .13588 L
.09435 .14108 L
.08869 .13588 L
.08024 .12676 L
.07435 .12187 L
.06613 .11559 L
.06018 .10786 L
.06482 .09385 L
.06613 .08487 L
.06829 .07985 L
.07861 .06584 L
.08024 .06429 L
.0874 .05183 L
.09435 .03993 L
s
.8468 .6542 m
.90558 .66316 L
.91678 .66588 L
.96437 .71307 L
.96713 .72426 L
.97619 .78263 L
.96437 .82668 L
.96127 .841 L
.90558 .88387 L
.8468 .89275 L
.78801 .87333 L
.75547 .841 L
.73593 .78263 L
.7449 .72426 L
.78801 .66902 L
.80258 .66588 L
.8468 .6542 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[67]:=",
  ImageSize->{288, 288},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`007P3oool400000300oooo1`00
00030?ooo`@00000:`3oool6000000@0oooo1000000]0?ooo`@000001@3oool4000002d0oooo1000
00040?ooo`@00000;@3oool4000000D0oooo1000000]0?ooo`@00000103oool400000340oooo000M
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0;P3oool001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0^0?ooo`007@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo02P0oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:@3oool2000000<0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0^0?ooo`007@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02`0oooo0P0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0;P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0^0?ooo`007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02T0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo10000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool001d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02h0oooo000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0;P3oool3000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0;P3oool001h0oooo1000000c0?ooo`030000003oool0oooo00@0oooo1000
000/0?ooo`@000001@3oool4000002d0oooo100000050?ooo`@00000;P3oool2000000D0oooo1000
000]0?ooo`D00000103oool4000002l0oooo0`0000030?ooo`@00000<@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool001L0ooooo`00002I00000040oooo000G0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
0380oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`3o0?oooiD0oooo0@0000010?ooo`002`3oool4000000P0oooo00<000000?ooo`3oool0o`3ooonE
0?ooo`4000000@3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?l0ooooU@3oool100000040oooo000:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`00
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`00003o0?oooi<0oooo
0`0000010?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oo
oiD0oooo0@0000010?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000/0oooo100000080?ooo`030000
003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3o
ool100000040oooo000G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooom_
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0000003o0?oo
og00oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo0000
0?l0ooooK`3oool100000040oooo000G0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?ooof`0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`400000
0@3oool001L0oooo0P00000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
oomY0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?l0ooooJP3oool100000040oooo000G0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooofX0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooomZ0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0ooooJP3oool100000040oooo000G0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooofX0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooomZ0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooJP3oool100000040oooo000G0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooofT0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooomY0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooJ@3oool100000040oooo000G
0?ooo`8000006@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooI`3oool2
00000040oooo000G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`3o0?ooofP0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooomW0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo
I`3oool100000040oooo000G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3o0?ooofH0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooomV0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0?l0ooooI@3oool100000040oooo000G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`3o0?ooof@0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0?l0ooooH`3oool100000040oooo000G0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooof80oooo0@0000010?ooo`005`3oool20000
01H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooof40oooo0P0000010?oo
o`005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0o`3ooomS0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooH`3oool100000040oooo000G0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooof@0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0o`3ooomU0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool06@3oool20000
0180oooo00<000000?ooo`3oool0o`3ooomU0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooIP3oool100000040
oooo000G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3o0?ooofL0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooJ@3oool1
00000040oooo000G0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3o0?ooofX0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`4000000@3oool001L0oooo
0P00000R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooom[0?ooo`800000
0@3oool001L0oooo00<000000?ooo`3oool08P3oool010000000oooo00000000003o0?ooofl0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooK`3o
ool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?oo
o`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0
ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo
000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo00000`3oool0000000000005
000000<0oooo100000080?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo00040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?l0ooooU@3oool100000040oooo00040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
ooooU@3oool100000040oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooonC0?ooo`<000000@3oool000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooonE
0?ooo`4000000@3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool00080
oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`00103oool00`000000oooo0?ooo`040?ooo`@00000
203oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool2
00000?l0ooooU@3oool200000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool10000
0040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000
003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3o
ool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?oo
o`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0
ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo
000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0
oooo0?l0ooooU@3oool100000040oooo000G0?ooo`800000o`3ooonE0?ooo`8000000@3oool001L0
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo0P00003o0?oooiD0oooo
0P0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oo
oiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo
0@0000010?ooo`005`3oool200000?l0ooooU@3oool200000040oooo000G0?ooo`030000003oool0
oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool10000
0040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000
003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3o
ool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?oo
o`030000003oool0oooo0?l0ooooU@3oool100000040oooo00000`3oool0000000000004000000@0
oooo100000080?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo00000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo00020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
U@3oool100000040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`<00000o`3ooonC0?ooo`<000000@3oool000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooonE0?oo
o`4000000@3oool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool00003
0?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool00080oooo100000050?ooo`@0
0000203oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3o
ool200000?l0ooooU@3oool200000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool1
00000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo
U@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G
0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo
0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040
oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003o
ool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`800000o`3ooonE0?ooo`8000000@3oool0
01L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3o
oonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo0P00003o0?oooiD0
oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o
0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0
oooo0@0000010?ooo`005`3oool200000?l0ooooU@3oool200000040oooo000G0?ooo`030000003o
ool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool1
00000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo
U@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G
0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo00020?ooo`@000001@3oool40000
00P0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000030?ooo`000000oooo00<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3ooonE0?ooo`4000000@3oool000H0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000H0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo0`00003o0?oo
oi<0oooo0`0000010?ooo`00103oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo00060?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
ooooU@3oool100000040oooo00060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo00000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo00020?ooo`@000001@3oool4000000P0oooo
00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3o
oonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo0P00003o
0?oooiD0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o
0?oooiD0oooo0@0000010?ooo`005`3oool200000?l0ooooU@3oool200000040oooo000G0?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo
U@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G
0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo
0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040
oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003o
ool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool1
00000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`800000o`3ooonE0?ooo`800000
0@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3o
oonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`400000
0@3oool001L0oooo0P00003o0?oooiD0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`3o
0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`000`3oool4000000@0oooo100000080?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo00050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
U@3oool100000040oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo0000
0`3oool0000000000004000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo00020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooonC
0?ooo`<000000@3oool00080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool0
00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000<0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooonE0?ooo`4000000@3oool000@0oooo0P0000050?ooo`@00000203oool00`000000oooo
0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool200000?l0ooooU@3oool2
00000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo
U@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G
0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo
0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040
oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003o
ool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool1
00000040oooo000G0?ooo`800000o`3ooonE0?ooo`8000000@3oool001L0oooo00<000000?ooo`3o
ool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0o`3ooonE0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooonE0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`@00000>`3oool100000040
oooo000G0?ooo`030000003oool0oooo0?l0ooooDP3oool4000000@0oooo1P00000e0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`<000003P3oool6000002l0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`3o0?oood/0oooo1000000G0?ooo`H00000:@3oool1
00000040oooo000G0?ooo`030000003oool0oooo0?l0ooooA`3oool400000240oooo1@00000T0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooom30?ooo`@00000:P3oool300000240
oooo0@0000010?ooo`005`3oool200000?l0oooo@03oool400000340oooo00<000000?ooo`3oool0
7@3oool200000040oooo000G0?ooo`030000003oool0oooo0?l0oooo?P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01d0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o
0?ooocd0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0L0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool06`3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo?03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo01X0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`3o0?oooc/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0I0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0603oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo>P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01L0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0F0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0480
oooo0P00000F0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool100000040oooo000G0?ooo`800000o`3o
oolg0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool04@3oool200000040oooo000G
0?ooo`030000003oool0oooo0?l0oooo=P3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo0140oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0o`3ooold0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool03`3oool100000040
oooo000G0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00h0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooc80oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0303oool1
00000040oooo000G0?ooo`030000003oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo00/0oooo0@0000010?ooo`000P3oool4000000D0oooo100000080?ooo`03
0000003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00/0
oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool000H0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool_0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool02P3oool100000040oooo00060?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
oooo:`3oool4000005T0oooo00<000000?ooo`3oool02P3oool100000040oooo00060?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`<00000o`3ooolW0?ooo`@0
00000P3oool00`000000oooo00000003000005D0oooo00<000000?ooo`3oool0203oool300000040
oooo00020?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o`3ooolU0?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool02P3oool100000040oooo00020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?l0oooo8`3oool2000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo00X0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooob40oooo0P00000:0?ooo`030000003oool0oooo00D0oooo0P00001A0?ooo`030000003oool0
oooo00X0oooo0@0000010?ooo`000P3oool5000000@0oooo100000080?ooo`030000003oool0oooo
0?l0oooo7`3oool2000000/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooad0
oooo0P00000=0?ooo`030000003oool0oooo00T0oooo2@0000180?ooo`030000003oool0oooo00T0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
2@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01<0oooo0P0000150?ooo`030000003oool0oooo00T0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02@3oool1
00000040oooo000G0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`090?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`<00000403oool00`000000
oooo0?ooo`0G0?ooo`800000@P3oool00`000000oooo0?ooo`080?ooo`4000000@3oool001L0oooo
0P00003o0?oooaL0oooo0`00000C0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`070?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0203oool100000040oooo000G0?ooo`030000003oool0oooo
0?l0oooo5P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`080?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0o`3ooolG0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0l0?ooo`8000002P3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo
5`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
>P3oool3000000030?ooo`000000oooo00P0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`3o0?oooaL0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03P0oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0i0?ooo`050000003oool000000?ooo`0000002@3oool100000040
oooo000G0?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0>@3oool2000000030?ooo`000000oooo00P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`0000002@3o
ool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`07
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`005`3oool200000?l0oooo5`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`050?ooo`80
00000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00H0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01P3o
ool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`07
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00L0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool01`3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo5@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`070?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0203oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo5P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`080?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00T0oooo0@0000010?ooo`005`3oool200000?l0oooo5`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`080?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo503oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0:0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00X0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02P3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo4@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0;0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool02`3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0
oooo3P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
o`3oool>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`005`3oool200000?l0oooo3P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0;0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0o`3oool=
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oo
o``0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0303oool100000040oooo000G0?ooo`030000003oool0oooo0?l0
oooo303oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
o`3oool<0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0T0?ooo`800000403oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo2`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08@3o
ool2000000030?ooo`000000oooo00l0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o
0?ooo`/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo01l0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01h0oooo0`0000040?ooo`030000003oool0oooo00d0oooo0@0000010?oo
o`000`3oool4000000@0oooo100000080?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`000P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01/0oooo0P0000070?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`00
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo100000090?ooo`030000003oool0oooo00`0
oooo0@0000010?ooo`000P3oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool2000000030?ooo`000000000000X0
oooo00<000000?ooo`3oool0303oool100000040oooo00020?ooo`030000003oool0000000800000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`00003o0?ooo`T0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo
0P0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool300000040oooo
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00`0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`0000003P3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3oool80?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0B0?ooo`<000003`3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool0
00D0oooo0`0000030?ooo`@00000203oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?oo
o`3oool0=03oool2000001l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo00<000000?ooo`3oool0=`3oool4000001/0oooo00<000000?ooo`3oool0403oool200000140
oooo00<000000?ooo`3oool0303oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo
1`3oool00`000000oooo0?ooo`0k0?ooo`<00000603oool00`000000oooo0?ooo`0>0?ooo`800000
00<0oooo0000003oool0403oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo03h0oooo0`00000E0?ooo`030000003o
ool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0@03o
ool400000100oooo00<000000?ooo`3oool02P3oool4000000@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3oool8
0?ooo`030000003oool0oooo04@0oooo0`00000=0?ooo`030000003oool0oooo0080oooo20000009
0?ooo`030000003oool0oooo00D0oooo1`00000A0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0o`3oool90?ooo`030000003oool0oooo04H0oooo100000060?ooo`P000004@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo0@0000010?ooo`005`3oool200000?l0
oooo2P3oool00`000000oooo0?ooo`1:0?ooo`H000000P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool200000040oooo000G0?ooo`030000
003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool100000040oooo000G0?oo
o`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool100000040oooo
000G0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool10000
0040oooo000G0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
0@0000010?ooo`005`3oool200000?l0oooo3@3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`8000000@3o
ool001L0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo04<0oooo1000000E
0?ooo`8000005@3oool00`000000oooo0?ooo`0?0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0o`3oool>0?ooo`800000?P3oool5000001P0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0?0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo03P0oooo0`00000L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool03`3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0oooo4@3oool2000003D0oooo
0`00000N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool100000040oooo
000G0?ooo`030000003oool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`0_0?ooo`<00000803o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool100000040oooo000G0?oo
o`030000003oool0oooo0?l0oooo5@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`3o0?oooaL0oooo0P00000X0?ooo`8000008`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`3o0?oooaT0oooo0P00000U0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo0P00003o0?oooa`0oooo2@00000K
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@
0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`H000004`3oool20000
02H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`D000002`3oool3000002T0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
o`3oool_0?ooo`8000001@3oool4000002`0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooola0?ooo`D00000<@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool05@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0
ooooJ@3oool00`000000oooo0?ooo`0?0?ooo`800000603oool100000040oooo000G0?ooo`030000
003oool0oooo0?l0ooooJP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool02P3o
ool2000001/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?ooof`0oooo0`000006
0?ooo`<000007@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooK`3oool60000
0200oooo0@0000010?ooo`005`3oool200000?l0ooooU@3oool200000040oooo000G0?ooo`030000
003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3o
ool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?oo
o`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0
ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo
000G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0<P3oool100000040oooo000G
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`4000000@3oool001L0ooooo`00002I00000040oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-5.70327, -5.36621, 0.260773, \
0.262624}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Instrument\ data\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "More and more computer programs are using XML formats to store \
information.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is particularly well suited to handle XML because there is a direct \
mapping between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s tree structure and XML, Symbolic XML. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s symbolic substitution and pattern matching tools make working with data \
read in from XML files quite easy."
}], "Text"],

Cell["\<\
As an example, I'll show you the processing of an XML format for \
GPS (global positioning system) data.\
\>", "Text"],

Cell["Display the contents of a .gpx file.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(!! Bangtail.gpx\)\)], "Input",
  CellLabel->"In[68]:="],

Cell["\<\
<?xml version=\"1.0\" encoding=\"ISO-8859-1\" standalone=\"yes\"?>
<gpx
 version=\"1.1\"
 creator=\"ExpertGPS 1.3.4 - http://www.topografix.com\"
 xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"
 xmlns=\"http://www.topografix.com/GPX/1/1\"
 xmlns:topografix=\"http://www.topografix.com/GPX/Private/TopoGrafix/0/2\"
 xsi:schemaLocation=\"http://www.topografix.com/GPX/1/1 gpx.xsd
 http://www.topografix.com/GPX/Private/TopoGrafix/0/2 topografix.xsd\">
<time>2004-06-23T15:56:41Z</time>
<bounds minlat=\"45.748583\" minlon=\"-110.885533\" maxlat=\"45.858800\" \
maxlon=\"-110.774583\"/>
<trk>
 <name>TRACK</name>
 <desc>Tracklog from Magellan GPS</desc>
 <type>track</type>
 <number>1</number>
<trkseg>
<trkpt lat=\"45.760683333\" lon=\"-110.875616667\">
 <ele>1687.000000</ele><time>2004-06-23T22:27:0.450Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760900000\" lon=\"-110.875100000\">
 <ele>1687.000000</ele><time>2004-06-23T22:27:41.440Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760566667\" lon=\"-110.872233333\">
 <ele>1677.000000</ele><time>2004-06-23T22:42:36.460Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760050000\" lon=\"-110.870400000\">
 <ele>1688.000000</ele><time>2004-06-23T22:43:34.460Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.759883333\" lon=\"-110.868616667\">
 <ele>1697.000000</ele><time>2004-06-23T22:44:33.470Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760233333\" lon=\"-110.867266667\">
 <ele>1702.000000</ele><time>2004-06-23T22:45:5.470Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760500000\" lon=\"-110.865566667\">
 <ele>1709.000000</ele><time>2004-06-23T22:45:45.470Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760916667\" lon=\"-110.863933333\">
 <ele>1718.000000</ele><time>2004-06-23T22:46:28.460Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.762866667\" lon=\"-110.862233333\">
 <ele>1732.000000</ele><time>2004-06-23T22:47:43.470Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763200000\" lon=\"-110.859883333\">
 <ele>1731.000000</ele><time>2004-06-23T22:48:27.470Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763616667\" lon=\"-110.858300000\">
 <ele>1732.000000</ele><time>2004-06-23T22:48:59.460Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763900000\" lon=\"-110.855633333\">
 <ele>1743.000000</ele><time>2004-06-23T22:49:54.470Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763916667\" lon=\"-110.854133333\">
 <ele>1743.000000</ele><time>2004-06-23T22:50:16.470Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763383333\" lon=\"-110.854750000\">
 <ele>1767.000000</ele><time>2004-06-23T22:54:42.480Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.762933333\" lon=\"-110.855283333\">
 <ele>1772.000000</ele><time>2004-06-23T22:55:23.490Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763100000\" lon=\"-110.853983333\">
 <ele>1778.000000</ele><time>2004-06-23T22:56:26.490Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763266667\" lon=\"-110.853233333\">
 <ele>1795.000000</ele><time>2004-06-23T22:57:1.490Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.762950000\" lon=\"-110.854016667\">
 <ele>1799.000000</ele><time>2004-06-23T22:57:47.490Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.762750000\" lon=\"-110.853316667\">
 <ele>1815.000000</ele><time>2004-06-23T22:59:49.020Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.762466667\" lon=\"-110.854000000\">
 <ele>1835.000000</ele><time>2004-06-23T23:00:20.490Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761683333\" lon=\"-110.854433333\">
 <ele>1845.000000</ele><time>2004-06-23T23:02:41.500Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761916667\" lon=\"-110.853366667\">
 <ele>1845.000000</ele><time>2004-06-23T23:03:34.490Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761716667\" lon=\"-110.852750000\">
 <ele>1881.000000</ele><time>2004-06-23T23:05:40.500Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761050000\" lon=\"-110.853833333\">
 <ele>1897.000000</ele><time>2004-06-23T23:06:30.500Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761366667\" lon=\"-110.852733333\">
 <ele>1909.000000</ele><time>2004-06-23T23:08:16.510Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761116667\" lon=\"-110.851983333\">
 <ele>1909.000000</ele><time>2004-06-23T23:08:49.510Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760933333\" lon=\"-110.850933333\">
 <ele>1909.000000</ele><time>2004-06-23T23:09:31.510Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761450000\" lon=\"-110.850483333\">
 <ele>1909.000000</ele><time>2004-06-23T23:10:2.510Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760650000\" lon=\"-110.850400000\">
 <ele>1924.000000</ele><time>2004-06-23T23:11:23.510Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760900000\" lon=\"-110.849633333\">
 <ele>1924.000000</ele><time>2004-06-23T23:12:32.510Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760116667\" lon=\"-110.850066667\">
 <ele>1944.000000</ele><time>2004-06-23T23:13:32.500Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760366667\" lon=\"-110.849083333\">
 <ele>1950.000000</ele><time>2004-06-23T23:14:58.520Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760666667\" lon=\"-110.848050000\">
 <ele>1968.000000</ele><time>2004-06-23T23:15:41.520Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760933333\" lon=\"-110.847250000\">
 <ele>1977.000000</ele><time>2004-06-23T23:16:21.500Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760416667\" lon=\"-110.848016667\">
 <ele>1983.000000</ele><time>2004-06-23T23:17:6.510Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760433333\" lon=\"-110.846883333\">
 <ele>1985.000000</ele><time>2004-06-23T23:21:5.520Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760800000\" lon=\"-110.846266667\">
 <ele>1982.000000</ele><time>2004-06-23T23:21:34.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761466667\" lon=\"-110.845366667\">
 <ele>1975.000000</ele><time>2004-06-23T23:22:26.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761533333\" lon=\"-110.844266667\">
 <ele>1967.000000</ele><time>2004-06-23T23:23:0.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761383333\" lon=\"-110.843050000\">
 <ele>1970.000000</ele><time>2004-06-23T23:23:43.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760483333\" lon=\"-110.842316667\">
 <ele>1980.000000</ele><time>2004-06-23T23:24:32.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.759900000\" lon=\"-110.841900000\">
 <ele>2001.000000</ele><time>2004-06-23T23:25:4.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760550000\" lon=\"-110.841566667\">
 <ele>2027.000000</ele><time>2004-06-23T23:25:47.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761066667\" lon=\"-110.841133333\">
 <ele>2040.000000</ele><time>2004-06-23T23:26:23.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760016667\" lon=\"-110.840633333\">
 <ele>2060.000000</ele><time>2004-06-23T23:27:24.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.759183333\" lon=\"-110.840400000\">
 <ele>2077.000000</ele><time>2004-06-23T23:28:17.520Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758533333\" lon=\"-110.840333333\">
 <ele>2078.000000</ele><time>2004-06-23T23:28:51.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757916667\" lon=\"-110.839466667\">
 <ele>2088.000000</ele><time>2004-06-23T23:29:35.520Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757600000\" lon=\"-110.838883333\">
 <ele>2095.000000</ele><time>2004-06-23T23:30:8.520Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758783333\" lon=\"-110.839416667\">
 <ele>2105.000000</ele><time>2004-06-23T23:31:14.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.759633333\" lon=\"-110.839100000\">
 <ele>2106.000000</ele><time>2004-06-23T23:32:5.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758700000\" lon=\"-110.838750000\">
 <ele>2114.000000</ele><time>2004-06-23T23:32:59.530Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758066667\" lon=\"-110.837866667\">
 <ele>2128.000000</ele><time>2004-06-23T23:33:46.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757500000\" lon=\"-110.837216667\">
 <ele>2131.000000</ele><time>2004-06-23T23:34:26.540Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757933333\" lon=\"-110.836533333\">
 <ele>2127.000000</ele><time>2004-06-23T23:35:7.540Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758600000\" lon=\"-110.836600000\">
 <ele>2131.000000</ele><time>2004-06-23T23:35:37.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758183333\" lon=\"-110.835416667\">
 <ele>2138.000000</ele><time>2004-06-23T23:36:22.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758716667\" lon=\"-110.833650000\">
 <ele>2128.000000</ele><time>2004-06-23T23:37:13.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758666667\" lon=\"-110.832250000\">
 <ele>2129.000000</ele><time>2004-06-23T23:37:49.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.758166667\" lon=\"-110.830783333\">
 <ele>2133.000000</ele><time>2004-06-23T23:38:18.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757233333\" lon=\"-110.829900000\">
 <ele>2131.000000</ele><time>2004-06-23T23:38:42.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756816667\" lon=\"-110.829066667\">
 <ele>2136.000000</ele><time>2004-06-23T23:39:8.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756066667\" lon=\"-110.828216667\">
 <ele>2150.000000</ele><time>2004-06-23T23:40:1.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.755583333\" lon=\"-110.827416667\">
 <ele>2157.000000</ele><time>2004-06-23T23:40:35.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.754550000\" lon=\"-110.827033333\">
 <ele>2161.000000</ele><time>2004-06-23T23:41:25.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753900000\" lon=\"-110.826783333\">
 <ele>2159.000000</ele><time>2004-06-23T23:41:55.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752783333\" lon=\"-110.826616667\">
 <ele>2174.000000</ele><time>2004-06-23T23:42:51.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752050000\" lon=\"-110.826350000\">
 <ele>2185.000000</ele><time>2004-06-23T23:43:37.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753216667\" lon=\"-110.825816667\">
 <ele>2202.000000</ele><time>2004-06-23T23:44:49.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.754033333\" lon=\"-110.825266667\">
 <ele>2211.000000</ele><time>2004-06-23T23:45:39.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.754800000\" lon=\"-110.825266667\">
 <ele>2221.000000</ele><time>2004-06-23T23:46:19.550Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.755866667\" lon=\"-110.825166667\">
 <ele>2229.000000</ele><time>2004-06-23T23:47:17.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757050000\" lon=\"-110.825516667\">
 <ele>2241.000000</ele><time>2004-06-23T23:48:21.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756366667\" lon=\"-110.824716667\">
 <ele>2241.000000</ele><time>2004-06-23T23:49:25.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.755666667\" lon=\"-110.824300000\">
 <ele>2248.000000</ele><time>2004-06-23T23:50:4.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.754800000\" lon=\"-110.823733333\">
 <ele>2250.000000</ele><time>2004-06-23T23:50:50.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.755483333\" lon=\"-110.823583333\">
 <ele>2291.000000</ele><time>2004-06-23T23:52:10.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756266667\" lon=\"-110.823466667\">
 <ele>2297.000000</ele><time>2004-06-23T23:52:51.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757033333\" lon=\"-110.823100000\">
 <ele>2317.000000</ele><time>2004-06-23T23:53:36.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756050000\" lon=\"-110.822850000\">
 <ele>2325.000000</ele><time>2004-06-23T23:55:15.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756633333\" lon=\"-110.822250000\">
 <ele>2329.000000</ele><time>2004-06-23T23:55:56.570Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756966667\" lon=\"-110.821500000\">
 <ele>2336.000000</ele><time>2004-06-23T23:56:32.560Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.756066667\" lon=\"-110.821833333\">
 <ele>2347.000000</ele><time>2004-06-23T00:03:51.580Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.754533333\" lon=\"-110.821633333\">
 <ele>2348.000000</ele><time>2004-06-23T00:04:42.580Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753666667\" lon=\"-110.821000000\">
 <ele>2349.000000</ele><time>2004-06-23T00:05:12.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752966667\" lon=\"-110.819650000\">
 <ele>2344.000000</ele><time>2004-06-23T00:05:34.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753233333\" lon=\"-110.818400000\">
 <ele>2350.000000</ele><time>2004-06-23T00:06:0.580Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753450000\" lon=\"-110.816233333\">
 <ele>2351.000000</ele><time>2004-06-23T00:06:45.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753416667\" lon=\"-110.814366667\">
 <ele>2354.000000</ele><time>2004-06-23T00:07:24.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753833333\" lon=\"-110.811366667\">
 <ele>2343.000000</ele><time>2004-06-23T00:08:8.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.754116667\" lon=\"-110.808850000\">
 <ele>2333.000000</ele><time>2004-06-23T00:08:38.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753800000\" lon=\"-110.807050000\">
 <ele>2324.000000</ele><time>2004-06-23T00:09:0.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752900000\" lon=\"-110.806133333\">
 <ele>2314.000000</ele><time>2004-06-23T00:09:23.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753700000\" lon=\"-110.805216667\">
 <ele>2303.000000</ele><time>2004-06-23T00:09:45.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753300000\" lon=\"-110.803666667\">
 <ele>2297.000000</ele><time>2004-06-23T00:10:5.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752950000\" lon=\"-110.801733333\">
 <ele>2302.000000</ele><time>2004-06-23T00:10:36.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752550000\" lon=\"-110.799883333\">
 <ele>2307.000000</ele><time>2004-06-23T00:11:24.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752750000\" lon=\"-110.797683333\">
 <ele>2299.000000</ele><time>2004-06-23T00:12:1.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752383333\" lon=\"-110.796166667\">
 <ele>2300.000000</ele><time>2004-06-23T00:12:25.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.751566667\" lon=\"-110.795950000\">
 <ele>2305.000000</ele><time>2004-06-23T00:12:54.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.750666667\" lon=\"-110.795183333\">
 <ele>2309.000000</ele><time>2004-06-23T00:13:34.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.751350000\" lon=\"-110.794400000\">
 <ele>2320.000000</ele><time>2004-06-23T00:14:16.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.750766667\" lon=\"-110.793383333\">
 <ele>2322.000000</ele><time>2004-06-23T00:15:3.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.750550000\" lon=\"-110.791700000\">
 <ele>2330.000000</ele><time>2004-06-23T00:15:53.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.749266667\" lon=\"-110.790733333\">
 <ele>2334.000000</ele><time>2004-06-23T00:17:11.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.748583333\" lon=\"-110.789883333\">
 <ele>2358.000000</ele><time>2004-06-23T00:17:56.590Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.749616667\" lon=\"-110.789866667\">
 <ele>2377.000000</ele><time>2004-06-23T00:19:36.600Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.750033333\" lon=\"-110.788883333\">
 <ele>2384.000000</ele><time>2004-06-23T00:20:59.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.750616667\" lon=\"-110.786466667\">
 <ele>2380.000000</ele><time>2004-06-23T00:21:46.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.751033333\" lon=\"-110.785483333\">
 <ele>2378.000000</ele><time>2004-06-23T00:22:16.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.751700000\" lon=\"-110.785183333\">
 <ele>2378.000000</ele><time>2004-06-23T00:22:43.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.751966667\" lon=\"-110.784116667\">
 <ele>2374.000000</ele><time>2004-06-23T00:23:13.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752550000\" lon=\"-110.783500000\">
 <ele>2378.000000</ele><time>2004-06-23T00:23:50.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.752683333\" lon=\"-110.782616667\">
 <ele>2378.000000</ele><time>2004-06-23T00:24:21.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.753200000\" lon=\"-110.781783333\">
 <ele>2403.000000</ele><time>2004-06-23T00:24:46.120Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.754316667\" lon=\"-110.780183333\">
 <ele>2399.000000</ele><time>2004-06-23T00:25:40.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.755816667\" lon=\"-110.779533333\">
 <ele>2397.000000</ele><time>2004-06-23T00:26:27.140Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.757283333\" lon=\"-110.779733333\">
 <ele>2392.000000</ele><time>2004-06-23T00:26:59.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.759333333\" lon=\"-110.778683333\">
 <ele>2393.000000</ele><time>2004-06-23T00:27:45.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760800000\" lon=\"-110.778166667\">
 <ele>2382.000000</ele><time>2004-06-23T00:33:17.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.762216667\" lon=\"-110.778316667\">
 <ele>2377.000000</ele><time>2004-06-23T00:33:44.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.763266667\" lon=\"-110.779116667\">
 <ele>2374.000000</ele><time>2004-06-23T00:34:1.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.764033333\" lon=\"-110.778750000\">
 <ele>2366.000000</ele><time>2004-06-23T00:34:33.640Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.765300000\" lon=\"-110.779766667\">
 <ele>2356.000000</ele><time>2004-06-23T00:34:57.610Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.766516667\" lon=\"-110.780966667\">
 <ele>2349.000000</ele><time>2004-06-23T00:35:19.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.766500000\" lon=\"-110.783250000\">
 <ele>2349.000000</ele><time>2004-06-23T00:35:44.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.767133333\" lon=\"-110.784833333\">
 <ele>2348.000000</ele><time>2004-06-23T00:36:7.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.767850000\" lon=\"-110.784583333\">
 <ele>2354.000000</ele><time>2004-06-23T00:36:27.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.768800000\" lon=\"-110.783300000\">
 <ele>2353.000000</ele><time>2004-06-23T00:36:58.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.770583333\" lon=\"-110.782916667\">
 <ele>2345.000000</ele><time>2004-06-23T00:37:33.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.771866667\" lon=\"-110.782516667\">
 <ele>2334.000000</ele><time>2004-06-23T00:37:54.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.772650000\" lon=\"-110.781516667\">
 <ele>2334.000000</ele><time>2004-06-23T00:38:13.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.773400000\" lon=\"-110.781466667\">
 <ele>2338.000000</ele><time>2004-06-23T00:38:35.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.774400000\" lon=\"-110.781733333\">
 <ele>2342.000000</ele><time>2004-06-23T00:39:15.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.775266667\" lon=\"-110.780800000\">
 <ele>2351.000000</ele><time>2004-06-23T00:39:56.620Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.776050000\" lon=\"-110.781400000\">
 <ele>2354.000000</ele><time>2004-06-23T00:40:29.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.776783333\" lon=\"-110.783700000\">
 <ele>2356.000000</ele><time>2004-06-23T00:41:16.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.777516667\" lon=\"-110.784916667\">
 <ele>2353.000000</ele><time>2004-06-23T00:41:40.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.779200000\" lon=\"-110.782583333\">
 <ele>2351.000000</ele><time>2004-06-23T00:42:26.640Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.779933333\" lon=\"-110.781783333\">
 <ele>2333.000000</ele><time>2004-06-23T00:42:47.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.780416667\" lon=\"-110.780733333\">
 <ele>2339.000000</ele><time>2004-06-23T00:43:28.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.781750000\" lon=\"-110.780783333\">
 <ele>2342.000000</ele><time>2004-06-23T00:44:5.640Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.782333333\" lon=\"-110.779650000\">
 <ele>2346.000000</ele><time>2004-06-23T00:44:37.630Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.782283333\" lon=\"-110.777316667\">
 <ele>2341.000000</ele><time>2004-06-23T00:45:19.650Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.783700000\" lon=\"-110.775350000\">
 <ele>2335.000000</ele><time>2004-06-23T00:55:8.650Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.784166667\" lon=\"-110.774583333\">
 <ele>2339.000000</ele><time>2004-06-23T00:55:27.650Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.784700000\" lon=\"-110.775916667\">
 <ele>2351.000000</ele><time>2004-06-23T00:56:23.660Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.785233333\" lon=\"-110.774666667\">
 <ele>2360.000000</ele><time>2004-06-23T00:57:23.650Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.785400000\" lon=\"-110.775633333\">
 <ele>2364.000000</ele><time>2004-06-23T00:58:13.650Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.785716667\" lon=\"-110.777200000\">
 <ele>2369.000000</ele><time>2004-06-23T00:59:2.660Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.785400000\" lon=\"-110.780116667\">
 <ele>2379.000000</ele><time>2004-06-23T01:00:5.170Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.785583333\" lon=\"-110.780883333\">
 <ele>2369.000000</ele><time>2004-06-23T01:00:39.660Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.785766667\" lon=\"-110.782200000\">
 <ele>2371.000000</ele><time>2004-06-23T01:01:20.660Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.786166667\" lon=\"-110.783900000\">
 <ele>2375.000000</ele><time>2004-06-23T01:02:15.190Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.788466667\" lon=\"-110.786516667\">
 <ele>2413.000000</ele><time>2004-06-23T01:03:16.660Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.791966667\" lon=\"-110.792000000\">
 <ele>2423.000000</ele><time>2004-06-23T01:08:33.670Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.793683333\" lon=\"-110.793700000\">
 <ele>2425.000000</ele><time>2004-06-23T01:09:7.680Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.793833333\" lon=\"-110.795966667\">
 <ele>2425.000000</ele><time>2004-06-23T01:09:31.680Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.796366667\" lon=\"-110.790300000\">
 <ele>2425.000000</ele><time>2004-06-23T01:11:8.680Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.797866667\" lon=\"-110.791433333\">
 <ele>2425.000000</ele><time>2004-06-23T01:12:13.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.798183333\" lon=\"-110.793600000\">
 <ele>2425.000000</ele><time>2004-06-23T01:12:38.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.798166667\" lon=\"-110.796233333\">
 <ele>2425.000000</ele><time>2004-06-23T01:13:10.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.797983333\" lon=\"-110.799550000\">
 <ele>2425.000000</ele><time>2004-06-23T01:13:43.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.798983333\" lon=\"-110.800300000\">
 <ele>2425.000000</ele><time>2004-06-23T01:14:29.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.799433333\" lon=\"-110.799533333\">
 <ele>2425.000000</ele><time>2004-06-23T01:14:54.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.799816667\" lon=\"-110.798750000\">
 <ele>2288.000000</ele><time>2004-06-23T01:17:1.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.800166667\" lon=\"-110.798150000\">
 <ele>2291.000000</ele><time>2004-06-23T01:19:38.680Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.801283333\" lon=\"-110.799966667\">
 <ele>2291.000000</ele><time>2004-06-23T01:20:22.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.801850000\" lon=\"-110.801816667\">
 <ele>2247.000000</ele><time>2004-06-23T01:21:1.220Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.802016667\" lon=\"-110.804366667\">
 <ele>2254.000000</ele><time>2004-06-23T01:21:44.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.801750000\" lon=\"-110.805850000\">
 <ele>2251.000000</ele><time>2004-06-23T01:22:14.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.802633333\" lon=\"-110.806350000\">
 <ele>2257.000000</ele><time>2004-06-23T01:22:35.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.802883333\" lon=\"-110.807916667\">
 <ele>2261.000000</ele><time>2004-06-23T01:23:8.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.802816667\" lon=\"-110.810133333\">
 <ele>2262.000000</ele><time>2004-06-23T01:23:48.680Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.804083333\" lon=\"-110.811833333\">
 <ele>2265.000000</ele><time>2004-06-23T01:24:38.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.804800000\" lon=\"-110.812016667\">
 <ele>2243.000000</ele><time>2004-06-23T01:25:0.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.805800000\" lon=\"-110.811633333\">
 <ele>2264.000000</ele><time>2004-06-23T01:25:29.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.807850000\" lon=\"-110.811783333\">
 <ele>2269.000000</ele><time>2004-06-23T01:26:11.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.808366667\" lon=\"-110.812050000\">
 <ele>2240.000000</ele><time>2004-06-23T01:26:27.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.807816667\" lon=\"-110.815533333\">
 <ele>2252.000000</ele><time>2004-06-23T01:27:19.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.807650000\" lon=\"-110.818116667\">
 <ele>2245.000000</ele><time>2004-06-23T01:27:53.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.807116667\" lon=\"-110.820316667\">
 <ele>2243.000000</ele><time>2004-06-23T01:28:23.690Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.806950000\" lon=\"-110.821883333\">
 <ele>2243.000000</ele><time>2004-06-23T01:28:49.700Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.806133333\" lon=\"-110.822500000\">
 <ele>2227.000000</ele><time>2004-06-23T01:32:47.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.806833333\" lon=\"-110.823183333\">
 <ele>2220.000000</ele><time>2004-06-23T01:35:32.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.806533333\" lon=\"-110.824283333\">
 <ele>2213.000000</ele><time>2004-06-23T01:35:48.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.808083333\" lon=\"-110.824450000\">
 <ele>2214.000000</ele><time>2004-06-23T01:36:32.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.808600000\" lon=\"-110.825350000\">
 <ele>2226.000000</ele><time>2004-06-23T01:37:5.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.809383333\" lon=\"-110.825783333\">
 <ele>2226.000000</ele><time>2004-06-23T01:37:33.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.812416667\" lon=\"-110.826316667\">
 <ele>2215.000000</ele><time>2004-06-23T01:38:41.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.814150000\" lon=\"-110.826533333\">
 <ele>2217.000000</ele><time>2004-06-23T01:39:7.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.813950000\" lon=\"-110.828766667\">
 <ele>2219.000000</ele><time>2004-06-23T01:39:36.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.815333333\" lon=\"-110.827300000\">
 <ele>2188.000000</ele><time>2004-06-23T01:39:58.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.816500000\" lon=\"-110.826183333\">
 <ele>2177.000000</ele><time>2004-06-23T01:40:16.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.817266667\" lon=\"-110.826216667\">
 <ele>2176.000000</ele><time>2004-06-23T01:40:43.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.816700000\" lon=\"-110.828050000\">
 <ele>2166.000000</ele><time>2004-06-23T01:41:21.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.816516667\" lon=\"-110.829300000\">
 <ele>2160.000000</ele><time>2004-06-23T01:41:40.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.815900000\" lon=\"-110.831066667\">
 <ele>2155.000000</ele><time>2004-06-23T01:42:2.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.816850000\" lon=\"-110.831916667\">
 <ele>2154.000000</ele><time>2004-06-23T01:42:28.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.817700000\" lon=\"-110.833266667\">
 <ele>2146.000000</ele><time>2004-06-23T01:42:53.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818733333\" lon=\"-110.833833333\">
 <ele>2145.000000</ele><time>2004-06-23T01:43:15.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818683333\" lon=\"-110.835600000\">
 <ele>2136.000000</ele><time>2004-06-23T01:43:46.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.817983333\" lon=\"-110.836450000\">
 <ele>2141.000000</ele><time>2004-06-23T01:44:8.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818266667\" lon=\"-110.837316667\">
 <ele>2141.000000</ele><time>2004-06-23T01:44:23.710Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.817750000\" lon=\"-110.838150000\">
 <ele>2143.000000</ele><time>2004-06-23T01:44:50.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818333333\" lon=\"-110.840116667\">
 <ele>2141.000000</ele><time>2004-06-23T01:45:35.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818750000\" lon=\"-110.842166667\">
 <ele>2140.000000</ele><time>2004-06-23T01:46:4.720Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818433333\" lon=\"-110.843500000\">
 <ele>2141.000000</ele><time>2004-06-23T01:46:37.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818200000\" lon=\"-110.846066667\">
 <ele>2141.000000</ele><time>2004-06-23T01:47:35.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.817800000\" lon=\"-110.847800000\">
 <ele>2141.000000</ele><time>2004-06-23T01:48:5.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.817766667\" lon=\"-110.849350000\">
 <ele>2135.000000</ele><time>2004-06-23T01:48:29.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.818683333\" lon=\"-110.850816667\">
 <ele>2134.000000</ele><time>2004-06-23T01:48:50.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.819333333\" lon=\"-110.851100000\">
 <ele>2139.000000</ele><time>2004-06-23T01:49:22.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.819333333\" lon=\"-110.851950000\">
 <ele>2144.000000</ele><time>2004-06-23T01:49:58.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.820800000\" lon=\"-110.851950000\">
 <ele>2147.000000</ele><time>2004-06-23T01:50:53.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.821666667\" lon=\"-110.852100000\">
 <ele>2145.000000</ele><time>2004-06-23T01:51:18.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.821950000\" lon=\"-110.853083333\">
 <ele>2146.000000</ele><time>2004-06-23T01:51:37.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.821883333\" lon=\"-110.853966667\">
 <ele>2156.000000</ele><time>2004-06-23T01:52:12.750Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.822333333\" lon=\"-110.854583333\">
 <ele>2165.000000</ele><time>2004-06-23T01:52:57.730Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.822566667\" lon=\"-110.855616667\">
 <ele>2166.000000</ele><time>2004-06-23T01:53:53.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.823600000\" lon=\"-110.856183333\">
 <ele>2171.000000</ele><time>2004-06-23T01:54:58.750Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.824900000\" lon=\"-110.856716667\">
 <ele>2186.000000</ele><time>2004-06-23T01:56:17.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.825000000\" lon=\"-110.857883333\">
 <ele>2194.000000</ele><time>2004-06-23T01:57:0.740Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.826483333\" lon=\"-110.858983333\">
 <ele>2194.000000</ele><time>2004-06-23T01:57:38.750Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.827783333\" lon=\"-110.859450000\">
 <ele>2210.000000</ele><time>2004-06-23T01:58:19.750Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.828383333\" lon=\"-110.860133333\">
 <ele>2217.000000</ele><time>2004-06-23T01:59:2.750Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.829366667\" lon=\"-110.860200000\">
 <ele>2225.000000</ele><time>2004-06-23T01:59:46.750Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.829816667\" lon=\"-110.860383333\">
 <ele>2225.000000</ele><time>2004-06-23T02:00:59.760Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.831416667\" lon=\"-110.860766667\">
 <ele>2251.000000</ele><time>2004-06-23T02:11:16.770Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.832600000\" lon=\"-110.860700000\">
 <ele>2246.000000</ele><time>2004-06-23T02:11:35.770Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.834583333\" lon=\"-110.860000000\">
 <ele>2246.000000</ele><time>2004-06-23T02:12:13.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.836116667\" lon=\"-110.859883333\">
 <ele>2243.000000</ele><time>2004-06-23T02:12:45.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.836866667\" lon=\"-110.859383333\">
 <ele>2237.000000</ele><time>2004-06-23T02:13:7.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.837850000\" lon=\"-110.859516667\">
 <ele>2215.000000</ele><time>2004-06-23T02:13:44.770Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.839400000\" lon=\"-110.859250000\">
 <ele>2202.000000</ele><time>2004-06-23T02:14:6.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.840800000\" lon=\"-110.859200000\">
 <ele>2199.000000</ele><time>2004-06-23T02:14:36.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.841316667\" lon=\"-110.860283333\">
 <ele>2187.000000</ele><time>2004-06-23T02:14:58.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.842366667\" lon=\"-110.861350000\">
 <ele>2161.000000</ele><time>2004-06-23T02:15:32.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.843383333\" lon=\"-110.861600000\">
 <ele>2146.000000</ele><time>2004-06-23T02:15:54.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.844816667\" lon=\"-110.861783333\">
 <ele>2137.000000</ele><time>2004-06-23T02:16:23.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.845700000\" lon=\"-110.862083333\">
 <ele>2134.000000</ele><time>2004-06-23T02:16:41.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.846766667\" lon=\"-110.862200000\">
 <ele>2119.000000</ele><time>2004-06-23T02:17:8.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.846000000\" lon=\"-110.863366667\">
 <ele>2108.000000</ele><time>2004-06-23T02:17:28.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.846650000\" lon=\"-110.865133333\">
 <ele>2097.000000</ele><time>2004-06-23T02:18:23.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.847283333\" lon=\"-110.866266667\">
 <ele>2095.000000</ele><time>2004-06-23T02:18:51.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.848033333\" lon=\"-110.868216667\">
 <ele>2097.000000</ele><time>2004-06-23T02:19:25.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.848416667\" lon=\"-110.869800000\">
 <ele>2087.000000</ele><time>2004-06-23T02:19:48.330Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.848333333\" lon=\"-110.871100000\">
 <ele>2077.000000</ele><time>2004-06-23T02:20:3.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.849600000\" lon=\"-110.872416667\">
 <ele>2053.000000</ele><time>2004-06-23T02:21:5.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.848166667\" lon=\"-110.872866667\">
 <ele>2049.000000</ele><time>2004-06-23T02:21:30.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.846650000\" lon=\"-110.871750000\">
 <ele>2039.000000</ele><time>2004-06-23T02:22:3.780Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.846733333\" lon=\"-110.873500000\">
 <ele>1990.000000</ele><time>2004-06-23T02:22:53.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.846833333\" lon=\"-110.875050000\">
 <ele>1981.000000</ele><time>2004-06-23T02:23:12.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.848250000\" lon=\"-110.875416667\">
 <ele>1964.000000</ele><time>2004-06-23T02:23:48.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.849183333\" lon=\"-110.877333333\">
 <ele>1949.000000</ele><time>2004-06-23T02:24:30.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.849966667\" lon=\"-110.877700000\">
 <ele>1954.000000</ele><time>2004-06-23T02:25:1.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.850850000\" lon=\"-110.876833333\">
 <ele>1946.000000</ele><time>2004-06-23T02:25:26.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.851600000\" lon=\"-110.877100000\">
 <ele>1943.000000</ele><time>2004-06-23T02:25:47.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.852166667\" lon=\"-110.877516667\">
 <ele>1932.000000</ele><time>2004-06-23T02:28:10.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.852466667\" lon=\"-110.878933333\">
 <ele>1912.000000</ele><time>2004-06-23T02:28:58.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.852783333\" lon=\"-110.880700000\">
 <ele>1900.000000</ele><time>2004-06-23T02:29:19.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.853900000\" lon=\"-110.881133333\">
 <ele>1894.000000</ele><time>2004-06-23T02:29:37.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.854966667\" lon=\"-110.881083333\">
 <ele>1882.000000</ele><time>2004-06-23T02:29:54.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.854966667\" lon=\"-110.879933333\">
 <ele>1864.000000</ele><time>2004-06-23T02:30:27.790Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.856466667\" lon=\"-110.880700000\">
 <ele>1844.000000</ele><time>2004-06-23T02:30:52.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.857150000\" lon=\"-110.880866667\">
 <ele>1818.000000</ele><time>2004-06-23T02:31:35.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.857416667\" lon=\"-110.880166667\">
 <ele>1791.000000</ele><time>2004-06-23T02:32:35.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.858166667\" lon=\"-110.878916667\">
 <ele>1784.000000</ele><time>2004-06-23T02:33:7.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.858800000\" lon=\"-110.880000000\">
 <ele>1779.000000</ele><time>2004-06-23T02:33:50.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.858383333\" lon=\"-110.881250000\">
 <ele>1780.000000</ele><time>2004-06-23T02:34:23.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.856250000\" lon=\"-110.882966667\">
 <ele>1786.000000</ele><time>2004-06-23T02:35:32.800Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.855000000\" lon=\"-110.883533333\">
 <ele>1792.000000</ele><time>2004-06-23T02:36:8.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.853150000\" lon=\"-110.883216667\">
 <ele>1796.000000</ele><time>2004-06-23T02:37:1.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.851700000\" lon=\"-110.883300000\">
 <ele>1804.000000</ele><time>2004-06-23T02:37:43.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.850266667\" lon=\"-110.882733333\">
 <ele>1809.000000</ele><time>2004-06-23T02:38:23.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.847333333\" lon=\"-110.883000000\">
 <ele>1821.000000</ele><time>2004-06-23T02:39:38.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.841900000\" lon=\"-110.881666667\">
 <ele>1843.000000</ele><time>2004-06-23T02:41:56.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.840533333\" lon=\"-110.882116667\">
 <ele>1849.000000</ele><time>2004-06-23T02:42:32.810Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.838116667\" lon=\"-110.884000000\">
 <ele>1865.000000</ele><time>2004-06-23T02:43:44.820Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.835633333\" lon=\"-110.884150000\">
 <ele>1877.000000</ele><time>2004-06-23T02:44:38.820Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.834166667\" lon=\"-110.883250000\">
 <ele>1878.000000</ele><time>2004-06-23T02:45:7.820Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.828600000\" lon=\"-110.883033333\">
 <ele>1859.000000</ele><time>2004-06-23T02:46:7.820Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.825383333\" lon=\"-110.885166667\">
 <ele>1850.000000</ele><time>2004-06-23T02:46:37.820Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.822450000\" lon=\"-110.885533333\">
 <ele>1835.000000</ele><time>2004-06-23T02:47:1.830Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.819183333\" lon=\"-110.883416667\">
 <ele>1818.000000</ele><time>2004-06-23T02:47:28.830Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.810000000\" lon=\"-110.883950000\">
 <ele>1819.000000</ele><time>2004-06-23T02:49:3.820Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.807183333\" lon=\"-110.881550000\">
 <ele>1802.000000</ele><time>2004-06-23T02:49:33.830Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.793683333\" lon=\"-110.881683333\">
 <ele>1741.000000</ele><time>2004-06-23T02:51:19.830Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.790750000\" lon=\"-110.883066667\">
 <ele>1730.000000</ele><time>2004-06-23T02:51:48.840Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.787766667\" lon=\"-110.882350000\">
 <ele>1731.000000</ele><time>2004-06-23T02:52:19.830Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.782466667\" lon=\"-110.878300000\">
 <ele>1714.000000</ele><time>2004-06-23T02:53:27.840Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.776933333\" lon=\"-110.877733333\">
 <ele>1702.000000</ele><time>2004-06-23T02:54:27.840Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.774216667\" lon=\"-110.877783333\">
 <ele>1699.000000</ele><time>2004-06-23T02:55:6.840Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.772300000\" lon=\"-110.878483333\">
 <ele>1694.000000</ele><time>2004-06-23T02:55:31.840Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.767366667\" lon=\"-110.878183333\">
 <ele>1688.000000</ele><time>2004-06-23T02:56:36.840Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.761200000\" lon=\"-110.875983333\">
 <ele>1672.000000</ele><time>2004-06-23T02:58:13.840Z</time>
 <type>Trackpoint</type>
</trkpt>
<trkpt lat=\"45.760950000\" lon=\"-110.874950000\">
 <ele>1672.000000</ele><time>2004-06-23T03:00:50.840Z</time>
 <type>Trackpoint</type>
</trkpt>
</trkseg>
</trk>
<extensions>
<topografix:active_point lat=\"45.804971\" lon=\"-110.849028\"/>
</extensions>
</gpx>\
\>", "Print",
  CellLabel->"From In[68]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(GPX\ files\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "I have written a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package, or collection of commands, that does some of the processing I am \
typically interested in for these files.  "
}], "Text"],

Cell["\<\
Load a package of commands I have put together for analyzing data \
collected from a GPS device.\
\>", "MathCaption"],

Cell[BoxData[
    \(Needs["\<GPXTrack`\>"]\)], "Input",
  CellLabel->"In[18]:="],

Cell["Import the GPS tracks as Symbolic XML.", "MathCaption"],

Cell[BoxData[
    \(\(tracks\  = \ GetTracks["\<Bangtail.gpx\>"];\)\)], "Input",
  CellLabel->"In[19]:="],

Cell["\<\
Using pattern matching, it is possible to extract the data from the \
symbolic XML.  The package contains a command that gives a summary.\
\>", \
"Text"],

Cell["This gives a quick summary of the track.", "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnalyzeTrack[First[tracks], \ Units -> "\<Metric\>"]\)], "Input",
  CellLabel->"In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.031746 0.31746 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.031746 0.34127 0.349206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
F9FAFEFEFFFFF1F2EAD9DCCBD8DCC5F5F9DEEAEED3EAEED5FFFFF1FBFDF0FFFFFBFFFFFD
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFCFBFAF8FFFFFDFFFFFDFAF9F7FFFFFDFDFCFA
FDFCFAFFFFFDFFFFFDF9F8F6FFFFFDFFFFFDFFFFFDFBF7F6CFC7C5FFFBF9FFFCFDF8F4F3
FFFDFCFFFFFDFAFAFAFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFEFF
F9F8F4FFFDFAF3DADEFFEDF2FFF8FEFFFBFCFBFFFFFBFFFFFFFCFFFFFDFFFFFFFFF5FBF7
F8FFFDF8FAF5FFFAFAE7D1D3F8EEEFFFFEFDB1ADAAC1BDBAFFFDFAFFF8F5FFFDF7FFFEF8
EEE7E1D7D2CCD5D0CCEDECE7FFFFFBFDFFFAFCFEFBFCFFFAFFFFF6FCFFF4FEFFFDFBFFFA
627056D0E5BCCAE0AFD3EABCD4E7C9CCDEC4D9E9C5CBDBAAD5E5A4DEEBA3DBE5A68E9859
6F8039CBE196D4EAA2CFE9A0C7E09CCAE8A2CBE8A5CAE9A5D6F5B1C1E09CC8E39ED2EDA6
C9E09ACFE79D7C9048CBDB94D5DB9BB6BA7D8D9154879051DDE9A7DBECA8C4D994D7F1AA
D0ECA2C0E095C7E79CCCEEA2BEE395C0E597C9F0A1C6E89BCDE7A0D1E6A1CAE19BD0E7A1
4B621C8BA25CCAE49DCAE49DD3EDA6C0DA93D1E8A2AEC57FA8BF79D5ECA6D0E5A0CBE399
DDF5A7C1DC8FD8F2B3C6E0A3CEE5A1475D158D9A55D9E1A89C97790D0500312A0EA9A77E
CED496D3E39CCEE3A2D0E7A3D8EDA28C9E54ACBD79E4F3B8CAD6A8D6E0BBFCFFE6F9FFE7
F9FFE8F9FFE6F9FFE1E3F7C4CDE5A9BDDB93CDEC9ED4F0A3CFDE9DD6E2A4E0EEB08DA15C
839752CDE59BD1E99FC7E295D5F0A3C7E396CCE89DCDEDA1BEDE95D6FAB0BEE49BC5E79D
A9C07AC5D992DDF1AACBE29AC8DF99CDE8A1BFDA93D7F5AD
FEFFFFFAFCFBFFFFF8F4F7E6A6AA93B9BDA2E7EBD0F1F5DCECEFDEFFFFF4FFFFFBECECEA
FEFEFFFFFFFFF1EFF2FFFEFFFBFAF8FFFFFDFFFFFDFFFFFDFFFFFDEBEAE8FFFFFDFFFFFD
FFFFFDFEFDFBFDFCFAFAF9F7FFFFFDFDFCFAFFFEFCFFFEFDD0C8C6FFFAF8FFFCFDFDF9F8
FFFEFDFFFFFDFAFAFAFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFEFF
F8F7F3FFFDFAF3DADEFFF0F5FFF9FFFFFEFFFBFFFFF8FEFEFFFDFFFFFDFFFFFFFFF5FBF7
F8FFFDF4F6F1FFF8F8E1CBCDFFFCFDFFFEFDFFFEFBFEFAF7D7D2CFF5EDEAF7EFEC736C66
B9B1AEBEB9B5D9D6D1FEFDF8FFFFFBFEFFFBF3F8F4F1F3EEFFFFF6FCFDF5FEFFFFFBFFFB
606E55D3E5BFCBE1B2D5EABFEEFFE6F2FFEAF8FFE6E0EDBFD0DF9ED0DB96D4DD9E9BA566
8FA059D1E79CC8DF97C8E29BCBE6A1D2EFACC9E8A4C4E39FBFDE9BD1F0ACCEEBA8D4EFAA
CCE69FCFE79D97AD64A3B46D939C5B9EA4669BA465A0AA6B6F7E3BC5D692D9EEA9C3DD96
CCE89EC6E49ACBEBA0D0F2A6CDEFA2CAEFA1CAEFA1C6E89BCEE8A1CDE29DD8EFA990A761
C6DD97EFFFC2BAD48DD2ECA5C7E19ADBF5AED2E9A37A914B79904AC7DE98D6EBA6D9F0A8
BCD486D5F0A3C3DD9ECAE4A7D7EEAACDE39BB9C68198A0679893750800005A5336221F00
E2E8AAD5E29DDBF0AFD1E6A5CADE97D4E59FB4C48587965DACB88AE0EBC3F4FEDCE5EECF
E0EBCBE3F1CDD6E5BACEE2ADE3FBBDD0EEA6C9E89AD0EAA0D8E6A8D5DEA5C8D69997AA6A
8FA461D1E8A0C6E096D2ECA2BED68AD8F0A4D2ECA2D5F1A7C8E69EC8E9A2B8DC94CFF0A9
D5ECA661752E8FA55DDBF1A9D5ECA6D3EDA6DBF6AFB9D78F
FCFFFFF5F9F8FEFFF8FEFFF1BCC1AA9DA387BABEA3F2F6DDFFFFF1FFFFF4F7F6F2FFFFFD
F9F7FAFFFDFFF9F4F8FFFEFFFFFEFDFFFEFBF4F0EDD1CDCAE5E1DEC9C5C2ECE8E5FBF7F4
FDF9F6FFFEFBFFFEFBFFFDFAFEFAF7FFFEFBFFFDFAFFFEFBD0C8C6FBF3F1FFFCFDFFFBFA
FFFEFDFFFFFDFBFBFBFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFEFF
FDFCF8FFFDFAEBD2D6FFE9EEFFF9FFFFFEFFFBFFFFF9FFFFFFFAFEFFFBFFFFFFFFF9FFFB
F7FFFCFEFFFBFFFAFAE7D1D3FEF5F6F9F8F6FFFEFDFFFEFBEDE8E5DBD6D3E3DBD9FFFDFA
FFFBF8FFFAF7FFFBF8FFFFFBFEFEFCFBFDFAFCFFFDFEFFFBFFFFF8FCFDF7FEFFFFFBFFFE
66725EDEEDCEDAECC4E3F4D0F7FFF3F8FFF4FBFFECE7F2C8E0EAADE5ECA9D8DCA19DA569
8E9F59CCE297CDE49CD2ECA5CEE9A4CDEAA7C5E4A1D3F2AFC0DE9ED2F1AEBFDC99C9E49F
D0EAA3D1E99FD7EDA4C0D48CA1B06DD2DE9EE3EFAFB8C786223300829651D7ECA7D1EBA4
C6E298CBE99FC9E79DC5E59AC7E79BC4E699C1E396C6E69AD0EAA3CDE29DCBE29C8CA35D
C1DB94C2DC95D7F1AAC6E19AC4DF98BDD891DCF6AFAEC881768D4796AD67BCD18CCAE199
E1F9ABD2ECA2C9E3A4BFD99CE1F8B2C6DC93C4D18B9EA66B423D1D1B1300958C6F504D22
6E7235D6E19DD1E1A2BCCE90CFDFA1DFEFB1C5D49B9DAB76BFCB9DADB88EC2CDA5FCFFE1
D7E3BBD4E3B8DAEAB9D6EBB2C4DD9CC4E29AC7E69AC5DF98D7E2AAD9E1AED0DDA7A6B87E
B2C888CFE8A4C6E099D7EEA6DCF2A9D3E79FC4D891CFE59DC7DE98D1ECA7D3F4AFCDECA8
CAE19B6A7E37859B53BCD28AD7EEA8BFD992D0EBA4D9F4AD
FCFFFFFAFEFDF8FBF2FEFFF1D7DCC5BBC1A5A3A78CA3A78EFFFFF1F5F7EAF5F4F0FFFFFD
F8F6F9FFFEFFFFFDFFFFFEFFFFFDFCFFFEFBE8E4E1DFDBD8FFFDFAE7E3E0E1DDDADEDAD7
EDE9E6FFFBF8FFFEFBFFFEFBF9F5F2FFFEFBFDF9F6EBE6E3D5CDCBF5EDEBFFF9FAFEFAF9
FFFEFDFFFFFDFEFEFEFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFEFF
FFFFFBFFFDFADEC5C9F6DBE0FFF1F7FFFBFCFCFFFFFBFFFFFFFBFFFCF7FBFFFFFFFBFFFD
F6FFFBFEFFFBFFFAFAE3CDCFFFFCFDFFFFFDFEFAF9FFFEFDFFF9F9FFFBF8FFFCFDFFFDFB
FFFDFDFFFEFBFFFEFDFFFFFDFDFDFBFEFFFDFCFFFDFEFFFBFFFFF7FCFBF7FFFEFFFEFFFF
71796AEFFCE2EFFEDDF7FFE9F9FFF8F7FFF6F9FFECE0E6C2D3D8A0CACF8F999A61555B1F
A3B46ED1E99DD0EAA0D2EDA6CBE6A1C8E5A3C7E5A5ECFFCAF1FFCFD5F3B3BEDB99C9E7A1
D3EDA6BDD78DE0F8ACD4EAA1C4D893CEDE9DD3E6A4CDE09ECADE99DBF0ABD0E7A1869D57
A3BD74C3DF95CEEAA0CAE89ECEEDA1C8E89CC4E498D1F0A4D7EEA8C9DE99D9F0AACFE6A0
D0EAA3D0EBA4D3EEA7D9F4ADF4FFC8D4EFA8C4DE97C8E29BD4EBA5A7BE786B803B798F47
B9D183CCE69CCDE7A8D6F0B3C1DB94DBF1A8DBEBA4CFD79C969372090200716849A09B71
4A4B0F8E9754DBE9ABD9E8AFD3E1ACCEDCA9D3E1AEC5D3A2EEFACCF0FCCED7E3B598A476
DBE9B8BECF9BCDDEA7CBE1A3D8F1AFC6E49CCEECA2DBF4B2E6F0BED9DFB3C0CC9C8FA26B
C7DFA3CDE7A6CEE7A3C9E09AD5E6A0CCD994D5E29DD9E5A3D0E3A1D3E9A8C2DF9DC0DD9A
DAF1ABD1E59EB4CA828CA25AD1E8A2CAE19BC6E099CAE59E
FCFFFFF6FAF9FCFFF8FAFFEFBDC2ABDAE0C4C4C8AD5F634AB6B9A8FFFFF4FFFFFBF5F4F2
FFFBFFFFFDFFFAF5F9FDF9FAF8F4F3FFFDFADDD9D6F4F0EDFFFEFBFFFEFBF2EEEBF0ECE9
ECE8E5EEEAE7F7F3F0FFFEFBFBF7F4EEEAE7F5F1EEE7E2DFE9E1DFFAF2F0FFF9FAFFFBFA
FFFEFDFFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFEFF
FFFFFBFFFDFAD9C0C4F3D8DDFFF1F7FFFBFCFCFFFFFBFFFFFFFDFFFEF9FDFDFDFDFBFFFD
F3FEF8FEFFFBF3E1E1D2BCBEFFF8F9FFFFFDE9E8E6FFFEFDFEF8F8FFFCFCFFFDFFF1EBEB
F5EFF1FCF8F7FFFEFFFFFFFDFFFFFDFEFFFDFBFFFCF5F7F2FFFFFAFFFCF9FFFDFFFFFEFF
787E74FBFFEFFBFFEAF9FFEDF0F7F0F8FDF9FFFFF3F5F8D9E4E7B2E0E0A4A6A36E73763D
D6E7A0DEF9ACC8E298C4DF98C7E29FCFECAACBE8A8F2FFD1F2FFD1C0DD9DC8E5A3CEEBA8
D9F3ACC0DA90CCE79ACFE79BD2E9A3D5ECA8D5ECA8C1D894DFF6B0C1D892D1E8A2B3CA84
657F369EB86FC4DE95CDE99FD3EFA4CBEA9EC6E599D2EEA3C5DA95E0F5B0647B3592A963
E4FEB7BFDA93C2DD96EAFFC0F2FFC8C3E199C8E39CD9F3ACCDE49EC8DF99ABC07B748A42
DFF7AB90AA6197B174AEC88BCFE9A2C3D990DBEBA2DAE2A685825F080100706748C6C197
98995D969F5CCDD89CD6E4AFD7E4B8CEDBB0DCE9BED3E0B4F1FDCFFCFFD8D4E1AC4A5721
A0AF76D0E2A6E1F3B5C9DF9EC2DB97DCFAB4CCEAA2E0F8BAFFFFDCD7DBB88F9A708C9E6E
CBE2AAD4EEB1CBE4A3C8DD9AD5E19FC8D190E6EBABD6DC9CD5E1A1D9ECACC4DD9CDDF8B5
C3DA94D6ECA4DAF0A88BA15982995394AB65D4EEA7CFE9A2
FCFFFFFCFFFFFCFFF8FCFFF1D6DBC4E6ECD0DDE1C6B4B89FA4A796E3E5D8FFFFFBFFFFFD
FFFDFFFFFDFFFFFBFFFFFDFEFFFBFAFFFEFBDEDAD7F7F3F0F5F1EEFFFEFBFDF9F6FFFEFB
FFFDFAE7E3E0E3DFDCFFFEFBFFFDFAC4C0BDF9F5F2FFFEFBFFFAF8FFFCFAFFFCFDFFFEFD
FFFEFDFFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFEFF
FFFFFBFFFCF9DCC3C7FCE1E6FFF9FFFFFEFFFAFEFFFAFFFFFFFDFFFFFBFFFBFBFBFBFFFD
F7FFFCFDFFFAE6D4D4E2CCCEFEF5F6EFEEEC1E1D1B706F6DFFFEFFFFF9FBF6F0F2FFFDFF
FFFDFFFFFEFFFFFEFFFBFBFBFCFCFAFCFFFDFCFFFDFBFDF8FFFFFAFFFCFCFFFCFFFFFDFF
797B76FCFFF3FCFFEDFBFFF1FCFFFFFEFFFFFFFFF6E8E8CCD7D5A5D2D097837D49515219
C1D28BD2EDA0CFE99FCCE7A0C7E4A1CDEAAAC3DFA2F2FFD1EDFFCCB9D598D2EFAFC3E09D
CEE9A2D2ECA2CDE89BD0EB9ECEE9A2CBE6A1C8E39ECFE8A4D2ECA5C6DD97C6DD97809751
79934AA5BF76C3DD94C5DF96C7E197CBE79CCEE89ECFE99FD1E6A17E934EBDD28DD9F3AC
CDE7A0DAF5AECCEAA2C4E29ABAD890CFEDA5D0EBA4C6E19AD0E7A1CFE6A0CFE39EDCF2AA
B6CC81E3FDB4C7DFA3C0DA9D47601CC5DD93CEDE95D8E0A4989572120B006A5F41E8E1B7
CFD094717835343E02D1DDABE5F1CBE1ECCAE5F1CDEFFBD3E7F3C5DFEBB9DAE7AFDAE8AB
A4B475718442CBDF9ACCE39DCDE6A2B8D690DBF9B3D1E9ADFFFFDFE7EACB9DA784DAEBBF
DCF4C0D8F1B7C1D99BDAEDADD5DFA04F54144B4B0D3D3F002A30007C8A4CCFE3A4BDD694
D7EEA8C5DB93D5EBA3D1E79FC9E09AA8BF799BB56E556F28
FBFFFFFBFFFFF5FBF1FCFFF1FEFFECF5FBDFE9EFD3FFFFEAE4E7D6CECEC2F2F1EDFEFDFB
FFFDFFF2EDF1FFFDFFFFFDFFFFFAF7FFFEFAFBF6F2FFFEFAFFFEFAFFFEFAFFFCF8FFFCF8
FFFEFAF7F2EEE8E3DFFFFEFAFCF7F3A09B97FFFEFAFFFEFAFFFDFBFFFDFBFFFCFDFFFEFD
FFFEFDFEFEFCFFFFFFFCFEFDFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFEFF
FEFDF9FFFAF7DDC4C8FFE4E9FFF9FFFFFEFFFAFEFFFAFFFFFFFCFFFFFDFFFAFAFAFBFFFD
F8FFFDFBFDF8E4D2D2FFF0F2FFFCFDFFFFFD2322206C6B69F9F5F6FFFDFEFFFDFFFFFDFF
F8F3F7F9F4F8FBF9FAFFFFFFFFFFFDFCFFFDFBFFFCFCFEFBFFFEFBFFFBFDFFFCFFFFFDFF
7A7A78FEFFF4FCFFF1FAFFF2FEFFFFF9F8FDF7F4EDE7E5CEE3DFB2ECE7B091895863622A
9BAC65C0DB8ED6F2A7D5F0A9C8E5A2CAE7A7BEDA9DF2FFD3F2FFD3D4F0B3D9F6B6C0DD9A
C3DE97CEEA9FC5E093CAE699C9E79FCDEBA5C2E09AD2EDA8CFEAA3D4EEA7D4EEA77E9851
C8DF97D2E9A1D7EEA6CFE69ECDE59BD7F1A7D6EEA4BED68C90A560CFE49FDCF1ACCCE69F
D1EBA4B8D38CBFDD95D7F7AED8F8AFC0DE96C7E29BD7F2ABCDE49ECEE59FDCF0ABCAE098
D6ECA3D0EAA3C8E0A4D5EFB288A15DE4FCB2DDEDA4CBD39797956F362F139B9072DCD5AB
F7F6BD949A5A3F480F384416FBFFE6FBFFECF5FFE0F9FFDFD6E2B4D1DEA9C5D398DAE9A8
DEEFA94E621A445810DBF2AAC3DD96E1FFB9BAD794EEFFCDF6FCDAFEFEE6D6DFC0F8FFE1
EFFFD7CDE8B1C7DFA3C6D89A4952135F5F23DBD79AE1DFA24A4B11323C00CEE0A2DDF3B2
D1E8A0D3EBA1C3DA92CEE59DDEF5AFC3DA94CCE39FD4EBA7
FEFFFFF8FAF7F9FCF3FEFFF3F3F8E4FEFFEDFEFFEDF7FCE8FFFFF4F4F4ECDAD9D5C3BFC0
FFFEFFFFFBFDFFFCFFFFF9FAFFFEFBFEF9F5F3EEEAFEF9F5FEF9F6FDF8F5FFFEFBFFFCF9
FEF9F6FFFEFBF7F2EFFBF6F3E9E4E18A8683FFFEFBFAF5F2FFFEFBFCF6F6FFFAFAFFFEFD
FFFEFCFEFEFCFFFFFFFBFDFCFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFF
FFFFFBFFF8F6DCBFC4FCDDE5FFF7FCFEF9FDF9FDFEFEFFFFFFF9FFFFFCFFFBFBFDFBFFFF
F8FEFAF0F1ECD6C6C6FFFAFAFFFCFDF2F1EF1D1C1A74706FFFFEFFFFFEFFFEF8FCFEF9FD
FFFDFFFFFEFFFFFDFEFFFFFFFDFFFCF8FAF7F9FEFAFEFFFDFEFDFBFFF9FBFFFBFFFFFCFF
7D7C7AFFFFF8FEFFF4FCFFF6F5F9F8FEFFFDFFFFF3F3F3D7DAD8A8D9D49C807943636327
B4C47DC6E194CDE79DC6E19AC3E09DD3F0B0C5E1A6F1FFD6E6FFCDCBE8B0C8E5ABC8E4A7
CEE8A7CEE9A2C9E399D5F1A7E1FFBFF0FFD3DDFBBDC6E3A3D1ECA9C0D995D5EFA8A5BF75
D0EAA0CAE598CDE89BCCE79ACEE69AD7EDA2BED48B879B545B692BD3E1A6CEE0A4D2E6A7
CCE2A2D1ECA9D3F0ADBCDB95C5E69FCBEDA3C7E79EC7E59DC8E39CCCE69FD5ECA6CBE29A
D0EAA0C7E399C9E3A2D0EAAB6D8740BFD68ED0E19BDFEAAE81835C0D0A006D6946DFDEB2
D8DCA1CED796F6FFC46A77423F46254F5539858F6DE9F4CAD1DFACDCEBB2D0E0A1D9E8A3
D3E39CCFDF96D7E79E314500D5ECA6BCD591D2EFADDDF2BAFFFFE3FFFFE8E9F3D1D4E4BD
ECFFD3C7DBA6DEEDB497A165585C1FBFBF83DCDE9FDDE2A29CA566454F12AAB478D0DEA0
CADB97DEF4ACCAE098CFE6A0D6EDA7C9E39CCCE69FC8E29B
FDFAF3FFFFF8FFFFF6FFFFF6FFFFF6FFFFF8F8FBF2FCFFF8FDFFFAFFFFFDF4F3F1CCC8C9
C4BBBEF1E7E8FFFBFDFFFCFBFFFDFBFFF8F6C8C0BEFFF8F6FFF7F8FFFCFDFFFDFDFFFBFB
FDF9F8FFFDFCFFFEFFFFFDFEFCF8F9F8F6F7FDF8FCFFFDFEFFFEFFFFFEFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FDFCFAFFF8F8E2BCC7FFDAE5FFFBFFFFFFFFFEFDFFFFF8FFFFF8FFFFF3FDFFFEFFFCFFFF
F6F6F4B2AEABA89D9BFFFCFAFFF7F8FFFDFF2C2628787274FFFDFFFEF8FAFAF6F7FFFEFF
FFFEFFFFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFDFFFFFDFEFCFDFFFDFFFFFDFF
7E7A7BFFFEFDFFFFFAFDFFF7F8FFF3EEF7E4F3FCDDD8E1B6DEE3ABDEDEA0504B09A3A35D
D9E69ED1E79CCFE79DCBE59ECBE6A3D0ECAFC5E2ACF0FFDDF0FFE1BCD8AFD2EFC3D0ECBC
C5E0A9D9F3B6D2EBA7DDFABAE6FFD7E9FFE0DCF9CBCFEAB7D8F0B6C5DB9AC9E09893AE5F
CBE894C7E58FD6F49ECEEC96CDE695DAEFA2D3E39A4D57188B8E5FF9FBD4E2E9BFFBFFD9
DEEFBBDEF5BDC6E2A5C2E29FCAEEA8C9EFA6C2E89DC1E59BC5E79BCFEFA4D4F2A8C1DF95
C7E69AD5F5A9C1E196D1EFA769843DC4DB97D3E7A8CFDEA75D683D010900727B50D8E2B0
D6E4A7C7D892D3E89DD4E3A0FFFFD5DFDDB771774B404D18BBCD91D6EBAAC5D992D6E69F
DCE8A0DCE39DD5DC96B3BE79D3E29FC7DC99CFE9A8E6F9C1FFFFDDFCF9D8B6C197DBECBF
CEDFABD2DCA7DCDBA5807942A29D63DBDD9EDEEFABC6E099C9E09CB3C28165642B9A985F
A3AC6DD0DF9EC4D493D1E6A1E1F8B2B7D28BD2F0A8D2F2A7
FFFEF8FFFFF8FCF9F2F6F5F0FCFDF8FCFCFAFEFFFFFEFFFFFEFFFFECECECFFFEFFFEFAF9
8F8785B0A6A5FFFCFAFBF0EEFFF7F6FFFDFBCAC1C2FFFCFDFFFCFDFFF8F9FFFDFFFFFDFF
FFFBFCFFFEFFFFFDFFFFFDFFFDFBFEFBF9FCFDFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFF
FFFEFDFFFAFBF7CDD7FFE6F1FFFBFFFEFFFFFFFEFFFFFBFFFFF4FFFFEFF8FFFEFFFCFFFD
FFFCF9B9B1AED2C9C4FFF7F2FFFCFDFFFCFF2D27297A7476FFFDFFFFFDFFFFFDFEFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFEFFFDFDFDFBFFFEFFFFFEFF
7F797DFFFEFFFFFFFDFDFFF7FBFFF3E1EED2D3E2BBCEDCA9D9E3A7D3D8955D5D15A7A95E
D5E398CFE59AD7EDA4BFD690D6EFADCCE6A9CBE6B1EAFFD8EDFFE0C6E0BBCCE6C1C3DCB4
BCD4A4D2EBB1E2FBBAF2FFD1E8FFDBEEFFE6D6F1C8D4EABBC2D59DD7EAAAE8FEB5829B4A
CFED97C4E58CC8EB91CAEB94C4DF8ED0E799D1E1987A84479FA078DEDDBEFFFFE1EEF6CD
F3FFD4CFE6B0D1EDB2D0F0AFB4D892CFF3ABC8ECA2D0F2A8C2E297D5F3A9C2DE94D8F4A9
C5E599C7E899D1F2A3BDDC908BA55CE2F9B5D3E7ACCCDFA8667647000C00475728BFD09C
CBDD9FE2F8B0D5EC9CD1E399FCFFCDE8EABB9FA6738790596D793BC5D491DEEBA5DBE8A0
D4E098D1DD95DEE9A4B9C681ADBC7BDFEFB0CCDEA2E6F3BDF4F2C9EEECC5A6B284B5C692
DCEBB4E8EDB5E2D8A35B4E17E5DFA3D9DF9FCAE59EC9EDA3D7F7AED0E3A1716F345E551E
7C7D43F0FABDE3EFAFD7E7A6C1D691D8F2ABC9E79FBBDB90
FFFCFBFFFCFBFCF8F7FEFCFDFFFFFFFFFFFFF9FAFCFEFFFFF3F5F4FFFFFFFCFBF9F8F4F1
FFFBF8E4DBD6C0B5AFC7BCB6FFFCFAF8F0EEE3DADBCCC3C4FFFBFBFFFBFBFDF7F9FFFAFC
FFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFEFCFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFF
FEFAF7FFFAFAEBC2CAFFDAE3FEF5F6F5F9F8F9F9F9FFF9FEFFF7FFFFF8FDFEFDFBFCFFFA
EEEBE4D6CFC7FFFAF1FFFAF3FFFDFBFFFDFF251F21736D6FFFFEFFFFFEFFFFFCFDFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFDFDFDFFFEFFFFFDFF
7F797DFFFEFFFFFFFDFDFFF7F9FFF1DCEBCEC9D9B2D4E5B1DDE8ACD1D8946B6D247A8134
D3E398CAE095D1E79EC9DF97CAE19DD1E7A9CEE5AFF5FFDDF5FFE4EBFFDDDDF3CFD0E7BD
CBE1B0CFE7ABD6F1AEE2FCBBE2FDC8D8F2C2D9F0BCD0E3ABD0E0A2D1E1A07C904896AE60
CEEB99C5E791C0E38FD1F39FC5E496CDE79DD0E69EB1BF82B2B98DE3E7C2FEFFDDFBFFDA
E0F2C0E8FFC7C8E4A7CAE9A6DAF7B4C3E19BC5E0998BA25C8AA058A6B771B0BF7A5C7028
C9E59AC5E697D6F5A7C1DD92B2CC83BFD692D6EAAFD1E2ACB0BD8F000900525F31DFF0BC
D4E6A8CAE098CFE698C6DC91C0D497D8E9B3D8E1ACE7EAB36E6C33615F226565259CA65F
E3F5ABC5DD91CBE79CC6E19A798E4D5D6B2EE5EAB2EDEDBBFFFFD8434216C6D2A0E9FAC4
C3D299D5DDA2B2AB74AEA56AE0DEA1C8D38FCEECA2C9EFA2BADC90D9F0AADCDE9FE9E4AA
7C7D41AAB072D7E0A1CBD797E0EFAEC9DD98D3EAA4D3EDA6
FDF8FCFDFBFEFDFBFEFFFFFFFFFFFFFEFEFFF4F5F7FBFCFEFCFEFDFEFFFDFAF9F5FFFFFA
FFFEF8F9F2E8DAD2C7D8CFC6FFFDFAFFFAF8FFFCFDAFA6A7FFFBFBFFFDFDFFFDFFFFFDFF
FFFEFFFFFEFFFFFDFFFFFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFEFBFFF9F6E0B7BFFDD5DDFFFDFBFCFFFDFFFFFDFFF7F8FFF7FDFFF9FBF2F1ECEFF5EB
B8B8AEF4EDE3FFFEF3FFFDF4FFFBF9FEF8FA1C16186B6567FFFCFDFFFDFEFDF9FAFFFDFE
FFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFDFDFDFFFEFFFFFDFF
7F797DFFFEFFFFFFFDFBFFF7F2FEEAE6F7D7D0E2BAD6E8B4D9E7AADCE7A3949A506B7326
97A95DD4EA9FD8EEA5D4E8A1D9ECAAD0E2A6D1E2AEF2FFD6F4FFDEF0FFDCD6E6C2CFE1B7
D5E9B6CEE6A8CDE8A1C7E29BD3EBADC1D69BD8EAACD5E3A5DCE8A8A4B16C43540DC5DB90
C9E598C8E998C0E393D4F6A9C8E89DD1EFA7CDE4A0CCE0A3C8D6A5DEE9BEF5FFD4D7E9B5
C8DDA5CDE5A9D8F2B1BFDA97C1DA96CBE29CA6BA75869552DEE9A5E7F0ADE0E7A47A8541
CFE79DCBEA9CD1EDA0D0EAA094AB63C5DA97D0E2A6D7E5B0738150212E007F8C5E96A471
D2E2A4CBDF98DBF0A3E5FDB1D6EFAED5EAB1D1DCA4DBDEA5E4E2A9DEDA9D9797574D5712
7D9247E4FEB4C8E69CC3DE97D8EDACD8E3A9474A156866357B7949D7D9A8CEDBA5C7D99F
E6F5BA8F975B6C6A2D969253ECEEADD0E099D6F6ABC9F2A3B6DB8ECBE59CDAE19EDFE1A2
959E5D2C3800697837D9E9A8C6D997D4EBA7D5EFA8C0DB94
FFFEFFFFFEFFFFFDFFFAF9FEFEFDFFFBFCFFFAFBFFFEFFFFFEFFFFF5F7F4FFFFFBFFFFF8
F3EFE6FBF4EAFFFFF3FEF7EDC8C0BDFFFDFBF9F3F3DBD5D5F7F1F1FFFAFAFFFEFFFAF6F7
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFDFFF8F8E0B7BFFDD5DDFFFDFBFBFFFBFEFFFBFEF9F6FFF3F5FFF8F8FFFFF8F8FEF2
C4C4B8FFFFF3FFFEF1FCF3EAFFFDFBFFFBFD1D191A6B6768FFFEFFFFFEFFFFFDFEFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFDFFFFFEFFFFFDFF
7F797DFFFEFFFFFFFBFBFFF5F6FFEFE8FBDBCBE0B7CADEA9CBDD9FDFEEA9CDD98FA8B468
63752BD8EEA5C0D48CD6E7A1DCEBAAC8D399DCE4B3FFFFDDFEFFE3FEFFE4EDF9D5DFEEC3
DAECB8CDE6A5CDE99FCDE99CCCE299D8E9A2D3E09ADDE8A3CBD59085904BA7B770D9EDA6
CDE79ECDEDA2C3E59BC9EDA3C1E399D0EFA9C6DF9BCEE4A4CCE1A9E0F4BFB5CA92CCE4AA
869E62A4BE7DC6E19ED5EFA8E3FAB4C6DA93869550E4EDAACCD191D8D89AECEAAD959A58
D3E79FC9E399D0EB9ECEE69C637931D1E4A2CDDD9FD6E3AD5965351C280088946673814C
9CAC6EC6DA93DEF3A6BACF84D4E4A5C4D398D7E5A8CEDA9CD4DE9FE1ECAADCE9A495A25C
5C6C2566762FD5E4A1D3E2A1CDD89CDDE8AED3DCA7D9E0ACEBEFBCE3EAB4DEECB1CBDD9F
CDDD9E919C5A4E500FE4E7A4D0DA95C5DA8FC3E598BEE896CDF4A5D3F2A6D0E099D1DC98
CDE29D637E3757722B7F9D55D9F8B2CBECA5AFD38BCFF5AC
F0EEEFFFFFFFFFFFFFFDFFFEFEFFFFFEFFFFFDFEFFFEFFFFF2F4F3FEFFFDFBFCF7F4F3EE
FFFFF8FFFFF6F6F2E7FFFAF2E3DBD8ADA5A3FFFDFDA39D9DFFFDFDFFFDFDEDE9EAFFFBFC
FFFDFEFFFDFEFFFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FEFAF9FFFAFBEBC1CBFFDBE3FCF7F4F4FBF4F8FAF5FFFBF8FFF9FBF9E9E9FAFBF3A4AA9E
A5A599F3EDE1FFFAEDFFFDF4FFFDFBFFFCFE1F1B1C6E6A6BFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFDFFFFFEFFFFFDFF
7F797DFFFEFFFFFFFBFBFFF5F8FFF1E2F5D7CAE1B7CDE5B1CAE0A2D0E3A1DAEAA3D4E49B
6A7E36000F00DEEFA9E4F3B0CFD99CD1D8A2DCDFB2FFFFDAFBFCDCFFFFE4FFFFE3FCFFDD
E4F7C0CDE6A5C7E398D0ED9DCEE595DFF2A3D6E499D1DB92D8E29BA7B16CC1CE89CCE09B
D7F0ACCEECA6CBECA5C6E7A0C1E198D0EEA6C9E39CD0E6A5D3EBADC0DA9DCDE7A8BBD594
B6D08F617C37C0DB94CFE9A0C1D890D3E7A08E9B56DAE3A0E5E7A8D3D395DEDA9DA4A667
D4E59FC7DF95D1E99DCCE29795A961576824D3E1A4CEDBA3707A48262F008E9768E6F3BE
CEDEA05F702A394E01E1F3A7D4E0A0DBE6AAD6E6A7E2F5B3D0E7A1CBE29AC7DD95DCEDA6
96A15C4D5411616528E9EDB2D5DAA2E1EAB3E3F0BAC8D59FCFD89FC2CC8FD6E6A7CFDF9E
CEDD9AABB8734D5410D2DC97DBEBA2E0F8ACD1F6A6B8E391C7EE9DBFE091CCE098E1F2AB
D9EFA7CFE9A2829C554F6A23001000BBD993E2FFBAC4E39D
CACCC1EFF2E7FEFFF8F8FEF4FBFFF9FCFFFBFDFFFCF7F9F6FBFDFCFEFFFFFFFFFDFFFFFD
F6F5F1F8F5F0FFFFFAFFFEFAFBF6F3FFFDFAB8B2B2F7F1F1FFFCFBFFFEFDFFFEFFFFFEFF
FFFDFEFFFDFEFFFDFFFFFEFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFDFFFFFBFFFFFDFFFFFD
FFFEFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFEFF
FFFEFFFFF9FDF7CDD9FFE6F1FFFDFDF9FFFDFCFFFDFFFEFBFFF9FBFFF3F3FFFFFAC6CEC3
EFEFE7FFFEF6FFFCF3FFF8F2FFFEFBFFFCFB201C1B6E6A69FFFFFDFFFFFDFDFCFAFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFEFFFFFCFDFFFFFEFFFFFDFF
7F797DFFFEFFFFFFFBFBFFF5F8FFF1E5F9DDDDF6CED9F3C3D0E9AFC9DF9FCDE19CCFE39C
9DB26D869B56384807919D5F5E662B676937545229ADA986B1AC8EAFAB8EE1E5C4F0F8CF
DBECB6D3E9A9C4E095CFEC9CD2EB9ACEE394D6E69BCFDC94E5EFAAD1DC9AA0AC6CB0C081
CCE2A1B7D28FCBEAA4C9E9A0CBE99FCFE99FCFE59CD4EAA2CFE8A6C7E1A0D2EDAADBF9B3
C9E7A193B167B1D084C5E196A8C278ADC37AC5D68FD8E5A0E2EBAAD5DA9ADCDDA1535919
D4E59FCCE299D0E69BD2E79CD7E8A1374601BECC8ECED9A1767E4B303A089EA876D7E4AE
C0D092DCEDA79CB16487974C8D9655CAD394C5D594CCE69FC2E299D3F3A8BBD78DD4E8A1
E0E9A68587486F6A304F4A126F6F399DA66FD2E3ACD7EBB0D2E2A3E3F2AFD3E4A0D1E29C
D3E29D7E8B4557621DDAE79FCAE095C1E092BCE392B7E290D4FBAACDF0A0D2EDA0CCDD96
DFE8A5CED494D2D898C8CE8E53591B595F21545A1E424A0E
B8C1A6E1E9D1F1F9E2E3EBD6E7EEDEF8FEF0FEFFF8FEFFFAFEFFFDF3F5F4FAFAFAFFFFFF
FFFFFFFFFDFEFFFEFFFFFCFBFFFEFDFAF5F2FFFDFDF9F3F3FFFEFDFDF9F8FBF7F8FFFEFF
FFFEFFFFFEFFFFFDFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFDFFFFFBFFFFFDFFFFFD
FFFEFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFDFF
FFFAFEFFF6FCE5BBC9FFDAE7FFFDFFF8FFFFFAFFFEFCFBF9FFFAFDFFFBFBD3D5D0A9B0A9
D5D4CFFFF8F5FDF2F0FFFCFAFFFEFBFFFEFD231F1E716D6CFFFFFDFFFFFDFDFCFAFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFEFFFFFCFDFFFFFEFFFFFDFF
7F797DFFFEFFFFFFFBFBFFF7F7FFF2F4FFEDF2FFE6D8F3C6CFE7B3D3EBB1D3E7A8CEE3A2
D5E9AAD5E9AAB9C88D869157C4C895CECD9FDDD9B4B0A98CACA58B8A866DC0C0A4D5DBB5
CFDDACD9EFB1C5E197CAE99BD3EFA2CBE699C6DC93E6F7B1C8D494D7E3A5D4E2A590A266
AFC58593AD6CC2E09ACDE8A1D5EFA5CBE294CFE293D5E79BD0E7A1C5E09BCEE9A4C5E39B
CEECA2D1F0A4CBEA9CC9E89AC8E799C4E093D1E99FD0E49CCCDD97E4F3B0D7E3A391A05D
D5E9A2CEE49BD4E99ED6E89ECBDB94D8E7A2939F5FD2DDA3828B560B15008C9664D4E1AB
D2E2A4D5E9A2C7DC8FDAECA0ADBA757A89488EA25DD4EBA5C6E298CBE79DD4EBA3CFE39C
D2DE9CE4EAACD6D79DCDCE955A5D26313A03D7E4AED2E4AACBDE9CDAEEA6C0D18BD7E7A0
DDEAA44B581252621BCFE499D2ECA2C3E495CBF2A3C4EE9CCAEFA1BFE292D8F4A9CADE96
D8E19ED7DC9CDDE2A2DFE1A2D1D296E1E2A6D5D69CA2A369
B9C69AAEBB90D3DFB7E1EDC9CCD5B8E9F1D9F6FAE9FEFFF6FEFFFAFEFFFDFEFFFFF9FAFE
FEFFFFFFFEFFFDFCFFFFFEFFFFFEFFFFFEFBFFFEFDFFFEFDFFFEFDFFFEFDFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFBFAF6FFFEFAFFFFFDFFFFFD
FAF8FBFFFEFFFFFEFFFFFDFFFAF7FEFFFDFFFFFEFFF6F4F7FFFEFFFFFEFFFCFBF9FFFEFF
FFFDFFFAE6EFF5CADBF8D2E1FFFDFFF4FFFBF9FFFFFBFBFBFFF7FCFFFBFDBCC1BDDCE5E0
FFFEFFFFFCFFFEF2F6FFFBFDFFFCFCFFFFFD0100006D6C6AFFFFFDF7F6F4FFFFFDF9F8F6
FFFFFDFFFFFDFAF9F7FFFFFDFFFEFDFCF8F7FFFEFDFFFFFDFCFFFFF2F6F7FFFFFFFFFDFF
787276FFFAFCFFFEFDFEFFFAF9FFF6F5FFF1EEFFE6DEF8D1D0E7B9C7DEAACADEA9D1E4AD
D8EBB4C0D19BD8E6B1D2DCAAD7DAAFE4E2BCDAD5B7FFFEE6FDF6E3D9D4C06A6A527F8563
D6E3B7C9DCA4CFE8A4CDEBA3C4E39DCBEAA6CFE9A8D0E4A7D3E2A9D8E5ADCFDEA7CEE0A6
B1C789667F3EAAC580D8F2A8C3D88BDBEC9CDDEA98D0DE8FCADE96DEF8B1C4DE97C4E096
D9F8ACC3E294C3E495CDF09EC3E694C2E593D8F9AAC0DF93D1EDA3D1EDA3C1DC95ACC67F
889E56D6EAA2D2E49ADBEDA3D1E198DDEAA4CED997919B5F7F8A520C1600808A56D5E2AC
C9D99BDFF3ACCBE093D4EC9EC8E49AACC78094A964CDDE9A909B596F78379EA967DCE8A6
D4E7A5C9DE9BD3E9A8D8ECAD909E63757C468F915FC2C78FC6D793DBF1A6D0E099E4EFAA
B3BD784F5A1570813AC5DD93CAE89ECAEC9FC3E89BC8ED9FC7E79CC7E69ACCE89ECDE79E
D4E9A4CEE29DD8ECA7D8E9A5D5E4A3DBEAA9CEDA9CDAE6A8
B9CB8F9CAE74C0D19BC8D6A5DBE8BDEAF4D2F1F7DDFEFFF1FAFDF2FEFFFBFEFFFFFEFFFF
FEFEFFFEFEFFFAFAFFFCFCFFFFFEFFFFFEFBFFFEFDFFFEFDFFFEFDFFFEFDFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFBFFFFFBFDFCFAFFFEFC
FFFEFFFFFEFFFCFAFFF3F0F7FFFCFFFFFEFFFFFEFFFFFEFFFFFFFBFFFFFAFCFBF6FFFCF7
F5EFF1FFF9FFFFD9E7FFE6F3FCF8F9F7FFFFE5F0EAF9FBF8FFF8FA201418F7FBFAF5FEFB
FFFEFFFEF5FAFFFAFFFEF1F8FFFEFFF3F2F032312F5E5D5BF5F4F29D9C9AB5B4B2FFFFFD
F8F7F5FFFFFDFDFCFAFEFDFBFFFCFBFFFCFBFFFEFDF9F8F6FCFFFFFCFFFFFFFFFFFFFBFF
7C767AFFFDFFFEFAFBFBFCF7F6FFF5F4FFF1ECFFE7DFF7D7D3E9C3CCE1B8CFE0B4D3E3B6
D5E4B9CBD8ACD4DFB5D3DBB2DEE2BFD7D8B9D2D0B9FFFFEDFFFFF1FFFFF0ABAC9AA2A88C
808C648C9E6A8FA56789A6648FAF70597B3F415C256077417A8B579CAA77DDEEBACEE1A9
CDE5A9C8E2A1ABC681B2CC82B3C87B899A4AD5E18FE4F1A2D9EDA5BAD18BD8EFA7D0EAA0
BCD88DC5E496DBFCABBEE18FC8EE9BC2E895C3E898B8DD8DC3E89BCAEFA2CDF1A7CDEDA4
9EB56DADC179C7D891D7E99FCFDF96C4D18BD6E19FDBE7A9828D530F1C0085925DCFDEA5
C8DB9BC9DE99CFE59ACDE899C8E89DBEDE95CADF9AE8F4B2B7BD7D9FA162BAC080B3BE7C
CDE29FD4EFACC4E19EBAD493CCDEA2DAE3AC7E7C49393C036D813A768E42313E00252F00
757C38C1CA87E8F9B3CAE49DCCECA3C6E89ED0F0A7C7E59DD0EBA4C7E19ADCF7B0CBE59E
C9DE99D8ECA7BFD08CD0E19DD6E5A4DAE6A6DFE9ACD1DB9E
E8FEB68196519CB170C9DB9FDAE8B5E2EFC3FCFFE3F8FFE6F9FDECFEFFF6FEFFFBFEFFFF
FCFFFFFCFFFFF5F8FFFBFCFFFFFEFFFFFEFBFFFEFDFFFEFDFFFFFDFFFFFDFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFF7F6F4FFFDFAFFFEFDFFFBFA
FFFBFFFDF8FCFFFCFFFFFDFFFFFDFFFEF9FDFFFBFAF9F5F2EDEAE3F8F5ECFFFFF3FFFFF4
FFFEFAF6E3E5E3B9C3FFF4FAFFFFFAF7FFFAF2FEF4FEFFFAFFFCFBB7ADAEE9EFEDF9FFFF
FFFEFFF6ECF4FFF9FFFFFAFFFFFDFEFFFFFB0001006D6E69646560ACADA8AEADA9D2D1CD
FFFFFBFFFFFBFFFEFBFFFDFAFFFEFBFFFEFBFFFEFBFDFCFAF5F9F8FBFFFFFFFFFFFFFAFE
837D81FFFCFFFFFAFCFFFFFDFCFFFBF8FFF8F5FFF4F5FFEFF1FFE9F2FFE5F5FFE2F9FFE2
F5FFE0FCFFE4FCFFE6F3FCDDFEFFEAFEFFEDF5F8E7FFFFF6FFFFF8F5F8EFFCFFF4FBFFEF
EFFDDCD8E9BDD8EBB4C7DFA595B37FBCD9A9D5ECBE4D603349592C9DAA7CBECE9DD0E5AD
D3ECB2CEEBABC1DE9BDAF5AECDE79DD9F0A24B5C0ECBDB90CDE19AE1F8B2C6DD95CEE89E
D9F5AAC3E294DBFCABB7DA88C6EC99CAF09DC0E796CAF1A0C2EB9DC0E99BC1EA9EC2E69C
C2D99153671FCEDF98DDEFA5D6E69BEFFFB6D0DD98D3DF9F717C421C2900899861CDDFA5
E2F7B6CEE59FDDF5A9C6E194D2EDA6C6DF9BDBF0ADD1E1A0C9D394D7E1A2E3EDAE8C9B5A
4E6121CDE2A1D2E8A7ECFFC2DDEFB1BDCB90D3DBA2D9E5A7BBD58BD9F4A7D3E098E3E8A5
E8EAA9C8CE8ECADA99CEE7A3D3F2AEB5D490D8F1AFDAEFAEBDD090778A4AB5CC88D8EDAA
D6DF9EDBE0A0F8FABBCECE905D5B20615C22625C22322900
C3DB8DE0F8AC4E651D96AB68BDCF95DEECB9E5F0C6F4FEDCFEFFEAFEFFF1FBFEF3F7FCF5
FCFFFDF9FFFDF8FEFCFCFFFFFFFFFDFFFEFBFFFEFDFFFEFDFFFFFDFFFFFDFFFEFFFFFEFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFDFFFEFBFEFAF9FFFEFF
FFFDFFFFFDFFF8F3F9F7F2F6FFFDFFF9F5F4FFFEFBFFFFF8FFFFF3FFFFEFF2F1DDAAA995
AFA99DA19089785051896765FEFEF2F5FFF4ECFAE9F2F8EAFDF6EECAC2BF989F98F8FFFD
FAFAFAFFF7FFFFF9FFFFF3FCFFFDFCF8F9F4343530393A35DFE0DBFDFEF9FFFFFBA5A4A0
FFFFFBF9F8F4FFFEFBFCF8F5FCF8F5FFFEFBF8F3F0FFFFFDFBFFFFF5FBFBFEFFFFFFFDFF
7C767AFFF8FDFFFCFFFFFEFFF9FBF8F7FEF7F5FFF7F7FFF6F8FFF4F9FFF1FBFFEFFCFFEF
F8FFEBFCFFEFFCFFEFF9FFEDFBFFF3F9FFF4F9FFFAF3FCF7F5FEFDF9FFFFF9FFFBE6F3E2
DEECD2A3B38E3C4E1E3448176D845A6F855E586A4422310A9FAA8049562A000A00D3E8B0
BDD99EC7E7A8C4E7A3C2E6A0C9EAA5C5E39DE0F9B5829953889F5BA1B872CFE6A0D9F3AA
BDD78DCDE99CC1E092DDFCACB5D685C8E998BEE191D3F6A6C4E99BC7EC9FC5E99FC5E59C
E4FBB3CBDF986D7E376B7D33C9D98ECCDC91CDDD96D5E4A1CAD89B8D9C639DAF75A6BA7F
B6CC8B9DB770A4BF7297AF638A9E599CAC6B98AB69CDE09ED2E5A5E2F5B3BBCE8ED0E3A3
ACBC7D8694568F9D5FC7D597C7D597DCECADE0F0B1D0E7A3CFEFA3D3EFA2C5D08BD9D999
EBE9ACDEDFA3D7E7A8D2EBAAD3F1B1C0DD9DD5E7ABDEE9AFDCE5ACACB77D91A3652D4000
616B2C868B4B343900838546E3E1A6DBD69CC8C2888F894F
CCE798B9D487D9F1A7425714A5B779E3F2BBC3CFA1EDF8D0FEFFE4FEFFEAF8FFE9F9FFEC
FCFFF3FAFFF3F6FFF1FBFFF6FFFFFAFFFFFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFFFFFFFDFFFEFBFFFDFCFAF6F7
FBF6FAFEF9FDFFFDFFFFFDFFFFFBFAFDF9F6FFFDF4C6C4B76B6A567A7A62D5D5BBFFFFE6
FFFFEAFFF1E1BD978E220200282C15607357A6B99D616B53DCD6C6646054EDF8EA000500
01020012090C0B00030E01080201000001003A3C3733353073746F70716C6968640A0905
050100030000030000080401120D0A1E19161C17143837352D333137403DA5A6A8FFFEFF
8D838BFFFBFFFFFBFFF1EBEFFFFEFFFBFFFFF6FFFCF7FFFBFAFFFAFAFFF8F9FCF3F6F9F0
FEFFF8F0F3EAF4FAF0F9FFF8EAF6ECE3F2EBF4FFFFF2FFFFE5F7FBF4FFFFCCDCDBADBDB3
000B00C1D0B3D6E5BED1DDB5D9E4C2CFD8B9CBD2B0D5DBB7CCD1A9242D000F1D00586D35
DBFABEB6DD9ED1FBBBB4E0A1C0ECADBCE5A9B9E0A7D2F4B8CEEBABD9F2B0566F2B8CA65F
BFD990D8F2A8C2DD90CDE89BD2ED9EDFFAABD1E99DD4ECA0C0DA90D1EBA1D3EDA4D7EEA6
C2D792C6DC94E1F5ADE1F6AB3D4F03495B0FEDFEB7D1E29ED6E6A7D6E8ACC3D79CBCD294
D0E9A7CCE7A0C6E597D9F1A55059184F55194B591B000E00D0EFACC4E5A0CAE7A5D9EFAE
D4E0A2EFF5B95A5B1F75793CD7E1A2D0E5A2C9E7A1C5E99FB6DB8DD2EEA3DBE4A1DBD99C
DED7A0DAD9A1D3E1A6C2DA9EBBD79CCCE3ABD6E0ACD0D2A1A3A1709FA16FD7E4AEC0D497
C8DE9DCCE5A1C4DB97D0E5A2D3E6A4829251707F3CC8D492
D4F0A3C7E398D6F0A7C6DD99849859B5C68FD4E0AEDBE6BBE7EFC8ECF3D1ECF6D4F5FEDF
FBFFEAEFFCE0E5F4D7EEFAE2FEFFF8FFFFFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFFF7F6F4FFFBFAFFFEFFFFFEFF
FEF9FDFFFDFFFFFDFFF3EFF0DAD6D5A4A19AAFADA1E2E1CFF6F6DEFFFFE4FFFFE3F3F3D1
FFFCDDFFFDE2CEA99680614C747A58718760788C6774826177755C9896815F6B55889584
8A8B83968E8B8C7D80897D7F87868261635E13151012140F91928DA4A5A0A09F9B74736F
9F9B988D89868E8A878A86837F7A77716C696D68657E7D797E87826D7874B7BBBCFFFEFF
786E76FDF2FAFFFBFFFFFBFFFFFDFFFFFEFFFCFFFFFBFFFFFCFFFFFEFFFFFFFFFFFFFDFE
FFFEFFFFFFFFFCFFFFF9FFFFF5FFFFF2FFFFF0FFFFC5DEE391A9B3546B7380959A93A6A4
EDFBEED1DFC8D2DDBFD9E0BFDADDC0E2E1C5E4E1C2C1BE9BAFAD8655582B3E4B1660783E
6A8C4F719D5EC0F2B5BCF2B8B4EBB4BDF3C1C4F8C8B1DDAACFF1B5C0DD9BBDDA97BBD691
3F59127188409BB168D5EA9FCFE197CCDE92D4E49BCFDC94C6D38DD1DE98C4D18CCDDC97
DAEEA9D3E9A1D2E69ECCE194D6E99AE7FAAB97A95F95A962AFC282D0E4A5D8EDB2D6EEB0
D8F3B0CAE8A0B3D485CAE49AE4EDAECDD298E0EEB194A869748E4DAFCC8AD4EEADCDE1A2
D1DFA1DBE3A7D3D99BB3BC7D788746768D477A985095BA6DCFF5A8C7E59BD5DB9BE8E3A9
ECE0ACDBD8A3D4E1ABD9F0B8D5F0B9E0F4C1E6ECBEFFFFD6CBC2979A9669CED4A4E1F4BC
CAE7A5C8ECA4D4F3ADCFEEA894AF6A536E27C5DC96D1E8A2
C8E69ECBE69FC6DF9BD9EFAFBED29593A46D939F6DD3DFAFD4DDB2D9E1B8DCE7BFE8F3CB
EFFBD3E1F0C7D7E8BEE0EECDFEFFF4FFFFFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFFFFFEFFFCF6F6FFFDFFFFFDFF
FFF9FDFFFDFFE7E1E59A9496F9F4F1F0EBE5FFFFF1FFFFECDCDBBFCCCCAADDDDB7E0E1B9
DDDBB47466415B381ACEB191DDE4B8D5EDBBCCE2B3CCDBB0DDDDBBFFFFE3F2FFE3F8FFEF
ECEEE0FFFEF6FFFBFAFFF4F2FFFFFAFAFFF81C1F18747770EBECE6FFFFFAFFFFFAD6D5D0
E9E6E1FBF8F3FFFDF9FFFEFAFFFEFAFCF7F3FFFDFAFFFFFBF9FFFDECF7F1FCFFFFFFFEFF
877D85FFFAFFFFF7FFFFFAFFFDF6FEFBF8FFFAFAFFFBFBFFFBFBFFFDFCFFFFFBFFFFFDFF
FBF5FFFAF9FFFCFFFFE9F2F7EFFEFFE9FEFFA3BEC57E9CA6D4F2FDE9FFFFEDFFFFF1FFFF
EEFDF6F8FFF3F3FDE4FFFFE6FFFFE692846A998B6E877A57BAB389FFFFD4E0EAB5BFD79D
C7EEAFC6F6B85791567DBC852D6C3D67A87E589873B9F0C6B5DCA3D7F7B6BCDB98DEFBB8
C8E19DCFE49FCFE099B3C078707C345E651F949A549FA25DAAAB67A09F5C7C7B3A8E9351
D2E39FCBE29AC5DB92DAF1A3CFE495C6DB8CD8EDA2CFE39CC5D898AABE7FC9DEA3CDE5A7
CBE8A5C5E59CC9EA9BD6F5A9C9DE9DD7E6ABCAD89DCAD59BDBE4ABA7B0774B561ACBDB9D
D2E5A5CDE3A2BDD692E7FFBAD6F0A9BDD48CA3B9717791486E93467C9A509BA1639F9861
9D8F5EA09A68939D69839764829A68DAECBCFFFFDAFFFFD9E4D4B0BDB189E3E4B8C3D19C
CDEAAAC5E9A3C1E09A6E8D47C1DC95CCE7A0DAF1ABD1E8A0
D1EFA7C9E49DD2EBA7D3EAA6D2E6A7A8BA7E9AA970AEBB85D1DEA9D3E0ABD3E1AEDCEDB9
E4F7C0DAEFB7D2E9B1E0F3C6FCFFEFFFFFFAFFFFFBFFFFFDFFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFEFFFBF5F5F7F1F1C5BFBF
8B8683B4B1ACF5F2EDEFECE3FDFEF0FFFFEDFFFFE8F4F8D7DADEB9E0E6BAD8DEB0B0B384
A0A3746E663871532DCBB38DD1D9AAC7DFADCBE1B2D7E3BBD8D7B8FFFFE3F9FFECF6FFEE
FFFFF3FFFFF6FCF3EEFFFCFAFCF9F4FFFFFA12110D62615DFFFFFBF7F6F2F2F1EDFFFEFB
D1CDCAFFFAF7FFFEFBFFFEFDFFFFFDFBFAF8FFFFFDF2F7F3F3FFFBF7FFFFF7FDFDF0F1F3
818588FEFFFFF7F2F9FFFCFFFFFDFFFFFDFFFEFEFFFCFFFFFEFDFFFCFBFFFDFDFFFBFFFF
F9FFFFF2FBFFF5FFFFF4FFFFF0FFFFA9C2C6638086B4D2DAE4FFFFE6FFFFEBFFFFF1FFFF
EDFAF1FBFFF4FFFFEFFFFFECF5E8D5826F5EBAA796FFF3DCFFF8D5FDFAD1D6DBB2D6E6B9
C2DEAEBCE2AFC8F7C3B1E5B5669A7483B9997DB3937EAE868BB67EC4EBAACCF0B0BCDC9D
C4E2A2CFE9AAD2E8A7CEE19FB9CA868C9B58D1DD9BD7E3A1E0EBA9B9C38480884C9BAB6D
8AA76585A661B5D48EBEDC92D1EDA2CCE79AD0E89ED3E9A1CEE3A0718645ADC383C5DE9C
D2EDA6C7E69AD4F3A3C2DE91CCE39DDCEFAFD4E0A2DBE3A7DEE1A8D0D39A676F34D1DFA2
CDE3A3CEEBA9CDEEA9C5E6A1BDDC96D8F3AECADF9AD1EBA4C2E79A98B86F909C5C95965C
9F9E66A2A570899861718852465F28BBCD9BFFFFD8FEF7CDDED2A89D9469E1E0B2D5E2AC
C9E6A4C5E9A1CEF0A686A65DD9F7AFBAD68CD0EAA1C9E39A
C9E598D2EEA1D1EC9FCBE397D0E69ED5E9A2BFD08C9CAC6B8F9F5ED9ECACD7ECABCFE5A4
C5DE9CD1ECA9CBE9A3DEF7BDEFFEDFFBFFF3FCFFF8FCFFFBFFFFFFFDFDFFFFFEFFFFFBFF
FDF9F8FFFEFBFDFAF5FFFFFAFFFFFAF0EFEBFFFFFDFBF7F6DAD1D4B0A7A8B8B3B0CAC5BF
FFFFF3F2F4DFFFFFEAFBFFE1C6D1A9E4EFC4CBD7A7D2DEACD9E6B07481494C5921AEBB83
D4E1ABE8E8B6CFB88FBBA782D1DCB1CCE5BBCADEB9E4EFD1FFFDEAFFFFF1F9FFF4F7FFF6
FCFFFAFFFEFAFFFEFDFFFCFDFFF9FBFFFBFB2F25266F6667F9F5F4FEFAF9FFFCFDFFFEFF
C4BEC2FFFDFFFFFCFFFCFAFFFCFFFFF9FFFFF7FFFFF1FFFFF4FFFFF5FFFFF8FDFFF8FFFF
6F8884EBFFFFF7FFFFF9FDFFFFFEFFFAF9FEF9FFFFF0F8FBFFFDFFFDFEFFF4FFFFE5FFFE
E6FFFFE1FFFEE0FFFBB0CECC496566BAD6D7DFFBFCEBFFFFE4FFFAEDFFFDF0FFFAF4FFF6
F9FFF4FFFFF3ECE8DCECE2D664534B1B0804230E154634343429151A1400363320010200
3139246875598A9C72C8DDB4D1E3CDD0E1CECEE1C3CAE5BAB9E2A8A4D29288B4776D965C
C9F0B9BDE4ADBEE1A9C4E7ADD3F7B9ADD493CFF8B6C4EDABA9D39477A36847743D86B77F
81B77982B97698CD89ADDC986A934FCFF2AEDBFAB6BBD691D2E9A5D8EDA8A4B87183974F
869C51CBE493E1FAA7C9E090D9E99ECFDA95E7F1ACD2DB98DDE6A5D1DB9EDEECAF77894D
677C41769053C5E3A5CBEBACBCDC9DCDEDAECCECABC9E9A6B8DC92CFF1A5D1ECA5BBD490
D8EEADCDE6A4C8E5A3CEEBABCBE5A6BDD395EEF9BFFDFFCA99996393925CECEDB4D5DFA2
C9E79FC8EDA0D2F4A887A75CBDDB91D4F0A5C8E499CAE69B
C8E595CFEC9ACFEA9BCAE294CFE59ADAEEA6D5E9A1C7DB94BBCF8880964ECDE49ECEE89F
C9E49DCBE99FC3E398D3F0B0DCEEC8F7FFEDF7FFF0FBFFF9FEFFFFFDFDFFFFFDFFFFFCFF
FFFDFDF6F1EEFFFEF8F6F1EBFAF7F0FFFFFAF1EDEADAD4D4A39A9DFCF3F6FFFEFAFCFAEE
FFFFECFFFFE6F8FFD9F6FFD5DCEDB7B5C78DD4E6AAD0E2A44B5D1FC3D597CADA9CDFEEB3
D8E7B0D4D6A5C9B38ECEBA99D2DCB7CDE3BDDBEBCEECF4DFFFFEF3FFFAF3F5FCF4F2FFF6
FCFFFDFFFFFDFFFDFEFDF7F9FFFBFFFFFAFD2C22236A6464FFFEFFFFFFFFFEFEFFFFFEFF
8D888EFEF7FEFFFDFFFEFDFFEDF5F8F5FFFFF1FFFFE3F8F9F1FFFFE3F5F7F5FFFFEEFEFE
718784E0F4F2F5FFFFF7FFFFFBFFFFF5FDFFF4FFFFF3FEFFF9FFFFEEF8FAF0FFFFEDFFFF
E2FFFF557D751F3F3EC5E1E4F0FFFFEDFEFFF4FFFFF3FFFFF4FFFFF3FFF8F7FFF5E0E6D8
D3D1C50A010012000012000066584FDACDC7FFF8FFFFF6F8FCF5E3FFFBE5FFFFF3FFFCF3
FFFFF6FEFFEE0C12005B613F000300000200D6DBBDCEDDB2C5E6B1CEF7BDC8F0BBB0DAA8
224C1C54804FD2FECBC1F0B9ABDDA0CEFFC179AD6B7EB272AEE1A6BEF1B9B4E8B7C2F8C6
ABE5ABB7F1B48CC286447639CCF6B7385C1E779557D7EFB1D8EDACCEE19FD0E49DD8ECA4
556B20475E10C0D88ADBF2A4293700535D16263100D2DD99D5E19FE4F2B4C9D99BD8EAAE
8C9E64566B30000D00D2EAAED1EBAED3EFB2BCD999C8E7A4E3FFB9C1E196C5E59CC5E59C
CBEAA4C2E19BCFEEAAC4E19ECAE5A2BFD5948699595C6A2C849052B9C283CBD193D9E5A3
D1EDA3C0E295BCDC908CAB5FD0ECA1D9F3A9C2DC92D3EDA3
C9E89ACCEB9BCBEA9CC8E497CAE296D0E69DD5EBA3D7ECA7D4E9A48CA15C93AA66D8F2AB
C7E29DCCEAA2CBE9A1CDE7AACFE0BCF1FDE7F7FFF0FCFFF8FEFFFDFCFCFEFFFDFFFFFBFF
F3EDEFFFFBFBFFFEFAFFFCF8F8F3EFE7E2DE888481FFFAFAF0E7ECFFFCFFF7F2EFFFFFF4
FFFFEDFEFFE4D2DDB2D3E1AED0E2A8D7E9AB97AC6B8CA15EB7CA88E3F6B6D4E7A7D6E5AA
D7E3B1C6C49BC4A98CE5CBB2DBE0C0D8E9C9F1FDE5FEFFF0FFFCF4FFFCF8FCFFFBF8FFFD
FEFFFDFFFEFFFFFDFFFFFDFFFFFDFFFFFCFD272727696B6AFBFFFFFBFFFFE9EFEFF9FDFE
B0AFB4F4F2F7F9F8FDFCFFFFF9FFFFEEFCFDE8FCFBDFF8F5F0FFFFEEFFFFE4FFFDF2FFFF
928891FFFAFFF6F7FCEDFBFCE7FDFBF0FFFFF5FFFFF4FFFFE1FEFCEEFFFFEFF2FBB9B9C3
A3B0B97D8D9AB7BFD2F5F7FFFFFBFFFAF1FFFFF9FFFFF8FFFFFBFF9B949B837A7D493D3D
8B77798C71769879815D4344877B6BFBF9E4FFFFF3FFFFF1FFFFE6FFFFE4D0D4BDD7DCC8
FEFFEFECF4DCDBE5C3FBFFE679826F8992815F69505F6D4A9BAE81C9E1B1BFDAADD0EFC5
93BA8E648F6270A06E83B8808BC18383B7775F9250CBF9B9C9F0B7C7E9B6D4F1C3B3D3A4
C5EDB9BEE9B3BFE6B1B1D49E9EBC8690A972475C246C7D46C0D298DCEEB2D3E5A7D0E5A4
C8DF9BD9F3ACCCE7A0C0DA93CFE09CD0DF9EBDCC8B4E5C1ED3E1A4D8E6A9CBD69CD4DFA5
D7E2A8BAC589ABB67A5C682A96A26296A262BCC8869AA966C9DA94BED48CD1E79FD1E8A0
D8F2ABC9E49DD0EBA6C8E39ED6F1ACD9F2AEDDF4B0B2C784B5C886DDEEAAD4E3A0D8E9A5
D7F1A8C2DE93C9E59AAEC87E88A056CDE39ADAEEA6C9DD95
C8EB9BC9EA9BCBEC9DCDEC9ECBE59BC8DF97C9E098CFE49FD4E9A6CCE19E8DA460ACC37F
CBE4A0D5F0ABC8E3A0CEE6ACD1E1BDF7FFEDFBFFF3FCFFF8FEFFFBFCFAFBFFFDFFFFFBFF
FFFDFFFFFBFDFFFCFCFFFEFBBEB9B6A39E9BF7F3F0FFFEFDFFFDFFFBF5F9FFFFFAFFFFF3
E5E9D0E0E8C3DFEDBCD4E6ACACBF7F5F7431CFE49FC0D590D9ECAACDE0A0D8EAACCDDCA5
E7F0C5E3DEBED5B5A0F7DAC8F1F1D9EAF8DFFBFFF1FFFFF4FFFBF8FFF9F9FBFDFAF7FFFD
FDFDFDFEFAFBFFFAFFFFFDFFFFFFFFFAFEFD0912115A6664F5FFFFF5FFFFF7FFFFF9FFFF
FCFFFFD1D2D67E7F8365696A9AA4A57E8C8CA2B6B4B3C9C690A4A37F989550736D223836
3B2B36AD97A4C7CACFDBEFF0DDFBF9D0EAE9E3ECF3DCE9EF507273446365898B97C3BDCB
F6FCFFEEF8FFEAECFBBFBACE8678913F2D452B182E0D000D0A0005C4B5BAF7E9E9F9EAE7
FFF9F6E7CDCC5D3F3FF5DED6F3F2D4F0FAD5DFEBC7E7F3CFE0ECC6DAE9C2D2E0BFDCE9CB
EFFEE1F8FFEAF5FFE8F7FFECF3FFEDF7FFF3DFEED9C9D8BB98A4800008006F815B8CA57E
C5E5BECAF0C7BDEBBCC0F0BCB6E8ADBEEFAEBBE5A5D1F5B7C5E1A7D1E5B2BFCCA0E1F1C4
CBE3B3D1EDBCD5EDBDB5CB9AE0F2C2D2E2B1C6D2A2697543717D4B6775408FA26AD7ECB3
C5DFA2C0DC9FC8E8A9D1EEAECCDEA2D7E2A8D4DFA5D1DEA69DA8708C975FDCE7AFD2DDA3
D7E2A8E8F3B7CAD696CBDA97D8E5A0E9F6B0D2DF97D4E19998A35FA9B470A3B06B94A35E
A8B9757E934E8FA660DAF4ADD2EBA7B4CF88D8F3AED9F3ACB7D18ACFE6A0DAF1ABC0D78F
CDE59BD2EAA0D6ECA3D1E59D4F6019A9B972CCD993DBE8A2
C7EC9EC3E89AC7E99CCFEFA3D0EEA4CDE99FCDE79ED2E9A1D4EBA5CAE19DD1E8A4738948
D1EAA8D8F1AFBFD897D1E8B0D4E4C0F9FFEFFBFFF3FCFFF6FEFFFAFBFAF8FFFDFFFFFDFF
FFFCFFFFFBFFFFF8FBFFFCFF797373FFFEFBFFFCF9FFFEFBF3EFF0FCF8F7FFFFF6F1F4E1
D3DAB9E0EBC0CEDDA6A8BB7B91A6618CA35BE0F7AFD6EDA7CCE1A0CCE0A3C8D9A2EFFDCC
FAFFDDFFFFE8E9C5B9FFDFD4FFFFEFF8FFF2F5FBEFFFFFFAFFF9FBFFF8FBF6F8F7F8FFFF
FFFFFFFFFDFFFFFCFFFFFBFFF9FFFFF5FFFF011412677B79F0FFFFDEF2F0DBEEEAB3BFBD
AAB3B2878B8C616264969A99E1EBEAEAF9F6F1FFFFEDFFFCE8F4F4D7E5E5A6C5C076908D
57575FB8B5BEBAC9CCBED8D9819B9C4F6266727480C3CAD487A4A8B8D7DAECF9FFF4FDFF
C7D7D48192886F78733D3D3B32292A5347494234348F817E857B72FFFCECF7F2DEFFFFE8
A49F8291886BA19376FFFFDDEEFECFD0E9B2D7F0B7CBE4ADCBE2B4D1EAC0D9F3C6BBD4AA
F2FFE4F2FFE8F1FFEFDBF3DBF1FFEFF1FFF1EAFFEDE2F5DFE9F4D487916E556342516444
97AF8F85A37FCEEEC5C4E8BAC9ECB6B6D89CD6F2B5C9E1A5C3D29BD0DAA6B5BB8BCED4A6
D1DDAFCEDAAC8894669DA6798D9468A1A77BA5AB7FCFD6AA000800000A00364816C5DCA8
E1FCC9CBE9B5C5E8B2C4E1ABE5F1BFDEE2B0CFD3A1E1E7B7C8D09F58622EB4C18CD4E5AE
C4D89BD2E8A8C3DE99C8E69CD5F5A9C3E694BCDF8BE3FFB0DDE7A2CDCF8ED2D795DFE8A5
BBC68235440042560FCBE199C4DE97D5F1A7C2E098C3E197CFEDA3CBE99FD2F0A6D4F0A6
C4DA91DBECA5CCDC95D3E39C94A15B95A05B96A05BE6F0AB
CCF3A4C6ED9EC3E89AC7E99CCBEB9FCCEB9FCEEA9FD0EAA0CEE89FCBE29CDBF2AEA1B874
C3D998CCE5A3D5EBAACFE4ACD1E1BDF8FFECFBFFEFFAFFF1FBFEF5FCFBF7FFFEFFFFFDFF
FFF8FFFBF1F9FFFBFFFFFDFFC2BCBE746F6CFFFFFAF6F3ECFFFFF8FFFFF6E8EBD8EAF1D2
E6F1C7C6D4A1607234768B46C9E098DDF4ACB9D08ACFE5A5E6F9C1DEF0BCE8F8CBF2FED8
F6FCE2FFFEEDDDBAB6F9D7D5FFFFF6F8FFF8F3FAF3FFFFFDFFF8FEFFF9FFFCFFFFF9FFFF
FEFFFFFCF7FBFFFAFEFFFFFFF2FEFEF1FFFF112A265B7671B5D0CB97B0ACB9CEC99FAEAB
EBF4F3CCD0CFA7A9A8FEFFFFFBFFFFF7FFFDEDFEF6F3FFFDF4F8F9F8FFFFD8F5F1EAFFFF
6A797CF5FFFFE4FFFFE5FFFFEBFFFFEEFFFFF8F7FFFBFEFFA6C1C8A5C6CB748B93283B3F
0A2419A0B7A7B9C7BAF8FFF5FFFFF6FFFEF6FFFDF4FFFBEFFDFAE9FFFFECBEC2A76B7250
8D936DBAC197F3F6C9E2EEBCC0DDA5BBE2A3D1F9B3B9DD9DC5E7B5BDDEB1C4E6B4CBEDBA
D7F8C9E3FFDCDEFCE4C5E5CEA6C5A59CBE9DD7F7E0EDFFF3EEFFE4D3E4C0F1FFE4B9C9AE
000B000013001E2F0D61734B6375452132003C4B126570365C652C666F38686F3B242B00
3D4313272D0030330686895C75784BC9CC9F8C8F64A9AF838C956A313E12506134253B0C
143000A2C291BBE0ADD6F6C5BDD5A3BED29FDDF1BECBDFACD0E4B3C8DFABADC68F4F6B31
8EAC70D8F6B8DFFFBCC2E69EBBE194CCF3A4BAE492BEDD8FD7E09DDFDE9EECEEADD0D593
D4DD9AE5F0ACC4D58F5C7028879E56D6F0A6CFEDA3CAEA9FD6F6ABBFE195C1E196C8E49A
D3E79FCCDC95DBE8A2CFDC96DAE5A0ADB772A6AD69A5AC68
C7F0A1C8EFA0C4EB9AC1E696C4E797C7E899C8E799C8E497C7E398DAF4AAC2D991D8EFA7
A8BF79C8DF9BE1F6B3CDE0A8D0DEBAF6FFE9FBFFEDF9FFECFCFFF1FFFFF7FFFEFBFFFDFE
FBF4FCFFFCFFFAF3FBF4EDF4F1EBED45413EB3B0A9FFFFF3F2F5E2F9FFE5E8EFCED3DEB4
CEDCA799AB6F576C29ADC47CD2E9A1C6E099D6EFAEC8DFA7F7FFDDF7FFE3E8F7D8F9FFED
F1F8E8FFF8EFC7A4A8FBDCE1FEFFFAF7FFFDF9FFFFFFFFFFFFF6FFFFF4FCF6FEFFF7FFFF
FBFFFFF9F8FDF9F7FCFBFFFFF1FFFFEDFFFF2A44414D676486A19C9BB4B0E6F9F5F7FFFF
E8EEECB5B5B5A8A6A7FFFFFDF8FAF7EDF4EDF8FFFBF9FFFDFFFFFFECF4F6B6D6D1678F87
14312F6581827BA3A289B3B28FB0B594A8B17E7D8D7D80914360680E353A000C13122F33
98B7B2E5FFF7E4F7F1F4FFFAFBFDF8FDFCF7E2E1DCFFFFF8FCFFF6F2FAEB7885710E1E03
CDE1BED6E8C0C2D5A7D0EBB8B3DCA46E9E604E8136608F49A3CD9DC3ECC2B8E0ACC4EDB5
B5DDA9C3E9C0B2D5BD96BCA38CB2897AA379749B80749A81AAD2ADB2D7AEC1DEBFEAFFE5
3B4930434831818167918C6E918C64BCB889BDBC86D1D59ADCE6A9E2F0B3ACBE824D5F25
3E4710A6AD776D74408E956151582569703D7A8050C0C899DAE6B894A477ABBE90667D4F
718C5FB5D5A64D6E3F85AD7B9BD197D8FFD5ACE6A9A6DEA1D1FFCBDDFFD4AFDCA367925A
62895074975D3C5E229ABA7BD5F3B3B9D693E1FCB7D5EAA7E5EBADBFC182DBE0A0E9F0AD
DBE4A1D1DE98DCECA5AEC37899AF66AAC276BCD68CC9E59ACBEA9ED4F4A8DAF8AEC9E59B
D7EBA3C1D18AE6F3ADD4E19BDBE6A1CFDA95D9E39E838D48
BBE194C4EB9CC8EFA0C6EB9BC8EB99CCEF9DCDEE9DC9E898CCE999C7E494DAF2A6BDD589
9DB36BD0E69EC7DC97D1E5A8D2E1B8F9FFE8F9FFE8FAFFE9FEFFEDFFFFF1FFFFF8FDF9F8
FFFDFFFEF8FFFFF9FFFFFDFFFFFEFFF0EDE8F7F5E97C7E69767D5BBCC79CE8F4C473824B
899B5DB6CB86CCE39BD0EAA1C7E19AE1FAB9CEE5AFE6FBD0F5FFE6F4FFEEF8FFF6ACB8AE
7C837B6E69653A1B2182676E7377766E7E7B7A868675787DB1A7B0888189667173798B8B
A3ADAEAAAFB28E92956E76787888886A807E00080518312D556E6A7489847C8C89727D79
8A8A8A514D4C5C53546F67657E7A7763645F7D827B282F280D0E103644440F3A31000F07
000D0F253D410025241347451444466B8C93757C8C818A997DA6AA3E706F102F345E757B
657F7EB7CEC8E8F9F3E8F3EDB8BAB568676237363194958F7C817AB2BCB10F200E011500
C5DDBBC3DAB0CEE6B4C9E7B36E9D698BC187C5FDB4C2F7B373A2766F9B7782B17DBCE9B0
C1ECB7B9E4B76B93793F674CBFEDBCCAF9C575A180406F4F42754CCCFDD0BCE2BDC4DEC1
69775E252813D0CAB2F9EED2DCCEA9B5A87BB5B079CCCD91778142899C5A93AC6A88A15F
DAEAABD0DEA0D7E5A7DBE6AAAFBA80626D3537410C6D7A457A88556C7E4C91A574DBF3C3
BCD6A7BFDBABDAF7C9BFE7B381B97C3C7D3B0E4C0D1D591B083F0583B97F1849121B4A14
39642F8EB580C4E9B5C7E8B383A16B90AD755370366A82466A783B3D46074E58198C9856
CFDC97D1E19AD5E79DCCE196CEE398B3C97ED1E79CD8F0A4CAE49AC9E399C1DB92D6EDA5
C5D991C6D790CADA93D5E59ED5E29CDBE8A2DCE9A3BECB85
C1E59BC8EDA0C6EB9EC4E99BCAED9DC8EB99C5E793CDED98CAE793C7E490CDE695DAF3A2
4A60158EA358DEF2AACBDE9ED1E2B5F8FFE3F6FFE1F7FFE1FBFFE5F9FFE5FFFFF1FAF9F4
F9F7FAFEFBFFFFFCFFFFFEFFFFFFFDFFFFF6FFFFEFFDFFE2E2EEBC93A5674F62207E934E
DDF5ABCCE69CD1EBA1CEE9A2CBE5A4CDE6AFE7FED2F4FFEAF5FFF4E8F7F0E5F0F4000307
00080732312F684D562C151F01090B000908788A8AA0A9AEE7E4ED0F0E16697B7DB0C9C6
AEC1BF0004042C36351822230004053242420006040006040006045F6F6C000302060A09
0A04060700002B1C1F7668686155557E7673030000AEB3ADF7FFFFD7F6F00D4B3C3F746A
6E727BFEFEFFC6EEF0417F7C3C837DBDF5F4EBFFFFEEFFFF468781084941D7EBF2F7FAFF
F7FFFF626F68B9C0B89092874743383E382C0B04002421184A4B434E5649293624000800
CFE0BCD0E3B6D1E4ADC2DDA8538153B4ECBDACE4A5B7EDB3C0EFCD001700447244C0EFB9
BCE8B3BFEABD85AE90C6F2D1B2E3ABB4E7ACCDFED1001300154F1DB7EFBEC5F2C9B9DBB8
5E7257313921050300342D10847B54605A2AEAE9B0DBE1A1D6E5A2D1E6A1BCD68FD2EDA6
D5F1A7BFD990CBE59CE5FCB6C1D691D1E6A3D4E8A9495D204B5F244F642B152900000D00
031B001C3400CCE7B4CFECB6C4E6AACDF1B4B7DAA0C5EBB2C3E8B2C2E9B4BFE5B4C2E8B9
BFE6B95A81544872445A845686B183BCE7B9BEEAB9BFE6B1C4DDA3CFE3A495AA69415613
92A860DAEEA6D5EA9FCADF94CCE1949BAD616A7C32C3D58BD6E7A0E1F2ABD0E19BCBDC96
95A9614F631B8FA35BD0E49CC9DD95D4E8A0D1E59DD0E49C
C8E8A5CDEEA9C9EAA5C6E89ECCEEA2CBEC9DC6E796CCEC99D1EE9AC5E28ED9F29FBBD483
91A6599BB063BCCE84D5E8A6C9DDAAD6ECBECFE2B4D3E4B7E7F4C9F3FDDAFEFFECFEFFF4
FFFFFFFFFEFFFFFEFFFEFEFFFDFEF8F8FAECE9EDD4D6E1B7D3E6A6CFE698DAF1A3C8E092
BFDA8BD8F4A7CFEBA1C3E09DD3EFB5C2DCAFF4FFEAD1E4D13645408D9AA0767F8ED4DDEC
EEF9FB9D9D9D150008D8C3CC8F999BAEC7C4708586B1BFC2ABA9B4E7EAF1F0FFFFE1FEFA
F0FFFFC7DAD8A1B0ADAEBAB8A3AFAF7E8A8A010D0D707F7CEEFAF8F8FFFFFCFFFFCCCACB
FDF3F4F3E4E7DAC7C9FFECEEFFF6F6FFFCFAFFFDFAFCFEF9F5FFFF90B5AD3E837180B8AD
626470FFFCFFE3FFFF8DCFCB1B68605B9C98EBFFFFE7FFFF4D938934766CF4FFFFFFFEFF
FBFFFA7582706D756070745BB6B99EB8B89E75775FACB19BF2FEEABFD1BB71856A29411F
B6CD9FD1E8B0D2E9A5C6E4A629562BC5F9D2BAEFBBC0F2C1B6E3C475A0842D582DA0CA98
C9F4BFAFD9AB658F6BA8D5AC7FB174B3E7A571A36E7FB3822B622B7DB27CABD9AAD8FDD4
839E7D4D624392A07FD1DBB6E3EABED8E1ACD5DFA2CEDA98C9D893CCE099EBFFBACBE59C
C4E395C6E999D3F4A5B6D68AC7E398D7F3A9BAD48DD7F0ACDBF1B1CAE0A2BED39893A86F
80955C6A7F47637A42152D006C8448738B4D688044617A4169824B6B8653738F5F5C774C
93AF87BEDAB46B89655F7D597C9C7789A88695B49275966BC6E5ACB9D79788A563AFCC89
C6E19AC7E198D0E69DDDF2A7E2F4A8BBCB8090A057D2DF97CCD792D0DB97D1DC98DFEEA9
7B8F47C6DC9392A85FA6BE74E5FDB3BED68CCDE59BD3EBA1
DBF6BFDAF5BECDE9AEC6E2A5CCE9A6CCEAA2C9E89CCEED9FD2EF9FC5E290CFE897CCE496
CFE497899E53E0F1AAD4E8A3CFE7ADC5DEA7C3DAA2C3DAA2D4E6B2E0F0C3E6F1CFFCFFEF
FEFFFBFEFFFFFCFDFFFEFFFFFEFFF6FBFFECE5EFCDCCDAA7C5DB90D8F29BB8D17DD9F5A1
DCF9A9C4E298B7D491D7F4BAC9E5B5CAE4C1687E698FA39ABDCCD1CCD8E6D8E0F7AEB6C9
929DA19C9C9C957E88FFEEF7F8FFFFE0F9F6DDF2F3DEEDF0DCDCE49FA2A9819999A7C6C1
7C959195A9A7C1D4D0F3FFFFFBFFFFEAEEEF2C32325B6461FBFFFFF4F8F7FFFFFFFFFCFC
FFF7FAFFF9FDD1BBBEFFF7FAFFF9FBE5D7D7FFFCFBFFFFFDF6FFFFB9DAD3124C3EC2F7ED
8B9CA3F4FFFFCCFAFAC8FFFF98DDD8437B7AEBFFFFEBFFFF1F574E0D4037F4FFFFF5FAF4
BACCB2637952A7BD8FDEF2C1D0E2AEC8DCA7B1C997557242B2D5ABC7EDC4BEE8BA7BA671
8AB273B8DE91C4E890CEF4A7729D70ACDBB9C4F3C78DBA8F80A78A6D9273173C13ACD0A0
B4D9A6C1E7B6365D31002800AEDF9EBEF1ACAADEA0A8DA9F729E63B1D8A1B0D8A4A0C798
6B92663A60379BC295C5EBBAC4E7AFC0E0A1C8E3A0DEF3AEDAE9A4DBE6A1D0D794D1DE98
D2F1A1C5EC99C3E996CCF1A1CDEE9FCAEA9ECFEDA3C9E59BC1DA96D0E7A3CFE5A4C6DA9B
D2E6A7CFE3A6CCDEA2D7EDADC5E09DC6E49ECAE7A5C0DA9BCAE2A8C4D8A3B6C79A6F7B53
484F2D6C7153171A001D1B04060100140D00706956898E70819D6AC2E9AA94B878BCDF9B
CAEBA4D7F5ADCEE89EC4DA8FC8DA8EE0F0A5B0BC74939E598D9653C7D08F939C5B263200
BED28BCBE399DAF2A893AD63BFDB90E4FFB5C8E79BC1E094
F6FFE2ECFFD8D7EDBFCBE1B0CEE7B0CEE8ABCBE6A3D0EBA4CBE79DCCE69CCDE59BD9EFA6
DDF1AA8E9F59D5E49FCCDF9DD2ECADC4E1A1D2EFADCDE8A5CDE3A3CEE1AAD0DFB4FBFFEA
FAFFF5F9FFFDF9FDFEFBFFFDFBFFF3FBFFEAEAF7CCD5E7ABD5EE9DD7F49ACEEA95CFEC9A
C6E49ACEEDAAC1DEA4C1DDADB2CCA98AA28A0007008FA2A0EDFBFF93A0B0B7C2D8535C6D
8E989ABFBEBC947982FFEDF7F6FEFFF0FFFFF0FFFFF0FEFFFEFDFFD4D7DCA8BEBC89A8A2
7D9390CBE0DBF4FFFFF0FCF8F1F3F2FDFDFB343633575C58F8FCFBFEFFFDF6F2F1FFFCFD
FFFAFDFFF8FCB8A2A5FFEEF0FFF9FBFFFBFBFFF8F9F5F5F3ECF5F4F0FFFF5E8982DFFFFF
567879E6FFFFDBFFFFA5E0DE629A99406C6DE4FDFFF0FFFF527571365750CDDCD9E9F7EA
5C7555BADAABD2F0BCB7D69BC6E9A9CEF5B4B9E5A83D6E368AC08FBAF4C4B4EFBF67A069
72A763CEFFAED0FDA2C1EC9A87B17F8DB7939EC49D567B527597743D5D38000D007D9A6A
E4FFD0C9EAB5183D07284F16C0EDACB2E19DBCEDAB729F5E476A2ACBEAAE8DB07849713C
95C39274A9756DA36FBCF3BAB3E7A7BFEEAAD5FAB4C3DE97C9DA94EBF2AFD3D292E4E9A7
C3DE91DAFDABBDE090BDDE8FCDEDA1C6E599CEEA9FC8E299D2ECA5D3EAA4C6DB98E0F5B2
C6D997CCDF9FE6F6B7CEE19FD4EAA2D7EEA6DBF0ABDBEEAECCDBA0D6E3ADDCE6B4ABB185
9B9B77BAB595A8A1848C8267493D2558493241311A3938197793605E88497CA465BBE2A1
CAEDA9C8E7A1C8E299CFE59CD4E69CD6E69DD6E39BDAE5A08E975660692A646D2E8D9959
C3D790DBF1A8BAD28889A359D6F2A7C4E397C0E094D8F8AC
FBFFF1F9FFEFE9F7DDDEEDCCDFF1C9D6ECBDCCE3ADCCE4A8C7E09FD0E9A7DBF2AEBED390
D3E6A6C5D596768446B5C888CAE7A4C0E19AD1F1A5CCEB9FCAE69CCAE3A1CDE1AEF8FFE4
F9FFF3F9FFFBFBFFFDF5FFF6EDF9E3E4F4D0D9EBB9CFE5A4C3DE8DD5F39DBAD785C6E49A
C0DF9CC5E4ABDBF8CA2B4623435D446A8272E5FAF38EA0A085949BF1FFFFF5FFFFE7F1FB
FBFFFFFFFEFBDDBEC6FFF2F9FCFFFFDAEDE9ECFCFBF9FFFFFFFBFFFFFEFFF2FFFFE6FFFC
F2FFFFF4FFFFF0FCF8F9FFFFFEFFFAFFFEFB676863C1C3BEF9FBF8F3F4EFFFFFFBFFFDFB
FFFAFDF6E3E7CEBBBFFFF9FDF0E4E6FFFCFDFFFEFFFFFFFFFCFFFFF3FDFFE7FBFCE7FFFF
43767196D1CB82B8B82A5A5C4D7074B3CCD1F2FFFFF7FFFFFBFFFFCAD0CC1522190C2311
A0C1A47FA57E8FB689CAF5C0BBEBB1AFE5A9BFFCC30C501F0F572F59A57F5FA984286D41
61A069BAF3AFBCED9CB3DF92C0E7B032562A18370E86A279627E4E647E4E687E4FA4BA89
BBD39FA2BE84B4D495C2E5A3769D5E9EC888C2EFAA87B169BCDA94C6E19ECCEFAFC4EDB1
BAEBB3A9E3A976B37884C585B5F2ADBDF2AAB9E59AC5E59CD9EAA4B2B7759F995D9D9B5E
8F9E59859C54D7EEA6D4EBA3C0D78FDCF3ABCCE29AD9EEA9ADC27DDDF2ADC8DC97C8DC97
D7E8A4DEEEADC0D08FDFEBA9D3DA96DCE29CCDD28FD1D6968C9053989D63AEB37DB3B785
A7AA7B8C8F62777A4F8D93679DA3778D9367272D01657546A1C48E00130085AD71D6FABC
C6E6A5C3E09DDDF8B1C9E197D4E8A0D2E39CD2E29BD3E29DBECD8AC9D897CFDD9FD9E9A8
CDDE98E5F6AFDDF1A994AC62B9D389C8E79BD7F7ABBFE194
FEFFFDFCFFFBFAFFF5F4FFECF3FFE7E5F6D4D3E5BBCCE2B1CEE5ADD3E8AFD2E6ABCFE3A8
CEDDA4E0EFB8818E5894A86BC9E8A2C3E89AC7EA96C4E690CAEA97CFEBA1D3EBB1F0FFD8
F3FFEAF8FFF8F9FFFBF3FFF1E0EED4D3E5BBCFE4ABCDE7A0CCE89BC8E797D0EEA4DBFAB7
C5E4ABC2DFB1C0DEBC000B00C3DBCBE8FFF78FA3A13A4E4FD6E8ECEFFEFFF1FEFFF8FFFF
FEFFFDFFF5F3E4BFC6FFF4FBFFFFFDF7FFFFF8FFFFF5F9FCFFF6FEFFFCFFF5FFFFF1FFFF
EFFEF9F8FFFFF9FFFFF8FDF9FFFFFAFFFFFADCDBD6FFFFFBFEFFFBFEFFFBF7F6F2FFFBF8
F1E5E7DACBCEB6A6A9FFF9FBFFFCFFFBF9FAFEFFFFF1F5F6FCFFFFEDF2F6F8FFFFEEFFFF
2E5C5A3C706E4E7B7E466C6FA3BFC3EDFFFFF4FFFFE6EEF0FFFEFFFFF7F4000100000A00
A6BFA25D7D56608454B4DFA7BAEAACA9E1A2BFFFC6327B46338157469671125E3A00431A
71AD79BEF2B0C6F2A5C7EDA0BEDE9D2B4812072100A1B88A5F74398FA366C8D9A39BAC78
B7C8946D8247C6E19AD2F1ABD2F4B7B1D79AC6F0A8BCE597C6E798C4E397C8ECA6C5EFAD
BDEDAFB5EBAF548E5183BF7FBDF6B1BAEEA6CEF8AEC3E199CEDF99B5BB7B959358A4A267
9DA667576323A9B575E1EDADCBDA99DBEAA9C4D4938F9F5E7F8F4E6C7D39A4B873CBDF9A
E3F4B0CFE09C6E7F3BD0DF9AE9F3ACD6DE959AA15BA8B26D70793896A061B3BF81D7E2A6
D5E3A8E9F8BDD9E8ADD1E3A7CDE1A4D6EAAB92A8687E985BAED199143B06ACD299C4E6AA
C3E1A3CAE7A4C1DB949FB66EDBF1A8C8DC94CEE29BD7EBA6D5EAA7DEF3B2D1E7A7CFE4A3
D0DF9AD4E19BA9B972A9BD75DBF3A9C4E095D6F6AAB9DB8E
FBF9FFFFFEFFFEFFFFFCFFFBF9FFF4F1FFE8E3F4D4E2F4CCE4F7C9E0F4C3D6E8B6EBFDC9
D2E0ADD4E2B1CEDAAAA1B47CB1D389C6ED9AC6ED94C6EA90CAED93CAE999D4EEADD8EEBF
E0F0D5F3FFF2F8FFFAF5FFF2E0F0D3D1E7B9CFE8A7D0ECA2D8F4AAB9D78FC9E6A4C5E2A8
BCD9AB33512D000B00B5D0BFCDE7DEA3BCB8BAD0CEF1FFFFE9FBFBF4FFFFE2F0F0F9FFFF
F6F6EEDCCAC6EBC0C7FFE9F1FFFCF9EBF4EFF0F6F4FFFEFFFFF8FFFFFBFFEFF8F7EAF9F6
F8FFFFFBFFFFF5FAF6FFFFFBFBF6F0FCF7F1FFFFF8FEFFF9E8EBE4FEFFFAB7B8B3AEAAA7
A9A0A1FFF6F7FEF3F7F9F0F3FFFDFFF8F9FBF9FFFFF8FFFFEDF5F7F8FFFFF5FFFFC7D6DD
000B13758992E8FFFFE3FFFFE3FFFFEDFFFFF4FFFFF5FEFBE5E6E19D948F95807BCCBCAD
8F9372CBDBACE0F5BACBE8A5CCF2A7CDFDB1AEE7A013551773B985BAFFD2A8E9BFAAE4B4
C5F2B9C2E6A0CAE691D7EF9992AA5EDAF0AFC9DBA9C8D9A5D8E7A2E9F6AEC6D19577814C
8C9963D4E4A6E1F9ABC2DE93C7E6ABBFE2A8C0E8A1CEF8A6C9F19BC7EF99C7F2A3C0EBA4
B5E2A1C6F4B67AA76C88B678BCE6A6C9F0ADBEDF986E89426C803BC9D895CED798DCE0A5
D5D59FCBCA9485854F93935DE5E8AFD2DA9F97A16497A365D0DC9E000C004C5C1BB8C887
80944F95A96485995293A9607F9B4E8AA95984A355CAE99DCCEB9FDEFCB2CBE99FC9E79D
C6E49CB5D389C4E397DBFAAEBFDE90C1E090D2F29FCDEDA2BCDFA58BAD7B9ABB86BFDEA5
D7F3B8A7C180738C48B3CA82D0E89EC5DD93D7EEA6CEE8A1C6E19ECCE9A7C3E1A1C8E1A0
DDE9A7424C078E9954DDEDA6D3E9A0C9E399BDDC90DCFCB0
FEFBFFFFFDFFFEFDFFF9FAFEFCFFFDF8FFF7F5FFF0F8FFEFF8FFECF5FFE3F9FFE3D8E7BE
DDEABFD2DDB2CBD7A9D7E8B289A45FBFE091CBEB98CEEE99CAE793C3DE91D4EDABD0E4B1
D3E5BFEAFADFF5FFEDF4FFEBDEF4CDCCE7B4C6E4A4C7E6A0C0DD9AD8F5B5C8E3ACCAE5B8
001200000D00E6FFF2DBF5EC1D3632718785EAFEFDF2FFFFF4FFFFECFBF6F8FFFFF5FAF4
FFFAF4FAE6E5FFF3FAFFF5FAFEF9F6FBFFFDFCFFFFF7F7F9FFFAFFF0E5EBFCFFFFF9FFFF
FAFEFDF0F2EFFEFFFDF4F5EFFFFFF6FFFDF4FFFFF7FFFFF87A7D76AEB0ABFEFEFCFDFCFA
FFFDFFF7F1F3FFFDFFFFFEFFFEFEFEFCFFFFF2FBF6F8FFFFF7FFFFF8FFFFDCEBF05F6E75
73818EF2FFFFDFF5FFEAFFFFE6FFFFE7FFFFE2FDF6F7FFFBFFFFF68A7C73FFF8EFFFEAD5
E3E5B6D7E5A7CEE29DC5DF95CCECA0BCE69AB6EAA27BB6744C8B54ADEBB8AAE2B1CAF9C3
C4E6A9C9E098DFEB99D8E48ED0E694C7DE96D3E8ADE0F4B7BCD184D3E697DDECA9CCDA9D
D5E5A7D3E3A2CDE494C6DE92CFE7ABDAF3B9C6E49EC8E99ACAED99CBF19EBFE497C5E9A3
D0F3B1BADC9F6584495D7C40CAE8AAC8E5A385A05BD4EBA5D4E9A4CFE2A0D9E9A8D3DFA1
D6DBA3EBEEB7D8DBA4979A61D0D59BE0E8AD959F63D7E2A68E995D010F006A7A3CDCECAD
C9DC9AD5E9A4D6EAA3D2EAA0C6E999D0F7A6BDE294CCF1A4C3E599C0E298C2E299D0F0A7
D4F4A9C8E89CCEEEA2BFE08FCAED9BCFF59EBDE38CCCF3A4C2E6A9DDFFCC85A66FC9E8AF
C5E1A496B06F78914DD5ECA4465E14738B41C2DC93CEE9A2C7E4A1CFEEABC9E9A8CDEAA7
91A55ED2E29BD3E49DD1E59DCAE097CBE399DBF5ABC0DA90
FCFCFCFDFDFDFFFEFFFFFEFFF8F8FFFBFBFFFCFFFFFCFFFFF7FBFCFAFFF9FCFFF3F7FFE7
EAF4D1DEE6BDD8E1B2D6E3ADBDCC91415315BACA8BD7E7A6C7D894D6E6A5E4F4B6C6D59C
D4E7B0D9EDBAE3FBC9DFFBC8D4F2BCCFF2B8BDE4A5C2E6A8C4E0A6CAE2B0CFE8BE546D4F
47604DDDF7ECCCE7E291A9A9EEFFFFF1FFFFF2FFFFF5FFFFF8FFFFFBFFFFFEFFFFFFFEFD
FFFBFBF4E0E2F3DEE3FFF3F6F9F9F9F7FDFDF6FFFEFBFFFFFFFEFFFFFEFFFAFAFAFEFFFD
FAFCF7FCFFF8FEFFFAF5F8EFFFFEF2FFFFF48D8A81B0AFAAFAF9F5FFFEFFFAF8FBFFFEFF
FFFDFFFFFDFFFFFEFFFFFEFFFFFFFDFEFFFAFCFFF8FBFFFAFBFFFDF6FFFFE0EFF45F787F
50727CDEFFFFE9FFFFE6FFFFDFFFFF62948886B19ED7F0DB786F606C5648FAEBD8F4F2CC
D2E1A0D2EB9AC9E495D4F3A7C0E49CBFE8A4C2F2B46CA26849824BB4EBB4BAEBB3C2EAAE
D5EDAFC8D590E1E199E0E4988FA759C0E094C6E69DCAEAA1CFF0A1C6E597D0ECA2CBE69F
C9E39CD0E79FC9DE93D9EAA3ACBB78586424263100D0DD97D3E7A0CFE59DD2E7A2CCE19E
CDE0A0D1E3A5697B3D495B1DADC080556A29AEC380CADF9CD1E6A3D9F0ACC8DF9BD5ECA8
D1E8A4D3EAA6D2E7A2D4E9A498AC67D1E5A0AFC282D4E3A8819059000B0062713ACDDCA3
D5E7A9CCE09BDBEFA7D0E89CCEEDA1C9E99EBAD890DBF4B0CBE1A0CFE3A4DCEEB2CCDEA2
D6E8AACADF9ECFE8A6CBE69FC6E89ECCF3A4B7E091C4EEA2C3EAABC7EAB089AB6FC4E4A5
DCFABA6A87447A944DC7E198CBE39996AE649EB66C738D4492AC658FAA65A0BD7ACDECA6
7C9E51DCFFAFBEDF90C3DF92D9F3A9D6ECA3C9DD96DDEEA8
DBD8CFFFFFF8FFFEFDF7F2F6FFFCFFFFFCFFFFFCFFFBF9FFFEFEFFFEFFFFFEFFFBFCFFF3
FAFFE8ECF6D1DAE5BACCD8A6CDD8A0D2DDA1737E42B7C385E8F4B4C4D090CFDE9DD4E5A1
D1E6A3DEF7B3C1DE9BC9E9A6C7EAA8B7DE9BB9E2A0D3F7BAD9F4BFBFD4A9576C4B6D836C
F0FFFBBAD3CF688082DAF2F4F0FFFFF1FFFFF5FFFFF8FFFDFBFFFDFEFFFDFFFEFFFFFCFF
FFF9FDF7E4E8FEF2F6FFFEFFFEFFFFF9FFFFF6FEFFF8FFFFFCFFFFFFFFFFFFFEFFFFFFFB
FFFFFBFCFDF7FEFFF8FEFFF4F7FAE7B5B7A2FBFCEAFFFFF3FFFFF7FFFFFBFFFEFFFDFBFE
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFAFEFFF8FEFFF8F7F9F4FBFFFFE9F6FCD1EAF1
466E78B3DDE9CEEBF9C7E8F197C6C05489776E9E84F0FFEF544532C0A592FFFFE4E9F1C2
D2E89DD2F098C1E18EC9E99DC5E9A3CBF3B4B2DEA337683053864EC7F8C0B4E0A3D3F5B8
CDE1A2D8E1A0A6A3604F520BB8D084CAEFA1C3E89AC4E99BC3E89ABADF91CAEC9FCCECA0
CFEEA2C7E197D0E69DD7E7A04D5813D5DC98DCE19EBFC6835C68264E5D1C9BAA69B2BE7E
C7D393DBE5A6DBE5A6B5C181727E3ED1E09FD8E8A7CADD9BD2E7A4C2D995D5EEAAC8E39E
C6E69DB9D98EC1DF95D6F2A7AAC47A9CB36BA1B675D1E3A794A26D000E00788653DBEAB3
CEDDA2CEE29DC9DD95C8DE93C9E39AC8E39CA0B773C8DD9C89995B93A166838E56838E56
8F9C64E1F0B5C9DD9EC1DA98CAE9A3D0F4AAC7F0A2C1E9A0C3EAA9C2E6A8B3D598C0E09F
A5C481BCDA94CBE59ED9F3AAD0E89EC2DA90CDE59BD3EAA2D4EBA5CDE7A0D6EFABB6D48C
D0F5A7B0D786D1F4A4C9E89ACCE299D1E29BD6E19DACB572
54483CC1B4ABFFFAF4FFFCFAFFFBFFF7EDF6F0E8F3FFFDFFFFFEFFFBFCFFF5FAF6F6FEF1
F7FFEFF4FFE5E8F7D6DEEDC2DAE8ABD7E49FB3C07B8B9B54ACBC73E4F6AABDD285E4FBAB
D3EB9DCAE797C9E898DAFBACC6E89BC7EC9FC3E99ECAEAA7C2D9A5CBDDB77D9072647763
EAFFF6A8BEBC293E41E5FAFDF1FFFFF2FFFFF7FFFFF9FFFDFCFFFDFFFFFBFFFEFDFFFCFD
FFEDF2EDD8DDFFF6FAFFFEFFFEFFFFF9FFFFF7FFFFF4FDFCF2F6F7FFFFFFF7F5F6FEFDF9
FFFFFBF7F8F2F8FBF2FAFFEFFAFFE0C3C9A3FFFFE3F1F6D8F8FCE5FFFFF1FAFBF3FAFBF6
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDF2F1EFFEFFFFF8FFFFE8FBFF
2D4E5789ABB58FA5B26C838B597E778EB9A6BDE8CCF4FFEC5B4933B89C86FFF6D7EEF6C5
CCE49ACFF099C7E696CBEB9FC2E39ECAEEAEC8F0B277A3667AA76CB7E5A7CBF5B6BBDE9E
C5DA99A3AE6C9E9F5D999F59CBE198CFEFA3CEEEA2D6F8ABD2F4A7C5E79ACAEA9EC5E599
CDECA0D8F2A8C5DB92D5E9A16B7B34DEE9A4CFD994D8E39FB2C17E9EAE6D8191507E8D4C
CFDE9DD1DD9DAFBB7B9EAA6AB1BD7DD0DF9ECFDF9ED4E7A5C3D8957D94506A813DC2DB97
DCF7B0D7F3A9D4F0A6CBE59BCEE69CBFD58DDDF0B0D4E3A8DDEBB627330197A371C9D8A1
D9E8ADD8E9A5DAEEA6DEF4A9B3CA828DA45E869D59BDD291CBDB9DA4B3788593586B793E
5D6C31B1C385D3E8A7D1EAA6CAE69CCCECA0B6D88BCCF0A6C2E6A6CEF2B4AFD194C8E8A7
81A05DCFEDA7D6F0A9BFD68ED6ECA3CCE299D6ECA4D2E9A1C8DF99CCE39DC6DD99E2FCB5
D2F1A5CAE99BC6E096E4FAB1C7D48EDDE7A2D8DA99868646
2714054532248F7D73E4D3CCFFFBF8FFFAFDFFFBFFFFFDFFFFFDFFFFFFFFFCFFFDFBFFFA
F8FFF6F3FFEFEFFEE9EBFAD9CEDBA3D2DF9AE5F4AFA4B56E96AB6093AA5CD6EF9EC5E08F
C8E593BCDC89CCEE9AC2E392C1E293E4FFB6C5E599C4E19EDEF2C130401C000F00DCEDDD
A7B8B2768888F1FFFFF1FFFFF2FFFFF5FFFFF8FFFFF9FFFBFEFFFBFFFFFBFFFEFDFFFCFD
FFF5FAECD7DCFFFBFFFFFBFCF6F7F9F9FFFFF9FFFFF9FFFFFCFFFFFFFFFFFDFCFAFFFEFB
FFFFFAFFFFF8FDFFF7DAE2CB596537CDDAA2D2DFAACEDAACDBE5C0E4EACEDADFCBFFFFF4
FFFFFAFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFDEBE9EAFCFFFFEBF8FF
7A929CE4FCFFF1FBFFF7FFFFEDFFFFE4FFEFC8EBCBACBD9969553AAC9174EFE7C2CED8A3
CAE69BC5E894C9EA99D6F5A9C3E29CBEDE9BD9FCBCCAF1B2C0E8A9D2FCBCC7EEADCBEBA8
DAF0AF83924FD3DA97DBE5A0CEE49BC9E59AC5E196C3E296C1E094C4E397CEEDA1CDECA0
B8D78BC9E59ADBF3A9CFE59C95A961CCDD96D1E19ACDDC97D6EAA5DCEFADD0E3A1D0E09F
99A96899A867B3C281CBD797DDE9A9DDE9A994A362B4C483BDD08EC9DE9BD3E8A591A864
7F9952A5BF76D7EEA6C4DC92D1E79ED2E69FE4F4B5C1CF941D2A00687442E2EEBCD6E3AD
59682D9FB06C8599518A9F54A9BF77C4D994E8FBB9CDE09ED8E8A9CADA9CDFF1B3CCDEA0
CCDF9FCFE2A284995670873FCBE399D7F2A5D9F4A7CBE99FC7E7A6C9EBAE87A66A8AA868
4C6927CBE6A3C2D995DFF4AFCDE39BD5EBA3D8ECA5C9DF97D0E5A0D9F0AAD0E7A3BFD992
BAD98DC8E799C9E399CAE097DEEEA799A45F292E00B7B978
3F24132307003E2417A48C80FEEAE1FFFBF4FFF2EFFBF1F0F8F2F2FDFCFAFEFFFDFBFFFD
F8FFFDF7FFFBF3FFF7EEFBE7F0FBD0E5F3B8D5E4A9DBEDAFDDF4B047611AA2C076C0E095
CBEB9FD8F8ACCFEFA3CCECA1D6F2A8C0DB94C3DA96D6EAAF97A67D00070044503CCCD8CC
232F2DBAC8C9ECFBFFEEFDFFF5FFFFF7FFFFF9FFFDFBFFFAFFFFFAFFFFFAFFFEFBFFFCFB
FFF9FBF0DCDEFFFAFDFFFDFDFAFCFBFBFFFFF9FFFFFBFFFFFCFFFFFDFDFDFFFFFDFFFEFB
F6F5F0FFFFF8FCFFF6AAB398455419C9DD95D4E5A1DEEDB2CBD9A6C5D2A7E7F0D1FEFFED
FEFFF4FEFFFAFFFFFDFFFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFFCFDF1E8EBFFFEFFF6FAFF
697A82F4FFFFFDFDFFF3F3F5F0FFF3D7F1D4D0ECC6C3D0A54834117B613CD1CD9EE0EFB4
D0F0A5C1E794C2E595D3F2A6CEE9A2C5E09BC6E3A0B3D390D3F6B2B3D893C7EBA5B2D18D
AFC884E3F6B4CEDA98D5E29DD1E59DD7EFA5D9F1A7CFE99FD1EBA1D4F0A5CAE69BC3E296
D9F8ACD4F0A5C0DC9199B369ADC57BCCE299D9EFA6DCF2AAC9E09AC9E09AC4D994DEF2AD
C6DA95D2E39FDCEBA8DCEBA8CEDA9895A15F82914ED4E5A1D7E8A4DAEEA9E3F7B2C4D994
829752849A52CADE97D7EBA3D6E7A0CDDC97C8D496E1ECB2242E0066703EDCE6B4CBD8A2
DDECB1CADB97D6EAA2D0E59AD5E69FDBEAA5CDDE9AD8E8A7CADA99D9ECACC7DC9BD0E5A2
DCF1ACD9EEA9DCF2AA576D24D4E99ED7EC9DD0E394D1E79ECBE8A8C0DFA399B77B84A161
4D6726D8F1AFB9D08CE0F5B0CCE09B91A560B1C27ED7EBA6B2C681849954DCF1AED3EEA7
D1F6A9C2EB9CDCFFB3C1E195C2DE945B712998A762DBE8A3
D9BCAE7F62544326182D13062E160A735F54D1C0B8F3E6DEFFFDF8FFFEFAFFFFFBF7FCF8
F7FDFDF8FFFFF8FFFFF6FFF7EDF6DBFCFFDFFBFFDFC3D4A8CEE4B3D3EEB9C2E1A8B3D297
7B9A5E99B87C7F9D617894598CA36B96A972B6C491000800394223747E66B0B8A98A948C
F8FFFFF7FFFFF5FFFFF7FFFFF8FFFFF8FFFDFBFFFBFCFFFAFFFFFAFFFFFAFFFEFBFFFCFB
FFF8FAD4C0C2FFFAFDFFFDFDFEFFFFFBFFFFF9FFFFFAFFFFFCFFFFF4F4F4FEFAF9FFFEFB
F9F6F1FFFFF8FDFFF4A3AC8FCDE2A1D1EA99D6ECA3C5DA97DAEEB3D3E3B4EBF7D3FCFFEA
FCFFF3FEFFF8FFFFFDFFFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFF8FBFFFCFDFCF7FBFEFFFF
586369F2F9FFFFFBFFFFFDFAFBFFF1DBF0CFD2ECBFE1EDBDA39065856F4082824C96AB6A
C8EA9EC4ED9EC8EA9DC5E399CCE39BD8EDA8CAE19BA6C0797E9C5654732DDAFAB1C2E299
809B56D0E7A3D9EDA8CBDC98D1E29CD0E49CC8DC94BED48BD4ECA2D8F2A8C5DF95D0ECA1
8CA85D58772B82A155CFEBA0C5E196C9E59AD3EFA4BDD98EC9E39CD8F2ABD6EDA7C2D792
E7FCB7D0E49FC1D28ECDDC998F9B5999A563DEEDAAD4E3A0C5D692E0F1ADB9CD88D8ECA7
E0F4AF9CB069B0C17BCADA93DBEBA4D9E6A199A366959E6510180078804FD4DCABCED8A3
E3F1B6D0E19DD4E59ECEE096DAE7A1D0DB97CBD795DBEAA7D9EAA6D5EAA5BFD690D9F3AC
C1D890CEE69CCAE097E3F8AD8EA054DBE99CC6D384D1E198CCE6A7C5E3A799B578D7F1B4
9FB779ADC383D4E9A8C1D492CFDF9E96A763CDDE9AC6D793E6F7B399AD68708341CBE59E
C6E69BC7EC9EB8D88C526E2399B068CDDE98CCD994DFEAA6
FFE9E1FFF8ED8E73681400003A2417321F112A1A0D908277DDD3C9F6EFE5FFFEF8FFFFFB
FFFFFFFEFFFFFEFFFFFBFFFFFCFFFBF1F9EEEEF9EBF7FFF4F3FFF0F1FFEFE5FFE3EAFFE6
EEFFE8C4DFBCCEE6C4DEF1D19BAA8B0006002F331A050900262916FEFFF3E6ECE2FBFFFF
FBFFFFF9FFFFF9FFFFF3FDFFF9FFFFFBFFFBFCFFFAFEFFF8FFFFF8FFFFFAFFFEFBFFFBFB
FFEBEEBCA6A9FFF2F5FDF7F7FFFFFFF8FEFCF9FFFFF9FFFDFCFEFDFFFFFFFFFEFDFFFEFB
FFFFFAFFFFF8EDEFE4BDC8AACCE2A4BED98CD3EAA2C3D998DBF0B7D4E5B8DAE8C4FBFFEA
FCFFF1FCFFF6FEFFFBFFFFFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFFF7F8FFFDFFFEFDFF
EFF7FAF8FCFFFFF4F4FFF9F1FCFFEAD7E9C1C6DEAAC5D29AF0E0ADAC9B659BA465D3EEA9
BFE59AC5F0A1CEF0A4C3DF95C8DE96DDEEA7D8E8A1C3D48DCFE59CDAF4AA325006335107
D5F3ABC0DB94D0E9A5D8EDA8D4E59FD5E59ED3E39CD8E9A2EAFEB6AFC57C50681E4C661C
D1EDA2DCFBAFC5E498C7E79BCAEA9ECAEA9EC1E195D3F3A7D9F7AFB4CF88D9F3ACCBE29C
C8DD98D0E49FCBDC98A5B672B0BF7CDCEBA8D2E19ECAD996D7E8A4CDDE9ADCEDA9D5E6A2
D3E4A0D4E39EDAE9A495A25C505D17535E1A8E985BD5DDA4111800515928E1E9B8D5DFAA
C8D69B5E6F2B51621B50601757611C5C632058631F4956118D9E58D2E8A0D5EFA6CBE79C
CEE89ED6F1A4C5DB90E0F2A6919F52485307F0F7AAD9E59DD0E9A8C5E3A789A568CEE8AB
C9E1A3809656DBEDAFDDEDAED2E2A16C7B3AD6E5A4D3E3A2CFE09CECFFBB7F934E001200
D5E6A0C8D792798440A2AB68C3C886EEEEAED3CF909F995B
FFF9F6FFF3EEFFF9F4DECBC46452483424173323160B00001D110373695DD5CCC3FFFEF8
FFFDFBFFFCFEFFFDFFFFFDFFF9F9FFFBFFFFF9FFFFF2FDFFF2FFFFF1FFFFE2FCF1EEFFFA
EEFFF8B7CEBE9CAEA0606E61949C9104050017140FAAA7A0ACACA2FFFFF6FEFFFBF3F7F8
F9FCFFF0F4FDFBFFFFF8FDFFFBFFFFFCFFFBFEFFF8FFFFF6FFFFF8FFFFFAFFFEFBFFFBFB
FFF8FBC6B0B3FFFAFDFFFDFDFFFFFFFAFEFDFBFFFFFBFFFFF4F6F5FFFFFDFEFAF7FDF8F4
FFFFF8D7D7CDB7B9AEB4BEA5D6EAB5CCE7A4CDE5A7DCF3BBBED2A1D8EAC0F0FEDDF4FFE7
FCFFF3FCFFF8FEFFFBFEFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFFAFAFFFBFBFFFEFF010103
EBF4F3FBFDFAFFFBF8FFFBEEFDFFE2D1E2B5D1EAB0D3E3A4BEB47983793C899853C7E99F
C6F0A4BFE99DC7E99FCBE59CD6E7A0D8E59FC6D089BAC67ED2E49ACFE59A92AE63AAC97D
C3E197DDFBB3B6D48ED0EAA3D5E6A0AFBC7684944D8E9E57CBDC95BCD08892A85FCBE399
CFE99FBEDA8FC9E89CD1F1A5C8EA9DBDE294D1F6A8C0E597C9E99ECAE8A0D2EDA6CAE49D
CCE39DDEF3AE90A45F869753E5F4B1CCDB98D1E09DA5B4718B9C587889459DAE6AD3E4A0
D1E09DD3E29DDDEAA5D1DE98D6E19CCCD793E5EDB1D4DCA3414815818757D1D7A7AFB883
636E34AFBE7BC4D48DE0EDA5DCE19EDCE19FCFD693E9F6B1A5B67091A75F6D873DC9E59A
CFEB9ECBE699D9EFA4CBDD91DEEAA0D8E097585C126C7631D2E8A8C4E2A6D1EBAE93AD70
C9DEA39BAF7287995DCCDC9EDCEAACAEBD7C61702F9FAE6DCDDE9ACBDC98D8ECA794A561
7A8944889550929D59D4DB98E3E5A4DADA9AA19D5E5C5819
FFFBFFFBEFF3FFFBFBFFFCFAFAEFE9FEF1E8DBCFC37F73654B3F311D0F020B0000302219
90817C928380FFFAFAFFF7FDF5F2FFF9FEFFF5FCFFEBF7FFBAC8D198ABAFB8CDCE9EB4B2
A1B5B3AFC2BEF7FFFFF4FDFC2F3032010002ACA5ACC1BBBFE3DFDCF3F4EEFFFFFDFEFFFF
F9F9FFF7FAFFFCFFFFFCFFFFFCFFFDFEFFFAFEFFF6FFFFF6FFFFF8FFFFFAFFFDFDFFFBFD
FEE8EBECD6D8FFFAFBFFF9F7FFFEFCFCFFFDFBFFFFF6FAF9FEFFFDFFFFFDFCF8F5FFFEFA
FFFFF8D7D7CDE2E4D9E6EED9ECFED6DEF6C6CAE0B2C9DEB5E1F2CEF0FFE1F5FFE9F9FFF1
FCFFF4FCFFF8FEFFFBFEFFFDFFFEFFFFFEFFFFFEFFFFFEFFFFFBFAFFFFFDFFFFFF000100
D8E3DFFAFFF9FFF8EEFFFEEAFEFFDFD6EDB7BFDE9BD2E7A29E985A575212AAC077C8EEA1
B1DB8FD6FFB3BCDC93D0E69ED3E09ADDE7A2D1D791A1A862D4E199D2E79CD0EAA0C7E69A
CBEBA0CDEDA2C5E59CD1ECA5D1E29CAEBB75D8E8A1DCECA5CBDC9581954DD2E89FD0E89E
D4EEA4C6E297C6E599CBEB9FC5E79AC1E698C5EC9DC5EC9DC4E69AD0EEA4C9E59BC9E39A
AFC67E80964EB7CB84D7E8A2D7E6A1D3E29D71803BB6C580CADB9592A35D9AAE67A4B871
D1E29ECEDD98D7E49FDBE8A2D2DD98D3DE9ADEE6AAD5DAA2333705666C3CD8DEAE6B743F
D6DFA6DDE9A7D4E19BE1EDA5DDE09DDDDF9EDADF9DDAE5A1DBEBA4D3E79FD2EAA0567026
708A40D5EDA3C7DD94CFE197E4F0A8CED58FDADF9C9AA362859B5DD5F3B7BFD89E637D40
112600D9EDB0A5B77B96A668C5D396E6F4B6889658808F4ED4E5A1C6D793D9EDA6D4EAA2
C8E29BD0EBA4CFE9A2CFE6A0D4E9A46E823D4F601CB6C582
FFFDFFF7F4FBFFFDFFFFFDFFFCF7F4FFFEF6FFFCF1CEC4B8978B7D3E30230D0000100000
0F0000462E2AE9D1CDF1E1E4FFFDFFF8FDFFF8FFFFBBC5D178858EB4C3CAEEFFFFEEFFFF
F4FFFFEDF9F9E9F1F3CACED1515055030004D4CAD3D9CFD7F8F4F3FFFEFAFFFFFFFFFEFF
FCFCFFFDFDFFFEFFFFFEFFFFFEFFFBFEFFF8FFFFF6FFFFF6FFFFF8FFFEFBFFFEFFFFFBFF
FEE8EBECD6D8FFFAFBFFFCFAFEFDFBFCFFFDFCFFFFFBFFFEFEFFFDECEBE7FFFEFBFBF6F0
F2EDE7E3E0D7FCFCF0FCFFF1F6FFEAEAFDDFDBEBD0D9E9CFEBFAE3F6FFEFF8FFF3FBFFF6
FCFFF8FCFFFAFEFFFBFFFFFDFFFFFDFFFFFDFFFEFFFFFFFDFFFFFDF8F8F6F9FBFA000200
E9F6EFF9FFF8FFF7EAFFFDE3F6FFD7CCE8ADCAEEA8CEE89FA3A261878343CBE399CAF0A3
CDF6AABDE39AD0EBA4C7DB96DDE8A4D9DE9CE2E5A28D9450D9E49FCFE39BD0E89ECAE89E
CAEA9FCAECA0C7E99DCDEBA1D7EBA385954ECCDC95A7B871D3E49D9AAE66CFE39BD4EAA1
C6DE94D7F1A7D4F3A7CEEEA2D0F2A5C3E89ABEE596D2F9AAC0E296CBE99FCAE69CB1CB82
9EB56D9BB169CCE099D3E49ED6E5A098A762B5C47FD1E29CE2F3ADC8DC95A6BA73B9CD86
889C57C2D38DD2E19CD7E49EDAE7A1D5E09CDCE4A8DBE0A80F13005A5D2E939969C3CA96
DEE6ADCED997D0DB96D3DD96E5E8A5DFDF9FD8DD9BCED794CEDB96CEDF98CFE59CAEC57D
B2C9816C833B8EA45CD9EAA4D7E3A1E2EDABE2E8AAAFBB7DB5CD91809E62ADC98E9EB77D
51692DC5DA9FC2D49A819055DCEBB0D3E1A4CFDDA0849455BACA89CCE09BD7EBA4C6DC94
DFF9B2B8D28BCFE9A2D4EBA5CAE19B465B1650641FCADE99
FCFEFFFAFDFFFEFEFFFCFDFFF9F7F8FFFEFBFFFEF8FFFBF2FFFDF3C7B9AE615144453126
2009012F160F3D241D2A1814D5D4D9EAF3FA838C91A5AFB1F7FFFFF8FFFFEDF8F2F8FFFB
F3FDF5F9FFF844474021221CF7F6F2575350ECE6E6FFFDFDFFFEFDFFFFFDFFFFFFFDFCFF
FEFDFFFFFEFFFFFEFFFDFDFDFFFFFBFFFFF8FFFFF6FFFFF6FFFFFAFFFFFDFFFEFFFFFBFF
E6D0D3D7BFBFFFF7F7FFF9F8FEFDFBFAFFFBFCFFFDFCFFFDFDFDFBFFFEFAFFFEFBCEC9C3
8F8A84FFFCF3FFFFF4FEFFF4F9FFF6F7FFF6ECF8ECE9F5E9F5FFF5F9FFFAFAFFF9FCFFFB
FCFFFBFEFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFDFFFFFDF5F4F2FFFFFDFCFFFF000300
DAEBE1F8FFF6FFFFEDEBECCDE9FBCBC7E5A7D1F7AEC6E2989B9A59999555D5ECA4B5D98F
CBEFA5C2E299CDE6A2A5B574858E4DDADF9FE1E2A6767C3EDEE9A7CDE19CCCE39DCFEDA3
C9E99EC6E89BCBEB9FCBEA9ED5EBA2697A33788942A5B971C9DD959EB26A9AAE66C9DF96
D3EBA1C4DE94C0DC91C1E094C2E497CBF0A2CBF0A2BDE294D3F3A8C3E197C5E1979BB56C
B4CB83CAE098DBEFA8CADE97CBDC964C5D17D1E29CC7DB94D5E9A2DAF0A8C5DB93D6ECA4
DBF0ABD6ECA46C8039768740CEDE97DAE7A2AFB77B5159202A2E0096996AE0E3B4C3CA96
D6DEA5E6EFAECDD792EFF9B2DEE09FDEE0A1DBE0A0D6DF9CE0EDA8EFFEB9D0E49DCDE29D
CBE09BD4E9A694A966516424BACA8CE4F2B7C0CD95D2E4AAB5CF92DFFDBFB2CE935B743A
A2BA804F642B657840AFC18793A269A9B87DE0F0B2C1D1928A9A59BACE89C9DD96D3E49E
C7D290E1E7A9EEF4B693995B525818B9BF7FDCE1A1DEE3A3
F9FFFFF9FFFFFBFFFFFAFDFFFCFDFFFAFAFAFEFAF7FFFEFAFDF4EDFFFCF4FFFCF3EAD9CF
907C7358443B1903000E000001030007120E5D6862F9FFFBF5FCF4F1F7EDFEFFF6F2F6E8
FFFFF4F8F8EC0301008C8A7EFFFFF6ABA89FFFFFF8FBF8F3FFFFFBFFFEFFFBFBFDFAF9FE
FEFDFFFFFEFFFFFFFFFEFEFCFFFFFAFFFFF6FFFFF6FFFFF8FFFFFBFFFFFFFFFEFFFFFBFF
DFC9CCCEB6B6FFF1F1FFFBF9FFFFFBFDFFFCF9FEFAFCFFFDFBFBF9FFFEFBF9F4F0B4ADA7
7D7970FFFFF4FFFFF3F7FAEFFBFFFBF9FFFDF8FEFAF5FBF7FBFFFDFBFFFDF9FEFAFEFFFD
FEFFFDFEFFFDFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFEFDF8F7F5F9FBFA000300
EBFCF2F7FFF4FCFEE8DADEBDD5E9B6C1E1A0C9EFA6CCE69DA09C5D938D4FE6F9B7CCEBA5
C1E198CDE8A1D6EBA8909F5E595F23D1D59AD2D59C888D53DDE8ACCEE1A1C8E19DD1EFA7
C9E99EC3E495CEEF9ECAE797D3EBA1C8DE9599AF66C7DD94D6ECA3DAEEA6CBDF97B8CC84
CFE59CCCE49AD7F1A7D9F5AACBEB9FCFF1A4D1F3A6C0E295D9F7ADBFDB91CEE89F90A75F
DBF1A9D6ECA4D0E49DD1E59EE1F2AC465A13E2F6AFCDE39BCAE098C7DE96DBF2AACDE79E
CBE59EC1DB92E2F8B08CA0588E9F58C9D893A2AC6FDCE4AB2C3000737647D6D9AADFE3B0
E3E8B0E5EEADD0D79389904A5156145C61215157175962216E7937B7C381D0DF9CD6E6A5
C4D797D9EDAEC5D99C9CB075DFF2BAC9DBA7D8EAB8CCE3ADDAF8BCBBDB9CCDEBAF9CB87D
364F15CBE3A95E733A9AAD754C5D2690A268C9D89DECFFBF94A7658DA25DCAE098DCEDA9
E7F0B1C3C78AE1E5A8282C00505515DFE5A5D8DE9EDEE4A4
F7FCFFFBFFFFF9FCFFFCFFFFFEFFFFFEFEFFF9F7FAFFFEFFFFFDFDF0E8E6FFFDF8FFFCF6
F8EBE3F9EBE2C6B8AD7D776B0004000006001A2517353D30737568FFFFF3F7F4E5FFFCEC
FEF7E7766F5FC9C3B5F6F3E4D9D5C9FFFEF2FCFCF2FFFFF8FCFDF8FBFBFBFCFCFEFEFDFF
FEFDFFFEFDFFFFFFFFFFFFFBFFFFF8FFFFF6FEFFF6FEFFF8FEFFFDFEFFFFFEFEFFFFFCFF
FFECF1E7CFCFFFFAFAFFFCFAFFFEFBFEFFFBF7FCF8FCFEFBFFFFFBF9F5F2E3DEDAC2BBB5
EAE6DDFAF8ECFFFFF3FFFFF6FAFCF9FCFFFFFCFFFFFAFEFDFCFFFFFEFFFFFAFCF9FFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFCFFFFFDFFFFFEFF000200
DBEDE1F6FFF3FFFFECD3D9B5CCE3AFC8E8A7BDE39AD1E8A2A0975C675A23C9D397D3E9A8
D1EBA2C6DD95E8F9B59DA76A9EA369C8CB96D2D4A2BFC692D1E0A9D2E7ACC7E1A0CFEEA8
CAEA9FC1E291D0F09DC9E694C7E396D6F2A7C1DB91BCD68CDCF4AACEE49BD2E69EAEC27A
6A7E36B0C67DC6DE94C5DF95D7F3A8C4E397B9D88CE2FFB5C6E297C2DC92DBF5AB778F45
DEF4ABC8DC94C3D78FDAEEA6CFE39B41550DDCF2A9D5EDA3CDE79DC9E59AD7F3A8C1DD93
C5E39BCDEBA1DCF6ADBBD38995AB629BAC66B1BD7FCCD59C343B087B7E4FDEE0B1D9DBA9
B9BC859EA464353A00737A34959B5BA2A86A93995B9EA4667780419EA768E0EAABD9E5A7
E4F2B5CCDEA4CFE2ABC9DDA88CA271859C6EC6E0B3CCE8B8C6E8ACC3E6A6D3F2B6B1CF93
ADC98F415A21B1C68E0C1F00A2B57DB5C98ED0E2A6C5DA99CFE4A1889F59D1E8A0C3D893
CEDE9DE9F7B95868279BAB6AE3F6B4D1E6A3BAD18BCCE69F
FCFFFDFCFFFDFAFCFBFEFFFFFEFFFFFFFEFFFAF9FFFFFEFFFFFDFFFBF6FAFFFEFDFFFEFB
FFFEF8FFFEF6FFFEF4F3F3E7000500000E00000B00020600030100241E125D5347FFFCEF
130500716358FFF6EAFFFEF3A6A297FFFFF6FCFDF5F8FBF4FDFEF9FEFEFEFFFFFFFFFEFF
FFFEFFFBFAFFFCFCFCFFFFFBFFFFF8FFFFF6FEFFF6FEFFFAFEFFFFFCFFFFFCFEFFFFFCFF
FFF8FDF5DDDDFFFAFAFFF9F7FFFDFAFEFFFBFEFFFDFEFFFDFDFEF9FFFFFAC9C1BED8D1C9
FFFEF6FFFFF4FFFFF3FFFFF6FAFBF6FFFFFDFFFFFDFEFEFCFFFFFDFFFFFDFDFEF9FFFFFB
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFF6FAFFFAFEFAF4F6060B07
D6E6DBF7FFF3FFFFECD6DCB8CAE1ADD4F4B5C3E7A1D3E6A4B4A56E604A19A3A36FD2E0A3
D4E8A1D1E59DD5E19F9AA266A8AB76D7D9A8D7DAABE7EFC0C0D09FDBF2BAC8E4A7CAE9A5
CEEEA2C2E191D1EF99CAE793D8F7A9C0E094CAE99DD5F1A6D5EFA5D2EAA0B8CE85DDF1A9
D5E9A1A7BB73C2D88FDCF4AABED88ECDE99EE1FDB2B3CF84C8E298CCE49AD2EAA0667C33
C8DC94D3E79FD0E49CCEE29AC6DA92586E25BFD78DC9E399C9E59AD6F5A9C5E498C8E89C
CCECA3B8D88DCCEAA0D0ECA1C5DD93CDE19AD3E1A3D9E4AA0910009B9E6FCCCE9FA9AB79
656831575C1CD1D693E7EDA7DFE8A7D7E0A1CDD697E2E8AA90965853591D5E64282D3500
000A00D6E4AFCFE1AFC3D9AAC7E1B49BB78E000F005C7D50C0E3A9C3E7A7BDDFA2CEEDB1
D2EFB585A167384F17D1E6AE000C0055692EE3F7BAD5EBABD3E9A893AA649BB26ACFE6A0
D6E9A78D9D5E5265237D924FD2E9A5C5E09BD1EFA7D9F9B0
FFFFF6FFFFF8FFFEF9FFFFFBFFFDFEFCFBFFFBFAFFFBFAFFEFEEF6FFFEFFFFFEFFF9FAFC
FEFFFDF9FBF6EFF2E9FBFFF89AA79DC8D5CB727C734A4B432D28221D120C44322E341F1A
0F00007A6763FFFBF8FFF7F5E0DBD8F7F6F2FCFEFBFCFFFDFEFFFDFEFFFFFEFFFFFEFFFF
FFFEFFFBFBFDFBFBFBFFFFFBFFFFF8FFFFF6FEFFF8FEFFFAFCFFFFFCFFFFFCFEFFFFFCFF
F9E4E9E8D0D0FFFAFAFFF5F3FDF9F6FEFFFBFEFFFBFEFFFBFEFDF9FFFFFABDB5B2EFE8E0
ECE5DDFFFFF4FDFBEEFCFCF0FEFEF6FFFFFAFFFFFAFEFEF6FFFFFAFFFFFAFFFEF9FFFFFA
FFFFFBFFFFFBFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFFFDFFFFFAFFE3D2DABEB3B7141412
F0FDF3F7FFF3F5F7E1D7DDB9C4DBA7DDFBBDDFFFBBD8E7A6E6D09FA4875BA29A6BE4ECB3
D0DD97E1F1A8C4CF8D9CA167858755D2D4A5D8DDB4F6FFD4AFC093E5FDC9CBE9ADC4E39F
D1F1A5C6E391D0EC95CDE994C1E291CCF1A3CBEDA0CDECA0B0CC81E9FFB7C7DD94D3E79F
CEDF98C3D78F8EA25A91A75ED7EDA4DBF3A9C2DA90DFF7ADD9F1A7CFE59CCAE0978DA159
A7BB73D4E8A0DCF0A8C7DB93E6FCB3BAD0879DB56BCEE89ECEEA9FCDECA0BEDE92C8EA9D
BFE399D8FDB0B7D98DD6F5A9D6F0A6B8CE86E2F2B3D8E3A9020900878A5BACAE7F595B29
969660B3B576E0E3A0D6DC96D6DF9EC9D396D6DEA2EEF4B8D1D59A9B9F6494975E72773F
535C2765713F6071449BB2862C4820264823000F000010003C622990B474CDEFB2CEEDB1
C9E6ACD1EDB3C0D7A13F561E71864E788D54C3D89DC1D797C5DB9ACEE8A1839D54CFE59D
D4E0A0868E52606A2DD3E1A3D1E1A0D8EDAAD8F2ABB9D48D
FDFFF9FBFEF7FEFFFBFEFFFDFBFFFFFCFFFFFCFFFFF9FEFFF9FFFFF8FFFFE9F4F8F5FFFF
EFFFFFF4FFFFECFFFDD2E5DFAEC2B7F0FFF7F9FFFFFFFFFFDCD1D58B7B7E604848180000
1F0601260F091F0B0A8E7E7EFFFCFDE4DEDE9A9693FFFFFBFFFFFDFBFDFCF9FAFCFDFEFF
FEFFFFFBFCFEFBFDFCFFFFFDFFFFFBFFFFFBFFFFFBFFFFFDFEFFFFFCFFFFFBFFFFFFFEFF
E1CCCBDFC6BFFFFCF1FFFFF1FFFFF1FBFFF1FBFFF3F6FCEEFFFFF6F7F0E8D0C5C1FFFCF8
FFFBF3FFFFF6FEFFF3FEFFF4FFFFF5FFFFF6FEFEF2FBFCEEFFFFF3FFFFF1FDFEEEFFFFF1
FFFFF1FFFFF3FFFFF3FEFFF4FEFFF8FEFFFAFEFFFAFFFFFABBB2ADFFF5F2FCF2F0070601
AEB5ADFBFFF6FFFFEFD2D7B9D3E6B9EDFFCFF2FFCFCBD99BEBDBA8BAA27476693CB8B781
DEE8A3D2E299DAEBA5ADBD7E9DAA72A5AF7DDBE1B5FFFFDCABB288F3FFD0D2EAB0C0DF9C
D2F4A8C3E694CBEC95CBEC95C7EA98CBEDA0C4E699CCECA0D3F2A6C3DF94DDF5ABC4DC92
D8EEA5CBE198D6ECA3D1E79EA1B76E8EA45BAFC57CCCE299D2E89DC9DF96D9EDA5CEE29B
849851B0C47DD1E59ED4E8A0C2D68EE4FAAF5A7025CFE79BDAF5A8BEDA8DD5F1A6CBEA9E
C2E49ACFF1A5C8E99AC0DF91D9F3AAD5ECA4C1D28ED9E7AA070F002F35074F5321999D6A
D6D9A4DDE1A6959A5899A05C798145939E62C6D59ACBDA9FE0EBB3D6DDA9D9DBACDFE0B6
D6DDB4707F580014005B754E6C8B6292B58BBEE3B88EB2865272412546111F420AC4E7AD
C6E8ABC5E5A6CAE6A9CBE5A6C7E1A290AD6BCDECA8C9E8A2E0FBB6C7DD958C9C55D9E49F
D5DE9FB1BA7B545E219CA868D5E5A4C7DC99D6F0A9D1ECA5
EEFCFFE6F4F5F5FFFFEAF8F8F5FFFFF4FFFFF4FFFFF2FFFFF0FFFFEEFFFFEBFFFFE9FFFF
D6F7FCDFFFFF8AB1B881A5A5C3E2D2EFFFF6F8FFFFF8F6FFFFF8FFE6D0DDB5999664483A
381D0A331908301911BBA8A4FFFAFAF7E5E3A5978CB3A99FFFFEFBFFFFFFF6F7F9FCFFFF
F0F6F4FBFFFFF4F8F9FEFFFFFFFDFFFDF6FEFFF8FFFFFCFFFFFEFFFEFFFFFCFFFDFFFFF4
EDD8C7D5BDA3F4EBCAE7ECC4E5F6C9E6FCCDE4F6CCE7F2D0EDEDD5FFFAEBC4B5AEF7E8E5
FFFCFAFFFFFAF5FDF2F9FFF8FCFFF6F6F8EAFFFFF1FDFFEAE0E4C9F1F8D7F4FCD7DEE6BF
EDF5CEE2EAC3EBF3CEECF6D3E1EACBE8F1D4E8F0D8CED7BCC2C7A7FBFEE1FBF8E5040000
7E7975F7F3F0FFFFF6E9EEDAF3FFDFECFFD4EFFFCEDCEEB0E0E1A7B2A9726E62309C955E
DFE4A1CFE197C2E297C7EDA4C7EAA8A4BC82E3E6B7FFFFD68B7E54EBE4B6DDEAB2CFECAA
BEE89CC0EF9EBDEA95C6F09CCBEE9EC8E79BCCEB9FCFEFA3C7E79BC3E397CBEB9FD0F0A4
CBEA9EC8E79BD7F1A7C9E399D1E79E889E5572863ED2E79CD2E79AD2E79CD2E69FCADE99
99AC6A8DA05ECEDE9DD3E49ED5E79DD4E798899C4BEAFDACCCE192C9DE91DAEFA4CFE59C
CCE69FCCE89ECAE594DCF7A8C8DF99E0F5B0BDD287DEEFAB000900545D329AA36ECCD59E
DCE3B0BEC59180894AB6BC7CD8DBA4B9C38EA9C68CC5E8B0C9E5B4CBDBB4DEE1C4CFCEB9
D1DAC56F836A000D00678B65DAFBCEB5D6A1C6E5A9D2EDB68C9D7B00110037572EAED6A1
BBE5A5C6EEA7C5E59AC8E99AC5EA9AADD886B5E996B7E896D0F2A5D3E39CA297577F7132
D9DE9ED5E6A296A665899C5ACEE3A0C6DF9BC6E19AD1EFA7
B4D0D4DCFAFCEAFFFFE9FFFFD3F6EFD9FFF2D5FEEED6FFF0D8FFF47DA99C76A1989ECBC6
9EC8C795C1C4ACD4DCE3FFFFEAFFF9F4FFF7F8FDFFFDF6FFFFF8FFFFF4FFFFF9F4FFEFE0
BFAC9B95837533201C0F0000341E2188706CDCC2B1FFF3E0C9B7B3AFA5A6C2BDBAF5F6F0
F7FCF5FBFFFBFCFFFDF7F8FAFBF6FDFFFBFFFFFAFFFFF9FFFCFAFFFFFFFFFCFFFAFFFFF0
FCEAD2D6C2A1EAE7BCDAE4B0CBE5A8C1DFA1C7E3A9DDEFBFFCFFDDFFFFE8E4D4C7FFFBF4
FFFDF5FFFFF8F4FFF2F0FEEDFBFFEFFBFFE9FEFFE8FCFFE4D6E0BBD3DEB3C7D3A3E4F2BF
CFDCA7A3B17C68744272804F919E70607043647146CBDBAECDDAACE3EEC4FFFFE8181204
685E5CD6CCCDFFFCF9FEFFF4ECF9DDF5FFDDF5FFD4C7DD9DD5E1A3E7E8AC978E5761581F
D9DC99E8F9B2C9EFA2C6F4A9C3F1A9C3E1A3E7EBB8FFFBCF988259E5D7AAD5DCA6C7E1A0
BAE69BBDF19FBAEB99C2ED9BC3E598D2F1A5CBEA9EC2E296CDEDA1D0F2A5C6E89BC2E497
C7E79BC7E79BBCD88DCEE89EDFF7ADC4DA91D1E59DA2B76CA6BB6EDCF1A4CBDF98D1E4A2
D3E6A690A363B4C485D9EAA6D2E49ADAED9ED9EB99768836DAEB9BDFEFA4D9E69ED0DF9A
D0E5A2D8EFA7C9E291C4DD8CCEE3A0C0D592D9EE9FCADB942C380A5E6941CAD49FE4EFB5
D2DAAB8F9766CDD79AE5EEAFE5E9B6BDC999ACC4928BAB7AF0FFE3F4FFEAF5FEEBFCFFF6
F9FFFA5C6E60011D076C8D6EDEFFD4E0FFC8CAE5A2C6DBA3C8D4BE000900709172679264
BEEBB0D4FFB8B8DA8ECAED9DBFE695B9EA9887C570C1FBA7BAE095D9E5A3AE9962A78E58
DDDFA0CBDA97D5E6A2546823D9EEABCCE39FCEE8A1D0EBA4
8DBBB8B5E6E0CEFFF74481713E7F69A4EACE90D9BB95E0BF68AF9190D2B6A7E2CC457A68
1B453B638682EBFFFFEEFFFFFCFFFFFFFDFFFFF9FFFFF9FFFFF7FBF4EAE9FFFEF6FFFEF8
FFFEFDFFFDFFA59CAD3D2F40240F181C000045250E725239927168FFF7F4FFF7F1E9DCD3
5D594D67685AF7F9EEFFFFFAFBF9FAFFFDFFFFFCFFFCF7FEFFFEFFFEFFFFFBFFFFFDFEF6
E3D4BFAB9E7EC2C399CADBA5D6F4B6CAEDABBEDE9FC5DCA4D7E0B5DBDABBD6CBB5FFFEED
FFFDECFBFFECEBFAE3CEE1C3D5E4BDDCE9BDC5D1A3D5E2B4D7E4B6D6E4B36B79463A4B17
45531EC6D7A1E3F2BBC3D49DE0F2B8DBEFB4BED094D4E7AFE2F2C1DBE7C1F4F6DE040000
706665BDB3B4D8D3D0FFFFF4F6FFE5D6E8BED3EAB4C7DD9FD6E6A7E0E9AA9A985D5D591C
989B58D5E29CBEE094BCE69CBBE49ED0EEB0E6EDB9FFFFD3B7A67AE9DEB0D9E2ABCBE5A4
C1EBA1C3F2A2BFEC9BC0EA98C1E396D2F2A6C9E99DC0E094CFEFA3D1F0A4C6E599CCEB9F
D9F8ACB4D085EAFFBBC4DE94D1E99FD2EAA0D5EBA2C9DF949DB466C0D789E1F7AECFE49F
CCDF9FC4D7978D9D5ECFE09CC3D48DD7E99DDDEE9E4859099BAB60D1E198C5D48FDBEBAA
CBDE9ECADF9CDBF2A4D2E99BCBDE9EF0FFC3DAECA0D2E39D293409676F48EEF7C2CBD49B
E4EABA939A67DAE2A6D3DFA1C5D6A0E3F3C6E3E5BE515230899474F1FFE8E6FCE7EEFFF2
D5DAD441433E000500A4BBA1DEFFD7B3D6A0C9E1A5DAECBCDAE7D6495C564A6B56598260
91BC8EAFD8A0D3F2B6D1F1B0CAEFACC5F4AE6FA861BDF5AEBFE6A7D3E1AC928358756033
DEDCA1EDF4B1DEE7A646510F45510FE5F4B1C9DD98C1D691
255D504D87785C9B860E5239468F71024F2B00431C3E8F662E7C546EB992ACEDCB91CCAE
61967C578470D0F6E7E7FEF6F1F1F1FFF8FCFFFCFDFFFDFBFFFAF4F9F7EBFEFFF4EDF5E6
DEE8DDE5EFE7FEFFFFEDE9E891827D3A1F143818031C00002A0200512C2493776CFFEEE0
FFFDECF1EAD7716B5BC1BDB2FFFDFAFFFDFDFFFDFFFFFEFFFEFFFFF2F9FFF0FBFFFBFFFD
F0E9D7C3BC9FDAE2B9D1E8B2CBEEAEBEE7A1C1E6A1D2F0B0D6E7B1D3D9ADC4C19EF7F4D5
FFFFE3FCFFE6E6F7D5C8DDB2C2D69BDFF2B2DCEEB0ACBE8272864B84975FA4B780E0F3BC
D6E9B1CEE2A7CDE1A4D7EBACD7ECA9C8DF97C7DD94D4EBA7CCDEACEBF9D6FBFFE8030100
D7CDCCE4DADBB9B0B1FFFFF6FAFFEAD0E0B9D1E5B0C9DFA1CBDE9EE3F2B1C9CF8F999B5A
9EA15EDBE6A1D0ECA2C4EAA1C7EFA9CFECACD8E1AAFFFFD3C4B98BDCD9A6DAE5ABD1EBAA
C7EDA4C5F0A1C4EB9CC3E898C8EA9DC6E89BCAEA9ECBEB9FC7E69AC6E297CFE99FDAF4AA
C3DD93E3FDB3B8D288D7F1A7C8E096CEE89EC8E298D4EFA2D0E7997E9547CEE49BC3D893
DCEFAFD1E3A596A667889955E1F2ABD4E69CD9E99ED9E99E8F9F56576621566524879759
9CAE7283985790A45C8B9F579CAE72D0DFA4CDDE97CCDB980E1600717952C5CE99CFD89F
D8DEAEB8BF8C929A5ED6E2A4DDF1BEE0EFC4FFFDDBE0D5B9A19F86F9FFEDF1FFF4F0FFFA
E7F0EB71737054554F899281D0E8C6BFDBABECFFCBF0FFD7EAFCEC465D55527765467155
81AB83BAE1B2C6E7B2C2E1A8D5F8BEB7E3A46BA26182B676C2E9B2D8ECBBA09871584B1F
E9E8AFB8BF7CDAE0A0969F5E495513B2C17ED7E8A4D7EBA6
38745B104C32064123B1ECCCC5FFDD08421A518B62001700539064A0DFB2B7F6C9A8EBBF
6EB38742896181C9A3A1D6B8E2F0E1FFFDF4FFFCF1FFFFF3FFFFF2FFFFEFFBFFECF6FFE2
D3E9BBCEE5AFBBCC95C7D19DFFFFDCFFF5DCC7AAA273504C4820181C00005231224D321F
5C4631FFEED8FFF1DFE7D5C79A8981E3D4CFFFFCFDFBF9FCF0F7FDF4FFFFEEFFFFE1F5F4
EAECDFC3C6ABD9E8C1C9E6B0C7F0AEC6F4ABC1EDA0C2E89DC4DD9CC0CF96969C6CA7AA7D
C7CEA4D3E0B4C8DCABD1EAB0CEE69A7D9642869E50AAC278D0E7A1D0E6A5D1E7A9CAE0A2
DBF1B3C0D696C7DE9ACDE49CC1D98DD3EF9BE3FCA8C1DB91BED2A1F0FFE0FCFFEF010100
FCF4F2FBEFF1CDC3C4FFFFF6FFFFEDD3DFBBCFE1AFD4E9AECCE2A1D6EBA6DBECA6D6E19C
9B9E5BCBD28EDBF1A9C2E19BD6F7B2D3F0B0D3E0A8DEE1ACB2B07DB8BB86CDDBA0CFE8A6
C7E8A1C1E699C8E89CCAEA9ECBEDA0BCE193CDEFA2D0F0A4BEDA8FCBE59BD9F1A7BED48B
8A9E56CAE097D0E69DD0E89ED8F2A8C3DF94D5F4A8C7E396D3EC9B7A9141576D24D7ECA7
CCE1A0C6DA9B97AA6A4E611FD2E39DD0E19AC7D98FCFE099CFDE9BCEDC9ECAD89D57642E
C6D49FD8EAAEC2D38F7384405A6930071400B9C883E8F4B4000700393F1B323906DDE4AE
DEE1B2DCE0AE5056188F995CC8DAAAE3EFC9FFFFE1FFFEE4A69B85FFFFEDF7FFF3E0F7E7
D5E9E095A29B4B4C46A09C91DADCC4CCD6B1D0EBB6C1E1B0DCF8E15E7D6D194129547F61
416B45C2E9BCC1E1B0D6F4C0B3D69CBDE6AABBEFAF8DBF80B5DEA6C7DFAD999E755A572A
D8E0A4DAE7A2E4F1ACC8D79261722C8A9E57CDE39BCAE199
C8FEDAABDFB9C4F4CEB8E2BABAE0B7C6E9BFBCDDB2E5FFD9C3E9BAD0FBCDB6EAB9CFFFDA
9CE5B05BAE7877CF9CB7FFD5D0F1DEF8FFF8F2FDECFBFFF1FBFFF0F8FFF0F5FFEFF8FFED
DFF4CDD3EAB6DCF2B1E8F8B7EFF6C0FFFFDAFFFCECD3BCB48A6C616444353C1F0F150000
402512280D00987D6CCCB0A2DEC3B8BCA59FD0C1BEFFFEFFF8FFFFE5FCFFDFFFFFEAFFFF
E9F5EBC7CFB8D7EBC6BDDEA9B6E3A0BCEFA2C1F2A1C8F3A3D5F5AADAF1ADAEBC7F96A167
9FAC7494A66C839B5FA1BC75C9E79194B356C6E48CD5F29EDDFAAAC3DF94D2EDA6C5E09B
C5E09BCFEAA3DBF5ACD7F3A6C9E493C2DE8AC8E48DCEE89ED5EABFDFEFD5F5FEED0F1008
E3DADBFFF7F9F4E8EADAD1CCF8F7E5D7DEBFCBDBAED5EAB1CFE8A6C1DC95C7E197DCF0A8
636825929552D1E09DC3DA96C9E4A1CCE5A4DBEAAFD3DCA3BAC18BADB67DD4E4A6DCF2B1
D0EBA6C2E096CDE79ED0ECA1C8EA9DBEE596CDEFA2C8E89CBFDB90DCF4AAD5E9A193A45D
9AAA6396A760D7EBA3D3EBA1CFE99FBCDB8FCFEFA3CFEEA0D4EF9ED1E8988DA35AD5EAA5
C0D594EDFFC2C8DB9BA8BB79A9BA74D6E7A1DCEDA7DAEBA7DBE9ABD7E4ACDEEBB6CFDBAB
CFDDACD9E8B1D2E2A1CDDD9CDAE7B287945EC1CD8BCCD89A363C162226034A511EDDE2AC
DADDAEE5E9B7DDE1A4767E42FCFFD8FCFFDFF5F6D4FFFFE3EFE5CCF9F3DDFCFFF1F4FFF6
E9FFF592A89CF7FAF14E483CF1E6D2D6D7B5CBE8B280A772B6DAB6365B3C083411134019
6B9669C7EFBDC7E9B6BDDEA5CDF1B3C5EFADBFF1AC99CB86ACD696DBFABF9FB07C58622D
D7E3A5D2E19CD6E5A0C7D892CBDC96485C15859952D8EEA6
B9DFAECFF4C1C4E0AFCEE1B3D4E0B2DBE1B5E2E3B9F9FAD0FFFFDADCEDC0BCD9ABDDFFDA
C4FFCE89D69E56AD762F7D537CB5A6D8FFFBE6FFF7EEFFF4F4FFF6F8FFFDF6FAFFFBFEFF
F0F4FDF9FFFDEEFDE0E8F9CCE0EEB9D1DEA9D5DEB1EBECCAFFF9E4FFFDEDFFFCED7B695B
644C4033170B401E141B000078534A91736BCFBAB5F4EFECF0FBFDDEFAFE91BAC0264C4D
102119303D299DB593C2E7B4C5F3B2B6EB9DB3E995C3F39FBEE594C8E89CCCE39BC8DC97
D0E49FCDE39BC8E299D8F7A9D2F39ABDE084CDEE93B2D37ABCDD86C8E893D5F4A4C7E696
C5E496CDEC9EC5E194BFDE90D3EFA2DBF7AAD1EDA0CCE6A5D5EBC5D8E7D4FBFFF6656660
E0DADAFFFCFDFFFAFC9A8F8BC9C6B7FFFFE8FBFFDFC8DCA7C3E09ED7F7AED2F4A7C5E093
848B47747533B7C280DCECABC7DC9BC7DD9DD4E6A8D2E2A4D3E1A6B0C082DDF1B2E7FDBC
DBF2AEC9E098D3E7A0D2EAA0C6E89BC7EE9FC6E89BC5E498D1EBA1D5EBA2BDCE879DAD66
D2DF99CBDB9462732CDAF0A7BEDA8FD0F0A4CEF0A3C1E494C4DF90CDE597E6FEB4829953
C5DA99C7DB9CDDF0B0D4E7A5536722D1E5A0CFE09CD2E2A3C4D398E2F0BBD3E0B2E1EEC2
F5FFD5E0ECBACDDB9EDBE9ACCFD9A7DCE6B295A05ED7E1A4141800929675B4B8864B4E19
A5A778C2C493DFE1A2EBEFB2767E4DD0D8AFFCFFDDDFE5BFBFBA9A9A947AD9DBC5E9F5E1
CFEBD5748F7C828D7D696856AEA48B83835FCAE7AFCBF7BA0029008EBA8758875398C791
94C18A7AA369AAD093C0E5A2B8E099C6F0A4CBFAAAB0DF8F7CA85B9FC57CC4E19ED7ECAB
6D7D3CD8E4A2CCD994E8F5B0DCE7A3C1CC88626D29C5D08C
C7E4A4D3EDAED7EBAEC9D49AE1E6AED9D7A4E6E0AEF8F2C2F4F1C4D2D5A8D9E9BCF1FFDF
D6FFD2B3E7B78FCD9C46876531746DBAFAF9DAFFFED3FFE4D8F9DEF1FFF5E6F0F2E6ECF8
E0E7F1F8FFFFF7FFEAF5FFDACFE7A9CAE3A1C9E1A3CCDDB0FEFFEDFDFDF3F0EDE4E5DED6
B5A8A25F4C4661463F2F1109280A0030130B96837CFAF3EDEBF4F3B2CACE779CA2406264
60716B31402D5C745488A97AB7E5A5C5F9AEBCF19FBAEE99CAF5A3BDE292CEEDA1D2ECA2
CFE79BD0EB9CD1EC9BC7E794C5E793CAEE97D3F59FCBED96D2F49DCEF197BEE089CEF099
D0F09BC2E28FC7E698D1EFA5C7E59FBFDC9AC9E3A4D1E9B7C9DCC0E0EEDFFAFFF7757772
ACA8A7FFF6F7FFFBFDAFA4A2B8B2A6FFFFECFCFFE3D6E8B8CFECACBFE399B7E18FD3F4A3
C0CA854E4E0E6F7535DEE9A7D4E3A2D6E9A9CCE0A1CBE1A1D3E7A8A3B978D5EBAAE3FAB6
DAEFAACADE99D6E5A0D2E89FC9E99DCDF2A4C0E094CBE79CE3FBB1BED28AA5B56ECEDB95
D8E39ED7E49E96A760889E55CFEBA0CBEB9FC2E799CAED9DCFEC9CD6EEA0B6CE84BBD28C
D6EBAACDE2A1D4E7A7CCDF9D6F833EDEF2ADC6D695DAEAACD2E1AACCDAA9F2FFD4FAFFDE
F8FFD9F7FFD1D4E2A7DAE8ABD4DDAED1DBA797A162D7E1A42024017B7F5EDEE0AF636631
4B4D1EF2F4C3D2D495DBE0A0C3CA96959E6FB4C090D4E0B2E1E6BD969A75B5BA9AD4DEC3
D7EBD093AA9024331CBCC6AB484E2C3B461B5A763C89B071123C00CAF8BABEEBB0B9E5AA
BEE9B19FC88E7CA466C3EAA7CDF5ACB5E090B6E18FCEFAA5B9E492ABD485D2F7AAC2E098
6C7C3BB9C482D6DF9ED3DA97D6D897DCDC9C4E4D0DA7A666
869E5091A85A8DA257C7D89190A059D2DE9CE4EEB1D5DDA4DAE1ADDBE1B1D8DFB5FAFFDB
EBF5D2D7E2C2CDDABEC8E7D53E7F83338384C1FFF1A9E7BECEFFCDEAFFDFCAE6C0C8E0BE
C2DAB6D0EABBC1E09CCDEE9FD2F4A0C5E695C8E5A2CFE6B8F6FFF2F7FFFFF6FFFEF9FFFF
F4F8FBFAFAFAF1EEE9AEA59C382C2031231622160A0600002F312E303B3D081B22DFF2F8
D1DCD6ACB9A873876B75946AADD69CB0E29BC9FCAFB5E899BDEC9CC9F4A5BFE497D1F1A5
CAE999D3F09CC5E38BC8E893CDEFA5C3E79FC7E99DCAED9BC7EB94CAEE94CDF094C5E88C
C9EA91CAEA97CBE79DC9E3A2CCE5AED9F0C2EDFFDBF5FFEAF7FFF4EEFAEEFBFFFAD8DDD7
757472FFFDFDFEF4F5FFFCFAC4BBB4E1DECDF4F9DBF9FFDDDAF3B9D5F9B1BEE997CAED9B
D8E8A1D3D896777C3CB8BE7EE5EFB0B9C887E3F8B7CBE4A2CFEAA7D0EBA88AA361879C59
A0B46FC9D895D8E7A2D1E59EC0DF93DBFDB0BEDD91C5DF95DBF1A8D9EAA34D5D16D0DD97
D2DF99D7E7A0D6E7A091A75E809C51DBFBAFC6E89BC6E999CAE797CDE597D0E89E95AC66
C7DE9ACDE3A2CFE4A3CFE4A1ABC07BCADF9AE4F7B5C7D99BD3E1ACDEEBBDDAE6C0FBFFE1
FCFFDDEDF9C7DAE8ADD7E5A8E4EDBED3DDA98D9758DAE4A7131700A4A887DEE0AFDCDFAA
5F61323F4110DEE0A1DBE29FD1DAA1DEE8B36B743FD6E3ADC9DCA5CEE5B1ABBE90687750
B3BA9BD4DABE000D00769069A1C391BCDDA464793E485E20CAEEAEBBE5A5C6EFB5CAF1BC
BDE3B086AE7A8FB8801E4809C1EAA4C5EEA2C7EE9DC1E895C7EE9DB0D78887B165C4E59E
DBEBAC949A5EADB174E7E7A9E3DD9FD9CF92DCCE91625216
D7F19AC5DF88CCE490E4FBA9869D4D576D22869A55C6D697D3E0A8E3EDB9C5CCA2FFFFDF
F7F8D9FFFEE2FFFEE8F0FFF487C5C43A8A8795E0CBB0F4CFADE8BCBAEBBEBAE4BE8BB48C
668D5EBBE4A8C3EE9FCBF59FC0E890BBDE8EE3FFC0CFE4BBF7FFF8F7FFFFF1FFFFF1FFFF
EEFFFFD9F1F3F1FFFFD8E8DEBBC6B69DA1904746341B170B07040003000202000A8B8A92
BEC0BBE4EBDBF8FFECB9D2AB0010002C5519B5E4A0BDECA6B4E39BC4EFA8C3EBA4B5D98F
C9EC9CBEDE89D2F098C5E592C7E7A4C4E3A7C8E8A5CBEDA3C7EA9ACAEC96CEF197CCED94
CEEE99CEEA9DCEE8A7D3EAB4DBF0C9E6F9DDF2FFEEF7FFF8F2FCF3F9FFFBEBF2EB000500
747671FDFCFAFFFDFDFFFAF8FFFDF8706A5EFFFFEAF5FFDAD3EAB4C2E39EC4ED9EC7ED9A
CFE39BD8E19ED9DE9E57591A4B4F12E6F0B1CDE29FC3DE99C5E4A0BBDA94D8F1ADCDE29F
899A56E5F4B1C1D08BD2E69FD3EFA4CAE99DCCE89DDCF6ACCDE39A849850A0B16ADDEDA6
DBEBA4C1D28BCFE39BDBF3A9839D53B9D88CC7E79BCEEFA0CCE798CEE698C7DF95859C56
9DB470CAE09FD2E7A4D7ECA7D0E69EDAF0A8BCD08BD5E7A9D5E3AEC4D1A3EEFAD4ACB892
9FAA8084905EC7D598C0CE91C9D3A1E6F0BC909B59DAE4A7232702686C4BECF0BECCCF9A
CACC9D646635060800797E3CE7F1B5D5E0A6BDC88C47571995B270C6E4A6D3EAB299A678
62623ED3D4B4C1D6AF597D4D6090561E4809CFE1A38F9D60819F63D8FBC3B6D6A5CDECC3
C8EAC720442000110014400F557E44B9E09DC1E29BD9F9AEB7D78EBADE9698C37CCCF3B0
C0D89A97A7699FAD70C6CF90D6D899F4F0B1D6CC8E66581B
CAEB90D7F89FD8F6A0BEDA86C9E493D0E89CC7DC97788D4CB0C288C4D59FD6E6B9F9FFDF
F2FFDCF9FFE6F9FFE8EEFFF1BDF4E1569A8B3E7E6E72AEA283BCB677AEAB71A4A53F746E
3B755D7AB48BB0E8ABAFE19AD0F8B2D6F4B6BDD1A0D4E1C3F6FDF5E7F0F5F1FFFFE5FFFF
E3FFFFC0EDF28AB8B66D988E1C3E2D213A242E3A2417180608000010000022061528101D
2318169D9B8CC7CCB5E4F2D1A9C096557544779E69C0EBB3CEF9C1A3CF94D6FFC1CBF2AF
C7EBA1CEEF9ED2F39CD1F0A0C9E7ABCAE6B3CBE8AEC9E7A7C4E39DC3E296C4E395C7E396
C8E49AC7E09FCBE2AEDAECC6ECFBE4F7FFF8F8FFFFF8FFFFFAFEFDFCFFFDF8FDF7000200
BDC2BCFEFFFBFFFFFBFDF8F5FCF4F1F6EFE77A7766E7ECCCDDEDBED0EAABD3F8AABFE494
D2ECA2CAD994E8EDAD929254535114E1E7A7C4D893D1EFA7CFF3ABC7E99FD2EDA6C0D590
C5D491213000A4B871DBF1A9CDE59BC7DF95D3EBA1CCE49AC9DF96889E55ECFFB8C2D68E
D8ECA4C2D68EDFF5ACCFE79DC7E1978AA65BADCC80C9E59AD0EB9ED2EDA0CAE49B91AB64
829955CEE4A3CDE4A0CEE59FC8DE9551671EA5B974B1C484B4C58E8191628F9E77F6FFDE
E9F6C8E4F3BC90A05FCFDF9EEAF7C2C2CF99B3BF7D576325090F008F9370DEE5B2CDD29C
F3F6C7C3C79553571A222700D1D298DDE5A9DCECABCBE4A08FAE681D3A00B9C88DC8CF9C
7C7A51ECF1C9DBF5C6D1F8C3B2DFA4B8DFA0D9E9AB99A46A7F9564A2BB93BED2B68FA491
536B5DAACABBCDF7E388B5980012008EB481D3EEB7BDD59BDCF4BAC5E2A8AED79F77A46B
BFEBAC9EC7856B8F4FCDECA9DBF4B0D9EAA6C5D08CB6BD79
C6EA93BDDF8BC5E592CEE99AE5FDB3BBD189CDE0A0D1E3A592A36C9DAF7BF6FFD9F0FFD9
DCF7CAC3E2B6BFE0B5BDE5C0CDFDE3D2FFF23D706113453C4E807D4478764E8683C7FFFA
0018024D8E6CB9F8C9C0F6C2B5DFADBDDDAEDBF0C9C9D8BBF8FFF6F5FFFFE9FFFFE6FFFF
427179457C81001A19033830588372000C000007001110000B00005D4346522E3C160002
1D08055A5142D6D1BDD6D9BEE5F0D0C3D9B55E7A5490B58CB6DFB5C1EABEC5EFBDCDF4BB
BADF9CCCEEA2BFDF8CC6E295CBE7ACCDE8B5CAE5AECAE6ACD2ECAFD2ECADD0E8AAD2EAAE
D3E8B0D3E6B8D9E9C5E6F4DBF8FFF5F9FFFFFBFFFFFCFFFFFFFFFFFFFEFFF5F7F2000200
777E76EAF1E9FEFFFBFFFFFBFFFDFDFFFDFA423C30DCDCC4C9D4AAD4E8ADBAD88ED5F8A8
C6E69BD2E9A1CBD191B0AE715F5B1ED6D899E2F6B1C5E39BC8EEA3BDE197D4EFA8D0E5A0
CCDD99D0E19D94AB63D6EDA5D2E69ECEDF98D3E79FCDE199D5EBA2869E54CCE49ACFE79D
C8E096DBF5ABC6E096CAE49AD0EAA0B5CF858BA55BC7E197CCE79AD0EAA0D4EEA5BDD790
91A864DCF3AFCCE39DC6DD95CCE297D6ECA14B5F187F925093A56BECFCCBF9FFDFF9FFDF
D2E2B1CDDFA3C9DA96C6D793D0DFA6D8E5ADC9D893D6E2A22B330A888E6ADBE2AFE7EEB8
CFD2A3E5E9B7D8DEA0ABAD6C3230006E6F35C7DA98D5F0A9C4DF98D4E9A4A0A56BD9D7A4
D5D6AAB6C294EEFFD8BBDCA7D2F1B8C0DCA1CFDFA1D4E1AB56653C505F42AEB6A7000802
57696BEAFFFFC7F2EBA4D5C20011008DB287D0E6B8CBDBAAC4D4A3D3EBB9C0E6B5B5E6AF
81B77BB8F1AD6EA35FB3E29EC0E8A2BBDC95D0ECA2CFE79D
D0EFA9DCFAB4CBE4A0BED392D9E7AADDE8AEE3ECB5CFD8A3CCD6A2CADBA7EAFFCEE5FFCF
DEFFCFBCEEB3C2FABDB4E8B7DBFFEAE8FFF8D6F5E3CDF1D7B0D8B5C0EFC5C5FDCCD9FFE4
B5F9CA1A5E3599D9B7DBFFF6E0FFF3E7FFEDBCDCB5C7E1BACAE3C3BCD8BFBFE1D185AEA8
4A7A7E84B5BCD5FFFFE0FFFFDFFFF5EFFFF4F2FBE6484532FFFCF3FFF8F8E5C7D17B5C64
2C100C1200000E000079715C9F9E89DCE6CE9DB09A19351E8AAD95E7FFF1D4FCD9D9FFD3
DCFFC9CCEFABD6F5A9D0ECA1C9E3A2CDE7AAC8E1A7D0E9B0EBFFCEF3FFDAF0FFD8F5FFE1
F4FFE5F4FFEAF7FFF0FBFFF8FCFFFDFCFFFFFEFFFFFCFBFFFFFBFFFFFDFFFFFFFB10150E
C9D5C9F8FFF8F9FFFAE8EDE9F2EEEFE9E0E1EAE1DA6B6653C8CCA9CBD8A3D3EAA6C7E69A
C0E699CAEAA1DBE6A49E9C5F534B0DDFDE9EDFEEA9BCDA90C3E99CC8EEA1DAF6ACCAE098
D6E7A3CFE49FD0EBA4749046BECE87D3DE99DDEAA4D2E39CC6DC935F792FB6D287D6F5A9
C7E69ACAE99DC3E296CEEA9FC8E096DDF3AA96AC63CEE49BCBE399C9E399D0EAA1D7F1AA
A2BB77D2EBA7D0E79FD0E89ECFE799CFE799D1E79CCEE39EE6F8BCF0FFCDDEEDC2F9FFDC
D3E4AEDDF2B17A8E4697AB63DCEEB2CAD99EE3F4ADD0DF9C010900626A43A7B07BD2DBA2
E1E7B7CED5A2D1D99DB4B677544A15706D36A2B575D9F3ACC4D390CFD396D1CA94B0AA78
E3EBBC889A6ADFF2C4F0FFD4D7DFB0EAF2BFD4E3AAB1C28C424C2744493215150DE1E2E6
EBF8FFEBFFFFCBF7F6AEE2D50012003D613B95A67AC2CB9CDAE3B4DCEEBEB6D7A8C6F5C1
69A368ADEBAAB5F0AE93CA86CAF9B3BCE89DD6FCAFC4E99B
C0D9A2CCE3ABD7ECB4F9FFD4FBFFD6D4E0AECED8A6DBE7B5D2DEACD3E4B07A9159B3CF95
BCDEA1BBE2A3D3FDBDB7DEA7DDF7D4F4FFEFF2FFECECFFE4F2FFE4EEFFDFCBF4BABAECB1
C3FBCA66A27E8AC5B1C1FBEFD7FFFF90C3B280AE9292BF98B8E6B5BCEBBDBCEBCB4D7C6C
0F3938E3FFFFE2FFFFE3FAFFF2FEFAFEFFF6CECBBAE4DBCAFFFCF3FFF3F0FFF2F7FFF2F4
CFB2AA55352614000037241552493A96968AE8F4EAEAFFF66E8C827CA092D0F8E0DCFFE2
D4F8C8BDDFA3C3E19BC8E499CAE69BD0EAA3C7E09FD3E8B0F7FFDDF8FFE6F8FFEFF9FFF6
FBFFFBFCFFFFFCFFFFFEFFFFFFFFFFFEFEFEFFFFFDFFFEFDFFF4F8FFF4F8F8F7F35F675C
6A7869ECFDEDF5FFF8F9FFFDFFFEFFE5DCDFF3E8E6F0E8DB9A997BECF4C3DDEDAECDE99F
C2ECA0C6ECA1D8E4A2A4A265685E21B0AC6DCDDA95D4F0A6C3E99CC0E699C3DF95DBF1A9
CDE19CC7DE98CCEEA4DCFAB0B0BD788A914D919C57D4E49DD7EDA4607A30CFEFA3C1E396
C7EC9EC5E79AD1F1A5BEDA8FDBF3A9D1E59D8C9D56D0E19AD5EDA3D0EAA1C9E39CD1EBA4
A0B975A3BD76CAE199D4ECA0D5ED9FCCE594D2E99BD4EAA2B2C486D2E3ADE5F5C8EDFFCF
C9DCA4D3E8A5849B4D889F51D7EAAACADD9DD1E397D0E19B121D006C744DBFC893424B12
737949DBE2AFE4ECB0D5D99CECE5B1B3AD7B555A206F773BC0C084E7E0A9D5CB98ECE8B8
C2CA9BA7B488E0E7BEFFFFDDEBE6C0C9C69BDEEBB6C8D6A3575C34F7F5DCFFFDF4FFFDFF
EEF8FFE3FEFFB6E4E21B51414B7E5F466D417F8F5E6D713EBABE8BD1DEA9CFEDB9BAE2AD
9AC99380AF78D5FFC7679152BDE1A1C3E49FC7E59DC1E094
D7E3BFD0DFB8D6E6BFF4FFDCF4FFDECDE4B6C7E1B1C9E4B1CAE1ADD0E5AD7D8C55BAC38A
CACD94D8D79ED9D49CDCDBA2E8F6BBF0FFD2FBFFE8FEFFF1EFF1E6F1F5E6DAE7CDCBE0BF
E7FFE9A3CDB7ACDDD7B7EEF1ACE9EE31717112544A377D5BADF5B5B4FAB4BAF5C5002C0F
00231DE9FBFFE9EAFCFFFAFFFFF2FBFFF9F8C5B1A8FFF9ECFFFFF3FEFFF8F2FCFBFCFEF9
E0C6B98E69597E5D4E482C211E0B04251D1AE5E9EAF3FFFFB2CCCD4E716DA7CDC0BBE3C9
BADFB6CAEBB4C5E2A0D5F1A6CCE893D7F09DCBE29AD2E5ADF5FFE0F9FFF1F0F9F4FBFFFF
FAFCFFFCFBFFFCFAFFFCFAFFFEFCFFFFFFFAFFFFF4FFFFF6FFF5F8FFFAFFFFFEF9000400
B8C9B7F2FFF6F4FFFAF2FDF7FFFFFFFFFCFFFFFBFDECDFD6CDC7ADFEFFD5DAE4A7D0EAA1
B7E698D5FFB4C7D691A3A26282763A6B6325B8C57FC3DF94C9F0A1D2F9AAC4E096CBE199
D3E7A0DDF7AEA6CC81C6E89CD3DE9A6B6E2B646B27DBE8A2CBE1987F9B50C5E79AC8EFA0
C0E99AD5FCADBDDF92D1EDA2CAE298DCEDA687944EBACA83CBE29AD7F3A9CDE7A0C6DF9B
9EB773758F48C6DE94D1E99BCDE695C1DA89DDF4A6CBE198DAEFAEC0D39BF8FFDAE2F4C2
D4E8ABCCE39BBAD38292AB5AC7DC99D9EEABCADF90D5E69F0B17009BA67ED6E0AB919C62
61693A939B6AD6E0A3E0E9AADADDA8DCD6A68D7B4D422A0064501EE9DDA9EDF0BBCDD5A2
C9CCA1E8E4BFDBD0B2FFFEE1FFFFDFF3EFCAE7EDC1DCE2B457562AFAF2CEF6EBD9FEF7F1
F2FAFDE9FFFF86B8AC1E5A4089C096B5DDA8D3E2A7C5C7889EA05FCAD593D2EFADC6E5A9
DBEEC09DAA7FC2CEA0798150979C66ECF0B5E6E8A9DFE1A0
DEDDC8EEF0DAFCFFE8F1FCDEF8FFE6F6FFE3F5FFE1CBE1B3D0E2B2D3DFADDDE4B0DCDBA5
E2D6A2DAC995AC925FE2CD96E0DA9EE5E2ADF5E7CAFFF6E8FFE8E7EBD3CFE4D2C4DAD4BE
F4FAE095A78F567162587972486F6C527B75C9F3E7477D5D57A36284D48B83C190749C82
F0FEFEF9F7FFFFFBFFFFF3FFFFF4FDFFF1F3F8D9D4FFF8ECFFFCF0FCFFF8EEF8F7FFFEFB
FFE0D7E5B3A8FFF3E8B7928A5037322C1D1A2A2426808185F5FEFFE3F1F2576A645C7162
9BB296C0D9B1D2ECBCCFE7ABCADF94DBEC9ED1E09FD8E2B0FCFFE1FFFFF1FAF6F5FFFBFF
FFF9FFFFF8FFFFF6FFFFF7FFFFFAFDFFFBF6FFFCF1FFFCF1FFFBF8FEF3F1FFFDF76E7063
858D7EF1FCECF6FCF2FFFFFBFFFBFFFFF2F5FFEEF0FFFAF1DCCCB5B6A986F3EDBBD7DFA3
C9E8A4C3E29EDFE5A9F7EAB3E9D29E5C4712787236A8B170CFE09CC7DC97D6E5A2DFEBA9
D5E19FC9DC9AD8F3AECEE7A3D4DD9CDFE4A2D2DB98AEBD784A6119B2CE84C6E69BCDEFA3
D3F3A8B4D086D5ECA4D9EDA5D1E29BD4E49DD5E29C919E58AFBE7BD9E8A5D8E7A6CCDB9A
AFBF80697C3AD0E49DD7EBA3CEE398D7ECA1D0E59AD1E59EDCEFAFD9E8AFBFCD9AD4E5AF
D0E4A5CDE29DCDE29597AC61AFBE7DCFDE9DDEEAA2D5E09C1E21007F8257C3C892D0D59D
777A4B878B59292E00858B4F979763C2BF8CA999686C5826836F3D564A1682824CB0B481
BFBE92C8C29EC7B99CD3C8ACB9B697E9EDCADEE4BEAEAF875A4D23EFDDB9FCEBD1FFFCEC
BCBFB4617569082E17C7F3D2C5EABEC4DCA8E0E3AAC9C085A49B60818143CEDE9FD1E3A9
CDD3A565633A2B28009A96695D5527A4996B9B9160D3C996
E9D8D0E5D7CEFFFDF1FFFEEFFFFEEBDED8C2FFF9DFE4E1C2D4D0ADBDB8925F582EA29A6C
B6AB7DD4C896BDAD7ADAC493A78258BB8D6CF6C2ACEEB4A6F5BBB0DBA297734432F1CEB2
DDC7A2FAEDC3DDD4A9E0D9AFDDCFAAFAE6C5DFC5A4DBDCB44C88523E8B5748795974857B
FFF8FFFFF6FFF3F3FBFFFFFFFFF6FAFFF3F3ECCEC6E8D5C7F7F3E7FFFFF8FFFAFFEECBD2
A5696BA35F5CFFEEEAE6B9B3A2817A3B221B0F00003E2926E9D1D1FFF7FAF1DBDD0B0000
3E3B329FA798C2D5C1D1E4C6D4DCADDEDEAAD4D0A3EAE2BDFFFBE0FFFBEAFFF7F0FFF6F4
FFF4F8FFEBF2FFF2FAFFE8EEFFF2F6FFF2F4FFECECFFF6F1FFF6EBFFFFEFF6F0E2E1D9CE
756D62FFFCF4FFF9F8FFF1F1FFEBEDFFF4F6FFF2EFFFF4E9FFF3DFCAA88DAA8C68EBD5AC
E7E3B6E2DFB2E1CEA4E9C9A2FFDAB4AF815D7B542B3D1E00E7D1A0E6D9A5E1DAA4DBD8A1
DCDBA3E9E9B3C7CA93E6EBB3DEE4A8CAD495D3E3A297AC69CAE39FCFEAA5C3DA96D4E4A3
D7E1A2E9EDB0D4D496E1E1A1DDE4A1CDD894D7E8A198A560AAA86DD1C891EEE5AEE7E2AA
D9D8A0D7DBA09EA66AD5DFA0E3EFAFC4D090DDE9A9D7E3A5D6E1A5CCD59CD8E1AAD0DBA1
D8E6A9CFDD9FD0DC9CDDE6A79CA065D4D39AECE7AFD9D29B3B2E013A2D0060562558501F
6961325F59295754215A5420615420A49F678A9A59D2E5A392935760571E675A25E4D8A6
E4E2B1DFE0B4D9DBB3FEFFDFE5F5D0D2E3BFE2F0CFFFFFE3664B2D7D583BD1B699A49377
302B0D2124055C6643444C274C4C26675E37543C16876B4479603859461C584D20484616
8287514C531D585C2907090006040068643F4F4927585232
CCB8B7C8B5B1EAD7D3E9D8D1EEDDD3D2C2B3EEDFCCCBBFA7B2A78BB0A5859A906CB3AC82
CFC89CE4DDAFCFC999EFDEB3B5917182523BB37E6CDDA395D0968BD29C906234249E7C61
6F5934C5B68B9E9260776A367E6636927146865A3597855F31623500391200281141504B
B8ABB5C8B8C5D9E3E5D7DDDBCFB7B7CCA6A5FFE7E1644C42AFADA0D6D6CEE4CAD3E2B2C0
E39DA5DB9396EBB1B0EABFB9886A608F776D270F05270A04381211E3BBBCA0797CB7999B
8D7F7F1B1C17000600495E4F889176B1B2926E6A4D817962E3D6C5FFEEE0DBC0B9D6B7B5
C19FA0FFE4E8B99199B88F97DDB4BC976E76FFD9E19B7B7CEADED2CEC8B8D0C8BD675A52
92807EDBC5C7B1979AE5C6CBCFACB0E6C2C2A5827C98766AE7C6B3C5A78D684B2D674F2D
84724C4D3E15AC996F745D3384693E9D805483663A694D1E755D2D4F3B099A8D598C824F
67602CC7C18F979161807D4AA1A66CB9C585A1B4744B6120708947ABC48292A263666E32
BCBB82D0CA90A2985DCBC287B4B4749DA66398AC64818E49847B44968452BCAF7BBEB47F
BBB67FB1B2797D80479FA76C919B5FCBD599BFC98DD3DBA0DADFA5E3E8AEDCDFA6DFE4AA
D1DCA0D5E3A5E2ECB0DFE4AAA4A36B6B662F8F8550ECDEAD291900877746E7D9AAEBDFAF
DCD2A1DBD5A3DCD6A4C5BF8B868046AAAA6CD9EDA8DFF6B0CFDA98E7E7A970632C877744
B7B17FDEE0AFCDD9A9EDFED1EAFFD6C0D6B0DBEECEFFFFE4907256FFD8BCFFF9DAFFF9D7
F5E7C2E7DEB7D7CFA8E9E1BAE0D7B0E2D4AFF9E9C5E9D7B38A77566D5D39A59774E0D9AD
DCE4ABDBE6AAE2EBB49DA37340421BABAB895F5B40A7A38A
FFF7F6FFF1EEFFFBF8FFFCF6FFFDF3FEF5E6FFFFECE4DEC6DED8BEE4E1C2F9F6D3CECCA5
DFDDB4E5E4B8E4E3B5FFFFD7FFFBDDFFF4DE998979F6E2D7FFF9F3FFF9F4FFFAF1FFFFF1
F8FDE6F9FFE8D3E4C0CCDAB6C9D0AEDAD9BAFFFDE1FFFFE6CAF4D0619878628D793C5D52
BFD9D6DDF1F2F4FFFFF4F8F9FFFAFAFFEBEAFFE7E894716DDFE3D5F8FFFAFFF9FFFFEDF9
FFC3CBF9BDBFFFDFDDFFF5EFFFF0E5FFFBF1C0AEA46C58513618165F3D3EBC9C9FFEE4E5
FFF3F3C2C4BFA3B4AA1C34268FA694C5D8C5F0FEEFF8FFF8FBFFFBF7F7F5FFFDFFFFFBFF
FFF6FFFFF9FFFFF9FFFFF7FFFFF9FFFFF9FFFFF9FFFFF7FFFFF7F7FFF5F3FFFBFB64585A
8C7B81FFF9FFFDE9F2FFF9FFFEEBEDFFFBF8FFFCF3FEF5E4FFFFE8FFFFE4EDEDC9D8D6AD
A79F6EF4EFB7BDC186CFDE9DD0E7A3CBE69FD3EDA6D0E49FD3DC9B959559A29C62A99E68
594F1C9C9662C4C28FD9DCA5D4DA9ED6E19FC7D695CDE29FD4EBA7D5EAA7C9D998E5EEAF
D1D195BCB67C93894EA49E62B4B474A2AB68A3B46EBECD8A8E8E5278733BACAA71B3B279
BBBF84ACB4788C96599BA769636F31A0AA6D515B1E999F6393975C7C7B4268662DBBBC82
D3E1A37A8D4B586829788446BFC5897D7E4459571E625B252C25006A632DA19B6797945F
73723CE5E8B1D9DCA5DBE5A9B1C1805F6B29C0BA7ED8D296DDE8A6D0DF9CE3E7AA78733B
645826B2AC7CECF8C6F7FFDAF9FFDDF5FFDDE7FCD5D4DCB7D2BF9E6648264F310F9C7F5D
856B488E7A55BAB18AE4E2B9DFE8BDD3E4B7ACBF916F82545F6E43919A6F9CA1792D3305
CBD69EDBE9AECEDBA5DEE8B6C4CBA19498733D3E1C969576
FFFEFBFFFEFAFFFEFAFCF7F1FFFFF6F7F5E8FFFFEDD7D6C1E9E9D1F4F7DAFFFFE3D5DBB7
D9E0B7D3DAB0ECF3C9FEFFDFF8FFE7F9FFEFC1C5B6D8D8CEF2EDE9FFFDFDFCFCFAFBFFFD
F5FFFBE5FCECD4EDD8F0FFF3E8FBE5DDEAD6FEFFF1E7F3DFD0ECD3BDE5CBBAE7D22F6454
73AFA3CCFFF9EAFFFFF8FFFFFFFCFBFFF5F6FFCDD4FFDDDFFBFFF8F2FFF9FFF6FDFFF1FC
FFD4DAE0AEB1FFF5F3FFEBE6FFFCF3FFFEF3FFF5ECBEAFA80F00003A2021180000FFF8FA
FFFCFAFEFFFBE7F8EE324C3F5C786CA0BEB2EEFFFFEAFFFBEBFDFDF2FFFFF8FFFFF5FCFF
FBFFFFF8FAFFF5F4FFF9F8FFF1F0FEFEFDFFEAE9F7FFFDFFFFFBFFFFFAFFFFF7FFD8CBD5
8C7C89FFF6FFFFF2FFFFFAFFFFFAFFFAF4F4FFFFF8FFFFF3F5FAE4EFF9DEEAF8D5D8E3B8
9699608B924EDAF0A7D2F5A5C7F7A3B8EC97ADE18CCBF8A5CFEFA3DBEFA7D2DB9ADEDFA3
7B7A415C5B23797C45D7DCA2CED496EEF7B4DFEBA9D3E4A0CFE39ED8ECA7D2E19EC9D291
C3C385EAE6A961581DE1DB9FD9DB9AD7E09DDBECA6D0E19DD9E2A39EA466D8E0A4DAE4A5
E6F2B4D8E7A6D3E3A4DAEAA96472348894541A24005B612387884EADAB70817A43A8A86C
BDCD8C90A7619AAD6B91A160A1AB6C8D9355A4A86D9C9D639F9E65A4A56CA4A56C91965C
757D44B4BF83D0DBA1D0E4A5BDDC96B7CC8797884FEAD59EE4E9A9D2E39FD4E4A3C3CC8D
88834C77713DD1D8A4FBFFD5E4EDC0FBFFDCECFFD6C7D6ABD5D0A8BAA8805D47224E3612
634B275F4D276D6840B7C093C2DCAC9DC28E638F5A517D48A9CD9DB6D1A4A0B2889DAD80
9DAE7891A26BDAE8B3CDD9A7D9E2B3DAE1B57B8058878C64
FCFCFAFFFFFDFFFFFDF8FAF5FEFFFAFCFFF4FEFFF4E7EEDCE0E8D3F5FFE6F7FFE4EDF8D8
E2EDCBC8D4B0DEEAC6E5F3D0E0F3D5DBEAD3EAF3E2EFF2E7E4E0DDFBF5F7FFFDFFF8F9FE
E7ECF0F7FFFFF2FFFEEFFEF9F7FFFDF6FFF8FCFFFAFBFFF8C1CEBDD4EFDCA7DDC67AC4AD
27806A2F82707DB2AAC5DEDBFBF9FAFFE6ECECB2BEFFEFF6F5FCF4F2FFFDFFFCFFFFF4FC
FFEEF5D6B2B4FFF7F6FFF6F0F3EEE8FBFBF3FFFFF8FFFEF8C0B1AE3E2A2B1F090B271515
7C7471F7FAF3F4FFF7F1FFFB738E85405E56C3E1D9D9F2EEF0FFFFEDFFFFF0FFFFF5FFFF
EBF5FFF7FFFFF7FFFFECF6FFF7FFFFEEF8FFF7FFFFECF0F9FEF6FFFFF8FFFFF4FFDECDDF
847385FFF8FFFFF3FFFDEFFEFFFAFFFFFCFFFBF5F5FAFAF2FFFFF4FAFEEDDCE4CDDCE8C2
DEF1B1C9E29171913ECDF39CB4E087BAEB90C7FA9EBEF097C1EE99C2E996C9E99DC9E098
D2E39FDDE7A860662A63672C909555C3CA86DFEAA6D6E5A0D0E19BC8D993DFECA7E6EDAA
EDEDAD9A9657817D3E504F0FA6A869C6CF8ECEDF9BCFE39ED7E8A4899D58CBDE9CC9DE99
D0E7A3C3DA94D0E7A3D3EAA4DDF2AFE2F3AFB4BE7FCCD292DBDB9FE6E2A5A79E65A3A365
DBEFAACBE79DD3EAA4CFE39ECDDE9AD8E4A2E0EAABCAD394CDD697D1DB9ED7E1A4D1DFA1
CEDEA06B803FD3E7A8D2EDAAC6ECA3D3ECA8CCC68CB29E69AAA166F3F9B9BCD38DCBE4A0
D9E1A56C6B3376703CE0DCACD4DCA9D9EAB6CDE1AED7E9B7D3DBAAD4D6A5E3DFB2D8D1A5
CFC89CDEDBB0BCC5981C32015D844F376831A5DCA5B8EFB8B3E3B1D3FACBD7F4C8C1D8AC
C5DCA8A8BC878A9C687C8D59283603737F4DCFD9A7AFB987
F4F8F9FCFFFFFAFEFDF8FEFAFBFFFBF8FFF7FBFFF8F2FDEDF9FFF3F8FFF1F4FFE9F8FFEC
EBFADDC9D8B9D4E3C4CCDDBDD4E5C3D9E8C9E0E8D0F9FAE8FFFEF4E6DBD9FFF7FBF7ECF4
FFFCFFFFFDFFFEFDFFFEFFFFF5F7F6FAFCF9FBFCF6FFFFF8EFF1E6DFF6E6BEF9E350A48A
82E4CB65C4AE00463786B3ACF9FFFFFFF4FCAF7D89FFF1FBFAFBF6F5FFFDFFFFFFFFFBFF
FFE6EBBEA4A7FFF6F6FFFDFAFFFFFBFCFFFBF6F8F3FFFFFBF9EFEE4E3E3E0D00001D0D0D
4E4442C0BFBAF5FDF2EDFFF1D4F7E3254F3986AD9AAFD6C4E0FFF6E9FFFDEAFFFFD0EEE6
CFEDE5D6F4ECD4F2EAD3F1E7D6F4EAD8F6EACCECDDD7F1E8F7FFFFDBE0E6FBFFFFC5C9D2
9496A2FEFEFFFEFEFFFEFEFFF4F4FCFBFCFFFCFFFFFCFFFDFBFFFBFBFFF8ECF4E7D3E2C3
BDD796C0E19085A2509DBA68DAF7A3C1E18CD0F29CC7ED96BAE48EC5EF99CDF7A3C3E898
C7E398DFF3ACB0BC7A97A05F7B803EA3AA66D6E09BDCE7A2DDEDA6D8E59FD9E49FD4DB97
DCDF9C8A8A4AAFAE6E5E5E1E939858DDE8A6DDECA9CADE99D5EAA58BA55CD1EBA4D0ECA2
D1ECA5C4E298CFEDA5D0ECA2D0EAA3BDD38BD6E5A2E8F1AEE4E9A9C7C787A19D60959756
CADE97CFEBA1C4DB93D6ECA4DFF3ACDBECA8C8D794E0EFACE7F3B1CBDA99D5E5A4DFF2B0
D0E6A59DB6749AB572C0DF9BC3E49DC0DB96DDE3A5605A20A4985EDAD89BD1E6A1D0EEA6
D3E8A59FA76B554915AFA36FE2E7AFC9D89FC3D89FD1E6ADDDF0B8C9DAA3E2F1BAE0EEB9
CDDBA6D2E4B0CCE7B22D4E190012007AA671AEDEAABAE8B7CBF5C7B2D7ABC6E5BBCDE8BD
D6EEBEC8DEADD6EAB7B2C49075865084955E94A36AA3B277
F9FEFFFBFFFFF9FFFFF9FFFFF9FFFFF4FDF8F9FFFBF6FFF6F8FFF6F2FFEEF0FDEBEFFEE9
E8F7E2DDECD5E6F5DEE4F3D4DEE9C1D1D7ABF0F0CAE2DCBCFFF1DAEAD4C6937A75C0A6A7
BEA3AA927B83B5A0A7EDDDE0E5D5D5F2E5DFBCB2A8A59D92FCF9F0DDF3E689C8B37FD5BC
BEFFFFC1FFFFBBFFFF2E7668D4E9EAFFFAFFD8B6C4FFECF7FFFCFFF4F8F7F6FAF9FFFEFF
FFFAFDDCC8CAFFFCFDF5F1F0FCFFFDF0F6F2F8FEFAF8F8F6FFFDFDFFFBFB7464640B0000
0A0000968F89EBEBE1F5FFF3BFEFC9B1F0C198D5A92F6C40407A514B855C457F574C845D
4C845D457D56033C13286136043F130C47190E4919367048487C6555857774A4982F5D52
507971D9FEF7E9FFFFE6FFFFEDFFFFE1FAF7F0FFFFF1FFFFE5F8F4F4FFFFEFFEF9B5C8B2
DFFEC5CBEBA2D3E7A0BEC9847374309C9C56B8B973D9E196D7EA9BD1EC9BBFE28ECAF09D
CCEF9FBEDD8FDFF7ADC9DA93B0BA755F66225B651EA7B36BD8E49CE5F1A9C7D18AE1E8A2
A5AB654F520FE3E5A45B601E676D2DD2DC9DD8E4A4DAEAA9CCE29A8CA65CCCE89ECDECA0
C9E99EC7E79BC9E99EC7E79BCFEDA3CFE99FD0E69EBDCD86DEE9A5F1F8B4D9DE9C727C37
D2E89FD5EFA5C8E096C9DF96C4D890CDDE98CCDD97DCEDA7C4D38ECEDF9BD1E5A0D7ECA7
C4DD99E1FCB773914B7A9852E2F9B5C6DD99CBE6A1DCECABB7B175A79D62E8F1B0C1D691
C6E49CCFE2A0938D536A5D26BBBB7FD5DFA2DAEFAED5EEADC3DD9EC5E1A4C1E4A4C4ECAD
B2DE9FABD99B8AB77C0028001E400DD8F4C4D8EFC3C3D8AFCEE3BCB2C7A078916A253E16
738D60C0D8A8B4CC9AD2E9B3E9FEC5CCE0A3C2D5959BAE6C
F8FCFFFCFFFFF2F8F8FBFFFFFBFFFFF7FDFBF8FFFCF9FFFBF9FFFAECF6EBF8FFF8F3FFF1
F8FFF6F8FFF4F5FFF1F3FFE6E5F0C5DAE3AECDD19FE9E6B9F5ECC5FFFADCFFF4E2FFF6EB
FFF7F6FFF7FAFFF7FBFFF8FBFFF6F4FFFAF17D74655D5A4BFEFFF8ABC5B8407E699FEAD5
AFF3E4B3FFF1218972328F7CCEF7F3EBF0F6FFF8FF654D5AFBECF3FFFEFFF5FBF7FCFFFD
FBEFF1FAEAEDFFFCFFFFFEFFFCFFFFF3F9F7FBFFFFFEFFFFFFFEFFFBF1F2D7C7C8210F0F
0D0000675853594F46FBFFEDB4DEAEC2FCC1AEE8AEAEE8AEBEF7C0B5EEB7AFE8B1B4EFB7
B0EBB5ADE8B0BDF8BEAEEAAEB1EEB2BDFBBCA5E3A2B4F3BAB4F5CDA1E2C4001500001400
1C523A53846F467261B8E1D3CFF0E7EAFFFFEEFFFFF1FFFFF2FFFFF3FFFFF1FCFEF5FFF8
D5F0C5C4E0A5DCEEB4D0D9A0E7E6ADE1DB9FA39B5D9E9959DBDE99CCD88EE3F8ABC4DF90
D4F3A3CBEC9BC0E190D4EFA2E0EDA7CFD69296A05B57611A4D5911D6E29ADDE7A0DAE49D
484F09646B25D7DE9ACDD4915E6726D3DC9DDDE7AAC9D595CEE29B93AB61C9E399CBE79C
C6E599CDEDA1C9EB9ECAEC9FC1E195D5F4A8CDE99EC8E096D6EAA2C5D68FD8E59F91A15A
D1E79CC5DD91D8EEA5D7EBA3CBDC95E8F9B2C6D79150611B51621CDAEBA5D2E6A1C1D691
DBF5AEC1DC95D2F0AA89A25EC3D392DEF3B0C0E49CCEECA6E3E9A94D4B0E9B9B5DDCE7A5
D3EDA6C6DD97E5EAAA5A56179E9A5BDCE19FD0E19DCAE39FCBE5A4CCECABC3ECA8C0F2AD
518A45437C3885B77880A96F415C295F6F42D8DEB8E1E2C0979B783F4926000900BED4AD
001000000D00031B00CAE3ACB5CD91DEF4B3CFE49FCBE198
FFFFFFFBFBFDF1F1F3FFFFFFFEFFFFEEF0EFFEFFFFECEEEBFCFFFDFCFFFBFBFFFBFBFFFA
FBFFFAFBFFFAFBFFFAF9FFEFF1FFD6E7FCC3D8ECB1D3E2A9E6EFBAFFFFD4FFFFDFFFFAE0
FFFCEFFFF9F4FFFBFAFFFCFAFFFBF2FFFFF3A7AC987C8874C2D7C85577693C715FAEE4D4
C3EBE38DC2B8399D85268E77C7FFFFE9FFFFF8F6FF614C5BEAD4E0FCF0F4FBFFFBFBFFFB
FFFAFBD2C1C7FCF1F7FEF9FDFFFFFFFCFFFFFAFEFFFBFBFDFFFDFFFFFBFFFFF2F3715D5E
35201F100000130000C6BFACCEDFB2C8E6AACDEAB0C8E5ABD1F0B7C1E0A7CAE9B0C2E3AA
C3E4ADC5E6ADC5E9ACC6EAACC8ECACCAEFACC8EDA8C2EAACB5E5B5CBFDD7D7FFE0BFEBC8
194222ABCFB39BBBA3213C29516858BECFC5ECF8F4F9FFFFF4F7FCFEFEFFFFFDFFFDFFFE
E5F3D9CDE2B9CFE6BAC5DBACC7DBA8D9E8B1C3CB92ADAE749A9659A19C5CD7D491E5E8A1
D3E196BFDA89D4F7A3C3E696D9EAA4D1DC9AD5E09C8B965159631C5A641D97A359909C52
515D157A863ED7E29DCFDA96868F4ED1DA9BCAD094E1EAABD2DF9998A85F798E43D2E89D
D6F1A4BFDE90CCED9ECBEE9EC2E797CBF0A0CBEE9EC5E697D1EDA0D7F2A5B8D3868EA65A
C6DC91DCF1A6D3E59BCBDD93E3F3AACDDD9495A55E8A9A53E2F1AC70813BBFD08AD7EBA4
C8DD98D6EDA7D0EAA3CFE49F6C7B3AB5C584BED994D3F2ACCAE8A2CDDD9C828043DFD99D
D7E09DD6E7A1CAE199D9EAA33D3900524D0DBFCB83C8DE96D6EDA9B8D291CEF1ADC5F0AB
6496515889479FC98AA5C48B96A6776C71486D6944726C4A534E2E2728061C2400506039
6B8059274114031B00516A336C8448C5DE9CC8DF97D9F1A5
E2DEDFFFFEFFFFFEFFFFFBFCF7F5F6FFFEFFF7F5F6FFFFFFFFFFFDFFFFFDFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFBFFF4EEFFDEECFFD5E1FDC3D1EAB0CEE6AAE2F5BEF9FFD7FFFFE3
FFFFEDF8F4EBFCF7F4FCFBF9FCFFFBE8F2E78C9B888EA591405F4FCFF3E5E6FFFDEBFFFF
F4FFFF80A09B3184723FA79065C1B297D4CFEBF3FEB8A3B4B49AA7FFF6F9FCFFF8EDF5EA
F6ECEBD6C5CBFFFBFFFFFCFFFDFBFEFDFCFFFEFFFFFFFEFFF6F1F5FFFCFFFFFAFDEBD9D9
9C84841C0000140000665545FFFFDCF1FFCACCDDA9C4D5A1D5E7B5C7DBA8CCE0ADD0E7B3
CBE2AECCE4B0CDE6AFCBE4ABCAE3A9CAE4A7CBE5A6C8E6AACAEFBCC0E7BABFE4B9557A4F
70956CB6D8B3C0DFBDBCD9BBD0EAD15C735F93A899ACBDB5F7FFFFF8FFFFF8FFFFF3FFFD
F2FFF3EAFFE8D7FBD5D6FDD1BFE9B9C1E8B3DCF9C1BED297E2EAAFD2D296A8A4675D5C1B
BAC17BDFEFA6C1DC8FD9F5AAD0E3A1E7F5B7C2CE8EE5F0AED7E29DE2EEA68A964E717F34
B1C178CBDB92E3F3ACCEDB968994529DA365DEE2A7D5D99CE0E7A4C1CD8559661ED1E399
CFE59AD1EDA0CDEE9FC3E696C9EE9EC3EA99C1E897C3E898C4E797C5E898CEEFA0DCF8AB
99AE63A4B66CDCECA3CDDD94D2DF97D2DF97A1AE68D1DE98CCDB968A9954808F4AC3D48E
CDE19CCBDF9AC8DD98D7EBA6DBEAA9A2B17098AF6BC2E09AC0E89FDAF8B2D0D293A89E63
8D894CC7D08DD6F5A9C8E79BB6BD779C9D578E964D9FAB6392A15E73864697AD6DC9E3A2
C9E7A7C8E6A8D4EDB3D6EBB3D4E0AE91996A7B7D5533340C3D3D1780825D9BA17BD4E0B8
C8DDB49BB288A3BB8B89A06C3A5216BFD594D2E9A1C6DE94
DFD9D9F2ECECFFFBFBFFFDFDF9F3F3FFFDFDFDF9F8FFFEFDFFFEFFFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFCFFFBF4FFF2F0FFE9E2FED5C7E7B5BDDCA3CAE7AFE5FBCCF7FFE3
FCFFF1FEFFFAFFFEFFFDFDFFF9FFFF8894928FA39A627E70A3C9BAE9FFFDF1FFFCF5FAF6
FFFDFFD3DFDD79B3A7004E3C1A8A7477CDC2F5FFFFF3DCF0A38B98FFFBFBFCFFF6FBFFF3
FFFCFAE3D0D2FCEDF0FFFBFFFFFDFFF8F6F9F5F4F9FFFEFFFFFEFFFFFDFFF7EDEEFFF8F8
E4CCCA240604310F0D372114F7FADBF8FFDFDBEDC5C2D4ACCEE3BCCDE3BCCFE8C1D5EFC8
CBE5BECBE7BECBE8BCCAE7B9C6E3B3C6E4B2CAE6B5CEEAB9BBD8AAD2F1C5C5E6B7001000
698F60C1E8B9C9F4C6C4F2C4B7E6BCB8E8C207361474A28690BDA690BDA9BAE6D7C3F2E0
C2F0D6D1FFE3B5EDC6A7E4B8C0FFCEBCFBC4AEE8AEBDEFB2BEE4A7CBE8A8F3FFC7AEB87B
8F9557979C5CC8CA8BCAD394CBDD9FBACE91ECFCBED8E6A8D3DE9CCCD793E4F1A9A5B56C
CCE196DBF1A6CBDF97D0E19BA2AD6B5F6527DDDCA3DCDCA0E1E3A2DAE19D929C57B5C27C
C4D890CBE59BD6F5A9C6E89BBDE294C6ED9EC7EE9FC1E899C6ED9ED2F7A9CDEFA2BEDD91
CADF9474843BD7E7A0DDEDA6DDEDA6D6E69F7B8843E4F1ACD0DD989CA964677331B6C582
DAE9A6D5E4A1D7E8A4D6E7A3BDCC89DEEDAA748443D3ECA8C5EBA2BADB94DEEAAA9D9B5E
4D4308DCD899D1E79ED7F7ABCAE99BD0E598BABB75A5A25F707535282E00717238D1D098
DEDBA4D8D7A1CFD29DD0D7A3E3F1BCB8CB94A4BB87657C4892A474CEDBADDDE6BBCDD8AE
CFE1B7B0C59AA5BB8DDAEEBB93A86F647839DAEFACCAE098
FAF2EFE1D9D6C2BAB7FFFDFAFFFDFBF7EFEDFFFEFBFFFDFDFFFEFDFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFEFFFFF9FFFDF1FFF2DAF1D4C5E1B8BDDEA9C5E6ADD1EDBAD7ECC5
F2FEE8FEFFFAFDFCFFF2F2FCBEC2CD2A3338708080758E88D5F6EBEEFFFDF4F9F3FDF3F2
FFF4F6FFFEFFE6FFFFCBFFFF1F957F329487E3F3FFFFEFFFDFCBD6FFFCFBEDF1E2FDFFF0
FAEDE7F7E3E4FFFAFBFFFBFDFFF7FAFFFDFFFFFEFFF9FAFEFEFFFFFAFAFAFFFAFAFFF8F6
FFF9F6391D1938161412000065634EE4EDD2FBFFECF0FDE3F7FFECF7FFEDF1FFEBE4F6DE
F4FFEFF3FFEEF3FFECF4FFECF4FFEAF5FFE8F5FFE8F7FFE6F9FFE4E3F1CED3E5BF5E754B
7F9A6DC8E8B9BFE5B4BDE9B6CAFAC8A5D9A8C7FCCE8CC59A98D0A985BE9B94CDAD85C0A0
14512F1758307DBE947ABE8F61A57276BB8474B87DB8F8BBB5F0B0B4E7A5AAD294D6F2B7
D0DFA6A1A46FC1BB87979763BCCF98CCE5ACCBE0A7CDDCA1D1DFA1DBE7A5CFDF98CDE297
D2EA9ED1EC9FBFD78DDCF0A9C1CD8B474B0EA4A269E3DEA6DFE1A0D7DE9ADDE7A29FAC66
9CB068D0E89ECFEEA2C7E79BCDF2A4CBF0A2CEF3A5D1F6A8C9EB9EBCDE91C4E498D8F4A9
DBF1A8AFC07972833C63742D6D7E3795A65FCFDE99D4E39E6D7C37000E00788744BDC987
283400D9E5A3D7E6A3C8D794DDECA9DBEAA7AFBF7E7C914ECEECA6CBE9A3D1E6A3D6DFA0
E7DEA59D975BD4E19CBDD98ED5FFADC5E695D6D791E6DD9CDEDEA09B9C60746D36746732
C8B684F9E9B6D6CC99EBEEB7C2D198A4C0856385493F63266481496B824CD2E0AFD2DFB1
E0F1C5C7D9AFCADBAFC4D6A6D3E4AE56682ECCDF9FD6E9A7
FBF4ECFFFEF69F9892F6EFE9F9F4F0FFFEFAEDE8E4FFFEFBFFFEFDFFFEFDFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFBFBFDE9F2E1D8E9C7CEE9B4CBE9ADCAE3AAC8DBAD
FCFFE8FFFFF4FDF7FBFFFBFF8D8997292933888F95F2FEFEF4FFFFF0FBF5FFFEFBFFF6F6
FFF6FAFFFAFBE2F6F4D5FFFF38A3912E8B80F0FFFFFFF3FFCABAC4FCF4F1FCFFF1FEFFED
FFFDF3E5D2CEE3D4D1FFF1F1FBF2F3FFFCFFFEFFFFFAFFFFEFF8F7F5FBF9FFFFFDFFFBF7
FFFBF689726C4D2E2B290C062E1D15BFB5ABFFFDF4FFFEF6FFFDF7FFFFF8FFFFFAFFFFFB
FFFFFBFAFBF5F8F9F3FEFFF7FFFFF6FFFFF3FEFCF0FFFCF0FFFDF1E9DDCDD4CDBAD9D7BE
878D6BD4E0BACEE1B4C5DFAFB6D6A4C1E6B2C2EAB6E7FFDFE3FFE0E4FFE4E4FFE6D1FFD9
5594654A8E5D86C4938DC7948CC28E4C854E0A450B7DBD8079C07EB9FFBEADEEAEC3F6BB
B8DBA5CEE0B0E5E6BE999B737B9363ABC995CCE5AEC8DDA5DBEAAFDAEAABD6EAA5D8EEA5
D7F3A6CDEC9EC4E095DAF1A9DBE7A583874A837E46E2DDA3E2E7A7D5E09CD6E39EB0C17B
768C44CBE59CC4E096C5E59ABCDC91C4E499C3E398BCDA90C5E197D6F0A7D7EEA6CAE098
CDE49CBED58DBBD28A94AB6390A65ECBE199DFF4AFCEE39EAABE796A7E39B8C887D5E4A3
8D9C5BA9B877D3DF9FE0ECACD3DF9DE1F0ABCFE49F8EA15F7A8948C7D798DFF8B6C5DB9A
DAE0A49F9F639A9A5CDBEAA5B5E08EB9E08DEEF4ACD3CE8CDCDE9FDADEA1C3BE84554A12
645420ECDFAAF2EBB5ABB076697D40557333143B0000160000140000100091A66DDBEDB9
C2D3A6DBECC0DCECBFD7E7B8D9E7B4485720BFCE95DDECB1
FFFEF4FFFBF0FFFBF0BFBBB2F0ECE3FFFEF7FFFFF8FFFCF7FFFEFBFFFFFDFFFEFFFFFFFF
FFFEFFFFFFFFFFFEFFFFFDFFFFF7FFFFFBFFFFFFF4F0FFDCD8F4BACAE9A5C6E59FCCE4A8
C7D3ABDEE2CBF6F1EDFFFCFF565158111016FBFFFFDFE3E2B7B5B6ABA7A6FAF2EF9C8D8A
9B787C8970736F7B796FA29B217B6F469791EDFFFFF6EFFFC5B8C1E1DAD4D5DFC7EAF2DA
FFF5E9C2B1AAC5B6B1FFFCF8FFFCFDFEFCFDF4F8F9F8FFFFF5FFFFF5FFFDF6FFFAEFF0EA
FFF9F2F3E0D9896D694125213E29268A7B78FFF8F8FFF8F6FAF0F1F7F1F1FEF8FCFFFDFF
FFFDFFFFFDFFFFFCFFFFFDFFFFFCFDFFFCFBFFFBFAFFFCFAFFF0F1FFFBF8FFF6EEDFD8C8
817F68FBFFE0FBFFDFCFE3B2D2EAB6DBF8C0C3E2A9B3D49BCBECB5CAEBB6B3D3A1C5ECB7
B6E9B1C2F9C0C6F7C0B3E0A9B0DBA5CCF7BFB1E1A75C92560A470B3B7D4069AA7073AF79
83B383C0E5BAC7E1BACBE4BDA0C194577C4954703FC4DBA5CADDA5CFE1A3BED390D0EAA1
C4E397C6E798C7E79BCCE69CDFEEABCED393827B44A19C62CFD897D7E6A1CEE29BC7DD95
91A86096B268C9E59BD3F1A7CBE99FD4F2A8D9F3AAD3EAA2D0E49DD5E49FD5E29DCDDC97
D9F0A8CCE89EC4E096D1EDA3C5DF96BCD68DD2ECA5C7E19ABFD690D6EBA6D2E5A3CEDE9D
D7E7A697A665D3E1A3D0DF9ECFDE9BBDCE88CCE09BDBEAA7ABB175192300C9E2A1CFE9A8
CADC9ED6E0A3D0D1957A8342D1EDA2E6FFB5DCE9A1D9E09AD6E19FE0EAABD9E2A3B9BD80
A6A76D73743A4E5418929E608FA4639DB776C5E5A2B1D18E98B8755E7D3A5D7738687D44
49592A68754A5B683CB5C193687444010D006D7743C6D39D
FFFDF1FFFFF3FFFFF2FFFFF4B0AEA2FCFCF2FEFEF6FCFBF6FFFFFBFFFFFBFFFFFDFEFFFF
FFFFFFFEFFFFFEFFFFFFFDFFFFF3FFFFFBFFFEFFF1F7FFDDD8FCB4C3ED97C1EC93CAEFA1
D0E8AEE1EDC5FFFFEDF8F8EE10110C000200D7E1D851524C8D7A7E927E807B7871080000
1B00002303080915134A77700D4F4B3B7778CEEAF5CCD0DC756A70140B04061000667055
726B5995877CCBBEB6FFFBF4F7F2EFFFFFFDF9FFFFECFBF8F2FFFFF2FFFFF3FFFBF9FFFA
FFFFF6FFFCF3BCA8A11000000A00002C251FF7EFECFFFFFAFFFFFDFEFFFDFBFCFEF2F6F7
FAFEFFF5F9FAF8F9FBFBFDFCFAFAFAF6F5F3FFFCFBFFFEFFFFFCFFFBFAFFFDFFFECACFC8
8A9380E8F7DAECFFD8D6EEBCC8E4AAB3CF92DAF6B9D9F3B4CCE4A6D5EBADE4F9BECDE1A6
D0E5ACD1E9AFBFD89ED6F2B7DDFAC0BFDCA2C2E1A8C7E5AFEDFFDC5B8150001200001500
5E996D4A8D612B7449B6F9CD8BBF91B4DBACBBDBAA87A26FDEF1BACEE0A4D5EAA9D3EDA6
C7E79BCDEFA2CDEDA1CFE99FD2E19EDDDFA09F965F5C571D9EAA68CDE49EE0F7B1C7E19A
C3DE9789A75FBAD890CBE9A1D4EFA8BED891C6DB96CFDE9B98A3615D63238B8D4EE9F2B1
CBE59CB9DB8FDDFFB5BCDE94BDDD94E9FFC0CBE9A3C8E6A0D3EEA9CAE39FBDD392E7FCBB
CCDF9F89995A000D00D4E4A5D5E9A2E5F6B0E9F5B3C4CD8C969E625A6427D2E2A4D0E6A6
D4F3B0C9E6A3D8E8A7D7DD9D4C4809424502C5DB90D3F2A6C6DD97CBE29ED1ECA7CAE9A3
C4E59ECAE9A3CDEBA5D0E9A5D6E9A7CDDD9EDAE8AACAD89AD0E3A3D5EBAAC8E3A0C9E3A4
8595645D683D535E333C451A060F007C8558474F20D9E3B1
FFFDECFFFFEFFFFDEEFCFDEFEDEDE1AFB0A8EAEBE5FEFFFBFEFFFDFEFFFDFEFFFDFEFFFD
FEFFFBFEFFFBFEFFFAFFFFFBFFF7F8FFFDF7FCFFECEEFFD6D9FAB5C7EE9BC2EA92C5EA9A
C7E7A6C6E0B1EAFFE7F4FFFA33423B9BA8A1C8D4C8FFFFF8CCB6B8715B5D5A5B53A4A198
A38386FFF0F5F1FAF9DAFCFB89BBBC3364696A8B944A58617A7478B9B0ABE6EED7A2AB90
9D96864C3B3137261F9A8B86B5ABA9BAB9B5C1C7C3CFDBD7EAF6F2EBF8F1F8FFFBFBFFFA
FDFFF5EEEADFFFF2E921100808000014110AFAF9F4FFFFFBF3F8F4F7FBFAF9FDFCE4E8E9
7E7F817E7F81838383858585807F7D7E7D79908F8BA8A7A58D8C9264646C8F9396636965
2B362885937C7E8F6F6F815B72885A748A595266339FB17DD2E3AFC4D5A1D7E5B2D3DFAD
D5DDAAD1DAA5E4F3BCCEE1A9BACF96D4EBB3D7EEB6C5DCA6CEE5B1BAD6A3D9FBC8B8E7B3
AAE5AF40895151A56A73C2897BB680497844305B267CA16D88A972829F6784A266C6E2A5
CDEAA8CFEAA7CAE19DDDEEAACDD896DBDD9CE8E4A57D7C3C737E3AC9DA96D6EBA8C4DD9B
CEEBA8C8E7A192B066ACC67CCAE097DCEDA7D7E1A2B4BA7E9B9F64A3A46AB0B273ACB572
D2E9A1C9E99ECAE89ED1EFA5CBE99FBFDD93C7E29BD0EBA6C9E49FD2EBA9D5EBAABBD08F
DFF2B2CFE2A08E9E5D5A6E29D2EAA0C3D990CEDD9AE0EAABD6E2A44E591DE0EBAFC9DC9C
C3E19BCDEDA2CAE298D8E29DC5BD7F8482458DA8639DC179D1EAA6DBF2AEC5E39DC1E59D
C8F1A5BDE69AC3E59BD2EDA6D0E49FDDECABCDD798D8E4A6D6E6A7CCE2A2D4F1AFC4E3A7
CBE7B78DA37C33431E000700292D0CE7E7C5504D2AC1BD9A
FFFFEAFFFFEAFFFFEFFFFFF3FFFFF8E0E1DCD7DBDCFBFFFFFBFFFFF4FAFAFCFFFDFCFFF8
FEFFF3FFFFF1FBFDE8FFFFEAFAFAE0FFFFE6F1FFDEE1F6CDD7F0B9C9E3A2CDE6A2CEEBA8
D0F3B9AED9AE9FCFBF81AFAD5B8184D1EBECEFF8F5F0EBE7655756D8CFCAF4FAF0FCFFF8
FFFCFACCC0C4F5F6FBF1FFFFDEFFFF81B0B6ABD2D9EEFFFFA7A8ACFFFEFAFBFCEEFFFFEF
FFFDF1E8D4CDB69896C4A8A7AF9D9B8E86837E7F7A80827D746F6C3A3230514C486E6F67
7F8579797D6F71675D281B13040000080703343631393E3A1217136165640707072D292A
0D0407100607302424120606070000040000050200312E272018160600003F3637211C19
0300000E0E040D0F020F13040F1604000700000500030D000814001521093A462E656F54
6974526C7B52CCDDB1CEE1B3CFE5B4D2EAB6C2DEA4CAE6ABC6E4A4C4E7A3C6EBA5BAE59D
C3F6A9B7EE9DC3FFAEB1EEA0B5F1ABC4FFBDABE7A965A165114A139ED39F8AB68578996C
7F95678D996B9A9E6B9A9B62B9B97BE0E39CDCE396D0D78994954F6D6F2ED8E1A8D6E9B1
CAE3A9CAE7A4CEEB9B8FA753C2CF7FEFF2ABDAD59D918B5BD6D2A3D7DAA5EAF5B386964F
C9DD96CDE39AE3F7AFBFD489D5EA9DD4E99CAABE76899D58B1C484D5E7A9CCDEA0D9EBAD
DAEAA9D4E5A1DFF0A9869C51CDE99CC9E89CD1E8A2CCE1A0D1E3A78B9B5DB4C382D4E59E
CEE394D6EC99C8DE89E2F3A3D8E39ED7E5A8C0D9A0B2CB9298A76CCFDB9DD9E8A7C3D792
CFE59DD3EBA1D4EAA1C9DF96CCE299D1E6A1C3D897CEE7A6D3EDB0C6E3A9D3F2B9BAE0AD
81B1891A4726062307C1CDB74C46365D4B3F9F877B563B30
FFFAEFFFFCF2F8F4EBFBF8F3FFFFFBFBFBFBE9EDF0F0F4F7F5FAFDFBFFFFF7FBFAFEFFFB
FCFDF5F0F0E4FFFFF1F7F6E2FFFFE6FDFFE2E5F3CFCDDEB2D1E8B2DAF4B7C7E6A3C0E4A6
B6E2B1BDEED052877D24555988ADB5EDFFFFF4FAF66F6C658F8882EAE7E0F9FFF8F9FFFA
F7F8F3B3ADAFFFFDFFEBF2FCDFFFFF91BCC277A0A4EAFFFF98A0A2FFFEFBFFFFF6FFFEF3
FFF8EFF3DBD7FCD8DAFFE8ECFFF9F8FFF8F6F8F7F2FFFFFACBBBBCA18F8F6459572A2720
2B352A1F271A160F050A0000110906030000060702000100000501000100010000262022
291D1F403033705D5F514141332522433A335F5D51A4A0958077727F74729E9391403634
0D050278736F8D8A8572716C666560292A240E110A2E332C4148401E281F000400000500
000600000B00667453BACAA6CCDEB6CEE4B6C2DAA6DCF8BED3EFB2C8E7A3BCDD96D9FEB1
B0D786BDE791BCE690BDEA95B6EA98B7EDA2AFE8A3A0DC9C0C49105C9664B7ECC0BDEAC3
BDDFBADBF5CE8EA1744D5B28919F62D8E7A2DAEB9DD8E596BEBF7B6565296B723CC6D59E
D1E6ADCCE5A3CDE597B0C673A8B364BEC17A9B9960C1BE8BDFE1B0EEF7C0D2E2A195A962
DAEBA5D8E9A2C4D68CDDEFA3D1E495C8DB8C88984F8C9D579AAA6BACBC7ECFDEA3D7E7A9
C3D392C8D993DAECA08EA557CDE99ED7F7ACC8E69ECDE6A2D4EBA7D5EAA592A65EA5B76B
C0D181EBFDABC3D685CDE295D1E79FD2E8A8D4EBB3CDE0A9404B11DBE5A8E3EDB0DEEAA8
DAE9A4D1E29BC9DE93D6ECA1CFE79DCBE79DD4F1AED6F4B4C2E1A6C5E6ADC3E4AFBCE6B6
2A623B164D2E537960CEE5D1ABAFA1564E435B4D440E0000
FFF7FFFFFAFFFFFCFFFFFDFFFFFDFFFFFFFFE7E7E7CFD1CEDDDFDCF6F8F7FCFDFFFFFEFF
FFFEFFF8F7FFFFFDFFFFFDFFFFFFFAF5F8E3EDF4CBCFDEA7C5DF9EC3EBA4B0E698C0FDBA
CBFFE376A69A90B2B1EAFFFFE2EFF88791937E897B6E7263FEF7F1FFFEFAF8FFFAECF9EF
FBFCF6D6D0D0FFF7FDFFFEFFEDFFFF8FB5B891B9BBE5FFFFB9C3C4F7F6F4FFFEF8FFF7EE
FFFBF4F8E3E0916F70FFF4F8FFF9FAFFFAF8FFFFFBFFFFFBFFFAFDFFF9FBFFFCFBFAF9F4
F1FBF0FBFFF6FFFEF6D5C8C21507040C0100322A279C9B97FBFBF9FAFCF9FCFCFCFFFEFF
FFFCFFFCF0F2FFFAFAFDEFEEFFF7F5FFFEF8FFFCF3FFFFF6FFFCFAFFFCFBFFFCFBC0B8B6
7C7472FBF6F3FFFEFBFDFCF8FEFDF9F6F7F2F7F9F4FCFFFBFCFFFBE9F0E9CFD4CEBEC4BA
979B8C4C513D131802161F040006001924024B5A33899A6E617343E0F5BDC9E1A7CAE4A5
D9F3B2C0DE98EBFFC3C0DF93C7E995CCEF9DD9FBAFBEE5A2D1FDC2A3D5A277B2842C6D43
77BE946FB78972B685AAE6B09FCF957DA465B2CD8AC8DB99D5E0A4A7B1759AA569647032
9EAC6ED3E29FEBFAB5C7D891C4D48DAABB75768743D2E2A1E5F8B8F9FFCDD9EDAEB1C685
425611A7BB73D1E69BB1C67993A859809548A9BB71D6EAA3CEE1A17E9054B7C98FDEF0B4
D3E6A4D8ECA5D1E6998DA358CDE6A4C3E09EC2DD96D3EFA2D0EB9ACEE794B7CE7C9BB264
9DB169CCDF9DCBDE9ED2E6A7D4E9A8D0E5A2C6DD97CDE29DC8D8996371339CAA6CCDDE9A
D3E7A0C1D78EDAF2A6CAE598D2EEA3BCDC91C4E59ECEF1ADBADEA0BFE5AA779C665B8553
7FB2897AAE8AC1EECDBDE6C6AACDAFC9E6C86C8367001400
FCF8FFFFFBFFFFFCFFF4F2FFF5F2F9FFFEFFFFFFFBFCFCF4D5D4CFCFCEC9FFFFFFFBFAFF
F7F5FFFEFDFFF4F2FFF8F7FFFCFBFFFFFFF4F2F8D2D3E5A9CBEFA7C8FDAFAEF4AB9BE4AD
D6FFFB7AA7A0F0FFFFFBFFFFF8F3F7010000E4ECDDFCFFF4FFF7F5FFFDFDEBF8EFF0FFF5
FEFFFAFFFDFBAA999FFFFBFFF0FFFF93B2B4BCE4E3E9FFFFCDDBDCFFFFFFFAF2EFFFFCF8
FFFBF8F0DCDB5B3B3EFFF1F6FFF5F7F5EFEFFEFFFDF7F7F5FEF2F6FAEAEDFFFCFDFFFFFB
EDF9EFF9FFF8FFFEF8D5C6C10F0000110000342522AAA29FFAF9F5FEFFFDFEFFFDFFFFFF
FFFDFFFFF9FCFFFCFDFFFBFBFFFCFBFFFDFAF9F4EEF9F6EFFFFDFBFEF6F4FFFEFBE2DDDA
8D8885FFFBF8FAF6F3FFFFFBFEFDF9FFFFFBFFFFFBFBFDF8FCFEF9FEFFFBFEFFFBF8F9F3
FFFFF8FFFFF4DAD8CBABAC9C4647351012000C1000020700070E0048532BDAE5BADBE8BA
D3E1B0C5D3A0C6D49FD7E6ADDAE9A8D2E19ECAD89ACBDAA1B7CB96CDEDBBB2E1ADB3EFBB
408A55075A223E9159408D5589C893BFEFBD7A9B6CCDE5B5D8EFBBD9EEB5C9D99A45520D
575E1A8B924FE2EAAECEDC9FD0E4A5CDE8A3C6E69ADBFEAEC2E296BFDA93D3E9ABD0E4A9
D6EDA993AB6141590D526A1CCAE193D6ED9FDEF4ABC9DE99CCE0A1132700576B30C2D699
D0E3A3D2E8A0BFD4899AB067667F3ED6EEB0D1EDA3BFDC8AD2F098BBD981C9E692C6E194
C3DC9A3C541A617540C1D69ED1E5A6DAF0A8D8ED9EDDF2A3DBEFAAD2E5A58FA461DAEFAA
D9F0A8C8E298CAE699C4E39500120035570B3C60183E631E274E0F21490B001C00315925
153E1298C29CAAD8B1CAFDD4B4ECBF49815433663BCDFFD5
F6F8FFFAFDFFFCFEFFFEFEFFFFFDFEFFFFFAFFFFF6FFFFF3E9E5DACAC8BCFFFFFAF9F9F7
FEFFFFFBFFFFF9FFFFFBFFFFF4F2F7FFFFF6E3EDCBC0D9A0B2E394AEEEA0B1FDCC9CE7C8
39755C496F62F2FAFCCCC3C6130600E8E0D3F8FBF2F9FBF8FFFAFEFFFCFFF5FFFDF2FFFA
FCFFF8FCF3EE998084FFEEF2F0F8FAA1BBBAB1D8D5D7F9F8DEEEEEF9FAFCFFFCFBFFFBFA
FFFCFAF9E7E7E9CACFFFF1F6FFFAFDFFFEFFFCFFFFFEFFFFFFFAFFFFFAFFFEF5F8F1F1EF
F8FFFBF9FFFAFFFBF7FFFAF84C2E2C160000230B096E5F5CFFFDF9FFFFFBFBFFFCF7F9F6
F7F7F7FDF9FAFFFDFFFFFAFBFBF2F3FFF7F5FFFEFBFFFEFBFFFEFBFFFEFBFFFEFBD4D0CD
74706DFFFFFBFEFDF9FFFFFBFFFFFBFAF9F5F6F5F1FBFCF7FAFBF6F4F5F0FAFBF6FFFFFB
FBF3F1FFF7F6FFF6F4FFFEF8FFFEF6E7E0D6BDB7AB585242060100110F000907002C2B0F
ABAA8CFFFFE1898A6A787959B7B69AB3AF9488826289815CE7E3B6DCDFAADCECAEC7E6A2
B7E69EB4F0AAA8E9A96FAE7742794F1A47281738256E8B75ADD0A6D0F1B8DAF1ADDDEAA2
7D80395C5D1BAAAD78E3EDBBD6EDB5BDE09EB9E693B9EA8FC5F097C7E99CDAF3B9C2D79F
C7E09ED1EBA2A6C076CEE99AD5ED9FCDE597C1D98FD4EBA5D3E9A9051A00485D24D7EDAF
D5EAA9D3EAA2CFE59AD2EAA093A96881975695AF65D0ED9BDCFDA6D9FBA5CAEB9CC4E39D
CFEDB1CCE9B38AA270657C46A6BA7BCADE96CADE89D5E896D5EBA3BAD08FACC5818FA962
CAE69C8FAE626F9041A9CC7CC8ED9FB0D689C1E79EBFE7A127500E4C7637BAE3A7CAEFB9
859F721E390E557F4F447A46165A215CA66BC3FFCEBCFFC7
F7FFFFF1FCF6F2FCF4FCFFF8FFFFF4FFFFF1FFFFEFFBF6E3FFFFEDDEDBC8F1F2E2F7FBEC
FBFFF6EFFBF1F5FFFBF4FFF7FFFFFBF8FCEED4E7C7D9FDCDBEF6B96EB2793E8366397867
001404D9F5E6CAD0C4776F62C1B6A4FFFAEBF8F4F5FFFBFFFFEFFBFFF7FCEBFCF4EAFFF3
F6FEF3FFFCF5FFF6F8FFF7FBFBFDFCDAF0ED547874B9DDD9BED0D0F4F5F7FFFCFDFFFBFB
FFFCFBFFFBFBFFECF1FFF6FDFFFAFFFAF8F9F5FBFBF7FBFCFFFCFFFFFAFFFBF5F9FEFFFF
F7FFFDF8FFFBF8F4F1FFF8F7663F4031070847282696837FFFFEF8FFFFFAE7ECE6FBFFFD
FCFFFFFFFFFFFAF8F9FFF9FBFFFDFFFFFDFFFEFAFBF5F1F0FFFFFDFFFFFBFFFEFACDCCC8
6B6A66FFFFFBFFFFFBFFFFFBFCFBF7FFFEFAFFFFFBFFFFFBFFFEFBFFFEFBFFFEFBFFFDFD
FFFBFFFFFBFFFFFBFFFFFBFDFFFBFBFAEEEEFFFCFAFDF2EEFFFDF4B4A79E1004000A0000
0800000800008F8675FFFDF1FFFCF8FFF4F1FFFCF3F2E3D0BFB292877E53070600D4DCA0
D4E7A7CAE7A7D8FCBFBBE1AEBFE4BBCBEED05A7A65000D002A552AACD59BCDEAA7B2C47A
F3F9B1D5D5952A2C006C7546D1E8B4C6EAAAC2EF9CC6F79BBCE88FC4E699D2EAB0DBF0B8
C4DE9DD9F5ABCBE79CC3DF92C1DC8FCEE99CD5EFA6D0E9A5CDE5A719310032470ECEE3A8
C1D797C9E09AC8E096CEE69AC6DC93E4FAB1142C00D5F1A4BBDB8FC7E99FB0D590D3F7B7
C3E6ACD0F1BABFDCA4C9E3A691A6636C7E34DAEC9AD5E795CCE29AE4FDB9CFEAA3D1ECA5
738F4587A65ACFEFA3B7DA8AC6EB9DCEF4A7BFE59CDCFFBEB5DE9CB9E1A2CCF4B6C0DFA6
D3E1B08C996B1937034D7D43A9E7A8A0E7A5B6FDB9A8EFAB
F4FFDCDDF3C4CCDDB1CEDAB2DAE0BEFAFBDCFFFFE6FFFFE6FFFFE6C7C6A8D9DCBDDAE4BF
DEEEC7BED5A9CFEBBBBFD8AED8E5CBCCDEC4D4F8D299CBA857907D467E7170A094E7FFFF
E8FCFBF3FFF51B250080875DFFFFECFCF4F1FFF9FFFFF7FFFFF6FFFFFBFFF1FFFCF0FFFB
FBFFF6FFF7EEFFF6F6B99C9EFCFBF9F2FFFF092E27AFD3CF97ABAAFCFFFFF8EDF1FFF7FA
FFF8F9FFFBFDC6ADB3FFF7FFFAEFF3F4F4F6F9FFFFFBFFFFFFFCFFFDF2F8FDF7FBFEFFFF
EBF7F3F8FFFDFFFEFDFFF8FA72464734040225000078615BFFF7F1FFFFF8ECF3ECF9FFFD
EFF5F3FAFEFFFFFFFFFFFEFFFFFDFFFFFCFFFFFCFFFCFAFBFFFFFDFCFEFBFAFAF8D6D6D4
767674FEFEFCF7F6F4FFFFFDFFFEFDFFFEFDFBF7F6F3EFEEFFFAFAFFFDFDF2ECECD0C7C8
93888EA79AA1D3C6CDF6E9F0F8E9EEE8D9DEDCCDD0B5A7A72B1D1D8C7C7CD3C4C18C7D7A
6F5D590D00000D0000776865B8ACB0FFF6FAFFFCFDFCF7F1E9E5D9E4E2CDFFF9DFB9B091
746A478D835F4A421B6260379BA276798B5B6F87576C8E5B2C5B25518145D7FCB9CCE69F
C0CF8AE9F2B379804C4B5523CBDDA9CBE8A8C5EA9CC7EF99CBEE9AD3EFA4C2D89AC0D59A
D7F2AFAFCD85CFEDA3D2F1A3E4FFB3C2DE91C9E59BC7E29DC3DD9E243D03001600C2DA9E
C8E1A0D6F0A9D2ECA2D3EC9BDBF19CC2D883E1F9AD849F5C7F9E638BAE7898BF8AB8E0AB
B9E2A6C1EAA8CAEEA8D4F2A8ADC57983984BBBC97E8E9E55D4E9A4BBD490D0EAA3D1ECA5
DEFAB0C6E599CAE99DCDEDA1CAEA9FCDEFA3BDDE97C2E6A0C5EAA7CAEEAEC7EBADD0E9AF
DBE2AEA9AB798190599CB87DCCF4B5C7F5B4ACDB97C4F6B1
DDFCB0D1EDA3D4EBA7D5E7A9D6E0ABE9EFC1F5F6CEE4E2BCE4E2BC85875FC9D2A5C2D39F
D2ECAFCDEDAABFE59CCAF1B0CCE9BDBFE1C0BDEECE467D6A5E9195E0FFFFE5FCFFF7FFFF
E8EAE9272A19FAFFDCF7FFDAF2FAE5FFFEFFFFEFFFFFF4FFFFEEFFFFFBFFE8F9F3F1FFFB
F6FEF1FFFDF4FFE4E4CDB3B4FBFBF9D7ECE73E665E5F837FDEF2F3EDF1F4FFFBFFFFF6FB
FFFDFDFFFBFCEAD3DBF7E2E9FAF1F6FEFFFFF8FFFFF1F9FBFAF3FAFFFBFFFBF6FCFAFEFF
F7FFFFF7FFFFF2EEEDFFF8FA6A3C3C3D0A07461F1A533733FFFCF4F2F2EAFBFFFBF3FEF8
F9FFFFFBFFFFFAFBFFFCFBFFFDFBFFFDF8FEFFFDFFFFFEFFFCFEFDFEFFFDFEFFFDCBCDCA
70706EFFFFFDFFFEFCFEFDFBFCF8F7FFFDFCFFFDFDFFFDFDE6E0E0D1CBCBE5DCDDFFFCFF
FFF7FCFFFBFFFFFBFFFFFBFFF7EAF1FFFBFFFFFBFFFFF3F7FFFAFDFFFAFDCCBCBD89797A
826F7185737359474799898A0C0004666064D6D7D9F9FFFFF7FFFFF8FFFBF5FBF1F1EFE2
E4D8C8DDCBB7EBD7BCE0D0ACE1DBABE3E8AEC8D897C7E4A1C5F1B448783C001400B1D494
CEE8A9CEE2A5ACBB84909F683B4A118B9D5FD6EBA6C8DE96D3E9A0CCE099D5E5A4DAEDAD
CFE8A4C2DD96D3EFA5D1EDA2B3CF84DAF6ABD1EBA4C9E4A1D2ECAF3A5319000D00CFE7AD
D4ECAECAE39FC3DD94D2EB9ACBE287D2EB90CCE498CFEBAEB0D09F80A57A4D734A6C9769
CAF5BD9CC782C6EFA1C4E795D2ED9ED1E699CCDC95DDECA7677C39D8EFABD8EFA9C3DA94
CFE9A0CDE79EC5E196D0ECA1CCE89EC7E59BCEECA4BDDC96CFEEABD4F2B2BAD89AD2E7AC
D1D99EF2F3BACED69B5F6D30D7E9ABC9DF9ED1E7A6C8E19F
CEF197B3D47DD9F4A3C9DE93CFDE9BE0EAADD9DEA8B4B885939765A3AC77CCDBA2D3ECAB
C1E29BC2EB9DCDFAA9B4E79CC8FEC2C9FFD89ED4C667979BB8DCE8E8FAFFFDFBFFCEC4CF
78715F7C7B5CF4FFE7EEFDE8F7FFF6FCFFFFFFF1FFFFF5FFFFF5FFFDF6FEF5FFFFF2FFFB
F9FFF5FFFCF5FFEAEAEFDCDEEDF6F3C4DFDA365D58BADEDAEAF9FCFEFFFFFFF7FCFFFBFF
FFFAFAFFFCFDC1ACB3FFF8FFFFFBFFF6FAFDF7FFFFF4FCFFFFFCFFFFF7FFFFFDFFFCFFFF
F7FFFFF7FFFFFCF8F7FFF8FA7A4A4A3C0604512824674C45FFFCF4FFFFF7F2F9F1F8FFFD
F8FFFFF9FFFFFCFFFFFFFEFFFFFDFFFFFEFFFFFEFFFFFFFFFDFFFEFBFFFCFCFFFDDDE2DE
8C8E8BFDFFFCFFFFFDFFFFFDFCF8F7FFFEFDFFFAFAD7D1D1DCD3D4EEE5E6F1E7E8FFFCFD
FFFEFFFFFEFFFFFDFFFFFEFFFFFDFFFFFDFDFFFCFDFFFCFDFFF7F8FFFBFDFFF0F3D4C6C6
C4B4B5D4C4C5D9C9CAC9BBBB261C1B3A39375F6A66A4B8B6E2FFFDE0FFFFE7FFFFDEF9F2
DAEAE0E8EFDFEFEDD6E2DCBAFFFCCDD8D89CE5EBA5CBDC95C4E9A68BB97B67945B7EA973
BFE6AFD0F3B9BCD89BD0E5A4495515656B2F9F9E66D9D8A2E4E5ACD8DE9EE2EDA8CDDD94
CADF9AD5ECA8D0EAA3CFE99FD7F1A7CEE89FC6DD99CDE6A5D5EDB1536A32001100DCF3BB
C1DB9EDEF9B6CAE69CD0EB9AD7EF97C8E28BCAE49BCFECB283A477284E27325A35517E53
6E9A65517E3DC3EBA2C6E89BD7F2A5D8EEA3C5D68FD7E6A1728543C7DC99D3E8A3D1E6A1
CAE098D5EBA3D4EAA2CFE59DD9EFA7CCE39BC5DC96D5ECA8D0E6A5CFE8A7DEF7B6C7DD9D
D1E4A2CDDC99DEE7A6A8AD6DA5A366979558D4D295E8E7A7
C1E18EE7FFB2CEE99ACFE698DCEDA698A560646F2D939D5EBFCD8FCADD9DD2EBAAD1F0AD
C7EFA9BCEAA2C3F5AED0FFC7B4FBC1B9FDD6467B73E2FFFFE9FBFFFCFEFF766A780B0000
D9D2B8D0D1B2FBFFF6F7FFFFF8FFFFF9FDFFFFF9FFFFF8FFFFF9FFFFFDFFEAF6F2F5FFFB
F3F6EFFFFDFAFFFBFBF2EEEF617574476B670A3231E7FFFFF5FFFFFFFEFFFFF9FDFFFCFD
FCF8F7FFFCFDDEC9D0E4CFD6FFFAFEFBFFFFF3FEFFF9FFFFFFFCFFFFF5FFFFFAFFFBFCFE
F3FFFBF8FFFFFFFEFDFFF8FA6B3F3E49181498736DBDA49DFFFDF4FAFAF2FBFFFAF8FFFD
F9FFFFFBFFFFFCFFFFFFFEFFFFFEFFFFFEFFFFFEFFFEFFFFF5F9F8FCFFFDFCFFFDEFF4F0
797B78FEFFFDFFFFFDFBFAF8FFFEFDF9F5F4C5BFBFE6E0E0FFFCFDFFFCFDFFFCFDE8E2E2
FFFFFDFEFFFDFFFFFFFFFFFDFFFFFDFFFFFDFFFEFDFFFEFDFFFCFCFFFCFDFFFCFDFFF7F6
FBF1F0FFF5F5FFF8F8FFF6F4FFFEF8C2C2BA808A8201120C00090488A8A3D4F7F3E6FFFF
EEFFFFF0FFF4F9FFEFFFFFE6ECEDC5E4E3B3E7E6AED7E1A4C2DF9FBFE7A9A4D09D588858
81B382AEDDA6D2F9B6CDE8A1DCE7A3908E5385784B908156897E504C4A0F6D752A758233
DDECA9D0E3A3CFE39EC3D790C7DB94D8EEA6D4E9A6D6EAABC9DEA56A7F47000F00BDD49C
D6EEB2B3CD8CCCE7A0CAE699CBE697D5F0A3C4E19ED5F4B95A7E4E87AE82C7F1C9B6E3B8
81AF7E6E9963C4ECAD98BB77B0CE86DBF3A9CDE297DFF0A9B0C47F526523A5B974D3E7A2
E4F8B1C9DD96CCE099D8E9A3CEDF99CDDE98E8F9B5D8E9A5C3D694C9DC9CC4D797D1E8A4
D5F5ACC8E69CDFEEA9E7ECAAD9D1939F91549085479C9153
CFE7ADC1D99DC1D797D9EEAB697D3640510A96A85EDEF3A8BAD288D3EEA7C5E5A4B7DDA2
C0ECB7C5F5C5C7FACFD8FFED74C49D358062457366EBFFFEE8E5EE080000554B30E7E3BE
FFFFEAFEFFF3FCFFFDFCFFFFFCFBFFF8F7FFFCFFFBFCFFF6FFFEFFFEFDFFF8FFFFF7FFFC
F9FAF5FFFEFDEFEDF0F7FFFFE4FFFF7EAEAE133F40DBFAFFF9FFFFF9F6FDFFFDFEFAF9F7
FCFBF9FFFDFDFFEDF4C1ACB3FFFAFEFCFFFFEAF4F6F9FFFFFFFCFFFFFAFFFFFCFFFEFFFF
F3FFFBF8FFFFFFFDFDFFF1F368403E21000070524AB7A49DFFF6EDFFFFF8FBFFFBE1EAE5
FBFFFFFCFFFFFEFFFFFFFEFFFFFEFFFEFFFFFEFFFFFCFFFFFCFFFFFBFFFEF8FAF9F9FBFA
6C6C6CFFFFFFFFFEFFF9F7F8F9F5F6DDD9DAF4EEF0FFFDFFFCF6F8FFFCFEFFFCFFFFFDFC
FEFFFDFBFFFBFCFFFDFCFFFBFEFFFBFEFFFBFFFFFBFFFFFBF9F8F4F9F8F4FFFDFAFFFFFA
FFFFFAFFFCF8FFFCF8FFFEF8FFFFF4F9FAECFFFFF4A19E95070400000100141912D6E2D8
ECFEF2F2FFF6DBF0DDEEFFEAF9FFEDFFFFEAF9F7DED8DCB9DAEFB7CEF0B4BEE8BA56865C
0840138DC48DBAE9A5BFE197D0E099FCFCC0CABB90A896706E5F34E2DBA4E5E99D939E4F
A4AD6CD8E2A6E6F0B1E3EFADD3E09BCEDD9ADDEDAEC2D196CEDFA961733F000F004B622C
CFE7ADD4EDACDCF7B2CAE5A0C9E6A6C8E4A7CDECB0B6D89BB0D89CD4FDC5A8D4A1BBE6B8
C6F1C65A8359587D5190B27F83A165CCE7A0E6FFB0B7CE7CCCE098D4E5A19AAB67CBDC98
CADB97D7E8A4DAEBA5C7D691E5F4AF8796514F5E1B42510E51601D9AA968DBE7A7D6EDA7
B9E596BAE998C0DC91D7E49EE4E0A0E9DFA1DED697E9E1A0
CEDFB2E2F4C498AB74869A5BB5CA85D6EEA2C9E291C1DE8CCEEFA0D4FAB1C4EEAEBCEBB5
9CCCA274A786548A70619F883D887182C3AFD2F4E4798476352D20AFA488C3C48BE7F1B5
F0FEDBF0FBEBF8FCFDFFFDFFFDF8FFFFFDFFF9FFF6F8FFF1FCFFFBF8FCFDFBFFFFF4F8F7
FFFDFEF7F6FBF7FFFFCBEAEDA3DDDE6BA8A9629197E7FFFFFCFEFFFFF9FFFFFFFDFEFFFB
FFFFFBFFFDFDFFF8FDC9B4BBFFFCFFFCFFFFF0FAFBFBFFFFFFF9FFFFFAFFFFFCFFFFFFFF
F4FFFBF8FFFCFFF8F9E5D1D01E00002D0C05BDA49DFFFAF1FFFFF6F7FAF1FCFFFBFBFFFD
FCFFFFFEFFFFFFFEFFFFFEFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFEFF1F0F3F5F4FEFFFF
666666F9F9F9FFFEFFFFFEFFEEEAEBDEDADBFFFDFFFFFDFFF9F3F5FFFDFFFCF6F8FFFEFF
FCFFFDF9FFFDFBFFFDFBFFFBFCFFFDFCFFFBFEFFFDFEFFFBFEFFFBFCFDF8FDFEF9FFFFFA
FFFFFAF8F7F2F9F8F3FFFFF6FFFFEFFFFFECFFF5E5FFF1E7C2A9A45F45440F0000080000
83847FB4BFB7F4FFFAE8FDEEF7FFF4F6FFEEF9FAEAE8ECD1C9D9AABED9A4CCF0C4BCE9C2
1D522657905BC1F4B1BFE99FCCE69FD3DDA0E5E1B2E7DEB3D1C99AD9D79CDBE29497A051
959758ECEDB4D3D79CD1D799999F5F4F5817A7B174E5F0B6D1DFAA748551000B00B1C590
0C2400A7BF81BBD691C0DD9BC8E6B2C6E6B5BCDFA7CBF1B4C8F0B1BCE6A7C5F0B8CBF5C5
CBF1CC6C8F6F244625BBDBB256743E4B6A26C9E996D6F29ED5EBA2BBCF8ABBCF8A9AAE69
91A5608599548D9E58A1B26C89985393A25DB3C27FE9F5B38F9B596B7735D7E3A1BAD189
C0EC9DCFFFAECCEEA1CBDF97D7DE9AE9EAA8DEE19ED9DF99
DBE6BB7C895B9BA974CCDEA2CEE5A1C2DE93D1F2A1D3F8A8C3EE9FAFDE96B5E7AAC7FDCB
76AE89366E53215A493F776ACBFFF6E3FFFFD7ECD9626C4ADBE0A8E1E8A4D1E399CBE4A0
D3ECB5D9ECCCFCFFFFFFFCFFFFFCFFFFFFFFEDF8E7F7FFF3F6FFF8FBFFFFF3F7F6FFFEFF
FEF7FEFBFEFFEBFFFF43767A2977795DABADCEFFFFEDFFFFFFFCFFFFFBFFF9FEF8F9FFF8
FEFFFAFFFDFBFFF8FDEAD5DAFFF9FCFEFFFFF9FFFFF8FEFEFFF6FEFFFAFFFFFBFFFFFFFF
F3FCF9FBFFFDFFF6F5C7B3B2110000321B13B7A69CFEF6EBFFFFF6FEFFFAF3F8F2F1F6F2
FFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFCFFFFFBFFFFFBFFFFFEFFFFF6F6F6FFFFFFFFFFFF
666465F2F0F1FFFEFFFBF9FAD3D1D2FFFEFFF4F0F1FFFBFCFFFEFFFCF8F9FFFEFFF8F6F7
FCFFFFFBFFFFFBFFFFFBFFFDFBFFFFFBFFFDFCFFFFFCFFFDFCFFFDFEFFFBFEFFFBFDFFFA
FEFFFAFFFFFBFFFFFBFFFFF4FFFFE6FFFFE2FFFDE8FFF8EDFFE5E9FFEFFBFFECFF522B40
1100090D010DE6E6E8F9FFFBF3FFEFF8FFEFF2FCE3C5D0AEDAE9BED8EBBDBFDAB1B9DCB2
4E7C4E001B00AEE2A4C2F3B1B7DE9DBBD999DCF0B5D9E6AEE0EAAED7E09DE0E89B989E54
5F5A20E7E0AACFCA927B793E5F5F215D5E22999E64DCE3ADD2DCAA616D3D000E00CCDEAC
E3F8C08BA365C2DD985371313D5E2F3C613682A875002100365E22295115638A55B0D6A7
B7D9B69DBE9F638263BEDEB7CAEAB87B9E5ECEF3A5BFE08FC8E298D6EDA5CCE39DB9D08A
D8EDA89CB16C80944FD7EBA6D8E9A5D6E7A3C0D18BD8E7A28E9D585F6E29CBDA95DEF4AC
C4E69AC0E598CBE99FD0EAA1D7EDA5C5D991C7DD94D1E99F
8C955E788349CDDB9ED9ECAAD1EBA2CFEFA3CBF2A3ABD78ABDF0A5BEF5B1B8F2B7AEEAB7
66A27C80BD9EA5E3CCC9FCEDEDFFFF67746B152206DDEEB7C8DE89C2E080C6E891C5EA9C
C6E5A2CDE4B6F8FFF1F1F3F0FFFFF8FFFFF6EFF7EAF8FFF6F5FFF8F8FFFDF8F8F8FFFDFF
FFFAFFFBFFFF648A9321666D68C6C88FE8EED9FFFFE6F9FFFFF4FFFFFAFFF5FFF6EEFFEF
FEFFF8FFFCF9FFF1F3F7E2E7FFF6F9FBFDFCF9FFFFF4F8F9FFFAFFFFFAFFFFF5F9FFFFFD
FAFFFCFCFFFBFFF9F7AD9B990D00004E4037D2CABFF7F5E9FEFFF7FBFFF9FDFFFAFEFFFD
FFFEFFFFFDFFFFFDFFFFFEFFFFFFFFFCFFFFF9FFFFF9FFFFFEFFFFFFFFFFFFFFFFF4F4F4
696768FFFEFFFFFEFFC0BEBFC3C1C2FFFEFFFFFEFFFFFDFEFFFEFFFDF9FAFCF8F9FFFEFF
FEFFFFFCFFFFFCFFFFFBFFFFFCFFFFFCFFFFFCFFFFFCFFFFF2F6F5FAFFFBFEFFFDFAFCF7
FBFDFAFEFFFBFEFFFBF9FAF2FFFFF1F6F0E0FFFDF1FFF9F4FFEFF1FFF1F8FFF3FFC4A4B1
48313925161938343186897EBAC3B2EDFBE4F8FFECD1E0C1C7D5B1CDDCB5D8EDC2CDE8BB
C7EBBB6D996678A972BAF0B6C7FDBFBFF2B0B2E098C9EFA6C5E197CBE095C5D187A8AB66
584F18B6A975C4B983625920989258D5D398696830434611D7DDAD737C4D000900E1F3C1
C1D69ED0E8ACE1FCB9B1CF91C0E6B5C5EEC46892640021004D73422F53236C9062B1D2A7
88A8813F5F3A183811C7E8BDC1E3B0BFE5A889B06DA8CE85CDEDA4D6F2A8BCD790EEFFC2
C2DC95C8E29BE0F7B1C6DD97C7DC97D5EAA5D0E49DCFE39CD2E39DA6B77094A55ECADB94
E1F0ADCCDD99D1E6A1CFE9A0C9E79FBCDE92C7EC9FC6ED9E
B3BC6BCFDA8BDCEA9BCADF90C8E497BBE093BBE59BD3FFBEB6EDAABAF6B880BF86579763
3B7D4D90D4A5B0F3C8C5F0D46D6865180700C9D0A4C7E69ACEFD97C6FB8FCDFF9BC3ED97
C4E39FCCE3ABD9ECBED4E4BDFBFFEAF9FFF0FFFFFDFEFFFFF7FFFBF2FFF6FFFFFDFFFBFF
FFF9FFF9FFFF16465258A8AF37A0A442A3AAA4D9EBF1FFFFFFF8FFFFF9FFF8FFF8F4FFF4
F8FEF4FFFDFAFFEFF2E3CDD0FFF6F7FEFEFCFBFFFFFAFEFDFFFBFFFFFAFFFFF4F8FFFEFD
FCFFFDFEFFFBF1E6E47A6866080000554F43F1EFE3FFFFF6FCFFF8F9FEF7FEFFFBF9F9F7
FFFEFFFFFDFFFFFDFFFFFEFFFFFFFFFCFFFDF8FFFDF8FFFDFEFFFFFFFEFFFAF8F9F6F4F5
6A6869FFFEFFF0EEEFB4B2B3EEECEDEEECEDFFFEFFF8F6F7FEFCFDFFFEFFF4F2F3FFFDFF
FFFEFFFEFFFFFEFFFFFCFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFD
FEFFFFFEFFFDFEFFFDFCFAFFFAEEFFFFF9FFFFFCFFF4F7FCF8FFFDF7FFF6EEFCE5EDFADE
D7E0C1D8DFBE292E100408003C412A626B56CEDBC9F7FFF1F9FFECEDF8D6FAFFDBC4D6A4
C2DAA6C7E9B6255324679F6E8BCF96A2EBA6B7FFABA1E286CDFEA3CAEC96EAFAB3CFD094
6C5E2D5240106A5A2783763FE8DDA5FFF9C27F7C45676733A2A57660673B182300718152
CCDFA8CEE6AAC1DC99D9F9B8C8F1B97BA978224D229DC5A05073538BAC8D133011052300
000E00193908D8F9C2C3E6ACC7EDB4B8DFA8A8D09B355C23CCF0AAB2D488D2F4AAB0D288
D7F7AECBE9A1BCD790D6F1AACCE69FD0EAA3D0E79FC6DD95E1F7AED3E9A099AD65A8B36E
BEB57A9E935BA3A76ACFE39EC7E8A1CFFBAECAFBACB4E896
8C9D3DD9ED8ECDE287D1E993CEED9FCEF4ABBEEBA8B3E9ABB2EDB593D49E458853589B66
80BF8ABEF9C3ABE2ABC3E4B9524A377B6951D4DCA1D4F59EB5EA80B9F385C2EE8CCBEF98
CBEAA6D4EDB4C6D8A4C9D8ADF8FFE8EEF7E6FFFDFFFBF4FBFBFFFDF9FFF9F9F5F4FFFBFF
FCF0FCF0F8FF9BCAD271BEC478D9DF358E9657879BF2FFFFFFF8FFFBEEF7F7FFFAEEFFF4
F5FAF3FFFDFAFFF6F8C5B2B4FFF8F9FFFFFDF4FAF8FCFFFFFEF8FAFFFCFDFAF4F4FFFFFB
FEFFFAFBFBF3D2C3C03E2C28392F26747065FFFFF6FFFFF8F3F6EFFBFEF7FFFFFBF8F7F5
FFFDFFFFFDFFFFFDFFFFFEFFFFFEFFFEFFFFF9FFFFF9FFFDFAFCF9FFFFFDFAF9F7FFFFFD
62615FF9F5F6E4E0E1EAE6E7FFFEFFFFFEFFFEFCFDFFFEFFF5F5F5F0F0EEFFFFFDFDFDFD
FFFEFFFFFDFFFFFDFFFEFEFFFEFEFFFCFFFFFCFFFFFEFFFFFEFFFFFDFDFDFAFAFCFBFBFD
FDFDFFFCFEFBFDFFF9FFFEFFFFF6FFFFF7FFEDEFFFF4FFFFEDFFFAEDFFF1EDFFE5DAF0C9
C8D9AFD7E3BB98A27F000600030B002A30226A6D64B8BEB4FCFFF3EDF5DDFCFFE3D8E5BA
D1E2B5CBE6B971986C6296685E9F69A9F1AFAEF9A6BEFFABADE490C4EEA2C5DEA4D7E1AD
9D9969A298659E9962B8B67BD9DA9EDBDCA0BBBE85989B667D80513D4418000B00849465
D6E8B4D1E6ABCBE4A3C9E7A7C1EAB082AE7B3D663CC6ECC7B9DBBACCEAC89AB38C82976C
657948758C58C3E0A8C4E7ADC5EEB4C1F2BB7BB288174C1E87B172D9FDB5C9EBA1BEE298
C7EFA9CCF1AEC3E29ED4EDA9CCE39DD0E5A2D1EAA8D2ECA5C1D78CCFE897E3FFB0BED28A
CCC88B72682D616528CFE2A0C3E49DC5EFA5B5E496BFF0A1
A1C45EDDFF9CB8D77ACFEC98D4F4A9C3E8A5BFEFB5B1EAB792D4A661A67977BC8DA2E0AF
C8FBC3BCE2A7354F1226380092A36FD5E4ADD3E09AD8EE9BBAE27FD7FD9ACBDD87E3F0A8
CBE9ABCEEAB9F9FFE1FDFFEBF9FFF4FBFFFAFFF9F9FFFBFFFFFCFDFFFDFDFEFAF9FFFEFF
FFFDFFF9FFFFD1F4F6D8FFFFC6FFFF72B1BA496E7EF2FFFFFFF7FFFEF6FFF4FFFFF2FFFD
F6F8F3FFFDFBFFFBFBE2D6D6FFFCFDFFFFFDFBFFFCFBFFFDF9FFFBF9FFF9FAFFF8FEFFF8
FFFFF6FDF4EBAA9791311C175C4D48CBC0BCFFFDF8FFFDFAFFFEFAFFFFFAFFFCF9FFFEFB
FFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFEFFFFF8FDF7FEFFF8FDFEF8FFFFFA
030000CBC5C5D2CCCCFFFDFDFFFBFDFFFDFFFAF6F5FFFFFDFCFEFBFCFFFBF3FAF3FCFFFB
FFFDFFFFFCFFFFF9FFFDFAFFF6F7FFFAFDFFF8FDFFFCFFFFFFFFFDFFFEFDFFFCFFFFFBFF
FDFBFFFDFEF9FAFFEFFEFFF5FFFAFFF9EFFFFBFFFFF4FFFEEBFDEDF8FFEFFEFFEBFFFFEA
FFFFECFEFFEFF7FFF3F3FFF59FACA24D4F4A392B2B0F01013B3B33FCFFF4F5FCEAEEF8E0
E5F3D9E3F8D7D0ECC6C8EDC1B4E0AB001A004F864380B7767FB277C5F3C2C2ECC6BFDFB8
DCEDB9D0DB9FBDD291D8F3AECFEAA5C5DE9ADCEEB0D1DCA4B0B887282F03020D005D6D40
D9EBB9D0E5ADC8DCA1D2EBB1BADFA98FB7856D8E63BFE0B3D1F3C1C2E1A6DAEDABCCD594
D8DBA6DAE0B2182B00C1E1B2C9F8C1AEEFB92F835F6CBC976095618BAF6F6D8B4384A860
7AAC717DAC7584A266B0C383CED899DFEAAECADFA6C9DF9FD5E795CEE78CC9F59EC4F1A0
D0EAA1CCDD97D4E9A4DBF2ACCFEAA384A25A87A55F8AA862
CDF390BDE181D0F399CCED9EBCE09ABBE3A7C8F7C37EB6893F7D5472B389BFFCD0C2F6C5
133A036D874A697535DEEDAAC8E9A4CAEEA6CCE49ACBE290D2F79AC9EA91CED68DD2DB9C
C1DFA9CDEBC5FFFFF3FFFEFBF4FDFAF5FEFBF5EFF1FFFAFEF5EAEEF9F0F3FFFEFFFFFFFD
F7F5F6EDF7F6E7FFFFD2FFFFDBFFFF91C0C88EAEBBF1FFFFFEFDFFFFFDFFF4FFFFECFDF7
FFFFFDFFFDFBFFFDFBE0D8D6FFFCFDFFFBFAFBFDFAF9FFFDF8FFFBF1FEF4F9FFFAFEFFF6
FCF8EDF0E2D97A635B49302B74625ECDBFBCFFF5F3FFF7F5FFFDFAFFFEFAFFFDFAFFFFFB
FFFFFDFFFFFDFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFEFFFBFEF7FEFFF6FFFFF8F3F3EB
24201DDAD5D2FFFBFBFFFDFDFFF7FAFFFDFFFAF6F5FAFAF8F1F3EEFCFFFBFBFFFAFEFFFA
FFFDFAF3E8ECFFFAFFFFFCFFF0F1FFFBFEFFEEF3F6FAFFFBFFFEFAFFFDFCFFFBFFFFFBFF
FFFDFFFFFFFDFCFFEFFEFFF1FFFDFFFFFDFFEFF5F1F8FFF6F9FFEFFBFFE9FFFFEAFFF9E7
FFF8EBFDFFF2EBFBEEF1FFFBF5FFFDFFFFFDB29FA30F0000040000000200D0D7CFF1FBF0
F8FFF4F5FFEFCCE4C2CFECC0CAECB9B9E0A7D3FCC24E79430013000012001A49298BB591
B6D4A0E0FDBDDCFCB9B8DC96BBDF97CCEDA6C8E5A3D1E6ABCDDBA890976B232800010600
D7E0B3D4E0AEDAEBB4C3D8A0CDE4B6D7F4C81A3E10C3EEB9BBE9A8C1EFA6C5E79ADBF3A9
DEE8ACC9CF9FE5F0C58CA57BADDCAE6FB68A28866175CDA5C7FFCDB1D598DCFAB4C5E8A4
A6DBA5CAFECDB0D19890A266DFE7ACD6DFA6D6E8B4D1E7A9D5E493D6EF93BEEF94B1E791
CAF1A2D2F2A7C6E298BCD88EC0DA93D4EBA5DAEFAACFE39E
D9F39AC1DD86D7F6A6CAEEA6B1D99ACCF7C185B384002E01609066CFFED2376131426432
5A753E8CA166CADA9CCEE4A3C1ECA7BEEDA5C9EDA3C2E497C2F29CC4ED9ED6E9A9D4E2AF
EAFFE3E4FFEAFCFFFBFCFBFFF9FFFFF9FFFFFFFCFFFFFBFFFFFEFFFAFBFDFCF6F8FFFDFF
FEFFFFF2FFFFDAFFFFBBEFEB73A4A8628A92C3DFEBE5F5FFF8FEFFFBFFFFF8FFFFF9FFFD
FFFEFBFFFAF9FFFCFBE3D9D8FFFCFDFFFCFBFAFAF8FBFFFDF9FFFBF5FFF7FBFFFAFFFFF6
FFF9EF998880381F183F2621E5D3D1FFFCFAFFFCFAFFFBF9FFFEFBFFFEFBFCFBF7FDFEF9
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFEFFFFFEF9FFFFF6F7F7EF827F78
635F5CF6F2EFFFFEFDFFFEFFFFFDFFFFFEFFFFFFFDFFFFFDFEFFFAFBFCF7F7FAF3FEFEF4
FDF3E9FFFCF6FFFBFFF9F5FFF7F6FFFCFEFFFAFEFDF8FAF5FDFEF9FFFDFEFFFBFFFFFBFF
FFFCFFFEFFFFFAFFF3FAFFF1FFFFFAEEEBE6FEFFF4D9E1CACED7BAD6DBBBE8E4C7EFEBD0
FFFFECFCFFF1F5FFF6F2FFF8F4FFF7FFFFFBFFFAFAC2B2B36F6E6C252A26757B77AAB4AC
EEFAF0F7FFF4F4FFECDFF8D1DDFACAB4D7A1B3D99EC5ECB3C8F0BC82AC7E67906870996F
90B78281A568C5E1A6DAF2B4CFE8A7D5F2B0C9ECACC5E4A9CDE3B2878F661C16005D5030
4E411E292600233000445221777856848F6DA7D5A686C88A7AC173B8FFB17ECA807EBF7B
BEE7A5D5EBADD2D79F8F9B6D5D886C286D50A4FACDA0EFB8B5E8B0BEE2A5C7E7A6C2E9A8
B3E6AEB2E4AFDCFFC78AA268738249BFCC94D1E4ACCDE3A3D4E798CDE790C5F198BFEF99
BFE496D2F2A7D5F1A7DCF8AEC5DF96DAF1A9C8DE96CFE59D
CADD8CD0E89AB8D791CFF6B7CFFAC412400F001300C1EABECBEFC1678454435A268EA16A
DFF0B9CEE0A6E3F5BBC7E1A4C5ECABC1EAA6BFDE9AD4F5B0B8E69DC9F2AEC9DFAEC9DFB9
E7FFF1E2FFF9EEFDFFF3FDFFF0FFFFF0FFFFF5FEFFF4FDFFE1F1F1F7FFFFFFFDFFF7EEF3
F9FDFEEEFFFFB0E1DB4D868060909480A5AEEDFFFFF2FFFFF3FFFFEFF9FBF5F9F8FFFFFB
FFF9F7FFF6F5FFF5F5D9CDCDFFFCFDFFFBFBF8F7F5F8FAF7F5FCF5F9FFFAFBFFF9FBFBF1
FFFDF434231B200700412823FFFBF8FFFCFAFFFCFAFBF3F0FEFAF7FFFFFBFEFFFAFFFFFB
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFEFDFFFCF8FFFFF6FFFCF6504D48
76726FFFFEFDFCFAFBFFFEFFFFFEFFF8F6F7F3F2F0F8F7F5F9F5F2FFFFFAFFFFF8FFFEF4
4C3F2EFFF8E8FFFAFAFEF7FFFFFDFFF2F5FAFCFFFDFEFFFAFFFFFAFFFEFFFFFCFFFFF9FF
FDFBFFF9FCFFF7FFF4F7FFEFFEFFF0FFFFEFF9FCE1FFFFE2EDEFCAD1D3ACCFD1ACF1F5D4
FAFFE4F2FEE8F7FFF4F7FFF8EEF5EDEFF0EBFFFDFAFFFDFBFEFEFCB5B9B8000202313735
A6AFAA95A195E8F7E2EAFFE0CEE7BFD9F5C4D0EEB8C3E2A9C8E9B4B4D6A3C6E7BABBE1B2
C3F2BC6090568CB579C2EAACBCE5A3B4DE9CC3F0AFBCE5A9D0EEBCD1E2B8666A47625D3D
D1CEABEBF0C7C9D9A8CFDFB24F54364B593858804EB6F0B323621C4083401F632AA8E5AC
C4F1B0D3F0AED7E2A8D2DFB3001700134329ABE6B6B6F0B6BAE3ABD9FAC1CBEFB27BA468
55844D52814B7CA36CC8E7AE3A5119E1F4BCDDF1B6CBE09FDAF0A5C0DD8BCAF29CC2EC98
CAEC9FC1DF95BBD98FCFEBA1C7E198DAF4ABC2D991CEE49C
E6F5B0D0E5A2CFEEB2BAE1ACA0CFA14D7C5282AD82C8E9BE9FB5843B48129FA46AE9EDB2
C0C88DDCEAAFD6EBB2F5FFD4B6CA8F9CAB7099A46AC9DAA3DBFAC1EEFFDDF4FFE8F0FFF4
DCFFFDDDFFFFE6FFFFE6FFFFDDFFFFD2FFFFDDFFFFE3FFFFE6FFFFF0FFFFFFFCFFFFFCFF
F8FFFF71908B5F948C48837DC4F4F8D7FCFFF0FFFFF4FFFFF4FFFFF7FFFFFFFFFBFFFBF8
FFFCFBFFFBFBFFFBFBD3C5C5FFF7F9FFFCFDFFFDFDFFFFFDF6FBF5FCFFFAFEFFFAFFFDF4
FFFDF41906002409027B625DFFF1EEFFF9F6FFFBF8FFFDFAFFFFFBFFFFFBFCFCFAFCFEFB
FEFFFDFEFFFDFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFEFDFFFBF9FCF3EEF4EAE8BAB5B1
686461FCFBF9FFFFFFFCFCFCFDFDFDFFFFFFFFFFFDFFFEFDFFFEFBFFF9F6C3B8B4786C60
433119E9D9C0FFFCF3FFF9FAFFFEFFF2F3F5FBFFF9FEFFF6FFFFFAFFFEFFFFFBFFFEF9FF
FBFAFFF9FDFFF9FFFBF9FFF1FBFFE7FDFFDFFFFFDD272400979366D9D8AADCE2B6D5E2B7
D8E7C6E3F3D9F8FFF3FBFFF8FEFFFAFFFFFAFFFFFAF3F2EEF7F9F8FCFFFFA1A5A8262B2F
13181B111A17748074889581748565C4D9B0DCF2C3BED5A1D9F1BDCFE7B3CBE3B3CFF1BF
C0F2BF87C88E5DA96854A76170C47979C57BB5F2AFC3F5BABCE2B1BADBB077976E406438
A3C799789A683E5A27809B6E6E8F7086A583677E4891A46D6B815B182C10576544B3C095
C3D79CC1DB9CC1E1AF839F76000900242E0BB8C79CCADEADC4DCA8C9E7B160875257824D
77A26A93BE867BA670A0C792476833C4DDA4DBEDAFC7DA98CCE69FC9E79DCCEE9AC4E692
C3E296CEECA4D2F0A8CDE8A1C5DF96D2ECA3D2EAA0D6EEA4
B8CC8FC9E2A8D2F4C2C5EEC264926DACD8B5B2D6B0304A1D6D7A45EBEFB2DDD999D7D393
ADAF70848F5580945F768856CED39DCFCE98D2D09DB0B686D8EDC2EBFFE5F1FFF4D9F7EF
DDFFFFC1F6FC8DBBC86F9FAD56929A4B8C8E60A19D6DA8A2A1D4CFE9FFFFFCFFFFF0EFF5
E9F9F9B8D8D53467628FC8C2D7FFFFE2FFFFE2F5FFEBF7FFF5FFFFF9FFFFFFFEFAFFF9F5
FDF2F0FFFAFAF9EBEBB1A3A3E3D3D6FBEFF1FFF9FAF6F2F1FFFFFBFAFDF6FFFFFAFEFBF2
CABDB529160F150000B39A95FFFBF8FFFEFAFFFEFBFFFFFBFFFFFBFDFFFAFBFDFAF7FCF8
FCFFFDFCFFFDFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFDFDFFFCFAFFFBF8AA9F9DFFFDFB
6A6665F9F9F7FEFFFFFAFEFDFCFFFFF2F4F3F8F7F5FFFEFBFFF7F5C2B4B1A59693B4A298
CAB59AA79378FFF7EAFBF0EEFFFEFFFFFFFDFEFFF8F8FEF0FEFFF8FEFEFEFFFBFFFEFBFF
FEFDFFFBFFFFF8FFFAF8FFEDE2F1CACAD2A3837F509D9362645828BCB986DAE2B1C7D8AB
C6DCB6E0F2D8F9FFF4FCFFF6F6F5F0FEFDF9FCFEF9FCFFFBFCFFFFF1F5F6FCFFFFECEFF6
B8BBC28A8E91070D0B0004000005000007002F3B1556653A71815464744790A073CFE9BC
B9E7B9B4F2BFAAF8BC89E09C6CC37C3F8F4864A5654879428DB48554774D002400001100
0012006F9566617E4E6081542E5E386C9972A3BD8D89996C8E9E83A3AF9995957B6D6F4A
747D4EE1F5C2BFDEB48CA87F697245505221B2B5865C6634B5C793D5F1BE456F3FAAD6A5
B4DBA2C6EEB2C4F0BB7CAB773159256A8950DCEFADD9EDA8BDDA98D3F2AECAE596D5EE9D
CCE89ECAE8A0C1DF97D6F4ACD1EDA3BFD990C7E197CEE89E
D6F7C0CBEDBABDE4B8B2DAB7598166B9DDC19FBA9946592CC9D299D6D996D3D089ACAC64
8A8F4D59642AACBE8EDCE9BBC9C28EEDE0ABF2E8B7B1AF86D8E7C6EFFFEFEEFFFFE1FFFF
D8FFFF9ECFDD5182933D72803C7D83367C7C3F8881377A717BB6B0C5EDEDEFFEFFF8FFFF
F0FFFFE3FFFF1B4543467877A6E2E0DCFFFFEDFFFFF5FFFFF9FFFFFAFCF9FFFCF6FFF8F2
FFFBFAFFFBFBFFFAFBCBBBBCFDEAEEFFFAFDFFFCFDFFFDFDFFFFFBF7F6F1FFFFFAFCF8EF
9D8E872F1B141F0200C8AFAAFFFCF8FCF8F5FAF9F5F9FAF5F6F6F4FBFDFAFCFFFDFBFFFD
FBFFFDFBFFFDFCFFFDFEFFFDFFFFFDFFFFFDFFFFFDFFFDFDFFFAFAFFF8F8AFA1A1FDF3F2
726E6DFDFFFCF4F8F7FBFFFFFBFFFFF7F9F8FFFFFDFFFEFBFFFBF9948582937E7DF2DAD0
B99F86553D23FFFAF1FFFBFAFFFBFDFFFFFDF8FBF0FCFFF4FBFEF3FCFEF9FFFEFFFEFEFF
FCFFFFF9FFFFF5FFF1F3FFE2D9EBBB8E9760665F2BE4D4A15C4A18A19764E1EBB7CFE5B7
CFE9C4D6EDD3F8FFF3FFFEFAFFFDFDFFFEFDF0F6F2F9FFFDF9FEFAFEFFFFEDEEF2FEFEFF
F6F6FFFEFEFF98999E8082814C4F462428171C2007080F000006000007004B512F586844
58775558855EABDAACBCF1BDACE2A87FB57B88BB8254804D8AAE827B9570334626000800
60714FD4E9C2D0E7BBB8D8A96C9A69497D4F6A9C77B6E5C3C0EDC6B3DCB2C2E2B9B9D3AC
647457ABB89ACBD5B0A9B688B3C78CA2BA7CC6E2A5B3CC92AABF8686A16E0F3A0F83B183
8CAD74C8EAAEBCEBB782B685113F0E739960D5EAA5D5E9A2C5E4A8CDECB0CADE96D6E89C
C2DD969FBE7865833DB9D78FD3EFA5D0ECA2D4F0A5D1EDA0
B6E5B1B4E2B378A27C1F4629ACCEB65C78613B4E2EFBFFDCFBFFC9838A4494984CC0C77A
D6E19DCCD9A1DEEDC2CED9AEE9E4ACE6DDA2CBCA94D0D7ADEFFFE4EBFFF3DAF9F4E4FFFF
4E7584537C8E5E879BA2CDDDD5FFFFD8FFFFD6FFFFC0FCF44E868390BEBCDDFBFDEAFFFF
EDFFFFD8F4F5EBFFFF19424472B7B2B4F5F1EAFFFFEBF2FCFFFEFFFFFEFBFFFEF6FFFDF4
FFF4F2FFFBFBFFF9FAD8C5C7FFF3F7FFF8FBFFF8FAFFF7F8FEF9F6FEFBF6FFFFFAFFFDF5
A697902E17114D302AD3BAB6FFFCFAFEFDF9FFFFFBFFFFFBFEFFFDFCFFFDFBFFFDF3F9F5
FBFFFDFBFFFDFCFFFDFEFFFDFFFFFDFFFFFDFFFFFDFFFDFBFFEFF0E4D0D1FFFAFBFFF8F7
6A6665FCFEFBFBFFFFF6FFFCF4FAF8FCFFFDFFFFFBF8F0EDFDEFECB7A5A1C2AAA8FFF8EF
C3A48F664A35FFF9F3FFF8F9FFFCFFF6F6F6FCFFF6FCFFF4FAFEF0FDFFF9FFFEFFFEFEFF
FBFFFFF2FCF3E8F8DDE4F6CCC4D7A0A5AE75463A06FFEEBDCEB887897D4DD8E0B1D5EABF
D9F4D3E9FFEAFCFFFAF7F3F4FFF6FAFFFEFFF5FBF9F6FFFBFCFFFAFBFCF7F7F7F9FFFEFF
FFFDFFF9F5FFFFFDFFFFFDFFF8F7F5FFFFF6D7D5C6A09F8BA09F8A6B6A5553523D2E321B
0008000015003E5430425B31A1BD8DC3E3B1C3E8B4BEE2B2CAE5BCCBDCBA797D62090900
DEE1C6D8DFBED0E2BACDE7B8D2F0BC9AC4965F9A7C498C6D73B98774B9807EBF8996CB9F
BCDAC25F6C58959573A3A574D4E8A9BCDB97CCF1AEC4E7A7CBE0A5D2EAB6305B30C0EBC0
9DBA80708E5295C4906A9E70001A00A0C7908FA662889D58C4E5AEC2E3AAD8E9A3D3E098
5B74309BBA7683A05DDBF9B3C2DD96C7E399D0ECA1C5E194
B2F0BDB2ECBC1C4A26B5D7BC6F8771B6C5AEC7D2B2E9F4C993A164CADB94D5E899D2E79A
CCDF9DDAEBB4CDD9B1D1DDAFD6DF9CD5E29A8DA363C6E2AFDDFFDFE6FFFADFFFFF567D84
506D7F819AB0D6ECFFF0FFFFF1FFFFF1FFFFE3FBFBE9FFFFE0FFFF09393990BAB9DEFFFF
EAFFFFF0FFFFEEF8FFD3F2F73E8E8521746AE6FFFFFAFEFFFEF1F8FFF8F8FFFEF4FFFFF4
FFF9F7FFFBFBFFFAFBFEEBEDECD7DCFFF9FDFFF3F6FFFCFDFFFDFBFBF6F2FFFEFAFFF8F1
B3A49D110000391C16E9D1CDFFFCFAFFFFFDFFFFFDFFFFFDFEFFFDFCFFFDFBFFFDFBFFFD
FBFFFDF9FFFBFCFFFDFEFFFDF1F2EDFFFFFBF0EFEBFFFDFBE3D3D48C797BFFF8FBFBF1F2
767273FEFFFFF6FCFAF9FFFFF9FFFBFCFFFDFFFEFAFCF4F1BFB1AE927F7BFFEBEAFFF7F1
BE9D8E6D4D40FFF5F6FFF8FFFFF8FFFFFEFFF8FBF4FCFFF4FBFFF3FAFFF4FEFFFFFBFDFC
FCFFFBF1FDE9D2E2BDCFE3B0D0E1AA9DA56C5A4C1BFFE7B9FFFACE5B4E22E3EAC0D6EAC5
F1FFEFEFFFF3FEFFFFFFFCFFFFFAFFFAF3FAFCFFFFF1FBF3FAFCF1FFFFF6FDFCF8FDFBFE
FFFDFFFBF5FFFFFCFFFCF6FFFFFDFFFFFCF9FEF9F3FCF8EFFFFBF0FFFDF4FFFFF6AEAA9F
B5B2A184836E0A0900010500081000D4E4B5596F3ED1E8BACBDBB4E8F2D0E9E7CE110C00
F5F3DAF8FBDECCDAB6D6E5BCDBDEB1CDDCB3B7E5C836805D2F8A51369B572B904E328551
81B3968BA38D5252305F5B2ECDD89CE0F6B5BFDF9CCBE9A9CAE0A2CBE4AD244B1FCDF4C8
C2DBA18BA56879A3718EBF924D7E4FBDE5B0CCE5A392A9654B6E38001800263500505D17
CAE3A1CEEEAD89A865C8E7A3CEECA4BCDA90DAF6ABC6E295
8BCF9E5D9A6E305E3A617F632E3D26FCFFEACED4B2A5AE81B2C488D0E9A5C9E79DCAE9A3
CFE9AAE5F9C4DAE6BEDBE7B7D5E29CCFE495496824CBF2BBC6F0CCE2FFFB7FAEA830595F
EAFFFFEFFBFFF5FFFFF9FFFFFFFDFFFFFEFFF5F6F8F4FFFFE4FFFF629292699B98E0FFFF
E2FFFFF4FFFFFFFCFFF1FFFF348C80016153D4FDFFFCFFFFFFF8FFFFF7FAFFFFF4F8FAED
FFFDFAFFF6F6FFFAFBE4D1D3F7E2E7FFF6FAFFFAFDFFF6F8FFFDFBFDF8F4FFFCF8D6CDC6
6B5C5537231C937871FFEFEBFFFCFAFFFFFDFFFFFDFFFFFDFEFFFDFCFFFDFCFFFDFBFFFD
EBF1EDF7FCF8FEFFFDF6F6F4FFFFFBFFFFFBFFFEFBFFFDFBCFC1C1DBCBCCFFFBFDFFFCFD
5C5A5BFEFFFFF3F9F7FAFFFEFBFFFDFEFFFBFFFFFBFFF9F39B8E88AB9892FFF8F4FFF7F1
C09C906F4D44FFF4F9FFF8FFFFF9FFFFFDFFFBFDF8FCFFF6FBFFF3F9FFF3FEFFFBFCFEF9
FCFFF6F8FFE9D5E6B9D2E5AED1DEA88D8F5D695B2EFFEFC5FFFDD460502CD6D7B5ECFBDE
F5FFF3EBF8EEFFFFFFFFF6FFFFFAFFFFFAFFF0F0F0FEFFFAFFFFF3FFFFF3FFFEF8FFFDFD
FFFCFFF5EDF8FFFBFFFFFCFFF9F3F5FFFCF9FFFEFAFFFEF8FFFEFAFBF6F2FFFDFDFAF0EE
FFF0E3FFF3DED9D2B5D2D2ACC2C99D9AA676839362616E4069744C797F5D737659010400
9094791D260727321075805873744A9FA87DD6F6CFB2E9BFADFAC692EBB1A0F8BE6BB987
568E695A7D5D52623E7881565D662F869155D9EBADC4D899DBEDAFC6DEA4A2C698A1C293
D1E4ACD0E4A96082500631048CBA8CCDF5C1C4DE9FD2ECAD5E804D385924B1C183CEDD9C
D5EFB0BDDCA0789658D9F8B5CAE7A4D1EFA7C3DF94CEEA9D
3E7F542F694094BE98000B00CFDABAC3C7A68B9068E4EDC0CBDFAACFEDB1BFE3A5CAF0B3
DBF9C3F2FFDAE4F0C8E1E9B8D2D892A1AF60A5C27FBDE2AED6FBDADAFFF24B7C76CEF7FB
F1FFFFF9FFFFF7FDFFF4F4FEFFF7FFFFFBFFFFFEFDF8FFFFE8FFFF9DCBCB2D615DDDFFFF
E2FFFFF8FFFFFFF7FFEEF6FF71CFC1188371CEFCFCFCFEFFFFF6FFFFEFF4FFFEF5F8FEF0
FFFDF8FFF8F7FFFAFADDCACCEFDADFFFF4F8FFFAFDFFF7F9F9F1EFFFFCF8FFFEFAABA29B
3829224C3831BA9F98FFF3EFFFFCFBFFFEFFFFFFFFFFFFFFFEFFFFFCFFFFFCFFFDFCFFFD
FCFFFDFEFFFDFBFDF8FFFFFBFFFFFBFDF9F6FBF6F2FFF9F7BBB1B0FFFCFDFFFCFFFFFEFF
5F5F5FFEFFFFFAFEFDFCFFFFF5FAF6FFFFFBFFFEFBEDE6E0786B65CEBDB6FFF9F4FFF1EA
BF9A91704B45FFF2FAFFF7FFFFF8FFFFFDFFFAFFFBFBFFF8FCFFF4F9FFF3FEFFFBFCFFF8
FEFFF3F9FFE5D5E5B4D1E0A7DDE5B4928F6274653CFFF7D0FFEDCB675638E7E3C8DEE3CD
F9FFF4FBFFFBFFFFFFFEF7FEFEF3F9FFFCFDECE7E3FFFFF6FFFAECFFFFF1F6EFE7FFFDFA
F6EDEEFFFDFFFFFDFFF3EDEDFFFFFAFEFBF2EBE9DDC8C6BAECE9E2FFFFFAFFFEFDFFFDF8
FFFAECFFFBE2D9D9B3C6D6A5D6EDB5C8E0A6C7D69FDAE2B1D2D7AED3DBB4C7D7B3021800
CBE3BFF1FFE1D6E2BEA3B18D6F885E3C54228694596E7D465F7A5755765BB3D2B3DBFDD8
C5F1C072A47114491D7DA67AB8C49484814E595321706F39C5D395E4FDBCC9E6B098B380
7D8C531221004C66368CAD80769C6DC0E5B2CCE9AFA1BF8396B885C0DEAAC7D99FE7F9BD
C8E4AAD0F1B8CCEBB086A466C3E09EC5E39DD1EDA3C6E096
265D3671A17B284B23435932D1D9B0A9AC81C3C69BD5DEB1D3E6B8CCE7BABFE0B3D9FACD
EAFFDBF4FFE1E2F1C8D9E0ADE6E39E4E5007D8ECADCCE9B9D9F7DBA2C8B961948DE0FFFF
EBF9FFF5F9FFF9FFFFFCFFFFFFFCFDFFFCFBFDFCF7F2FFFCDFFFFF8BB9B7144742DEFFFF
EBFFFFFCFFFFFFF4FFFBFEFF94F2E437A695D5FFFFFCFEFFFFEFFCFFECF1FFFFF6FCFFF4
FBF8F3FFFDFBFFFAFAEDDDDEDCC9CDFFF8FCFFF9FCFFFBFDFFFCFAFFFEFAF9F4F059524A
1E1109534039BFA69FFFF9F4FFFCFBFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
EFF1EEFBFBF9FFFFFBFDFCF8FFFCF9F7F2EFFFFDFAFDF5F3D2CCCCFFFCFBF8F6F7FFFFFF
767676FDFFFEFEFFFFFEFFFFFFFFFDFFFFFBFFFFFADBD4CE8E837DFFF1EAFFFBF3FFEDE2
BD9B8F6F4A44FFF2FAFFF7FFFFF7FFFFFDFFF7FBFAFBFFF8FCFFF6FDFFF7FFFFFDFCFDF8
FFFFF4F8FEE2D2E0AFCED8A3D4D5A99F9A725B4D28FFFEDAFFF6D6716044E2D7C1FFFFEF
FAFAF0FFFFFBF2F0F1FFFEFFFFFCFBE7DCD8BBAEA5D0C4B8FFF9EBFCF2E6FFFDF4FFFCF5
FFFDF8F8F1EBFFFFF6FFFFF3FFFFEFF8FAE4F7F9E1E2E6CFEFF2DFB1B5A6707368878377
A28D78A49170BFBC91DBE5B0CFE3A4DDF2B17C8A4D9AA36C888B5C5F643B76805B000900
CEDCB8F7FFDFF9FFDDE0EFC8C5E9B9A6CC9172813C272B000F0F000B0A00C6C8B3C2D1B2
B5DAA68CC28683C48E599363D1EDC4ABB68C9897675C5F288C9F5D627B375B7133A0B278
96A169747E4A859566AEC59793B0829ABC8AD4F5C073945D92B37ED8F5BFC9DEA6B8CD95
B4D09D86A772A6C7908EAD72B4D294CDE8A5CAE39FD9F3AA
B6D5B6B4D2B0233A10C6D8A8737D48DFE8B1C6CE9BE2EEC0E3F1CDD9ECCED4E8CFEDFFEA
F1FFE9F4FFE4E0F3C6D4DBA7B5A5674E3E00E0E7B1BACFA6E1F7E0A7C7BC03362FDAFFFF
F4FFFFFBFFFFF5FFFFF7FFFDFFFFFAFBFAF5F6FFF8ECFFFDE3FFFF83AFAE68928EE0FFFF
F0FFFFFEFEFFFFF4FFFCFEFF56B2A52F9B8BD5FFFFFCFEFFFFF4FFFFF9FDFFFFF8FBFEF3
FDFCF7FFFEFBFFFBFBF1E3E3E4D1D5FFF9FDFFF9FCFFFBFDFFFDFBFFFEFAF2EFEA332C24
2B211883726AE3CCC4FFF9F4FFFCFDFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFBFEFFFAFFFFFBF2EEEBFFFDFAFFFBF9FFFCFA807876FDFDFBF9FBFAFBFDFCFEFFFF
626365FCFDFFFEFEFEFEFCFDFFFEFDFFFEFBFFFCF8BEB7B1ADA49DFFFDF4FFFCF2FFFBED
BFA08E724E42FFF5F7FFF8FFFFF9FFFFFEFFF6FBF7FBFFFAFCFFF8FDFFFAFFFFFFFCFAFD
FFFFFAFBFEE9DBE3BCD9DFB1EAE5BF9E94714B411EFFFFDDFFFFDF7D6D53857462FFFCEF
FFFCF6FFFEFAFBF8F3FFFFF8F4EDE35D5143A79281B7A291E3D1C5FFFBF2FFF9F1FFFDF4
BDB5AA918B7D73715C7C7C60929673949B72838C614B562B76825C909E7B8A977BA2A98A
A59D79A19267AF9E70A19660585415494E0B919E598D9C5B929B64B6B587867855140000
4D351B6F5E42DCD6B6DCE7BCD3FABBAAD991C9F1AAC6DC9BD7D49F958C659A9D82859578
729867ADDFA2B2E9A882BB844E886282B692CBF0BCB0CF8C92B0687E984E6D7C37889152
404711B1B787EDF3C5D2DEB0D3E6B886A2722E54230C320091AF79BFDAA3D5EDB9CCE7B4
70905F678957B4D5A09AB980577539ACC685CBE4A2CFE6A0
D0D8C1A2AB8E6C774CEAF7C1687736C9D897E3F0B8FCFFDCFCFFEAF5FBEDEDF4EDF9FFFB
F3FFEFF5FFE8E1F8CAD4E1A99B8C51B3A469C9D39FD5EBC5DAF1DD70948A478077DCFFFF
F0FFFFF8FDFFE8F7F0F2FFF5FFFFF8FFFEF7F8FFFAECFFFEC3EEE77DAAA7CAEAE7E8FFFF
F2FFFFFEFEFFFFF2FFF0F2FF247E7238A192E1FFFFFBFFFFFFF9FFFFFBFFFFFFF8FBFBF1
FFFFFAFFFBF8FFFCFBE2D6D6FBEBEEFFFAFDFFFAFDFFF4F6FEF6F4FBF6F2FFFFFA3B372E
261C13AFA198FFF7EEFDEAE4FFFCFDFFFDFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFDFFFFFD
FFFFFBF5F4F0F2EEEBFFFEFBFFFCFAFFFCFAEADFDDA59D9BFCFFFDF8FFFEFAFFFEFCFFFF
323335FFFFFFFCFAFBFFFEFFF8F2F2FFFDFBFFF8F5A8A199B1AAA0FFF9EDFBF5E7FFFDEC
C0A28A71513CFFF7F3FFF9FDFFFBFFFFFEFFF8FEFAF9FFFAFCFFFAFDFFFCFFFEFFFDFAFF
FFFEFFFFFFF4EBF0D0F1F3CCEFE4C46D5E3F625938F8F2D0E9E0C1BBAD93776251B39D92
FFF2ECFCF1EBFFFFF6FAFBEDE1DECB5E523AD9BFA6876853B8A297FFFBF4FFFBF4FFFCF3
6D645557513B767654DBDEB3E5EEB9EFFAC0D1E1A287995BA4B77FD5E9B4D8EEBFBECE9F
D6DDAAE4E3ADE1DCA2D1CD8DA8AB64919D51DEF5A7CBE29AD2E2A3C1C391FFF9D3170000
A082686A5035E0D3B3D2D5A8C0D594E0FEB4CAE7A4D3E6A6F8F6BBD9D29EE4E9C172845E
264617B2D9A4BFE6ADC5F4C0002C061F5B37A9D9A9CEF8B9C1E59DD8F3A4BCC477B3B470
7579467A7D50A3A073CDCC9CCCD8A88AA474001B0000120092AF77D5EEB5B7D3A0C5E5B6
3D61337CA072C7E9B7BFDDA785A2688CA667839C5AB0C783
5E4E3F382E15B7B88C3E480BDDF2A7CDE398CCDEA0FCFFDCFFFFEFFFFDFDFFF7FFFFFDFF
F4F9F2F7FFECE3FFCECFE5A7B6B678EFF0B6CFEAB7AAD0A9E7FFF89ECCC2387C71C5FEF7
F4FFFFFEFFFFF6FFF8FEFFF8FFFBF8FFFAFAFFFEFBEDFEF899C4BD89B6B1E7FCFDF1FCFE
F5FFFFFCFFFFFFF5FFFBFFFF11675E4DAFA2E3FFFFF9FFFFF7FAFFFFFFFFFFFCF7FFFFF8
FFFFFAFCF8F5FFFDFBE6DADAF8E8EBFFF1F4FFFAFDFFFBFCFFFEFBFFFFFAEEEBE619150C
0B0200D2C4BBFFFBF1FFFBF4FFFCFDFFFDFFFFFDFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
FFFFFBFFFEFBFFFEFAFFFBF8EAE0DEDACFCDC9BBB8FFFDFAF6FCF8F6FFFEF5FFFEF9FFFF
38393BFEFEFFFFFDFFFFFDFFFFFCFDFFFDFBFFFDFAB3ACA4B1ADA2FFFDF0FEFCEDFFFFEA
B99E806C4D30FFF5E8FFFBF8FFFBFFFEFFFFF8FFF8F9FFFAFCFFFBFDFEFFFFFDFFFEF8FF
FFFDFFFFFFFBF6F8E2FFFFE39F9073766547A39D7BEBE8C5D6D1B1FFF6DAE5CBBAB99D92
604740918078F5F3E4FFFFED8D8D71ACA181FFFAD8DBB79DC3A89FFAE7E3E8D6D273655A
8A826FD9D4B6FFFFDAC5CD94D6E39EC8D88DD3E997D9F29FD4EFA2BCD790D3F0AED4EEAF
C9DD9ECCE2A1CCEAA0BEE491BCE78ECCF79DBCE48CCDEE9DCDE49EC9D79CE8EBBC0F0C00
0A0400A69E7A605633908359F4E1A7DBC788EAD9A1E9E0A9D1D299D3DBA0E2F0B3C2D39C
93A4783F542D5C74508FA98292AF834162377396757FA479CEF3B0BCD786E3E695DDD990
E5E7B59FA076605829AFA776747846798F606F99713866385A773D9FB77B8AAA7923481C
31562AA0C498B8D9AAD2F2C0C5E2AAD9F3B692A8687D9251
77664C3629078C8C5ADBE5A8D7EBA4D1E6A3CBDCA6FCFFE3FFFFF3FFF7FCFFF5FFFFFBFF
F6F7F2FBFFEFE7FED4C9DDAA979968D5DBADDAF5CCE9FFEFE6FFFBD8FFFD46857C79B2AB
E9FFFFF9FFFFF5FFFAFEFFFBFFF7F8FFEBEEFFFAFDFCFFFFEAFFFFE4FFFFF8FFFFFFFEFF
FCFFFFF6F3FAFFF4FFFBFFFF003734469791DDFFFFEFFFFFF5FFFFFBFFFFFBF8F1FFFEF6
FCFCF4FFFFFAFFFFFAFCF1EFE5CCCFFAE1E4F4E8E8FFFEFAFFFBF8FFFDFAB2A9A4070000
332920FFFCF4FFF6EFFFFBF8FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFEFDFFFEFB
FFFDFAFFFAF6EEE6E37D7572FFFCFBFFF7F6FFF4F4FFFEFBFBFFFDF8FFFFF8FFFFF8FEFC
6A6E6DF7F7F9FFFEFFFBF5F7FFFCFFFFFCFDFCF2F0B8B1ABA6A299FFFDF1F3F5E8D9D4BE
AD9976624825FFF1DCFFF9EDFDFAF5FEFFFDF5FFF7F8FFFBF9FFFDFBFFFFFEFEFFF9F7FF
FEFBFFFFFEFFF7F8EAFFFFEA5E4E35EFDFC5FFFADCFFFFE1FFFFE6FBF3DEFFFAEDFFF9EF
FFFAF1A5998D8B8D78D3D9BD252904E3DEB4EDD8ABAE98715C503857503D5E5842FFFBE1
FFFFE1FFFFDAD5DAA4E4EEAFCEE096D1E896D2EE99C9E791CAE795CDE99CC9E39A607A33
526B275C7C33BDE697CBFDA6BAF194B4E78BCAF49EC7E899D3EAA4D7E7A9CCD6A2010900
010700D6D7AF5C58325E51256E551C67490D6F56206457222326005F6D2FD4E39ED9E5A7
DDE5B6CDD5B04E5C3B000C00CFDDACD1E3B3000B00224620B5E5A7CEFCB1C6E194D3E4A0
D0E4B3C4D3ACE7E8BE55512458592FCCD8B0C7E6C495BA91D1ECB5C3E1A5BDE8B3001300
C7E8BB809D71CCE9BBCDEABAC0DCAB59743FCEE7AEC8E0A6
84854CDEE1A87A7F47D2DBA4DBE7B5E2EFC4DEE7C8FCFFEFFEFFFAF6F6F6FFFEFFF9F7F8
FFFFFAF8FAECE6EBD5DADEC5A49E88D4CFBCF1FAE7F2FFF8EBFFFDCFF7EE78AAA121534A
85ACA78AA7A5F0FFFFF8FFFFFFFBFFFFF9FFFFEEF7FFF4FDF7FEFFF8FFFFFDF8FFFFF9FF
F9E8F0FFF9FFFFF9FFF9FFFF3E666E245B60D5FFFFE6FFFFE9FFFFF8FFFBFFFFF3FFFAEA
FBFFF1F6FEF3FCFFF6FFFCF6CEA5A9E9C1C2C5BCB57B7D72584F4891827D2714100E0000
362724FFFBF8FFF7F5FFFEFBF5F9FAFBFFFFEEF2F3FAFCFBFFFFFDF7F3F0FFFEFAFFFAF7
FFFBF9938987BDB3B1F8F0EEFFFBFBFFFEFFFBF7F8FDFBFCFEFFFDFCFFFDFCFFFDFBFFFD
555B57FCFFFFFEFFFFFFFEFFFFFCFFF8EEEFFFF9FBB3A7A7C6BEBBFBF8F3F2F3EDD2CFBC
C7BB9554451AFFF7D7FFFFEAFBFCEEFCFFF8F8FFFAF1FFF7F5FFFFF4FFFFF3FCFFFBFFFF
F7FAFFFFFFFFFEFEF6FEFBEC615944E9DEC8FFFEEBFFFDEAFFFFF3FDF6ECFFFCF8FFF9F4
FEF7EFEEECDD70755E848E6B758153DCE5B0D3D99DB8C28583975CC1D69ECEDDA6FCFFD1
EAF1BBD3DBA0DAE4A7D3E4A0D0E79FC8E79BCCECA0D1F0A4D0EAA0566A23545F1DDEE9A7
D9EAA4C8E299A9C87C5F8436547B2CC1E698CBEBA0CAE39FC8D899D6E1A7DFE6B21F2200
070D00E1E7B9CED5A9DCE3B0E7E8ACD1D191DBDD9EE2E6A99AA364515B1E545D1ED8DDA3
DBDFACCED4A4E0E8B97780514953217D8B589FB083567C4B3D844C6DC38477C2877BC089
538E6214421D3E5835727B5C9C9B7F68674BDFE5C9C9D9B57C9867739E663D793D82B97F
C3DEAB75825693A57B39502693AD867B976F59784F5C7B51
818B46899452C4CE92DFE9B5DCE4BDFCFFE8FAFFEFF7FDF3FCFFFBF8FDF9FEFFFDF7F8F3
FFFFF8FFFFF4FFFFF3FFFFF3E5DCD5FDF6F0FFFFFAF6FFF8F2FFFFEDFFFFD7FAF3AAD2CA
95B9B5A2C4C3EDFFFFF3FFFFEDF0F5F7F2F9FFFAFFFFFCFFF7FFFFF5FFFFFEFFFFFFFCFF
FFFAFFFFFBFFFCF9FFE6F3FBE9FFFF57828B5F9097D0FDFFDFFDFBEBFBF1FFFFF2FFFFEF
FCFFF4EFFAECE1E9DC7E71697F4C51562427AEA69BE0E4D5DBD1C885726C412927270F0D
6B5959FFF4F3FFFDFBFFFFFDF9FFFFF3FDFCF7FFFDFCFFFDFCFBF9F4EFEBFFFDFAFFFDF8
FEF3EFCEC3BFF1E7E6FFFDFBFFFCFDFFFFFFF9F9FBFDFEFFFBFAF8FFFFFBF4F6F1D8DFD8
383E3AF6FCF8FCFFFFFBF9FAFFFCFFFFFCFDFFFAFDB3A7A7B9AFADF4F1ECFFFFFAFFFFEF
FEF6CF584D1FD1C9A4D0CBAEEEEDD9FEFFF4FBFFF8F8FFFBF7FFFFEDF9F9F8FFFFFAFEFF
F8FBFFFFFFFFF1F0EBFFFFF188846BDBD7BAE2DDC7F0EBD8FFFFF3FDF9F0FFFFFAFFFFFA
FFFFF6FBFFEECDD5BD9CA884A1AE80CDDCA5D8EBABCCE39FD6F8AEAACC82D2ECA5ECFDB9
D9E4A2EBF6B4DDE9A7CCE09B748F4893B36AA3C57B9EBE758DA45ECAD996E3E8A8DADF9D
CDDC97D6ECA3DAF4AAC0DC92ACCA82CBE9A18CA764526726E6F4B9DEE5AFE0E4B14F5321
030600D5DDACD4E0B0DCEBB4D0E0A1E0F1ADD9EAA6D3E29FD1DB9CD6DFA094995F65682F
B4B780E5EAB4D4DBA7DDE4B0A6AE7B3C46126E7A4888A876AAEEBB2A814E51A57376C395
7EC39789C19CD7FFDD0D260998A58B8F957B666D4E879571C7E4B67AA5708DC48ABBEEB3
CAE7AFA1B381778E6015310853734E7EA07F7C9E7D6E906F
919C5A7A8447EBF4BDDBE4B5C9D0AEFCFFECFCFFF3F4FBF3F4F9F5FAFEFDFEFFFFFFFFFD
FFFFFAFFFDF4F6F2E7BBB7ABFAF6EDFFFFF8FFFFFAF5FAF4F4FDF8F7FFFFF4FFFFECFFFF
F0FFFFEAFFFFE2F7F8F1FFFFF4FFFFF1FFFFF7FFFFE6FAF9E1FFFFDEFFFFE4FFFEDBEEEA
F9FFFFF2F8F6F7FFFFEEFFFFD4F9FFB5E4EA2C5D6482AFB4E3FFFFF4FFFFF0F0E8FCF8EF
A5A89F737B706C72687C6D68B68189D09DA2FFFCF3FFFFF4FFFDF4FFF5F03D2523442C2A
7F6D6DFFFAF9FFFDFBF0F0EEF9FFFFF6FFFFF9FFFFF9FEFAFFFFFDFFFEFAFCF4F1FDF4EF
C6BBB7F0E5E1FFFCFBFFFEFBFFFBFCFCFCFCFFFFFFFEFFFFFFFFFDFFFFFBFDFFFCD9DFDB
474D49FBFFFDFEFFFDFFFFFDFEF5F6FEF4F3FFF6F5ACA19DBEB7AFFEFBF2FFFFF4FFFFEB
F8EFC8615428B1A784E9E2C6F6EFDDFFFFF3E8E8E0FDFFFAF2F6F5FCFFFFFEFFFFF9F9FB
FBFAF8FAF9F4FFFFF4FFFFE99EA079D9DCB1D7D9B4E7E8C9FFFFEAFFFFEEFFFFF3FAFEF0
F4F8EAEBF2E0FCFFECC8D3B1D5E2B7D2E3AFD5E6AFC9DF9FCDECA6CCECA3D1E8A2D8E9A5
CFDA98C3CE8CD8E4A2B4C8836B853EC1E198D1F3A9C6E69DC7DE98E6F7B3DAE0A0D6DD9A
D2E19CD4EAA1D1E8A0CDE99FC5E39BD5F3ABB7D08E8DA2619DAB70CCD39DDDE1AE535725
030600D8E0AFDEEAB8C4D39CC7DA9AD1E59EC6D793D7E6A3DBE7A7E2ECADA9B1765F642A
838850CED39BD3DAA4DEE5B1C8D09DBBC591000A00485C2BCFF5C6C4F1C6B5E4B8B9E8BE
B9E7C0A9D7B0AAD6B22E583249714C96BA944669410D2E03C5E4B8D2EFC1D1EEBEB3D49F
D7FFC3B6E2A56E9A65134112001200305A363B5C3D7D9C7D
949E62B7C288CFD9A5D8E3B8C8D2B0FCFFEDFAFFF3FBFFFAFCFFFFFEFFFFF6F6F6F5F4F2
FFFEF9FFFFF6FDF6ECABA49AFFFCF3FFFFF8FFFFFAFFFFFBFFFFFDFFFFFFFCFBFFF5F8FD
F7FEFFF7FFFFEFFEFFF0FFFFDFF9F6E3FFFDE7FFFFD2FDF6ADE6E07FB8B265908989A8A0
ECFFFAF5FFFFEDFFFCE8FFFFE6FFFFDAFFFF78A7AD487379D5F4F7E0F4F5FBFFFF7B7C77
767B75B1B6AFCACDC6FFFBF8E5ADB8FFDDE5FFFCF6F5F5E9F8EBE39B86812B1311301818
B09E9EFDF2F0F5F0EDFFFFFDF2FBF8F8FFFFF8FEFCECF1EDFFFFFDFFFEFBFCF4F1FFFDF8
9A8F8BF6ECEAFFFDFBFFFCF9FFFEFFFAFAFAFFFFFFFEFFFFFFFFFDF8F9F4FEFFFDEEF3EF
606662FBFFFDF2F4F1FFFFFBFFFDFBFFFCFAFFFBF5B1A79ED7D1C5FFFFF1FEFFEFFBFEE3
EDE5C0AB9D7671644284785E716654F5EBE1FFFDF8FFFDFBFFFDFDFFFEFDF3EDEDFFFFFA
FFFFF4F2EFE0FCF9E69FA0808F9863D5E0A4E6EFBAE9F2C5FEFFDFFEFFE6FCFFECE9F1DC
D7E0CBE6F0D8FBFFECF6FFE3F9FFDFF8FFDCE3F4C0CFE4A9BFDC99D5F0A9CBE09BD7E6A3
C3CE8C778240B1BD7BD1E29EDFF9B2BDDB93C2E299CDEBA3D4EEA7BFD38EDDE8A6D8E39F
D1E09BD0E69DCCE39BD1EDA3C8E69ECCEAA2D9F2B0D2E7A6838E54D2DAA1D5DAA42E3200
0108008D9564828E5C60713A374C097B9149A5B974D1E29ECAD998E0ECACE2ECAFB0B87D
90985F5A5F27272E00606731959C6877804BA0A8757B855386916668744C42512A798B63
7089626A8960759E74B2E3B61D5526649E6EA0D6A573A373466A3E0D24009FAB83DFEFC2
B2D59BCFFDBF5F90588CBE8DB8E8BEB2E0BB8FB69784A789
99A36ED5E2ADC4D0A2EEFAD4E8F3D5FBFFEFF2FAEDFBFFFBF7FBFCFEFFFFFFFEFFFFFEFF
FFFDFBFEF5F0BCB1AB5B544AFFFFF6FCFFF8FEFDF8FFFEFBFFFCFDFFFAFFFFF9FFFFFAFF
FFFAFFFFFEFFF2FDFFE5FDFDABD0C9D1FFF6BBF3E670AEA157968E265F59224D4699B8B2
F2FFFDF7FFFDDFEBE7F2FFFFEBFFFFDEFFFF82A9AE577E85C4E5EAEDFFFFB5C4C9091314
7A807EEFF1EEFFFFFDFFF9FBFEC4D2FFCAD5FFF5F0FFFFF6FFF8F36D5855462E2E5E4646
B8A6A6FFFCFAFFFEFBF2F4F1FBFFFFF9FFFFEFF5F3FEFFFDFFFFFDF6F1EEFFFDFAFFF8F5
BBB1AFFFFCFAFFFBF9FCF7F4FFFEFFFAFAFAFDFDFFFDFFFEFFFEFCF6F6F4FEFFFFF0F4F3
565C58FCFFFDF2F3EEFFFEFBFFFDF8FFFCF6FFFCF3A69D8ED5D2BFFFFFE9FBFFE5FFFFE3
F9F3CFD1C4A15043237C6E5480715EDECDC3FFFAF6FFFAFAFFFAFBFFF9F6FFFDF4FFF8E8
C2BDA788876B979678555B2F96A562CADF94DFF0ACE1F3B5EFFFCCF6FFD9F0FEDAE1EFCE
D2DFC3EAF7DBE9F6D8F8FFE4F8FFE1F7FFDDF0FFD4D7ECB4DCF5B3C5DF98DCF0ABABBA77
929D5BA1AC6ACBD795DDEEAAC7DE98D3EEA7CEECA4C0DE96D6F0A9CBE09BE2F1AED2DF9A
D1E29CCEE29AD0E79FD5F1A7CBE9A1C0DB94CEE7A5CDE2A17E894F9EA66D989D672F3300
0108007C865287956090A46993AA66779148778E48CDE29DD9E9A8CCDB9AD6E2A4D9E3A6
D3DBA09CA4699BA068636A346D743E3B420C666D39B9BB89F4EDC18E80597F734D8C845D
4C4C2608140013300489B78845844F1358228CD19AA9E3B0A8D2A46E855B4A4E2BD7D9B2
DDEEBACAE5AE86A67484A97DB7E1B9BAE8C3002C0A659774
C8D4A4D1DEB0E9F5CDFAFFE3F9FFEAFBFFF3F9FFF8FCFFFFFEFFFFFFFEFFFFFDFFFFF9FB
FFF8F7FFFCF8D9CCC6B6ADA6FEFFF8F6FDF5F6F7F2FFF9F7FFF9FEFFF6FDFFF5FFFFF7FF
FFF8FFDFD8E0F9FFFFEEFFFF345D5501372A2F72610041359ED2D0E3FFFFEAFFFFEFFFFF
ECF5F2FEFFFBFEFFFBF1F7F5F0FEFEEEFFFF99B8BD54757C54757C67858D829DA4F1FFFF
F4FCFEFEFFFFF9F9F9FFF5FAFFCEDDFFC8D6FFFAF8FEFBF2FFFBF65D4543120000846F6E
C4B4B4FFFCFAFFFEFAFEFFFDFBFFFFF7FDFBF9FDFCFEFFFDF2F1EFFFFEFBFFFDFB88807D
F5EBE9FFFDFAFCF7F4F9F5F4FFFFFDFBFBFBFEFEFEFCFEFDFFFEFFFFFFFDFEFFFFDCE0DF
262C28FCFFFDFFFFFBFFFFFAFDF4EDFFF9EFFFFBED908875E5E4C8F8FEDCE9F3CEDFE7C0
E3E0BDCEC8A6ABA281FFFCE0FFFBE7907D6FCBB6B3FFF3F5FEE9E8FFF0EAFFFDECC1BA9E
817E5BA9AB83D2D7AED9E3AECBE095CAE38FC8E092D1E8A0DDF3B3D8EDB5D1E4B6D5E7BD
CFE1BBE6F7D3EDFFD9F6FFE0F7FFDFD8EBBEE5F9C8CADFA7C3D998DFF4AF91A25E6D7937
D3DE9CE8F3B1C7D391D6E5A2687D38D3EDA69FBA736C8740758F4895AC6694A8639CAD67
E2F3ADCCE098CEE59DC6E097CAE59EC8E39CD5EEAAD7ECABDAE8ABD5DEA5CED39D9BA06A
0A1100CDD7A3DBE9B4D0E4A9CAE39FE0FCB2BED8918EA55F65783696A665CDDB9DDFEBAD
CBD599DCE4A9DDE5AAE5EAB2BEC68DD3DBA29FA6707A7A443A2E007A6538BEA77DECD6AD
E3D4ABE3E0B589966A94B483B5EAB49DDCA536773F4A8451BFEABCC7E2B96F79564C502B
777F50E1EFBECDE3B559754CDFFFDDB3DFBB0017004B7F59
E3F0C5DDE9C1FBFFE4F3FFE4F9FFEFF8FFF3FCFFFDFAFEFFF9FAFEFAF9FEFFFDFFFFFCFF
FFFBFDFFF7F6AD9E9BABA29BFEFFF8FBFFFAFFFFFBFFFEFBFFFAFFFFF8FFFFF5FFFFF6FF
FFF0FAFFFCFFF7FFFFEAFFFEE2FFFF477A7175B3A6D9FFFFEBFFFFEDF7FFF2F2FEFFFCFF
FFFAFFFFEDEFFDEAECFFFBFBFFFEFFF9FFFFF1FFFF000C13284B51658C93E2FFFFE2FFFF
F5FFFFFEFFFFFCFCFCFFF8FDC68999B97F8DFFF7F5FFFEF8FFFAF65B43414A3031816C6B
E4D4D4FFFDFAF6F7F2F9FEF8FBFFFCFBFFFCFEFFFDFFFFFDF8F7F5FFFEFBF1E9E7564E4C
FFFDFBFFFDFBFEF8F8FDF9F8FEFDFBFDFDFBFFFFFDFEFFFFFCFAFBFAFAFAFCFEFDD2D6D5
000200FDFFFCFBFAF6FFFAF4FFFDF4FFF9EBFFFEEC867F65FDFDDBFCFFD9E5F3C2C9D6A8
CFD5B1E9E8C9FAF7D4FFFFDEFFF4DA5E4D3DB59D99FFF8F8FFF8F6FFFBEFB0A58966633A
868856D2DBA4D9E6B0C6D89AE0FBAACDEB93C5E290C7E396CCE7A2C7E1A2C1D8A0C9DFAE
D3E9BADDF3C5F5FFDCF1FFD6F5FFD8D3EAB4D5ECB4CBE0A5E2F7B67A8B47556421D5E19F
E6F1AFC8D391D7E3A191A05DA7BB76C6DB96C3DA94D7F1AABCD68FDBF5AEDDF4AE869C54
CDDE98C1D28BE1F7AFCFE9A0D4EFA8D3EEA7CCE5A1C9DE9DD0DEA1D5DFA3D9DEA6A2A973
000900DAE7B1DBECB5BBD193BFDA95C9E59BCEEAA0DBF5ACD2E9A3B9CE896777363C4B0A
A1AD6FCFD99CCDD599C9D196F2F7BDD3D89ED5DAA2E0E1A859571C6B62295B4B17685624
695427DDCFA2ACA87B293203BDD7A7C8EEBBB2E1AD7BAB792A552751784BB5D4AAE5FCD2
4D582D18210065764CCBE1BB4866424A6E4A00150089B38D
C6D1AFF2FDDBECF9DBF4FFE8FBFFF4F6FDF5FCFFFFFCFDFFFFFEFFF8F5FCFFFCFFFDF4F9
FFFBFDFFFBFAA79593BBB0ACFCFFF8FAFFFAFEFFFBFFFDFCFFF8F9FFF5FAFFF6FEFFFAFF
FFFAFFF7F5FAF9FFFFE5F9F8BFDFDC214C45BCEFE6E3FFFFF4FFFFFFFBFFFFFAFFFFEFFC
FFF3FCFFF3F9FFF7FBFFF6F8FFFBFDF9F7F8A3ADAF00060946696D4E7B7E8ABDC1E0FFFF
F1FFFFFCFFFFFFFFFFFFF5FAFFD8E7E2A8B6FFFAF8FCF7F1C5B3AF110000120000F6E1E0
FFF6F6FCF4F1FFFFFBF7FCF6FCFFFDFEFFFDFBFBF9FAF9F7FFFEFDFAF6F5C4BFBCB9B1AF
FFFDFBFCF7F4FFFEFDFFFFFDFCFBF9FFFFFDFEFFFDF9FBF8FFFEFFF9F9F9FEFFFFF1F5F4
070C08FEFFFDFCFBF7FFFEF8FFFDF3FFFCECFFFEE86F6A4AE3E5BDD6E0AED7E8B1CEE0AC
D6E2BCD3DAB9E5EAC2FBFCD4FFFFE1877B65AD9893FFF9F8FFF4F1FFFAEA5E5631878753
E0EAABD1E29ED4E8A9CEE7A3C3E090C8E893D1F19EC8E799C6E49CD0EDAACDE7AACBE4AA
D1EAB1C4DDA6D7EEB6D2EAB0CFE7ABD3EBADC0D998D0E6A5CADD9B95A46197A663D3DF9D
D5E19FD4E09E9AA664697835CBDA97D2E6A1D1E5A0D2E7A2D3EAA4BBD58ED7F1AAA8BF79
97A8629DAE67DDF3ABC7E198C9E49DD0EBA4C9E29ED1E6A3D7E5A7D6E0A4DAE2A9959D64
040D00D1DEA6CCDEA4D5EBADCFEAA5CEECA2CEEAA0CAE69CCBE59EDDF4AEC2D593DFEFAE
CFDE9DADB97BA5AF72BDC589C8D094E9EFB3E0E3AAD4D89BD3DA97E3E8A6D8D6999F965D
8679447A6C3BC7BB8B948D5F0B0E0098A577C4DEAED2F3C484AB7C144213497949ABD5A7
CFE6B8899A6E7288616C865FCAEAC5658762B7DCB3C5EABF
D1DBC0E1EBD0F6FFE8FBFFF1FBFFF8FAFFFAFAFEFFFEFFFFFFFEFFF9F6FDFFFCFFFFF6FA
FFFAFCFFFBFAEFDDDBFDF2EEFFFFFBFCFFFDFEFFFDFFFFFDFFFFFDFFFEFDFFFEFFFFFEFF
FEFEFFF9FDFFF8FFFFF4FFFF7A8F90607A799DBBBBEBFFFFF9FFFFFFFBFFF8F1FFFFFAFF
FFF9FFFDE9F2FFF8FDFFF3F5FFF4F5C0B8B68B8F8EF1FFFFE9FFFF4D7B794C8483CAFCFB
EFFFFFF9FFFFFBFFFEFFFAFDFFD3E2E9AFBDFFFAF8FCF8EF9F8D89110000563C3DFFF9F8
FFF2F1FFFAF6FEFFFBF9FEF8FBFDF8FCFDF8FCFCFAFFFFFDFFFEFDF8F4F3AEA8A8FFFCFC
FFFDFDFFFEFDFFFEFDFFFFFDFFFFFDFFFFFDFEFFFBFEFFFDFFFEFFFDFDFDFEFFFFEAECEB
050706343432231F1CE9E2DCFFFCF3FEF1E0847A5F9C9873DBDEAFD6E1A9D9EDAEC6DEA4
DAEFC6E4F5D1E8F5C9E8F0C1EAEBC3DFDABD86786FFFFBF8FFFBF4908571B1AE81CDD695
CEE094CAE294CDE8A1D1EFA9D5F5A9C5E697CBEB9FBEDE93CAEAA1D2F1ADC1DE9CD3F0AE
C0DA9BD9F3B4C9E3A2CAE5A2C9E49DD5F1A7C6E096CFE79DD9EAA47C8B48DAE9A6D9E8A5
CFDE9BDAE6A48A9654BFCB89E2EEACC6D592DBEAA7D4E8A3CDE29DD7F1AACBE69FCAE49D
8D9E58687732D0E49DD3EAA2D3EDA6BCD79092AB67687D3AD9E7A9E0EAADC8D095BBC589
0C170092A166D4E8ABCEE7A6C6E19AC8E69CD0EEA4CFEBA1C5E197CBE59CD4EBA5CEE39E
CFE09CD6E5A4DCE8A8444E0F5B6425969C5ED8DCA1DEE7A6DAEBA4D4E99ECEDE97D8E39F
D8DD9D86864A605923BCB080E0D3A6A7A0741011001B2B00BEDEAFBFEDBC91CD9947814E
6D9968A6CB9FB5DCB02E572D77A179C2EDC2C0E5B9CBEFBF
E2EAD3ECF4DFF9FFEEFBFFF4FCFFFAFBFFFCFBFFFFFEFFFFFEFDFFFEF9FFFFFDFFFFF6FA
FFFBFBFFFBFADFD0CBFFFAF6FFFFFBFEFFFDFEFFFDFCFFFDFCFFFDFCFFFDFBFFFFFBFFFF
F6FFFEF4FEFDF6FFFFE1ECEE879598889699B1C0C5F4FFFFF4FFFFE7F5FFF5FFFFF2FCFF
EFF6FEFEFFFFE9E4E8FFFCFDFFFCFA99918EBEBFB9F4FFFAE8FFFE98C5BE47827CACE1DB
EDFFFFF7FFFDF5FFF7FFF3F3FFDDEAF1B9C4FFFAF6FFFFF64D3B37200806543A3BF9E4E3
FFFBFAFFFEFAFBFDF8F7FCF6FFFFFBFFFFFBFFFFFDFFFFFDF6F2F1A29E9DC4BEBEFFFEFD
FFFEFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFBFEFFFBFEFFFBF8F7F5FBFBFBFDFDFDFEFFFF
000100050503030000FFF9F4FAEDE4FFFDEC62593C928E68DDE4B1DAE8ABC6DD99CBE5A6
D8F1C7EFFFE1E1F5C2D5E4ADD8E0B1E5E6C4A6A094B1A8A3D8CFC6959178C7CC96D7E59A
D9F19BD7F59FC8E89DBCDD96BBDB92D1EFA7C2E09ADFFDB7CBE9A3B9D791DDFBB5BAD590
D9F4AFCBE69FCEEAA0C0DC91D3EFA2CBE896CDE995D7F09FD0DF9AA3AF6DCFDE9BD8E9A5
CFE09CDBEAA78F9B59CEDA98C5D08EAAB573929D5BCFDE9BD8ECA7D2ECA5BCDA92D6F1AA
DCEDA76877328EA25B8CA35BBFD992EFFFC38FA6625B702DC2D092939F619BA368BEC88C
000A006B7B3DD7EBAEC7E09ED5F0A9CAE89EC8E69CC8E69CC7E399CEEAA0D2ECA5CAE19B
D4E8A3CDDE9AD3E29F8E9A588F995A9DA6659FA567AAB571CAE097D7F2A5D2EEA1CDE79D
D6ECA497A663464A0D524B15AD9F70503F13766A401E1F00A2B88ABDE5B3B2EBB67DB983
6694657AA175648F6469936B37643987B285B9DFAEB8DDA9
F8FCEBFAFEEFFDFFF3FCFFF8FDFFFAFDFFFEFDFEFFFEFFFFFCFBFFFFFDFFFFFDFFFFF6F7
FFFCFAFFFBF8C4B5B0FFFCF8FFFEFBFFFFFFFEFFFDFBFFFDF9FFFDF8FFFDF7FFFDF5FFFD
F5FFFFF5FFFFF7FFFFF8FFFFF9FFFFFBFFFFF2F5FEF5FFFFCCEFF1BDEDED88B8B89FCDCD
D3FCFEE7FFFFEDFFFFF7FFFF30312B3B3B31F9F9EDF9FFF6E9FFF5DDFFF66FA59781B5A8
D1F1E4F1FFF9F5FFF8FFFAF4FFDEE4D09DA2F8EBE3FFFFF42B1C15210907684E4FFFF9F8
FFFCFAF8F4F1FAFFFBF9FEF8FBFCF7FBF8F3908C89635F5EF7F3F2FFFEFFEDE9EAFFFCFD
FFFDFFFFFEFFFFFEFFFFFFFDFFFFFDFFFFFBFEFFFBFEFFFBF8F7F5FFFFFFFFFFFFF4F6F5
0A0A0AE1E0DED4CFCCFFFCF8FFFCF3DFD2C1554C2FB4B08AD2D9A5CFDFA0D2ECA3C5E4A1
DCF9CDF1FFE3DEF7BECDE3A3CEDDA6E1E9C0D8D9C98E8B8669665D8D9075D8E3A7CFE593
C5E286C4E58AC4E69AD2F3AECFECAAD7F1B0BFD998CEE8A7BDD895D4EFAAC6E19CA1BB74
C7E198BED88ED6F1A4D6F1A0CCE894D4F09BC3DF88CCE592CCDC95C3D28FC6D793D5E9A4
CFE39ED9EAA6909F5CDBE6A4C0C988DBE1A1A6AC6CB4BF7DD7E8A4D3EAA4C5E39BCCE7A0
D0E19BD8E5A0C8D995D6EBA6C2DC95BBD68FD8EFABD1E6A3DCEBAAB4C080929A5E8F995C
6775379FB272CEE4A48FA866D0EBA4C9E59BCEEAA0D4F0A6CFEBA1CEEAA0CFEBA1CAE49B
D0E79FCCE29AD9EAA4E4F3AEDAE6A4D1DC98919A59919C58CEDF98BDD78DD3F3A7CAEFA1
B2D78AC5E59ADAEFAAE0EAABE4DFA87D7141615428B3AC80545D304A623280A874BEEAB7
BCDBB1D1EBC458765025451E93B68C4F7345CCEEBBCFF2BA
FFFFF4FFFFF4FFFFF8FEFFF9FEFEFCFEFFFFFEFFFFFEFDFFFDFBFFFFFDFFFFFCFEFDF5F3
FFFCFAF8EDE7AEA199FFF9F3FFFEFBFFFFFFFEFFFDFCFFFDF9FFFDF8FFFDF5FFFDF4FFFD
EBFCF6EDFCF7F7FFFFF6FFFFF4F9FFFAFDFFFEFEFFF4FFFFAFE0DC4C8F864388835CA19E
65A5A4D0FFFFE0FFFFA3BCB8364037ACAEA1FFFFEFEAF2DDF2FFF3E7FFF484B8A141755E
BCE2CBECFFF2F2FFF4FBF9EDF7CBCCB38285FFFDF1FFFFF30F02001000008F7775FFF9F8
FFFCFAEFEBE8FCFFFDFCFFFDFFFEF9FFFEF9ABA7A4DBD7D4FFFEFFF6F2F3FFFDFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFDFFFFFDFFFFFBFEFFFAFEFFFAFFFFFDFEFEFEFFFFFFF5F7F6
000000FFFEFFFFFCFDF3E8E4FFF1E8C8BBAA52472BE6E3BAD8E1ACC9DC9AC7E399D3F2AF
E0FDD1F1FFE3DEFABDD0E9A5D1E5A6CEDBADF2F9E7C8CBC4ACAFA4CBD4B7D7E7A8C4DC86
D1EF8FD2F496C2E297C7E4A4D0E8AACEE4A6DFF5B7D0E6A6D3E9A89AB16D89A05A95AC64
96AE649BB669D4EFA0D0EB9AC5E18DD5F19CD0EC97D1EA97D2E39CBCCB88C6DA95D3E8A3
D0E5A0D0E5A08E9D5ADAE5A38C9151E6E8A9CDCF90727838B5C481C3D893D3F1A9CBE69F
D7E8A2DBE8A3D9EAA6D1E6A1D2ECA5CDE7A0CDE4A0D2E7A4D1E09FCCD898D6E0A3E8F2B5
C8D698CFE2A2D2E8A769823EC3DD96C4DE95D1EDA3D6F2A8C7E399C1DD93CCE89ED4F0A6
D0EAA1CDE49CC1D58ECCDD97C7D691D8E59FA2AD699BA863DBECA6DAF1A9C8E89DBEE497
D6FFB2C9F2A4B1D188D9EEABD5DB9FD3D0994137066A6234C2C495869262283E0FD7EEC0
D1E1BAD3E3BE9EAF8B273B16596F48687F538FA370A0B47F
FFFFF6FFFFF8FFFEF9FFFEFAFFFFFDFFFFFFFEFEFFFDFDFFFEFCFFFFFDFFFFF9F9FFF7F4
FFFDF8E7DDD4B2A89EFFFBF2FFFEFBFFFEFFFFFFFFFEFFFDFCFFFDFBFFFBF9FFFBF8FFFB
F8FFFDF8FFFFF8FFFFF7FFFFF3FCFFF8FFFFECF3FD899EA360958D024A3E529D9683CFCB
054F4E569897DCFFFF22423FF7FFFBF4F6E8FFFEE9FFFFE8D5E8CACAECCBD2FFDF215733
8CB897D1F4D6D6F3D7FFFFEFFFE7E2CA9E9BFFFFEFD5D8C5160A00523E37E9D1CFFDE9E8
FFFCFAFFFCF9FBFFFCFCFFFDFCF9F4C1BCB8F3EEEBFFFEFBFDF9FAFFFEFFF6F4F7FFFEFF
FFFEFFFFFFFFFFFFFFFFFFFDFEFFFDFEFFFBFEFFFAFEFFFAFBFBF9F0F0EEFFFFFFFFFFFF
282629F9F5F6FFFCFDFFFBFADECFC85A4D3CFFF7DBCBC89FD7E0ABD3E8A5C9E79DCBEAA7
E0F9CFE8FFD7E5FFBDCCE69CD7ECA7C2D39FE9F2DFFBFFFBFBFFF7FBFFE8D6E9A9C9E189
D8F392D2EF93C7E29DD3EBAFD7E9ADC4D496CADA9CD2E2A3CFE2A0718540C9DF97D3E9A0
BBD186A3BB6FD3EB9FC1D98BCCE798C1DC8DD0EB9CCEE69AD3E49E98A965CBE09BD0E7A1
CFE9A2CCE39D8FA05CD5E09E636526D4D496DCDA9D6062239DA866C4D994C8E69ED0EBA4
CCDB98DDE8A6D9EAA6B9CE89BAD18B88A25B94AB658DA25D909F5EA5B171939D5ECBD797
D1E09FDDF0AECBE4A0CAE39F9EB56F91A86089A35A859F56839F549BB76CC1E094DBF7AC
CCE89DD8F2A8DCF4AADCF2A9D7E8A1C5D58C83934C61712A8DA15C8CA35F88A65E719349
779B51A2C67CBCDC93CFE9A2C7D695E0E8AC9FA0674F4D1A838150BCBB8B77784C1F2200
797E55BEC49ED7DFBADEE6C16167434E5029A7A479888153
FFFEF8FFFEF9FFFDFAFFFEFDFFFEFFFFFEFFFFFDFFFDFDFFFEFCFFFFFEFFFDF9F6FFFEFA
FFFEF6D8D0C5D4CABEFFFEF4FFFEFBFFFFFFFFFEFFFFFFFDFFFFFDFFFFFBFFFFFBFEFFFB
F9FEFAFBFFFFEBF4F3F4FFFFF5FFFFF2FFFF94A5AD000F12E0FFFF74B0A85FA19DCEFFFF
99E0E446858ADCFFFF000C0BE8F3EBFFFFF1FFFEE6D7D6B7DCECC5CAEBC0BCEDBE578F62
57875FC0EAC6C4E6C5FCFFECF6D1C8B28A82DDD8C5676C5629201168554EFFF9F4FFF9F8
FFFCFAFFFEFDFCFFFFFCFFFDF6F3EEE7E0DAFFFDFBF7F2EFFFFEFFEFEBECFFFEFFFEFCFF
FFFFFFFFFFFFFFFFFFFFFFFDFEFFFDFEFFFAFEFFFAFEFFFAFFFFFBFFFFFDFFFFFFF3F3F3
121013FFFEFFFBF0F4928483685952F0E0D1FCF0D6E8E6BFD3DCA7DBF0AFC1DF95C5E4A1
E1F8CCEDFFD5EBFFBCC8E190DBF1A8CDE0A9DCE8D2F9FFFBEDF4ECFAFFE9CFE2A2D2E991
CCE685C4DC84D0E5A4DDEEB7D1DFA2E1EBACDEEAAAD7E3A156652299AA64D2E39CCEE29A
E4F9AEC7DD92ADC37ADFF7ADD1E8A0D9F3AAC3DD94D0E79FC1D28E899A56CEE39ECCE69F
CFEAA3CAE49D91A560D3DE9C585A1BE2DEA1ECE8AB878749969F5EE7FBB6C8E39CC7E29B
D6E5A2CBD6946475313247024B621C3F5912C8DF99D6EBA6D3E2A1D6E2A2919B5C5B6727
DBEAA9D3E6A4B8D18DD7F1AAC5DC96C5DB93CFE69ED6F0A7CEEA9FBCD88D98B76B719044
CBE79CC6E297C2DC92C7DF95D8EDA2D7E99FD1E399D3E79FD3EAA6CCE6A5C4DF9CD5F0AB
D9F2AE7D975059702AC8DD98E3F6B4CAD998D8E2A5EBF0B64D4B18413B0B82774AF5EEC2
929568030C005B6439E1E8BFDADCB575714BDFD3AB89784D
FFFBF8FFFDF9FFFEFBFFFEFDFFFEFFFFFDFEFFFEFFFFFEFFFFFEFFFDFCFAFDFAF5FFFEF8
FFFBF1C5BFB3F7EFE2FFFEF4FFFFFBFFFFFFFFFEFFFFFEFDFFFCFDFFFDFBFFFCFBFFFDFB
FCF6F6FFFFFFFBFFFFF5FFFFE9FEFFD1EDEE6180835B7A7CE0FAF964828283ACB2DCFFFF
D9FFFF366775B7DBE7677C81FCFFFDFFFEF1FFFFE4C4C09BD0DDB1D4F4C2AFE4AC5B9660
2A5E30B4E2BBB9DFBAE4F1D5FEDED1F7D3C7FDFBE6A7AF980900005E4C42FFECE7FFF9F8
FEF2F2FFFDFCFAFEFDF6FAF9F3EEEA7E7771F6EEECFFFEFBFFFEFFFFFDFEFFFEFFFBF9FE
FFFEFFFFFFFFFEFFFFFEFFFDFEFFFDFEFFFAFEFFFAFEFFFAFFFFFBF4F4F2FBFBFBFFFFFF
010002FFFEFFF5EAEE766867A19089FFFCEDFFFCE2FFFDD6D7E0ABD1E6A5CFEFA4C0DF9C
DBEDC3E8F8CBDFF5ADCCE391D7ECA1D5E6AFE5F1DBF7FFFBF9FFFBF9FFECC8D899D9ED96
D8ED90DDF19CCCDC9E8A9762667033A3AC69D6DF9CB0BA754B5611DAE7A1C8D58DDFEFA6
CBDC95CDE1998BA159C7DE9ABCD291DAF0AFC7E09FCCE2A1A3B674A5B974CDE49ECCE7A0
CEE9A2CBE59E93A762D4DF9D5C5C1ED9D397E4DBA0B1AD709AA060CCDD99B7D28BBBD58E
556421798442BDCC89C3D792D4EBA5CBE59ED1E8A2D4E9A4D4E3A0C4D08EE6F1AF889452
D0DF9ECBDE9CDDF6B2C6E099DBF0ABD3E9A1CFE59CCEE69CD2ECA2D8F4A9C0DF9398B76B
CDEC9ED4F0A3CBE79AD2EDA0D7EDA2D0E59ACCDE92CFE59CC0E09DC6E6A7DBF3B5D1E1A3
CDD79ADAE0A2BCC282939E5CCAD99680904FCEDE9DCDD99BC2C58EB2AA795B4A1C918658
CDDAA55168324C632FD0E4B3C4D4A7232A00D3CEA462562C
FFFCFCFFFDFDFFFEFDFFFEFFFFFCFDFEFCFDFFFEFFFFFEFFFFFFFDFAF9F5FEFBF6FFFEF8
FCF5EDB7B0A6FFFDF4FFFBF5FFFEFFFFFFFFFFFEFFFFFEFBFFFDFAFFFDFBFFFCFDFFFCFF
FFFEFFF4F6F5F9FFFFF2FFFDE7FFFAC5E4DF5A7E7EE9FFFFE8FDFF64797C7B949BE3FFFF
E3FFFF183948CEE0EE2E353FFFFFFFF4EDE3FFFDEAE1DEBFD6E7BBC0E5AFB7EAAF84BF87
2B6439C1F3CEBFEABFD1E2BEF7E2CDF1D4C68E87742C2B160A0000C2B2A3FFFAF3FFFBF8
FFFBFFFFFDFFCCCCCAD0D1CCFFFFFAF6EEEBFFFEFBFEF8F8FFFCFBFFFDFEFCFAFDFFFEFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFDFEFFFDFEFFFBFFFFFBFAF9F5FFFFFBF5F4F2FFFEFF
0B060AFFFDFFE0D6D7A99E9CFFFCF3FFF9E7FFFFE3F7F8D0F9FFCFCCE0A3BED996D8F5B5
CAE0AFD1E5B0C7DD92D2E896CCE099CDDBA6F1FEE4F9FFF8EFFAF2F8FFEDD2E6A7DCF29F
C9DB85D6E394C1C68C555A24DDE8A6AFBC7694A1594A5A11D8E89FD6E89ED0E59ACBE196
CFE59CD8EFA7AAC17B667F3B98AE6D7C9554B6CF8E8CA5638BA460CAE49DC8E69ECCEAA2
CBE9A1CBE59E91A560D2DE9C9DA262D8D89AE1DFA2DADC9DACB8766C813C7C9A52A7C27B
CEDD98E1ECA8C9D893D6EAA5CDE49EC3DD96DAF4ADC0DA93D1E6A3DAEAA9CEDD9C97A665
89995A92A565657A399BB26ECEE59FD1E8A0D2E9A1CCE49AC9E39ACEEA9FB9D58B8FAB60
BFDB90D8F4A9C7E398CDE79DC6DE94D7EFA5D2E89DCFE9A0CFEFACBBD999D3E9ABDDEBAE
D6DEA2DEE2A5DBE1A3D8E3A1CFE09CAFC37E90A56291A162D8DDA3DCD9A2B8AA79635C28
5A632EC9DCA57E925F253908D5E8BB66754CA7AF88727651
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFBFFFEFBFDFAF5FFFEFBFCF7F3
FFFDFBA8A09EFFFDFBFFFDFFFFFCFFFEFBFFFCFBF7FFFFF5FFFFF6FFFFFAFEFFFFFCFFFF
FAFFFFF4FEFDF3FFF8F2FFF6F0FFF8C5E1D57E9B99EAFFFFCEEDEF769494BFD4D9F0FFFF
C9E5E855666DF1E9F66B5D6AFFFEFFFEFFFFFFFDF8EEEDDBDBF5D2C6F0C0B3E2AB86BC8A
4B8668A8E0C3BFEABDCBE2B6EBE6C9D6C3B28B796D4C3C2C322209D8CAB0FCF3E4FFFCFA
FFFBFFF6EEF9D1CCC8EFECE3FFFEFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFAFFF9F6FFFCFDFFF7FA
060002FFFCFFE6DDDE9F9890FCF6E6FFFFE6FFFFDFE9EFC3DCE9B4C5D69FDEF3BABFD89E
C2E1A6C9E9A6D1EE9ED1E89AD0DFA6D8E3B8EAF5D3F8FFEFF5FFFBEFFFECD0E9AFC5DB90
D1DE96E3E8A6D0CB9359571EDBEAA5C8E096C6E0969CB86DC2DE93C2E195D7F7ABBCDE91
D4F6A9C2E296BCDC91D1EFA5D4F0A6CAE49DD1EBA4D3EEA7CCF0A6B9E296CAF0A5C9EDA3
BDDD94D4EFA88BA05BD6E7A3A1B06DBECA88E1F0ADC6DA95CBE59ED8F6AEC7EBA1C3E398
D4E49DD2DD98CADA93D0E49DDEF8AFD3EEA7BCDC93C2E19BD4F3AFBDD895E1FAB89DB271
8FA1636676382836007F8F50D3EDA6C2E098DAF5AEC7E399C3DD96D6F0A7B1C88290A75F
C8DF97CEE59DD3EDA4D0EAA1C0DC92D3EFA5CEECA2CDE8A1D1E8A4C8DD9CD9EEADD0E5A4
CDE09ECCE19EE0F7B3C9E09CCCE5A1D0E7A39EB370A0B06F818B4E95995EE7E5ACA19C65
4A44129E9C6CB8BB8E354016CADCB695AD8B547153608164
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFDFFFFFDFFFFFBF9F5F2FFFEFBF6F1EEFFFDFA
FFF8F9DCD3D4FFFCFFF8F1F8FFFCFFFFFDFFFFFFFBFFFFF3FEFFF1FCFFF4F8FFFAF5FFFC
F7FFFDF4FFF8F1FFEAE3FBDBEEFFEAE7FFEB92A8A593ACB07796986F8D8FD7E9EDF4FFFF
D7EDEBECFCFCFFFBFF372B35F6FDFFF4FFFFFFFFFDFEFFF6ECFFE8C5EABEB9DEAAA5D0A2
5C987F70AB95C0EDC2CDE7B8FAFDDEF0E3D03B241C19010047361AFFF6D8FFFFEDFFFEFB
F3EDFBDED6E3DDD6D0FFFEF4FFFFFBFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFBFEF9F5FFF9FAFFFCFF
060002FFFCFFF1E9E76C685DCECCB5EFF3D2F5FCD2DCE6B4D5E4ADD9ECB4C9DEA5D3ECB2
CAEEAEC8EEA5C9E996CCE498D2E0ADDDE8C0EBF7D1F2FFE4F3FFF9EAFFECD1EDB3D5ECA4
E2EEACE3E4A8DCD199696528D4E59FC9E89CD0EFA3B7D78BCCEEA1C7EC9ED1F8A9BEE596
B4DB8CCCF1A3D7F9ACCBEB9FD4F0A5C3DD93C8E096C6E297B2D88DD9FFB7B5DB90C2E49A
DFFDB5CFE9A28A9F5AD8ECA7BFD08C6C803BCADF9AD9F3ACC2E098C6E89EC9EDA3CCEAA0
E1EEA8D4DB95E3EEA9CEDE97C0D48DD1E8A0CAE59ED4F2ACC2DF9CD3EDACCAE0A0D5E7A9
E5F3B6DBE5A9C9CE94939F61C8E19DBFDD95CFEAA3CEE9A2DAF1ABC6DD978FA35E8A9E59
DDF1ACCDE29DC3D893C7E19AD5EFA8D5F0A9C5E39BCBE69FDFF2B0CDDD9CD7EAA8C4DB97
D5EEAAC9E49FBBD993D5F3ADCAE5A0D9F2AED5EAA7C6D695B3BD7EADB677989C5FEBE9B0
9D905C958456BCB38848491F323E18CAE0BC86A585557A5B
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFEFDFFFEFDFFFDFDFBF5F5
7D7779857F81FCF3F6FFFCFFFBF7FFF9F8FFFAFCF7F9FFEEFCFFEAFBFFEAF8FFECF5FFEC
C8D8BDD1E7C3C5DCAEC7E1B1D9F4CBD4EED3637A720006092C4047F1FFFFF4FFFFEBFDFF
E9FFFFEDFFFFEAF8FB000307EEFFFFEEFFFFECF7F1F9FFF4F5FFEACDE4B8CBDDABC7E4B8
71A89182C0A9E3FFEAC3DEB3DADFC1F1E6D427130C210B00423219FFFFE4FFFFF1FFFEFD
F6F0FEDDD5E4E0D6D4FFFCF2FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFDFEF8F8F7F3FFFEFF
030000FFFDFDFFFCF6636051ABAA8EE4E9C1DFE9B7D0DFA6CBDFA0DDF6B5CFE9A8F1FFCD
D5FAB7CBF1A8C8E893D0E89AE1F2BCF3FFD7F9FFE1F8FFEAF4FFFAF2FFF1CBE4AAC7DF95
D7E3A1D5D69AD7CE95585417CCDD97CAE99DD0EFA3CCECA0CBEDA0C7EC9EC8ED9FC4E99B
C7EC9ECFF1A4C7E79BB6D589D5F1A6D5EFA5D8F0A6DBF5ABC9E9A0D3F5ABC3E39AC9E49D
D1E8A2CCE09B93A25FD0DC9ADCE8A6445310C9DA96E1F5B0CEE59FC6E19ACAE8A0CFE69E
C5CC88E7E8A6535613525915D8E19EE1ECA8D0DF9CD1E09FD9E8A7D0DEA0D9E3A6D2DA9E
D0D69A060700E6E5ACE7EDB1D2E5A3D8F2ABCCE39DC3DA94DEF2ADCADE9997A66398A764
C7D693E1F2AED7E8A4C3D893CEE39ECBE29CC5DF98D6EDA7425513576726425513000F00
617A36D5F0ABCAE8A2BFDD97C8E39ECAE39FD2E7A4D2E2A1D3DF9FC9D293707437DAD89D
DBCC955F4B189E915DF3EBBA060500DBE3B4DEEEBF5D7042
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFFFDFCF8F9F9F5F4FBF5F5FFFDFD
E5DFE1D6D0D2FFFAFCFFFDFFFEFDFFFCFEFFFBFFFAFAFFECF9FFE3F9FFDFF8FFE1F7FFDF
C4DAA9D1EAB1CEE8A7CDEAAABAD5A2CCE6C3EDFFF7D5EAEDD1E8F0EDFFFFEBFFFFE0F9FD
EBFFFFEBFFFFF0FFFF0E2324EEFFFFF0FFFFEEFEF4F8FFF3F4FFE4D2E3B7D4E2ADC9E4B7
84BCA397D6C1E2FFEDCBE7C1EEF4DAF4EBDC35201B0F000062533EFFF8E3FFFBF0FFFEFF
FFFCFFF8F0FDDAD0CEFFFBF3FFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFBFFFAFBFFFAFCFFFBFEFFFD
010000FFFBF8FFFEF6A6A18E8F8E6FCCD2A6D0DBA3D7E7A8CBE29CCAE59EDBFBB2EEFFCA
D4F9B4CBEFA7C7E792D0EB9CE5F6C0F3FFD7F8FFE0F5FFE7F1FFF5F4FFF1CAE4A7C8DE95
DDE9A7E6EAADE8E2A85A581BD0E19BCDE99EC8E499D0EFA3C2E296C7E99CC2E497CCEEA1
CDEDA1C5E599CCEB9FD5F1A6CAE49AC6DE94BED48BCBE399D1EBA4C8E29BD9F0AAD3E7A2
CCDB98D3DF9D9DA866D6DF9EDBE4A35A6523D5E19FCEDD9AD9EDA8CDE49EC5DF98B0C781
65722DB3BE79CED994DCE9A3727F3A4A5914D3E29FD7E6A3D9E8A5D2E1A0D4E0A0D7E3A3
4E58192B3500687132C8D494637732BED38EE1F5B0D1E5A0D4E5A1D0DF9CB7C3819DA967
D5E09ED8E4A2CFDE9BE8F9B5A7BB769AAE698A9F5A889D58DEF1AFD9ECAADFF4B1C5DC98
C2DB978CA76284A25CD3F1ABD1ECA7CBE4A0C7DC99DCECABDCE8A8DCE6A7ADB3758E8E52
FEF1BC6E5C2A746635473D0C5D56281C1B006A6C3DD1D7A9
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFF0EEEFFFFEFFFFFEFF
A8A4A3B3AFAEFFFDFCF9F7FCF7F9FFEFF6FCE2EFDED3E2C1CDDEB1CEE3ABCDE2A9C8E0A2
D9F2AECCE89DC7E492D8F7A9CAE7A7C8E1B7F2FFF8E5FFFEE3FFFFD8FFFFD8FFFFE4FFFF
EBFFFFE0F5F8E9FCFF213033C8D0D3F8FEFCF8FFFAF8FFEFECFCD8D3E5B5D2EAAEBAE1AC
7EBAA06CAB98D0FFDFD2F0CEF0F8E1CCC4B71D0A060E0000B8AB9BFFFEEFFFFEF8F8F6F9
FFFCFFFFFBFFCDC3C1FFFEF6FFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFCFFFBF8FFFAF7FFFAF8FFFBF8FEFA
000000FFFFFAFFFFF3ECE7D188856296996AD8E2A6DFF0AAD0E89CC1E092C8EB9BC6EC9F
CCF1ABC6EAA2C5E590C9E495D3E6AED8E7BCD7E6BDD1E2C2F0FFF1F4FFEFD4ECB0DDF3A8
D3DF9DD0D698C8C68B5B5D1ED8E9A3D2ECA2C5DF95D5F1A6C6E297CFEEA2C6E599D0F0A4
D2F1A5C7E398C9E59AD3EDA3BCD48AE7FDB49BB16843570F95A662D0E19DC2D18ED4E09E
EFF8B7CCD292AAAF6FDCE1A1D3D898656B2BD6DF9ECAD694D9E8A5CBDF9ACFE49F89A35C
BBDB90BADF92DAFCB0CBEDA1C2E297B9D98E9FBD73BBD98FC4E298CFEDA5C7E59DC9E9A0
CDEDA4CCEEA4D6F8AEC8E89F98AD68D4E5A1D8E7A4CBDA97D8E4A2ECF7B5C0CB894B5614
969F5EDCE7A5D0DB99D3DF9D1A29008F9E5BD7E8A4E2F3AFC2D691C7DB96C7DC97D2E9A3
E3FDB6C6E19ABAD8908EAC64CBE69FCFE9A2D5EAA5D9EAA6D2E19ED5E09EDDE3A363642B
D9D5A6F7EEC7FFFFDB837B56564D2C5A54321B1200756F4F
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFEFEDF0FFFEFFFCF8F9E0DCDD
CFCBCAFFFBF8FFFEFBFFFFFDF9FFFFF7FFFBE5F8DCD1E6BBCAE1ABCEE6A8D0E8AACBE4A2
BDD98EC4E18DCBE98FCEEC96C5E09BBED8A9F4FFF4EBFFFFCAFBFFBBF8FD72ACAE6A9A9C
5C777E5E6F769BAEB296A1A578737AB2ACAEF9FFF8F7FFEDEDFDD8D1E5B2D2F1AEBCE9B0
61A0852B6A59E2FFF6C3E0C4DAE1CFCAC1B8160402271513E1D3CAFFFDF4FFFEFBF8F6F9
FCF6FFFFFCFFB5ABA9F7EEE9FFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFBFFFFFBFCFFFBF5FFFBF1FFF8F7FFFDF3F9F5
090907FFFEF8FCF4E7FEF6DFB7B38E7E7E4CD4DCA0CFDF98CCE395D1F19EBCDF8DC2E99A
C5E9A3C6E7A0C8E893CBE697CEE3AACEDFB2CCDDB1C8D9B7F5FFF4F4FFECCFE5A7DCF1A6
A1B06DA4AD6EACAD71919656D3E7A0D0EAA0C7E197D7F1A7CDE79DD5F1A6C8E499CBE79C
D9F3A9B4CE84D0E89EE9FFB79FB56C93A96081954DA1B26B939F5D8A9553E2EDABCED796
D3D999E6EBAB929757D4D999D9DE9E525717D1DA99DFEAA8D7E3A1C8D794DAEBA77F9952
D0F6A9CAF6A7C5F0A1B2D88BD7FCAFD4F4A99CBA70CEEDA1D4F0A6C3E197D5F5AAC0E598
CDF3A6C5F0A1A3CF82CBF1A6849B55D0DF9CDEEAA8D7E3A1C7D391D7E2A0E9F4B29BA664
4E5917E0EBA9D8E3A1697533D1DD9BCCDB98D8E7A4C0D18DDAEEA9D4E9A4C9E09AD3EDA6
D1ECA5C3DE97DFFDB59CBA72CAE59EC7E19AD6EBA6C0D48FD4E3A0D5E19FCED796565E23
DBE1B5EFF3D0FFFFE0FFFFE1FFFFE8DFD9C35048352D2210
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFEFFCFCECC
D7D6D2FFFFFAFFFFF8F0F3E8F4FFF0EDFFE5DEF5C9CBE3AFC5DEA4CDE7AACFE8AECBE5A8
D5F0ABCFEC9CC7E38CCAE691F5FFCAF4FFDCF5FFF3E0FFFAAEEAEB0A5457387E7E558D8E
5C747E7E8C951F3238BFC8CD82727D84757AEBF6E8F4FFEDF5FFDECBE2ACCBF0AABFF3B5
71B294024130E2FFFABBD7C1F5FDEEF9F2EA1F100D0B0000E0D2CFFCF4F1FFFEFDFFFEFF
FFFAFFFFFDFFA59A96B8AFAAFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFBFFFFFAFFFFFAFCFFFAF7FFFDF5FFFFF3FDFCFBFFFF
0A0607FFFDFAFFFBF2ECDFCCE8E0BC999565999D62B4BF7AC9DE93D4EFA0CBEC9DCFF4A7
C7E8A3C8E9A2CBEB96CFEC9AD1E9ADD4E8B7D3E6B8D3E4C0F7FFF3F1FFE6CBDFA2CFE497
85944FC1CC8AD4DA9CE8F1B0CEE29BD0E89ECCE49AD2EAA0CCE49AD1EBA1C9E399C7E197
C8E096DCF4AAD5EBA2778D44778B43CBDF97DBECA5CDDD96D2DD9BB2BB7A535C1B606626
3E4404464C0CDCE2A2D9DF9FDEE4A44E5716D4DD9CDFEAA8DCE8A6CDDC99BCCB888DA25D
BADC92C9EFA4C1E397C7E59BD9F1A7BED28A9CAC6593A35A93A05AD1E19AC9DD95CFE79D
CDEBA1C0E296D6FCAFC7E99D6F8640CBDC98D0DF9CD8E7A4D8E7A4D2DE9CD4E09E899553
3C480685914F939F5DDBEAA7CAD996D7E6A3D9E8A5DAEBA7CADF9ACFE6A0D5ECA6CEE8A1
C5E099BDD891CDE8A18EA962D8F2ABCDE7A0D0E5A0C9DD98DCEBA8E4F0AED2DD9B526025
C6DCADE3F9D3D9EDCAE9F8DBFCFFEFE0E2D4FFFFF6F9F4EE
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF6F6F8FFFFFFAFB0AB
FFFFF8F3F5EAFFFFF3FCFFEDF5FFE3F0FFD8E1FDC2CDE9ACC8E1A7CDE6AFCDE5B5C6DEAE
C7E0A7CDE8A5D1EC9DCCE798F5FFCCF3FFDAF1FFEFEBFFFF80B7BC4D92997FC6C87BB5B7
EBFFFFEEFFFF00080B7C9091D2C8D1897E82E3F4E4EEFFEAF9FFE1CADDA6C3E49FBDEDAF
B1EECF0D4A3AE2FFFDBBD6C7EAF0E6C9C2BA1A0C09221212F3E7E9FFFDFFFCFAFDFFFFFF
FFFEFFFFFEFBA79C968A817AFFFEFBFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFBFFFFFBFFFFFAFFFFF8FCFFFAF8FFFEF8FFFFF8FDFFFFFEFF
040002F7EBEBFFFBF4DECFBCE4D7B7B6AF814E4D14A7AE6BD3E39CC1D78ED9F5AAC1E198
CCEBA8CAEAA1C8EA93C8E893CBE5A6CCE3AFCBE1B0CBDDB7F5FFEFF8FFEAD8EAACC9DB8F
76863FDCE8A6D4DE9FD5E19FD0E69ED4ECA2D2EAA0CBE399C8E096CEE69CD1E99FD0E69D
D6ECA3C7DD94AEC27A576B23AABE76DAEEA6D4E59ED4E49DDCE7A5D1DA99949D5C9AA362
959E5D8D9655D8E1A0DCE7A5D3DE9C606C2AD5E19FC2CE8CDFEEABD2E19E8A995694A964
D0F0A7BCE096D8F6ACC8DF97D2E39CE2EFA9A7B16A9BA25C969C56B9C37CD5E29CD2E39C
C7DE96C9E79FCCF0A6BEE0966E853FE1F5B0CFE09CC7D894D8E9A5D2E39FD4E5A197A864
3A4B07B9CA86D4E5A1D0E19DDBECA8CADB97D3E7A2CEE29DD2E9A3CCE69FD3EDA6BFD992
D0EBA4DBF6AFC7E29B88A35CCAE49DCFE9A2C8DD98E0F4AFC4D591CFDE9BE3EFAD415315
CEEBB5BDDEAFC5E2B6E8FED8F8FFEAFBFFEFFFFFF4F9F9EF
FFFFFBFFFFFBFFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF6F6F8FFFFFDA9ACA3
FFFFF4FEFFF1FFFFEDFBFFE4DFF7BDC9E79FCAE8A0CDEAA7C5DEA7D1E8BEEDFFE5F4FFED
F5FFE6F5FFDCD2E8AAD0E6A5D0E5AAD1E3B9F6FFF2F1FFFF5B818AD9FFFFD5FFFF7FB2B5
DFFEFFE9FFFFD1FFFC436C66F2FFFFA4ADAA5C7965E9FFE9F6FFDEE2ECBACBDFA0C0E3A9
81B89971AA9BE2FFFFEBFFF8FCFFF8D6CFC71609031F0F0FFFFBFFFBF4FBFBF9FEFDFDFD
FFFFFAF6F3EAD8D0C5C0B7AEFFFEF7FFFFFBFFFFFBFFFFFDFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFBFFFFFBFFFFFAFFFFF8FEFFFAFCFEFDFEFFFFF7F4FBFFFCFF
0A0004FFF2F3FFFAF4FFF4E5FFFCE0EBDFB59B95617F8044E9F4B2BFD08CDCF1AEC1DA98
CDEAA8C3E39ACFF19AC5E791C8E5A3D4EFB8C9E0AAD2E4BAF8FFEFEAF7D9CFDFA0DBEC9E
91A15AC7D693D0DF9ED7EBA6D6EDA5CCE69CCCE49AD0E89ED2E89FC3D99094AA6190A45C
768A4290A45C92A35CCEDF98DBECA5D5E69FCEDF98D2E29BD2DE9CEBF7B5CAD694D1DD9B
DCEBA8D6E5A2CAD996DBECA8DBECA8455612D5E6A2D0E19DD1E29ED8E9A5879854D4E9A4
C4E39DD4F8AECBE99FC8DF97D5E69FE0EBA6C5CC86EDF3ABDADD98A3AA646F7A35CDDE98
D2E9A3CDEBA5C8ECA4CCEDA67E9851D5EAA5D8EFA9C0D791D4EBA5D7EEA8CFE6A0C9E09A
D2E9A3D1E8A2CAE19BCEE59FCEE59FCBE29CD2E7A2D0E7A1C5DF96CBE79DCEEAA0CFEBA1
C4E096D1EDA3CBE79D88A45AC8E299D6F0A7D7EDA5CBDF98CFE09ADFEEA9889550D6E9A7
C8E7A4D2F5B5EDFFCFD0E9B2E5F6C9E6F0CBE5EACAFAFDE0
FFFFFAFFFFFBFFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFEFFFFFBFEF7D5D9CB
F5FAE6FEFFEAE6EDCEF7FFD8E1FBB2C9E996CAE699CFEAA7CDE5B5DBEFD3F1FFF6F4FFFC
F5FFF4F7FFEAD2E6B3CFE4A9CEE2ADCFE1B9F4FFEFEFFFFF99B7C1DFFFFFCCFDFF7EAEB0
E9FFFFE2FFFFDCFFFF7FAEA6F0FFFFF2FFFF000C00EBFFEDF7FFE3C7D5A4C7DB9ED5F6BF
7CAF908ABFAFE6FFFFF2FFFFF0F3ECE1D8D11D0E0731221FFFFBFFFFFBFFFFFEFFF9FBF8
FFFFF4FEFDEBD5CEBEAEA89AFDFDF3FDFEF6FEFFF9FEFFFAFFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFAFFFFF8FFFFFAFFFEFDEDE7EBFFFBFFFAEFF7
0B0003FFF9FBFFEEE7FFFCEAFFFEE1E6DDB4D2CF9C53541A8A9256DEE9ADCBDA9FDEF2B5
D0EAABC5E39BCDEF98C4E68FC6E5A1D0EDB3C7E0A7D0E3B6F9FFEDF7FFE2D7E6A5D5E696
91A158DFF0AADAEFAAC9E09ABED88FDBF5ABD0E89EC7DF95D7EDA4586E25374B03DCF0A8
CCE098DBEFA7C6D790D7E8A1CFE099D1E29BD4E59ED8E9A2C9D895DEEDAAD9EAA6D4E5A1
CEE29DCEE39ED6EBA6C9E09A485F19D1E8A2D0E5A0D9EDA8D6EAA591A25E8B9C58D4EBA5
C3E49DBDE398C1E399DCF8AECAE097DBEBA2DEEAA0C0CA81E0EAA3CAD5909AAA63E1F6B1
C3DE99D5F6B1B8DD98C0E39F97B26D91AB64C0DA93D6F0A9C7E19AC5E099BAD58EDAF5AE
C3DE97C1DC95D9F4ADD5EFA8D1EBA4D4EEA7C6DD97CEE8A1D3EFA5CDE99FC8E49ACDE99F
CAE69CD3EFA5C6E298839F55D1EBA2D2E9A1B8CE86E5FBB3D8ECA5C7D8929AA964D1E29E
E1FAB8CFE9A8EDFFC7ECFEC4DEEBB6DAE0B0E0E3B8EFF0C8
FFFFFAFFFFFBFFFFFDFFFFFFFFFEFFFFFEFFFEFEFFFEFFFFFEFFFFFBFDFAF7FAEFB6BEA9
D1DABFD9E3C0D8E3BBE5F4BDDAF2A4C7E58FC7E295D1E9ADDAEEC9E9FAEAF7FFFFF6FFFF
F7FFFFF8FFF3D3E4BACFE1ADCEE0AECEDEB7F3FEEDEFFFFC9ABBC0E0FFFFDAFFFF96C0BF
E6FFFFE8FFFFA9D0CD80A39FF2FFFFEFFFFCC2E1D1D5F6DBBBD5B0C4DEAEDBFABEB7E0A6
8ABC9980AF9DEBFFFFF5FFFFFFFFFAA69C930D0000382924FFF5FDFFFBFFFFFFFFF9FCF3
FFFFEDFFFFE8D8D3BDB0AB98FFFFF3FFFFF4FDFFF4FDFEF6FEFFFAFFFFFDFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFAFFFFF8FFFFF8FFF9F8FCEDF0FFFAFDFBEBEE
0C00005546435D4F44584C36574E2D59542A62622E7B7E47B5BD84DBE6AED5DFAACCDDA6
C8E0A4C8E69ED4F69FCBEF97C4E5A0CDECB0D8F4B9F3FFD8F7FFE8F9FFE1DEEAA8D4E392
819349D3E9A1CCE69FC3DE97CCE89ED6F2A7B4CE84C6DE943D530ACEE49BD3E79FC5D991
D8E9A2D7E8A1CADB94DFF0A9D3E79FC7DB93CADE96D6EAA2E4F8B3C5D994C2D792879C57
819852647E379CB7707F9A53849F58CFE9A2CEE59FCADF9AB6CA856A7B37B2C17ED2E9A3
BFE59CD1FFB2BBE599C9EFA2BDDD91C7E295DDF4A6D7EC9FCADF94D9EFA6BFD9926B8A44
BADF9AC7F0AEC6F3B2C3ECAAABC8856B853ECDE7A0D0EBA4C9E49DE0FEB6D0EEA6BEDC94
CCEAA2D5F3ABBAD890C8E39CCBE69FC1DC95D8F2ABCAE49DD3EFA5CAE89EC4E298CDEBA1
CCE89ECDE99FC8E29998B26989A058C4DB93E7FDB5D3E9A1C6DA93D6E7A1ABBC76536221
C9D69EF9FFCFFFFFD4EFF3C1D6D5A5E3DFAFDED8A8E8E0B1
FFFFFAFFFFFBFFFFFDFFFFFFFFFEFFFFFEFFFEFEFFFEFFFFFEFFFFFCFFFAF7FEEEA2AA92
B0BA97CAD5AADBE7B5CFDEA3CDE39AC8E094CDE3A2DBEFBEEAF8DFF6FFFDF8FFFFF8FFFF
F8FFFFF8FFF4D2E3B9D0E3ACCFE1AFD0E0B9F4FFEEEFFFFE92B6B69DC9CA8BB5B491B5B3
E7FFFFF0FFFF5E7374F2FFFFECFAFBF2FFFFE8FFF3C2DFC9C8ECC6CEF8C6B4E6A7B7EAAF
7FB18C7AA490F0FFFFEDF6F5FFFEF886786D0E000044332CFFF4FDFFFCFFFFFFFFF8FEF0
FDFFE5FFFFE1C7C3A8B5B09AFFFFEFFFFFF1FFFFF3FFFFF6FFFFFAFFFFFDFEFEFEFCFCFE
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFDFFFFFBFFFFFAFFFEF8FFFBF6F5E2DC0D000053443F
0A0000FFFCF0FFFCE9FFFFE3FFFFDCFFFFD1F9FFCADCE5ACCDD89EE2ECB7DAE4B0D6E4AF
D1E6ABCBE69FC9EB94C4E890C1E59FCDECB0DFFBC0F5FFDAFBFFE8F2F9D7D7E29ED6E594
8A9C50D1E8A0C9E79FD4F4ABD2F0A6CAE69BCFEBA0859F55D2EAA0C8DE95DCF0A8D8ECA4
CCDD96D0E19AD3E49DD9EDA5D5E9A1D5EBA2D3E9A0C8DE95CCE09B8297525A6F2AD5EFA8
D1ECA5D5F3ABBFDF96D8F8AFCEECA4D4EFA8CFE6A0C4D89381904DDCE8A6D9E4A2CEDF9B
C9E8A2CDF1A7BBDD93CAEA9ED0EAA0D5EDA1CADF92CFE197DEEFA8D0E49DC6DD994F6928
CEEAAD58773C577841CCEBB0CAE5A2607731CCE69FD5EFA8D1ECA5AFCD85C5E39BD0F0A7
C8E69EBEDC94DAF8B0CAE59EC9E39CD9F3ACC4DB95D1EBA4C4E298C7E59BC9E79DD1EFA5
C9E59BC3DF95D0EAA1C0DA91DCF3AB89A058D0E69EC9DF97DCF0A9CEE29BDDEEA8DDEBAD
848A5AFFFFDAF6F7CD9390655E5A2D5F5729615628AAA06F
FFFFFAFFFFFBFFFFFDFFFEFFFFFEFFFFFEFFFEFEFFFEFFFFF4F8F7FCFFF8F8FFEBDCE7C7
B1BE93E4F2BDD6E5AAC6D89ACCDEA0D6E7B0E1F1C2EBF9D8F6FFF5F9FFFFF9FFFFF9FFFF
F9FFFFF8FFECD3E3B2D1E3A7D2E3ACD4E3B8F8FFF2F2FFFF557E784E7D77305450EBFFFF
EEFFFFEDF9F9FFFEFFF7F4FBFCFFFFF8FFFFE4F3EECEE9D6B5E3BF74B07C5FA465498B4E
376A4186A792EDFDFAFEFFFFFFFCF6CAB8AC382516554339FFFAFFFFFCFFFFFFFDF9FFEE
ECF4CDDFE6BA9F9F7DB3B294FEFFE8FDFFEBFEFFEEFFFFF3FFFFF8FFFFFBFEFEFEFCFCFE
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFF6C5B3A56B5645938272F0E3D2
0F0800D3D3B9D2D8B6FCFFDCEFFDC8D8EAB0D8EAACD2E5A5DEF0B4F8FFCEFBFFD6EFFFCC
E3F7BCCEE9A2BADD83BCE388C5EBA2C8EBABCBE9ABCAE1ADBDC8AABAC09CD4DE99DFEC9A
9BAD61CAE49BBCDC93C8EAA0B6D68BD6F5A9CAE99D89A55AD0E89ED8EEA5C8DC94C8DC94
DCEDA6D8E9A2C4D89093A75F8399509BB36998B0666E863C7B904BB0C580CFE49FC3DD96
C9E49DC1DF97D2F2A9C0E097C3E199CCE69FB1C681859451BDC886DBE1A1D7D99AD5DA9A
727C3D4D59177A854389934E626925929852BABD78E7E8A4D5D595E2E3A7DCDFA6B6BB85
9BA171181F00000700BCC898DAEAAC94A863A9BE79BBD08BDBF2ACDEF8B1C8E39C8BA961
8FAA63A9C47D92AC6598AF6994A96496AB66D0E49FD6EDA7C5E399C9E99DC7E79BD0EFA3
C9E59AC2DE93D4EEA4D3EDA3CDE59B96AE64D3E9A0CAE097CEE49BD1E79ED1E59DB9C789
70764AC0C19FB0B08CB6B48EDCD8B2D9D4AC9B94689E9668
FFFFFAFFFFFBFFFFFDFFFEFFFFFEFFFFFEFFFEFEFFFEFFFFFCFFFDFCFFF6FBFFEDEDF9D5
C3D1A0CBDA9FD4E8A3CFE2A2DAE7B9EFF9D6F8FFE4F9FFEFFCFFFFFBFFFFF6F9FFFAFEFF
FAFFF7F7FFE2D3E5A9D2E6A1D2E4A6D5E5B8F9FFF1F4FFFDE5FFFFE6FFFFE0FBF6EBFFFB
EDFFFDF7FFFFFFFDFFFFFCFFF7FFFFDEF0F0F4FFFFBAD5C6C0F4D0003909266D31A7E8AE
C2F1C7EAFFF0F7FFFFF0EEEFEEDFD89A8778200B00402E22FFFAFFFFFAFFFEFFFAFCFFED
E6EFC2D1D9A6909169C8C8A6E8EBCEEEF2D9F7FAE5FEFFF0FFFFF6FFFFFBFEFEFEFEFDFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFEF4715F4B6F5A3FF9E9CF50492C
313011DBE3BECADBAECFE6B0EBFFC8D0EDAAB8D690D0EBA6DEF7B6E0F5BAF1FFCCE9FAC6
DAEEB3D5EFA8C8EB91CFF69BCCF2A9BEE3A0C6E4A4C6DDA7B8C1A28C906D969D598D9A48
889A4ED9F3AAD2F4AABFE59ACBEDA1C6E69AB2D28686A559D6F0A6CFE79DC6DC93DDF1A9
C9DA939FB36BA2B66E99AF66A6BE74BCD68CCEE89EC8E298D5E9A4DEF2ADC8DD98D1E8A2
CDE8A1CAE8A0CCEAA2D1EFA7C8E39C8AA15B7D8E4AC9D492D0D595E8E8AAACA86B8E8A4D
9F9F639FA162E9EBAAEAEDAAB2B572A6A763757431979655D7D598E9E7AEE3E2ACD7D6A6
5B59301E1C00060300ABAD85D5DEA5ADBC79849551CBDF9AA0B46F859C568DA45ECDE7A0
C9E39CC3DD96E1F6B1D1E6A1CADB97BDCE8A7D8C4961752ECFEDA3CEF0A3C2E296C9E99D
CDECA0C8E499D0EAA0CBE59BC5DD93ADC57B92A85FD4EAA1D5EBA2D3E9A0DDF1A9DEF1AF
C8D4A2D6DFB2CFD8ABD8E0B1DCE2B4EEF1C2D8DAA99C9C6A
FFFFFAFFFFFBFFFFFDFFFEFFFFFEFFFFFEFFFEFFFFFEFFFFFCFFFBEFF5E7FBFFEACFDBB3
B0C18A96A967D5EA9FD6E6A8E7F0D1FEFFF4FEFFF6FAFFF9FEFFFFFCFEFFF5F7FFFCFFFF
FCFFEDF9FFD6D5E69FD3E695D1E59ED3E4B0F8FFEEF8FFFDEBFBF8F4FFFFF9FFFFF8FFFF
EEFFFFE6FDF5EEF3F6F3FBFEE9FFFFE4FFFFEEFFFF8DAC9D5B9171246336A2DEAAAFE5B1
C3ECC2DBF5DCF9FFFDFFFEFFFFFBF3A089791C06002F1C0EFFFAFFFEF7FFFEFFF9FCFFEA
E8F2C0D8E1A896976BE0E0BAD7DBBAE4E8CDF5F9E2FFFFEFFFFFF4FFFFFAFEFEFEFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFEF44130148A7651D5C9A3141000
131A00CEE0B0CDE9AFD1F4B2B4DC93C4ED9FDBFFB3CCF1A4B1D08AE0FABBC0D59DD3E6AF
CCE0A5CCE69FBEE187C9F296C7F0A4BCE19ED0EEAED5ECB67D8667888C67EBF2ACDCE894
B5C77BC1DB92C2E69CC9F2A6C3E89BCAEC9FDFFFB3A6C579D2ECA2C5DD93CFE59CC8DE95
DAEEA6A2B66EBDD189CEE49BD8F0A6CCE69CCFEBA0D3EDA3CBDF9AC7D894DDF1ACCADF9A
D5EFA8BDD891DDF8B1B8D38CC3DA947B8F4AD7E3A1F2F8B8E3E3A5DAD498B8AE734D4409
D7DC9CD4DF9DCED995C8D38EDEE9A4D1DD955F6A25545F1AE0EBA9CFD99CD0D9A2D3DBAA
8E956B1C2200050A00959974DDE5ACD1DC9A838F4D8E9D5A657431889C57ABBF7ADCF1AC
D1E6A1D4E9A4C4D591D6E7A3E9F5B3D6E2A0B4BF7D74833EC6E298CCEEA1C3E397C9E99D
D0EFA3CBE79CCEE89EC7E197D7EFA5CDE59B889E55ABC178D0E69DC9DF96C3D990CCE39B
D7F1AACAE59ECBE69FCAE39FC4DB97D4E9A6D1E1A2687839
FFFFFBFFFFFBFFFEFFFFFEFFFFFEFFFFFEFFFEFFFFFEFFFFFEFFFBFCFFF3FCFFEAD5E0B8
8C9A6797A769D0E19DD5E2AAECF1DAFEFFFAFCFEF9F5F7F6FFFEFFFFFEFFF8F9FEFEFFF8
FEFFE4FAFFD1D2E79CCFE696CCE5A1CCE4B2F0FFEDF2FFFBF5FFFFF7FFFFE4EDF2F0FFFF
DBFFFFDCFFFFCEF4F595B7B894BEBAD0F8EFBDD4CA59766491C7A7A6E7BFB6F3C9B3EBBE
BCEABBE7FFE0D9E8D5EFEFE5F5E7DABEA7993218094B352AFFFAFDFFFCFEFFFFF4FCFFE6
E4F1BBDAE6A6919960DCE2B2D1D9B0E2E9C8F7FDE1FFFFEDFFFFF3FEFFF7FDFDFBFDFEFF
FEFFFFFEFEFFFEFEFFFEFFFFFEFFFFFFFFFFFFFEFFFFFEF3655231AC996EDDD1A9050600
162300CDE4AEBFDFA0C8ECA6CEF2A8C4E99B517223CAE99BD4F0A5C9E29ED3EBB1C8DDA5
D7E9ADBACE898DAA56A3C571C0E49CC7E7A6D0EDABC3D69EDAE1B8999A6ED8DE96D4DD8C
D7E79CD3EDA4C2E69CBFE59CCDEDA2C3E296C9E59B89A359C6DD95D1E99FE0F6AEC9DF96
C7DD95B7CD84E0F6AECBE198CBE29AD5EFA5CCE69DA5BC7494A55F73843E70873FA6C278
839E5792AC6592A963677E38A8BF79D6EAA5D3DE9CD3D898BFBB7E625C207A7438C0C082
D7E2A0D8E9A5D2E6A1D2E8A0CDE39AD9EFA6A5B9717E8F4875823DCDD798E2EAB1DDE4B1
D8DFB55359350007006C744FD6DFA8D8E3A1D3E29FD4E5A1CEE29DCFE49FD7ECA7CBE09B
D0E5A0D1E5A0D6E7A3CFDE9BD4E3A0DEEAA8CEDA98BDCC89B1C77FCDE59BCBE79DCEEDA1
CEEEA3C4E498CCEAA0D0EAA0D3E9A1C5D9919FB06A65762FCEE29BDEF4ABCCE39BD3EFA4
C7E899C2E593CBEE9ED0F3A3D1F0A4BFDB90DFF9B0C8E29B
FFFFFDFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFF9FAF4FEFFF4FEFFEDDCE3C4
8A9269919A6BDAE4B0D1DAADECF2D8F7FBEDFEFFFAFFFFFFF6F4F9FFFDFFFDFAF5FFFFEF
FEFFDCF5FFCBD9EFAECFECAAC8E9B2C7ECC3DEFFEDE9FFFFEEFFFFE7FFFFE9FFFFA6D9EA
9DF0FF31939E227C843A818586AEADDAEFE6DEE9D90013000A3D1C4E916E70B69AA7EDC8
B8F4B8BDEBABC6E3B5DFEAC8E9E1CCAA97894327235E4644FFF8F8FFFEF6FEFFECF5FFD9
E6F8BEE2F6AF7D8F45DAEBA7D8EAB6D6E5BCF9FFE1FEFFEAFBFEEDFFFFF6FEFFFDF8FCFD
FBFFFFF7FEFFF7FEFFF9FFFFFCFFFFFEFDFFFFFDFFFFF6ED614B26B29D70DED4B1010500
001000C7E4ACC8E7A4CBE9A3DCF1AE99A865CDD78EA3AE60D7E695BFD489D8F0B6D3E7B2
97A165485110D4E59F8FA45F455E1DD0E9A8D5EAA9CCDA9CDFE3A89E9E60DBDD94DAE194
D6E499CEE69CB9DD95CBECA5CAE19BE0F1ABC6D7938A9B55596D28CBDF98D4E9A4CBE199
AFC47FCDE39BCBE09BCBE199DAEFAAC9DF97CFE49F2236008E9F58DAF0A5BFE496C4ED9E
CCECA1CBE59ED6E7A3D6E6A5DAEFACBFD290D8E2A37374382D2700605C1F8C9552DFF0AA
CDE39BC6E099CBE9A1CCEEA4CEF0A6CEEEA3CDE49CD6E69F585E18E3E2A1D7D197E8E1AD
E6E1B74A4A26000500707A55D8E7AEC1D590D5ECA6DBF5AEC7E59DBCDA92DDFBB3BCD790
D0E7A1C3D792D6E7A3D6E7A3CDE19CCBE09BD6EDA7D0E49F585E1ED4DB98D6E7A3CCE89E
C9EDA3BFE89ABDE197D3F1A7DBECA8CFDA96919757646B28D0DC9AD4EAA2BBD991CAEFA2
C0E598CCF1A4D3F5A9BBDD91CAE89EC4E298CFEAA3CEE9A2
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFCFDF8FCFEF3FCFFECEEF2D9
B7BC9CB0B690E6EDC3E9F1CAF5FAE3F8FEF0FEFFFBFFFFFFF8F6F9FFFEFBE6E7D7E8EDCD
ECF9C4E8FCBDC9E4A1B6D999B6DEACC7F3D0E2FFFDE3FFFFDFFCF8BCD9DD93BDCB72B3C7
1E81940D7E8E4CBBC4479C9FDFFFFFF0FDF4FCFFEFC5D8BC6B9A76195A384C967B95DFBA
A5E7A7BAF2A9CAEDB3C6D7ADFCF8DF938177492F2E462D30FFFBF8FFFBEFEFF5DBEEFDD4
D3E6AEC7DC999FB668CCE299C0D59DC8D9AFF6FFDFFEFFEAF8FBEAFAFCF1FDFDFBFCFFFF
F9FFFFEDF6FDF8FFFFEBF4F9FBFFFFF9F8FDF3EDF1FFFCF1594219A18C5DDDD7B7000700
283F15C9E7B1CCEBA7CFE9A2CBD799A7AB6EE2E29CB5B668D8E28CEFFFB0C5DFA29CB37D
959D61DEE3A3D6E2A2D2E4A6CCE0A3ABC183C2D595DFEBA9DCE19EB6B7716E7027A6AC62
D1DE96DDF4ACD6F7B2C7E8A3DBEBAAD3DE9CAFBB796F7E3B869552D6EAA5D8ECA7CEE39E
D8EFA9A4BB75CEE39ED7ECA7D5E9A48FA35E70813DD8E9A3CBDB92D1E99BCBF6A4BAE794
C6E89CD1E8A0D5E1A1D5E1A1C6DB9AF1FFC56771324A4B0F8A8448D7D598E2F3ADBFD990
D9F3AACFEBA1C5E69FBDE199BDE39ABFE399C6E097D6E89E5C5F1AB9B472EBE1A4DDD49D
E3DFB2454720000900596942CEE2A7D5ECA6C7E29BC9E9A0C4E69CC4E89ED5F5ACD2F0A8
E0F7B1C1D691EBFCB8C8DC97D0E5A0CBE59ECBE9A1CFE49F868648D0CE91E2EEACCFE9A2
C3E99ECAF4A8C5EBA0C9E79FCFE09CD7DD9DC9C98B6C6E2FDAE5A3D0E5A0C4E69CC6ECA1
C4E89ED6F8AECCECA3CDEDA4CEE9A2D1ECA5C4DF98CEE9A2
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFDF9FAF2F9FBEDFFFFED
DDE1C6C3C9A7E4EAC4FEFFE4FEFFF3FCFFFDFBFFFFFEFFFFFEFFFDFEFFF4D4DDC0D3E0B2
C4D996D0EC9FCCEEA1C5EDA7A8D2A083AE907FAAA17BA3A244615D3A585856818870AEB9
2A828E4EB3BDB6FFFFCAFFFFE0FFFFF4FFFBEBF4DFD0E3C5BDE5C0C0F9D0AFF1CB1A5F32
2C6E3094CC8BCAEFBCD7E8C4DAD5C28D7A731D05054C3336FFFAFAFFFEF4E7ECD6DFEDCA
CDDFAFCFE3A8C5D89676884ADEF0C0DBE9C5F8FFE4FEFFEDFDFEF0FFFFFAFEFEFEFEFFFF
F9FEFFF7FFFFF8FFFFF6FDFFFCFFFFF9F7FAFFFCFFFFF8ED5F4C229F8F5EE5E0C0010A00
566D41C7E6ADCBEAA7CEE7A3D5E3A6A3A76CDADB979A9D50E4F09A8699485F793CB8CF97
C8D496ECF5B4CFDD9FD5E9AACEE4A6829A5C667A3B687736D0D996E5EBA58A8D46AAB269
CDDD96BCD68FBCDF9BC4E4A1CFDF9E8D9856B4C07EC7D693ECFBB8C8DC97C5D994D9EEA9
D1E8A2A1B872D5EAA5BCD18C859954CCE09BD8E9A5C6D791E1F1A8C9E193CBF5A3BBE895
CBEDA1D3EAA2E3EFAFDBE5A6778A4A405313818A4BEFEFB3E1DB9FE1DFA2D1E29C8CA65D
7D934B92A961A7C57FC5E69FDAFEB6D7F9AFCCE89ECDE29796A059A2A560ECEBABD3D299
D2D8A85B683D00120062794FCBE0A5CCE19CDFFAB3C0E097D1F3A954782E73934AABC981
D0E7A1B5CA857A8B47D8ECA7D5EAA5C4DE97CCEAA2CFE49FB6B8799F9F61CDD997D1EBA4
C1E59BCCF6AAC6ECA1C8E69ECCDD99D2DB9AC9CB8C757A3AD9E5A3D2E7A2CBEDA3CBEFA5
D1F1A8ADCB83BFDA93D3EEA7CAE19BCDE49EDBF0ABC2D792
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFAFFFFF6FFFFF1
F0F4DDD1D5BAE2E7C7FFFFEAFEFFFAFEFFFFF5F8FDFCFFFFFBFFFBF9FFEFCDDEB4CDE5A7
CCEB9BC9ED95C3ED97C3EEA68AB683446F545078777B9EA47D97969EBBB7E1FFFF79B3B7
428D9347979E80CBD0BCF9FAD0F4F0EAFFF4F2FFEBD5E8CAC9E9C0B4E2B3B0EAB76CAD75
1F602677B0797DA478D6E9CBFFFDEE8E7C78200A0C4D3739FFF8F7FFFEF6F2F6E5E3EDD2
DEEDC6D7E7B8D4E2AD677542BDCCA5D3DEC0FBFFE9FFFFF1FFFDF4FFFEFBFFFEFFFEFFFF
F3F8FEF9FFFFF8FFFFFBFFFFFBFCFEFFFEFDFFFCFBFFF7E7635227A59967E2DFBE000700
647B4FC6E5ACC9E8A5D0E9A7B9C68E8C9157E5E7A69AA1548F9D485F7523A2BE81CAE3AA
EAF9B8BDCA85D7EAA8CDE3A3B5CF90BBD5968AA060657838A2AF6A9AA45F89934C86924A
D8ECA5E0FBB6C7EAA8D3F3B2C9DC9A949F5DDEEAA8D7E6A3D2E19EBED28DDCF0ABCEE39E
90A7619BB26CC6DB96CBE09B9CB06BCDE19CD6E7A3D8E9A3CEDE95D3EB9DBFE997C3EE9C
D0F0A5C9DF97C1CB8CB1BB7C4558184D6020EDF6B7D9D99DDED89CDEDEA09DB16A6C863D
D7EBA4D3E7A0B4CB87ACCA84BAD993BBDB92C7E399D7EDA2A6B36B8E9851D8DF9CDEE8AB
D6E4B193A97B000D005D7A4ED2E7ACCEE39EBED891617F378EB06652742A92B269ACCA82
C1D892B6CA85576824DBEFAAD3E8A3C4DE97CEECA4CEE59FD1D696616123A0AC6AD2ECA5
C3E79DC5EEA2C0E49AD0EEA6E7F8B4D8E1A09297577F8545C7D391CAE19BC7E79EC8EAA0
C0DE96E3FDB6CEE59F5E752F96AB66A6BA75D7E8A4DBECA8
FFFFFDFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFEFEFFFFFFFDFFFFFAFFFFF4
FFFFF1ECEFDAE3E7CEFBFEEDFFFFFFFFFDFFF6F6FFF8FDFFF8FFFAF5FFECC4DFAACAECA2
CDF69AC3F18EBBEA8CC1F0A2A0CC997FA78FABD1D4E7FFFFEEFFFFEAFFFFCDF7F3558C87
86C2C09EDADA73A9AB3561626A8D8986A296F4FFF3C3D6B8C4DDB3C9ECB6C2F3B2A4DF9F
B2F3BBA7E0B300170093A78EF0F1E391847E392526493536FFFBFAFCF8EFFCFFF1F4FDE8
F2FFE3C8D6B3D8E2BDD1DBB8586146A8B099FCFFEEFFFFF4FCF9F4FFFEFFFBF9FEFFFEFF
FCFFFFF8FDFFFBFFFFECF0F1FFFFFDFFFEFAE8DDD9FFFDEC5C4F22ABA470D3D4B2000800
5D7748CCEBB2C9E8A5D1EAA9919E68CAD19BDEE2A5C8D087909F4CB6CD7DD7F5B5C4E0A5
C8DD98D4E8A0D3EAA4CFEAA7CFECACD3F0B0D4EEADC7DD9CD0E49FA4B46DAABA718FA059
C3DA94DAF9B5B7DC99B8D8978DA05E8C9755DBE7A5D4E3A0D4E3A0D8ECA7DEF2ADC1D691
61783297AE68ECFFBCC8DD988B9F5ACEE29DD3E4A0CEDF99CBDB92DFF7A9C5EC9BBFEA98
CAEA9FCBE199626C2D646D2EB5C586C3D394DAE3A4CACA8EEAE4A8959557889C55C7E198
D0E19BD9E8A3B9CC8AC2D995DBF6B1D0EEA6D0EAA1D3EB9F9AAC6292A259D5E49FD1E4A4
D3EAB4C2DFAF00120067885BD1E6ABADC17C738A44849F58AACA81CDEDA4CDEDA4B9D48D
D0E5A0CEE29DCADB97C7D894CFE39ED4EBA5CBE9A1CDE49EDCE2A25A5C1D8B9755D4EBA5
C5E79DC7EDA2C2E69CCEECA4CEE29DD3DE9C858B4B9DA665DFEEABD2E9A3DEFEB5BBDD93
ACC67FA8BF79B4C9847A8E499EAF6B8E9D5AC9D593DBE7A5
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFDFFFEFEFCFBFCF6
FFFFF6FEFFF2DADDCACECEC2FDF8FEFFFCFFFFFDFFFCFFFFF8FFF8F4FFEAC2E0AAC9EFA2
BDEA8BC1F48DBBED8CC1F0A0C1ECB7C6E9D1E5FFFFEBFFFFF1FFFFDDF8F3A0C9C1CAFCF3
DEFFFFDDFFFFD0EFF287A3A65B7B783A584EEDFFF2F2FFE9E7F6CBC7DFA5C5EDA4CBFFB8
B5F4BFA4DEB64B7253768C75DFE1D3968C8322100C2A1814FFFCF6FEFAEFFEFFF4F2FBE8
FBFFEFE2ECD4E6EBD4F8FDE6707561BBBFB0FFFFF6FFFEF9FFFAFAFFFCFFFDF8FFFEFDFF
FCFFFFFBFFFFFBFFFFF5F7F4FFFFFAFFFAF2FFFCF3CFC3AD7C7646C1C08AD3D9B3021200
5F794AD1EEB6C8E5A5CBE1A3869260FAFFD1D3D89ED3DD98E7FAA9CCE594B3D28FCFEFAE
C3DD93D5ED9FC7E398CAE8A2C9E8A4B9D895C4E19FD3EEA9CBE29CCFE59CCDE398D5EDA1
B9D58BCAEBA4CBF0ABD5F5B293A6649DA866CAD694C4D390D1E09DD1E5A0CDE19CE2F7B2
90A761C2D993C2D792C6DB96C0D48F93A762C3D490DEEFA9D3E39AD0E89ACBF2A1BBE593
CBE99FE3F7B0394203616A2BD3E1A3DFEFB0DAE3A4E7E8ACBFB97DAAAC6DC2D890D7F1A8
D5E6A0DBE8A3A5B574ABC07DCFE6A2C6E099C9E098CAE095899E5393A55BD9EDA6C7DC9B
D2EBB4CBE8B80015004A693DD2E6AB92A661788D48BED891C8E69EC7E59DD1EFA7DEF8B1
D1E6A1DFF0ACB2C17ED0E19DCFE39ED3EAA4CCEAA2CCE39DDEE7A693985892A15ED4EBA5
C4E49BD1F5ABCEF0A6C3E199D7ECA7D5E4A1818C4A55601E7F904C667D37A1C17876964D
647E37B0C580CFE39EDBEFAADEEFAB8594516E7A38CFDB99
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFAF9FEFFFFFFFBFBF9
FFFFFAFFFFF8DFE1D6CFCCC5E3D8DCFFFBFFFFFDFFFEFFFFF9FFFAF4FFEDC3E1AFCAF2AB
C8F69CCAFC99B7E98AB5E192C1E6B0D3F1D5E7FFFDE1F4FBE3F2F792ABA8396158DCFFFC
E8FFFFEEFFFFF8FFFFF2FFFFE9FFFFB7D6D0F0FFFAF5FFEBF3FBD4CEDBA3CAEB9CB8E89C
BAF6C292CCA695BE9E50674DCBCEBD776D613221175B4A42FEF4EAFFFFF3FEFFF3F1FAE9
FBFFF3FCFFF3FAFCEED1D2C4DDDDD1F4F4EAFFFEFAFEF5F6FFFCFFFFFBFFFDF7FFFFFEFF
F4F7FEFBFFFFFCFFFFFEFFFAFCF8EFFCF2E6ECDCCD7D7256BAB885D5DDA4D5E0B8061800
688050CBE6AFCBE5A6C8DDA2909C6ED0D7ABE0E9B4CCD898D9EE9FC2DD8CDCFDB8C5E9A3
D7F7A4BCDA84CFEE9ECFEFA3C7E6A0CDEEA9C5E4A0D0F0A7CBE79DD7F3A6C3E090DCF9A9
C9EA9BC8EA9EC5EBA2BFDE98A6B6759EA967E6F2B0DDECA9D3E29FD8ECA7C6DA958A9F5A
C1D892D0E7A1C9DE99ECFFBCBACE89425611DFF0ACD2E39DD2E299CCE395C0E796C6F09E
CAE89ECADE976B7133A7AD6FD4E0A2D2E0A2C7D091B4B579ADA76BEAECADCAE199CCE89E
CFE39CD3E29D94A4639FB270D2E7A4D1E6A1D8EEA6D8EDA28B9D53708238A4B56FDDF0B0
D3E7B2CBE1B3000B001B320887965DA3B470CEE29DDAF1ABD8F3ACBDDB93D3EEA7C3DA94
CADE99D8E9A5445310DFF0ACD3E7A2CBE29CCDEBA3CCE69FDBE6A4CFD59594A360D5ECA6
C4E49BCEF0A6D0F2A8C4E29AC2D792DAEBA7DCE8A6C7D391E1F5B0C9E09ADEFCB4BAD890
CAE49DD4EBA5CDE29DCADE99C9DD98DBECA8A4B370556421
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF6F5FBFFFEFFFFFFFF
FBFBFBFFFFFDFAFBF6FFFCF7BEB0AFFCECECFFFBFFFBF9FAFAFFFAF5FFF3C2DCB5CAEEB1
BCE798C2EE97BFEB94D5FBAEE6FFCEECFFE2F4FFFAF5FFFFF5FFFFA8BBBF51766FCFF3E9
E8F8F5FCFFFFFCF7FEFEFEFFDAEFF2EAFFFFEBFFFAF1FFEBFFFFE1D9E0AAD2EDA0C4F0A3
A7E1AE8BC59F001000B9D0B4DADDC8A19A870D00002F2212FDF4E3FFFEECFDFFF0FCFFF3
FAFFF2FEFFF3FFFFF6D5D2CBFEFBF4FFFFFAFFFCFDFFF8FBFFFBFFFFFBFFF4EEF8FFFEFF
FCFFFFFBFFFFFAFFFBF9FAF2FFFFF3FFFDED0E0000645939DCE1ABD2E0A5C7D6AB000C00
677F4FC1DAA1D1E9ADD1E4ACBEC99FD9E1BAD4DDAED6E4A7D4EB9DCCE997C0E19CC7EBA3
C3E58ECEF195C7E993C5E697C8EA9EC5E79DC5E69FC9EB9FCCECA0CAEB9ACDEF9BBEE08C
D4F7A5C2E595C2E79ACFEDA5DFF0AC414C0A98A462D9E8A5CBDA97CEE29DE6FAB5869B56
CCE39DD9F0AAD2E7A2C2D792DFF3AE4C601B97A864D1E29CD5E29AE1F8AAB3DA89D9FFB1
C2DE94889953A0A467D6DA9DD9E5A7D4E0A2DCE2A4AAAA6E969255CFD192DEF5ADC2E096
D3E9A1D3E49E8A9A5994A765CEDE9DCDDE9AD4E59FD2E49AE2F2A96E7E3553621DE0EEB0
BAC694DAE5BB0712005B6540D2DDA5E0ECAAC6D793D6EDA7CAE49DD0EBA4CEE8A1D5ECA6
D3E7A2D0E19D51601DCDDE9AD3E7A2CEE59FCAE8A0D0EAA3D4E09EE6EFAE869552D6EDA7
C8E69EC0E097C8E89FCDEBA3D3EAA4CEE29DD4E5A1D5E6A2CBDF9AD1E8A2C5E099D3F1A9
D4EFA8C2DC95D4EBA5D0E7A1D2E7A2CCE19CC7DB9695A964
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFEFAE8D6CCF0DACFFFFAF7FFFCFAFFFFFFF9FFFAC9DBC3C0DBB2
CDEFB3BCE098C8EA9ED5F4AEE9FFC8F8FFE1FBFFEDF6FDF5F8FFFFC6D7DEADCBC9D7F2ED
FBFFFFFFFDFFFFF1FCFFFBFFF4FFFFE4FEFDF0FFFFF4FFF0FFFFE3E0E7B4BBD58CC8F2AA
91CA95397249B1D7B2CEE3C2D6DABF756F55291A05483C26F5EDD8FFFFECFEFFEDFCFFF1
FAFEEFFFFFF6FFFEF8DDD5D2FFFEFBFCF6F6FFFAFDFFFBFFFAEEF8FFFBFFFBF5FFFFFEFF
FCFFFFFBFFFFFCFFFAFFFFF4FBF5E5FFFEEA5F4D359E9471D1DAA1CEE2A5CADDB0001000
5F7544CADFA7DBEFB4B4C58FAFB996DEE5C4D7DFB6CEDDA4D6ECA3C9E696C6E7A0CDF1A7
C8EC92C4E98AC9ED93CAED99C5E599C9E99ECBEDA3C4E699C9EC9CCEF19DB9DD85D8FCA4
CBEF98C9EC98CCED9CC5E196D5E49FB4BF7D869250CDDC99DEEDAACDE19CC8DC9792A762
D7EEA8C0D791D6EBA6D6EBA6CBDF9AD3E7A29DAE6AAABB75D3E098D6ED9FC5EA9AC6ED9C
CEE89FB3C27D97985CE1E2A6D9E3A6D6E2A4D3D99B5E5E22949053DBE0A0CCE69DC6E69B
D3EDA4C9DF9799AE6B8C9F5DD6E6A5D1E09DCEDB96D9E69ED1DD959EAA624D5613A0A66A
E0E2B3E2E0BA070100767151D9DEA8DAE5A3CFDE9BD4E9A4C9E09ACCE69FD7F1AACDE29D
D4E5A1C6D59254601ECCDB98D9EDA8D0E7A1C8E39CCBE59ED2E19EA4AF6D7F904CE0F5B0
CFEAA3C9E79FD0EEA6C3E199CFE9A2CFE6A0CBE09BD1E5A0DAEFAAD2E9A3C4DF98C3E199
CEECA4C8E69ED1ECA5D8F3ACC0DB94D4EEA7CFE9A2CBE59E
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFDFAF6E3D4897260FFF9F2FFFBFBF6F1F5FBFFFFF8FFFAF5FFED
C9E3B4C8E4A9CFEAA7D3ECAAD2E4AADEEABCF6FBDBFAFEEFFBFFFFEEFBFFE4F9FCF2FFFF
FEFFFFFFF6FEFFF2FEFFFAFFF7FFFFF1FFFFE5F9EEF6FFF2FEFFE6CCD5A8C8E2A38CB573
376E376DA274C1E6BBD4E8C3D4D8B7A29B7E2F21074C3E24B1AA90D3D1BAF2F6DFFEFFEF
FEFFF2FFFFF6FFFEF8E1D7D5FFFCFDFFFDFDFFF6FCFFFBFFFEF2FCFFFBFFFFF9FFFEFFFF
F6FAFBFBFFFDEFF7ECF6F9E8FFFFECFAEED45D4C30A69D76D8E6ABD1E9ABC5DBAC000B00
667846D0E3ABC3D299758151B7BE9FFAFFE6F3FDDAD2E0ADCDE49CD0ED9DCDEDA4BDE295
C8EF94C4EC8CCAEE96CCED9CC6E49ACBE9A1D3F3AACFF1A5C0E595D2F8A3C6ED94BFE68D
C1E58DCBED97CCE997D7EDA2D1E09BD1DC9AB4C07EC4D390DBEAA7C7DB96D5E9A4CDE29D
B0C781D1E8A2D2E7A2C9DE99CFE39ECFE39EC7D89496A560748139C7DC8FC7EA9AC3E898
CBE29AD3E09B636327ABAB6FDAE2A6D9E3A6D9DDA066662A9B975ADFE4A4CDE79EC6E89C
BAD88ED8F4AAC6DD99A3B674CFDF9EDBE7A5DDE8A4D9E59DE0EAA3B3BD769FA66353541A
393206B3A68442301A3B2C0FE1DFACDDE6A5DAE6A4D5E9A4CEE39ECAE19BDAF1ABC8DD98
D1E29EB6C5824E5A18D0DF9CD6EAA5CEE59FCAE59ECCE69FC3D490CCDB989CAD69D0E5A0
CDE7A0C6E19AC8E39CE0FBB4C9E49DD0EAA3D6EDA7CFE6A0C4DB95C4DE97D4EEA7E1FCB5
CDEBA3C8E89FC3E199CDEBA3C1DF97CFEDA5C8E69ECCEAA2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFDFAFFFCE8CAB19BFFFAF1FFF4F5FFFBFFFFFEFFF7FDFDF8FFF4
C9DAB6D3E7B4C9DFA1D1E4A4CBD8A0D3DBAAFFFFDFFFFFEDF9FDFEF9FFFFF5FFFFF7FFFF
FDFCFFFFF9FFFFF9FFFFFCFFE8EEECF7FFFBF4FFF3EDFCE5F2FFDFCADCB2D7F8C34E7941
275C2497C795C6E7B8DDEEC4CBCCAA9C93743121073E3016B9B298D1CFB8F0F3DEFEFFF1
F9FBEDFFFDF4FFFDF8D8CECCFFFBFCFFFDFDFFF8FEFFFAFFFFF9FFFFFCFFFFFDFFFBFFFF
FBFFFFF9FFFAFBFFF4F2F7E1FFFFE6ECE1C36B5B3A9D966AD2E4A6CFECACC6DEAE000B00
6C7D49DDECB5C7D19C687144B9BDA4FAFFE9F8FFE2D6E6B7CFE6A0D1EDA0D1F1A6C3E598
C1E88FC0E78ECCED9CCFEDA3C7E29FC5DF9EC9E6A4C6E5A1C5EA9DCDF4A3CAF29CBAE089
D2F49ED4F19DCAE191D1E399D7E49FDBE6A4D2DE9CCFDE9BD0DF9CDAEEA9D8ECA7CCE19C
657C36AEC57FD1E6A1CDE29DD6EAA5CDE19CE2F3AFB5C47F7B8840ABC073CCEF9FC9EE9E
CEE59DDEE9A5454308868449DEE4A8D8E0A4D2D6995C5C208E8C4FD6DC9CCAE69CC7EDA0
CDEFA3D7F7ACBFD89495AA67B6C584D1DD9BD8E39FCFDB93D6E29AD3DD96DCE3A09F9E65
51481D7767466C513E120000E5DFADD5DB9BC6D18FE2F3AFD0E49FCBE09BCFE49FD0E49F
CFDE9BA3AF6D4A5513D8E4A2D1E5A0CBE29CCDE8A1CCE69FE5F9B4D3E4A094A863C7DC97
D9F0AAD4EEA7C1DC95C5E099D1ECA5C8E39CCDE8A1CFEAA3CCE69FD5EFA8D3EDA6B9D38C
C5E39BD3F3AAC4E49BC9E9A0C7E79ECDEFA5C0E298CCEEA4
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFAFFF2E0FFFBE8C3B0A9F5E6E9FFFAFFFFFCFFEDEEF0FBFFF6
F7FFE4F8FFD9D3E5A9D9E9ABD1DEA6D1DAABFFFFE1FAFDE8F6F8F5FBFEFFFBFFFFF6FAFF
FDFCFFFFFDFFFFFDFFFFFBFBFFFFF6FCFFF1F9FFECD4E5C5D0E6C2CAE9C0C3EABE275524
7AAC77BEEAB5DAF6C6E3F0C58E8B682315001B09004E3E27E8DDC9E5E0CCEEEFDDFFFFF3
FBFBEFFFFFF8FFFAF8C7BDBCF9F1EFFFFDFDFFFCFFFFFCFFFFFBFFFFFDFFFFFEFFF9FFFD
F9FFFDEAF6EAF9FFF1EAF0D6DDDABBE0D6B36D5D39888252C7DD9DCBEBAACBE3B3000C00
677542DAE4AFDAE3AE969B72EDEFDAFFFFF3FCFFEAF4FFD8E3F9B8C6E295C5E399CBEB9F
CCF29FD1F6A6E6FFBCF0FFC8E4F9C0D8EDB5D2E9B1C9E5A8C4E7A3BEE499C1E897C2E895
D4F3A3C4DC8ED9E9A0D4DF9AD1DC98DFEAA8D6E2A081904DD4E3A0CDE19CCDE19CDCF1AC
89A05A9BB26CC3D893D5EAA5D4E8A3CBDF9AC7D894D4E39ED8E59D889D50C7EA9ACAEF9F
D4EAA2D2DB98585319979258D6DA9FD8E0A4E2E6A978783CA9A76AE5EBABC8E69CBDE698
C6EB9ECCECA1CCE5A1ABC07D95A463909C5AAEBB76E5F2AAD8E89FD4E49BD1DC98DBE1A5
B1AD80564726371E0A170200595321575C1C5A6322C4D390CFE39EDAEFAAC7DB96DCEDA9
D3DF9D939F5D485311DEEAA8CEE29DCAE19BCEE9A2CAE59EC7DC9791A560869A55D4E8A3
CBE09BC7DE98D1EBA4CEE9A2C0DE969CBC738EAC6489A75F87A25B97B16A89A05A536A24
96B16AD1EFA7CBE9A1C9E79FCAEAA1CEF0A6C1E399CCF0A6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFBFFFBEDFFF5E8A49494FFFAFFFFFAFFF8F2FCFFFFFDFCFFF1
FBFFE1F7FFD2D1E3A5D8EBABD4E3ACD2DFB3FCFFE8F5F9E8FEFFFAFFFFFFFDFCFFFEFDFF
FCFFFFFBFFFFFCFFFDFDFFF4FFFFECF6F5D7F8FFDBD6E8BEBCDDB2AED8B0BFEECA54875E
76A674C0E7B2D1E8BAFEFFDFB7B19136240C2712004A3728E8DCCEE5DFD1E9E9DDFDFFF4
FFFFF8FFFEFAFFFBFBD1C5C5E3DBD9FAF5F2FFFCFDFFFCFFFFFDFFFDFBFEFEFFFFF9FFFD
F6FFF9E8F6E7F9FFEFE6EFD2D3D3B1E5DDB65C4D249B9865C9E2A1C8EBABC8E3B0000D00
606D38CDD4A0DDE1AEB3B38DFFFFF1FFFFF6F5FDE8F9FFE1E9FFBFC4DF92C5E196CFEDA3
BFE197C4E4A1DDF6BCEDFFCEE3F2C7D7E6BDD1E3B9C9E1B1C7E6ABC7ECA9CBF1A8D2F4AA
C9E59BC0D48DFAFFC1D5DB9BDCE5A4CFDA98CDD997AFBE7B8A9956D0E49FD2E6A1C8DD98
D5ECA6ADC47E899E59CBE09BD4E8A3D7EBA6C9DA96DEEDA8DAE79F859A4DC0E393C4E797
D1E59ED5DE9B645F25A8A369DDE1A6DBE1A5DEDFA36D6D319D9B5EDCE2A2C8E69CC6EFA1
C2E79AC1E196D4EDA9D1E4A2B6C28297A36196A560D6E89ED4ECA0C5DD91D8EFA7CBDB9C
CCD2A2928E69100100100100A6A370969859787E3E9EAA68D1E29ED1E5A0CDDE9AD3E4A0
D7E3A18E99574C5715E2EEACCFE09CCDE29DCCE7A0CAE59ED1E8A296AB668EA25DCDE19C
D1E5A0D3E8A3D5EFA8C5E0996E8E457B9D53AACA81C9E9A0CBE69FD0EAA3C1D6918EA35E
576E28C4DB95CFE9A2C8E39CC6E49CCEEEA5C8EAA0CEF0A6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFFFDF6FFF5F1EEE3E7FAF0F9FFFBFFF8F6FBFFFFF8F9FFE7
D2DEB0D7E6ABC8DB99D0E5A4CBDDA9D1E1BAF8FFEFF9FFF6FEFFF8FFFFFBFFFCFFFFFCFF
F9FFFFF2FEFEF5FFF8FBFFEFF6F1D3FFFDD6D9DDABD6EAB5CAF4C2B4EBC1C0F7D8437957
275524BCDFA9BFD2A5FFFFDFD6CAB06954411D06002E170FF1E2DBFFF6EFFDFAF5FFFFFB
FFFCF9FFFDFDFFFBFDF7EBEBD5CDCAD6D1CDFFFCFAFFFDFDFFFCFDFDFDFDFCFFFFF9FFFB
F7FFFAF5FFF4F8FFEDE5EECFE9E9C5E3DCB24D3E13ACA976CFE8A7C5E8A8C3DEAB000F00
6B7541D4D9A3DFDFADB1AE8BFFFBEFFFFFF8FAFFF1F4FFDEE4FABAD1EC9FD5EFA5CAE8A0
CDEDAECFECB4E7FDCFF9FFE3FCFFE6F8FFE4F9FFE8F5FFE4C7E3B3C7E8B1C7E9ACCAEAA7
C7E09ED2E0A2DCE0A587884E969F60737E3C6E7A388A995652611ED0E49FE3F7B2CADF9A
CDE49EC9E09A6B803BD2E7A2D7EBA6CFE39EDCEDA9C4D38E919E56B9CB7FCCED9EC4E797
CCE099E7EEAB5651179D975DE0E4A9D9DFA3D6D79B626226929053D1DA99C5E59ACAF3A5
D1F6A9C4E298C9E09CD4E4A3DBE7A7D0DC9AA0B16BBCD488C4E395C9EC9CD5F7ABD2EFAC
D5E7B3D2DAB16C684D080200E2E0ADCFD1929BA161505B19C9DA96C4D893E8F9B5D7E6A3
D9E5A3909B59515C1AE0ECAACEDF9BD1E6A1CAE59ECBE69FD5EFA8BCD38D90A56097AB66
BFD38ECCE19CAAC17B90AB64C3E39AC2E49ACEF0A6CCEEA4C1DF97CDE7A0DCF1ACD1E5A0
4F631ECADE99DAEEA9D2E9A3C8E29BCAE8A0C9E9A0C7E79E
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFF3EFF0FDF7FBFFFCFFADA7B3F9F6FFFFFFFDFEFFEFF4FED9
D4E1A9D1E5A0D2E89FD0E6A5C5DBAACEE1C1E7F9EBF4FFF8F7FAEFFFFDF4FFFBFFFFFCFF
F7FFFFEDFFFFEEFFF3F7FFE9FFFFDAFFFDCBC4C488C9DDA0B2E3AB85C497609F84185033
4D784AD6F4C0D1E0B5F6F6D48C7D66160000140000412726F4E2E2FFFCFDFFFEFDFFFFFF
FFFBFCFAF4F6FFFBFFFFFBFBDDD8D4BBB8B1FFFDF9FFFDFAFDF9F8FFFFFDFCFFFDF8FFFA
F5FFF8F5FFF3F2FFE6DEE9C7DDDFB8D3CEA47B6C418C8954CBE5A4C6EAAAC6DEAC000E00
707944E0E3AEE1DFAEA39F7CFCF5EBFFFFFAFCFFF4F7FFE2DFF3B6D2ECA2D6F1A4C0DB96
C8E5AFC6E1B6DFF0CEF9FFEAFDFFEEFCFFEFFBFFF1F7FFEDD0E8C4C1E1B2C4E5B0C6E3A9
D6EBB2E0EBB39B9B676B6A34DFE5A7D0DB99A4B06E4B5A17B9C885B8CC87CBDF9ADCF1AC
C3DA94DEF5AF8A9F5ADAEFAAD4E8A3BBCF8ACCDD999BAA658B9850D9EB9FD1F2A3CBEC9D
D0E49DD7DE9B605A20A19B61D3D79CD9DFA3EBECB086864AB4B275E4EDACC5E59ABEE799
C5E79BCFEBA1D7ECA9D6E6A5D3DF9FC8D7949AAE67D1EDA0C5EC9BCBF8A5AFDB8CCAF4AC
C2E1A8C8DEB0CED7B80A0E00D6D6A2DFDFA1A9AF6F525D1BE6F5B2D1E29ED9EAA6C6D592
D7E3A1949F5D545F1DD9E5A3CDDE9AD6EBA6C8E39CCDE8A1C8E29BDBF2ACD4E9A4BFD38E
CBDC98D4E8A3CDE49ECDE8A1CFF1A7C6EAA0C1E59BC3E59BC8E69ECFE9A2D2E7A2D0E19D
788442DAE6A4DAE9A6DCEDA9CEE39ECAE49DCEE9A2C5E39B
FFFEFFFFFEFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFDFFFEFFFFFFFDFFFEFFFFFFFF
FFFEFFFFFFFFFFFEFFFFFFFFFFFFFFFAFAFCFFFDFFA5A2ABFFFEFFFFFFFAFCFFEAF6FFD6
D8E8A9C9DF96D1E99DCFE8A4D0E8B6E4F9DAF1FFF8F7FFFFFEFFFAFFFEFAFFFAFFFFFBFF
F0FFFFE7FFFFE1FFEDD7F5D1D7E0B5CAD19ED5E6AFD2F1B8568551002300002B0293CB9E
C0E9AFCBE6AFCFDFB8FDFFE5A99C8B23070049201A6A4441CBB9B7F7F1F1FBF9FCFDFCFF
FFFEFFFFFBFFFFF6FDFFFBFFF0EDE8B2B2AAFFFFFAFFFEFBFBFAF8FFFFFDF9FFFBF7FFFA
F5FFFAE8F9E9F8FFEFF1FCDED3D4B2E5E0B8E3D4A97C7946C7DFA1CEF0B3CEE6B6000A00
646E39D8DDA5D8D8A2918F66B0AF9BC6C8BAD2DCC4D7E9BFC8E19FC1E092D0F1A2C5E79D
C7E6AAC6E2B1DFF4CDF9FFECFEFFF3FDFFF7F9FEF7F3FFF3F4FFF3E6FFE1F1FFE4F1FFDA
F9FFDAF8FFCF9D9B6BDAD8A5D3DDA0D5E4A1D0DF9CD5E6A2C7DC97DCF3ADD7EEAAC6DB98
D6E5A4D0E09F96AB68C0D995CFEAA5CEE7A3D2E2A1AFBB79C2CF8AC9DD95C1E196CCEAA0
DAE9A6B4B979807E43BABA7EDDE5A9D6E0A1D8D99D656728909656CEDA98C8E299D2F2A7
CBEA9EC9E59BC9DE99D3E6A4DDECABCADA998BA159CBE79CC6EB9BC0EA98C9F4A5CDF5AE
C5E4A9D5EBBCD8E6C20A1200DAE1ABE6EBAB908E535E5E20DAE4A5CFE09CC2D691DFF0AC
D4E09E97A26054601ED1E09DCDDE9AD9EEA9C6E19ACCECA3D1EFA7BCD88ED5EFA8DAF1AB
C9DE99D2E7A2DAF4ADC4DF98CAEAA1C9EBA1C4E69CC7E99FD1EFA7CDE8A1C7E19ACFE49F
8B9C58D1E29EC7D894D4E9A4CFE6A0CBE59ED5F0A9CEECA4
FFFDFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFF
FFFDFFFFFEFFFFFDFFFFFFFDFCFFF8FCFFF8FBFBF9B6B4B5B9B8B6FFFFF6FDFFE6EBF7C9
CFE4A3CDE79DCCE89BC7E59FC8E0AEF5FFEAF8FFFBF4F9FDFFFEFFFFFCFFFFF7FFF9FDFF
DFFFFFCCFFEEB6EEC9A1D4ABB1DBB379A37D467A5693C29EBBDFB9C3E8B5BCEEA7BAEB9A
C6EB9BD4EEADF3FFE6F9FFF231281F1D000079372BA86A5DFFFCECFAFFF4EAEAECFFFEFF
F7F8FCFDFBFEFFFAFFC5BAC0DADADAFBFDF8FFFFFBFBFCF7FFFFFDFEFFFDF8FCFDF8FFFF
F1FDFBF5FFFFF6FFF8E1E8D6F4F2D9746B4A5C4D24E9E3B3CDE2AAC3E1AB637C52000A00
D9EAB3CFDD9FDAE6A48B965AD1DCB2D6E4C0C7DAADCEEAAFC0E595C8F39ABCE996C3F09F
C0EA96C9EB9FD9F2B8EDFFD7FAFFF0FBFFFCF8FDFFF6FDFFF4FFFFF3FFF9F5FFF1F8FFE8
FBFFDFE7EFC090905EDFE2ABD8EBABC6DD99D2E5A3D1E6A3D0EEA8C2E19BD9F4B1D1E1A2
9C9D63ADAE74B2C585D3F4AFB8E69DC4ECA5D8EAACA5AD72D3DFA1EFFFC2BEDD99C8E3A0
767A3F78763DBEC488D3E1A3CFE2A0D1E1A0B5B97CA2A868A8BC77D1E79FB3BE7ADCE9A3
CEE69ACFEB9ED0EAA1D0E7A1E2F7B4BED39095AA67CDE49ED6EEA492AA606C833BCADF9C
D1E3A9D2DEAEDBE3BA465126C4D89DE7F1B2A4935F5F4B16DCDDA3D7E7A6D2EBA7D0E7A3
DDE8A697A05FC2D18ECBDC98DEEDA8D3E7A0BAD88ECBF0A3CCF2A5BEE395C4E69ACDEDA2
CCEAA0C6E298C8E49AC7E399C7E29BDAF8B0CAE8A0C6E49CCDEBA5BBDA94C5E49ED3F2AC
93B16BBEDC96D3F1ABC9E8A2C5E49EC9E8A2C9E8A2C9E8A2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFFFDF9FFF4FBFFF6F9FAF5F4F3F1DCD8D7CDCAC1FFFFEADAE5BB
D1E5A8CFE9A2CFEDA3CBE8A5C6DCADF4FFE7FBFFFAFCFFFFF4F3F9FFFDFFFFF9FFF6FFFF
DDFFFF82C7A883C1985D986A336C412A643C377856A4DBBBD3EECBCFE7B3C4EE9AC8F596
BEDF88CCE5A4F4FFEDF9FFFB2B241E1B000079291E9A5142FFF2DEEDF5E6FFFFFFEFEEF4
EBECF0FFFFFFFFFAFFCFC4CCF4F4F6FCFFFDFEFFFBFCFDF8FFFFFDFFFFFFFBFFFFFBFFFF
F8FFFFF4FFFFDDE6E1FEFFF6FEFCE7857C5D64552EBDB688CFE1ADC5E1AE627851000B00
D7EAB2CADB97CEDF988FA05CC0CE9BC3D5A5D2E9B1C8E7A3C6EE98BFEE92BCEE99BDED99
C4EC93C6EA93D1ECA9E4F7CAF8FFECFCFFFDFCFFFFFBFFFFF5FCFFF8FFFFF6FFF3FBFFEC
E9F1CCDCE2B4B0B07ECED19A6B7B3DDDF2B1CFDFA0C4D797D3F0AEC8E5A3BDD192B6BE85
524815B8B07FD6E3ABC0DEA0B7E4A1CFF6B5BDCA94A4A674D6DFA8C0D298C9E3A6C1D598
2F2C0088814BD7DFA4D4E7A7D4EAA9BFD2908A9052CED796D1E8A2BAD1897A7F3DA1A663
CEE398CAE99BCCE89DBED992BFD894A8BE7D9AB16DD5EAA5A2B66F65762F43520DD2DE9E
D8E3A9DCE4B16C7349465423D2F0B2CFE2A2816B39B49A69ECEDB3BED392C1E09AD1EFA9
CAD9969BA765C3D792D3E8A3CCDD97CBE199DAFCB0BFE89AC0E99AC0E798BFE496CFF1A4
CFEDA3D1EDA3D0EAA1DEF5ADC9E09AC9E09AC3DA94CFE9A2CEE9A4E2FDB8C9E7A17B9953
A5C07BCEE9A4D9F4AFC6E19CC8E39ED7F2ADD5EEAAC9E29E
F9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF9FFFF
F9FFFFF9FFFFF9FFFFF9FFFDFBFFFAFCFFFBFAF8F9FFFDFFFCF5FCAFAAA7FFFFF1F8FFDE
E5F6C2D9EFAFD1ECA9D0EAADCDE0B3F6FFE8FCFFF8FEFFFBFEFFF6F7FAF1FFFEFFE4F2F3
C5F5E937765BC2FBD2ABE1AFBDF0B8B5EAB2ABE7B4CCFFCFCCE8B8C3DBA1BFE695C1EC93
D8F5A5CCE0A5EAF9E4F7FDF93228262F070582332C82382DEFD9CBFFFFF6F7F5F8FFFDFF
FEFFFFFFFEFFE2D5DFCCC0CAFFFDFEFEFFFBFFFFFBFBFAF5FFFEFAFCFBF9F8F9FBFCFFFF
F9FFFFF8FFFFFBFFFDFFFFF6FFFBE7BBB092513F19A0986AD3E4AECBE6B163784F000A00
DFF0B9D0E19DCFDF98AAB9769EAB76D3E3B4CFE4ACC1DC99CBEE9AC1E990C6F1A1C1EA9C
CAED99C9E696D1E5A8E6F3C8FCFFEAFFFFFAFFFEFFFDFCFFFEFFFFF1F6EFFCFFEFF0F7D8
F5FAD2D1D3A4373303F0EDBA1F2200010800374009758048DAEBB4D0DFA8B1B381544D1F
1B08006A5D33DFE2B3C1D39F35521C637A462B2C00383309AAB080D4E1ACD9EAB363703A
1E1A004C4614D4D9A3D3DEA4A9BB7D9CAC6DBEC889D2DD9BD2E6A17F904CBFC484949B58
D7EDA2C4E596C7E69ACEECA4DAF5B0C4DD9B95AE6A90A761B7CD85C4D890889953ADBC7B
CFDDA2DEE8B48A9368364816C5E9A9C9E4A181743FE1CD9AD1DB9ED6F3B0C5EBA2BEE29A
92A762D7EBA6D4EEA7CAE59EEEFFBDCCE89EB4DD8FBCE798BEE596DCFEB1C9E99DC5E498
C0DA91D6EDA5C6DA93CEDF99DAEBA7D9EAA6DBECA8D5E6A2C7DA98CCDF9D94A966BCCF8D
D5E1A1D5DFA0D3DD9EDBE5A6E0E9AAD2DB9CCBD495D8E1A2
FBFFFFFBFFFDFBFFFFFBFFFDFBFFFFFBFFFDFBFFFFFBFFFDFBFFFFFBFFFDFBFFFFFBFFFD
FBFFFFFBFFFDFBFFFFFBFFFDFAFFFBFFFFFFFFFDFFF9F1FCFFFBFFCFC6CBD8D4CBFFFFEC
FCFFDDDFF2BBCDE2A7CFE4ACD2E3B9FBFFEAFAFEF0FAFEF0FBFFE8E2EDCFFEFFF6CBDAD5
A7D3C6114930B9ECC1BFEEB7BBE8A7C1EEABBAEEACBAE8A8C2DAA0D6EAABD4F9ABC5EB98
CAE199D0E1ADF9FFF3FEFFFF1F11112100009F524CBF756CEFD3C8FFFAF4FFFDFFFCF7FD
FFFFFFB1ADAEDED1DBCEC1CBFFFEFDFFFFFAFFFFFAFFFFFAFFFEFBFFFEFDFFFDFFFEFFFF
E1E4E9FBFFFFF2F7F3EFEFE5FFFFEC9C917372603C9B9062D5E2AACFE6AE64764C000A00
E5F4BBD9E8A5D5E29CC9D5939EA874E9F5C5CCDDA6CAE19DCDEA96C9EB95CCEEA2C6E89E
CFEB9ECEE59DD7E6ADEAF2C9FCFEE8FFFFF4FFFDFAFCFBF7FFFFF8F5F9E8F4FADEEAF0CC
E3E6BBDDDCAC6A6434C8C08F8E8657080400636735E3EBB8CDD5A4C4C6975F532B88744F
2B13007D6A49DEDCB5E5EDC4020F00C4CAA43B3211130900414419E2EABBDAE2B156592A
2D29000A0300E9E9B7E6EBB595A066DBE9ACCDD99BCBD797D8E7A6A3AF6DE7ECACAAB370
CCE498C3E495CBEB9FCDEDA4C8E6A0C8E3A0C6DF9BC4DE97D2E8A0D8EEA5B9CA84627231
95A368A5B27D596237273706C4E4A5D3E8A7675320FCE2B1D6DA9FCBE1A0CDECA6C9E7A1
849350C0CB89CBDC98C6D793D5E29DD1E29CD0EEA4CFF1A5C5E498D9F5AABBD58BD0E89E
CFE59DE1F2ACC9D691E7F2AED3DE9CDAE3A2D0D998D9E2A1CCD697BFC98A808C4CD8E1A2
CACE91BBBC80B5B579C4C488C6C68AABAB6FA2A065B6B67A
FFFDFDFFFEFBFFFDFDFFFEFBFFFDFDFFFEFBFFFDFDFFFEFBFFFDFDFFFEFBFFFDFDFFFEFB
FFFDFDFFFEFBFFFDFDFFFEFDF8F6F7FEFCFFFFFBFFFAEDFEFFF8FFFEF0FDCAC0BFDDDBCC
FFFFE4E4F1C5CFE0ACD0E0AFD3DFB7FCFFE8FAFDECFAFFE8F8FFD8EAFECBE3F0D6CADCCE
97C0B058886EA5D0A3C6ECB1C3E79DC2E797C7F2A3C3E79DCBE09DD4E7A5CCECA0BDDD92
C6D999CED9AEFCFFF6FFFEFF2010132D0305BE7370F3AAA4FFEEE8FFF6F3FFFCFDD7D1D1
95948FD2CFCAFFF3FDFFF9FFFFFCF9FBF8F1FFFAF4FFFEF8FFFCFAFFFAF8FFFCFEFFFEFF
FEFFFFFCFDFFF9F9F7FFFFF6FFFDEAA5977A66522F9D9063D4DFA3CDE1A6647447000900
DDEAB2DBE7A5D5E09BD7E29ECAD39EA4AC7BD7E4ACDDEEAACEE593D1EA97CDE7A0C7E09E
D1E8A2CFE4A1D6E3ADE3EAC1F1F1D7F9F6E5FFFBEFFFFFF3FFFFEDF2F6DBF0F8D1DEE5B9
D2D6A4E4E4B2A39D6BF4E9BBE3D0A6796C4247481C5A6233DCDFB4F5EDC65C4324F3D4B8
654A2F140100E7E1C1D2D1B2060300474024EADAC14F4126090900D1D3AB5D58305C542D
B9B48A625D33C9C296DCD8A9B0B37ECED79ED9E9ABE9F9BACBD397888C4FE7EBAE85904E
D0EB9EC8EB9BC8E89CC5E59CBCDA94C8E3A0E0F9B5E0FAB3D1E79FCBE198C5D690DCECAB
97A56A99A671F4FDD2404C1CA7B67DA8A76E8C6337B88B619E8E5ACBCF94626C2D7F8849
76703463591E605A1E898347BAB073B4AC6E838846899651A1B56D859D535A7027869A52
7D8C47616E293B44017279364E53138688495456177D7F405E5F2375763AB0B17597985C
A1A163B4B476B1AF729E9C5F9E9C5FA2A0639A96598F8D50
FFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFEFB
FFFEFBFFFEFBFFFEFBFFFDFDFFFDFFFFFAFFFFF4FFFFF9FFFFF0FFFFF8FFFFF5F7C0BAAE
FEFFE6EBF3CCDBE8BAD7E5B4D3DEB4FEFFE4FFFFECFFFFE4F5FFCFCBE5A6C0D4AFC9E1C9
496F5A8AB597C1E5B7CFEDAFD7F2A5BFDB87CBEA9ACBE59BD1E09DC9DA96CBE79DD9F4AD
E6F4B9D9DFB9F8F9F1FFFCFF39252743191ABE7773ECA5A1FED5D1FFF7F5FCEEEBC3BCB4
FFFFF0FFFFF3FFFAFDFFF1F7FFFDFAFFFDF7FFFEF8FFFDF8FEF3F1FFF6F6FFFCFFFFFDFF
FFFEFFFFFFFFFFFEFCEFEBE0FFFFECEADBBE140000A29666D9E1A5CEE0A46C794D000A00
D2DCA7DCE6A7D6E09BDAE3A0E4EBB739400DC1CA91D6E39ECEDF8FD2E594D3E6A4CDE1A4
CDE8A5C8E2A1CBDEA7D4E1B5E0E7C5EAF0D4F5FBE1FCFFE8F2FFDCDCEDC1EAFCCACADDA5
D6E5ACDAE5AB898E58DAD6A6E6D7AEEEE5BC818F5E001200D8E1B4E5E1BB614A2BAB9075
7A6B4C0702006D7150E2E7C73534180A0400E8E0C96F6A4D0D0D0072704A5E4E2DA89876
DAD2AD726D459F936BADA177999565D6DDA7DDEFB3BFD193ECEFB687854CC9CA909BA765
CDE89BC8E99AC5E498D2F0A8D4EFAACFE8A6CEE5A1B4CB85C9DD96DDF1A9E8F7B2C6D594
C7D29879834FA3AA8028310296A36B9691597A4F245C2D036C5825E9E8AF959E5FCACE91
897F44EADBA2E4DA9FA89E63C2B277FAEBB0D9D596D4DB98DBECA5D5EBA2BDD189D8E9A2
DDEAA5E1ECA8CED592E6EBA9E7E9AAD9D99BD5D396ABA96C98965BE9E4AADCD79DE3E1A6
D2D797E4EAAAE3E9A9D6DC9CD9DE9EDCE1A1D6DB9BD2D797
FCFFFAFCFFFAFCFFFAFCFFFAFCFFFAFCFFFAFCFFFAFCFFFAFCFFFAFCFFFAFCFFFAFCFFFA
FCFFFAFCFFFAFCFFFAFEFFFBFFFEFFFFFBFFFFF1FEFFF8FFFFF1FFFFF1FDFFFBFBB8B0A5
FFFFE5E8EEC8D3DFB1CDD9A9D1DAADFFFFDFFDFCDEEDF4CBD9F2B1CDEDAAD7F2C5B6D1B2
587B5D9DC19DD7F3C0C4DA9ADBEDA3C6D789DFEFA8D4E3A0DEE8ABD6E4A6CFE69ECFE4A1
DCE5B0E4E5C3FFFFF6FFFCFD2D18172000009E5B53EFAAA3FFDBD7FFF6F1A7978AC6C1AD
FFFFE5FFFFEAFFF2EBFFFAFAFFFDF8FFFEF6FFFDF6FFFCF6FFF1EEFFF9F8FFFBFDFFFAFF
FFFDFFEDEBEEF8F4F1FFFFF3FFF8E3EFE0C1CFBC94A39564DAE0A0CDDB9E727E50040C00
C6CE9BDDE5A9D9E29FDAE0A0DDE2AC6064317D8248B4BE79D1DC8DD6E296DCE6A9D1E4AC
C6EBA8BEE8A6C3E6ACCFEDBBD9F4C7DDF6CCDEF7CDDEFBCBDDFFC8CFF7B9B6DF9BC3EBA4
BDE19BD0EFACD6F0B1293B01D1D3A2E0E8B7C5EBB06C995E001600505D2F58502BCDC5A1
656D46051A005F7A51B7D0A9303E1D000600D4DFBF949E7C1C2000797353684E35856B50
B3AB87514D273D2F0A71623BACA476DADEABBED496D6EAABDAD9A1D7D099CBCC929AA664
B9CF84CBE699CBE59BD3EDA6CBE29EC0D594D6E9A7DCF0ABD8E7A2CDDD96CDD894DCE6A7
F4FCC3626936D3D5AD3F4819C7DFA3E9F3B66E5222F2D2A3F5F0B8C8D698D1E8A4C5D896
DADF9F9595577479399FA162949051B8B777E1E8A5D5E49FC8DC94DAF2A8D5EBA2C9DD95
C9D893E1EEA9DDE6A3D0D794D0D293C4C486757336B6B275E4DFA5D7D197F1EBB1D0D094
D4E3A0CBE29CC9E09AD2E9A3D8EDA8CADF9AC6DB96D6EBA6
FFFFFAFFFFFAFFFFFAFFFFFAFFFFFAFFFFFAFFFFFAFFFFFAFFFFFAFFFFFAFFFFFAFFFFFA
FFFFFAFFFFFAFFFFFAFFFFFBFFFCFBFFFBFEFFFAFFFFF0FAFFF8FFF2DFE3DFD0CBA19A8A
FFFFE2DCE3BABBC495B4C08ECAD2A3FFFFDAECECC6C5CCA093AD6ECFF3B3ADCD9E284821
89A9848DAC80B6CD95C0D393CBD692BCC282C4C790989A69A8AF7CC6D199BFD38EA3B372
D2D5A6D2CFB0E9E5DAEEE3E1240D071C0000874D41E1A197DFAAA6B69087CBBBA4EDEAC9
CED4A8DBDDB6EADFCDE7D8D1DCD3CCE4DDD5F8EDE7F6E9E3E5D6D3EDDDDDF3E4E7DDD2D6
FEF8FCE7E3E4E1DED9E3E0D1FFFEE4AC9F7DCFBC92AA9E6AD1D696C3CF9170774D000600
B9BF8FD9E1A8DBE1A1D6DC9CD5DAA4ECF0BD42480C9BA25CD6DF90DBE398DCE1A9D4DEAA
CEE7ADC9E7ABD3ECB5E6FAC9F1FFD4EAFACDD8EABACBDFAAC6E2A5C8E7A3CEF0A6CAEA9F
CDE8A1CCE5A1CDDFA14C551CE2DAA90606005C7B3FC0E8AA0014006F774665562F7E6E4A
1B2000000A005C7347D4E6BEA0A483282708373D1B4B512F0B0C00A79E7F694B3371563B
38300C2521001101006B59339B8F65D9DDAADAEFB4CFE3A6E2DFA8A197627B7C42838F4D
D6E7A0D8EEA3C2D88FD0E49FDEEEADD2E2A3DAE9A8D5E19FDAE5A1D5DF9AE1E8A5D6DC9E
9699628F9160E3E1BA000800D1EDB0C4D9986B5724E8D19FDCE2A6CFE8A6C7E8A1CEECA6
D2E19EE9F4B2C8D492D9E5A3ABB06EA2A966D1E09BCFE59DD0E89EC6E096D1E99FDAF0A7
D3E7A0CBDC96D7E49FDFEAA6DDE3A37479399B9B5DABA96C929055A8A369BBB57BD9DDA0
CDE7A0CEF2A8C6EAA0C1E399C9EBA1CDEFA5C8EAA0C6E89E
D1B8BBDAC1C4E1C8CBE3CACDE0C7CAD8BFC2C9B0B3BBA2A5B49B9EEAD1D4BEA5A8B0979A
DBC2C5F1D8DBD1B8BBF0DCDDE7DDDBF3EBE8F0E5E3F1E1E1F6E4E2DECDC5B6A9998C866C
E4E4C0C9D1A28B95618A9761C9D19EDFE5B5BCBD917E86574D683187AC7692B889002300
83A276516C39B0C688A2B273889055969565B0A7889C957B777858969F72BCCC8DABB97B
A2A377B8B497F0EADEE1D7CE4630231D0000431201C08678B97E786F43368E7E5DB7B988
97A165BBC48DC2BD9FD1C5B5B7B0A6D7D0CAEEE5DEE5D8D2D1C2BFCFBFBFDDCFCFE8DCE0
B9B3B5D0CCCBC6C3BCD5D2C1A49F82837A53A7996A7E733D7C7E3D979F647F845C010500
7A7F569299659BA367929B5C969D67AAAF795F6527545A149CA3559B9E57BEBE8AC1BE91
9F986ADBD0A2C8B990A99570B29A78DEC6A2C2AC83BCAC7BA1985F9A9555B9B673A3A05D
9C9455AEA469B4A36F664B1CFCD2A84524004F4E16666F36403A068F784CAD7F5DC49675
937954584A23827950EBDDB8B6997B6F4D314E3316231000241E00E0D7B663452B503518
A39B776B674133230099875FA3986BDFE3B0CFE4A9D0E4A7DFDCA5BFB580A0A167A8B371
DCECA5CFE197CFDF98D7E6A3D8E4A4D3DFA1D3DD9ED5DE9DE3EAA7E0E5A2CFD190EAEAAE
54511CA19D6EEAE2BD010700C9E7A9C9E2A0625520F0DFABC9D597D0EFABC8F0A7C4EAA1
CCE19CD5E6A2DCF0ABCBDF9A808B47899450C1D58ED8F2A9CCE89DCAE99DCCE89DCCE89D
CDE79ECFE69ED1E59ED3E49EDAE6A4485311545A1A8388488B8C50A1A165817F44D4DD9E
C9E9A0C2ED9EC2ED9EC3EC9EC3EC9EC3EC9EC3EC9EC3EC9E
FEE1E5FFE7EBFFEBEFFFEBEFFFE9EDFFE5E9FADDE1F1D4D8FFE6EAFFF6FAFFE7EBFEE1E5
FFEAEEFFF6FAFFE8ECFFF5F4FFFDF6F1EDE2FFF8EEFFFDF1FFF9EAFFF5E0CAC1A2A09C76
C7CA9DDCE4B1D1DEA6D2DFA7D8E2ADCDD5A2D4D6A7D6DFB2C2DCADC7EDBEB9E2B6001100
D7F4C4C3DCA3CFE5A5DDEDAFECF3C0F7F2D2FFF4EAEEDFD8C9C7B8D5DCBBE4F1BBD4DDA4
E2E3BBDEDAC1FFF9EBFFFDF39782714A2B1748220BAE7E6AF8BCB48D5C4DD8C9A0E0E6A8
D9E9A0CCDB98DFE0B6F5EFD9F5F1E6FFFDF7FFFDF8FFFBF7FFF7F4FFFAFAFFFBFBFFF9FA
FFFDFDFFFFFBF6F6ECFFFFEDFFFCDBE6E2B5E6DCA77D7439A3A363B6B9808F916C070700
B1B590B8BE90B5BE8599A3679BA46FA8AF79999F5F81873F777E2E9A9D56C6C6948B865C
C0B386B09D72D2BB92E3C7A0D5B491BD9D77BFA479AF9967AF9F639F9452B2A964A59C57
A09555A6965BAB96617A5B2C6F4218856131635D2374783B7B723B98814F91663C72451E
B2956BA29163B6AB7D65572A886C459777515F411D6B55306F6A44B9B48EAA9172563E1C
827A53959267AB9E74AA9B70776F40797E48A9BF817B8F5094935BCCC58FC4C58BA0A968
98A55F9CAC63C4D18BCAD694A0AA6B9CA669C3CC8DD5DB9BC9CE8CB6B976929252E4E2A7
5C5622BAB385D6CCA8121500CEEAADCADF9E64531FEFDBA8D4DEA1C7E6A2B4DC93C3E9A0
C9DE99D4E3A0D4E8A3C4D591757E3B99A25FCADE97D2ECA3CAE99DC9E99DC9E99DC9E99D
CAE89ECCE89ECDE79ECFE69ECEE29DDFF0ACD3DF9DD4DF9DD7E0A1E6ECAECED295364200
C9E9A0C2ED9EC3EC9EC3EC9EC3EC9EC3EC9EC5EB9EC5EB9E
FFFBFBFFFBFBFFFBFBFFFBFBFFFBFBFFFBFBFFFBFBFFFAFAFFFBFBFFFBFBFFFBFBFFFBFB
FFF3F3FFFBFBFFFBFBFFF7F2ECE8DCFFFFEFFFFFECECE4CDF0E5C7D4CAA6555124939361
DDE5ACDAE5ABCDDCA1E7F6BDF8FFD0E3EDBBDDE0B5D7DFB6D3ECC4B7DCB38BB88F002600
E8FFD5DEF5BDBED796D6EAAFF4FBD2FFFFEBFFF8FDFFF5FFFAF9F5FCFFEFFEFFDCFDFFD5
FFFFE3FCF7E3FFFFF3FFFDF1B5A38F3F270F371C01A77E6ADFA099703B29E6D8A7D1DD95
D3EB93C3D889D4DBA8ECEBCFFFFFF4FFFEFBFFFDFAFFF9F7FFFBFAFFFBFAFFFBFBFEF6F4
FFFEFBFAFBF5EFF1E3E2E4CCE1E3BCD9D9A7DDD89E585415E4E4A4CECE9AEBEACB030300
FAFDE0DFE6BDD8E2AED7E2AADFE9B4CCD79DDDE8A4D6E1938E97469DA35BDDDDABE9EABE
DCE1ABD6DBA3FFFFCEFFFFD2DED6A8E1D9AAEDEAB5DADB9FDEE8A1CEDC8FD5E696D5E696
DAE89DD6E09BDDE2A2D3CE946C5D24DDD499D4E5A1C4DE97E1F5B0DBE1A1DFD49CAB9E67
E0DEA5DAE2A6CDDD9FCDDD9FD7DCA2E4E3AB636029D1CE9BE5E7B8D8D7ABEADBB462532A
CFC89CF5F1C2D8CD9F857A4C5C592660682F97A96DF9FFCDCED19865632A4D4E14D6DF9E
C8D58F697930879750D4E09E949E5F3A4407596223A2A8685459175A5D1A646424B5B579
5B5823A8A475A8A07B040500D1E5AAD7E1A4785C2CDABB8CE8E9AFDAF0AFC9E8A2DCFAB4
DCEBA8DDE6A5DBE7A5DEE9A79B9D5CD9DB9AE4EFABBED28BCAE99DC8EA9DC8EA9DC8EA9D
C8EA9EC8EA9EC9E99ECAE89EC7E19ADDF4AEBCD08BD2E39FE3EFAFCED899E3ECAD3E4D0A
CDE7A0C9E99EC9E99EC9E99ECAE89ECAE89ECCE89ECCE89E
FFFAFBFFFEFBFFFCFDFEF9F6FFF6F7FFFCF9FFFCFDFFFEFBFFF9FAF5F0EDFFFAFBFFFEFB
FFF6F7FFFCF9FFFCFDFFFBF7FFFFF3FFFFEDFFFFE8E9E4C4DAD5ABE9E6B366652D969C5E
D8E2A3D2E2A3CDDFA3EAFBC4F7FFD4E1ECC1D9DFB9CDD7B2C4DDB6ACD0AA719F788EBB92
EFFFE0CAE2B0C6E2A7CBE2AAEAF6D0FFFFEEFFF7FFFFF3FFFFFEFFFBFFF8FDFFE4FFFFE3
FFFFEBFFFEF2FFFDF4FFFAEFC6B5A33D29111F0B00846350BF7E7A783E30F2E7B1D5E696
C7E585DEFAA3DBE8B2EFF4D6FBFEF3FFFFFDFFFEFBFFFAF8FFF7F5FFFAF8FFFBFAFFFAF7
FFFFFBFEFFF8FCFFF1D9E0C1D2D9AFD6DBA3E9E9A962611ED2D093F6F4C4AEAA91030200
DFE3CCCCD3B1D0DCACCBDAA3C5D39EE2F1B6E7F7B0C3D18295A34EA8B067ACAE7DD7DDAF
D5E4A9D2E5A5B2C083EEF7C0D3DAA4D1D8A2CBD599DBEBAACEE69AC8E593C4E690C6E892
D1EE9CCDE89BD1E79FDDE9A7B8BA7B9CA360D7F1A8C1E397CEF0A4BFD990D4E09EA0A666
CFDA98D7EBA6CBE9A1D0F0A7D9F4ADC8DD98ADB876C8CE92D5DCA6CED29FDFDBAB56501E
AAA774D8D5A2E4DEAAE1DEA9D9DCA3434D11B4C486DBEBACC9D195D0D499E9EDB2E6ECAC
D7E79EC7DC91D5E9A1DCEDA9CDDC9BDBE7A9E9F5B5D6E19FD2DB98BDC480B3B876737438
5B5B25908E5EABA781030600AFC388C3CD907056257F6333C7CB90C4DD9BC0E49CC0E19A
C6DA95D3E29FD6E7A3C5D49159601DA1A865CCDB96D7EEA6CAE99DC8EA9DC8EA9DC6EB9D
C6EB9EC6EB9EC8EA9EC9E99ECCEAA2D4EFA8D9F0AAC7DC97D5E5A4DEEDACD0DC9C8E9D5A
CFE69ECDE79ECDE79ECDE79ECDE79ECFE69ECFE69ECFE69E
FFF7FCFFFBFDFFFAFFFFF9FBFFF6FBFFFAFCFFFAFFFFFBFDFFFAFFFFFBFDFFFAFFFFFBFD
FFFAFFFFF7F9FFF6FBFFFCFBF9F9EDECEFDAFFFFE6F1F1CBE3E3B1E0E1A5565B19909C54
CCDB96CFE4A1D3E9ABEBFFCAF5FFDAF1FDD9F1F8D9DBE6C6D0E6BFBFE2B882B28ADBFFE5
F0FFE8C6DCB5D3F1BDC6E2AFE5F7CFFFFFEDFFF9FDFFF5FFFEFEFFF9FFFFF7F9EBFFFFEF
FFFFF6FFFFFAFEFAF7FFFEF8FFF2E281725D150A003A1E10A666677D4338E6DDA6CBE18E
BDE07CCFF097CCDDA6DEE7CAFAFFF9FCFFFFFFFEFFFFFEFDFFFBF9FFFDFBFFFEFBFFFFFB
FAFDF6F7FFF0F8FFECCEDAB6D6E2B2DCE6A9D6DE954B4E07E1DFA4DCD7ADCEC9B6040200
FFFFF1FCFFE8E3F3C6DCEEBAD7EBB6CADEA1C6DA92E2F5A3E7F9A3BAC67C666D3A929A6B
CEE1A1D4EAA28B9E5ED2E0A3D8E3ABD9E4ACE1F1B3BBD08DC9E59AD0F3A1C5ED95C0E890
C4EA95C8E99AC4E096CFE49FE3EEAC54601E94AB65C6E69DC4E89EC7E99FCCE39B9AAB65
98A560CFE09ACCEAA0C6EC9FBDE495C5E498D5E09B959A58DDE5A9D6E0A4E2ECB08E9458
3E3C0378733BD1D298DCE2A6D1DD9FE0EEB0939F61C9D595E2F1B0DBE7A7C9CD90D6DC9C
D3E89DCDE89BC8E298CFE6A0D1E8A4C4D998C0D391D3E4A0DDECA7D1DE98E7F4AF8E9859
D0D89FE7EBB9DBDDB5000900C6E6A7D9EFAE988B56685824D5E8A8C7EFA8C8FDAFBAEDA0
CBEFA5C6E69DCBEFA5D6F8AE8DA45CCEE59DC7E99DBBE093C9E99DC9E99DC9E99DC8EA9D
C8EA9EC8EA9EC8EA9EC8EA9ED4F4ABB8D68ED0EAA3CFE6A0D3E6A4CDDD9C8B9A59CADB97
D0E69ECFE79DCFE79DCFE79DCFE79DD0E69DD0E69DD0E69D
FFF6FAFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFF7FBFFFBFFFFF9FDFAEFF3
FFFBFFFFF5F9FCF1F5FFFDFDFEFFF6FCFFEFFDFFE3E8EAC2E3E6AFB5BA784C560DB8C679
D9EEA3CEE59FC4DDA3DEF6C4F7FFE4F8FFEAFCFFEFCEDBC1CEE3B8B9DDAD8BBE957AAB8B
D5F1D8D3EACDCDEEC3BCDEACD3ECC2F6FFE4FFF8F5FFF1FBFBFFFFF8FFFFFEFDFBFFFEFB
FFFEFFFFFEFFFDFBFEFFFEFBFFFDF1B4A8980C0900110000A6656D90534ED5CE98CEE793
D8FE99C0E48AD3E8B0E8F5DBF9FFFBF5FDFFF7F8FAFBF9FAFFFCFCFFFEFBFFFEFBFCFDF7
F9FFF5F9FFF3F7FFEBD0E0B9D6E4AFD9E8A5CEDB8C6870256B692EA29D77817B6D17140F
EAEEE0F6FFE7DEEFC5C8DFABC8DFA9CDE5A7D5EDA1C7DF8BCFE38CE0F0A5A6AE7B778353
889D5A425A0EB6CA85748445808E53E3F0B8C7D99DD9F2B0C2E096CEF3A3C3ED97C0EC95
BFE693CBF0A0C4E498C9E39AD2E1A08793537D8D4CDDF6B2C7EBA3D3F9AED4F2AAC6DC94
B6BF7CD8E59FC9E59ACBF2A3B5E08EDAFDADD1DB94C4C581ADB673CDDC99CBDF9ACDDC99
4C4A0D938F52EAF0B0CCD896CFE39ED5E5A4B7C182656F30A1B472D2E2A1E1E5A8D9DF9F
C6DE92D4F5A6C9E99DC1DF97D4F2ACD2EDAAC7E09CD9F0AAD2E8A0CBDF97D2E69F8D9D5C
D4E2A7DEEBB6C6CFA4000A00BFDD9FD1E6A5A59561655521D6E6A7BFE7A0BBF0A2B9EC9F
C7EDA2C7E99FCCF0A6BFE197809A51C0DA91C8EA9ED9FEB1CAE99DCCE89DCAE99DC9E99D
C9E99EC8EA9EC8EA9EC8EA9EBDDD94DAF8B0D7F2ABC3DA94C3D895DBEEACB3C281D5E9A4
CDE79ECCE89DCDE79DCDE79DCDE79DCDE79DCFE79DCFE79D
EFF3F4F8FCFDFCFFFFFCFFFFFAFEFFFAFEFFFBFFFFFAFEFFFAFEFFFAFEFFFCFFFFF4F8F9
FCFFFFFCFFFFFCFFFFFAFFFBB2B9B16B7461696E50868C6092975DB7BE78CCD98AECFDAD
D0E69BCDE6A2CEEAB0E4FED1EDFFE2F3FFEDF7FFF2D1DDC7D2E8B7C4E7AFAADFB5326346
CEE9DAEFFFF4E7FFE7C8EFC0E0FFCFF9FFE3FFFDEFFFFBFBF9FFFFF7FFFFFDFAFFFFF8FF
FFFBFFFAF8FFFFFEFFFFFBFFFFF6F0C2BAAD0707000E00008F4D5BA86B6AACA473C9E591
CEF894B8E087D1E9B5E4F4DAF7FFFDF7FFFFF9FDFEFFFFFFFFFEFDFFFEFDFFFFFBFDFFF9
F8FFF5F8FFF3F5FFECD0E5BAC7DAA2CCDD97D0E290B0BB6D74733A68623EDAD4C80A0603
FEFFF8F9FFEFF5FFE1F4FFDAE5FFCBC6E3A3D0EC9FD1EB94CFE68CD4E798DCE8B6D4E2B1
E1F6B1C1D98BD6EAA3D2E2A1B3C186616E36B3C589D0E9A7C4E29AC8ED9FC0EA96C9F59E
C1E895D0F5A5CBEDA0D1EBA2D3E1A3DFE9ADA5AF73CCDC9DBDDC98BCE098C7E6A0D1E5A0
9193529FA462E2F8AFB3D88AD5FFAFC4E797CCD28A94914C78823BD9EEA3C5E194CEE499
5D5C1B7F7A3ACED794DEF2ABD8EFA7D5E9A4CCD292BFC8877F9652A6BD79E1E5A8D5DB9B
D0EC9FCEF5A4C3EA9BBEE499CAEEA6CDEEA9C3E49DC2E299C7E59BD0ECA1CCE69D91A864
CBE1A3D1E4ADC4D4A70B1D00A4B87DD3D79CAD8D5E704E20BDBE84CBE4A2BEE49BCAEEA6
CDE49EC9DD98C8DD98B1C580A5B06CE7F4AFCDE39BBFD990CFE79DCFE79DCDE79DCCE89D
CAE89EC9E99EC9E99EC9E99EC8E69EC3E199C2DD96E3FAB4CBE09D97AA68A4B372C9DE99
C9E99EC5EC9DC6EB9DC6EB9DC6EB9DC6EB9DC8EA9DC8EA9D
E8F7E4F2FFF1F7FFFBF7FFFFF5FFFDF8FFFDF8FFFDF8FFFFF9FFFFF2FAFCFBFFFFF7FEF6
FBFFF6F9FFF1FCFFF8E4EFE1BACCB2CCDDB9D2DAB1D3DBA8DCE7ABD6E5A0D3E49DC9DD95
D4EBA7C5DFA2C8E0B0E8FCD9FAFFF2FCFFFBFAFFFFD1DED4C4E0BAC5EFC1BAF0CE33624E
BFDAD1E7FBF0EEFFF1C5E0BFDDF1CCF9FFE1FFFDEFFFF9F5F6FEFFF5FFFFFBFFFFF9F7FF
FFFDFFF7F5FFFFFEFFFFFEFFFFFCF9DBD4CC0F0F051001007D464CCF9D94989262D7EDA2
BBE083CBF39DCFECB4D9EECDF1FFF2F7FFFDFBFFFDFEFFFDFEFCFDFAF8FBFDFBFEFFFFFF
F5F9F8F9FFF8EEFDE8D6E7C3CDE1ACD2E7A4D4E99AD5E29AAEAE7A746D50F2EBE1030000
F8FAF7F9FFF6F7FFEAF4FFE1DBF6C3CCE9A9CAE99BC4E089D7F198CADF92D3E2ABCDDEA8
C1D890D7F09FD0E69BD3E7A2CBDB9C73854790A264CDE3A2D0EBA4CAE89EC1E494D2F8A5
BEE592C7EE9BBFE695C6E69BCDDD9EDAE4A8B4BC809DA96BCBE4A2CBE9A3D8F3AED0E49F
C0C5859CA15FBFD38CD5F5A9C7F0A1B9DB8EE7F1AABEC17C717D35D0E69BC5E697D2EDA0
70712F666121B2B775D2E19CCAE199C1DB94E7F6B3C6D592B0C98599B06C828B4CBBC684
CAE69BBEE393C8ED9FCDF2A5C2E49AC3E49DCEF0A6CCECA1C5E59ACFEEA2C5E399819C57
D2ECADD1EAB0C8DFAB000C0092A166E2E1A8AF9363684C1C95935AD9E9A8C8E19DD3EEA7
D3E4A0DEEDAAD7E8A499A8638B9451D7DE9AD5E29DDBECA5CFE69ECDE79DCCE89ECAE89E
C9E99EC8EA9EC8EA9EC8EA9ED0F0A7C5E39BD4EEA7CCE19C9FAF6E7F8B4BC8D293D8E9A5
C9E99EC3EC9EC5EB9EC5EB9EC5EB9EC5EB9EC5EB9EC5EC9D
C6E2A8CAE4B7DEF1DDF4FFFBF5FFFAF6FFF7F5FFF3F9FFFAFAFDFFFEFEFFF9FAF4FDFFEA
E5E7C2CFCFA9BEBAA1636A49C6E8ABBADE96E7F5B7D1DB9ED5EBADC9E5A8C7E0A6CDE6AF
C7DFADEEFFDAF5FFE6F8FFEFFFFBFFFFF9FFFCFDFFEAFEFFE3FFFFCDFFF2CBFFF34F7A71
B4CFCAF5FFFFF9FFF8FFFFF4FFFFF3FFFCF3FFFBF8FFFCFBFBFFFFF4FFFFF1FFFFF4FFFF
FAFEFDFBFBF9FFFFFFFFFEFFFFFEFBFFF9F6453E3623150A492E1DECD2B7ACA674DAE5A3
CFE59CCDECA0C5E8A4CDEBB5D0E6C0E4F2D9F7FFF1FCFFFAFFFFFFFFFDFFFFFBFFFCF7FF
FFFCFFF6F6FEFBFFFBF9FFEFF8FFE1D5EAB2CEE7A5D1E3A5D4D5ADBCB49F625952030000
6D6C71FBFFFFF8FFF6F1FFE6DDF7C7CAE7A5C7E696CFED97CBE792CAE296D1E5A6D1E7A9
CDE79DD3F09ED0EC9FC4E095D0EAA3B1CA8693A865D0E5A2D3E6A4D3E7A2CCE29AC9E59A
CEF1A1C7F19DC0ED98C6F09ECEE39EDAE6A6D9E3A4939F5F8C9C5BD1E5A0DAEBA7CFDE9B
D6E2A09BA765ACC17CBAD68CD8F8ADCCEAA0C2D991D4E8A1CDDE9A8CA05BCFEDA5D1E8A2
DADC9DA0975C847A3FBCBC7ECFE49FCDEEA7CBECA5BEDD97CFE8A4D5EAA7DBEBAA8A9B57
94AA62C4DE94DBF5ABC4DE94D7F1A7CCE69CC3DF94D2EEA3D1EDA2D1F0A4C4E2988DAB65
CFECAABAD797CFEDAF000F00D0E4A5D0DC9EE3E2A959571E9BA163D6E5A4C4D795D7EEA8
CEE59FD7EEA6CBE29A8EA45BD9E9A2E1EDA5D0DA95D8E59FC0DA91C7E99DD1F3A9C4E89E
C1E79CC3ECA0C9F2A6CBF1A6CDEFA5CBE9A1CCE39DCCDB9857601FA5A768DCDA9DD7DD9D
C8E19DCDEEA7CCEDA6C8E9A2C8ECA2BFE399DAFEB4B9DE91
CEF0A3D0EEAEDDF5D3EBFFECF2FFEEF1FFE9F6FFEBFBFFF6EFEFF7FFFDFFFFFFFAFFFEE7
DFDEB2DFDDAD66604099A076C9EFA4C0E794CBD692D8DEA2CDE2AADBF7C4C8E4B4CAE3B9
CEE4BEE1F4D4F1FFE6FFFFF6FFF9FFFFF1FFF9FEFFEBFFFFC4F1F7A9DCDD9BC9C9163A3A
EEFFFFE7F3F1FFFFFDFFF7F6FFFBFAFFFAFAFFFBFBFFFDFDFCFFFFF5FFFFF0FFFFF2FFFF
FBFFFBFCFBF6FFFFFDFDFDFBFFFEFDFDF8F56459532619092E2005CFC39DA49E6CE1E5AA
DBEAA9D3EDA6B9DD95C6EBA8CEE6B4E1F3CDF2FFE3F7FFEFF8FAF7FBFAFFFFFCFFFFFBFF
FFFAFFFCF9FFFEFFFDF5FEEBEFFFDBCCE3AFCAE7A7D5E8B0EAEBC9FFFEEB29221A040000
05040AFCFFFFE3EDE5F7FFEDE3F9CACEE8A7C9E898D1EE9ACDEA98CBE699CDE6A4CBE6A3
CDE99CCAE999C8E99AC3E495D5F3A9C7E399B0C783DBEEACD0DF9ED7E3A1DAE9A6D7EDA4
CEEDA1C5EC9BBFEF99C6F29DD0EAA1D6E5A2CDDC99C3D28F626E2CC6D290D4E09ED7E6A3
D9EAA6CCE09B9AAF6AD5ECA6CDE7A0CAE59ED8F6AED2ECA5E1F1B041500FD8F1ADB9D08C
D9E5A5E5E9AC5D571D2E2C00CCD697E1F8B4C9E8A2C1E59DD8F6B0C1DA96CADF9CDFF3AE
435712637730D0E49CCEE49BD4EA9FCAE296CFEA9DD0EB9EBEDA8FCFEBA0CBE69F82A05A
D4F1AED4F3B0CCEAAA001000CDE3A3CDDD9EE0EEB0525E208E9859DDE9A9D5E6A2CFE49F
C7E198C3DF95D8F4A98AA45AC7DC91D0DD95E9F0AAD4DF9AE2FCB3C8EAA0B8DA90C7EBA1
D1F7ACC3E99EBEE499B9DF94C3E59BC6E49CD4EBA5E0F1AD8F9857C6CB8BEAE8ABDCE1A1
D8EDACC5E29FCBE8A5CBE8A5D0EEA8C7E6A0C7E59DCDEDA4
C5E793C3E39AC8E2B3CEE6C4D1E5C0D4E5C1E3F2D1F5FFEBFCFFFFFEFEFFF5F5F3FFFFEF
FFFFDAA9AA7ED0CDACD3DBB4C4E4A3C5E49EE9ECB5E9E7B7FBFFDDE6FBD2F5FFE4EBFFDC
F5FFE4F7FFE8F7FFECFBFFF1FFFBF6F4F0EFF1FFFFDCFEFF4A717621484D3C5D62EBFFFF
F1FFFFF8FFFFFAFCF9FFFFFBFFFFFAFFFFFAFFFEFBFFFFFDFEFFFFFBFFFFF9FFFFFBFFFF
FEFFFDFCFDF8FEFEFEFAFAFAFFFEFFFFFBF89D928C3D30201B0D00BBAF89A39D6BCACE93
D6E5A2D9F3AABBDF95C9ECA8C9E4ADE4F7CAF8FFE4F9FFECFCFFF6FDFFFCFEFDFFFEFDFF
FFFDFFFBFBFBFCFFF6F9FFECF7FFDFD1EAB3C9E6A4CCE1A6FEFFDDF2EDD9575046050100
EBE9EEFCFDFFEDF4ECF9FFEDE4F5C8CEE7A6CAE699D0ED99CEEB99CBEA9ECBE9A3C7E59F
CFEEA2C8E797C7E899C5E898D1F1A6CAE89EB3CC88BDD28FDBEAA9D6E2A0D4E3A0CEE29A
C1DD92BDE292BFEC97BEE896D7F1A8C3D490DAEBA7D6E7A34B5A1794A360D7E6A3D7E6A3
CCDD99DAEEA992A76293AA64C4DE97BDD891D0EBA4C7DE98D3DD9E7F8849C6D695D1EAA6
D9F8B2BAD892AABD7B7C82448E884EC9C48AD7E1A2D7F0ACC5EBA2C1E79ECCE5A1D2E6A1
D4E8A36B8139B3C980D4EAA1CEE499DDF5A9C6E194D1EC9FD2ECA2DBF7ACD9F4AD7C9A54
C9E6A3C7E4A2ADCA8A0A2400D2E6A7CBDB9CD4E3A24A5616606A2BD0DC9CDEEFABCCE19C
D1EDA3CCEAA0BFDE928DA95ED5EDA3D6E7A0D4E098D5E09BC4DA92D4EEA7CBE59ED5F0A9
CAE8A0C1E198D3F3AAD2F2A9CAEAA1C6E49CCBE59ECAE19B92A6619AA9669BA765869552
B3C887C1D796D2E9A5C5DC98D2E9A5D6EFABB7CE88D1EBA4
C8EA93C7E899C8E4A9CAE2B0C9E0ACCDE4B0E2F5C8F6FFE8FAFFFEEAEDF4FEFFFFF5F9EB
F6FCD8E9EEC56E6F4DCED9B1CCE8AED8EDB4D2CDA3FAEDCDFDFFE3FBFFECFBFFEDF7FFEB
F8FFECEFFFE2F3FFE8ECFAE0FFFFEFFCFFF3DBFCE959837596B8BAEBFFFFF0FFFFE2F1F8
F8FFFFF3F9F9FCFFFDF6FBF5FBFFFBF9FFFBF9FFFDFBFFFDFEFFFFFFFEFFFFFCFFFFFCFF
FFFEFFFDFDFBFFFFFFFBFBFDFFFDFFFFFDFDDED3CD695C4C0D0000A1956FABA5739FA368
CAD996D5EFA6C9EB9FC9EDA5C7E3A8DDF4C0F1FFD7F8FFE4FBFFECFCFFF3FEFFF6FDFFF7
FAFDF4F0F6E8F9FFEAF1FFDCF1FFD6D0ECB1C8E7A3C6DEA2E3EBC4FFFFEAA7A397030000
FFFEFFFFFFFDFEFFF6F2FBE0E4F1C3CEE2A3C7E295CCE997CAE999CBEB9FCCEDA6C6E7A0
CDECA0C7E696CAEB9CCBEDA0CBEBA0C5E399B0CA839CB16EE0EFAED4E09ED0DF9AD2E69F
D0EAA0D6F9A9D1FBA9C2E998D2EEA4C0D590D8EDA8D3E7A24B5C187C8D49D5E4A1D4E3A0
D6E7A3D9EAA6C5D994485D18DAF1ABD8F2ABCAE49DD5EAA5D4E3A2D1DB9C0C1500BFCF8E
D3F4ADCBF3AAD5F9B1C3D895585319E5D8A1F3EEB4CED899C1E09AD0F6ADC1DF99D8EFAB
D7EEA8C9DF97889E56C8DE95E3FBB1C3DB8FC2DD90CDE89BC4DE94BCD68CCBE69F849F58
D8F3B0D6F3B0DEF8B7B6CF8ED4E9A8CEDE9FCEDD9C6E7A3A444E0FCDD999DBECA8CDE29D
CCE89EC2E297CEEEA2B9D88C4F691F4B5F1793A058DBE8A2CEDF99E2F6B1C7DB96D1E6A1
CBE29CCFE6A0D7F1AAC0DB94CBE69FC8E39CCCEAA2D1EFA7CCE7A0CBE69FCFEAA3CEE8A1
BDD28F374A0A637634D3E6A4CEE19FD4E7A5E1F5B0D1E5A0
CBEC93CCEC97CFEAA3CEE9A6CCE69FD1EAA6E3F8BFF5FFE0F2FEF4F9FFFFFAFFFFFBFFF6
FCFFE6F5FFD6ACB48BCFDCB192AA78ADBD90F1E3C6BCA794C8C0B37F7F73DEE0D5EAEEE0
E4EDDCE8F6DDF5FFEAE4F5D5C9D2B5D2E3C3C1EFC84C7F60E7FFFFEEFFFFF7FFFFFBFFFF
FEFDFFF7F6FBFCFFFFEBF5EDF4FFFBF2FFFBF2FFFDF7FFFDFEFFFFFFFBFFFFF8FFFFF8FF
FFFDFFFFFFFFFFFEFFFCFBFFFFFDFFFFFDFFFFFCF88F81740E0000786A45B9B18096975B
D9E6A1C8E298C7E99CC5E99FC8E7A4CDE7AACEE5AFD1E5B4DBECC2EDFBD8FBFFE8FCFFEA
F8FFE7E0EECDD8E8C1CADEADD3ECB2C3E29FC9EAA3CAE7A7F5FFD7EFF2D7909181131007
7D7A75FCF9F2FFFFF1FAFDE0E9F2C3D5E5A7CDE398CAE795C7E696C9EB9ECAF0A7C6EAA2
C7E79BC7E698CBEB9FCEF0A3C9EB9FC9E99EC5E099ADC27D7B8A47838F4D93A05BA6B771
B9D187C9E89AC8ED9DBCE193C5E399D8F2ABC1D892D8EFA9566B2691A560C8D995D5E6A2
CDDE9AC9DA96D8E9A5516520ABBF7AD8EDA8C6DB96CBE59EC2DD98CEE3A05C5D21A7A86C
CEDE9DC5E49EB3E196D0F8AFB2C18056511765561FDCD39AE6F0B1D1EAA6BFE099CBEFA7
CCE7A0D6EDA58DA45C486016C8E096D7EFA5D6EEA2D0E89CE4FEB4CCE69CD7F1AA8CA65F
CEE7A5BFDA97C6DF9EDDF6B5CFE4A3D7E7A6DAE9A8BECA8A535E1CDDE9A7D3E4A0CEE39E
C9E59BD1F1A6C1E196DCFCB1C5E196A8C0768D9E57B1C17A7F8C47909C5A6E7A386E7D3A
6A79369AA966C8D995D7ECA7D5ECA6CFEAA3CBE9A1C6E89ECBEFA5BDE69ABFE89CCEF0A6
DAEFACA9B87798A766CCDB9ADBEAA7C0CF8CCDDC99D9E8A5
C3E48DC6E691CBE898CAE797C8E392CBE697D8EEADE2F5C7F0FFECE7F2EEF8FFFFE8F4E6
DAE8C7DEEDC2EEFCCBDDEFBDDAF2C2E9F5CDFFF5E1FFF2E8FFFCF8FBF5F5FFFEFDFFFFFB
FEFFF8C0CCB8A1B4969CAD8B8C9673BFD6ACB9EEB83E774EEBFFFFF3FFFFF6FAFFF3F0FB
FFFBFFFFFCFFFFFEFFF9FFFDF2FFFDF0FFFBF0FFFDF4FFFDFCFFFFFFFBFFFFF6FFFFF6FF
FFFCFFFFFFFFFFFEFFFDFCFFFCF7FEFFFAFCFFFCF89E90830E0000584A25CBC392B2B276
EFFCB7C7DF95C3E397C7EC9FCBEAA4C9E6A3C4DE9DC4DCA0CEE3ABDDEFBDE5F5C6E5F5C8
E7F7C8D2E4B2CCE1A9BED89BCBEAA7C2E39CC8EDA0C8E7A4DDEEC1FCFFE4CDD0BB010200
727064DDD9CDFFFFEDFFFFE3EEF1C2DEEAACD4E8A0CFEA9BC5E697C6EB9EC8F0A7C3EBA2
CAE89ECFEBA0C7E79BC9EB9EC6E89CC9E99ED7F2ABC9E09AD9EAA6E2EEACD4E19CC2D18C
C4DA91C6E297C3E598C9EB9EC3E398DBF9B1C4DF98C6E09992A96395AA65D0E49FD4E5A1
D7E8A4DFF0ACDCEDA9C6D79381924ECADE99E0F4AFD3EDA6D3F9B0C1E09ADFE5A79D985E
B5B67ACFDF9ECAF2A9BDEBA0CAE9A3DAE6A6C0B77E8F8049959056D3DD9ECDECA6BDE39A
BAD58ED2E9A3D2E9A3D3EAA26C843ACCE49ACAE296D2EA9ECBE59BC1DB91CDE79E849E57
CAE39FCAE3A1C4DD9CD3E9A8CFE4A1D6E9A7D6E5A4DFEBAB545F1DDBE7A5CBDC98D2E7A2
D2EEA4B5D58AC0E296C9EB9FCAE99DC9E399E2F8AFBBCC868C9B58DAE6A4DEEAA8B2BD7B
85904EC3CE8CD6E2A0D3E29FCCE09BCCE39DC6E49CC3E79DC8F2A6BDEC9EBBEC9DCCF5A9
C9E09CCEDA9A94A060828E4ED2DE9CF1FDBBDAE6A4737F3D
CBE898CFEC9AD2EF9DD1EF99CEEC94CFED97D3EDA4D6EDB7D5E8CCF7FFF8F7FFFAF7FFF4
D1E2BEE8FCCBB7CC91D4ECB0BEDAA7CCDCB5FFFDEAFFF2EEFFFBFDFFF9FFFFFCFFFBF6FC
FFFFFBDEE4D6D0DEC5D4E3C29CA47FD5EBBCC5FBBF437D4DA1C0B8F4FFFFF9FBFFFCF4FF
FFF9FFFFF9FFEBE0E6FFFFFDF5FFFDF1FFFDF0FFFDF2FFFDFBFFFFFFFCFFFFF6FFFFF6FF
FFFCFFFFFFFFFFFEFFFFFEFFFAF5FCFFFDFFFFFBF9A19184120000564622D7CD9CB5B579
D4DF9BCEE49BC9E99DC8ED9FCAEA9ECEECA2CEECA4CEE9A2D1EAA8D5EBAAD0E6A6C9DF9F
D1E7A7C9E2A0D0EBA8C9E7A1D3F5ABC4E99CC7EC9EC3E49FE2F6C5FBFFE4C2CBB00F1200
B7B6A47B76639A947CFFFFDFE2E4B3DAE2A6D7E8A1D3EB9FC5E697C4EA9DC7F1A7C2EAA1
CAE89ED6F0A7C4E298C7E79CC7E99DC3E398D2F0A8CEE59FD0E19DD4E3A0ADBA7592A15C
AFC37CC2D991C2E096D7F7ACC8E89FCAEAA1D2F0A8B9D78FCCE69F849B55DDF1ACCFE39E
CEDF9BD2E39FCAD996E7F8B48B9C5894A561CBDC98C7E29BB6E297CAF4AAC6D997CCCD91
71682FADA86ED4E7A5C4E8A0C2F0A5CAF2A9C5D191686228594A13ACA66CDBF0ADD7F6B0
E9FFBEC2D993C8DF99D8EFA7A7BF757E964CF7FFC3C4DC90CEE69CCFE79DD8EFA792A963
D4EBA7DCF3AFD4EAA9CEE4A3D1E6A3D0E49FCDDC99D1DD9B4E5917CEDA98CEDD9AD3E8A3
C3DF95D8F8ADD4F6AABFE195DDFBB1C4E096CEE59DBCD089C9DA96E5F6B2CBDA97869250
646F2DCAD392D4DF9DDDE9A7D9E8A5D8EDA8CEE9A2CEF0A6C7F0A4C1F0A2B5E899BFEB9E
CEE59FE9F8B5B3C27F879653F2FFBEBCCB8887965393A25F
C9E49DCDE99ECFEC9ACDEB95CAE890C9E692CAE49BC8DFA7E3F7D2D4E6CEEDFEEBF5FFED
C5DAB3BCD39DE7FFBCC7E59FC2E5ABD8EFC5FFF8E5FFFAF4F7ECF0FFFDFFF5EDFAFFFBFF
FFFBFCF4F5EDEBF4DFE0E9CA868765CEDEB1B6E6AA1E542354786CECFFFFF9FFFFFCF6FF
FFF8FFFFF7FFFFF8FFFFFCFFFBFFFFF5FFFDF2FFFDF4FFFFFBFFFFFFFDFFFFF9FFFFF8FF
FFFCFFFDFCFFFEFDFFFFFEFFFCF9FFFFFDFFFFF3F2A190861100005F4F2BD3C9989A985D
9AA360D1E59DD1EFA5C5E79AC7E899CAEB9CCAE99BC6E597C8E499CDE79DD1EBA1D0EB9E
CBE59BC7E398CEEDA1C3E397C9EC9CBBE090C6ED9CCBECA5D4ECB8DCECC5768161000500
EFF1D9A09E858580629D9973D3D3A1D0D69AD3E29DD2E89FC6E599C4EA9DC7F1A7C5EBA2
C5E099D6EDA5C4DE95CCEAA0D3F3A8C6E69BCEECA4CAE49DD1E5A0D4E3A0A1AE698F9E59
C9DA94DDF3ABC6E097CBE99FC6E89EC4E69CC5E79DD2F2A9D1ECA5849E57D5EAA5D0E49F
D9EAA6C6D793D9E8A5CCDB98D5E6A27C8D49B5C682D6EDA7C8EEA5C2ECA2C8E7A1DCEFAD
B2B075756C33E4E5A9CBDE9CC0EAA0B9E79CD8F6B0CAD495B4AB72595017586122CEE19F
C8DD9AC7DE9AE0F7B3CBE29CCEE59DE2FAB0667E34D6EEA2CFE79DCEE69CD2E9A190A75F
C6DD97C9E09CCEE4A3CFE6A2CCE39DCCE19CD5E6A2D0DC9A626D2BD4E09ED8E7A4CDE19C
CCE69DD2F0A6BDDF93C8EA9EC7E59BC4E096D6EDA5D6ECA4D5ECA6C7DC97CFE39EC0D18D
8793519FAA68909B59DDE8A6D3DF9DD3E4A0C6DD97CBEBA2C2E89DC9F5A8BDEE9FC3EDA1
D1EBA4C2D691CEDF9B98A965CCDD9992A35F96A763D5E6A2
CCE6A9CFEAA7CCE89DC7E494CAE795D2EEA1CFEAA7C6DFA6CDE4B8D4EAC6EDFFE1F4FFE4
D5ECBECAE4A7D0ECA1CBEDA0C2ECACC9E9B8FFFFE8FFFCF3FEFAF9FFFEFFFDF7FFFFFCFF
FFFDFFFFFDF8FFFFF1E8E8CEA0977A494B24D0F3BDDAFFDD568273CEF0F2F1FFFFFCFFFF
EEE0EDFFF7FFFFF7FFFAE9EFFFFAFCFAFEFDF8FFFFF6FFFEF7FFFDFBFDFCFFFCFFFFFDFF
FFFEFFFDFEFFFEFFFFFEFDFFFFFDFFFFFDFFFFFBFAB09F95110000604D2CD2C598A5A36A
969F5ED9EDA6C5E099C3E398C8E99AC8E998C8E998C9E898C9E996CBE896CBE896CBE894
CDEA98C7E794C7E995CCEF9BCAF09DC5EB98C3EA97C8ECA2C3DEA7D8EAC063724B020C00
D5D9B8DBDBB9E1DDB859562B9F9F6BCAD094DCE8A6D5E9A2BDD98FD3F5A9C8EEA5BDE199
CEE39EDBECA8CEE59FDCF7B0C3E199D1F1A8CBE99FC9E39AD0E69E95A6608B9A57D7E6A3
D6E7A3CDE19CCDE49ECAE59ECCEEA4C3E79DC7E99FCAEAA1CCE7A091AB64D0E5A0CCE09B
D9EAA6C6D793D0DF9CD7E6A3D0DF9CDAE9A6536420D5E6A2CEE19FD7F2ADBDEBA0C4F0A5
D2E9A5DBE1A33D3200756F35D0E09FCFF0A9BFE99FD0F4ACCADA9997985C666026949257
D9E5A7CEE3A0C4D996D6EBA6CCE29AD8EEA5D1E79E4C6219DAF0A5BDD388D4ECA2CAE199
D8EFA9C0D791DAF1ADCFE6A2CCE39DD1E79FD7E8A2D1DE99606B27D9E4A0CBD893D4E8A1
D8EFA9CDE8A1C8E89FC2E299CDEBA3D1EBA4C3DA94D0E7A1D2F0A8C8E69EC3DE97D4EBA5
CFE39E95A461586422CAD694D2DE9CDCEBA8CDE29DD0EAA3C5E59CBBDF95CCF5A9C7EDA2
CCEAA0BFD990DEF5ADB0C77FC9E098687F37CBE199CDE39B
CAE3ACCCE6A9CBE69FCCE89DD7F3A9E0FBB6D9F2B8CAE3ACCBE3B1CBE3B3DDF4C8E3FACC
CCE4B2C3DDA0C9E598C2E497BAE8A7C3E8B5FCFFE5FFFEF1FCFCFAFCFFFFFDFBFFFFFDFF
FAF5F9FFFFFAFFFFF1F5EFD9AB9A8059512DD7EDBEE7FFE600281885B2AFEAFFFFE1EEF4
FFFDFFFCEFF9F6E0ECFFF8FFFFFAFFFFFEFFFEFFFFFBFFFFF9FFFFFBFFFFFBFFFEFBFFFE
FEFFFFFDFEFFFEFFFFFFFEFFFFFDFFFFFCFFFFFBFAAE9D93200B00685535CCBF92928D56
919759CFDF9EC9E29ED0F0A7C9E99DC9EA99C9EA99C9EA99CAEA97CAEA97CAEA95CAEA95
D0F09BCAEC96C8EC95CBEE9AC8EE99C4EA95C3EA97C8ECA2CEEBB3C9E0B2728558000900
D6DFB4DFE2B7D7D9AA7878463C3F08E2E8ACD6E19FDCEDA7CDE49CCFEDA5BDDF95DDFBB5
E1F1B0D0DC9AC8DC97C8DF99C7E29BCEECA4C3E197C9E59BC4DA92B6CA8397A663E1F0AD
C4D591D4E8A3D1E6A1D3EEA7C5E79DC7EDA2C5E79DD1F1A8C8E69EC7E19A273E00D4E9A4
D3E7A2DBECA8E4F3B0D0DF9CD9E8A5C5D692B6C7838D9C59DCE2A4D2E2A1BDE99EB8ED9F
C1EBA1D0E7A3B7B2788479419E9E62D5E5A4C0E69DC4EEA4C8E7A1DCE8A8C1B67E6F622B
626A2EECFFBFD7EAAAD1E4A2D1E5A0C8DE96D7EDA4CCE299849A4F99AF649EB66C849C52
D1E8A0DFF9B2CBE29E8CA65FA7C178CCE39BD3E7A0D8E5A03B4602D7E29EDEEBA6CBDC96
C1D691C9E39CD5F0A9CAE8A0D0EBA4D8EFA9CEE39ED9F0AAC3E39AC5E99FDAFAB1CFEAA3
BBD28CE8FCB7C2D38F91A05D8A9956D7E8A4CADE99D9F0AAC9E49DDDFBB3C5E79DBEE096
C5E59AD4F2A8C7E59BA6C47A9DB96FA2BE74DAF4ABD2ECA3
C9E1ADC9E2A9C9E4A1D0EBA6E1FBBEECFFCEE3F9CAD0E6B7CFE6AEC6DEA4CFE6B0D2E9B5
CFE5B4CAE1A9D1EBA4C7E99FBFEDAFC8ECBEFAFEE3FFFFF3F9FEF8F9FFFFFBFEFFFFFEFF
FDFCFAFFFFF6FFFFEDEEE6CFAF977F5A4A29D5DEB3EDFFE60011009ACFC9C1EBE7EBFFFF
F5FFFFF3F4F9FFFAFFFFF4FEFFFAFFFFFBFFFFFDFFFFFFFFFBFFFFF8FFFFF7FFFFF5FFFB
FBFFFFFCFEFDFEFFFFFFFEFFFFFEFFFFFBFEFFFBFAAB998F180300604D2DCFC095A59E6A
A4A86DD5E3A5CDE3A2C9E7A1CDEBA1CDECA0CDECA0CDEC9ECDEC9ECDEC9ECCED9CCCED9C
C9EA99C6E796C4E795C7EA96C6EC97C5EB96C7ED98CBF0A3C2DFA5DAF4C4C1D7A6102200
D1DFACCAD4A0DDE4AEE5EAB2A2A86CD1DA9BDCE6A7C9D895CDE19CC7DE98D5EFA8C6DB98
D1DA9BD4DA9C7C8848D1E4A2BDD790CFEDA5D1EFA5D3EFA5CDE49CE0F4AD8A9956CEDD9A
D5E5A4E6F9B7C0D592CAE5A0C7E99FC7EDA2C5E79DC5E59CCDEBA3D4EEA7485F198BA05B
CCE09BBDD18CE1F2AECFE09CC7D894E1F5B0C6DA9598A4628B8F52D9E2A3D4F2ACB8E499
C9FEB0B9E79CD5ECA8DDE3A5423900F7F1B7C0CF8EC3E19BD6FAB2C3DC98D3D196A0975E
52581C869456D1E1A2D0E09FD9EAA6E1F5AEC7DB93DDF1A9D4EA9F4B61168AA258D8F2A8
C9E39ABDD98FD1EBA4647F384E6A20CFE99FCBDF97DAEAA355601CE9F2AFD9E4A0CEDB96
E1F2AED0E7A1D2ECA5C6E099C1D894CDE29FCEDE9DCCE19ED6F6ADBFE399BBDD93CCECA3
C6E19AD2E9A3CFE49FD3E7A25B6C28C3D792D1E5A0D5EAA5C1D892D5EFA8C8E29BCDEBA3
BFDF94C9EB9EC3E598CFF1A4BADA8FCFEFA4CCEAA0C5E399
CCE5AECBE4AAC9E4A1CFE9A8E1F9C7EFFFDCEBFFDCDCF1C8D9F1B7C9E2A0CAE2A4CEE3AB
E1F4C6E1F4C6EAFFC6DFFBC0D5FBC8DBF9D3FEFFEBFFFEF4F7FDF9F6FFFFF8FFFFF8FCFD
FDFFF9FFFFF3FFFFECEDE3C8CCB196664F2FD3D6ABDCF6CF75A693518A83A6D9D2DEFFFF
E5FFFFF1FFFFF6FEFFF9F6FDFFFBFFFFF9FFFFF8FEFFFBFDFEFFFFF8FFFFF4FFFDF4FFFD
FAFFFAFCFEFBFEFFFFFFFFFFFFFEFFFFFAFDFFF9F8A8968C2914015D482BCDBB93C3B988
9E9E68D6E1A5D7EBAECDE7A6C9E49FC7E59DC7E59DC7E59DC7E59DC7E59DC6E69DC6E69B
CAEA9FC9E99EC8EA9DC9EC9CC7ED9AC6EC97C6EC97C9EB9FCFECB2BAD5A26C8450000D00
D3E7ACE3F2B7CED99DC8D295B1BB7C737D3ED0DC9CE4F0B0DFEEADD8E9A5C8D995C0CC8C
6C6D33434209525A1EA0AF6ED6EDA7D7F2ABBDDB91C3DF95D7EEA6C3D99195A662CCDD99
C4D493C9DC9ADDF2B1C4DF9CC8E9A2C4E89ECDEFA5C0E097CDEBA3C7E19AD5ECA6748944
B4C883DBEFAAC3D792DEF2ADD1E5A0CEE39ED2E6A1B3C480A4AD6EB2BB7CCDDD9CD2F1AB
BBEB9FBAEFA1BEE89ECEE5A1BBB67C92854EC4C488E6F5B4B3CE89D7F0ACE2E8AABFBE85
929A5F465115B0BC7EC7D695D9E8A7D6E7A1C8D993CADE96CFE59AD1E99DD3EDA3B7D388
D1EDA3DCFAB0C4E29A79974D719044E4FFB5CAE097D3E39C596420CED794DEE7A4DAE5A1
D9E8A56478338CA15CE6FBB6DEF1AFD7E7A6E1EDADCDDD9CBFDA93CEEEA5C6E69DCFEDA5
D1ECA5C2DC95C6DD97DAF1ABCADF9A7B904B93A863CCE19CD3E8A3C0D791DBF2ACCBE59C
D6F6AABFE496CBF0A2C9EB9ECAECA0C9E99ECAEA9FCBEBA0
CDE7A6CDE8A5CBE69FCDE7A8DFF4CBF2FFE9F5FFEFEFFFE0E5FABFD1E8A0CFE6A2CEE1A9
F3FFDEF3FFE3F8FFE3F2FFE0EDFFE5F0FFEBFFFDF4FFFBFBF9FDFEF2FEFEF8FFFFF5FEF9
F6FEEFF4FCE4FFFFE4F2ECC8F2DAB8766039DAD9ABC8DFB58CB5A3002D2527605774ADA4
C3F8EEDFFFFFE9FFFFF2FFFFFCFFFFFFFDFFFFF8FFFFF8FCFFFCFDFBFFFDF4FFFDF4FFFB
FAFFF9FCFFF8FEFFFDFFFFFFFFFEFFFFFAFDFFF9F8A8968C2D1604513C21C5B38DE9DEB1
9C9C6AD3DEA6D6E9B1C6E0A3CEE8A7CEE9A6CEE8A7CEE8A7CCE9A9CCE9A9CBE9A9CBE9A9
CBEBA8CDEEA9CDEEA7CCEEA2CAED9DC8EB99C5E894C2E498C4E2A6D2EDB8658147001200
CCE5A4D7ECA9CFE39EE0F1ADDCEBAA8C9B5A4B5719707A3B838D4EA0A96A394201777B3E
C7C0899C955E45460CC7D192BED28DC8E29BCEEAA0D1EDA2CDE79DC8DF978A9E597C904B
D5E8A6CBE09FDDF3B3CCE7A4C5E49EC3E59BD3F5ABCEEEA5C8E69ECDE7A0D7EEA8C7DC97
758944A4B873C9DD98C8DD98D3E8A3C7DE98DBF0ABC4D994C7DC99B2C1809FA567ADB778
CBE9A3C5F1A6B3E699BBE59BDDECABDEDCA1887F46B1AF74E1EBACCCDF9DC6D695D5E3A5
D2DCA0A9B1765D6529838D4ECEDA9AD1E09BE7F8B2D4E8A0E0F6ABBED68AD0EB9ED9F5A8
C9E89CBCDC90CCECA1BCDC91C9E99DC3E294C3D990DDEDA64D5813747B37868D4A2F3600
576220A6B57287975639490862713098A263A5AD71DFE9AAD6EAA5D6EDA7D5ECA6CFE9A2
C9E39CD0EAA3DAF5AEBDD891BFDA93DBF6AFAAC47D6D8740C7E19AE1F8B2CBE29CC6E097
CBEB9FC4E797DAFCAFBBDB8FC3E397C6E599D3F1A7C4E298
CDE99FCDE99ECAE699CDE7A8E0F4D1F5FFF3F5FFF8F5FFECE5FBBDD4EA9FD2E8A0CCDDA6
F9FFEAF5FFEFFBFFF1F6FFEFF5FFF4FBFFF8FFF7FAFFF8FFFDFCFFF3FEFFF7FFFFF5FFF8
F7FFEFEDFBDAF3FED4E2E1B5DEC99E6C572AD9D9A3C9DCAF688A7900110B124E4445897C
6AB4A3A1E8D8C4FEF0E0FFFFF4FFFFFFFEFFFFFAFFFFF9FFFFFCFFFEFEFCF7FFFDF5FFFB
FBFFF8FCFFF6FEFFFBFFFFFDFFFEFFFFFBFCFFFBF8AB998F240D00442F14B6A480EDE1B7
A4A373C5CD9ACCDFA8D2E9B1CCE4A8CBE5A6CBE4AACBE4AAC9E5ABC9E4ADC8E5AFC8E5AD
BFDEA3C3E3A4C5E5A2C4E59EC6E89CC8EB9BC8EB99C6E69AC5E1A6D7F2BB4F6B30001700
C6E19CCBE59CCAE199CDE39BC7DB96D0E09F5662244E561A5B612567682C676729D0CB91
D3C8926458248A884FC6CF90E6F6B5D7F1A8CAE69CCEEDA1CAE49ADEF6ACA7BC77617530
C5D898C3D897CCE2A2CBE6A3C8E7A1C5E79DCFEFA6CAE8A0D0EBA4CAE49DCCE39DDAEFAA
798D48637833C0D590D4EBA5C6DD97DFF6B0C3DA94D6F0A9D2EBA7D6EBA88086486E7436
E4F3B2C8E39ECFF9AFC4EEA4C5E39DDDECABB6B77BA9A76CB6BA7DD4DE9FD0E3A1E0F3B3
E1E9AEEDF2BA5D62285860248B9556D3E09BD4E39ECDE199C7DD92CAE598CCE89BC4E395
C7E79BC6E89BCCEEA2D0F2A5CFF1A4C8E99ADDF5ABD0E19A444F0A2D34007277356F7432
BDC685D9E4A2D0DC9C7D89494953145B642585894EB2B679D6DFA0CCD896CCDD99CADE99
D8EFA9C7E19AC4E29AD4F4ABCEEEA5C9E9A0C8E89FB4D28A9CB770B6D18AC9E09AD6F0A7
C4E397C4E596CBEB9FD3F2A6CBEA9ECBE79CD1EBA2CBE59C
CAEA95C9E994C9E694CEE8A7E3F6D8F5FFF8F6FFFCEAF9E2DEF2B5D0E799D4E8A0CBD9A4
FBFFF1F5FBF9FCFFFFF8FEFCFBFFFFFFFDFFFFEEFDFFF5FFFFFCFFF2FBFFF5FFFFEDFFEF
F4FFECDFF4CBD6E8B6D5DAA4AC9C685C4B15D7DB9EDEF2BFC4DFCE638C863874684B9886
6ECAB326826B6EBDAA82BFB0DAF9F4F1F9FBFFFBFFFFF9FFFFFAFFFFFBFBFAFFFAF8FFFA
FBFFF6FBFFF5FEFFFAFFFFFDFFFEFFFFFCFDFFFBF8AF9D932B1404554025BCA988DDD1A7
C0BF91A3AB7AA4B581CEE2ADCFE4ACCDE5ABCDE4AECCE4B0CAE5B2CAE4B4C9E5B5C9E5B5
CBE7B4CEEBB3CBE9ADC6E5A2C6E69DCAEA9ECCED9CC9E99DCAE6ABD3EEB7567436001900
C6E49AC6E597CDE99CC9E399D4EBA3E6F9B7CDD99BD2DA9EECEDB3D3D196E9E3A7DFD59A
E6D6A3786B3787824ADEE4A6CCDC9BC5DC94CCE89EC7E69ACFE99FC1D98FE7FCB7CBE09B
899E5D9DB271C9DF9FC9E3A2CCEAA4CCECA3CBE9A1BDDB93D9F4ADC1DB94E0F7B1C0D590
C7DC97B6CB8693A863CFE6A0D5ECA6C6E099C9E39CCBE59EBCD591DAF1ADECFFBECAD998
9FA567818749D4E3A2CAE39FC9EFA6CDF3AABCD792D6E6A5BCC083C5C68AE2EBACCCD699
CBCE95E0E0AAC1C48B9AA064717A3B8D98549AA964D2E39CCAE095E0FBAED0EC9FBEDD8F
CFEFA3D1F3A6C1E699C8ED9FC5EA9CC5E697C4DC90D7E99FE0EBA6D5DC98D5DA98D8DD9B
D2D898D5DE9DE5EFB0D9E3A4D5DB9FD1D59A97965D555519727236A5AA6AE2EBAAD2DE9C
E1F5B0D3EDA6BBD991C5E79DCAEEA4C9EFA4C5EBA0A2C67CA2C47AD0F0A7D0EBA4C1DD93
DBFAAECFEEA0B6D587D0EC9FC9E399C3DD93D4EBA3CFE69E
CBEC91C7E88FC6E48ECEE9A6E4F7DBF2FFF8E8F4F0D3E2CDD6EAADCCE395D5E69FCBD9A4
FCFFF4F7FAFFFCFFFFFCFFFFFBFBFFFFFBFFFFEBFFFFF4FFFFFBFFEFF8FDF5FFFFE3F8E7
CAE2C2C9E0B4C7DCA4E5EFB3A0915866571CDEE5A2F2FFD1EDFFF2BAE1DC427E72004C39
31957B83EACF00250E3E8575C1E6DFE1EDEDFFF7FFFFF9FFFFF9FFFFFAFBFCFEF9F9FFFA
FCFFF6FBFFF5FEFFFAFEFFFAFFFEFFFFFCFDFFFBF8B19F95120000644F34EEDAB9FFFFD8
FFFFD6979F6E566635758954F6FFD5F6FFD3F4FFD7F3FFD9F3FFDCF1FFDEF0FFE0F0FFDE
F1FFDDF1FFDAE5FFC8D4F2B2CBEAA4CAEA9EC9EA99C4E498C9E5AAC6E2A8638143001300
C5E59AC4E596D0EF9FCEEA9DCCE69DCBE09DD3DFA1E1E9AED6D59CE8E3A9E5DCA1E3D79D
E7D5A35B4B18AAA56ED9DFA1D6E5A4CAE199D0ECA2CEEDA1D0EAA0D3EDA3BED38EDBF0AB
CDE2A1CFE5A4879D5FCFE9A8C5E39DD1F1A8CEECA4C1DF97D8F2ABCDE7A0BDD28DE0F5B0
DBF0ABC4D9948DA45E4B621CCAE49DCDE7A0C8E39CCDE8A1D9F2AEC4DD99CAE5A0D5E8A6
D4D599E5E0A6A6A76B879756C5EFA5B3E699CFF7AED2EBA7D2D699A09E63505417D6DCA0
E1E2A9DEDEA8DADBA2D7DDA1CCD2945A652193A05BD4E59ED3E99EC7E295CAE699CDEE9F
C2E296C6EB9DCAEFA2C0E798C8ED9FC8E99ACFEA9DD8EAA0D2DD98D7DE9ADEE09FE1E6A4
ECF1B1CDD695D5DE9FDAE3A4DCE2A6E4E5ABE0DFA6E3E1A65F5A20585619D2D797E3EEAC
C5D692C9E39CD8F6AEC5E99FC3E99EC0E99DC7F0A488AE63B9DD93C6E89ED0EEA6CFEDA3
BFDB90D7F3A6CCE89BC7E396D8F0A6CDE59BD5EBA38BA159
pop
P
% End of image
1 0 0 r
.03 w
.27308 .58365 Mdot
.28562 .59119 Mdot
.35517 .5796 Mdot
.39965 .56163 Mdot
.44292 .55583 Mdot
.47568 .568 Mdot
.51693 .57728 Mdot
.55656 .59177 Mdot
.59781 .65958 Mdot
.65483 .67117 Mdot
.69324 .68566 Mdot
.75795 .69552 Mdot
.79434 .6961 Mdot
.77938 .67755 Mdot
.76644 .6619 Mdot
.79798 .6677 Mdot
.81618 .67349 Mdot
.79717 .66248 Mdot
.81416 .65552 Mdot
.79758 .64567 Mdot
.78706 .61843 Mdot
.81294 .62654 Mdot
.82791 .61959 Mdot
.80162 .5964 Mdot
.82831 .60742 Mdot
.84651 .59872 Mdot
.87199 .59235 Mdot
.8829 .61031 Mdot
.88493 .58249 Mdot
.90353 .59119 Mdot
.89301 .56395 Mdot
.91687 .57264 Mdot
.94195 .58307 Mdot
.96136 .59235 Mdot
.94275 .57438 Mdot
.97025 .57496 Mdot
.98522 .58771 Mdot
.20352 .98764 Mdot
.2108 .81607 Mdot
.26418 .60162 Mdot
.28925 .59293 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.34127 0.031746 0.65873 0.349206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
CFF2A0CAEB9CCCE39BC9DD98E0ECAED4DE9FCAD495B6C37E75853E91A65BD1E69BC3D78F
9DAD6E6A753B6D7343F8F7D8FFFDFBF5EBF4FFFDFFFFFFFFA1A19FFEFFFBFBFCF7FFFFFB
F9F4F1FFFEF8FFFFF4EEEDD8A4AC87C5D5A4C1D799D9F4AFC2DD98D8F3ACCAE199C4DB93
E0F4AC5F752C8DA358D7EFA3C5DF95D7F1A7D7EEA8CCE19CD3E3A4D2DEA0979C629AA266
D5E49FCFE99FC6EC9FC5F0A1C4E69CD3DF9DA38C58735C28D3E3A2C8E9A2C9E9A0C9E9A0
C6EB9EC8EA9ECCE89DCDE79DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
CDEDA1C9E99DC9E89CCDECA0D2ECA2C4DE94ABC37994AC628BA158D5EBA2C9DF96CCE299
D5EDA3D5EDA3C0D88EDAF4AAC2E098D0F0A7D0F0A7C8E89FCAEA9FC8E89DC5E79BCBEDA1
DBFDB1D7F9ADD0F2A6C8EA9EC5E79DC6E89EC7E99FC6E59FD0EDAAC7E29FDAF3B1CFE9A2
C8DF99A7BF758BA158D2E89DD4ECA0CCE79AD2ECA2C9E89CCAE89EC7E79CC5E69FCBEDA3
CBEBA0C6E89BC2E99AC9EEA0D4EBA3C9DD96AEC27B97AD6586A15A8798548D8348624410
7B5023FDDBABD1CF94D6E5A4C5D395DFEFB0CFDFA1D7E7A9D4E2A5C8D699E4EFB3D4DEA2
DCE4ABDDE0A9D6D6A0E0DFA9DAD4A0837D49594F1C7E7F4590A45F89A85CCBEA9EC3E296
ACCC80D5F5A9B1D387D7F9ADC5EA9DC8EDA0C9F0A1C5EE9FC0E99ABDE898C0ED9CC8F3A3
C8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C1E492BEDF90D4EEA5D1E5A0C6D496A5B171758141B3C27DDDEEA7CDE297CCE297DEF4AB
D6E6A7CCD79D9CA272EAE9CAFFFCF6FFFCFFFFFCFDABACA76C6F68FDFFF7FEFFF8FEFFF7
FFFEFAFFFCF3FCF9EAD5D7BFE3EBC4D3E4B0CFE7A9B9D48FDAF5AEC6E099CEE59DDBF2AA
C1D78E95AB62C9E195C9E195D2ECA2C5DD93D7EEA8CADE99CBDB9CD9E5A7697136A1A96D
D1E09BCDE79DC5EB9EC6F1A2C8EAA0DCE8A6B29B67866F3BD3E3A2C8E9A2C9E9A0C9E9A0
C6EB9EC8EA9ECCE89DCDE79DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C7E79BC5E599C7E69ACAE99DD0ECA1D0EAA0CBE399C5DD938BA15896AC63D1E79ED3E9A0
CBE198C9E197DEF4ABC2D991DCF7B0C0DE96C2E098D2F2A9D0EEA4CAEA9FCBEBA0C6E89C
CFEFA4CDEFA3CBEDA1C9EB9FC8EAA0CAECA2C9EBA1C9E8A2CCE6A7C0DA9BCFE8A7CAE3A1
D1E8A4BFD68EA3B970DAF0A5BCD488CEE69AD6F0A6C6E297C1DF95CAEA9FC9EBA1C5E79D
C9E99EC6E89BC3EA9BC7EC9ED1EBA2D3E7A0CBE199C3DA92E2FFB8C9DD98DFD69B967B46
70471989693899995DDDECABE2F0B2CFDD9FCBD99CE2F0B3CED99D6B763A7F8A4E98A266
89915694975E7C7C4674733B2A27009C9962DCD6A2E1E5AAD6EBA6CBEA9ECEEDA1C2E096
CCECA1C4E499CDEFA5C0E298C3E59BC5EA9DC6EC9FC4ED9FC7F0A2CAF5A5C2EF9EB9E494
C6EB9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
CFF2A0CBEC9DCCE69D8DA25DB4C48587965595A463D1E29CCEE29ACCE498D5EDA1D2EAA0
C1D494B3C186A5AB7BE7E8C6FFFEF3FFFBFAEBEAE5A6A99E979F90FAFFF2F7FEEEFEFFF3
FFFFF3FFFFF1EDECD8C9CEB0F1FED3C7DCA4DBF8B6D0EEA6CDE7A0C3DA94D5ECA4C2D991
728A4090A85ECEE99CCAE598D1E99FCEE69CC7DB96DAEBA7DBE9AB9BA769313B00D6E0A3
D3E49ECFE99FC5EB9EC3EE9FC3E59BD9E5A3B39C688B7440D3E3A2C8E9A2C9E9A0C9E9A0
C6EB9EC8EA9ECCE89DCDE79DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C7E79BC8E89CCAE99DC9E89CCAE69BCBE79CD0EAA0D4EEA4DAF2A8677F35839950B3C980
CEE49BD2E89FDDF1A9D0E69EC8E29BD0EBA6D0EBA4C2E098C1DD93CDEBA1D1F0A4C5E599
C6E599C6E69AC8E89DCBEBA0CCECA3CBEBA2CBEAA4CAE9A6CFE8AECAE1ABD9EEB5D4E9AE
D3E7A8B2C784768C4480964DE6FCB1D9F1A5C2DD90C5E196CCEAA0CBEBA0C4E69CC9EBA1
C9E99ECAEA9EC6ED9EC5EA9CCAE49BCEE49CD1E8A0D1EDA3BBDD93C3DA94EAE6A9AE9761
6947177056236C6D31748342B7C385C3CD90DBE5A8D0DA9DA1AB6E2A34003C46094F571B
3A4004686E3224270055561C8F9057F5F6BCC8C78FD7DFA3C4DE97D2F2A7C5E59AD3F3AA
D2F2A9CAEAA1D2F1ABC2E39CCBECA5CCF0A8C7EDA4BEE79BC0E99DC6F1A2C4F0A1BDE899
C6EB9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
B6D987DAFBAC8DA95FCCE39DD2E2A3DFEFAED8E8A7DCF0A9D3EBA1C7E295E0FBAEC4DE94
DDF0B0C3D196E2EAB9FDFFDAFFFFEFE8E8DCCED2C1EEF6DFF0FDE3F9FFEAEDF7DEF1F9E1
ECF0D9EBEDD58F9275A3AB86D6E6B5CDE5A9C8E7A1BEDE93D8EFA9D7ECA7C6DD958FA960
88A258BCD88DC8E497C9E497D1E99FC2D88FE9FAB6C9D895A4B072263200949F63D9E5A7
D5E6A0D0EAA0C5EB9EC2ED9EC1E399D7E3A1B49D698E7743D3E3A2C8E9A2C9E9A0C9E9A0
C6EB9EC8EA9ECCE89DCDE79DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C8E89CCBEB9FCEEDA1CCEB9FC9E59AC5E196C6E096C7E197CCE49AD1E99FDCF2A9BAD087
889C5493A75F8DA159D2E69FCAE19BD4EDA9D4EDA9D2ECA5D4EEA5CBE79CC9E59AD4F0A5
CBE79CC8E79BCAE89ECCECA1CBEBA2C8E89FC8E7A1CCE9A9CEE6B2C9DFB0D0E4B1CDE2AA
DCF0B5DBEFB0BDD28FC3D9919BB168D2EA9ED5EDA1CCE89BC5E196D0EEA4CBEBA2C5E59A
C7E59BC9E99DC9EEA0C8ED9FCBE59CC9E098C8E299C6E49AC4E89EDBF6AFE5E5A7D4C189
937543E5D09BC9CF9195A8669CA868828C4D5961254A5415747E4197A162D4DEA1D9E3A4
E2ECAD8F985997A061D9E2A3CBD495DEE7A8EFF8B9D3E2A1D6F0A9C2E299D1EFA7C3E19B
BEDC96CCE7A4CDE7A6C9E6A4C5E2A0C9E8A4CDEEA9CAEEA6C2E89FBCE599C1EB9FCBF4A6
C8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
D0F6A3BDE09078964CD9F3ACCDE0A0CEE19FCEE19FC6DC94CFE99FC1DD90CFEB9EBBD78C
D5EAA9C8D79CFAFFD1FAFFD7F9FCDFE3E7CCA8B290F9FFE1F8FFDFF8FFDDF6FFDCD7E3BD
CAD2ADEAF0CC8D946BB5C191D0E4A9C9E49FC8EB9BDBFCADCBE29AD5E9A4D0E79F8CA65D
C4E397DCFBAFCCEB9DCCE89BD5EBA2DEF2AAC4D390E0ECAA9EAA6C5B6729B2BD81D4E2A4
D1E29CCDE79DC4EA9DC3EE9FC7E99FE0ECAABDA67297804CD3E3A2C8E9A2C9E9A0C9E9A0
C6EB9EC8EA9ECCE89DCDE79DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C7E79BC8E89CCAEA9ECCECA0CDECA0CCEB9FCBE79CCAE69BCEE89EC7DF95C8DE95C9DF96
B5C9818C9D564C5D169CAD67677C39B1C884D4EBA7C6DD97C5DC94CAE49ACAE49ACEE99C
D1EC9FCCE89BCCE89DCCEAA0CAE8A0C7E59FCBE8A5D2EEB1E6FDCFE4F9D0E5F8CBDAEEBD
DDF0B9DDF1B6CCDF9FC9DD9897AD64CFE79DC8E094D4F0A3CCE89DCAE89EC4E49BCEEEA3
C8E49AC7E69AC6EB9DCAEC9FCFEBA1D0EAA1CDE99FC7E99DCAF3A7C8E89FCDD393D7CB91
987E4BF0DFA9E4F0B0CEE5A1C7D695A6B27079834497A361B7C383DAE6A4DAE6A6D0DF9C
D3E29FC7D894D9EAA6DCEDA9E1F5B0BFD38EC3D792C7DC97D1E8A2CEE8A1DCF3AFB5CB8A
E1F7B7D0E4A5C8DC9FD0E4A7C7DD9FC7DFA1D4EEAFE2FFBDD9FAB5C3E79FBEE499CBF0A3
C8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
8BB25F698E3EB4D288C0DA93E2F7B6CBE09DDDF2AFC8E299C8E499D6F7A8D1F0A2D7F3A8
ACC281B1C387EBF5C3FAFFD5EDF4CBD6DEB5889567E4F6C4E1F6BEE0F5BDEAFDC6CBDCA8
D5E1B1C7D3A3656F3D839259D3EAA6CDEC9EC7ED96B7DB84C9DF96C4D893DBF2AA91AD63
C5E498C1E195D1F0A2C9E598C9DF96D1E29BDCEBA8DAE6A43642048D995BD0DEA1E2F2B3
D1E59ECDE79DC3E99CC3EE9FC6E89EDCE8A6B29B67866F3BD3E3A2C8E9A2C9E9A0C9E9A0
C6EB9EC8EA9ECCE89DCDE79DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
CBEB9FC7E79BC4E498C5E599C9E89CCDECA0CFEBA0CEEA9FC8E298CDE79DEDFFBAC9DF96
D8E9A2DDEEA7D2E29BC7D892D2E5A397AC6B91A462829752677D35AAC278E8FFB4BDD589
D3EB9FCCE79ACBE59BCDE99FCCE7A0C8E6A0D0EDAADEF7BDEBFFD7F5FFE6F7FFE3F7FFDD
F7FFD7EDFFC8DFF1B3D2E5A3869C54D3E9A0C6DE92D7F2A5CBE79CC9E89CC3E398CFEDA3
D0ECA1CCE89DC4E699C4E699CBE79DCFE9A0CCEAA0C7EC9FC2EEA1BADE94DBE6A4C5BC81
947F4AD9CC95D7E7A6C7E29DD6EAA5DCEBA8C8D794E0EFACC6D592D3E4A0C6D793D5E9A2
CFE59DD0E79FC6DD95BED88FC5E197D6F5A9D9F7ADD6F2A8C7DE98DEF1AFC5D898E4F4B6
C0CF94D4E1A9DEEBB3DDEAB4E5F4BDDDEFB5E2F6BBEEFFC6E5FFBECEEBA8C4E39DCAECA2
C9E99EC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C6F09CC1E897DEFEB3C4DF98B3C988D6EDA9CDE4A0D4F0A6C7E69AD0F3A3B5D687C9E89C
8EA7659BAD71D2DCAAD2DAABDEE8B6CAD7A28D9F65BFD394D6EFADCDE6A4CBE1A0D1E5A6
D7E6ADD2E1A894A26793A664CDE79DBDDF89CDF698D1F59BE9FFB4CEDF9BC7DE9685A157
CAEA9EC8E89CDAF9ABBEDA8DD7EDA4DFF0A9CFDB99000B00475114D4E0A2EBF9BCBDCD8E
D4E8A1CEE89EC2E89BC3EE9FC5E79DD5E19FA28B576F5824D3E3A2C8E9A2C9E9A0C9E9A0
C6EB9EC8EA9ECCE89DCDE79DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
CDEDA1C9E99DC6E69AC4E498C5E599C6E69AC8E79BCAE69BE0FAB0BBD58BC9DF96C7DD94
D1E29BCBDC95E2F2ABDFEEA9D5E5A4EFFFC2CCDC9BC2D691D1E59E7B91485B7126C8E094
D0E89CC9E497CAE49ACEEAA0CDE8A1CAE5A0D2EDAAE1FAC1F5FFE4F5FFECF0FFDFE0F2CA
CCDDB0C6D8A4CFE1A5CBDE9E2E4300C9DF96D7EFA3CFEA9DB7D388D2F1A5CFEFA4C0DE94
D2ECA2CEEA9FC6E89BC4E699C7E399C8E49AC6E69BC2E89BC5F4A6C8EEA3DAE6A4979155
6B5A24E1D89FD8EDAAC5E49ECBE09BD3E49EC9DA94D0E49DCBDF98E4FAB2D3E9A1CFE79D
CEEA9FCEEDA1D0F0A4D9FBAEBCE193BFE695BDE697C6E89BD9EEABCEDC9E2D3900515B1F
D6DFA8FFFFD3939A67919865C4CB98DAE2AFEFFCC6F2FFC8E2F6B7D1EAA8CCE7A4CBE9A3
C9E99EC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C0EB99C4EB9CC7E79CCAE59EDFF8B4CBE4A0C7E29BCAE89EC4E498D0F0A4CCE89DCEE59D
94A765869457D8E2ADD6E0ABCAD79FD3E5A7ABC07F91A862C8E29BD2ECA3C1D892D6EBA8
CCDF9FD3E6A6A6B977B2C880D3EEA1C9E994C3EA8FC3E78FBDD78DD7ECA7CBE59C8AA65C
CEECA2BEDA8FCFE99FD3EBA1C1D58DDEEDA8D2DE9C4D591799A565E1EFB1B9CC8CE0F5B2
D0E5A0CAE69CC1E79CC6EFA3CCEBA5DDE6A7AA8B5C735425D7E1A4CAE7A4CCE7A2CAE8A0
C8EAA0C8EA9ECAE89ECCE89ECAE99DCAE99DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9EC8EA9D
C8EA9EC9E99DC9E99EC9E99DC9E99EC9E99DC9E99EC9E99DC9E99EC9E99DCAE89EC9E99D
C5E79AC8EB9BCBEDA0CCEF9FCAEC9FC9EC9CC8EA9DC9EA9BC2E296D5F4A6C8E79BD9F5A8
CAE49AD0EB9EC9E197C5DD93D4EBA5C1D894CFE6A0D7EEA6D1E79FDFF5ACBDD38A61772E
D1E79ECBE399CDE49CD0EAA1CDE8A3C8E39ECEEBA8DEF7BEF5FFE8F5FFEFF0FFE3E8FAD4
D4E5B9CBDDA9D6EAADD1E6A3C3D893C8DF97869D55C4DE95DCF5B1CEE9A6B9D696D6F0AF
CBE29CCEE59DCBEBA0CBEDA3CCECA3CBEBA2CAECA2C7EDA2BCE599CBEDA1D0DC9A9E9E60
584F16EDECB3C8E1A0CEEDA9D2E9A1CBE198D1E79FD2E89FCDE496C8E094C4DE95D3EFA5
C3E294CDEE9FC5E59CC1E29BD7F9ADC7EC9EBCE096D1EFA7B0C3814E5D1CD6E2A4D4DEA2
DBE4ABFBFFCDFFFFD3BAC28F5D6532A9B37EEFFCC4F8FFCEE3F7B8D2EBAACEE7A5C8E39E
C9E99EC8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
BCE899C1EA9CCDEDA4DCF6AFBCD38DDCF7B0C1E399C8ECA2CBEDA1CEEAA0CFDE99D2DB9A
A7AD6D8F9557DEE8ABD1DFA1D0E3A3CCE19EC7DE9A89A05A667D37D9F0AAC7DE98D0E7A1
CEE3A0C6DB98AEC37E809751DCF3ABC8E298CAE699D0EFA3D3F1A7C1DF97CAE59E8AA45D
CFE6A0CDE19AD6E5A0D5E29DD1DE99DAE6A4C7D391556421CFE39ED5EAA7CAE39FCEE9A4
D0EAA3CBE9A1C3E9A0C0E69DCDE6A4DFDEA6C99F77845831DFDCA7D3E2A7D1E3A5CFE5A4
C9E8A4C6EAA2C9E8A2CAE8A0D1EDA3CFEBA0CDE99EC7E69AC5E498C5E599C8E89CCBEDA0
C4E699D3F8AABDE495C5EC9DC6EFA0B8E192C8F1A2C6EFA0C8EEA1C6EC9FBEE298C8EDA0
CBEFA5C7E99DCEF0A6CCEEA2C4E49BC4E499CEECA4CDEBA1CCEAA2CEECA2CAE59ECAEA9F
C2E797B9E08DC9F09FD2F9A6C1EB99BFE995C9F3A1C7F19DC0EA98C5F19CC4EF9DBEEA95
C0EA98C6F09CC5F09EBFE997C0E99AC4EB9CC6EB9DC8E89CC8E79BCCE69CD1E99FD4EAA2
576D2599AF67CFE49FD4EBA7BFDA95CAE7A4D6F5B1DBF6BFF5FFECF7FFF3F5FFEAE3F4D0
D3E6B8CDE2A9CAE09FC6DD97CEE59DCDE79EB7D08CBAD294D9F0BAD5EBBCC0D7ABCCDFB1
DAE9AECBDE9CD1ECA9CDEDAABEE39EC1E9A3C5EDA6C5E9A1D0EEA4C6DC93D4E19CAFB575
747A3EDFEDB2BED79DD1EEAECDE89BCFE897D0E79FCEE99CCEEB91CCEA92CBE6A1C9E6A3
C4E18DC5E290D2EAACDBF0B8D3E8A5CDE09EC5D79DB9C88F778A4ABFD38EE0F3B1C9DC9A
D1E4A4F9FFCDF9FFCDCADEA1D0E4A7B6CC8E4861209CB574C8E3A0D4F1AEBEDB98CBEAA4
C8EA9DC6EB9BC8EB9BC8EB9BC8EB9BC8EB9BC9E99DC9E99D
C3EDA1CBF1A6C2E299C4DE97E0F5B0C8DC97CFE6A0CAE49DC5E099D2ECA5DCF1ACD5E6A2
B3BF7D828D4BCAD090D9E4A2D1E5A0E4FBB5C9E09AB6CD878EA55F9DB46EDCF3ADC3DA94
CEE59FE4FBB5CEE59FA4BB75AAC17BC9E09AD0E7A1C6E099C1E198B8D88FD6F4AC8AA45D
91A560E1F0ADCEDA98D9E4A2D4DF9DE0EBA9C5D18F445511D8ECA7C5DC96CAE59ECDE8A1
C9E49DC8E89FC5EDA4C6ECA3D1EAA8DCDAA1BE936973461FE1DBA7D4E2A5D3E3A4CFE5A4
C9E8A2C6EAA2C8EAA0C9E9A0C6E49ACAE69BCCEB9FD1F0A4D3F2A6D2F2A6CEEEA2C9EB9E
C9EB9EC8EA9DC7EC9EC1E698CDF2A4D2F9AAC0E798C3E89BD0F0A7D2F0A8D2F0A8CAE8A0
C9E49DCBE69FC9E39CC7E19AD5ECA6DDF4AECEE39ED2E7A2CFE49FC7DB96D8ECA7D0E79F
D7F7ABCFF4A4C9EC9CBCE191BDE292CCF3A2CDF4A3B7E18FB9E391C9F4A2CEF9A7C0EB99
B8E391BDEA97C0ED9ABCE996C2EF9CC6F19FCBF5A3CFF4A4D0F0A4CFEBA0CDE49CCBE199
5267224E631EC2D794D8EFABD0EBA8C0DD9AC9E8A4D3EFB5ECFFE1F6FFF0F4FFE9E6F7D5
D7E9BFD2E6B3D2EAAED4EDACCBE4A2D2EBAABED69AB5CC94CBE1B0CFE5B7CCE1BAE2F1C6
D4DBA7CFD79BD9E9ABBCD496C3E3A2DAFFBCC0E19CCAE5A0D6E7A1DBE5A0E3E8A5C5C786
9CA266C9D49CD8E9B3CDE2A7D1E99DD1E99BCFE9A2CEE89ECDEA8DCBE98FC9E4A1C8E2A1
DBF7A0D0EC97CEE3A8C8D9A5BACA89B4C380B4BE89AAB781ADC07ECEE59DDBF0ABC8DF99
D0E7A3ECFFC1EDFFC4D0E9A7C8E3A0C4DF9C587532567330C6E3A0CFEEAACBE8A5C8E89F
C8EA9EC6EB9BC6EB9BC6EB9BC8EB9BC8EB9BC9E99DC9E99D
C8ECA2BFE197D4F4ABCDE7A0C7D391E7ECAC9E9C5F929254BBCA87B5D38BC1EDA0B3E495
BFE89CB2CC85929254E8E6A9DDE9A7BFD48FCFE49FC7DC97C5DA959AAF6ABFD48FDAEFAA
C8DD98CCE19CC3D893D0E5A04F641F768B46E3F8B3BFD690D0EEA6DCFAB2D1ECA5B7CE88
8FA45FB0C17DD4E3A0D5E19FCFDB99DFEBA9D7E3A14F5E1BB0C17DDCF0ABCADF9ACDE49C
C8E49AC7E99CC5F0A1C4EFA0CFEDA5D6DB9BB69262684414DBDFA2CFE6A2CFE6A0CCE7A0
C6EB9EC5EB9EC6EB9DC8EA9DCAECA0C7E99DC5E59AC5E59AC7E79CC8E89DC5E59AC3E197
C4E298CDE99FCEEAA0C3DF95C9E59BD0EAA1C8E299D0E69ECCDB98D1DC9AE0EBA9CAD593
CED796EAF3B2DDE6A5DAE3A2D9DF9FC9CF8FDDE3A3D3D999D8DE9EE8EDADD0D595D6DF9E
C4D891CCE69DCEE59DC8E299CFE9A0D3EFA5D0ECA2CCEAA0D3F1A7C3E398BFDF94CDEDA2
D6F6ABD0F2A6CAECA0CCEEA2C3E89AC1E698C1E396C3E397C6E49ACCE89ED1E8A0D2E9A1
DBF2ACBBD28C7B924CC5DC96D1ECA7CAE5A0CAE8A2D6EFB5D7ECC5EBFBDEF7FFEAF7FFE8
EBFCD8DCEEC8D0E2B8CADDB0D0E3B5F3FFD6F7FFD8F7FFD6F2FFD1DAEEB9BCD09BBDCA94
FFFFCFEFE8B1D8D9A0DCE6AACADC9ECEE2A3D1E1A0949F5D9093509D9856A3995B7E7236
625920AEA874D9D9A7D4DDA48CA05989A157899F5E889F5986A049849D49839958819756
809A437C963F879B5C94A86DA1B56EB9CD85D1E4A4D7E9ABD4EBA5D0EAA1CCE39DC7E19A
CDE7A0D7F1AAD6EFABCEE9A4C8E39ED3EEA9C2DD98D1ECA77F9A55A9C781DAF5B0CAE8A0
C8EA9EC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99D
C5E79DD0F0A7C9E39CCEDF9BDDDD9FE5DCA15A4911665D229EA766CDEBA3C0F5A5B1EC9A
C1F4A5C8E89F555B1B868648DFEBA9CCE19CD6EBA6D9EEA9C8DD9894A964D4E9A4CFE49F
D6EBA6DBF0ABD5EAA5C7DC97D9EEA9889D58D1E6A1D6EDA7C9E39CCCE7A0C3DD96E4FBB5
D2E7A28B9F5AC9DA96D5E6A2D7E6A3D2E19ED2DE9C55611F2C3B00DDECA9CAD996DAEEA7
CEE99CC9EC9AC1EE9BBEEB98C9EB9ED4DF9BBB9D6772541ED7E2A0CAE89ECAE89EC9E99D
C5EC9DC3ED9BC6EB9BC8EB9BC5EA9DC4E99CC5E79BC6E89CC9E99ECDEBA1D2EEA4D5EFA6
CAE199DCF2AACADE97CDE19AD9EAA4D6E5A0DBEAA5D2DD99E4E6A7CFCF91F3F3B5E0E0A2
9F9D605856192C2A005F5D205856196F6D3055531659571A5856196B692CC7C386EAEAAC
E2ECADDAE9A8D0DF9ED8E7A6E1F1B0CDDD9CC1D492D8EBA9D0E3A1D0E5A2D4E9A6D4E9A6
CBE09DC2D995C7DE9AD1EBA4D6F2A8CFEDA3C9E79DC8E49AC9E59BCCE69DCEE89FCEE89F
CBE29CDBF2AC92A963C2DC95D5EFA8CEE8A1CAE49DBED698CADDAFDCEEC8F1FFDEF7FFE6
F7FFEAE9F9DED9E9CFCEDEC3CBDBBEF0FFDFF7FFE1F7FFDCF7FFD4F7FFD1F6FFCBFCFFCC
5E5C233029004A4B12555D225664274454154F5E1BDBE4A1EDEEACEAE5A3E9DEA09F9357
5A4F17DFD8A1D4D39DE2EAAFD1E1A0CDE4A0CDE3A5CEE3A0CDE492CBE290CBDE9ECADD9D
D4EA95CDE58FCFE4A1CFE5A4CAE296CDE899D4EEA7D1EAA6D3EEA7C8E49AC3DE97CAE59E
CFEAA3CBE69FC7E29BC8E39CDAF5AEC8E39CCAE59ECBE69FD3EEA9C3DD96D1EBA4C0DB94
C9E9A0C8EA9EC9E99EC9E99EC9E99EC9E99DC9E99DC9E99D
BADE94C1DF97D0DF9CEFEFB1B09F6766511AAB9A62A19D60525E1C92B068BDE99CC5F6A7
C3EDA1C4E69C9DB26D6978358B9F5ACADE99DFF3AEBBCF8ADDF1ACA7BB764C601B90A45F
C9DD98CDE19CC9DD98D5E9A4C5D994E3F7B2879B56C7DC97D8EFA9C0D791C9E09AC7DE98
C4D99496AB669DB26DC7DC97CDE19CCFE09CF0FFBCCFDB993E4907D6DF9EE2E8A8D2DD99
D3EA9CCAEC98C0EC97BBE893C4EB9AD1E399B8A469725E23D1E59EC5EC9DC8EB9BC6EC99
C3ED99C3ED97C8EB97C9EA99C3E89BC7EBA1CDEFA5CCEEA4C9E9A0C7E29BC7E19ACBE09B
CFE09CD5E4A1DCE8A6CED796D0D696D7DC9CD5DA9AEBEBADBEBA7BA8A264918D4E4C4809
585415A29E5FA09C5D9A9657A09C5D888445A19D5EA09C5DA5A4649A9959484707262600
8F935891965C7A7F45777C42A9B176D8E0A5DDE5AAD5DFA3D5DFA3E3EDB1E0EAAECED99D
CDD89CDEE9ADDFEAAECFDD9FCBDB9ACADF9ACDE29DD0E7A1D3EAA4D1EBA4CFE9A2CCE7A0
D2ECA3D1EBA2B8D289203A00CEE89FD9F0A8C3DA92DEF5B1CDE2A9CFE3B2D7E9BFE5F6D2
F2FFE8F7FFF3F7FFF7F4FFF6F8FFF8F8FFF3F2FFE4D4E4BDC6D8A4C9DD9ECEE29BD3E49E
899253BBC086E1EFB2E0F2B4A4BD7BA8C17DE0F7B1CADE97CAD791CAD18DDBDC9AADAD6D
727435E9EDB0CDD599D6E4A6D3E6A6D2E8A8D3E7ACD5E8A8D7E99DD7E99DD7E5A7D7E6A5
D6E997D0E691D3EAA2D4EEA7CAEA97C9EB95CAEC9FC3E599C7E79CC6E69BC8E89DCCECA1
CEECA2CBE99FC8E69CC8E69CC4E096C3DF95D7F1A8CAE49BC5DF98A1B870ABC27AD4EEA7
CAE8A0C9E9A0CAE8A0C9E9A0C9E9A0C9E99EC9E99EC9E99E
DAFCB2D7F1AADCE2A2D5CC915E4B136A571FE9DFA4D5D5978894521B3000C3DD96CAE8A0
C7E59DCEEEA5DCFFB6BCDC93889F59D4E8A3CFE39EE4F8B3C2D691D6EAA5DFF3AE485C17
D2E6A1D5E9A4D0E49FD4E8A3DDF1ACBDD18CD1E5A0526621C7DB96E3F7B2DAEFAADBF0AB
CCE39DCFE9A2BED89198AF69DCF1ACC6DA95C7D693D7E2A0545A1A676C2CD3D395DFE4A2
D3E398CCE997C3ED97BFEC97C4EE9ACDE297AE9E62645418CFE69EC3EC9DC6EB9BC6EC99
C5EC99C6EC97CAEA97CCE999CDEDA2CBEDA3CBEBA2C9E79FC8E39CCAE49DD1E6A1D9EAA6
E3EFADBDC886E5EBABDBE0A0E9EBACDBDB9D656326504E114B4B0B626222B1B171E1E3A2
EFF1B0E6E8A7D0D291E6E8A7DADF9DE8EDABD2D795DBE29FD7DE9BCBD28FE7EEABE0E6A6
9DA1665D602740430C63662D70733C464B113F420B676C32DFE4ACD0D59BCFD49CDCE4A9
DFE7AED3DBA0D3DBA2DFE9ADD9E3A6D8E4A4D5E4A3D0E3A1CDE29FCEE59FCFE9A2D2EDA6
CDE99FC9E59BDDF7AECAE49A3F570DC7DD94DFF5ACCEE49CD1E7A6CCE1A6CFE3B0E0F2CA
F4FFE9F7FFF4F8FFFBF8FFFFF8FFFDF8FFFAEEFBE7DDECCBD5E5B6D6E8AED5E8A6CEE29D
DEEEB0CBDDA1D7EDAFBAD795C8E7A3D7F8B1B2D289D3EFA5D8EEA6D5E6A0DEEBA6C9D490
A8B371D2DE9CDDECA9CDE09ECBE1A0CBE1A1CEE2A5D0E3A3D4E49BD4E49BD6E2A2D5E19F
D2E393CAE08DCCE39BCAE89EC3E694C4EB98C6F1A1C1EC9DC1E79AC7EC9FC9EEA1C7E99D
C5E79BC8E89CCAEA9ECCEB9DC4E095E9FFBAC4DE94C5DD93CAE298CAE098829850CCE39B
CCE7A2CAE7A4CAE7A4CAE8A2CAE8A2C9E9A0C9E9A0C9E99E
647E37889C575C61215A561981783DEBE7AACFD494E1EAA9E1EAA9414606EBEBADDCDE9F
CDD997C5E099B3E495C1F2A3DFFAB3839450899A56D8E9A5D0E19DD1E29ED6E7A3CFE09C
445511839450DEEFABCEDF9BD3E4A0E3F4B0BBCC88E2F3AF6F7E3B98A965B5C984DEF3AE
D2ECA5CFEAA3CAE59E3F5A13D2ECA5CADF9ACCDD99DEE9A7B3B87849490B8D894CDFDF9F
D6E099D0E799C7ED9AC2EC9AC8ED9FCDDE98AC995F5F4F14CFE6A0C3EC9EC6EB9EC8EA9D
C6EB9BC9EA99CFE799D0E69BCFE69ECBE4A0CCE39FD1E6A3D5EAA7D7EAA8D4E4A3D1DD9D
DFE9AAD2DB9CD2D89AACB0738182465F5F23505014797E3EA5B06CADBC77C3D28DD0E19B
D2E39DCEDF99CADE97D0E49DCDE39BC4DA92D3EAA2CEE59DD0E79FD7F1A8C5DF96CDE29D
CCD89AE5EBAFDDE2A8ADB3778F945A949C608A8F5560682C4B5318464E12666E3396A063
99A367828C4F9AA468D2DA9ED8DEA2DDE3A7DEE8ABD8E7A6CFE2A0CBE09DCAE49DCCE7A0
CFEDA3BCDA90CEEA9FD9F3A98EA65C8DA358E1F3A9BACE86D1E79FCCE2A1D2E7AEE4F7C9
F5FFE4F7FFF1F4FFF4F1FCF4F0FBF5DFEBE1D1DECDC9D7BEC5D5B1CCDDB0D4E5AFD0E3AB
C8E0A6C3DFA4CEECAED0F3B1BDE29CC6ECA3D8FEB5C2E39CCAE8A2CBE4A0CBE09DA5B876
829651BDD18AD8ECA5CEE49CCEE8A1CFE8A4D2E7A6D4E7A5D7E79ED9E69EDAE5A3D8E5A0
D9E99ED0E598CFE9A2CDECA6C4EA9FC4F0A3C8F8AEC4F4AAC0EA9EC5EBA0C5EB9EC2E79A
C0E597C3E598C8E99ACBEA9AD2EEA1AFCB7EDBF6A9D9F1A5D3E99ED3E79FC0D48CC3D991
CDE6A4CCE6A5CCE6A5CAE7A4CAE7A4CAE8A2C9E9A0C9E9A0
98A76494A05EB1BA79DEE7A6D7E09FD0DB99DFE8A7B3B979777538A49B60E3D79DE8DFA4
DAE0A0C9E39CCEFDAFB7E8999BB66F97A864BDCE8AC2D38FD7E8A4E3F4B0BFD08CDCEDA9
D7E8A4B7C88451621EB8C985CBDC98D2E39FD7E8A4D0E19DE0ECAA8B9A57DDEEAACEE39E
C9E39CCCE7A0D5F3AB64823ACAE59ECFE6A0DDEEAAC7D391E0E5A55D5D1F3F3900E5E1A2
DCE19ED5E59CCAE99DC2E79AC8E89FD1DD9BB19C6766521DD0E5A2C5EBA2C9E8A2CAE8A0
CAE89ECDE79DD3E49DD6E39DD5E4A1D5E4A3D7E6A5D8E7A6CCDB9AA9B575778343525C1D
869051818A4B37400173793BA0A668969A5DDCE0A3D7E2A0C9DF97D3EFA5D2EEA4D0ECA2
CBE79DC5E399CEECA2C9E99ECBEBA0CBEDA1C4E69AC5EA9DC7EC9FC4EA9DC8EEA1C7E99D
D4E8A3CEDD9CD7E3A3DAE6A6D2DE9EDBE7A7E0ECACD0DC9CD5E1A1B6C28292A1608B9A59
96A5648C9B5A5A69282733005F6529808449A8B074C8D496D4E4A3D3E8A5CEE8A1CCE7A0
C6E298D4F0A6C8E499C7E197DEF4A984994E7C8E44E0F2A8D2E89FCAE199CAE0A0D7ECB4
E5F7CDEEFFDDF5FFEAF8FFF3F8FFF6E7F5E6E4F0E2E6F5E2E4F4DAE6F6D9E9F8D7E2F4CC
E8FFD1C6E3ADC8E5ADC3E3A4C6E6A3C9EDA7BEDF9ACCEBA8C6E3A3D1E9ABD8EEB08FA364
4C5F1FDAEBA7CEDE97D6E89ECEE89FCDE99FCEE89FD1E79FD3E49DD3E39CD4E19CD2E19C
D2E39DCADF9ACBE6A3C9E9A8BDE6A2BBEAA6BCEFADB6E9A6C2EDA5C1EA9EC1EA9EC8EEA1
C8EFA0C5EA9AC6E997CAEB9ACBEA9ACEEB9BC7DF91DAF2A4C7DC91D1E69B8D9E57D6EAA3
CFE5A5CCE6A7CCE6A5CCE6A5CCE7A4CAE7A4CAE8A2C9E9A0
DFE4A4D5E09ECAE19BD1EFA7C5E59CCFE9A2DEE4A49D975B69561EE3CE97EBDFA5D5D597
E1EDABCFE6A0BDDD94ACCA82677C3799AA66D1E29EDBECA8D3E4A0D0E19DDDEEAACDDE9A
D9EAA6A9BA76546521899A56D9EAA6D6E7A3D6E7A3C9DA96BAC68496A562CCDD99D5EAA5
D5EFA8C4DF98CEECA478964ED2EDA6C2DC95CFE39EE5F1AFCAD0909294558A8649A8A467
EBEBADC8D190DEF5B1C8E6A0C5DE9CEDF2B8977A4E6B5023CAD89DD6F5B2D1EAA9C4DA99
D1E8A4D4E8A3D3DE9CE0E6A6DBDFA2E2E6A9D3D79AE3E9ABB7BD7F60692A535C1D485213
656F3078844498A464B7C685CEDD9CD8E7A6D8E7A6D1E6A1CCE89EC8EA9DC8EA9DC8EA9D
C8EA9DC6EB9DC5EC9DC3EC9DC1EA9BBBE696C4EF9FC1EE9DC1EE9DCCF9A8C7F4A3BFE899
CBEA9ED0EAA0CEE69CCFE79DD3EBA1CBE399C7DF95D2EAA0D6EEA4D7EFA5C6DE94CAE298
D9F1A7B9D18790A85E93A7607C85463B3F045F672B7D874A9EAD6CD6E9A7CDE49ECBE59E
D6F0A7C6E097D9F3A9C9E197D3E99ED8EDA28C9E54D8EAA0D7EDA2CAE097CFE6A0D3E9A9
CBE0A7EBFFCCEBFDD3F7FFE4F7FFEAE7F9E1F7FFF3F5FFF6EFFFF2F5FFFAEDFDF2F1FFF0
F1FFE4D6E8C0D2E5B7B2C49091A56AB1C588E0F4B9D7EAB2D1E2ACD1DFACA8B482848C59
4B531A8D9154A3A363979E5897AF637A9B4C8EAD5FBCD78ABBD389879B548E9F598A9E59
90A465ACC488557337C6E9AFCAF2BD7FAE7AA4D6A1B4E5ADBEEBA8BFE99FCAF4A8C4ED9F
AFD687D2F7A7CCEF9DCBED99C9E996C9E694D0E998D4EC9ECFE499D7ECA183944DCEE29B
E1F7B7DDF5B7DBF3B5DEF8B7DCF7B4CCE9A6C5E39DCFEDA7
CBD191DEEDAAC7E59DC0E49AC3E79DC9E39CDDE3A37F753A635018FAE9B1D3CD91DEE4A4
D0DF9CE3F7B26E7F3BC2D38FD8E9A5C6D793D6E7A3C4D591E1F2AED6E7A3CEDF9B93A460
4C5D19B3C480D1E29ED7E8A4C3D490CDDE9AD8E9A59FB06C657431DAE9A6CEE29DCEE39E
C7E19AC1DC95DEFCB4809E56CEE9A2D6F0A9D4E9A4D1E09DE2EDABE4E9A9AAAC6D5F5F21
4F4D12AFB378CADC9ED1EAA9C5D99CD5D5A1BC9971694721D7DEAAD0E8ACD4E6ACD1E0A5
CFE1A3DBE9ABDAE0A4C6C78BDEDEA2ACAC704C4C104344086E7235989E60BBC4859EA869
D2DE9ED1E1A0D2E5A3D3E8A5D2E7A4CEE5A1C7E09CC3DE97CAE89EC9E99DC8EA9DC8EA9D
C8EA9DC8EA9DC6EB9DC5EC9DC7EE9FC7F0A1C9F2A3BDE898B7E292BDE898C0EB9BC5EE9F
C6E999C7E897C2E394C4E594CEED9FCAE999C7E698D0EF9FC0DF91CEED9DC9E89AC7E696
D5F4A6D3F2A2C5E496C9E197CEDA98B2BA7E9EA86B6D793971803FACBF7DC2D792D8EDA8
CBE29AC8DF97D2EAA0C2D88FC8DE95CEE398B5CA7F869B50AABE76DAF0A7D5EBA3BFD690
E9FFBCC9DF9FE6FBC2DDF4C0EAFFD4F4FFE6EBFFE6E4F9E8F0FFFBF2FFFFF2FFFFF2FFFF
F4FFF4D3E8C9D2E4BEBDD0A32A3C0A879A63AEBF8B748654AEBF938B9C72919D75667146
7A8050DDE0A9D3D194DEE5A1CAE49AC8ED9DC7EA98CFF0A1C9E7A1CEE9A4CFE9A0CDE6A2
AAC38A8EAB758CAD761A3F0B2950245B855F528059306030AAD697C3EEA6B4DE94C9F3A7
CCF2A5C5EC9BBFE290CBED99CAEA97D1EE9CD3EE9DCAE294C6DC91D4E99E9FB069CDE19C
E5FAB9EDFFC5F5FFCFF5FFCDDBF4B2CBE6A3CEE9A4C2E09A
D6EDA7C8E29BDEF9B2C9E49DD4E9A4D0DF9C9FA464666427989457D4D496F1F7B7E2EEAC
C5D18F8E9957D2D898D6DC9CDBEAA7DCF0ABDAEEA9CBDF9ADCF0AB80944F455914D3E7A2
D5E9A4C9DD98DFF3AEDAEEA9D4E8A3D1E5A08B9F5AC9DA96CFE09CD7E8A4D9EDA8D1E6A1
D6EDA7D0EAA3B7D18ADDF8B1C3DD96D5EFA8D7ECA7C7DB96C9D895DDE8A6DDE6A5CED496
99985F55581F000B0064783DD5E4ABE2DCACBA8F6D6B4320E2E0B0C8D9A3D4E1ABD8E5AD
D1E0A7DCEAAFCCD1998F90565A5A1E54521558581AA8AA6BDFE4A4DDE3A3E2EDABD6E2A0
D8E9A5D2E7A2CBE59EC7E29BC5E39BC7E79ECAECA2CEEEA5CCE89ECDE79DCDE79DCDE79D
CDE79DCDE79DCCE89DCCE89DCAE69BCDECA0C7E69AC4E498CEEEA2CFEFA3C7E79BC3E696
CBF19ECAF29CC2E996C3EB95CDF3A0C9EF9AC3E996C9EF9AC7EA98CDF09CCCED9CC5E793
C3E493C5E793C7E897CBE79AD5E9A4DBEAA9DDECABCEDD9C93A3624D5E1A637732C5D994
CCE099E0F4ADCADE97DBF1A8DBF1A8CEE49BD6ECA390A65D8EA25BD3E9A1C4DA91DAF0A7
C7DF93D6EEA4CDE7A0CAE5A2BFDBA1F1FFDDF1FFE8F0FFF3F0FFFFEBFFFFEEFFFFE4FDFF
EAFFFFE5FFEFD5F4D4C1DDB52F4A1D587443173102E0FBD0C6E2BCC7E2BFD2EDCAACC59E
B2C598D7E4AFDDE5A9D5E4A1C7E79EB8E193D6FDAEABD184CAEDABC0E3A3D4F8B0BEE19D
B7D7A5C8E9BCAFD4A187AD7E456A48C6EDD0B0D9BB89B38B507C41C2EDA8B8E19BC6F0A6
CEF4A9BFE697C5E898C9EB97C2E28FC9E692D0EB9ACDE597D8EEA3CDE39A889C55627631
CFE4A3D6ECACCAE0A0CAE0A0DBF1B0CCE5A3C4DD99DFFAB5
C7E59DD0EBA4C7DB96D2E19E818A49282E004E5716909B59C4D08ED4E3A0CBDA97CDD997
9FA8679AA060EEF3B3D4DD9CC8D794D6EAA5C7DB968FA35E4E621DAEC27DD2E6A1D3E7A2
D6EAA5CFE39E92A661788C473549046B7F3AD2E6A1D7EBA6DAEEA9C7DB96C7DC97E2F7B2
CCE39DE2F9B33C530DCBE29CD5ECA6CEE59FCEE59FD5EAA5D4E8A3CDE19CD3E7A2E5F4B3
D8DEA2BBC388899B5F63783D4C5B224A42133F11006F42217871436F7C476C764148531B
2534003544094E571E484E12A6AA6DCFD494DCE1A1DDE3A3CFD897C7D391DAE9A6D4E5A1
CDE29DCAE49DC9E49DC6E69DC6E89EC8EAA0C8ECA2CBEDA1CDE79DD0E69DD0E69DD0E69D
D0E69DD0E69DD0E69DCFE79DCAE097D3EBA1C8E096CCE49AD8F0A6D2EAA0CEE69CC8E497
C2E593C4EB98C1E895C1E895C7ED9AC2E895BCE28FC3E694D0F3A1C6E796C9EA99D0F1A0
C9EA99C5E695CDEC9CD2F1A3CEE89FD3EAA4C0D590D1E5A0DDEEAAB4C581758441303F00
93A25DDAE9A4C6D791D8ECA5D2E8A0D1E8A0C6E097C9E098AFC47F94A861D8ECA4D1E79C
C0D88AD0EB9CD3EFA2C4E298C9E8A5D4F3BACDECC2C9E7CB94B3A44D6C675B787E86A9AD
4370699ACBB8C9F7DBB5DEBC578056001B00001A007FA782719D7C9DC8ACC7F2D66D9573
28481F85A06DD0E4A7CEE7A5CBEFAFA5D08BA2CD85D3FEB79CC58BC7F0B8B5E29DBCE9A8
B4DBAEA4CAA3D8FFCEC2E9BCAFD2B4395B43709279406440557C45C7F0AEC1EAA6C3EBA4
C2E89FC0E699CBEE9ECAED9BD2F29FC7E792C2DF8DBFDA8BDAF2A8D5EBA3BDD38B849954
7B9150889E5DB7CD8DCFE5A4BED493C8DE9DD7EEAAC0D995
D1ECA5C4D893A8AE6E5A581B5E5A1DE8EDADCFE39ECAE59EC5E59CC9E49DE5F4B1D9DF9F
797B3CCED494C6D592D4E8A3D4E9A4DAEFAA8FA45F809550DFF4AFD7ECA7CEE39ED2E7A2
CBE09B9EB36E778C47C0D590E0F5B0CFE49FC9DE99D8EDA8CEE59FE1F8B2BFD690C3DA94
D6EBA6869B564F641FD7ECA7CEE39ED0E7A1D0E7A1CDE7A0D1EBA4D2EDA6C8E39CBDD48E
CEDD9CD7E5A7E2FBBAC4DE9DD2E1A6EAE2B18355316133115F5728566129464F184D5B20
8CA061C9DF9EDDEDAEDAE9A8CAD996DCEBA6DAE9A4D4E59FD2E69FD8ECA5DCF2AACBE29A
D1EBA2D0ECA2CFEDA3CEEEA3CBEDA1C8EA9EC3E89BC4E499CDE79DD0E69BD0E69BD0E69B
D0E69BD0E69BD0E69BD0E69BD1E69BDDF2A7CFE499D0E59ACCE196C2D78CD2E79CD4ECA0
C3E296CDEDA1CEEEA2CCECA0D1F0A4CEEDA1CBEA9ED4F0A5CCE89DC6E096CAE49ACFE99F
CCE69CCCE69CD0E89EC9E59ABBDB90D8F8ADD3EFA5CEE59DC9DD96DAE9A4CBD692606926
ABB473D1DC9ADDECA9B9CD88C2D792E8FFBBC8E69ECDE8A1D0E5A08FA35CC8DC94D0E69B
C9E193D3EE9FCBEA9CCBEBA0CBEFA9C4E8AACCF1BE92B891577E617EA592C3E9DCE0FFFF
A6E3DB00372AB1EFD8B4EFCF4B825B0D4218B8EFC7BAF2CF407B5F407C63C2FEE5588F72
0013009FC997C4E8AAC3E5A8B5DDA84E7A454B7B3DAEE0A37CAB7DB5E7B6C5FCB9BCF3B2
86B68E76A480B5E1B0C9F0C154765B2A47310012001C3A16B3D8A4CDF3B6BAE1A0C7EFA9
C5EAA4C3E99EC3E598CCEF9DD3F3A0CAEA97CDEA9AC5E091D0EAA0C8DF97E8FFB9D5ECA8
CBE29ECAE19D889D5C596E2B91A663D4E9A6DCF1AED1E8A4
D4D999ADAF708A8649A3A164A9AE6EDAE9A6CEECA4CDF1A7C4E69CC8E39CD5E19FBEC484
A0A666C7D391DAF4ADCFEDA5D4EBA5CFE49F526722DEF3AEC7DC97C0D590DFF4AFCCE19C
D1E6A1667B36CDE29DCDE29DB6CB86E8FDB8BDD28DCAE19BCBE59EC9E39CDAF4ADDEF5AF
C7DC978B9F5AC3D792D1E5A0C5D994D0E5A0D1EBA4C8E39CC0DE96C4E69CCCF0A6D3F5AB
D3EAA4CAE19BBAD993CBEAA4E0F3B3E5DEA8AD7D578F5F39BAB37FDAE5ABE1ECB0D3E3A4
D6EFABCFEAA5C2DC95CFE6A0D9F3AAC6E097C1DB92D0ECA2D4F0A6C6E298C2DE94C9E79D
C5E399C4E499C4E499C5E59AC7E79CC8E89DC9EB9FCAEA9ECCE89BCCE89BCCE89BCCE89B
CCE89BCDE89BCDE89BCFE79BD2EA9ED0E89CC6DC91DAF0A5D8EEA3CFE59AE0F6ABCAE097
D2ECA3D7F1AACDE7A0C2DC95C5DC96C7DE98CADF9AD2E7A2CCE09BD7EBA6D8ECA7CFE39E
CDDE9AD1E29ED5E6A2D1E8A0D6FBADB9E293BDDF92DDF9AECCE29AC9D893E8F1AECFD492
2C3100464C0CD7E2A0E8F9B5D2E9A5C4DF9AC3E49DD3F2ACD0E5A0CBDC98A8B973CCE098
CEE69CD7F1A7B8D68CCFF0A9BCE19CBBE2A3CBF4BC79A5744F7C51B0DEB9E1FFF0BEF4DC
BBFEF58CD3CD78BBAAA7E3CA669F7E326A45B4EBCBAEE9CDB3F1DC2B6B5A5F9D8E5D9882
001D00709B6EB9DFA6C6E9B1BBE4BA6B9972B3E5B2BFF5C372A88439714AAFEDAEB3F1B2
86BE9982B692BAEAB888B280001500859E883F563A546C488CAC7BBDE3A8C2E8ABC7EEAB
BFE49ECDF1A7CAEC9FC3E696C4E594C1E18ED2EF9FD1EDA0D6F0A7BED891CCE5A1C2D995
DBF2AECFE6A2CEE3A0B1C6838196538DA25FBDD28FCEE3A0
9F7746785A26D1CB8FDEEAA8CAE8A0CFF5AAACD086D4F2AAC5D994F4FFBE45500E8C9856
D1E6A1D7F5ADC0E49AC2E69CD1ECA5000F00D4EBA5C5DC96D5ECA6DEF5AFCAE19BC9E09A
C1D89299B06AD6EDA7D0E7A1D1E8A2D5ECA6DAF1ABD9F3ACCAE59ECCEAA2C0DA93ADC47E
3B4F0AE0F1ADEEFDBACDDC99DDEEAACDE29DC8E29BD4F2AAD7F9AFC5EEA2BAE498BCE597
C7E59BD3F2A6BCE295CAEFA2D8EFA9E4DFA5AF82585F3006D9D29BD6E2A4D5E4A3CDE29D
C9E79DC8EA9EC7E79BCAEA9EB4D98BCAF1A2D5FCADC3E89ABCE193CBF0A2D0F2A5CCEEA1
CFF1A4CEEEA2CCECA0CCEB9FCAE99DCAE99DCDE99ECBEB9FC6EB9BC5EC9BC5EC9BC5EC9B
C5EC9BC6EB9BC6EB9BC8EB9BC8E99AC1E293BEDD8FD7F6A8C1E092B6D587DCF8ABC2DC92
D1E6A3C8DB9BADBD7E98A8699FAD6FADBB7DB9C587C3CF91A3AD70AAB477A9B175A6AE72
9DA5698A92569FA569CCDC9BC0E798B7E793C2EC9AD2F3A4CDE39ACFDC96E3EAA7E1E3A2
CDCF90707535687132CCDB9AD5EBAAC8E5A2C2E6A0C1E29BD0E5A0D6E7A3C8D99595A964
C9E09CC3DE9BC6E5A2C6E9A7D5FCBBB4DC9DBDE9ACC6F6BCB5E8AFB6EBB3B2E9B297D1A9
7DBAB3518E91568D87CEFFF24470572550356A967FC4F3E1C6FAEE295E561F544E9ACABE
436B5143633ECBE3B3CCE6B7BFE6C974A28872A680BAF2CB75AF964A8A689AE0A4A4E8AB
81BE9C578F6CB3E5B0739E68000D00CDE4CAB5C8A8A4B9901A3707B7DAA2CCEFB5C4E8A8
BEE19DCBEFA7D5F7AABEE191CEEF9EC4E594C8E799C3E294D2EEA4D1ECA5CFEAA5CDE6A2
CBE29ECFE6A0D0E5A0D7ECA7D0E49FA6BA7595A866B1C482
8D582C785422DED89CCEE29DC6EFA3BFEEA0C5EEA2CAE8A0D8E7A4CBD4934E5716C2D18E
C2D993CAEAA1C5EBA0C8EEA3C5EA9D213F00D4E8A1D6E5A0D5E9A4C9E09AC2E098D5F3AB
D0E7A1748944CADB97D3E7A2D3EAA2C6E097CEE89FC3DF95C7E399D6F2A8CEE8A18BA25A
97AB66D4E59FC7D894DCEDA7CFE39ECEE59DCCE69FC4E499BFE399BEE799C2EEA1C9F2A4
C6E69AC8E99AC8F1A2C6EFA0C0DC92DBDD9EB99062896032E9E7ACC8DB99D0E49FD7EEA6
C4E69AC7EC9ED2F4A7C3E696CFF6A7BBE293BDE495C8EFA0CFF4A6C8ED9FC1E396CCECA0
C2E296C5E498C7E69ACCE89DCDE99ECEE89ECEE89ECDE99EC6EB9BC5EC9BC5EC9BC5EC9B
C6EB9BC8EB9BC8EB9BC9EA9BC9E89ACEED9FD0EFA1CAE99B7C9B4D6B8A3CC4E395D4EEA5
D9E9A8C5D3969CAA6C85935597A567B4C483C7D796D4E4A3CCDC9BB8C688A9B779B3BE82
959E655059226A713BD2E1A6CAE9A6C7EFA6BFE49EBFE09BD0EDAAD1EAA8C9DB9DD0DEA1
D4DEA2B7C1853C460AD4E2A5CCE0A1D4EFACC1E09CD0EEA8D1E79ECCDD96D8E9A38EA35E
809655DDF8B5C9E6A3CCEBA7BFE09BCEF3ADBCE5A1BDE9AAC0F0B6B8EDB7A9DFAE6CA47F
0F4837477C728BBAAAB5DFCB5A81661A41268FB9A1C9F6E2CFFDF259867F5F8882A1C4BD
44614F324A30C3D9B3CAE5C4D4FAEB94C2B780B19BB2E6CF6DA3950B452F77B689B8F7C8
A0D9B90B4121BDEDBB8BB37F000C00B8CBAD8893718C9D730D2900C8EAB7BDE0AAC3E4AB
D0EFB3BFDF9CD0EFA9C5E59CCEECA2D5F3A9DFFBB1CBE69FC9E49FCFEAA7C5E09DCFEAA5
CFE9A2CFE9A0CCE39BC6DD95D1E8A0E0F5B0C5DA9793A865
9473405B440EE5E3A6D8E7A4C5E59CC5EEA2BEE499C9E9A0CEE29DD7E3A187904FDAE3A2
CFDE9BD6EBA6D2F0A8BFE598BFF19C7EA854B9C57DE6E7A5E2EBA8D4E9A4B3DC90CCF4AB
D1EAA6AAB976A5AB6BAAB571CBE198C3E294D4F3A5CEED9FD7EFA5BDD38AE0F6AE879D54
D3E9A1D0E69DCDE39BD3EBA1CFE9A0CDE99ECAE89ECBEB9FC9EEA1C9F0A1C6EC9FC5EA9C
CCE89DD0EFA3B7E092BEE99ACFEFA6D6DF9E9F7F4E8A6A39DAE0A2CCE7A2CDE7A0CCE89E
C8EA9EC6EB9DC9E99DCAE99DCAE99BCCE89BCCE89BCCE89BCCE89BCCE89BCCE89BCDE89B
CDE89BCDE89BCDE89BCDE89BCDE89BCFE79BCFE79BCDE89BC6E297D5F1A6C7E398D4EEA4
C6DE94DAF0A7A9BD756A7B3471823B98A9628EA25A94AA61CDE39AC9E1978BA55B738941
505F1E9CA86ACADA99D0E5A0D0EAA1CAE99DC5E898CEF3A3C6EB9DC2E79AC6E59FD1EEAE
C7DFA5D3E5B1CDDDAE90A0716875497A8E5DB4CE9EBEE0ADC4EFB9B6E3ACCCF7BFC4EBB4
BEDCA6D5ECB672834D273400C5D499D5E7A9C2D796D5EBA3D5EB99DAF09DBBD284D6EEA4
C9E39C6E8841D2ECA2D6EF9ED0E995D8F19EC1DD90C0DE9EC3E7B9567F61002314023222
447852A5D6A7BAE3B7BADFB45A80571A441E538562477A5B699983385F4D728C81869A91
25352A495E4F173720557C69A0C8C7729B9F638D8CCAF2F186AEAD000E053D6A5675A389
4E7B643B684BB9E1BCC4E4BD6177536B7656777B583B431C0B260092B386C0E1B2CFECBC
D6F2BFBFDAA5C8E1A8CFE7ADDCF1B6E6FBC0DBF3B5CBE3A5CDE5A7CFE9AACAE4A5C6E49E
D1EDA2CCE999C7E396C8E497CBE79CCDE99FCAE59EC6E19C
9F8E5673672DCFCF91DBE6A4D6EDA7CBEBA2C5E59CD8F6AED2E9A3D5E6A2515D1B7B8644
D7E3A1D6E7A3B8CD88DBFDB1C6FCA6B6E38EA7B1688D8A47C8CD8BD3E7A2C2ECA2C1EDA2
D5EEAAC8D492999E5C616824DAEFA4D9F6A6C0E28EB6D585CFE59AE0F4ACC1D58D99AF66
BDD38ACBE399D3EDA3C6E096C9E59AC9E89CC5E498CAEA9EC3E598C7EC9EC2E799C6E69A
CDE79DD4F0A5C6EFA1CAF3A5CFEFA6D4DF9DA789578E7240D7E1A2CAE8A2CCE7A0CAE8A0
C6EB9EC6EB9ECAE99DCCE89DCDE89BCDE89BCDE89BCDE89BCDE89BCDE89BCDE89BCDE89B
CDE89BCDE89BCDE89BCDE89BCDE89BCDE89BCDE89BCDE89BD7EFA5BFD78DC8DE95D2E69E
D9EAA343530C9CA963E1EEA8C7D28DE1EEA8D0E099C2D38CDAEEA6DBF1A8C7DF95CDE39B
C4D392DBEAA9D7EBA6C9E098CAEB9CC7EE9BBCE893BCE994C1F19DB3DF90D5FFB5BDE29F
C1DEA4DEF6C2293F10C4D3A800070095A0766077495A7F4C001400588F583F763F85B67F
CBF0BCCAE5B2B5C795414D1BB1BB86D7E4ACD7E6ABD0E49FC5DC8AC5E18AE9FFB5BBD78D
CFEDA79DB873D0EB9EBED784D4EB91D1E88ECFE793D7F2ADCEEFC0000F00234E47AEDCCF
B2E2B2D7FFC4B8DBA1DCFDC87C9D6E80AA7CC2F5CADFFFED4A7559CAEAD3CDDBCEC3C8C1
A5ACA5D2E2D8EAFFFB547C71DFFFFFDFFFFFD5F6FBCAE9ECD9F7F7C5E4DFC4E4D95A7C6B
4D735ACCF1D2B5D7B4D2ECC7D3E3BECED6AF0C0A001C2100000F00000F00C2E2B3C6E1B4
ACC59BF5FFE1E8FAD0F6FFDEF8FFDDF7FFDAE7FBC6CEE6ACCCE4A6CFEAA7CCEAA4CEECA4
CDEBA1CBE9A1CBE9A3CDEBA5CEEBA8CBEAA7C5E3A3C0DEA0
BEB87C7E7A3D979759D1D797DAE6A4CCE09BCCE39DC5DF98C7E19ACAE49D8FA6608BA05B
C0D48FDFF0ACD8E7A4C5DC94BBE694D8FFAEC2CE86888947B9BE7CB6C783C5E9A1C1E79E
CCE7A0D6E7A3E4EBA88E9551CDDD94CBE395D3F5A1D3F4A3CBE397D0E69DCFE59CABC379
DFF7ADC1D98FDDF7ADD3EDA3CFEBA0D3F2A6CBEA9ED5F5A9C7E79BD1F3A6C9EB9ED0F0A4
C6DE94C4DE94C2E79AC7EDA0CBE9A1D4DD9CAE8E5D866836D7E1A2CAE8A2CCE7A0CAE8A0
C6EB9EC6EB9ECAE99DCCE89DCAE99BCAE99BCAE99BCAE99BCAE99BCAE99BCAE99BCAE99B
CAE99BCAE99BCAE99BCAE99BCAE99BCAE99BCAE99BCCE89BD1EBA1D5EDA3DDF3AABFD38B
99AA63DEEEA7BECE87D9E9A2D7E49EE3F3ACDCEDA6CFE39BCEE69CCBE59BCCE69CD9F0A8
D7EBA6D9EAA6CADF9AC3DF95CFF1A4CFF9A7C4F19EBEED9CBFEE9ECAF6A9BAE49CA4C986
729054334C15CEE2AFD9E9B898A26E94A36CC5DEA5C7EBAEC2F0B2B8EAADBEF0B58BB67E
8CAD78758B5ABCC99BA1AA7B2E3806D5E2ADCEDFA9CBE1A3CAE99DD4F7A7C0E19AD1F4B2
BDE1A3B1D49488A761B9D88AD2EE97CAE48BC3DF8AD6F6ABADD3982D572F86B69EACDDC0
C1EDB8A8CE918FAC74C3DEA979956485A677C7F2C5E4FFE8CDF0D0C7DFC7E4E8DAD4D1CA
D2D1CCFBFFFBF0FFFCE7FFFBE9FFFFDCF9F5ADC6C2F0FFFFE8FFF5ECFFF6CDE6D1D2EFD3
E3FFE2DDFBD5CFEAC1D2E7BCBFCCA0EEF1C4999568595B2CC6DDA7D6F4BECBE7B6C0DAAD
E2F8D2F5FFE8F5FFE8F7FFEAF5FFE6F6FFE2E3F7C6CBE3A9C8E39EC9E89AC9E994CDEC9C
C7E1A4CAE2B0D0E8B8D8F2C2E3FDCEEDFFD8F2FFDFF2FFDF
D4DA9ADADF9F7B7D3E8E9051DCE1A1E8F1B0D2E19EDCF1ACCCE7A0C0E097CDEFA5AAC880
708741ACBD79E8F1B0CCDB96C1E396C8EA9DE1F1AAD5DA98C1C7879AA664ABC681C9E8A2
CBE69FBDD28DE0E9A6BEC581B7C37BCCE194CDED9AC3E694D5F0A3BFD78DDDF5AB92AC62
CEE69CC2DC92CAE49AC2DC92C7E398CEEA9FC2E195CFEEA2BEDD91CBEB9FC2E296CDE99E
DEF4ABCDE59BC9EB9FC7EC9FCFEAA3D6DC9CAB89596B4B1AD8E1A2CCE7A2CDE7A0CAE8A0
C8EA9EC6EB9ECAE99DCAE99DC9EA9BC8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EB9B
C8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC9EA9BCDE79DC2DA90CAE097D5EBA2
ADC179D3E49DDAEBA4CFE099D2E39CCBDF97CEE29AD2EAA0CEE89ECAE69BC8E499C5E196
C9DF97CDE39BCBE59CC9E79DC7EC9FC1EA9CBAE697B8E799B6E499BAE59D8FB8727A9F5C
CBE9ABCCE5ABD2E7AF8A9C6296A667CBDF9ACEE9A4C7EBA5B4DD99C5F2AFBDE7A8C9ECB2
C6E1ACDCEEBC5864363F481B848D5E323E0E5E6E3DD0E9B0D4F8B2B1DB93BDE7A7BAE3A7
C7F2BAB6DFA7AFD6973C5D16C3E292D3F49DD0F19ABEE191C0E9A500170010431893C399
C0E9B177995C97B077CADEA9D4EBB7AAC494CEF2C2B2D6AADAF5D2F8FFECF8F5E6E6D9D1
C8BDBBFFFEFBF6FFFEF1FFFFF2FFFFDAEEE55B6B61F0FDF3F4FFF5F7FFF4EBFAE5F5FFEC
F0FFE4F4FFE4F5FFE1CBDAAFF2F9CFD8D7AB968D625F5D2DCADDA6CDE8B1CCE6B6EEFFDB
F5FFE6F2FFE5F2FFE8C2D2B8D4E4C7D9EDC8D2E8B9C7E1A4C9E79DC9EB95C6E98BC9E996
CEE5AFD8EAC4E1F6CFE8FED7ECFFDBE9FFDAE6FFD7E5FED6
D5E6A2CFDB99666C2C636325898548CAC88BE7EDADCFE09CCDEBA3CAF0A5C5EEA2B6DC91
849F589CAD69B2B777DDE3A3E3FAB2C2DE94D1E59EEBF7B5CED4949BA465788B49D1EAA6
CFEDA5D7F1AAD2DF9AD7DE9AA1A761DBE99EC2E28FCDF09CCBEA9CD2ECA2C4DE9489A55A
91AB61CAE69BD1EDA2CFEBA0D0ECA1D4F0A5CCE89DD4F0A5CAE69BD1F0A4CCEB9FD4EEA4
D3E49DC6DA92C9E79DC2E297CFE9A2D7DC9CB38F5F6F4D1DD8E1A2CCE7A2CDE7A0CAE8A0
C8EA9EC6EB9ECAE99DCAE99DC8EA9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9D
C6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC8EA9DB9D58AE1F9AFCEE49B99AF66
8B9F57CEE29AD9EDA5CCE098DDF3AACCE49ACDE59BD1EDA2CBEA9ECCECA0D1F1A5CDECA0
D0EB9ED0EB9ECFEEA2CAECA0BFE59ABBE59BBFEDA4C2F1A9D7FFBD9CC78290B774A6C987
C7E4A4D0E8AAB0C6884C611EA6BD6FD3EC9BD9F6A6C0E192C9EEA1D9FDB5CCECA9B5D194
D1E4ADC9D5A3CFD7A86D7546A1AA7D0009004052229CB983A1CB8BB9EAA8C2F4B9BFEFBB
BAEABAA3D1A2749F69284F106E9248D2F5A3B8DC85DAFFABC7F1A54E80391F551715470C
4870323F5D1FB6C991CFDEA7D0DFA87E935BD2EFB9CDE9B8DAECC4FFFFE6FDF0DFFFF9F1
FBE6E5FEF0F0F4F6F5F8FFFFE8F1ECFBFFFBE2E7E1F8FBF4FFFFF8F6F8EBFCFFF1FBFFEF
F9FFECF8FFE8F4FFE1F3FDDAD2D3B1CFC9A7A194727B734EE9F6CAB4CA9BF5FFDFF7FFE3
D7E8C6F1FFE1F0FFE2CCDDBDC6D7B3CDE2B7CBE4ADC7E4A2CEEEA2CCF099C7EC8DCBED99
D4E9B1E3F2C9F4FFDBF7FFDFF5FFDDE2FACACDE5B5BFD7A5
D4EBA5DAEEA9DFE8A7DCDC9E6C682B4440038A8C4DCFDE9BC1DC95D4FAAFC6F0A4D1F7AC
D1ECA5D7E8A4A8AA6BA7A96AD0DF9CD5EAA5C5DC98D5E8A6D5DE9F9FA5674E5819D5E6A2
BBD991CEECA2D1E29BD7E19A4D4E089AA45BC2DF8DC5EB96C0DF91DAF6ABCAE69BB9D58A
9AB66B779348BEDA8FD7F3A8CEEA9FCBE79CCAE69BC7E398CBE79CCBE79CCDE99ECEE69C
CFDC96D1E19AD7F3A9C3E197D4EBA5D7D99AB692627A5828DAE0A2CCE7A2CDE7A0CCE7A0
C8EA9EC6EB9ECAE99DCAE99DC8EA9DC5EC9DC6EB9DC5EC9DC6EB9DC5EC9DC6EB9DC5EC9D
C6EB9DC5EC9DC6EB9DC5EC9DC6EB9DC5EC9DC6EB9DC8EA9DE1FDB2C2DA90B1C77E40560D
CFE59CDFF5ACCAE097D5EBA2CFE79DC9E399CEEA9FCEEDA1C3E397C0E295C6E89BC8E99A
CBEA9AC5E494C7EA9AC7EC9FC3EBA2C8F3ACC6F3AEB6E5A14A7736739D5BC3EAA9C1E4A2
CDEAA8C3DC9A8CA35FCCE299DAF39FC2DE87C7E58FE5FFB2B2D183C2DE94D3ECA8E3F5B7
DBE6AEDEE7B2E0E6B6D8E0AF919A6B4656255C703D4C6A34689658689C5E91C6908DC191
82B58C94C49C97C295CDF5C08DB1711F4100CAEB9CB4D785C5EE9FBEED9FC3F7ADC8FAB5
CCF3B2B6D295E0EFB4E4EFB5CFDDA28B9D61CFE7ADBDD49CF7FFD6F6F6D2FFFBE6D9BDB2
E8CCC9FFF9FAFBF7F6FCFFFFFEFFFFFDFDFDFFFFFDFFFEFDFFFEFBFFFEFAECE9E0FFFFF4
F3FAEAFBFFF1F2FAE3FFFFECFCFAE3FFFAE3D9C8B4C6BCA3EDF4D5F3FFE1F1FFDFF8FFE6
F8FFE4F8FFE3E0F0C9D0E3B5CCE3AFD0E9AFC9E6A6C5E49ECAEC9FC7ED9AC4EA93CDEDA1
DFF1BDE6F3C8E9F8CDEAFBCEE8FCC9DFF6C0D5EEB4D0E9AF
CADF9AD1E5A0CDD896DBE0A0CBCB8D666628212600778341A0BA73BCDC93C5E99FC3E59B
CAE49DE2F3AFD2D8989BA060A4AD6EDBEAA9CCE5A3D0E7A3D7E3A39B9F62606525D7E2A0
DDF8B1C7E79CD1E79EDFEBA362621C8D934BE1FCABC2E593CAEB9CCCEB9FD8F7ABD3F2A6
BCDB8F4F6E2293AF64A7C378D2EEA3C5E196CDE79DBED88ED4EEA4C8E298D2ECA2CBE198
DAE5A0DDEAA4D6F0A7B6D48ADBF0ABDADA9CAE88596F4B1BDBDFA2CDE6A2CFE6A0CCE7A0
C8EA9EC8EA9ECAE99DCAE99DC8EA9DC6EB9DC8EA9DC6EB9DC8EA9DC6EB9DC8EA9DC6EB9D
C8EA9DC6EB9DC8EA9DC6EB9DC8EA9DC6EB9DC8EA9DC9E99DBCD68CD7EFA56D853B8FA75D
C9E197D8F0A6CDE59BC9E399C4E095CAE99DD0EFA3CEEEA2C9EB9EC4E99BC2E799C3E696
CDEE9DC6E997C9EE9EC9EFA2C2ECA4C4EFAAB1DE9D8AB6778AB475C9F1B3B0D796C9ECAA
CBE8A5D8F2AB7A9149DAF2A4C4E08BDDFBA3CAE892BDD985DBF3A5DBF1A8C8D794D1DB9E
A4A96F6368308F9360868D5943501A576831677C43C7E6ABC3F1B181B4797AAF7BA9DEB0
0B3D17A9D8B4D2FCD8B5DAAFC2E2B089A76B8DAB65D5F3A9D9FBAEADD688C0EC9FB9E49C
CDF2ADCBE8A8CFDFA1D4E0A2AEBA7C748445CBE1A0D5EBADFCFFD4FFFDD4FFF8DDE1C1B2
F6D7D2FFF9F6FFFEFBFDFDFFFEFBFFFBF5FFFFF9FFFFF8FFFAEFF7FFFCFFF3EDF1FFFEFF
FEFFFDFCFFFBF8FDF6F1F4EBFFFFF8FFF9F2FFF0EBDFD2CCFFFFF8F9FFF2F9FFF1F5FFE6
F5FFDDF9FFD8DCF0B5CBE29ECDE79ED0EC9FC8E799C4E596C8EA9EC4E89EC1E59DCBE9A9
F8FFD9EEF9CFDBE8BACCDCABC7DAA3C8DEA0C9E2A0CBE6A1
61722E546320BCC886DFEAA8C4CD8CD8E1A0BDC88691A05D687C379BB26CC6E099C7E19A
D6EBA6C8D995E3EFADD6DFA0A0A469CDD79AC7E29FD0EDAAD4E3A29B9F6298985ADBE1A1
CAE69CCAEA9FCCE49ACFDC94A2A35F767C34C6DE90CFF2A0CBEC9DC0DF93C1E094CAE99D
CBEA9ED4F3A7C2DE93ADC97E94B065829E538EA85E77914799B369859F5596AE64899D55
929D58919E5887A1587B974DCCE19CE1DFA2B28C5D6E4A1ADBDFA2CDE6A2CFE6A0CDE7A0
C9E99EC8EA9ECAE99DCCE89DCAE99DC9E99DCAE99DC9E99DCAE99DC9E99DCAE99DC9E99D
CAE99DC9E99DCAE99DC9E99DCAE99DC9E99DCAE99DCAE99DD6F0A6AFC77DA6BE74D6EEA4
D0E89ECAE49ACDE79DCEEA9FCDECA0CEEEA2C4E498BCDE91C8EA9DCEF3A5CAEFA1C7EC9C
C8EB99C3E996CAEFA1C3ECA0BBE49EC5EFADBBE5A692BE81C3ECB0BAE2A4D1F5B7C8E8A5
C6E49E7690478CA458C9E193CDEA96C5E590D1EC9BC9E193D6E89EDDEAA5D2DB9CA1A76B
72733993965D9CA16997A06792A065DBEDAFC4DA9ACAE8A8C4EEAEB7E7ABB5E5B1BDEEC1
7EAC88659072C1E6C7C5E7C6B0CAA35B734393A870CDE3A3BDD895DEFEB5BFE59CCBF1A8
C2E5A1CAE7A5CBDE9ED4E3A2BECD8A6E7F3BCAE19DD1E6A5F7FFC8FAF7CAE2CDAEEFD0BC
E6C8BEFAE6DFFFFEF8FAFCF9FFFEFFFFFCFFFFFCFFFFF6FFFFFBFFF7EDF5FFFCFFFFFDFF
F9FDFEFBFFFFF9FFFFF8FEFAFFFFFDFFFEFBFBF1F0CAC0C1CFCDCEF8FDF7FAFFF2FBFFEA
E8F5CACCDDA6D9EEA9CEE796C7E38ECAEB92C8E992C8EB99CFF1A5C8ECA6C2E6A6CCE9B3
F9FFE1F3FAD8E2EDC5D8E5B9D5E6B2D4E9B0D1EAA9CEE9A4
DCE5A4D1DC9A9CA866DDEEAACFE39ED6EAA5C3D792D7E8A4D0DC9A4D5816515C1ADDE9A7
CFDE9BD3E7A2C3DA94D9E9A8989C61DEE3A9C3DE9BD6F5B1CADA999DA365969457E1E6A6
C6E097D6F6ABC0DC91DDEEA7D7DC99696F29DFF7ABBFE091D7F6AABCDB8FD1F0A4CEEDA1
C4E397CCEB9FC7E398D2EEA3CCE89DCCE89DCDE79DCDE79DCDE79DCDE79DCFE79DD1E59D
D3E09A9CAC654C661D425E144B601B101000B18B5C755121DEE2A5C5DC98CADF9AD1EBA4
C9E99EC4E499CAE69BCAE49ACEE89FCCE69DCCE39BCBE59CD0E79FCEE89FCFE69ECBE59C
CDE49CD2ECA3CFE69ECFE9A0CAE199C8E299D9F0A8CDE49C7E964C9FB76DC1DB91D1EBA1
D2ECA2CEEA9FCCE89DC7E69AC2E195C9E99DC9E99DD6F8ABBADC8FD0F2A5CCEEA1C4E699
C9EC9CD5FAAAC0E598C6EEA5C6EFA986B0701B4506C3ECB0C8F0B4C6ECAFC8EBABCCECA9
B5D38B89A359D6EEA0CEE698C3E294CFEEA2CDE79ED8ECA5D9E5A3858E4F52561BBBBC82
FFFFCBF2F6BBD0D89CDCE8AAD3E3A2D2E6A1CBE29CCCE7A2C8EBA9C3EBAFC1E9B5C5ECC0
B7DFBD35593DAECCB492AA922A3A20505E3DB5C098D0DDAFD5E6B0CCE1A6CBE5A6C1E09D
C1E6A0CFF0A9D1E8A4CFE09CDAEBA7CDE19AB8D28BCBE29EFCFFCDE4E4B2ECDAB663472F
A28877F9E7DBFFFFF3FAFFF7FEFFFBFEFEFCFFFFFDFFFEFDFEF8F8FEF8F8FFFFFDFEFFFB
F7FFF9AEBBB2C8D8CE96A39A667068252A236E6D68706D68AAA9A5FCFDF5FEFFF1FCFFE6
DEEBBFD0E2A8DBF1A9C8E190D3EF9ABCDD84CFF099D1F4A2C2E498C2E6A0BFE2A2C7E1B1
F8FFE9FEFFF1FCFFEDE8F3D5CFDDB9D0E3B5D2E9B3C5DEA4
D1D394EBF1B1859451495E19CAE59EC8E39CD1E8A2D2E39FE9EFAFE6E6A8545416929455
DBE6A4D2E6A1D4F2AAC9E29E95995E909459D0EBA8C8E7A1DBF0AD929D5B868648CDD292
C7DD95C7E59BCFEDA3D4EBA3E0EBA7B5C07C7D934BDCF8AEBEDA8FD2F1A5CEEDA1C9E89C
D0EFA3CCEB9FC8E499C8E499CCE89DCCE89DCDE79DCDE79DCDE79DCDE79DCDE79DD0E69D
CADA93D3E49DC1DD93CDEBA1D6EDA7C2C4859F794A734F1F676B2E869D59BED38ED4EBA5
C8E69CC9E99ED5F1A6D6EEA4D5EBA3D8EEA6D2E69FC6DC94CADE97D7EDA5DCF0A9D4EAA2
CFE39CD7EDA5CDE19AD4EAA2DEF2ABD2E8A0BDD18A96AC6496AE64ACC67CC5DF95CCE89D
CBE79CC8E79BC7E69AC5E498DBFBAFC8E89CC1E195BFDF93C2E296CAEA9EBCDC90CEEEA2
CCECA0C1E397CDF1A7B2D791A2C986B8E19FAAD294C3EBADBEE4A7BDE1A3BFE2A0C3E29E
A4C27893AE61CCE496C6E194CCEAA2C9E6A3D1E7A6C3D395DCE4A965682FC9C993EDEDB7
E1E2A9DFE4AACFD99CD5E4A3D5E6A2D0E49DCEE49CDAF1ABC9E3A4CCE9B1C2E0AEEEFFE4
E5FFE4A3BFA8BCD1C06677675C6455B8BCABF2F4DCFFFFE4ECF4CD96A375E0F2BED2ECAF
C8EDA7BCE297D6F0A9D1E5A0CDE19CDEF3AE77924BD3ECAAF5FFC9FFFFCFE9DAB3685132
B29C85F3E7D1F1F6DFF8FFEF74806A737C678E937F5558458586749D9E8CE2E7D3CCD8C2
C9DBC34A61471A321A2940265E705A829079A0A9947B806C686957E0E2CDDCE0C5CAD2AD
CFDBADD2E3ACC7DC9BC8E299BEDA8DD0EF9FD7F8A7BADB8CCCEEA2D1F5ADD6F7B2D3EEB9
F7FFE9FEFFF6FEFFF1E7F1D8CFDDBACDE0B3D3EAB4D0E9AF
E7E7A9DDE3A3D3E4A0D7F1AA63833AC7E79ED6F0A9D8E9A5D7D99ADBD79AE2D99E625E21
E6EFAECEE39ECBEDA3BAD8929DA1665D5E24E0F6B5BEDD97C7E09CB5C6825F6424E8EFAC
DBEFA8CBE79DCBEBA0C3E199CEE39ED4E5A1CFE2A08EA35E92AC63D4F0A5C3DF94BEDA8F
D5F1A6CEEA9FD1EDA2CCE89DCCE89DCCE89DCCE89DCCE89DCCE89DCCE89DCCE89DCFE79D
D5E69FDFF5ACCEEEA3CEF0A4D3EDA6F2F7B79A7646735121E6EAADC0D7939AAF6A768D47
6E8C4284A2587F994F5C722961752E9CB069D3E49EDAEEA7D4E59FD0E49DCEDF99C3D790
D3E49ED3E7A0AABB7596AA63AABB75ACC079A4B56F8CA059BBD389C4DE94CEE89ECEEA9F
CBE79CC9E89CCAE99DC9E99DC2E296C4E498D3F3A7CBEA9EDAF9ADCDECA0BBD78CD2EEA4
C4E29AC5E49ED3F2AEC0E09D799C5AB9DD9DC9EDADBDE4A5C8ECACC8EBA9CCECA9CDECA6
A1BF75B7D386D1EC9DD4EEA4C8E5A2CAE6A9D5E9AECEDBA5D3D7A4525220FFFFD3F1F1BF
CFD49EEAF3BCE9F8BDD2E4A6D2E5A3CDE19CCADB95D0E09FD7E6AFEFFFCED1E4B7F5FFE4
F4FFEDAEBFAC8C9A8D878E86E6E8E3FFFFF8FAF6EBF9F6E3D1D1B73C42209FAA80C3DAA4
CBF0AA4F782A617D3394A964B8CC87DDF2AF7E9956CDE7A6E2F4BAE7EBB8F6E8C1624E2D
736244F0EACAECF7D5DCF2CBA8BE90A7BB8AC3D3A679865AAAB58AB3BE93F3FFD6D2E5B7
D4EEBEBEDCAAB9D9A8D2F2C0C1DDADD7EFBFE5F8CAEEFED1A5AC80DFE5B7C5CCA0687144
E1EDBFC9D9AAD6E8B6F0FFD1D3ECB3CAE6A9BEDD9AC6E69DC5E599C0E393C5E695C2DC9B
F8FFE7FCFFF2F9FEEAE7F2D4D1E0B9C6DAA7C8E0A2CDE8A5
DCE2A2C9D492D9EDA8C3DD96729048D2F0A8C4DB95CCD896E0E2A3DEDA9DECE3A8777538
A9B271C9DE99D1F3A9D7F5ADBABE813F4004DCEFADCDE8A1C4DF98E4FBB394A15CDCE5A2
CBDA95D0E69ED4F4ABBCE098D2F1ADC4DF9CD6E6A8D4E4A59EB56DD6F0A6D5EFA5CBE79C
D2ECA2CBE79CCDE99ECCE89DCCE89DCCE89DCCE89DCCE89DCCE89DCAE99DCAE99DCCE89D
D1E79ECBE59BBBE093BDE396C3E199CED494BD9D6C6F4F1ED6DC9ECFE8A4D3EAA4C4DB95
ABC97F97B56B6A82382E4400273B006D813AB6CA83D4E8A1D3E7A0D2E69FD7EBA4DAEEA7
96AA63BCD089ABBF78A2B66FB8CC85C0D48DC3D790C3D991D2EAA0D0ECA1D0ECA1CBEA9E
CAE99DCBEA9ECBEB9FCCECA0C8E89CD3F2A6CBEA9EC5E196C5DF95C5DD93CEE69CCFE69E
E1FAB8CBE5A6B8D5953C5A1A8EAC6CB2D291CFF2B0C8EBA7C5E8A4C8E9A4C9E8A2C9E79F
91AD63CAE69BC8E396CFEBA1C4E19FD4EDB3CFE0A9E5EFBBAEB2806D6C3EFFFFD6DEE0B1
CFD7A6F4FFCDF8FFD4D0E5ACD1E5A8D9E9ABD4E2A5DBE4ADAAB084999D78ABB290A6B193
9DA993879282D6DDD5FEFFFDFFFEFFF1EBEDFFFDFAFFFEF4FFFFEF777B605057355D7140
4F742E436C1D0A26002E4300E1F4B2CFE3A4849E5FCEE6AAE0EEB9EDF0C1FFFFD847350F
100200BCBA93C4D5A8CEEBB5C6E4A4C4E19ED2EBA9C9DE9DCBDE9ECADD9DD4EAAAC7E1A0
CBEAA7C9ECA8BBE09BCDF5AFBDE09CD0F0ADC6E0A1CDE1A2838F4FE3ECADD7E1A52E3803
6E7A4A5E6E419AAB81E2F7CCDEF5C9DCF7C4B5D298DDFCB9D8F8ADD7F7A4C3E48DD4EEA7
FBFFE6FEFFF1FCFFECF6FFDFE9FACDD6EBB2CDE6A2D4F0A5
CCDD99D4E8A3CDE29DD5EAA5D9EEA99BAF6AA4B370DCE5A4E5E7A8DDDD9FDADA9C979C5C
9BA765DBF0ABBCDA92C9E09AD8DE9E57591AC8D794D0EAA1D3F1A7B3D286D5E9A163702A
DBE6A2DBECA8B6D58FCFF9B1BCE7A0D6F9B7DDECB3CCD59C9BAF6AAAC278D3EBA1D2ECA2
C9E197CCE69CC7E197CFE99FCCE89DCCE89DCAE99DCAE99DCAE99DC9E99DC9E99DCAE99D
CAE69BCEEDA1C4ED9FCDF8A9DDFFB5CCD795CAAC7A987A48CDD697CAE39FDAF1ABD9F0AA
C8E49AC5E197CBE198C3D990DDF3ABC2D7929BB06B788D48647934647934768B468A9F5A
95AA65CCE19CCFE49FCCE19CD8EDA8D2E7A2D4E9A4D9F0A8D0EAA0CCE89DC9E59AC6E599
C7E69AC7E79BC8E89CC9E99DC6E599CCEB9FBCD68CDFF7ADD2E89FCCE098EAFBB4CCDD99
7E9257C6DBA391A96F041E006A8445DFFCBAC7E6A2D3F2ACC6E69DCAEA9FC5E59AC6E49A
85A157D2EEA4C1DD93C9E49DCDE7A6D3EBAFCAD9A2DAE2AF8F916297986CEFF0C6E5ECC0
D2DFB3D2E5B7D6EEBECDE5B3D5E9B8D0DEADA8B081A5A77FB5B093F0EAD4FFFFECC9CCB9
FCFFF3EBF3E8F0F5EFFFFFFFFFFDFFFFFAFEFFFCFFF5F0ECFBFCEEEDF2DBA1AA8B90A375
7B9F57D6FBAB98AF67738342E0EEB1C7D69DB1C68EBCD09BCFDBABE4E5BBCABC95513F19
71653BE7E6B6C4D9A1D2F2B1CBF0A3C5E898C4E093DEF9ACCCE297D1E79CCBE399D2EEA3
C4E498CAF1A2C4ED9EC5EE9FBDE495C8ED9FCEECA2DDF5A99AA85BD9E498CFDA95C6D496
87956056683850623ADFF4CDEDFFDCF2FFDFD2EDBAB5D194BFDD97C7E396C3E18BDDF4AE
F9FFE1FCFFEDF7FFE4F9FFDFF8FFD6E1F7B7CBE59BCFEC9A
D8F6AECAE59EE4FBB5CFE39EC8D492CDD695585E1EE5EAAADBE0A0CAD090E9F2B196A260
4E5F1BA5B974CFE6A0DAEBA7C0C686616624DDEAA5B4CA81CCECA0E0FFB5BFD98FACBD76
9DA461CFDB99D4F3ADC4F2AAB1E49FB4DE9EDDEBB6DEE3ADA6B57296AC63C8DE95D3EBA1
CBE399D4ECA2C8E298D1EBA1CCE89DCAE99DCAE99DC9E99DC9E99DC8EA9DC8EA9DC8EA9D
C9E89CD2F4A7B9E596B4E393C7EDA2D9E5A38E7240CEB07EECF5B6C9E29EC3DA94CBE29C
CCE89ECFEBA1D5EBA2D0E69DD0E7A1C6E099C8E29BD4EEA7D7F1AACEE8A1CBE59ED1EBA4
C8E29BDFF9B2CFE9A2C4DE97C7E19AC1DB94C8E29BCCE69DCCE89EC7E69AC5E498C8E89C
CAEA9EC9E99DC9E99DCBEB9FC5E498D0ECA1CDE59BD9EFA6B9CA8381914A99A660838F4F
5A6833ADBF8DB4C6922F440B859D5FC5E09DCEE9A2C2E096CEEDA1D5F4A6CBEA9CCEEDA1
8AA65CD8F3ACC9E49DCEE9A4CDE8A5CBE1A1DAE8ADD0D9A49C9E6FA3A478D6DBB2E0EBC1
D7E9C1CEE7BDDBF6CDC8E1B986987284906CA5A988FFFFE6FFF6E8FFF8EFFFFDF4F9F7EB
FCFDF5FCFFFAFEFFFDFDFDFFFBF6FCFFFCFFFFF9FDFFFEFBFFFFF4FCFFEDE5F3D2CBE1B2
C9EAA3CFF0A1D7EDA5E1EDADCED79EDEEBB6CBDBAA7C8C5FD2DBB0BDBB945C4E29625028
B6A97CD9DCA5D6ECACBFE099CDF2A2C6EC97CDEC9CCEE99ACAE294CBE294CFE79BC6E393
CBEC9DC4EB98C2EC9AC4EE9CCEF5A4CDF2A2C5E697BCD4868E9D4CDFEC9DD4E199E0EFAC
BDCC91D3E5B18FA274738A5E819B6E718B5CCCE7B2D4EDB3D4EEADC2DC95DCF7AAC0D698
FBFFEAFBFFF4F9FFEFF8FFE6F7FFDDE0F8BEC3DE99C6E297
B8E296C2E69CCCE69FD9E8A5DDDFA0F5F1B4ECE8AB42420497A05FDCEBA8C8DD98D6EDA7
495E1995A964E0EFACCAD593DADF9DD9DE9BD2DC97E2F6AED8FAADAFD685C6E798CFE59C
D0D5933C4504CBEAA6C2F4ADB0ECA6C7F8B7F7FFD3FFFFD2DDE9A9C9DD95C4D890C9DF96
D5EBA2D5EDA3C8E298CAE49ACCE89DCAE99DCAE99DC9E99DC8EA9DC6EB9DC6EB9DC8EA9D
C2E497C5EC9DB9EA99BCED9CBCE599E0EFAC5F4512BDA16FCDD798C0DB96D1E8A2DDF4AE
D2ECA3CAE49BD0E49CCEE49BCCE7A0CEECA4D3F1A9D1EFA7C7E59DBDDB93BFDD95C6E49C
C3E199CAE8A0C3E199CEECA4D3F1A9CEECA4D3F1A9CCEAA0CCEAA0C8E79BC9E89CCDEDA1
CDEDA1C9EB9ECAEA9ECEEEA2C5E498D0EAA0D4EAA18B9F57B7C780AAB570D2DC97E0EAAB
CDD9A9D6E6B9677746849760889C5FDDF4B0CFE9A0CDE99CC7E494D1F0A0C1E090C9E89A
85A359C9E79FC6E49EC9E49FCBE4A0D4E9A6F0FEC0EAF2B9BDBF8D95966AE0E7BDD8E4BE
CDE3BDBDD9B3D1EFCDEEFFE9C7DABEF7FFE8E9E8D4FFFDF1FFFAFAFFF9FDFFF4F4FFFEFB
FFFFFBFEFFFDE3E7E6FEFFFFFFFEFFFFFCFFF5F0F4FFFFFBFBFFF0E8F2D9E5F6D2D5EDBB
CAEAA1BFDC8CC5D48FDBE3A7E4E9B3C9D1A26772470008001A1E0067633E7969459A875D
C8BC8CD0D197E0F5B0BDDF93BEE396BBE092CEECA2C9E39AD1E8A0D0E69ED9F0AAC5E197
CDEDA4C5EA9DC5EBA0C6EFA3BCE096C4E69CCFEDA5D8EFA78B9850CFDB93D8E59FD4E5A1
D8EBA9D3E9A9C0D89C8AA36976925834501699B279C2DBA1C7DFA3D1E6ABD7EDAFC9DAAE
F2FCF4F9FFFFF9FFFFF2FEF0F7FFEDE2F6D1CCE4B2D7F0B7
C4EA9DD3F5A9C6DB96535F1F57561D5D58216E6B34B3B37DD3DCA3D9EBADD3E9A9839C5A
92A764D9E9A8C6CF8EE8EFACDEE5A1535A17D8E1A0D3E2A1C2E09AC6E7A0CEE9A4D4E7A5
DFE3A69FA569C0DA9BC7EFB0B6E8A9C2EAB5F5FFD8FFFFDACFDA9ECCDD9792A35D95A962
C7DB94CDE19AD2E8A0D3EAA2CFE69ECDE79ECDE79ECDE79ECCE89ECCE89ECCE89ECCE89E
D5F1A6BEE093C1ED9ECDFCACB9DF94D4E3A0694F1C997F4CDAE6A6C7E59FCCE69FCEE59F
C3DF95C8E299D5E9A1D2E89FC5E399C6E89CC5E79DC2E498C7E99FD1F1A6D0F0A7C7E79C
CFEFA6C9E99EC1E198CEECA2C9E79FC1DF95CDEBA3C8E69CCDE99FC9E59BC7E79CCAEC9F
C8ED9FC3E89AC3E89ACBEC9DD0ECA1D1E99FCDE199344500BFCC86DDEAA5DCE9A4CCDF9F
CBE2AECCE4B430400F9AA873899D5EC8DF9BCCE69CCFEC9CC5E494D3F3A0BFE08FCBEA9C
8EA85FC9E39CCCEBA7CAE9A5D0EEA8E8FFBBF5FFC6FFFFCFCFCD9D8D8C60FCFFDDE8FAD4
D0E3C3E5FCDFF1FFEFEBFEE8A2AB9AFFFFF3FFFDF1FFFEF8FFFAFFFFFAFFFFF7FDFFFCFE
FBFAF8FCFEFBFEFFFFFEFFFFFFFEFFF2F2F4FFFFFDFBFEF3FBFFEDF8FFE4E7FDCFC1DDA2
C7E79CCBE79AE0EFAACBD495DBE0A8DCE4B1DEECBB445123555B2FDBD6AEE1CFA76B5629
A39360E5E3A8CFE09AD1EDA2D3F1A9CBE69FCDE49ED7ECA7CEE19FCFE2A0D0E3A1CEE3A0
D2EBA7C4E29CC0DF99D7F6B0C3E19BD4EFAAD1EAA6CFE49F90A15BDDEDA6CFE099D9EDA6
C8DE96C6E099D4EFA8CEE9A4C1DE9BD2EFADCCE6A5CAE4A5DAF2B4C0D89C011600000B00
BAC6BAD6E0DFD3DED6CAD8C9D6E5CECEE2BFC9DEB3DFF7C7
CBDD91B6C87E788442828E50C2C993DEE4B4C6CDA1DDE6BBD8E5B9D2E2B3D8E9B5ADBC85
616C32606A2DCFD595DCE3A0D5DF9AE0EBA9788246C0CA95CBD7A7D9E6B8DDE9BBD0D9AA
DCE0AE919864DBE9B4D4E8B5C4DBAFD3E7C4FBFFEDF6FFE0FCFFD3D3E29FE5F4B18C9B58
6574318B9A577D8C49C9D895D8E7A4CDD997DAE6A4DDE9A7CAD694D3DF9DDFEBA9CDD997
D4E19CD1E79EC6E89CBEE497CDEFA5D1DD9B705623A7905CD4E3A2C7E6A0C3DE97CFE9A2
CBE79DC1DB92D2E39CD7EBA3CAEA9EC5EC9DC6EB9EC6EB9DC4E99CC4E699C6E89CCAEA9E
C9E99ECAE99DCAE89ECCE89DCDE79ECDE79DCDE79ECFE69ED0E5A0CFE6A2C9E9A0C5EB9E
C2ED9DC1EE9DC3ED9BC6EC99D6F2A581974C97A760B8C881D9E8A3CDE19CCEE7A3C0E39F
BFEFB182AD75B5C7939DA77290A465D1EBA4C8E499CCEB9BC9EA99C7EA96CFF5A2D2F1A5
83944ED3E4A0D0F1ACC5EDA6C3E8A3D4F3B0DEF2B5EBF2BEF4E8C03C340FD6E6BFEAFFDA
E9F6DAF4FEE6F6FFEFF9FFF2B5AEA6FFF6F1FFFFFAFEFFFBFFFEFFFFFDFFFFFDFFFFFEFF
FFFFFDFFFFFDFFFFFFFFFFFFFEFEFEFEFFFBFCFFF4F9FFECEDFDD6DCF3BDD1EBAACAEAA1
C8EA9DCAE99DD1E59DD6E39ED6E2A2D4E2A4D0E5A4D0E4A5D8E3A751501875633168511F
A79360E8DFA6D7E2A0CFE09CD4E3A0D6E2A0D7E2A0D7E2A0D7E2A0D7E2A0D7E2A0D6E2A0
D6E5A2C9DA96D0E49FDEF2ADC1D59080944F5468234F631CB7CF85C1DC8FCDE89BD1EBA1
CCE89DC8E499C9E89CCDECA0CEECA2C5E399C3E197CEECA2D3EFA5B3CE87759049435B1D
3B4D23516240667753B9CBA5D9EBC1C0D3A6DBEFBEDDF3C2
7D833BB2B975D5DE9FE8F1B8CCD4A3E7EFC6ECF6D1EFFAD8E0EBC9E3EDCBE7EFC8D8DFB5
B8BE8E777C4696975ECBCF92DFE9AAC2CD91D7DFAC454C22A9AD8CF6F9DCD9DCBDEFF3D2
F5FAD2999F73D5DCB0E8F0C7E9F2D3DEE8D0F6FEF1F4FFEAE4F5C1CEDE9DDFEFAED1E1A0
D6E6A5E1F0AFBBCA89BDC989677333515B1C869051DAE3A4E9F2B3D7E0A1D7E0A1DCE5A4
D6DD9ADDEDA6C5E399CBEDA1CFEFA6CCD8968B7440BBA671CFDF9EC8E9A2D2EDA6D1ECA5
D4F2A8DAF4ABD2E39CC3D78FC4E397CBF0A2CFF1A4C5E79AC2E497CAEC9FCDEDA1C7E79B
CAE99DCAE99DCAE99DCCE89DCCE89DCCE89DCCE89DCDE79ED0E5A2CFE6A2C9E9A0C5EB9E
C1EE9DC1EE9BC2EE99C6EC99708B3CD6E89ED5E29CE0EDA8D4E8A3C4DD99C2E39ECEFBB6
AEEBA894C88ACADCA8B0B982A1B675D3EEA7CAE69BCBEA9CCBEE9CC0E693C3EA99C4E397
8E9955CEDA98C9EAA3BCE79FBFE8A2C9ECAAD4E9AEECF3C0FFF5CE504623D7E9C1DBF5D0
F3FBE3FEFFEEFBFFF3FFFFF6CABCB9FFF5F4FEFFFBF6FFFAFEFFFFFFFEFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFEFFFFFFFDFEFEFCFBFFF7F8FFEEEFFEDDE4F8C7D6F0B1CFEBA0CAEB9A
C5EC9BC6EB9DCFE79DD3E49DD3E49ED0E69ECCE89ECDE79EDAEBA7D5DA9ABFB3796D5821
4C3B05CEC58C98A1629CAB6A96A15F97A05F97A05F97A05F97A05F96A15F96A15F95A15F
B9C5838E9D5A707F3C7E8F4BA8B975CADB97DBECA8E0F6AEC3DF94C7E698CDEC9ECDEC9E
C8E799C5E496C6E597CAE99BC5E496C5E496C7E698CDEC9ED2F1A3D1F0A2CAE99BC3E199
C2DA9E7A91595F7640465D257E955FD2E9B1C8DFA9D0E7AF
C8CA89D5D798C8CB92E2E6B4CFD1A9FFFFE1FFFFE6F4F8DFFFFFECFFFFEAFDFFE5DDDEBE
BDBD97716F467D794CD7D7A5D7DEAADCE4B3A6AB83A1A485B9B9A1FFFFEDFFFFEBFFFFEA
F0F1D2B1B594E7EDCBFEFFE6FCFFEDF6FEEFFBFFFBF9FFF3D2E6B3D2E9A5C6DD99CEE5A1
D4EBA7D2E7A4D6EBA8CCDF9DB4C78592A2618B9B5A95A4638E9D5C8F9E5D95A4638E9A58
939E5A94A55EC4E298C9EEA1C6E69DD3DF9D6A531FA18C57D7E7A6BDE199CDEBA3C4DF98
C2E096D1EDA3CBDF97DAEBA4D8F0A6C7E197C7E197D7F1A7D8F4A9C8E499C1E094CAE99D
CAE99DCAE99DC9E99DC9E99DC9E99DC8EA9DC8EA9DC9E99ECFE6A0CFE6A0C9E9A0C6EB9E
C2ED9DC2ED9BC5EC99C9EA998CA458E3F5ABC5D28CC4D38ED1E6A3D5F2AFB9DE99BBEAA6
9BD694ABDD9ED8EBB4B9C28BADC281D2ECA5CCE69CCBE79ACFF09FC0E693C3EA99C4E397
ADB673D1DC9ACBEAA4BFE99FC1EBA3C6E7A2CCE2A4EDF4C0FFFFD6635935D4E6BECCE6C1
E6EED6F3F6E3FBFFF4FEFFF5E2D4D1FFFAF9FEFFFBF9FFFFFEFFFFFFFEFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFBF8FEF2F0F9E4E2F2CED7EBB8CFE9A8CDE99CC8EB97
C2ED9BC3EC9DCCE89DCFE79DCFE69ECDE79EC9E99EC9E99EC9E09AD9E4A2DAD49867581F
82753EB7B57A82915090A5628FA05C909F5C909F5C909F5C909F5C8FA05C8FA05C8DA15C
B4C883CBE09BDCF1ACD7EEA8CCE39DC8DF99C7DE98C3DD94CFEBA0CDEC9ECDEC9ECAE99B
C7E698C6E597C8E799CAE99BC9E89ACDEC9ECEED9FCAE99BC3E294C2E193C8E799CFEDA3
D6F3B1B8D595CBE7AA8CA96992AE71D6F3B3BBD79ACFECAC
D7D79BF5F4BBA7A572919064A1A17DFFFFE6FFFFECFFFFEFF0EEDFFFFFF1FBF8E78F8A76
7A745AB6AF92E5DCBBEAE4C0E8EAC2949873BDC0A3EFEED9F5F3E4FFFFF4FFFFF3FBF8E9
B4B19EBFBEA9FAFCE6FBFEE9FEFFF4FBFFFAFCFFFFF9FFF6C4DBA7D4F2ACCDE8A3D2EDA8
C8E39EBAD590D0E9A5D0E9A5BBD490CDE4A0D7EEAACDE4A0CBE09DDCF1AECBE09D9AAE69
99A66199AD6580A0558BB0637F9F5684904E69521E927D4892A5636A8E4689A75F87A55D
80A0558AA65C94A860D6E7A0C7D891D3E49DD6E7A0CBDF97C6DC93CDE59BD0EAA0CEEA9F
CAE99DC9E99DC8EA9DC6EB9DC6EB9DC5EC9DC3EC9DC6EB9DCCE89ECDE79EC9E99EC6EB9D
C5EC9BC5EC9BC8EB99CCE89B8DA257C1D18AE5F4AFDEF2ADCDE6A4C4E4A1CBF4B0A2D590
8CC785B7E7A9D3E4ADABB37AA7BA7ACBE59ECBE59BCAE699CCED9CC3E694CCF1A1CFEB9E
C8CF8CCFD895CEECA6C5EDA4C5EEA2C7E8A1CCE2A1EDF2BCFFF8CD655C35CDDFB5C9E1BD
DAE2CAE8EBD8F5FDEEF8F9F1EFE1E0FFFBFBFEFFFDF9FFFFFEFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFDFFFFFDFFFFFBFFFFFAF8FEF0EAF4DCD7E7C2CDE1ACCAE5A0CCE997C7ED96
C1EE9BC1EE9DC8EA9DCCE89DCCE89EC9E99EC6EB9EC6EB9ED0EBA4D8E7A4F1EFB2473E03
B5AF75DEE2A5DFF4B1C9E49FD1E8A2D2E7A2D2E7A2D1E8A2D2E7A2D1E8A2D1E8A2CFE9A2
C5DF98D0EBA4D3EEA7CBE69FC9E49DD2EDA6D5F3ABD3F1A7CDECA0CAEB9CC9E89AC7E899
C9E89ACAEB9CCCEB9DCBEC9DCAE99BC9EA9BCAE99BCBEC9DCCEB9DCAEB9CC7E698C4E498
CBEBA2CEEFA8D1F2ADCCEDA6CAEBA6CBECA5C7E8A3C5E69F
D7D49DBCBB855E5C2C605D34615E3FAFAA94C4BEB0FEFAEFFCF5EFFFF9F6FBF2EDADA39A
BBAFA3F5E8D8FFFDECFFFEE8DEDDC1A3A38BFFFFEFF1EFE3FFFEFAFFFDFBFFFDFBDAD2CF
B4ADA5DFDBD0FFFFF4F9F9EFFCFDF8FEFFFFFCFFFFF7FFF6C9E4AFC6E89EC8EAA0CAECA2
CDEFA5CDEFA5CAEAA1C8E89FD2F2A9CDEBA3CBE9A1CAE8A0CAE59ECBE69FC9E49DC4DB95
CFE09AB7CD84D9FBAFCDF3A6BDDF95D0DC9A69521E9D8853DAEDABB2D68ECDEDA4C0DE96
A4C47991AF6582984FB4C57EE5F2ACD7E29DD0DB96D9E6A0E2F3ACDDF1A9CFE59CC2DC92
CCE89DC9E99DC8EA9DC6EB9DC3EC9DC2ED9DC1EE9DC3EC9DC9E99DCAE99DC9E99DC8EB9B
C8EB9BC9EA9BCCE89BD0E69B8B9C55B0BF7ADCECABD1E6A5B4D390CDF4B1C5F4B07AAF6B
97D08CC3EFB0CEDBA3989B649BAB6CC9E09ACCE49ACCE79AC9E898C2E593CEF1A1CAE598
BDC481B6BD7AC8E39EC4EDA1C3EC9EC8EA9ED0E5A2E8EDB3F4E6B960542CCBDCB2D5EDC9
E9F1D9F3F6E5FBFFF4FBFCF4EFE1E0FFF9F9F9F9F7F7FDFDFEFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFDFFFFFBFFFFFBFFFFFAF9FFF1E7F1D8D2E2BBC9DEA5CAE59ECEEB97C7EE95
BEF099BEEF9DC5EC9DC9E99DC9E99EC6EB9EC3EC9EC3EC9EC2E49ACEE39EDDE2A25D591C
918F54D0D99AD3ECA8C6E7A0CAE8A0CCE7A0CCE7A0CAE8A0CCE7A0CAE8A0CAE8A0C9E9A0
CEEEA5C6E69DC0E097C4E69CCCEEA4CCEEA4C1E399B6D88CC7E99CC5E79AC6E69AC6E89B
CAEA9ECBEDA0CBEB9FC8EA9DCCECA0C7E99CC4E498C4E699CBEB9FD0F2A5D3F3A7D1F3A6
C7EC9EC7EC9EAFD487C5EA9CCCF1A4BCE193CEF3A6C4E99B
A8A7718A8855908F5FD5D3ACA5A1849B968276706467605A736968554B4C3D3133675B5B
F4E6E3FFFBF6F9EBE2FFFBEF9C9686FFFFF1FEFBF2FFFEFAFFFCFDFFFBFFFFFBFFC6BDC0
F6EDEEFFFDFBFFFEFBFFFEFBFFFEFFFFFEFFFEFEFFF9FFF8D2EDB8BDE197C2E69CB7DB91
BCE096CBEFA5C3E59BCDEFA5C9EBA1C3E59BC6E69DD0F0A7D0F0A7C7E79EC8E69ED5F1A7
D5E9A2D9F1A7BEE396CCF5A7CFF1A7D1DD9BA18A56C5B07BD5E8A6C1E59DD6F6ADCDEDA4
CCEEA2D4F4A9C8E096D5E69F525D187E8843B0BA75CBD691CEDE97CDDE97CFE39BD0E89E
CCE89DCAE99DC8EA9DC6EB9DC5EC9DC3EC9DC2ED9DC3EC9DC8EB9BC9EA99C9EA9BC9EA9B
CAE99BCCE89BD0E69BD3E49D83924DE3F2AFAEC181E8FFC0C9ECAABCE6A4BEF3AF9FD893
AFE6A2CCF4B5D5DEA592935A92A062CEE39ECCE299CFEA9DCFEEA0C8E998CCEF9FC5DD93
A1A6649BA25FC3DD96C6ECA1C1E897C6E999D0E69EE2E8ACE7D6A85E522ACBDCB2E4FCD8
FAFFE9FFFFF1FCFFF4FFFFF8E5D5D6FFFAFDFFFFFFF9FFFFFEFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFDFFFFFBFFFFFAFFFFF8FAFFF1E7F1D6D1E2B8C9DEA5CBE79DCFED97C6ED92
BEF099BCF09DC5EC9DC8EA9DC9E99EC6EB9EC2ED9EC2ED9ECCEEA4CBE29CDBE1A189874A
A3A367D4DE9FCAE8A2C2E69ECBEBA2CCEAA2CBEBA2CBEBA2CBEBA2CBEBA2CAECA2CAECA2
CCEEA4CBEDA3CCF0A6CBEFA5C0E49AB8DC92C5E99FDAFFB2C6E89CC6E89BC7E99CC8EA9D
C9EB9EC9EB9EC6E89BC4E699C8EA9DCAEC9FCBEDA0C7E99CC1E396BEE093C1E396C4E699
C1E696C5EC9BD5FAAACBF2A1C4E999C6ED9CC3E898CBF2A1
44470E8E915AD5D7A6ECEDC3CBCAABFFFFEAFFFFF3D3CEC8DAD1D2FFFCFFFFFBFFEFE3E7
FFFBFDFFFBFBFFFBFAFFFCF889827AFFFDF7FFFEFAFFF6F7FFFCFFFDF2FADCD1D9B7ACB4
FFFBFFFFFCFFFDF7F9FEFAFBFFFDFFF8F8FAF8F7FDF9FFF2C6E1ACC6E89ED5F7ADD1F3A9
CBEDA3CAECA2C2E49AC7E99FC8EAA0CDEFA5C8E89FBFDF96C2E299C7E79EC9E9A0D0ECA2
D3E7A0C6DE94C4E99CB7E092C6E89EE4F0AE947D49DEC994CFE2A0C2E69EC2E299BDDD94
C3E599D0F0A5D2ECA2D0E49CDFEFA8DDEAA49EAB6552621B687831C4D58EE8FCB4C9E197
CDE79DCCE89DCAE99DC9E99DC8EA9DC6EB9DC6EB9DC6EB9BC8EB99C9EB97C9EA99CAE999
CDE89BD0E69BD3E49DD4E39EDAE6A4BFCF8EDCF0B1C1DE9EB9E09FD0FFBF083F004E8742
BCF1ABC8EDAADEE6AD95945B929E5ED5E9A4CAE097D2EA9ECFEEA0CAEB9CCCEEA1CBE399
949655979C5ACBE29CC7EC9FC4EB98C7E897CEE49BE0E6A8E3D2A4645830CADAB3E5FDD9
FCFFEBFFFFF3FCFFF6FFFFFAD0C0C1FFFAFDFFFFFFFBFFFFFEFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFDFFFFFBFFFFFAFFFFF8F9FFF0E8F2D7D2E3B7CBE0A5CEEA9FCFED95C3EA8F
BFEF99BFEE9DC6EB9DC9E99DCAE89EC8EA9EC2ED9EC2ED9EC2E49AD3E8A3DADF9F585619
99995DDAE4A5E3FFBBBCE098C7E99FC8E89FC8E89FC8E89FC8E89FC8E89FC7E99FC7E99F
C6E89EC2E49AC5E79DCDEFA5CFF1A7C9EBA1C2E49AC0E296C7E99DC8EA9DC8EA9DC8EA9D
C7E99CC6E89BC6E89BC6E89BBFE194C6E89BCDEFA2D0F2A5CDEFA2CAEC9FC9EB9EC9EB9E
D8FBABC0E595CEF1A1B7DC8CC0E393D6FBABC0E393C4E999
BCC687DCE6A9DBE4ADD7DFB0D9DDB8FAFDE2FFFFEEFFFFF6FFFEFBFCF6F8FFF7FCFFFCFF
FFFBFFF8EDF1FFFBFDFEF4F3B0A8A6FFFAF7FFFDFBFFFCFDFFFAFEFFFBFFDED3DBA89DA5
FFF6FEFFFCFFFFF9FEFFFEFFFFFDFEFFFFFDFFFFFFFCFFF1CAE1A9C8E89FC1E198C5E59C
C7E79EC5E59CCCECA3C8E89FC6E69DC8E89FC7E59DCBE9A1D2F0A8C9E79FC2E098CBE79D
C7DD94D6EEA4C6EC9FC3EC9ECCEEA4C5D18F6F5522A68F5BD8E8A7CAEEA6C7E79ED1F1A8
CCEEA2BDDF93C9E399D1E79ECEE29ACBDF97C9DD95B1C57D768A4252681F839950D3EBA1
CFE79DCDE79DCDE79DCCE89DCCE89DCCE89DCCE89DCAE99BC8EB99C8EB97CAEA97CCE999
D0E69BD3E49DD4E39ED6E2A07A8948D1E4A4D7EFB1C5E8A8B9E3A3A5D89591CA86C2FBB6
B9EDA5BCDF9BE5E8AF9A985F929D5BDBECA6C8DC94D2EAA0C4E395C4E596CBEDA0D5EDA3
9395549EA05FD0E7A1C3E89ACBF19EC9EB97CDE39AE2E6A9E6D5A76A5E38C7D7B0DFF4D3
FEFFEFFFFFF4FBFEF5FCFBF7BAAAADFFF5F8FFFFFFF7FDFDFEFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFDFFFFFBFFFFFAFFFFF8F9FFF0E9F3D8D3E4BACCE1A6CFEBA0CEEC96C2E68C
C2EE99C2ED9DC9E99DCCE89DCDE79ECAE89EC5EB9EC5EB9ED0EEA6D8ECA7DBDD9E8F8B4E
C5C388D2DB9CC0DB96D0F1AACAEAA1CBE9A1CBE9A1CBE9A1CBE9A1CBE9A1CAEAA1CAEAA1
CBEBA2CAEAA1C7E79EC4E49BC6E69DCBEBA2CBEBA2C8E89FC6E89CC8EA9DC8EA9DC7E99C
C6E89BC6E89BC9EB9ECCEEA1CDEFA2C6E89BC0E295C1E396C7E99CCBEDA0CAEC9FC6E89B
CBEB9FC0E094CAE99DCDEDA1CEEDA1C9E99DC2E195CDEDA1
DAEEA6D2E69FC5D596D6E5AECEDAACF6FFDDFCFFE8FFFFF1FFFFF6FEFDF9FFFDFCFFFCFD
FFFDFEFFFEFFFFFDFDFEF9F6ACA7A4FFFEFBFFFDFBFFF8F6FDF3F4FFFCFDE2D7DBD2C7CB
FFFBFFFFFCFFFFFCFFF7F3F2FFFFFAF5F5EDF3F5EAFCFFEACADDA5CBE59CD1EBA2C9E39A
CCE69DD2ECA3C9E59BD1EDA3CBE79DD1EDA3D2EEA4C8E49AD2EEA4C8E49ACAE69CD1EBA2
CFE59CD2ECA2C0E699C2EB9DCDEFA5D6E2A0634916A9925ED5E4A3C3E49DC9E79FCCEAA2
C7E99DCBEDA1D2ECA2C9E399C9E59AD2EEA3D0ECA1C8E499CCE89DD1EBA1B9D38998B066
6B8339D3E9A0DBF1A8C5D991CEE29AD4E8A0D9EDA5C9E195C4E692C9EC98C6E693DFFAAB
D3E89DCDDD96D6E39E849350344405CDE3A3D0EEAEB3DA99BEEBAA93C683A9E09CBEF6AF
B8EAA1D4F5B0999A6059541A8E9756CEDF99D9EDA5D0E89ECDECA0C4E498CCEEA1CCE49A
9EA05F979958CFE6A0C9EEA0C4EA97C6E894D2E69EDCE0A5E1D0A4675936F1FFDBF2FFE8
F9FDECFFFFF6FBFEF7FFFFFDAE9EA1FFF5FBFFFEFFF6FAFBFEFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFDFFFFFBFFFFFAFFFFF8FBFFF2E8F2D9CFDFB8C8DDA4CEEAA0D0ED99C7EA90
B9E08DCFF4A6CEE89ED8EEA5C7DB94D4EBA3C7E79CCCECA1D6EDA7C6D290E7E3A66B6126
A39D63DEE2A5D1E8A4CEECA6CCE7A0CAE59EC9E49DC9E49DCBE69FCBE69FCAE59EC8E39C
CAE59ECFEAA3D4EEA7D2ECA5CCE69FC8E29BC9E39CCBE69FD4F4A9B3D589D4F6AAC5E79B
C4E69AC7E99DCDEFA3C9EB9FCBEDA1BDDF93CFF1A5C4E69ACEF0A4C8EA9ECCEEA2C2E297
D0ECA2C4DE95D4EBA3C0DA91CFE69ED8F2A9C7DE96CCE69D
BAD584D8F3A6E5FCB6CDE1A2D4E5B1FBFFDDEFFADAF6FEE7FEFFF3FDFEF6FFFFFBFDFDFB
FFFEFCFFFFFDFEFDFBFFFEFDD0CCC9F6F1EEFFFEFAFFF8F5FFFDFAFCF2F0FFFCFBDED4D5
FFF9FDFFF8FBFFFBFBFAF7F2FFFFF6FFFFF1FFFFEDF8FFDFDFF1B5C8DE96D5EBA3A8BE76
96AC64C5DC94CBE29AD3EAA2D8EFA7CFE9A0C2D991CEE89FC3DD94D6F0A7CEE89FCFE69E
D3E79FCDE79DC0E699C6EFA1CAEAA1D2DD9B694D1BB59B68DAE6A6C8E7A1CCE7A0C8E69E
C1E397C7E79CCFE99FC6E297C4E699C9EEA0C8ED9FC3E598C8E89CD3F2A6D0ECA1C3DD93
8CA45A899D55A9BA73DEEEA7DEEEA7CCD993D7E29DD7E99FD7F9A5C8EB97BDDC8CC1D98D
CDDE97E2F1ACCBDA977B8B4A8EA464C1DE9EC7EAAAD2FBB980AF6B83B570C8FDB9B2E69E
B8E89ECBEAA49394586B65299FA865CFE09AD0E69DC5DF95C8E79BC5E79ACAEC9FC8E096
9FA160999B5AC8DF99C9EB9ECEF4A1C3E493D3E7A0DDDEA5F4E1B95C4D2CF8FFE5F5FFED
FFFFF3FFFFF8FCFEF9FFFEFDB3A0A6FFF7FDFFFEFFFCFFFFFEFFFFFFFEFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFFFDFFFFFBFFFFFAFAFFF2EDF7DFDBEBC6D1E5B0CEE9A4CDEA98C7E992
C6E999CFEFA3CADE96C6D68FDCEBA6D4E8A1BAD48BCEEAA0C7DB96E3ECABE0D79CA4955C
CABF87CACB8FDDF0AEBED994D0EAA3CEE8A1CEE8A1CFE9A2D1EBA4D2ECA5D3EAA4D2E9A3
D7EEA8CAE19BC0D590C5DA95D5EAA5DCF1ACD5EAA5C7E19AC5E399C9EB9FC6E69BC5E79B
D4F4A9D0F2A6BBDB90CDEFA3B9D98ECFF1A5D1F1A6C7E99DC8E89DC8EA9EC3E398D6F4AA
CCE39DD7ECA7CCDF9DE7FCB7C6D997C8DD98E1F4B2D5EAA5
D8F8A3BEDE8BC7E398C1DA96D0E5ACF4FFD6FBFFE3FAFFE8F7FCE8F2F6E8E8EBE2A1A39E
AAABA6888886A6A6A4B4B4B2F6F2EFFFFFFAFFFFF8FFFFF6FFFEF6FFFEF6FFFEF8928A87
FFF7F8FFFCFDFFFEFBFFFFF8FAFBEBF5F9E2F0F7D6FAFFDACFDFA19EB26BA2B66FA1B56E
D6EAA3E3F7B08B9F588DA35B849A52829951B2C880D1E8A0C7DE96D0E79FDEF5ADC5DC94
D2E69EC9E197C5EA9DD0F6A9C5E39BCBD493684A18AB8D5BE0E9AAC1DC97C8E29BD9F4AD
D1F1A6C6E69BCEE89ED6F2A7C4EB9CC4EF9FC4ED9EC1E899C1E698C8EA9DCFEEA2D3EFA4
D8F0A6D0E49CC2D38C91A15A818C47B3BE79DAE49FD8E89FCAE999BEE18DD5F2A2DCF2A7
D2E39DC0D18DA6B675A6BC7BD0EDABCDF0AEB8E19F9CC9867FAE6ACAF9B3B9E8A4C8F6AE
C7F3A8CEECA49D9D5F989254C6CF8CDBEFA8D2EAA0CBE79CC5E599C8ED9FC7EC9EC4DE94
A6AB69A6AB69C4DB93C9EB9EC6EB9BC6E599C9D998D8D8A2EBD7B258472BFBFFEAF2FFEE
FFFFF6FFFEFBF8FAF7FFFCFDB5A1AAFFF2FBFFFEFFFCFFFFFEFFFFFFFEFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFBFBFFF5F6FFEAECFBDADFF3C2CFE9A8CAE699CAEA97
D7F8A9C4E095D6E69FE0EBA6D0DB97DAE9A4C8DF97DAF1A9CDDC99DEE3A3ACA06674632B
A0935CB7B57AC8D79691AA668AA15B89A05A89A05A8BA25C8DA45E8FA66090A5608FA45F
9CB16CBCD18CDEF2ADE4F8B3D3E7A2C5D994CBDF9AD8EDA8CEEAA0DDFDB2C9E79DD1F1A6
C1DF95CAEA9FC6E49ACAEA9FD5F3A9CAEA9FBEDC92D1F1A6C1DF95D0F0A5CAE89ECAE59E
E3F8B5C0D391CADA9BD6E9A7D7E7A89FB27099A96A425513
C6E892C8E895688739001700D6EBB0F0FFD0FBFFE1D9E2C5EAEFD9E2E4D642433BD9DAD4
FFFFFBFFFFFBFFFFFDFFFFFDFFFFFDFFFEFBF4F1EAFFFEF2FFFDF1FFFFF3FBF4EAC7C0BA
FDF5F3FFFDFDFCF8F5FFFFF5FFFFEDFEFFE6D6E1B9DBE9B6D9E9AAA3B46EC4D58FCFE39C
CADB95D9EDA6D0E49DD5EBA3CEE49C839A524A6119000F00D7EEA6B9D38AD8F2A9CEE59D
DBEFA7CFE79DCCEEA2CFF4A7C3DE97DDE2A2815F2FB69665D7DD9FD8F1ADDCF3ADC6E099
B9D78DCDEBA1D6F0A6BFDB90C5EC9DC1EE9DC4EF9FC6EFA0C4E99BC1E396C3E397CBE79C
CFE99FBED48BCBDF97E1F2ABE0EDA7949F5A56611C8C9E54CAE999D3F4A3D5F0A3BCD289
8C9D596373327D9251C5DF9EBFE2A0CDF6B2BDECA823550ED2FFBBB4DF9ACAF3ADBCE49D
C3EDA1C5E1969A9A5AB5AF71D6DF9CD4E8A1C8E096C7E69AC5E79ACCF3A4C7EE9FC8E499
B6BD7AC2C785C6E097CAECA0C3E89ADAF8AECCDC9EE1E1AFE4CDAD6A5840FBFFEDF3FFF2
FFFFFAFFFDFDF8F8F8FFFAFEC0ACB5FFF3FCFFFEFFFBFFFEFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFEFFFFFFFFFFFFFDFCFFFAFBFFF3F8FFE8E8FBCECFE9ACC9E59BCFEEA0
B5D488D1EBA1C9D690DBE5A0E4EDAAC8D590394F07354C04606F2C8F9454AFA36953420A
75662FD1CF94D1E09FC9E29ECBE59ECAE49DC9E39CCDE49ECFE6A0D1E8A2D0E7A1D0E5A0
CCE19C93A7625367223A4E094A5B175A6B2751621E3D520D001000B9D78DDAF6ACB8D68C
CDE99FD5F3A9C6E298CEECA2C9E59BC6E49AC2DE94D5F3A9CBE79DC9E79DCBE79DCAE49D
C9DE9BE0F3B1CEE1A1889B594D6020B6C987D6E9A9E4F7B5
CDED9A8EAD5DA3BF74C6DF9D697C44DFECBEEFF7D29FA388616250C9C7BBFFFFF8FBF8F3
F2F1EDFFFFFDEDEBECFAF8F9FFFEFFFEFDFBFFFFF8F1EFE3FFFFF3B6B2A6A19D92EFEAE4
FFFDFDFFFDFCEAE9E5FFFFF4FBFFE9F5FFDCD6E1B6CFDEA75D6D2CB5C981D7EBA3CFE59C
D4E8A0CCE299C7DD94CFE79DD9F1A7DCF6ACC1DB91D0EAA0D5EFA5CCE89D93AF64849E54
84985071873E58782D4C6E22546E27A0A263694515A88454DADB9FC7DC99D1E5A0D6EBA6
C9E59BC5E197CEE69CCFE99FC7EC9EC0E99AC4EB9CCCF1A3CCF1A3C9EB9EC9E99DCDECA0
CCE89DD5EFA5D3EBA1C1D78ED8ECA4CEDF9890A15A8EA45B90AF61C4E397ADC77D98AE66
90A36192A766C3DC9BDBFBBABEE7A3BEEDA9C6FAB2558941B4E19CCCF4AEB8D994CEEFA8
C2EB9DC4E0939C9D5BCEC989DDE8A3CCE299C4DE95CBEBA0C5EA9DC8F1A3C4ED9FCAE89E
BEC784D9E09DCCE69CC6EB9EC3E79DCEECA6D0DFA6DEDDAFE9D1B55F4D39FBFFF1F2FFF3
FFFFFBFFFDFFFFFFFFFFFDFFD5C1CAFFF8FFFFFEFFFCFFFFFFFFFFFFFFFFFFFEFFFFFFFD
FFFFFDFFFFFDFFFEFFFFFFFFFFFFFFFBFFFAFBFFF6F8FFECE8FAD2CDE6ADC7E29FCFEDA3
D3F2A6D5EFA5DBE8A2B1BB768F9A5691A05B849B5390A75FBCCD89D3D999FDF3B87C6D34
8D8049F3F3B7D1E1A0D7F2ADD0EBA4CFEAA3CDE8A1CFE9A2D1EBA4D1EBA4D0EAA3D0E7A1
D6EDA7D1E6A1CBE09BCBE09BD0E49FCEE29DC7DB96BED38E90AA6398B36C839D5693AE67
CCE69FCAE59ED4EEA7C6E19AC5DF98DCF7B0D5EFA8BFDA93C9E39CCBE69FDEF8B1C4DE97
C8DF99899E598499567E934ED4E9A6D6EBA6C2D794C5DA95
CEEB9B7C984BCAE49DD6EAABE3F1BCCCD5AA717755A7A78FFFFEEFFFFEF4E6DEDBFFFDFB
FFFCFDFEF8FAFFFDFFFFFDFFFFFEFFE9E9E9FFFFFAFFFFF6918F82FFFFF3FFFFF6FFFEF9
F6F2F1F7F5F6FFFFFBFEFFF6EFF7DFFBFFE3D2E0AF485A1EA1B570BBD188CAE097D8F0A6
C7DF95CDE59BE8FFB6BCD68CC3DD93CFEBA0CCE89DC2E195CEEDA1C5E498C2E296D2EEA3
CCE098D5E9A1D0F0A5CBEDA1C9E09AE1E1A3684213835D2E58581C5467258C9D59CADE99
D6F0A7C8E49ACEE69CDBF3A9D0F0A4C9EB9EC5E79AC8E89CCBEB9FCBEB9FCCEB9FCDECA0
D7F6AAC5E498D0ECA1D0ECA1CCE69CD9F3A9D6F0A6C9E59AB8D78BE0FEB4C5DC94CDE29D
D8EBABC5DB9BCEEBABB4D996CCFBB7B1E6A0A8E09793C880C2EDA6C7EBA5CAE5A0D9F4AD
C8EFA0CCE89BA3A460E0DB99E2EDA8CEE69CCBE79DD1F3A7C4EA9DC1EC9DC2ED9ECAEA9F
B6BF7CDFE8A5CEEA9FC4E99CCAEEA6BBD896DFEEB7DDDBB2F9E1C9534031F0F9E8F5FFFA
FFFFFDFFFDFFFFFEFFFFFCFFE3CED7FFF9FFFFFDFEFBFFFCFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFEFFFFFEFFFFFFFFFFFFFFF8FCFBF9FFF6F5FFECE5F7D1CCE4B0C6E0A1CCEAA4
C0E095BED88E95A55E5C6722D5E09CD4E59FD3EDA4D2ECA3E7FBB6D5DE9DD1C88D6D6127
9E955CE8E9ADD0E5A2C1DF99C9E9A0C8E89FC7E59DC7E59DC8E69EC9E79FC9E49DC8E39C
C4DE97C7E19ACEE59FD2E9A3D3EAA4D1E8A2CEE39ECBE09BC7DE98CAE49DCBE29CD3EDA6
CBE29C435D164C631DC6E099DCF3ADB7D18AD3EAA4D6F0A9C7DE98D2ECA5BFD690001000
4A641BC4DE95CCE69DD7F1A8CAE49BD4EEA5D0EAA1DAF4AB
D3EDA38CA35BD4E9A6D5E4A9C4CE9CE0E5BDD1D0B2FFFFECFFFDF2FFFCF6FFFBFBFFF5F7
FFFAFFE6D9E0FFFBFFFDF3FBFAF7FEFEFFFFF7F8F36B6C64B0B0A4F4F5E7FFFFF6F0EFEA
FFFEFFF5F3F6FFFFFDFBFEF5BCC4AD7D89659CAA79D3E5A9CAE19BD5EFA5CCE69CD2ECA2
D6F0A6BEDA8FC0DC91D3F2A6D7F6AABEDE92CEEEA2DAFAAEBDDF92CAEC9FD9FEB0C5E498
D7EBA3D9EDA5C7E59BC4E499CDE29DE3E1A4764D1FB1885ADEDCA1DCECABC6D7938B9F5A
769047A6C077CEE49BC4DA91D1EBA1CFEBA0CBE79CC7E398C8E499C8E79BC8E79BC6E599
BCDC90BFDF93CBEDA0D7F9ACC6E89BBDDF92C9EEA0C3E598D1F1A6D3EFA5C2D993D3E8A5
DAEFAEC5DE9DCBEBAACCF5B3AADD98BDF6AF4E883EC5FBB0BFEAA2B7D891DDF2ADC4DB93
C1E696C7E494999A56DCD795D7E49EC9E197C7E399C3E599C3EC9EBCE899C4F0A1C8EA9E
A2AD68D8E29DCFEBA0C4EA9DD1F5AFD5F1B4FBFFD6F8F6D0F5DCC67D6A5CF6FEEFF5FFFB
FEFCFDFFF8FFFDFCFFFFFCFFE8D3DCFFF8FFFDF9FAF8FDF9FFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFEFFFFFEFFFFFEFFFDFCFFFAFEFFFAFFF9F5FFEEE7F8D6D3EBBBCBE4AAC9E8A4
D4F6AACBEA9EA8BC7492A25BDDECA7CCE099DCF8AEB8D68CC9E09AD2DE9CE7E3A6897F44
B1AB71D5DB9DD1EAA6C5E69FC9EDA3C8ECA2C9EBA1CAECA2CDEDA4CDEDA4CDEBA3CCEAA2
D0EBA4D0EBA4D1EBA4CFE9A2CDE7A0CDE7A0D1E8A2D3EAA4DDF4AEC6DD97D2E7A2D6EDA7
D7ECA7CDE49EB1C68192A963819651839A54C8DD98D0E7A1667B36809751E6FBB691A860
A8C479D1F0A2CBEA9CBBDA8CD3F2A4C0DF91D2F1A3C3E294
D6ECA4A6BA739FAE6DD8E3A7DEE5B2D5D8ADDEDFBDFFFFE5FFFFECF3F1E2FFFFF4FFFEF6
FFF7F5FFFBFBFFF4F7FFFBFDFFFDFFEDEDEDCAC9C4D4D1C8FBF9EDFFFFF3FFFDF2FFFFF6
F8F3EDFFFFF8CECEC2858A74CFD9B7DDEABEC7D99FCFE4A3CCE69FC5DF95D5ECA4CDE59B
C7E197D3EFA4CAE99DCAE99DCAE69BD0EC9FCFEEA2B9D98DD8FAADC1E698C3E598CEEA9F
D0E49CD4E59EC7E198D0EBA6D9EFAEDBDCA2664417B59366DFDEA6C9DC9CD9E9A8DFF4B1
B9D79190AB66839654869552CAD996D2E39DD4E8A0D0E69BCDE89BCEED9FCDEE9FC5EA9A
C1E899DCFFB6BAE093B7DD90D0F7A8C4EB9CC4E99BCAEC9FC4E498C9E59AD2ECA3C9E29E
CAE3A1D0EDABC2E7A4BAE7A4C1F6B05F9851BEF6ADB2E69CB8E298DAFCB2C7DE96D0E69D
CDE99CD2E89D9C9F5ADEDF9DDBEAA5D2ECA3CFEDA3C3E599C8EFA0C0E798CDF4A5CBEA9E
929F59CEDB95CFEBA1C8ECA2B7DC97EBFFCDF9FFDAFFFFE0C4AEA0A49089F1F2ECFBFFFF
FFFDFFFFFBFFFEFEFFFFFDFFEAD9DFFFF9FFFFFAFCFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFEFDFFFEFFFFFCFFFAF9FFF4EDFBE2DEEFCDD4E6BECDE5B1
BFDC9AE1FCB592A661A7B874CFE39EC9E39CC4E69ACFF1A5D0EBA4C9D895E1DFA25D5419
938E54D8DEA0D1EAA6C3E79FC4E89EC3E79DC3E79DC4E89EC7EBA1C8EEA3C7EDA2C6ECA1
C6ECA1C7EBA1C8EAA0C8EAA0C9E9A0C8E89FC9E79FCAE59ECAE59EC9E39AD4EEA7CEE89F
BBD58EDDF7AECAE49DCAE49BD1EBA4D3EAA2ABC27CD5ECA4D5ECA6C9E098D0E7A1C9E39A
CFEEA2C3E397D4F3A7CBEA9EC5E196DAF4AAC9E197D1E99F
D4E49DCFDC9659621FDEE4A6D2D79DDDE4AECDD7A3F9FFDAF4FFDCF2FFDFF5FFE4F1FEE0
FFFFECF0E8D5B2A092BBA99FB1A8A1D2CFC8D1CDC4FFF9EFFFFDF3FAF0E4FFFDEFFFF7E5
FFFFEAFDF8DBC5C5A3A3A97DD7E1ACD5E5A7D4E9A4C8DF97D1EBA2D1E8A0D5E4A1D6E39E
CDE39AC8E499C8E799CBEA9CD5EA9FD9EB9FD4EA9FCAE699C4E797C7EA9ACBE699CADF94
CFE197D5E69FD6EBA8D2EBAAD0E9AFCFD9A5634D26A99269D1D8A4DAEEB3CFE3A6CDE7A6
C8EDAAC9E9AAB6C58E616630989960E0E4A7D9E39ED7E99DD1ED99C2E68FC3EE95C6F49C
BCEE99B5E695C3F2A4CDF7ABC1E79AC3E598CEEFA0CBEA9AC9E898C8E797CBEC9DC7E99D
C1E59DC6EEA8C8F3AEBAE9A5C0F2AD4F823DB1E39CCAFAB0BBE599CBF1A4C7E899C9E497
CCDC93E1EDA5939C59D9E5A3C4D996CFEAA5D2F0A8CEECA2C7E698D2EF9FC9E493CDE496
95A75DDAEEA7C6E19CCDEEA9C2E9A6DCFDC4EEFFD6FAFCE4BCADA8CCB7BEFFF9FFFFFBFF
FFFCFFF8F4F5FFFFFBF2F3EDF3EFECFFFCFFFFFBFFFFFBFFFFFEFFFFFFFFFFFFFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFDF9FAF5FDFFF7FAFDF2FCFFF6FCFFF6E3E9DFCED7C2
C0D4A3D6ECAED9E8ADC9DB9DDAF3B1C0E19AC2ECA0C2ECA0C6E69BCEE29BE0DF9F534B0D
A19B5FDDE3A3C3DD96D6F8AED0EEA6C8E69EC2E49AC4E89EC4EDA1BFEB9EB9EA9BB7EA9B
B1E495C5F8A9B2E394C7F3A6C9F3A7B8DE93C8ECA2CAEEA4C3E89BD7FCAEC8EA9EBFE194
D4F6AACAEC9FBADA8FCFEFA3C2E297D3F2A6C8E69CCCEB9FD0EEA4C6E599CDE99FCAE89E
C5E39DCBE9A3D6F1ACD1E8A4CFE2A0CFDB9BE9F2B3B1B779
DBEBA2E2EFA7DCE5A24B5111A7AD6FC4CC90E0EFB4CBE3A7D3F2B7C1E2ABCCECBACEE8BB
939D78B3B091FFFDE4FFEFD8FEF9E6FFFFEFFFFFEFFFFFEFFFFEEEFFFAE8FFFFECFFFEE7
FFFEE0DBDBB5BEC494C5D098DEEEAFC5DB93D0EB9ED1EDA0CEEAA0CDE7A0CFE49FD1E79F
D0EAA0CEEA9FCBEA9ECBEA9CC5E093C4DF92CAE598CDE99CC7E79BCAEA9ED4F0A5D6F1A4
D9F4A7CBE59BC6DF9BC5E2A2C7E9ADD1E8B46B623BA99D75D5E1AFC8E1A7C4E0A3C1E4A2
BFEDACBFE9AAC9DDA8E3E9B9D4D7A295995E949D5C8B9B52C9E28FC0E18AD3FBA2B3DF88
C8F5A2C2F1A1C0EC9FB9E397BBE196CBEDA0D0EFA1C1E090CBE896C6E693CAED9DC9EEA0
C0E89FC2EBA5C2EFAABAE9A5A8D79395C47EC9F6B1C3EEA6B9E296C3EA9BD0F5A5CCE798
E9F3ACC4C9869BA863DEF1AFCCE5A3C8E5A2C7E59FC5E197CCE798C2D989D8EE9CDCF1A2
7D9247CDE49CDDF6B4BDDC99C3E8A5DFFFC5F7FFE1FFFFEDB5AAA8E8D4DDFFF7FFFFF8FF
FFFBFFFDF9F6FAFDF4FCFFF6B9BAB4FFFFFDFFF6FEFFFBFFFFFEFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFEFFFFFEFFFAFCFFF4FEFFF4FAFEF0F8FBF2FEFFFBF0F1F3ECF2E6
DDE9C1C4D59E96A36BA7B67BD4EDACC3E49FC0EC9FC2EEA1D0F0A5DAEBA5D8D4957C7036
9D9459D9DA9ED8EFABB5D38DC5DA95CDE19CD3E8A3D5ECA6D0EBA4CDEBA3CCECA3CCEEA4
D4F8AEC7EBA1E1FFB9B8DA90C8E89FE1FFB8BBD991C5E59CC9EB9FBFE194C7E99CCAEC9F
BEE093C8EA9DD4F6A9CAEC9FC3E598CFEFA3C9E99DC4E498C7E79BC8E89CC9E99DC8E69C
D4EFACD3ECABB6CA8BC9D99BE3EEB2BCC1877F804768672F
BDD287DDEFA5D0DB974952119DA667DFE9ACC4D496D5EBADD0EEB2BBDAA1D3F1BBD3EDBD
B5C499D8DAB3FFFFDFFFFFE1FEFFE4F7FFE7F9FFE8F9FFE8FAFFE8FFFFECFDFFE7FFFFE8
FFFFE4D3DEB6CCDCABE1F6BDDBF6B3B9D98EC9EF9CC9EC9ACAE99DC8E89DC0EC9DBFEE9D
C9F0A1CEEDA1CEE89EC7E69ACEF9A9C1F2A0C6F2A3CCF1A4C7E29BC5E099C1EA9EBCEB9B
B8E592BEE999C9F3A9C7F2ADB2E0A0B6D7A02829002C2B0060773F001900001300023100
437F39AAE39FCDF0B6C5D9A4E0EEB9C8D69B95A3654D5E18768D3FDBF4A1B7D37FDDFAAA
C2E195CDEBA1CCECA3C6E89EC9EBA1CBEDA0C8EB9BC8EB99CDEA98C7E492CBEA9CCEF0A4
C4EAA1C0E8A2C2EBA7BEE8A688B270C1ECA7C7F0ACBEE69FCAEEA4C0E295D2F3A4C6DE92
C7D38B62692586934ECBDE9CCCE5A3C6E3A0CCEAA4CCEAA0D5F0A1D1E898D2E896D4E99A
97AB63CDE49ED2ECABC7E6A3C4E7A3E1FFC4EEFFD3FFFFE8A99F96FFEFF0FFF8FEFFF9FF
FFFBFAFFFFF8FAFEF0EBF1E3A5A79CFFFFFAFCF6F8FFFDFFFFFEFFFFFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFEFFFFFCFFFBFCFFF6F9FFF0FCFFEFF6FEE9F5FEEBFBFFF4FAFFF7FBFFEF
DEEBBDC9D79C7F894D9FAD6FD0E5A2C8E69EC3ECA0C4ED9FBDD98FDEE9A5E9DFA495824A
A2935CE7E2AAE0F0B1D5EAA9DAE4A5DFE4A4DCDC9ED5D396D9D397E3DA9FE6DCA1E3D79D
DED298786E33D2CC90E2E0A3D7D99AD7DD9DD1DC9AE2F1AED0E69EC9E098D8EFA7D9F3AA
C6E097CCE89ED3EFA5BCDA90C9E79DCAEA9FCFEFA4C5E79BC5E79BCEF0A4C7E99DC9E79F
C3D895E8F6B8DFEBADD7E1A4A1A96D5A602454581DDEE2A7
D4ECA0DEF4ABD7E7A0D6E39E929D5BD7E3A3E2F2B3BDD192C0DD9DC2E0A4BAD99EDEF9C2
B1C3918C9566D8D9AFD6D9AED1E2B5C1D8AACADCB4CDDDB8D2E0BFD6E1C3CDD6BBD2DDBF
C6D1AFC3D2ABBCD2A1C3DFA4C5E6A1C0E699CEF8A4C6ED9AC8E99AC7EC9EBDF19EBAF09C
C0EB9BC7E99DCAE69CC4E49BBBEC9DB4E999B8E89CC0E89FC9E6A3CFECA9C5F0A8B4E99B
BEF5A1C5FCA87FB26572A45D1B4F0D8DB37A1C22004B4C20CBE4ABC3EAA9C8F1ADB0E49C
8CCE8468A76170995DB9D7A1BED9A4D9F2B9D4EAACCADF9C6A7E365A6C20CEDE93D8E89F
D0DF9AD7E8A4CFE4A1CFE8A4D5F5ACC6EB9DBDE493CFF5A2CFEC9CC8E394CCE89DCFEFA4
C5E9A1C2E7A2C4EBA8C3ECAA9FC886CCF5B1B7DF99C0E59FD6F8AEC1E195CEEA9FC9DF94
E2EEA658621DAEBD78D6EBA8D2EDAAC8E5A2CCEBA5C8E69CCFEA9BCFE696CADF90C9DE91
99AF66A9C07CB7D192CFEDADC4E4A1D4F0B3DDEDBEF5F8D9B2A89CAE9F9CFFF5F6FFFBFB
FFFAF4FFFFF6FEFFF4919888D5D9CBFDFDF5FFFEFBFDF7F7FFFFFDFFFFFDFEFFFFFEFFFF
FEFFFFFCFFFFFCFFFDFBFFF8F6FFECE5F2D8E7F4D8E6F3D5F2FFE4F8FFECF8FFEFF8FFE5
C9D7A2E2EEB0A7B172C2CC8DCFE39ECAE69CCAEFA2C7E99DDDF3ABDDE4A1DCCD94634C18
A6905EE5DBA6848E528691558A8A4E7C73385B5116473B0153440B6B5A226E5B235F4C14
614C156B58206F5E26695D23A49A5F877E43A7A366DADA9CC8D38FD9E8A3D3E29DC9DA94
D5E6A0D4E8A1CEE49CD6EDA5CCE69DC1DF95CFEFA4CCEEA2C6E89CC9EEA1C2E79ACEE9A2
D7E3A3C8CE90B6BC80707638454B0FA0A96AD7DFA3DCE6A7
D6F5A9B8D489C5DB92DDEEA8D7E49F54601E879854DEF3B0D1EAA8D2EFADD6F4B4B8D497
D6EEB2C4D59E86935DDCE9B3CDE2A7DBF4BAD7EBB6D4E5B8D6E5BED3E1BEC6D1B3A0AB8D
F8FFE3F8FFE3E4F7C9CCE5ACD0EFACCAEFA2BFE693B7E18BC1E895C7EE9DC7F19FC1EA9B
C0E798C3E99CC7EBA1C5EBA2C2EAA3CAF2ABC7EFA9C8EDAAD3F6B6CDF0B0B2D69699C47D
77AE5B7CB862C4FAAC96CA82BFF3B1D3F6BCB4B687CDC99CD7EAB2BFDFA0C1E6A3CBFAB4
B2F2A8B7F6B0C0E9AF7A9D67557A46CDF0B8B9D89CD0EAA9D3E7A2D5E29D636D28D3D896
DEE3A3E4EAAED2DEA0C4D998CEE9A2C8EDA0BDE795C6ED9AD1EE9EC9E497CAE69BCCECA3
C7E8A1C4E9A4C6EDAAC3EAA9C5ECABD1F8B5C3E8A3C4E8A0C8E89FC7E69AD1EBA1D7EDA2
C8D48C59641FBFD08AC9E09CC8E3A0C8E7A3D3F2ACCEECA2D1EC9FC8DF91DDF2A5D1E69B
84995493AC6ACFE9ACD0ECAFC7E1A0CCE2A4E6F2C2E9EACAD2CAB7463930FFF8F5FFFCF8
FFFEF6FFFFF4FAFEEF9BA292FEFFF4FFFFF6FFFFFAFDF9F6FFFFFBFFFFFDFEFFFFFEFFFF
FCFFFFFCFFFFFBFFFAF9FFF4E5F1D9D2E1C0D1E3BBD2E4BAE1F6CBF3FFDFECFFDBF2FFD7
CBDB9DE1EEA9BDC683D8E39FD5E69FCEE69CCDEDA1C8E79BC9DA94D6D698F6E1AC7E5F30
AA8E5FB0A06F5F622D4F541C61561E6051185A4E14676125939355C8CE8EE1EAA9DDE9A7
D8E3A1DEE7A6C9CE8EDEDC9FECE3A85E52185A49116B5F25BAB87BCCD191D7DD9DDBE4A3
E4EDACDCE8A6CFDE9BCFE39ED4E9A4C3DD96CDE8A1D0EEA6C3E39AC1E399C7E99FD2ECA5
DEE4A4E6E4A7ABAB6F595B1C9EA466DDE8A6CDDC9BD1E29E
C7E79BC2E195E2FCB2D1E79EC6D79194A35E8FA05ACBDF9AD4EBA7BDD893C0DD9AD0EDAA
D3EEABD6EFADC6DC9C99AE6D92A963C5DA95D1E3A5D0E1ABD9E4B9DDE7C2C8CFB0879073
EBF4D5F9FFE1C6D5AAC0D49FD1EBAACEECA2BFE290CEF49DC0E691CAED9BD1EDA0CBE79C
C6E69BC8ECA2C9EFA6C7EBA5C5DF9ED6EEB0C6DFA5B9D79BB5D99C89AB6F5A753E587839
79AA5B88BF6BB4E498D1FFB7BBE8A7C3DEA761582DA29368C6CD97E5FBBDC9E3A2BADF9C
B7EFA8B6EDAAD3F6BEC9E7B5C2EAB675A06BC9EFB6D1EFB1CEE4A3D5E4A1D1DA99595E1E
AAAB71D4D79EE4EEB2CFE1A3C4DF9AC8EA9EC6ED9CC1E897CEED9FC9E59AC9E79DC8EAA0
C4E8A2C8EDA8C4EBA8B4DD9B98C17FBCE3A0D1F6B1CAEEA6BBDB92D0EEA4CEE89ED1E79C
DAE79FA9B670E9FDB6D7EEA8CAE7A4CAE9A3C8E89FC4E298D2EDA0D9F0A2C9DB8FA7BB73
A1B673BAD294DCF5BCC7E0A7D3E7AAD9E8AFCAD2A3FDFDDBD4CEB87D7367FFFDF4FFFDF6
FFFFF6EEEEE4D1D5C7F9FDEFFBFEF3FFFFF8FFFFFAFFFFFAFFFFFBFFFFFBFEFFFFFEFFFF
FCFFFFFBFFFDFBFFF8F9FFF1DFEECFCFE1B9CFE5B4CAE3ACD1EAB3DDF8C1DEF9C4EDFFCC
D8EDA8B7C77EAAB570D3DF97D7E99FCFE79BCDECA0CCE89DD9E6A1E5E1A4F0D9A788673A
65461A655325D7D7A5D9E0AADBDAA1DFDFA1DBE0A0D2DD9BD0E19DD2E9A3CCEAA2C4E49B
D2F2A9C4DF98E4F9B4D8E7A4C6CB8BD5D396FFFCC0B5AF736E6C2F57591A7C7E3F9CA161
939959AEB776DAE5A3D3E29FDAEBA7D4E8A3CFE6A0D5EFA8C7E29BC6E19AD5F3ABC5DA95
A4A667504A0C6F6D30B1B372DDE6A5D5E49FDBF0ABCBE59C
C8EA9ED7F7ACBCD88DCEE69CD4E8A0D3E49D51621BA0B46DCFE59DD1E8A0DFFBB1C3E197
C0DE94D0EEA4C1DF97D0EAA093A657A1AF62BEC984C6D094D2D5A6DADCB5CFD0B1CECEB2
FFFFE6FFFFE3D6DDB4D9E5B3D6E6A8D1E59EC9E092D0EC98C7E794CFEA9BD8E59DD5E09B
D1E79FD1ECA7C5E6A1BBD59698A36BAEB58197A3718FA16D89A670445F2A2C380A6D7B46
C2E69CBDE898C0E49CD3F2AFC5E1A6D5DDAA6D512ABA9872E3D9A6969960929C60CADE9F
C8EFAEB6DEA0CEE2AFD4EABBCCF2C3598554B6DDA8CDEFB3B7D494D5EBAACCDC9DE4F0B2
949E62B0BB81D4E2A7DCF0B3CEE7A5C7E59DC9EB9EC8EB9BC8E89DC7E79EC9EBA1C4E8A0
C3E8A2C7F0AABBE6A19DC88367924DB2DB97C8F0AACAF0A7C3E59BD2F0A6C5E196C9E197
A2B269BACA83CFE39CC5DF98C7E4A1CDECA6C7E59DD2EEA3C6DE92D0E59893A55B7B8C46
CBDD9FD2E7AECBE3AFC6DDA9D7E6AFE5EDBAC5C89DF5F5D3A8A28AF5EEDEFFFDF4FFFDF5
FFFEF8F1F1E9AFB0A8FFFFF8F4F5EFFEFFF9FEFDF9FFFFFBFFFFFAFFFFFBFEFFFFFEFFFF
FCFFFFFBFFFBFBFFF4F8FFEDE4F5D1D0E6B7D1EAB1CBE8A8CCEBA8CCECA9BDDD9AC1E09C
C1DB918CA154B3C078D5E398D0E598CDE597CFEEA0CBE79CD3E09BD9D598E0C695B8956B
8D6D44847147F2F4C5C8D9A2C4E39FC7EDA2CDF3A8CEF4A9CBF1A6C6ECA1C4EA9FC3E99E
C1E79CC3E79DC5E79DC2E299D5F3ABD0EBA4C6E19ACADF9AD8E1A2A0A4679B9F629A9E61
6C7234747A3CA1AA6BA5AF70C6D292DDECABD0E09FD9ECAAD1E4A2D2E5A3DCF1AE909F5C
777938999857C5C786DFE9A4D6E5A0C3D990C8E69CC0E094
CBEDA1BEDE93D4F2A8C1DB91DDF3AACFE39B93A45D7C8D46CFE39BD8EEA5BFD78DD0EC9F
D3F2A4C0E192D0F3A3C9E996D2E68F8E9C4798A35799A261989D679B9E73A9A987FFFFE4
FFFFE4F7FBDAD7DEB5DFE9B7C7D296D4E39ED9EB9FC7DE8CD0E998D2E99BD4E199D2DD98
D5E6A2D4E9A8BFD799A9BD829DA572AFB585969E6F93A17092A47441512242491FBCC994
C8E39ED3F3A7CAE39FCCE0A1CEDFA8E9E7B767411D936742AC97689A955D9E9D64859054
93B173D0EDB3E2EEBEE0EDC2C7E7BE91BA8E9EC491BDE3AAC8EBABCEEDAAD8F2B1C2DB9A
CEE4A69BB0759DB277CAE2A6D9F2B1CCE7A2C9E59BC7E69AC5E59CC5E9A1C8ECA4C1E9A2
C0E9A3C7F2ABB2DF9A88B7717CA964CAF5AEBAE49CC3EBA2CFF1A7CCECA3C1DF95D5EFA5
A3B46DE6F6AFD2E8A0CEE8A1D2F0AAD1EFA9BDDB93D1EBA1D1E79CB7C97F96A65FA3B26F
DBEDB1C9DDA8DFF7C7E8FBCED2DAABDFE2B5FFFFD8C5C5A37D7960FFFFEDFFFEF2FCF7F1
FFFFFAFFFEFBAAA9A7ECEBE9FFFFFDFBFAF8FFFFFDFEFDF9FFFFFAFFFFFAFFFFFDFEFFFF
FEFFFDFCFFFAFBFFF4F8FFECE7F9D1CCE3AFC8E2A5C8E6A0CEEEA5C3E59999BB7186A85C
93AF627C9446D9EBA1E4F6AAC8DE93C9E497D3F4A5C7E69ADCEBA8E7E5AAEBD3A3C7A67B
A58860A59469D5D8ABCCE3ABCAF4ACBAED9EB5E697B9E89AC0EA9EC1EA9EC4EA9FC8ECA2
C0E49AD1F5ABC0E298C9EDA3CAEEA4BAE095C7EDA2CFEFA6D6E6A5D1DA9BD7E0A1DCE5A6
B7C08177804150591A4A5415A1AB6CD7E1A2CCD697DAE4A5D6E0A1D8E2A3D4E0A0535C1B
5C611FD2D794D9E39ED6E69FD0E69DCCE89DC3E598CDF4A5
C0DE96D5F3ABD5F0A9B8D289DCF3ABDAF0A8A2B66E93A45DD3E59BD4E99ECCE297D2ED9E
CBEA9AC3E694C3E996C7EB94C9E287DCF097CDDF8DDCE9A3B5C084B5BF8BD9E0B6EFF7D2
F7FFDAFEFFDFE9F4C9E3F1BCD4E4A6D6EAA3C3DA8CD1E896CDE293D0E799D8F4A9BAD88E
CCE39FD8E8AADCE7AF929F6AD2E6B1C6DDA9BFD19F929E70A4A77C292F03B4C193D0E5AD
CAE5A0CCE69DD5EAA7D8E8AAC7D49CF0ECBC70482491643DE7CF9FDCD39AE7E2A8D1D99D
B1CB8E99B57BB4BB8FFFFFDDCAE0BACEEEC582A3743C612B79A162A0CB86BEE9A4C4EDA9
BAE1A0C7EBADACCE9129470BCCE6A7D1E7A6C2D792D7EEA6C1E29BC3EBA4D3FBB4B5E099
C8F6AEB8E7A173A55EB7E9A2BAE9A1BFEEA6C2EDA5BEE89ECDF1A7BEE096CBE99FCCE69C
91A25BD1E29BD5EBA3CAE49DD3EEA9CCEAA4CBE69FCEE69CC5DA8F809047A8B570D4E0A0
D4E3AAD1E3B1F5FFDFF0FFD9D9DBB4F4F2CBFFFFDF474627B0B096FFFFEDFFFFF2FFFDF6
FFFEFDF4EFF3B1ACB2FFFDFFFEF9FFFFFEFFEDEBEEFFFFFDFEFDF8FFFEF9FFFFFDFFFFFD
FCFEFBF9FEF7F8FFF1F6FFE9E4F4CDC8DFA9D2ECABC7E59D92B266B1D484B6D989CFF2A2
C2E394D3EFA2DCF2A9CBE196CDE79DCDECA0BEE395D4F4A9C4D591F2F2B6EDD9A75E4117
745D33A2976AD4DDAEC7E0A7CBEFA9C9F2A6C4EA9FC3E79DC8E89FCBE9A1D0EBA4D1EBA4
D4EEA7CEE8A1C9E09AC7E19ACDE7A0D3EEA7D1ECA5CFE9A2CBE09DD6E9A7D4E4A3CFDF9E
D5E4A3D6E2A2D4E0A0929C5D5C66271F2800A1A76995995C93975A6064276263279CA161
DCE6A1D4E49BD7ECA1DEF6AAC7E396CCEF9FC7EE9DBAE492
90A562CBE29CBFD690EEFFBFC1D892C9E098D3E7A097A86186964FDDEFA5DFF1A7C7DE90
C6E393D3F5A1C5EB98D3F9A2CBED8FD5F296C8E18DD2EA9ECEE3A0C7DBA0D4E6B4D2E3B6
F3FFD8F8FFDCF1FFD2F0FFCCCCE5A4CDE99FCAE797D0ED9BD8F0A2CAE699BAE395D6FEB5
CCE9A7CCE0A5CFDCA7C6D7A3CCE9B3CFF0B98FAA75D6E6B5999F71505628CDE1AECAE6AB
D1ECA7CBE29AD5E8A6D8E8AACBDAA192905D6B4820C99F77FDECB8DDD89ED9DA9EE5F1B3
CBE9ABAECB91A6AF82E4E8C3EFFFDBF2FFE4D9F4C7B6D9A379A36417460242762EC0F3AE
C1F2B0C7F5B4AFD799CAECAFD4EEAF2A3E00DCEBAACDE09ECEEDAABDE59FBBE4A0C8F3AE
90BD7856853FB7E9A2BEF0A9C3F5ACBBEBA1C5F1A6C4ECA3C4E89ECEF0A6C0DE9490AA61
91A55DD0E19AD3E8A3C7DE98C8E39EC3DE97C8E29BCFE59C5E6E27CBD892EAF5B1D9E3A6
F4FFCCF7FFDAF7FFE3F9FFE4FFFFE1E2DCBA9B9774898869D2D5B8EFF3DCFFFFF1FFFFF8
FFFEFDFFFDFFA59DA8FFFAFFFEF6FFFFFCFFFFFDFFFCF8F9FFFEF9FFFEF9FFFDFAFFFFFD
FFFFFDFEFFFBFCFFF4FBFFECEBFAD3CCDEAACDE3A3D0EAA3C0DC91CFEE9ECCEB9DC5E697
CEF0A4C1E198C3DD96C1D890CDE99FD5F5AAC1E79CC2E49ADBEEACD4D89D7765336D5529
584318FFFBCDF7FFD2EAFFC9C0D997C6DD97DDF4AEC1DB94D7F1AACEE8A1BFD992D0EAA3
C6DD97D7EEA8D5EAA5D3E7A2CDDE9AD0DF9CCAD694CDDE9AC9E09CD5EEAABDD490DDF4B0
C9DE9BD2E5A3D2E1A0D9E5A5D1DB9C99A26351551852531767682C4F4F13D7D79BD6DB9B
CADA93D5EDA1C2DD90ABCA7CDCFDAEBADF8FCDF4A3C7F19F
535D20919D5DDFEFAEC0D592D0E7A3D2E9A3D1E8A2B0C47D98A963AEBE77CCDC95C8DA90
EBFFB7C1DE8EB7DA8ABEE690C8F195CFF89CC2E891C5EA9AD3F7AFCDF0AECAECB0BEDFA8
E3FFCDD8F9C2D8FABEE0FFC3C5EAA4CCF2A5CCF3A2C2E996C7EE9FB5DE90C1EFA4B8E69D
B9E09DAFCE928DAA72B0CD978DB37A83A970B3D49D49642DA3B880CFE4ACDDF9BEC5E3A3
C4E29AE1FBB2CDE4A0B4CA8A93AB6DB8C18A715B2CA5895ADCD79DD5E09ECFDB99CBE1A0
C2E9A8CEF2B5B7C798BCC29CFAFFE2F9FFE4C7DCB1C5E3AFD5FBBEBEEDA992C67E81B670
88BD7993C483DEFFCBBADCA0BAD497A2B4789EAA6C84945587A46483A86580A7668AB36F
3A6722497832C7F6B0B8E7A1BDECA4C0EEA5C5EFA5BDE39ACDEFA5B7D58DE0FAB1788F47
92A35CCFE099DBEFAAD5ECA6D4EDA9CDE7A0D1E6A1D4E59E47520DE1EBA6D1D797C9D196
FEFFD6FBFFDFEBFAD9FAFFE7FFFCDE9F947446421FD9DAB8FEFFE3F5FEE1FAFFEBFBFFF1
FAF9F7FBF4FBFFFAFFD6C9DAFFF9FFF4EAF5FFFCFFFFFCFEFFFEFAFFFCF8FFFBF8FFFCFB
FFFEFFFFFFFDFEFFF5F9FEE8E9F3D0DCE9BBC8DAA08FA46190A75FBED68ADEF6ACCBE79D
D0EFABC1E09DD6EFAED6EFADCAE5A0CCEBA5C3E9A0C3E49DD0E5A48E9257837340695324
9C8B5DE8E4B4F8FFD4D9EEB5DDE5A9F5F7B8D0D696D9E5A38A9F5A99B36C55752CC9EBA1
99BB71B1CF879EB56F94A5618D9655A7A96AADA96CC2C485D6EBA6CDEDA4BBD991C4DF98
E4FEB7C9E09AC8DC97D6E7A3D5E4A1D8E4A2CBD493DDE3A3E4E9A9CED091FEFFC1D0D998
DEF6ACC4E397C6E69AE7FFBCB4D689CAEFA1C1E698CAEFA1
4A4911A0A469DBE5A8D7E7A6CBE1A0D2EBA7C8E19DC2D7928E9F5B909F5AD2DF9ADAE7A2
CDDE97C7DF95DBFAAECDF0A0BEE690CCF6A0BEE896BEE798C0E69DC4ECA6BEE5A4C3EAAB
C3EAABBFE6A7C0E5A2C3EBA5BEE69DBFE89ABFE899BFEA9AC2ED9EC8F2A8C8F0A9C2E9A6
CDF4B5092F00B8DEA58DB0785D7E49C9E7B1819E66CCE9AFC6E4A6D0EEAEC9E3A2C8E19D
CBE199D6EAA3D6E9A7DBEFB0445E1FD7E5AA645220AE9A67D2D797DEEFABE0F4AFC4E29C
D4FDB9EBFFD4F7FFD8DADEB9FFFFE2FEFFE3D4E3B8C8DFABBBDA9EC0E7A4BBE6A1BFEEAA
ADDB9AC1EDAE7AA065CBEAB1E3FBC1DAECB2D2E0A3D8E8AACDE7AAC4E4A5C5E7AA537737
729958C3ECA8C6F1ACBFEAA3C0EAA2C5EDA6CDF1A9C6E59FD6F1AACEE59FD1E79F889953
9AAA63C8D992CFE39ECEE39ED0E7A3CFE49FD5E6A2D1DE9859601CDFE4A1D1D394E3E6AF
E4EABED2DCB9EFFCE0FCFFEAE5DEC16A5F3F524E29CFD4ACD6E1B7F0FEDAF0FDDFF9FFEE
FFFFFAFCF6FAFFF9FFB6A5B5DDCDDAFFFAFFFFFBFFFFF7F5FFFDFAFFFEFAFFFDFBFFFDFF
FFFDFFFFFEFFFFFFFAFFFFF1DBE0C2DBE3BAE7F1BD8A985B9EAE6DCFE09ADDEEAACADF9C
CCE8ABC7E3A9F7FFD3F8FFD1CBE3A5C3E09EC9E9A6C9E8A58B9E5E5C5F26AB9B68DAC495
FFF4C3CDCB98CCDFA7CEE6AAD2DA9ED6D899D7DD9D55611FCEDF9BBED58FD7F2ABCDEBA3
CCEAA2D6F1AABAD18BCCDD99DEE9A7DEE3A38C8C4E565C1C475E18CEEEA5E0FEB6CBE9A1
B0CB84DFF9B2CAE19BCFE49FCEE29DC5D692EFFEBBD2DE9CC3CE8CDFEAA8D0D998D7E6A1
C8E49AB5D78ACDEFA2C3E598C7E79BD5F5A9C2E195C7E69A
8779485A501BD9DAA1CDD99BD0E4A5D2EBA9D4EDABE0F7B3D9E9A8808C4C7F894AD6DF9E
D8E4A2E0F1ADC4DA92CDE99FC7E79CD3F5A9C7E99FD0F2A8BEDD97D2F3AEC6E6A3D5F5B2
C1E19ECFF0ABCEEDA9C7E6A0CEEEA5C1E196C1E196D6FBAEBEE69DC7ECA7C9DFA172854D
84A066C5E6AD60874E92B37ED8E8B7B1BB899BA974C8DDA2CFEFACC2E19BD4E59FDFE8A5
E0E7A4D9DF9FD2D89A525D21D8ECAFC8D1985A4816A89761DFE6A3CADE97D3E9A1C4DF9A
E2FFC6DFFFC5F8FFD4DFDCB9FFFFE1F6FAD7D5DCB2E5F1BFD6E8AED1E7A7CBE5A4CFECAC
CFEDB1CAE7AD9BB67F94AD76586F37AABD85D1E3A7D4E6AAD8EDB4ABC389809960000F00
8EAC6EC6E6A5C2E5A3C9ECA8C4E5A0C1E09CCBE6A1CEE5A1C8DC97DCEBA8838F4D8F9A56
CDDA94DFEFA8D3E4A0CDE19CD1E6A3D7EBA6DEEDAAD1DC97505512E3E4A2E1DFA4E8E6B3
CBCDA5CDD2B2FBFFECFAFFE6D0C7A8867A54B9B88CDCE4B3CBDCA8E7FBCAF8FFE1F7FFE6
FFFFF3FFFCFDF1E1EBC3AFBBCEBDC7E4D5DAFFFCFAFFFDF8FFF8F1FFFDF7FFFCFDFFFCFF
FFF9FFFFF9FDFFFCF9FFFFF4FAF9E4D1D5B4D4DAAE626935909960D0DA9DCED89CDAE7AF
D2E6B3CADDAFFBFFDAFCFFD8D0E1ABD0E5ACD4F0B3CBE3A5687639C6C58DDFCB99A28758
AA9866E6E3AEDAEEB1C1DE9EDCF7B2CAE49D869B5692A762E2F3AFD9EAA6CCD896D5E19F
C6D290E1F0ADDAEBA7D3E7A2CADF9AD2ECA5C9E49DD1EFA7C8E49A839F5558742A4E6A20
CAE49BCFE9A0CDE79EBFD990D0EAA1CCE69DD1E8A0D0E79FCCE39BDAF1A9D0E79FC7E198
D5F3A9D1F1A6BEDC92D8F4AACAE49BC6DD95D1E79F96AA63
E6CEA0C3B1815A5420E2EAAFCFE1A5C7E09FC6E09FBCD593D6E8AAD2DEA0D6DEA2969C60
D0D89CDCE6A7D3E3A2CDE09ED2E5A5C6D89ACADD9DD8EBABC7DA9AD7ECABCADF9CCDE29F
D7EBA6D5E9A4D0E49DCBDF98E0F1ABCFE09ACADB95D0E49FCBE4A393A96BB3BC87F0F7C4
BDC997819361DFF5C4C7D9A9808155C0BD90D3D39FDDE5AACDDE9ACFDF98E6E9A4DDD896
EAE0A2DBD196A49B62C2C087DFE8AFE4E5AC88713FA9925EE6E8A7CFDF98D3E29DC5DA97
DAF8B8CEE5ADE3E0B7B5AA8ADFDABAE8E8C4D0D3A8B2B684898E56979F64C1CB8FCBD49B
D2DCA78B9765BBCB9AD0E2B0C4D8A3B4C990A7BF8397AC7193A46E8A9B65485B24859A61
E6FEC4D1EBACD6F0B1C2DC9BC5DE9CE0F6B5D2E5A3CDDC9BE0EBA9919757A1A666BDC280
D7E29EDBEBA4CEDF9BCDE19CD2E5A3D1E29EC8D590A9B06C575A17E5E4A4DDD8A0D9D5A5
DEDCB6DDE0C3FCFFEDFEFFEB948969978B61DEDEACE4EFB5CFE3A6C0D89EE3F9C8DAE8C5
FDFEECFDF4EFFFF9FFFDE8F1F6E1E8C2B0B0D9CCC4FFFBF1FFFDF4FFFDF8FFFCFDFFFBFF
FFFBFFFFFAFFFFF9FDFFFDF7FFFAEAFFFFE6FFFFDD7E7F53A7A977ECEFBAD9DEA8D4DBA8
D1DEB3D3DFB9FFFFDFFEFFDAD3DCAFD7E5B2D9EEB6C8DCA160682FD6D19AFEE6B6A08455
CBB584D9D49DCCDEA0C5E29FB9D48FD9F3AC8CA15CCBDF9AC5D491E7F3B1D7E2A0DCE5A4
DDE6A5D7E2A0D3E29FCEE29DD2E9A3D1ECA5CBEBA2BEDE95C1DB92E0F6AED6EDA5C1D890
A4BB73CEE89FCAE69CD6F4AAD1EFA5CCECA1BFE195C7E99DCAEFA2CAEFA2C9EEA1C6EB9E
C3E398CFEBA1CDE79ECBE29AC7DB94BECF89202D00AFBC77
F2D2A9CBB3875B512080834CCBDDA3C9E1A3D5EFB0DAF3B2DCEEB2CDD89CDEE3A9777A41
DADDA4CBD397D5E1A3D6E0A4EDF0BBC5C392E9E7B4E6E5ADDFDEA6D7D89CE1E3A4D8DA99
DDDE9CC8C987E4E3A2EAE9A8E5E1A2D7D394EAE6A9DDD89EC5BF8B8D8959D4D3A3CCC99C
C2BD93BEB58EDACEA8C8BC96B7AB83E5DAADE0D4A2E1D29BF4E1A6EEDC9CEADB96ECD997
EDD098B49461624614E6D29FE5DEAAE3D6A2876235B18D5BD9D193DCE19EDDDF9EE3E9AB
D0DFA4D4DBA8E5D1AEBFA68897916F9A9B73B8B78BC5C191A9A26E999059D4C993EFE5B0
EAE2B3928E619495697D8657DBECB8C9E0A8C1DFA3CFE9ACCDDBA6BAC291848E5AE6F3BD
CFDEA7C2D498D6E8ACD6E8AAC9D99ADFEEADD2DC9DD6DC9EF8FABB7D7B3EDBD79AE5E4A4
DAE19ED8E59FCDDC99D5E6A2DBEBAAD7E6A3C8D38F9FA4615D5C1BD6D092E6DFA8E5DFAF
E9E5C0D1D1B5FCFFEDFFFFEC897F5BAA9F71CDCE95D7E3A3C8DF99C3DE9BD4EBB3ECFBD0
FFFFECFAF1E8FFF8FAFFF8FBFFEDEFFFF5F1B3A598CFC6B7FDF3EAFBF0ECFBEFF1FFF3FA
FFFAFFFFFAFFFFFAFFFFFBFAFCF4E9FFFFEAFFFADA85815BA5A277D9D6A9E3E0B3E0E1B7
D9DFBDE0E5C5FFFFE3FFFCDBDEE0B9DEE7BAC1D29E97A66F71743FE7DBA7F0D4A5947445
B9A270ECE3ACD9E9AAD8EDAAE2EBAABCBE7F959A5AE3E9A9DEE9A7D2DE9CCDDC99D6E7A3
D5E9A4C4D893DFF3AED7E8A4D3E29FC4D390E2EEACDAE6A4D8E7A2CEDE97DAEBA4CADE96
A0B66DC6DE94CEEA9FCBEB9FC6EB9DC0E798CDF8A8BCE998BEED9CBDEE9CB4E895CBF7A8
BDDD92E2F9B3CDE19CD9EAA6D1DD9B909958A2A868DAE0A0
E0C39BD9C298978B5B4F4F1B5A652B68783AB9C488A0AA6EA1A970B9BE86C3C38D76733E
6157229390598E9A5C93A1649DA46E646732A5A56F8A895189894D68682A929252888B48
5558134F520DA3A460ABAA696C66285B5217A1945D9E935D58511D72703F989B6E080B00
59542E63553059471F5346195D5B2841440D94945E5E592155460D5D4D0F645A12594F07
634F106A541B69541F6757244F491577693866390F966A3B9B8B4F9A9956999959D6D79B
A3A6719A956BAE967AC2AB8BCCC6949DA069959466969366A09A6A9D9362B8AA7D98875C
9E8C64C1B38CACA37A6F6D449CA37A808D5FA0B479879B60606C3C3C4518A0A877929963
949A5E9A9E61A4A569ACAA6FBFBA83978D5CADA073D8CA9DCFBE90CCBA88A08C59BFB379
B0AF6FA3A8668F9555929B5A9BA465A6AC6CAAAA6A8A86475D5517A1955BC0B37ECDBF90
E4D8B0E1D8B7F1EBD1A8A18452401A7B6B3A9E9760B9B97BB1B875CBD49590935CBBB88D
F9EBCEFFF0DEF7D6CDF2CFC9FFE7DEF2D2C5EACFBABDA991B7A895B1A494B5A79CC7B9B0
E4D2CEF5E3DFF8E7E0F3E2D8F6E7D4FFF3D9DACDABD7CBA5FFFFD8EBE2B7E4DBB0ECE3BA
F6EDCCECE1C3FEEDCFFAEAC9FAEEC8F5F2C7A5AC7949501CB2AF7AD4C491CEAD806D461B
B39265B9A573A5A86F8E94587C763C63571DA1975C9E985CB2AE71929455BBC181A4AF6D
9CA765737F3D95A05E929858A2A465A2A063E3DDA1DFD99DDFDF9FDCDE9DD1D694E6EBA9
848B48E5EEABD9E4A0CFDE99CBDF98D8EFA7CDE79EC6E49AD4F4A9BFE195CDF2A5C7E59B
D3DF9DE3E8A8D2D4957F7F414E4A0DE1DB9FDBD297E4DBA0
C0AE88908158574F2069683245460C5B591E6B5722604B16A498649D9763655E2A6D5D2C
6546185B4513D5E4A3CBEDA3C8E9A4CAE9A5CFE8A4D3E8A3D2E39DCFE099CDE297CEE69A
CAE797D7F3A6C8E396C5DB92EEF9B7CCCD91AEA56E5C5922DBEBADCFE8AED4EABC8D9F77
D7E1BCD7DEB2505A1E95A45FC8E298CDEFA5BDE4A1BEE2A2CDEBABD5ECA6DBEE9CD5E791
D4E5959EAB65C9D394DFEDB2D3E7ACC8C89474451BAD794AE3D191D3D48E555C18878B50
534F209C9171D9CAB3B8AF88B4B76659610C919865969E79495128545930676443504728
5D4E2F5D4D2B8E7F58D8C9A8DBCFB99990735F59254E4F16818D674959354C5624585C21
9B975051430062490968441070432271412D5E2A1FA57368F2C3B1A97D627C552E977849
8978426A60255E551C8279408F844C675A23594A115C4B135E491279622E5B410E674D1C
E3C89BE3C89D987F56563D14694C20694D1E6145156D511F9B7D4B5F3D0F5A3308A77B54
A77655BE896A763E2360280F9C6449703A1E996848724A26856E4562502865532B5B4722
755E3C8B7452947C5A5B431F977F59C8B1886F59308B764B927F54E2D1A3958456E6D1A6
5D3D17A57F5BAC815FAC815EAB8A616C5627463F09625F288A804B988251B68F647A4A24
673713A47E575942166B5B2A6C58236049135E47115D46109B824C644D175441096E5F26
665C2160571C60571C5D5117604F176D56206F541F674E18614D186858248D7C48766531
5945126852209A8452644E1C614D1AC2B17D93834F5F521D5D521C8C834C5E5720675C24
715C279A804D8C723F674B196B4F1D7557256C4E1C6C4E1C
E4DCB5CEC99FEBE9B8DBDBA5E5E9AE585216785A26C7A774E2D19DE2DBA5D1CB97E1D1A0
B08A5D6C521FD5E9A4B8E394BCEB9BBFEB9CC6EB9ECCEAA0CEE89FCFE79DCEEA9FCDEE9F
C2E998BAE492D1F8A9CFEFA4BCD08BEBF1B3948F58CFD096C3E29C83AC66678851D1EBBC
DAEBBFA5B78398AF6BC8E99ACEF8A4B5E997C3FBB4BDF4B3A6D698C8F1AFB4D586CFEC98
90B25CB7D889D8F2B1C5DEA5C3E1ADDFE7B684572EB88455DCCE8FE9F0AAC5D395DEE8B4
DEDBB8D9D3B9CBCAB5D0D7ABDEE88FD6E389DFEBBBBECBADC3D4B297A685899476A6AB8B
C1C19DE2DDB3E4DDAFE8DEBAD2C6B6908776DED9B3D5DCB0A6BFA17998785F7747D1DFA1
E3E59AE6DA8EFADF9CF9D19EFFD4B9CD978DFFCFD0FFEBEBFFF2E8F1C8B282603BAE9666
F0E3AED1CB91DAD49AEBE5ABCBC289F1E6AEEEE3ABE7DAA3A5965F74632DF4E0ABEAD6A1
F9E4AFECD7A2F7E0ACEED4A1CBAC7D987849CEAE7FEFCFA0FFDFB1ECCA9CFFE8BBEFC99C
F8D2A5F4CB9FEDC498FAD1A5FDD4A8F5CCA0FFECBFE5C596FAE6B1D6C992E1D49DE4D7A0
DACD98B3A671AC9F6A9B8E59AFA26ED9CC98E3D6A2EDE0ACE6D8A7DCCF9BE1D3A2E4CFA0
F3D0A6F0C39AFFD5ADF6C79D916C3F755B28BAB178DBD69CE4DBA4EBD7A4F1CA9F83532D
D3A17EF4C8A573552FCAB588E1D09CFFF6BEE0CD95ECD7A0E8CF99F8E1ABAF9A63827139
C6BC81DBD297F6EDB2ECE2A7E3D29AD6C18A8B703B8B713E9E8D599F925EA79764998755
937D4C846C3CAA8F60AD9263917546D9BE8FC5AA7BAE9666B09A69C6B2809F8D5BA4935F
927D486F5A258D7843B5A06BAD9863B8A36EC2AB779D8853
B8BB90EAF0C2CFD7A4D1DCA2CEDC9EDCE1A17B6830AB945EEBE0AAE7E6AEE1E2A9EBE4AE
AF93635D4914D5ECA6BFEB9CC2EE9FC3EC9EC7E99DCAE59ECCE39FCEE39ECBE59EC7E59D
C4E69AC3E89BCAEFA2CDEBA1D1E5A0B4BD7EB7B57CE8EEAEC6EB9BADDD8996B772CFE7A9
D5E4AB8FA163D2ECA5C0E598BCE89BB3E59C9BCD9082B17B93B986CEF0BDD9F6BC7E9C56
6A8A37C6E597C5DEA57D966C63815BCAD2AD6D4521AD8154EEE8AACADA9BDAF2BE6C825C
606A527B846F708367C7DDAEC3DA8CD5EA9DD4E3BA9AA992475A44556C5065805F617C51
98B178AFC585D3E3A4E8F4C2DDE9D1657366BDD4C4D5F8E488B9A3538A6AD3FFD3B8DFA0
C3DF92D9E798DADB95C7BC8674603D957A67D1B6ABFFF9EDFFF9E3ECDFBCC4BE8C9E9F65
D7E3A3E0F0AFCFDF9ED6E5A4DFEEADC7D393D6E2A2D7E1A2DBE5A6A8B172B3B97BD4DA9C
D1D598D0D497D5D69AE1DBA1EAD4A2896F3E67511FD0C38EE0D9A2E5E6ACC7CF93CFDD9F
CFDFA0D6E6A7D6E4A6DDE9ABD6E0A3DAE0A4D1D59AE3E4AAD9D99DDDDDA1ECEDB1E3E9AB
DFE8A9CFDB9BD3E2A1D2E2A1D3E3A4D0DEA0D7E3A5DBE3A7D3D89EE1E2A8F3F2BAE3DCA6
EED8A7F9DAACD9B78AA88859886E3D9E915AD3D397DBE1A1E6E6AAE7DCA6EECFA1956E45
BD936DF8D5AD594419DFD7A6E1E2A8C4C989E6E8A9E6E6A8AAA66969672ABBBB7DD4D999
DBE6A4DEEAA8C9D593C7D290E1E6A6DEDEA09B95599F9A60E3E9ADE6EEB2D4DA9ED3D79C
E0E1A7B0AF76BBB980EBE9B0F9F4BCD1CF96D3D198E1E0A7D1D298DFE3A8D6DA9F9BA367
7C8848D6E5A4E2F1B0C2D190D8E7A6E2F1B0CFDB9BD1E09F
657143B5C392CDE0A9CEE3A8E5FEBDCEDE9DD8CF96877841BCB77DD3D79CD2DC9FDFE0A6
CBBA847A7035D3EDA6C0EB9CC5EE9FC8EDA0C9E9A0CBE4A2D2E6A7D8EAAED7EDADD2EBAA
C3E29ED5F6AFC0E097C3DF95BFD38E6E7937E1E1A5CBD795C8F5A0A4D981D1F1A5CCE099
A5B171A2B271CEECA6B8E09971A35C71A46287B47B90B6832E4B1D4A65388EAA7A8EAC70
A8C875DEFDAFD2EABA82997C1D3B21D3DDC4795437C19A71DADBA2C7E0A7A5C8A0274930
243C2E91AA978AAD8C436936CEEFA8D9F4B1BBCDA77D8C777E9286CCE9D7C1EACCB7E7B7
B4E5A39CCA7FCCF0A6DFFEC2EDFFEA83A99A7BAFADB4F0EE4E9180579A7BA4DFB1C9FDBF
BFE99FD2EEA3CEDD9A9EA36B7E7A55DCD2B9B9B09FFFFFEDFFFEE0C9CEA5E4EFB5849453
B2C985B5CE8AD5EEAAD0E9A5CFE8A4D6EDA9C6DD99CEE5A1C2D794D9EEAB6D803EB2C583
D8E8A7DFEFAEDFEFAED4DE9FE8E6AD9A935C46440B7E82477E884BCDE0A0CDE6A4D9F6B3
CAEBA6C8E9A4B7D893C0E19CD5F4B0D4F1AEBBD693D0E9A7CADD9BDBEBAAD5E8A6C2D794
C9E09CD4EBA7D4EDA9CFEAA5D3ECA8CDE6A2D7EEAAC8DF9BD1E6A3E3F6B4C1D190C7D194
DBD69EF3E6B19D89566C5B25B4A971E1DFA2D7E3A1D8E7A4D6E19FDCDA9FF2DEABA28355
B49368EED6AA6E6433E4E7B0D8E7A6D0E49FD3E4A0D8E7A49EA967899553D0DF9CE0F4AF
C5DF98DAF5AEC5E099C8E29BDEF2ADC5D491B8C1809DA665CCDB9ADCECABCBD99BD4E0A0
E2ECAFAFB879A2A86CC4CA8CD2D89CD9DFA1E3EBAFDAE4A5DAE4A7AFBB7B97A56790A361
A8C680C0E19AC1E29BC7E8A1DAF9B3C4E39DB6D58FD8F7B1
5067332D4511CDE9AFBDDCA0C5EAA7C0DD9BE0E4A9716B319E9F63DCE5A6D8EBA9D4E0A0
E6E0A4A19F62C0DE96C3EE9FC4E99BC8E89DCCE7A4D3E9ABE2F3BDF1FFCEF6FFD3F2FFCF
C6E0A3D0EDABCBE9A3C8E29B5C702B8C9856D8DC9FDAEDABB3E89880BA66CBEA9EE0F0A7
484F0CD3DF9FC7E7A67EAC6C5A9150A7DB9DB5DCA3CAE8B2CAE0AFC8DEB00C270094B27C
C3E591C1E092D1E8BE9BB39D000B00CEDACC795944A88766E7EFBEC2E6B64D795EA1CFC2
B4D9D2BCE3D1DDFFE8AFE6ACC3F0AFB4D89ADAEFC67F917B576C6780A09D82B9A277BA8F
BBFFBEC1FFB4CAFFB1AEE09BCDFFD18ACAB233838A51A5B02972697ABAA0B8F2CAB1E3AE
C5EEACC6E5A1C8DA9C828A57CECEAAECE8CFAFAA97FFFFEDFFFFE4E4EDC2DEEBB3D4E7A5
7D924FEAFFBBCBE29CC4DB95C5DC96DFF4AFC9DE99D4E9A4D0E5A0CADF9ACFE49FAFC47F
8CA05B98AC67C6DA95DAEFACBFDA97ECFFC4CAE3A18196558D9D5E5864264F591C8A9457
949E61889456A5B375C8DB9BCDE6A4C6E3A0D9F8B4CAEEA8CAF0A7C8EEA5C1E59DCAE9A3
D3EDA6D1E6A1CCDD99D4E5A1CEDD9AD2E39FE6FBB6B9D38CCFEFA6B9DD93D2F8ADD9F9B0
687837777B3E7C7A3FA19F62C3C888CBD893CFE69ECAE69CC6DC94D1DA99E2D79F56420F
BBA574C3B38292925CCFDDA0C7E09CE9FFBDBED891BFD690C1D590DAEFAACFE6A0BED992
C7E99FCBEFA5D3F9AEAED288C7E59DD5ECA6D8E9A581904DB5C17FD8E3A1D7E1A2E0E9A8
E1E7A9CFD494BEBF83B0B273ACAD719092539FA36692985892985A9AA362D0DA9BD0E19D
C9E49DD1F3A9CFEFA6C3E39AC7E79ED3F3AAD4F2AACCEAA2
4B6933001900C9EAB1CCF4B6BEEDA9B8DF9CDBE6AAA09F66767839CBD694D4EBA3C3D991
E2E4A5B5BA7AA4C27CCAF0A5C8E89DCCE7A0CFE5A7D4E7B0E8F5C9FBFFDDFBFFDDF9FFDC
D0E4AFCDE5A9D2EBA9CFE6A0516520C1D08DD9E3A4CBE4A3A5DE99A1DD97C5E39DD8E19E
585A1BE1EBAEC0E1A841723A9DD99DB5EBADD8FCBEC5DD9FDAE9AEC8D9A3638050A1C48A
D0F39FBCDD8ED7F0C6B5CEB9001406B2C2B7876A5CB3947FDCE8C2D2FAD560938071A49D
7FACA59ECDBB91CEA2BBF8BCB9EDADD3FBBFC3D9A86A795C0C1E1E4C6D72175347004826
79CA8FA3EFA7B1EDA5BDF2AEC6FFC78BD7B32284852C8D9628716879B59BC2F9D2B2E2B0
BDE3A6D3F0B0A9BB81AEB687F0F1D1FFFFEAB5AF9FFBF8E7FFFFE8FEFFDFDBE8B3E3F5B7
93A664C6DA95DAEEA9CDE19CDDF1ACC8DC97CDE19CD4E9A4D0E49FDCF1ACC5DA95D7ECA7
92A661819550D1E5A0CDE49EC9EAA3ABCF89CAE7A4D6ECABCFDFA0A1AB6E8B8F54626128
5250174B4A1155561C85894ED1D99DDAE6A8CDDD9EBED493CAE9A3CDEEA7CAE9A3D2EDA8
C9E09AD3E8A3D4E5A1D7E8A4D3E29FD3E49EC5DB93D3EAA2D4F0A6BDDD91D1F3A796B86C
27410060742FB1BD7BE8F3AFD9E8A3C8DE96D2F4A8C3E89BD4F0A6D5E49FDFDB9E544710
8D7D49ACA56FCFD79ED4E6A8CAE39FBFDA93D1E8A2DDF2ADB0C47FBED38ED5ECA6DBF6AF
CEEEA5B3D78DBCE09662843A69873FBBD28CDCEDA99BAA679AA966CADB95D4E3A0D6E5A0
CEDA98DCE7A3D3DE9CB0BB778893519AA561919C5A909D58DCEBA8DDEEA8D0E19DD8ECA7
D2E9A3C9E39CCDE7A0D4EBA5CDE49EC8DF99CADF9AC9DE99
72955B577D42395F24B9E5A6C4FBB8C8F7B3C8DA9EA0A1675F5F21A8B16ED1EBA1D7F1A7
EBF4B1D3DC9D95AE6CC3E29ECEE9A2D1E7A6D0E1AAD3E0B4E5EFCCFAFFE4FCFFE6F7FFDF
D6E6B7D2E5ADCDE3A3C7DC9791A661C8DC97E3F3B2B3D19581BD89AEEAB7BDD5A1D3D6A1
9C9964CED5A1BADFAC3F7541B7F6BDB0E8A7BFE099CBE093E6F2A68D9D56AACA8BBFE6A3
C6ED9AC4E99BC8E6B4B4D3B41A412C4F6455654842C2A49AF7FFEBBEE4CB8EC1B23D7165
618F8485B59D144F21205D217FB776B1DB9BDEF4B6D2DDB3444F4B98B3BCD6FFFFC1FFFA
6FBF98428B5685B782C4F1B6C1F8B593DDAA2F968558BDB9539886669B7DB9E7C088B07E
9FC1851830008D9B66EBF1C5E0DFC1FFFFEDABA398FFFAEEFFFFEBFFFFE4E8F0C7C5D29D
D2E0A2475814B3C480E0F1ADC4D591D7E8A4D8E9A5D2E6A1E3F4B0BED28DDFF3AED1E5A0
B9CD88DFF3AE65793492A6619CAC6BD1E09FE2EEAEDAE6A6BFC98ADCE5A6DFE5A7DEDFA3
D7D79BE4DFA5A59F655A4F175C4D1666551F624E19CFC28BDDD89ED6DA9DD6DC9CE2EDAB
C9DA96D5EAA5CDE79EC1DD93CBE59CD0EAA0D1E79ED6E7A0D1DC97C1C8827B803D515C17
88A35CC4E49BD7EEA8CFE39CCCE39BC7E69AC7EE9FBFE899CAEA9EC8DC95D5D59771662E
615620B0AE75E3EEB2CDE2A1D1E4A2D1E29EDCE8A6DAE5A3949F5DE3EEACD4E09EC0D18D
D2E7A2DBF5AEC0DA93A5BC767E924D95A15FDCE2A2D9E4A28DA75EC9E99DCEEEA3CFEFA3
C5E399D5F4A8D0EEA4C4E397CDEBA1C7E79BD2F2A7CBEB9FC3E599BFE194CBEDA1C6E49A
DBECA8CCD795E2EDABE1EAA9C6CF8EE8F1B0ECF2B29BA161
CCF0B2BDE4A5C7EFB10015007EBB78B1E4A1D7EBB0DBDCA2979356A9AE6BC2DD90C6E597
CCDB96D4E0A095A96AD0E6A8D0E5A4D3E2A7D0DEADD3DDB8E9EED7FEFFEFFEFFEDFCFFE6
D3E0B5CDDEA8D1E3A5BBD08B9DB46EC5DC96CEE4A3D1F7BE3C7B50BCF6CED8EEC0CFCE9E
5D5526DCE2B2CEF2C4094110A7E8B0C5FDBCCDEDA1D7E995939C49ABB96ABFE09BCAF3AD
BAE595D2FBADBFE3A6BEE4B554805C000F00321414C8A5A9FBFFFAE9FFFBCFFBEA4A7B66
7DA78FC4F0CFB5EBBA4F894F001C00143C004D5E1A4F532072756A26393DAADDD8D1FFFF
A5ECCE0E4A268BAF89C7E4B4C0E9A7B5F2B6328F7261C0ACAFF2D33E704A2B592A001300
56783BC4DEA1DCEDB7F9FFD7FCFFE2FFFFEDAAA69BFFFFF4F8FBEAFBFFE9E5EFCDD8E8BB
CCDEA0E3F8B3122700CEE39ED8EDA8C9DE99CEE59FCAE19BBFD690DCF3ADC9E39CC2DC95
DDF7B0C4DE97D3EDA6D0E49FA4AA6CABAC70CCD093D9DFA1E5EEAFD0DA9BD9E3A4D8E2A3
DFE8A9D9DDA0E2E2A6E2DDA3E3D8A0EEDFA8604C1764531D6C632A49470A6C6C2ECFD494
D8E3A1D8E7A4CFE09AD5E9A2D8ECA4C4D58ED9E9A22732004D530D595A16565512DFE9A4
C7E79CD2F8ADC3E197C5DF96D2ECA2CAEA9EC5EE9FC3EC9DC8E89CD3E49DDEDC9F63591E
A39862D5D39ADFEDB0CDE0A0D9E8A7DBE6A4D2D898595E1ED2D797E0E5A5D0D696E2EDAB
D2E19ED1E5A050641FCEDF9BD3DF9D9EA464E4E4A6D5DC9984A055C6ED9EC4EB9CC8EFA0
C2E99AC2E99AB9E091CBF4A5C8F1A2BBE495BBE696C2ED9DC1EC9CC2ED9DC6F1A1C5EA9C
CADE97E2EDABCDD695D5DE9DDAE0A07379394348089BA060
C2E5A1CEF1AFC1E5A7B5E3A34B8845B7EBA9CCDFA7BDBC8481773A9F9C59D1E99BCDEC9E
D7EBA4CDD99BACB77F808D57E8F3BBDCE6B2E7EFC8FEFFE8FEFFF3FEFFF4FEFFF3FDFFE9
D5DDB6D7E4AFC9DB9DA4B97491AB64CFECA9CCEAAAB7E2AC65A67BA7E1B9D4EABCECECBA
554D1CD9DDABCAEBBE2C6231B2F1BAB9F1B0CCECA1D5E493A4AD5CCDDB8CC7E6A2C5F0AB
BEECA3C6F4A9BBE79CA2CF8C1E4F172C44224E3032896372C0BFC4EBFFFCE3FFF281A987
64845B032200214819356130001400C8E6B4D0D996E6E4A9999578C6D1C1486F5A0F452D
2D6447A7CFB4CEDCC3D7DDBBD2E4A8C7EFB10C542C1D6D4A29683B3C733C78AA6DBBE9A8
CFF7B1C6E6A3CFE8AEE4F8C7E1EFCCFBFFED4F5547FBFFF6F3FEEEF8FFF1E7F7DCC7DEB4
CCEAAAC7E99D9EC07491B367BCE194D2F7AAC2E79AC0E598BFE598BFE598CCF2A5D1F7AA
B3DC8EBCE597D6FFB1BDD98FE3E9A9AEAA6D9F9F61747939B8C180D4E3A0D5E9A4D2E9A3
D8F2ABCEE8A1CBE59ECEE59FD0E5A0D8ECA7DBECA8CFE09CCFE09C95A4618D9957505916
5A5C1B5756163733004943055E59195753135B5A19797C39A3AD68C7D48ED6E69FD0EAA0
BFE89ACBF5A9C0DE94DBF5ACD2ECA2B3D286D1F6A8C7EC9EBDD78DE8F5AFBBB57967581F
9D905BDDD8A0E0EBAFD7E7A8D8E4A4D3DC9B969B5B919354D7D799D3D596E2E7A7D1DA99
D8E4A294A561CEDF9BD8E7A4DBE6A4D7DC9C86844792975597AF65C5E898C0E595CDF2A2
BEE393BAE190D9FFAFC0E796C4EE9CC3ED9BC2EC9AC3ED9BC4EE9CC5EF9DC4EE9CC5EA9C
CFEBA1CCE39BD8EFA7AEC57D8CA25A8CA25ACADE97D4E8A1
C5E49ECDEEA9CCECABC9F6B56FAD6AC0F7B6D9ECB4DCD9A2A8985DA7A05CC1D888C0E190
D6EDA7D2E0A3BEC494A1A477B0B688CAD1A7EDF2D4F8FCEBF3F6EDFAFDF6FFFFF6FFFFED
DEE4BED0DAA6E5F5B696AB66ADCB85C0E3A1B8DEA185B67E92D5A0ABE4B1CAE1A9D0D198
615A24D7DCA6C0E0AE1D521E7FBC83B0E6A8C9E8A2C9DB9196A057D2E19CC9E7ABCBF3B7
B9E7A6C5F4ACC6F6A2B7E79355893F8BA576765657300519D4CCD9EAFAF7E2FFE2B6D6A7
C0D7A171864E98B282A0BF96C3E2C3CAE0BCF2F5BCCFC98DD4CDA15B613D71906682AD82
BDE3BC566E4E928D779E9375504F1952652D64976C003409C3FAC1C1F2B1BCE9A4BEE8A0
C5E9A1C8E7A3CDE7AAD4E8B5D1DFBBFBFFECBBC4B3E5EDDEF9FFF4F4FFEFE5F4DDD0E6BF
CAEAA9BEE396CCF1A4A7CC7F668C3F8DB366CEF4A7BEE497C9F2A4CBF4A6B1DA8CBFE89A
D6FFB1C0EB9CBAE395D0F0A5C8D794ECF2B2D9E2A1EBF6B4C3CF8D3B4C0895AA65C3DD96
CCE7A0C3E39AC5E79DCDF1A7C9EFA4B9DF94B6DF93C7EBA1CCE7A0D4EAA2E4F5AFCCD994
DBE4A1DBDD9CDADA9ADFDE9EE6E5A5DDDD9DD5D796D1DA97D6E39ED5E9A2D1E79FC6E49A
BFE99DBFE99DD6F4ACC7DE96CBE29AD2ECA2D0F0A4C0DF93E1F7AEACB57291874C806C37
AB9A66E6DFA8D1DB9FC2D293D6E5A4AFBB79A4AD6CC6CC8CEBF0B0DFE5A5D5DE9DDFEBA9
D2E39F687D38CEE39EDDF1ACCBDA97DBE4A3848647838A47AABB74829A4EDBF3A7DBF6A9
C3DF92DDFCAEBBDA8CCAEB9CCBEC9DCBEE9ECCED9ECAED9DC9EA9BC8E99AC8E99AC9E99D
BEDE93CAEA9FCAEA9F76964B819F55C6E49ADEFAB0C3DF95
D0ECA1CBE99FCCE9A7C5EDAE7CBA77AAE2A3C2D79ED7D29B9F894FAC9E5DD3E899CFF2A0
D2EDA6D5E4ABF8F6CDFFFFDFC6C6A2F6F7D8FBFEEBC5C8BFB3B5B4EAECEBFFFFF8F8FBE6
DFE6BDCDD69FC1D08D93AA62D4F3AFCAF2B3BDECB55A9157AFF1AAC3FBB0D6F0A7D8DF9B
5E5D1CDAE3A4CFEEB36C9C624A8147A6D99ECFEEB3CBDFA49EA873DAE8B7B8D1A7A5C99D
7CA771CAF9B5BDEE95BDEF90BCF199D1EAB089666288576CF5E7F6F2FDF9E0F6D2D5ECB4
E8F7B6A0AA6BD6E4B1D5E6C2E6FBECE2F0DFEBE9C0FFF6BFDCD59EB5B97E97AE6A789753
C9E1A57C8556887958A08969B6A77C9C9F72C2E0BA517C4FA2C88BC3E49DC7E79EC4E096
D5ECA4DDF1ACD2E0A3CCD6A2C9CFA9FFFFE6FDFFEAA4A595FFFFF1FFFFEFF3F8E2E8F4D0
D2EAACD3F1A7C6E49AC9E79DB3D18762803667853BD8F6ACC2E096D0EEA4C9E79DC9E79D
C8E69CC7E79CD1EFA5C6E69BD1F3A9B8DA90C7E59DCCE69FD6EBA694A56189985597A663
C8D995E3F7B2D9F3ACBCDC93BEE79BC9F8AAC7FAABCDF7ABD5ECA4CEDE97C1D28BD0E69D
E0FAB1C1DD93CAE89ED3F3A8CAEA9FCDEBA3D1ECA5D0EAA3D0E5A0CFE39ED3E2A1D0E5A2
BFE59CD9FFB6BAD58ED4EAA2DBEFA8D8EEA6C3DD94DAF1A9CCDB967C7E3D9D8C5468511D
A38F5CE1D7A2EEF6BDD7E9ABCDE4A08CA65FB0C580D5E9A4D2E39FD4E5A1C2D691C7E19A
C7E59D83A35ABFDF96C7E59DC5DF98D2E6A175844146510DDDE4A05C631FD5DC98C7D18C
DAE5A0E7F4AEC3D38CD3E49DCEDF98CFE39BD3E49DD1E59DD1E29BD1E29BD4E59ED4EAA1
D2F0A6C5E79BC6E89C93B569B2D488D1F3A7BBDD91CFF1A5
D0E998C7E295CAE5A0BAE3A18DCE8AB2EDADD1E9AFE9E4ADAB9259AE9F5CC5DC8CBBE28F
C3E49DCFE2ABF4F0CDFFFCE2FFFFE6F6F5E0F4F4EAF5F7F6E4E7ECD4D8DBD5D8D1D8DBC6
D8DDB4D5DEA5808F4AA5BD73CEF1ADB3E1A386BB870A450BA5E694C7FDA5C5E08FE0EB9F
494C07D3DC99CDEAA8BAE4A40020004F7F45C5E8B2D1E9B988996DC5D5AED6EECAB0D0A9
7DA475B3DFA0C0EE96D1FF9EBCEF92D4EAAAD7B1A8FFDDECFFF8FFFBFFFAE0F2CAD3E7AA
D3DD988E9551D0DBA1CFDEB7F7FFF8F9FFF8FFFFE3FFFFD6E1DCA2DCDF98D8EA98D9EF9C
DDEBA0DDDFA0D8C799ECD6AFEADBB4C7C59E96AC85122F00A1BA79CCE299D5E9A1CFE197
D9E6A0D2DD9BD2D89CECEEBCE4E2B9FFFFDDFFFFE4FFFFE85E5A41FDFBE2FAF6DBF6FBD3
EEFEC0C6DC94D4EAA2CEE49CB3C981DDF3ABD1E79F596D268A9E57B9CD86D5E9A2D5E9A2
C5D992CBDF98E1F5AECDE79ECDF1A7CDF6AACAEEA4B4D48BCEE9A2CFE6A0DBEFAAD3E4A0
B3C27F8C9D59667A358AA15BD1ECA5D7F7AEBADC92BDDD92BED68CD9EFA6D7F1A7CFEEA2
CBEDA1BCE295C2EB9DC2ECA0B7E195BDE59CC3E9A0C6E7A2C5E29FC8E19FD0E4A5D2EBAA
C8F0A9BCE49BCCE7A2D3E7A2D3E4A0DBECA6C3D991D3E7A0727D39EBE9ACD6C28D684E1D
A99362E4D8A6BFC78ED5E9AAADCB858CAC63CCE7A0D3EDA6C3DA94D8EFA9D1ECA59EBE75
54782EB2DB8FCBF1A6CAEEA4D7F7AED6F0A9CDE29DADBC79E5ECA98F9451A9AE6BCED893
DDE8A3D4E19BD2E29BD6E7A0D1E59DD1E59DD1E59DD1E59DD1E59DD1E59DD3E49DD1E59D
C8E49AD3F1A7BCDA9095B369C1DF95D8F8ADBADA8FC8E89D
D2EA94CDE693D0ECA2B6DF9B8ED48EB5F6B4D2EBB2D6D39CAE945BBEAF6CDAF5A4C6F3A0
C5EFA7D4ECB8F8F5D6FFF7E4FFF8E6FFFFF4FFFFFDFEFFFFFBFDFFFCFFFFE9ECE5BCC0A9
A4AA7CAFB97C7E8E45BED88ECAF2ACBFF1B67EB98B4A8952B7F39DC5F796B5D27EDAE89D
6D7430CFDA96CBE59EC7EBA5224F0A265416A4CA97C5E4B8869F78C4DAB6E6FCD67D9770
618559B5DCA3C8F1A2C4EF95B9EA91D6EBAAC59E8FDAA7ACFFF8F9FCFFF4E3F5CBD3E7AA
CFDA959BA25CD5E4A3DAEAB9ECFAE1FBFFF4FFFFEFE3E4C4E3E8B2DAE49FACBB6A687722
85913DA0A457A8A363ABA16C9491689AA07A677E501732007C8C4D949E5998A25D9FA662
A0A56387894A8E8D54C3C08BE0DCADF3ECC2F1E9C2F5EDC8716944E4DFB9F4ECC7FFFFD1
D8E2A3D2E29BD9E6A0DCE9A3D9E49FD9E49FCFDA95BAC47F99A35EAFB974989F5BADB470
E7ECA9DEE3A0CCD18ED7E29DC4D891CEE89FD3EFA5C7E59BCDEDA2BEDE93C1E196C4E298
D5F1A7CEE49C8D9C57616A27929453D3CF90E9E1A3E6E6A6DAF6A9C4EE9CC0E796C0E597
C7E99DCAEA9FC1DF97D6F4ACD3F1ABD3F0ADCFEEABCAEAA9C5E8A6C2E6A6C0E7A6C0E9A5
BBE69FBADF99D7F0AECCDC9BD1E09FC0CF8CF0FFBF889955757E3DDDD89EFEE8B675592A
A69061EFE3B3EFF6C0E0F6B87E9D578AAC62D0EEA6CCE7A0CCE69FD6F0A9D4F2AA77994F
5E8439CEF8ACCBF4A8BFE59ABFE197B9D48DC8DF999AAE69BBCF88D2E69F879D55D8EFA7
CBE59CCBE99FC3E398D1F3A7CEF3A6CBF0A3C7EC9FC7EC9FCAECA0CAECA0C7E79CC4E298
C9DF96D0E49C8B9F57889C54C4D890D6ECA3D1E79ED2E89F
D2EB8FCEE891D6F0A6B6E19A7FC87FA6EBA8BBD89EAFAE76795E27A19251D1EE9CBAEE99
B0E299C0DEAAF2F1D5FFFCEFFFFDF3FAF5F1F7F5FAFEFEFFFBFEFFF6FAFFF8FDF6FCFFE7
D3D9A9CBD694DEEEA3CEEA9DBEE7A3B7ECB479BA90A4E7B2C4FBA7C5F094CBE79CDBEBAA
B8C285BDC98BD9EFA7C9E89CC4ECA3BBE8A569945E20471844643B5F7A513E5626475F2F
6B8B5CCAEDB7C9EAA3B6DB8BCFFAAAD6E8AA9F7660AF7C78FFFAF1FAFFEEE1F6CDD2E9B1
D9E5A3ACB870C5D992D3E7A8F9FFDCFBFFE8FBFFF4FCFFEFCBD6ABAEBC7F83934CA4B263
BDC975E2EA97E5E99CC3CA87DEE7BAD7EABDB2D198CBEBA8D1E4A2D0DD98CDDA95D9E4A0
CFDA969FA8678D9355ABB175BDC0899FA26D959863D7DAA5828550DCDFA8E2E5AEC6CE92
DBEAA5CFE39BCDDE97CEDF98D3E39CDBEBA4DBE8A2CDDA94D7E29DDCE7A2B3BD78959C58
9198549DA460C5CA87DCE6A1D7E49FDAEBA5D2E8A0C8DF97D2EEA4D4F2A8D3F3A8D2F2A7
CAE69CD6EDA5D6E7A1CFD895C2C282A49E60A2965ABAB978C7E396BEE894C1E897C4E797
C6E69BD7F3A9C4DE97D4EBA7C9DF9EC7E09FC8E2A3CAE8AACEEDB1CCF0B3C6ECAFC1E9AA
B7E29DD5FAB5CBE4A3D8E8A9DFEBADD6E2A2A7BA788FA05CD4DA9CDED7A0E6D09FC0A578
C6AF83F0E6B5FFFFD3CFE4A994AF6CA4C27AC9E39CC9E09AD5EAA5CADF9ABBD58E87A55D
C7E99FBBE196C4EA9FCBEFA5CAE8A0E5FCB6D9EDA88D9E5ABFD38CD8EEA694AB6386A057
D2EEA4CCECA1C7E99DC4EA9DC2E89BBFE89AC0E699C2E89BC5EB9EC8EDA0C7EC9FCAE89E
D9EDA5DAEAA399A962B9C982D6E69FCADB94D3E79FD8ECA4
CBE685C3E084D2EF9FC0EEA57BC77DAFF8B1D1F3B7CECF96A68D55AC9E5DC2E490B7F19C
C1F9B0CFF4C0F3F3DBFFF3EAFBF0ECFFFDFFFFFDFFF9FBFFF0F6FFF9FFFFFCFFFAF5FBDF
DAE1AED6E19DE3F4A6BFDB8EB9E3A1B2EBB483C7A0ABEFC0B4E69DBDE294CEE8ABD6E8B6
D2DEAE94A16BD6E7A1CEE698CAEF9FBEEA9FC2F2B4BCEBB478A06CB6D7A0D0E9A7CAE09F
D4EFBCC5E1B0CCE8ADCFEEABB1D690D0DEA3E7C0A3EBBAABFFFDEAF3FFE4DFF8D0CBE6B3
CFE1A59DAE6897B265C3E090CCE29AD3E4B0F6FFF3E4F4E9BDD0B2DBEEC1DDEEB8C6D496
D4E297C6D582DFF19BD7EEA0C9E6B0C4E9B3C5F3AACCFBAACFF3A9C8E7A1C5E49ECEECA6
CFEDA7C6E49EC8E39ED2EDA8C6E19CCBE6A1DAF3AFC8E29BDEF8AFC4DE94D2ECA2D8F4A7
C4E699C2E99AD5FAACD3F8AABADC8FBCDC90CCEB9FC7E69ACBE79CC3DD93CAE298D7EFA5
D3E9A0DDF3AABDD18951651D51621CC6D590C9D893E9F8B3D9E8A3B1C07BE3F4AEC1D28C
C9DA94D6EAA3D5EBA3CCE29AD3EAA2DBF2AAC0D78F98B0664E6618BED688E2FAAED5EDA1
BDD48CD9F0A8D8EFA9BDD490D2E8A8D8EEB0E2F7BEEEFFCBF4FFD3EFFFCEE2F6C3D1ECB5
CCF3B2BCE49EF3FFCBE7F7B8CEDA9CE3EFAF526523DCECABE6ECB0D4CD96F2DCABAA8F62
9E895CE6DEAF000B0093A86DD0E5A4DAEEA9D6E5A2D8E4A2DDE8A6D7E2A09DAC69C3D792
DBF2ACC0DB94D0EBA4D8F2ABC0D48FCEDD9AD1DA99919757D3D999D2DB9ABBC6844E5D1A
D5E6A2CADF9AD5ECA6C6E099CEE9A2D0EEA6D5F0A9D3EEA7CEE9A2CDE7A0D0EAA3D5ECA4
CBDC95DDEEA7C6D790D4E8A0CBDF97D6ECA3DBF3A9C3DB91
DDF09FC7DF91CAEEA6BFF2AD6AB76FA4EBA5D0F4B7D6DEA5A3925AAD9F62D1E29BCCEDA6
C4E6A9C0D8A8E5EBCFFFFFF1FFFEF8F9F7F8F8F8FFFBFFFFF8FFFFF4FEFFF8FFF9FBFFEC
E0E9BEF7FFCAC0D592CBEAA6CDF9BAB2E9B271B287488655C0EDA8C9EBA1BFD89FD7EBBA
D5E2B48C9964CFE09CCEE597C1E090CFF8A9B5E39BC2EFAE86AC6FD5F3B3C8DE95D6EAA3
CAE3AACDEAB2C8E5A5C9E6A3CAEEA8DDEBB0DAB799E6BBAAFFFEEAF0FDE1E6FCD5CDE7B7
C6DEA28DA45E849F52D8F1A0DBF0A1CADC9EF3FFE8F4FFF395AA89B9D0A4D5E7B7D7E9AF
D8E9A3D4E99AC9E38CD1F2A1BADEA0C4EEAFBDEE9DBFF19ABBE697C4ECA3CBF3AAC4ECA3
BFE59AC8EEA3CCF0A6BFE399CBF0A3C0E598C2E799CEF3A3B8DE8BCEF4A1C8EE99C1E895
C0EB9BC6F3A2BCE899B9E494C8F3A4C8F1A2C1E79AC8ED9FC5E79BD3F3A7CBEBA0C9E99D
C4E298C0DF93CEECA2D1EBA2AEC27B99AA6491A05B818E49A2AD69D7E29ED0DB97E0EDA8
D8E7A2D0E49DCFE69EC9E79DC4E69AC8EEA1C7F2A3BEE596A9C175AEC076869B50D0E49C
DDF3ABC3D893CCE39DD3EAA6C5DB9AD2E8AAE7FBC0F8FFD3F9FFD3F5FFD0E3F1BCCFE4AC
C3E6A6C8EBA9F7FFCFFCFFCDC1CC90677537C5DA99D4E9A8D3DFA1E1E0A7EADAA78E794A
B8AA795D5B2896A86EC5DD9FC9DE9BDEEFA9CFDB99D6E19DD2DB9ADEE9A574803ED4E39E
CADE99E3FAB2BFD690CFE69ED6EAA5D2E19CE1ECAA969F5EB9BE7EE9EEAED8E19E7F8A45
BBC882CDDC97CCE09BD5EAA9F2FFCAF7FFD3F5FFD4EAFFC8D8EDB2CBE1A1CCE39FD4E9A4
CDE19C91A25E8CA05BD4E8A3D0E69ECCE39BC7DE96D7F1A8
D4D7ACD8EABAB8E5AEBFFFC286D18EB0F3B0CCF4B6CEDDA4BFB985A59361644F207E693C
AB9971C8C39DDEEAC4F2FFE7F9FFF4F4FBF3F9FFFDEFFAF6F7FFFFF2FFFAEAF7EDF7FFF3
F7FFECEAFED9C3DDB0DCFCCAB0DBA5C3F4BC80B9827FB577C5EFA5C7E79BC8E3A0D4EAAC
D1E2AB95A46BC4D797DAF1A9C5E194D2F3A4C6E89BCBEDA18BA65F8EA360CEDA98DCECAB
CBE8A6BEE29ACAED9BCEF19DC0E595CBDB9D7E6547B59387FFFEEFFDFFEBE8F4CED2E6B1
CAE9A6BFDD95ACBD779DAA65DFEEABC3D597B4C6928DA16ECBE0A8C9DEA3CBE1A3D5EBAA
CFE6A0CDE79ECCE89DC9E99EC8E9A4C5EAA4C3ECA0C3EC9DC2ED9EBEE99AC3EC9EC6EC9F
C3E89BCAECA0D1F1A6CCECA1CDECA0C4E498C5E599C6E89BC2E797C7EC9CCBF2A1C6ED9E
C8F3A4C1EC9DC8F2A6C1EA9CBDE398C9EEA1CDEFA5CBEBA0C8E89FC7E79CC2E299D4F4A9
C9E9A0BEDE93D3F5ABC8E69EC4DB95D5E9A4CBDC98B8C9858D9C59A0AF6CCFDE9B8E9F5B
B3C782CBE09BCBE59EDBFBB2B7DB91C0E69BCAF4A8CCF2A5D1EDA3D1E79F8BA1598EA45C
6B823CC0D791D4EBA5CBE29CCAE19DC9E09CDEF4B3CAE09FD3E8A7E3F8B7BFD493D4EAAA
C8E5A5D1EBACF8FFCCECF7BDB1BC82A9BB7DC6E3A1C8E7A3C5DB9ADEEAACE2E0A75D541D
807E45B2BA7ED5EEACC8E7A1D0EAA1D1E79ED8EEA6C9DD95E6F7B1CFE0996E823BCDE199
D3E9A1CEE69CC9E39ACCE89DD0ECA2CCE89DC0DC92B7CE868D9C5BDCE8A6CFDC94CEDF91
98AB5AC3D88BD4E9A6CEE3ABF3FFDBF2FFE5F4FFECF4FFEABFD8AED0EBB6CDEAAACDE8A3
D7EBACDAEAACA5B779E2F4B6CADF9EC9DF9EDAF1ADC8E19D
D8DCC3D6E5C6BDE4B8B9EFBB75B0767FB77AB3DCA0D7F3B9D3DDA8F1EDBDB09A736B4E2C
6147265C4D2CEEF6CFF9FFE6FDFFEEFEFFF4F3FBECF8FFF3E2F1DCF4FFF0E0F2DAE3F3D8
E0EFD2EDFCDBEDFFD9DFF8CEBCDEACB8E3AD8ABC81B7E8A6C1EA9CD3F4A5C4E096D1E8A4
C9DB9D92A264D2E5A5CFE6A0CDE79DD1EE9EC6E693CCE99792A85D455610E2ECADD3E1A3
C7E6A0C0E798C8EC94C7EB91C6E997D9EBADAE997ED2B4AAFFFEF3FFFFEDEBF3CED0E3AC
C3E7A1BCDE94B6C282ADB37794A26489995B94A7678A9D5DD2E7A6D2E8A7CAE39FCBE4A0
CCE7A2CAE8A2CAE8A0C9E9A0C8EAA0C8EAA0C6EAA0C5EB9EC5EE9FC2EB9CC4ED9EC6ED9E
C4E699C6E69AC8E79BC3E296CEEA9FD0ECA1D2F1A5D3F3A7D0F2A5C9EEA0C2E799BBE293
C3E99EB8E195C4EA9FCDF1A7CBEDA3C9E9A0C5E39BC5E39BD3EEA7BFDD95D5F3ABC2E299
C9E9A0DCFEB4BBDD93C8EAA0CEEEA5D4F2AACDE8A1D5EFA8C1D892C1D691D4E8A397AB66
8B9F5A8DA25DB0C781CEE8A1D1EFA7C5E59CD5F5ACB5D58CC8E29BD1E8A2D8EFA9B6CD87
69803A95AC66889F59B1C882DBF2ACCEE59FCBE29CCDE49ED0E7A1BAD18BDCF3ADCBE4A0
CEE8A9CEE3A8E1ECB2DEE7AEC9D49ACEE2A3D5F4B1C3E49FCEEBA8C3D696DEDFA36D682E
747436DDE8A6C6E19AC7E99DC8E49AD8F2A8C7DF95C9E197D0E69DD1E79E677D34D5EBA2
D0E69DCBE399C8E298CAE69BCCECA0CBEDA0C5E79AC1DF9595A866D7E6A3D7E79ED9EC9B
91A452DCF1A2BBD08DDCEEBAF7FFE6ECFBE4EEFFEDF4FFF3CBE0C1C3DDAEBCD89BD5EFAE
C7DB9ED0DFA68A9C62C9DB9FD8ECADCFE5A5CAE3A1D4EDAB
B5C8ACBDD0B2DDECCBF5FFE3EBFFDCBBE2AD8AB77E557E445E7D44A7BE888A9C6CD9E6BA
A4AF85464725CCC1A5FFF0DAFFF4E4FFFDECF7F5DEF8FFE0EEFDD6C0D3A6D3E3B6CCD8A8
D2D5A6F1F3C4F0F1C5F6FFD2D3E6B8CFEFBE87B380C6F3B8C4EA9FCFF09FC8E298D2E7A2
D1E4A48C9C5EDDF0B0C8DD98D2ECA2CEEB9BC1E18ED1EE9EC5DB905B6C26D0DA9BCCDA9C
CDEBA5CAEFA1CBED96C4E78DC7EA98DCECAED5C0A5DCBEB4FFFDF2FEFFEEEAF2CDD1E4AD
C5EAA4C7EBA1CDDC9BCED69AC6D496BDD090CFE2A2C9DC9CF8FFCCF1FFC6D6EFABCAE39F
CCE7A2CAE8A2CAE8A0C9E9A0C8EA9EC8EA9EC6EB9EC6EB9EC4EB9CC4EB9CC6ED9EC9EEA0
CBEB9FCBEA9ECAE99DCBE79CC5DF95C9E59AC2E195BEDE92C5E599C6E89BC7EC9ED0F5A7
C4E69CCDEFA5D4F4ABCFEFA6C2E098C0DB94CDE7A0D9F3ACC5DF98D5EFA8CCE69FC7E29B
CCE7A0C7E59DCBE9A1CCF0A6BDE79BBBE79AB1DB8FCAF0A5CFF1A7CAE8A0DBF5AEC2D792
D7EBA6CCDB9898A764657431B1C07D9CAB68C1D08DE1F2AEC4D994D9F0AAD2E9A3BDD48E
CEE59FD0E7A17B924C9CB36D758C46647B35C3DA9496AD678AA15B94AB6599B06A8BA460
7892519EB678C7D59AD0DBA1CDDB9ED1E5A6CDECA9C3E49FD5F0ADC8D897E8E8AC4F490F
8D8B4EDBE4A3CFE9A2C6E69BC3DD94DBF3A9CDE39ACFE59CD0E49CCBDF974B5F17C2D88F
D0E69DCDE59BC9E399C9E59ACAE99DCCECA0CBEDA0CDEBA19EAE6FC2CE8EE1EEA8D3E194
ABBA6996A757D3E4A0C4D39CE2F1CAEDFAE0F8FFF1F7FFF1EDFEDEEDFFD5CFE4ABCAE0A2
D3E5ABE0F2B885975BA9BB7FD6EAABD1E7A7BDD694D0E9A7
EEFFECF3FFE9FDFFE5FBFADCFCFFE1F3FFDEE9FFDCB5E2A9C0E9B1CAF1BA00130093BE89
B5D9ABD9EBC5615339B69D87FFF6DFC2BDA0F4F6D1DBE7B9C7DAA2CAE0A0DAEFAAD7E8A2
D4E19CD7E2A0D4DFA3DBECB5CDE8B5ABCF9F92BD90B5E2ABCAF0A5BEDF8ECFE99FD6EBA6
CDE0A096A667DCECABCCE19CCDE89BD3F0A0C4E491CFEC9CE8FEB3BCCD8799A565DEECAE
D0EBA8CDEFA3C8E893C6E790CBEC9BD1E1A3E3CEB3D8BAB0FFFAEFFCFFEDE9F3CED0E5AD
C5EDA6CBF1A6D8E8A9DFE9ACD8E8A9D0E3A3DEF1B1D3E8A7F4FFC9EAFFBFD4EDA9CDE8A3
CCE7A2CAE8A0C9E9A0C9E9A0C8EA9EC8EA9EC6EB9EC6EB9EC5EA9CC7EC9EC7E99CC8EA9D
CEEDA1CDE99ECBE79CD1EBA1C8E298D3EDA3D1EDA2CDECA0D2F1A5CAEA9EC1E396C7E99C
C1E198CCEAA2C1DC95C1DC95D0EAA3D9F0AAD6EBA6C3D893D3E8A3D6EDA7C3DA94D6F0A9
CEE8A1BDD891DAF5AEC4E89EC1F0A2C4F9A9B8E99AC3EFA2C8EEA3BFE197D0EBA4D5ECA6
CFE09CDCEBA8DBE6A4C9D291E2E8A85359194C52129DA866D9EDA8D2E9A3CBE29CD2E9A3
CDE49ED2E9A3DAF1ABBDD48ED6EDA7C9E09AD6EDA7CEE59FDCF3ADCDE49ECBE29C7F9854
688241A8C082D7E5AAD9E4A8D4E2A5CFE3A4C9E8A4D2F1ADC9E29EE4F3B2DEDCA1483F06
B4AE72D2D797DFF4AFCAE69CCEE59DCDE59BDCF2A9D0E69DDCF0A8D0E49C41550DCFE39B
D3E79FD2E89FD0E89ECCE69CCAE69BC9E89CCAEA9ECFEAA392A063EEF8BCCFDA96CBD78B
E0ED9D9DAB5C919E58DEECB1C9D4A9E2EBCCF3FDE5EBF5DDEDFBDAF8FFDEDCEDB9CFE1A7
CADCA2D7E9AD85975B95A96AC5DB9BD5EBAAC9E2A0CEE7A5
E2FFE3F3FFE9FFFFE8FFF7DFFFFFE3F9FFDAF1FFDDCDF4BFBCE4AFBFEEB7BCF6BB548F55
7FB480D4F5CA99987A585135A9B58FD9F1C1B8CF99C5DE9DCBE29AD3EF9BC8E68CCEF193
CCF597B2DF84C2F3A1ABDF95A4D89A5D925CAADEB0BAE9B5C6EFA3C0E28ECDE89BD5EBA3
94A463BECE8FD2E2A1D5E9A2CCE498D2EF9FCDED9AC6E393D0E89CDBEFA87F8D4FD2E2A4
CDE6A5CAE8A2C3DE8DCDE995D0EFA1CFDDA0EDD5BBE8CAC0FFFDF2FEFFEDE9F5CFCDE4AC
BDE79FBEE89CCADF9ED2DDA1C9DC9CC1D695CEE3A2C1D796D2E9A5D2E9A5CBE4A0CFEAA5
CCE7A0CAE8A0C9E9A0C9E99EC8EA9EC8EA9EC8EA9EC8EA9ECBEDA0CEF0A3C6E69AC6E599
CFEBA0C9E399C4DE94D2EAA0CDE59BCEE89ECCE69CCAE69BCAE99DC8E89CC7E79BCBEB9F
CDE8A1DBF5AECEE59FD5ECA6DAEFAAC9DE99D1E5A0D8ECA7CBDF9A94A863C3D893D9F0AA
C9E39CD4EFA8C6E19ABADC92B7E396C5F6A7BEED9FBEE89CC6ECA1C2E49AC8E39CCDE49E
C9DD98D4E3A0E1ECAACFDA98DFE8A7E3ECABEBF1B1A6B16F8DA15C879E587F9650A1B872
D0E7A1CBE29CD2E9A3D9F0AAC4DB95D2E9A3C8DF99CEE59FCDE49EBCD38DD2E9A3D9F2AE
B7D491D8F2B1DDEDAFCFDA9ED5E3A6D4E9A8C6E3A0C9E8A4C0D793BBC787A6A167655821
A2985DDCDA9DD1E09DC7DE96D3E9A1BBD188D0E49CCCE098CCDD96D6E7A03C4D06E3F4AD
D3E49DD3E79FD3E9A0D0E89ECBE59BC9E59AC9E59ACEE59FA3B078959C66E6EFAEDBE59C
D5E091AEBB6B79853BCED899D2DAA9D2DAB3EAF1D2F9FFE3FEFFE4FEFFDFE5EEBFE9F6C0
D9EBAFCFE3A4ABBF80CCE2A2DEF4B4DCF2B1D4EDABC9E49F
CDEBC7DEF3D2F9FEE0FFFEE1FFFFE1DADCB5D7E4B8C5DDADCBE9B5B8E1A9B0E3AAC6FDC4
80B57F436D3DD7EDC68E9E77455B2DC6DFA8D0EAADCFEAA5DCFBABC6E98FB9DE7EBBE581
C3F28CBDEF8EBAEF97C5FBAD86BD7A7EB57CB3EBBABDF0B8BDE69AD1F39FC7E295D1E79F
4D5D1CE1EFB1CFDE9DD7EBA4D5EDA1C7E293CBE896CBE898C8E094D0E69EA2B07293A365
C9E1A3D2EDAAC8E092D3EC99D1EDA0D6E1A5E8CEB5F1D3C8FFFCEFFCFFEDE9F5CFCCE5AC
BEE9A1BFEBA0CAE09FCEDEA0DDF2B1D3E9A8DDF3B2D1E7A6D0E7A3CFE8A4C8E39ECCE7A2
CAE8A0CAE8A0C9E99EC9E99EC8EA9EC8EA9EC8EA9EC8EA9ECAE99DCFEEA2C8E499C9E59A
D7F1A7D0E89EC9E197DCF4AAD2EAA0CAE298CCE69CD0EAA0C9E59ACAE99DCDECA0C4E397
C5DF98D3EAA4C7DC97DDF2ADC0D48F5D712C374B063C500B5465214B5F1A96AB66D2E9A3
C4DE97C8E39CDAF5AED3F3AAC4E89ECBEFA5C1E59BBBDD93C7E79ED3EEA7CFE9A2CBE29C
D7ECA7C9DD98CDDE9ADFF0ACCDDE9ABBCC88D2E39FD4E5A1D1E6A1D1E8A2D4EBA5455C16
001500809751D4EBA5C6DD97CAE19BD9F0AAE2F9B3C9E09AD2E9A3E9FFBAC5DC96C7E09C
CAE7A4D7F2AFCEE0A2C6D496D2E2A3D2E7A6C2DF9CC3E09DE2F7B47D8647A39A6174652E
96874EE5DFA3D9E4A2D9EDA6DDF3ABCFE59CD3E79FE3F7AFC8D992D7E8A142530CCEDF98
CFE099D1E29BD2E69ED1E79ECFE79DCCE69CCBE59BCDE4A0F4FFCB2932009DA768D3DF97
D6E393D3E08EDCE89C58631FDFE8AFD1D9AADEE4C0DADFBFF4FAD8FFFFDFFFFFDAFDFFD3
D5E7ABB6CC8CC3D999F7FFCCF7FFCCD8F1ADD0EBA6C7E29D
C7D9B3E2F7CEF4FFE1F5FFDFF7FFD7D4D7ACDCD9AEE0DFB3DEE7B8D7E7B6E1F7C6BAD5A2
CAEAB8A7CF9B97CE97BCE8B3757E512C2B00E1EEB6C9E2A0A4C97BD9FFAECBF69CCBEF95
C8E48DD9EF9DCADF94C9E09C83A666C8F5BAAFEAB0B2EDABBEE99ACFF19DCDE79DCFE49F
4E5C1ED2E0A2D7E6A5D4E5A1D6ECA3C7E293C7E492D2EF9FD0EAA0D6EDA7C8D8998C9E62
AEC388D3E9A9CEE499D3EA9ACCE79ADCE6AACEB499DFBFB4FFFBEEFAFFEAE4F3CACAE6AC
C0EEA5C5F4A6D0EBA8D5E7A9CEE4A3C2DB97CEE7A3CDE6A2CCE5A1D4EFAACAE59EC8E39C
CAE8A0CAE8A0C9E99EC9E99EC9E99DC9E99DC8EA9DC9E99DC8E499D2ECA2C9E399CDE59B
DDF5ABCFE59CC2D88FD6ECA3D9F1A7C5DD93D3EDA3DEF8AEC9E399C5E196C2DE93A1BD72
8DA76077914A49601A7D944EBED38EB8CD88C7DC97D7ECA7D2E6A1D1E6A19CB36D89A35C
6B863F67853DB4D48BCEE9A2D5E9A4D6E5A2D8E7A4D2E39FD3E4A0D8E9A5D2E6A1CEE39E
CCE39DDAF4ADC3DE97C5E39BDDFDB4C8EAA0C2E49ACEEEA5CDE7A0C7DE98DDF4AECDE49E
C3DA94C0D7918DA45EA3BA74869D57C4DB95C5DC96D6EDA7CFE6A0B2C983E5FCB6C5DF98
BBDA94C7E59FD1E4A4D6E5A4DAEAA9D4E9A6CBE9A3D3F1ABCDE29F9EA466DCD1998F7B46
B5A26AECE3A8D9DF9FD5E6A0CEE29BD4EAA1CDE199CFE39BD4E59EC5D68F86964FCADA93
D2E29BD1E29BD1E29BD0E49CD0E69DCFE79DCFE79DCFE4A1C8D7A0A2AF79909E60D8E8A1
CFE090C5D783E1F09FA8B66B929E5E99A36EC8D1A4CDD5ACEBF3CCF8FFD7D6DDB38E9A68
AEC28599B270B2CB89E5FEBCE6FFBDCEE9A4D3EEA9D0EBA4
D7E0B5D8EABABBDEA8C0E6ADDDF4BED0D8A5A1996A60522561592A4D49192C2800C5C798
D3DFAFC8EBB37CC1805D995BCEDAAA665F334A511E90A469A7C585C5E9A3C2E39CD3F1A9
CEE29BCEDD9AE6F2B2778748809D5DC3ECAABAEFABBAEFA7C8F1A2BCDD8CDAF4ABD2E7A4
7E8C4FADB87CE2EEB0CDDE9AC7DD94D7F2A5CEEB9BC9E898C1DD92DDF4AECEE1A1D4E6AA
82965BC3D798CBE095CFE696C8E094E2ECB0BCA186C8A89BFFFFEFFCFFECE3F2C7C6E4A8
BCECA0C0F1A2C9E6A3CFE4A3D7EEAAC6DF9BCFE8A4D4EFAAD5F0ABE2FDB6D5F0A9CCEAA2
CAE8A0CAE89EC9E99EC9E99EC9E99DC9E99DC8EA9DCAE99DCDE79DD9EFA6CDE39ACBE198
D6ECA3BDD38AA7BD74B7CF85C8E09695AD6389A35987A1577892489FB96FCFEBA0C4E095
C5E099E4FFB8C1DB94C7E19ADAF1ABC5DC96CFE6A0CEE59FC6DD97D9F0AADBF5AEC2DD96
D2F0A8CBEBA28BAD6387A25B7E8947959758C0C585D8DE9ED6DF9ED4E09ED2E39FD6EBA6
CFE6A0CCE7A0CBEBA2C6EAA0C9EFA4B3DD91C7F3A6C4EDA1C8E39CDFF6B0C7DE98D1E8A2
D0E7A1CFE6A0CBE29CD8EFA9D1E8A281985293AA64AFC680B4CB85829953B5CC86CDE8A1
CFF0A9C8E7A1CADF9CCFDF9ED0E09FCADF9CC6E49ECCEAA45A6D2BDBE1A3E9DCA5AE9964
B7A26BE3D99E979C5C91A05D8A9E5794AA618DA159687C34B7C8818E9F58C9D992D9E9A2
D8E8A1D5E59ED1E29BD1E29BD0E49CD0E69DD0E69DCEE3A0D1E4ACD7E8B1A2B575899D55
DEF3A4C9DF8CD5E896D8EB9CCCDD978E9E608D9A658591619EAA7CAFBA8FAFBA8F8A9865
D1E7A9D1EAA6CEE7A5C7E29DC8E39ECAE59ED3EEA7CCE7A0
DCDEACD0DFA6C6EAAABAE7A2BBDE9AD7EBAC97945D6A5A2783713FA58F5EB89D70867142
B9B381D5EAAF96D38D63A25CCDE8B1959E6F737A4E4A5127545C3379845A6C794E97A87B
CCE4B2BCD9A3D9F8BD87AA6AA1C480BCE098C5EA9DC5EA9CC8EB9BC2E296D6EFABCEE0A2
BEC98F78834BC2CD91DCEBAAD0E69ECFEA9DD1EE9ECCEB9DB8D489D6F0A9CFE4A3D4E8AB
B1C48C65793CDCF1A6BFD485D4EC9EE5EFB2CAAF92FCDCCDFFFFECFCFFE8E5F6C9CCEAAC
C0F0A4C0F1A0CAE8A2D4EAA9CCE5A1CBE6A1C9E49FD6F1ACEEFFC2EBFFC1D4F2AAC5E399
CEECA2CAEA9FC7E79CC7E79BC8E89CC9E99DC9E99DC8E79BD4EAA1D1E59DD6EAA2C9DF96
CBE19892A85F667E34C7DF95CFE79DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCCE89D
CBEBA2CDEFA5C8E89FC6E49CCFEAA3CEE9A2C9E39CCDE7A0CEE9A2C9E49DC8E69ECEEEA5
CFF1A7C7EBA1C4E89ECCE7A0ADB6756D6D2F797B3CB2B777E2EBAAD0DB99D2E39FCCE19C
D0EAA3C9E79FC2E49AC0E69BC3ECA0C5EFA3C4F0A3C4EDA1CBE69FD9F0AACCE39DD2E9A3
D4EBA5CFE6A0CFE6A0D0E7A1C2D993D0E7A1D8EFA9D7EEA8ABC27C6279336E853FC7E29B
CBEDA3D2F2A9D0E5A0C6D793D0E19DDAF1ABBCDA9291AF6794A863D2D898EEE1AAC0AB76
E3CE99B9AC7566672B879653869A5370883E4B6118273B00B9CA83DEEFA8CADA93D7E7A0
D1E19ADBEBA4C3D48DBACB848DA159DFF5ACC6DC93CDE49ED0E8ACCDE5A9C2DB99455F16
CEE99ACEEA96D1EA97D4ED9CD6EEA4C8DF9BB9CD908FA26A869864B2C492C9DBA9CFE2AB
CDE6A5CCE7A0CCE7A2CCE7A0CCE7A0CAE8A0CAE8A0CAE89E
D2D397E6F0B1B8D690DFFFBCC9EFA4BFDD95B7C3817672354C3B03D3BA84E1C190D6BA88
685B266E783BBCE49EC6F3AE738F55C8D8A9D5E1B974805C9CA789A1AE9286967B5D7155
87A17E82A17798BD898AB073B7DF98CCF3A2CBF19AC6EC95C6E89BC3E29CCDE3A3CCDEA4
EAF4C05F6833F2FBC4CAD89BCADE99C7E197C3DF92CEED9FC8E499D5F0A9C8DE9DCADEA1
C8DBA3A0B4777C9146E6FCAAD7EFA1C1CB8CB4997BC1A28EFFFFEAFCFFE6E6F8C8CBE9A9
BCEFA0BCED9BC4E29ACCE39FC9E49FCAE8A2C9E49FCEECA6DDFBB3DBF9B1CCEAA0C6E49A
C7E79CC7E79CC7E79BC8E89CC9E99DC9E99DC9E99DCBE79CD2E69ECBDC95CEDF989DB169
6A8037CFE59CD1E99FCFE99FCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCAE99D
BEE096C5E99FC9EDA3CDEFA5CEEEA5C8E69EC7E29BCFEAA3CFEDA5CBE9A1C7E59DC3E39A
C1E399BFE399C5E99FD1ECA5D4DF9DDBE0A0D4DA9ABBC684AFBB79606F2C4E621D798E49
7C964FAAC57ED1EFA7D5F5ACC7E99FC0E49AC4E89EC9E9A0BFD992CFE6A0CCE39DCBE29C
C2D993DBF2ACD0E7A1C5DC96DFF6B0D9F0AAC3DA94C2D993DBF2ACDBF2ACC3DA94B5D089
6D8F4554762A7E954FCBDC98CADE998CA35D819F57B3D189D2E7A2E2E8A8DDD0996C5722
8D7843A49760C8CC8FE2F1AED9EFA7CFE79DD1E99FBFD58CCEE29AD0E19ACFE099D5E59E
DCECA5CDDD96ADBE777788417E924A92A65ECBE198DCF3ADCBE5A4CDEAAAC8E3A0CEE9A2
688437D2EF9FC1DE8CC4E191C1DD90C9E59BCDE6A4CDE5A7C6DEA4D4EBB3CEE5AFCDE5AB
CCE7A4CAE8A0CCE7A0CAE8A0CAE8A0CAE8A0CAE89ECAE89E
5D642086904BDEE9A4C6DA92D2F4A7C0E798CCEEA1D7EBA3A9A5666151161B0600EEDBA1
A6A0645F5F218E9051D7DDA1DDE5B2051500617A50CBEEC6ABD4B24A775A4E795E6B9178
527056001200667D53C2DDA6C5EBA2C8F9A0BFF995B5ED8CC9F2A6CBE9A9DCF1B8D9EAB6
CAD3A4D0D6A86B723FC9D49AD7EAA8DDF4ACC9E598CDEC9EC4E397C3DE97C7E09CD8EEAE
D1E6ADCCE0A353681DC8DE8CC7E08FDDE8A6E3C9A6C9AA95FFFFE8FAFFE1E2F4C0CAE9A5
BFF09EBFF19CC6E49ACDE49ECAE59ECCECA3CAE8A0C7E79ECEEEA5CBEBA2C6E69BC9E99E
C5E599C7E79BCAEA9ECAEA9EC9EA9BC8E99AC7E899CAE699D0E49CD2E29BA0B16A394D05
D3E9A0CEE49BD4ECA2C7E197CDE79DCCE89DCCE89DCCE89DCCE89DCCE89DCCE89DCAE99D
D3F7ADC7EDA2BFE399C2E49AC7E79EC8E69ECDE8A1D4EFA8C5E099CCE7A0D1ECA5CEECA4
CBE9A1C9E9A0C9E9A0C8E69EDEF3AECBDF9ACDE29DD2E7A2DDF4AED2E9A3D2E9A3C8DF99
E3FAB4CCE39D8EA55F4A5F1A394E096F833EB5C984DEF2ADE5FAB5C4DB95C8DF99DCF3AD
C4DB95DAF1ABC6DD97D7EEA8C3DA94CDE49ED2E9A3D0E7A1CEE59FCDE49ECDE49ECAE59E
D6F8ACD3F5A8D0E79FBBCF889EB26B97AE66B1D186D8F8ADC5DC96CCD594F1E6AE8D7944
A28E59A39860E8EEB0CBDC98CDE49CCFE99FD4EEA4E9FFB7D1E79ECADE96D4E59ED6E7A0
CEDF98CCDD9643540DDAEBA4D6EAA2D8ECA4CCE299CBE29AC8E39ED5F2AFCFEDA7D7F5AD
7B994F749347DFFEB0D8F7A9CFEEA2D9F7ADC4E29AD2EFACC7E4A2C8E4A7C1DDA2CDEAAA
CAE8A2C9E99ECAE89EC9E99EC9E99EC9E99EC9E99EC9E99E
B6C2789DA75E90934CDBE59CC8E497C3ED9BBEE997C7E99CCAD48F7E7939342C00B7AF71
BEBD7DB7B3747D6A3281703AD8D6A5D4E0B060774986A97F9AC6A26A97786C977B0A2E14
97AF9710230596A57CD6E9B2BDD893C9F19BBBED8CC3F699BEE39DE0FDC5EEFFD1EBF8CC
FFFFDDF7FCD3868C5EBDC691C2D293D2E9A3C6E297CDEC9ED1F0A4C8E69CCAE5A0CBE4A3
C8E0A6D2E8A8D1E699798F3C839C49E3EEAAC3AB85B6987EF3EED1EAF5CDD7EAB3C5E49E
BFF19AC2F39ACCE89DD2E8A0CBE9A1CFEFA6CAEAA1C6E69DCAEAA1C8E89DC6E69BCDEDA2
C9E99DCBEB9FCCECA0CAEA9EC7E899C6E798C6E798CBE79AD6E7A0DDEDA67D8D46DAEEA6
D1E79ED2EAA0C3DD93DCF8ADCCE89DCAE99DCAE99DCAE99DCAE99DCCE89DCCE89DC9E99D
C9EDA3C1E79CC6EAA0D0F2A8CDEDA4C9E49DC8E29BC7E19AD1E8A2D2E9A3CEE59FC6DD97
C5DF98CDE7A0D2EDA6D2ECA5CFE9A2C7E19AD7F1AAD0EBA4BCD790C7E29BDCF6AFC9E39C
C8DF99CEE39ED0E49FD0E19DD4E3A0D3DF9DBAC38299A56393A7625B722CA1B872A7BE78
CAE19BC5DC96CFE6A0D3EAA4DBF2ACD0E7A1D1E8A2D7EEA8D4EBA5D3EAA4D3EAA4CBE79D
B6D88BC4E699D5EDA3D4E8A0CCE099C9E098C7E79CCAEA9FDEF5AFCDD896ECE3AAAB9A64
B4A36D989258E3ECADCDE19CC3DD94D5F1A6B5D186C5DF95D4ECA2CDE39ACFE39BD4E59E
A9BA7372833CE0F1AAC4D890D9EDA5B2C87F5D732ABED68CD1EBA2C3DF95CBE79DBDD891
D7F2ABB5D089759147C0DE94BCDA90CFEDA3B9D78DCEEEA5C7E6A0C8E7A3C2E19ECDECA8
C9E9A0C9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99E
D1E196E3EFA5979854555B15D2E89FE0FFB7BBE696CFF5A8D9EDA698A15E4B51116D7232
DDE3A3EBE7AA907643765C295E5824DDE4B0C8D2A0D7E4B8CEDDB6D1E1BDD2E1C0000F00
3F4D2A626E46D9E5B5D3E0A8DCE8A8DAE79FC9D788D7ECA1CAE6ABDBF7C6F7FFDFFBFFE1
FFFFE1DADBB9E6E8C0909867DCEBB0DDF2ADCEEA9FC5E496CEEEA2D1EFA5CEECA6C1DC99
D8F2B5CEE7A6C3DA8CD3EB97CFEB964A5510917A50B4997CDED9B9DBE6BBD2E4AAC4E298
BEEF96C0F196CAE598D0E69DCAE89ECCEEA4C7E99FC5E79DCCEEA2CBEDA1C7E79CCBEB9F
CBEB9FCBEB9FCAEB9CC8E99AC7E899C8E99ACAEB9CCFEB9EDAEBA48A9A5391A15AD5E9A1
CDE39ACBE399E4FFB5ADCC80C9E99DC9E99DC9E99DC9E99DC9E99DCAE99DCAE99DC9E99D
C7E99FC4E69CCFEFA6D0EEA6C2DD96C5DC96D4E9A4D9EDA8D3E4A0D4E5A1D5E4A1D5E4A1
D6E7A3D8E9A5D4E5A1CADE99C5D994DDF2ADCDE49EC0DA93D2ECA5D8F2ABC9E39CD1EBA4
D0E7A1CDE29DCEE29DD6E7A3DAE9A6D8E4A2D5DE9DD2DE9CD3E7A2D9F0AABCD38DD1E8A2
516822889F590D2400000F00C9E09ACFE6A0D2E9A3C8DF99C2D993D2E9A3DBF2ACCDE99F
D7F9ACC9EC9CC9E195D0E59AD2E89FCCE69CC7E99DCCEEA2C5DF98CCD896E5E0A6CDC089
CFC28BB1AC72CFDB9DC4DB97CBE99FDFFFB3CCEB9FC6E297D3EDA3C9E197D5EBA2C7DB93
95A961DAEEA6C2D68EDBEFA7D0E49CC5DB9299AF667D9549D3EA9CD9F0A2CDE39ADAF0A8
D0E7A38FA662465F1DD2EBA7CEE8A1D9F5ABCCE89ECFEDA3C6E49ACFEDA5CBE9A1CDEDA4
C9E99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99D
D3E39AD3E098E6F0A998A35E5E742BC8E69CCCEEA4BDDD94C1D894DCECAB9EAD6C6D7738
C5CD91DFDDA4F7E6B2DACA969A9960919B5E9BA46B47521A54612C6E7A488F9D6A909E6B
CFDBA9DFECB7CDD8A0C1CB8FD8DEA0DCE19FE2E5A2C8D293D5ECB8D6F1C6F7FFE3FBFFE4
E8EDCFF7F8D8C6C8A39CA475B6C38BB5CA87D7F3A9C9E89AC0E094C3E398CDEBA3D0EDAA
CFE9ACC3DE9BDDF6A5CEE891D5F19A9DAA62A28D609E8463D0CCA9D5E1B3D5E7A9CBEA9E
C4F59AC3F296CCE496D1E69BC8E69CC9EBA1C4E69CC4E69CCDEFA3CBEDA1C6E69AC8E89C
C9E99DC7E79BC5E697C6E798C9EA9BCCED9ECCED9ECFEB9EA2B36C94A45DE4F4ADC9DD95
D0E69DD4EEA4C4E095DFFFB3C8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99D
D5F5ACC4E49BC7E29BCBE59ECCE39DDDF1ACE3F2AFCAD694DCE7A5D6DF9ED1DA99D4DA9A
D3DC9BD3DC9BD4DD9CD6DF9ED3DC9BDEE9A7D9E5A3DCEDA9D1E5A0CFE49FC5DC96CFE6A0
D8F2ABCDE7A0CAE49DD1E8A2D1E6A1C9DD98CBDF9AD5E9A4CCE19CCAE19BDAF1ABD8EFA9
B8CF89CEE59FA3BA748BA25C97AE68869D57849B559EB56FB9D08AC3DA94C5DC96C9E59B
BCDE91CEF1A1D7EFA3C9DE93C7DD94D5EFA5D1F3A7BFE497CEE9A2DCEBA8D6D197A0955D
938850AEAE72CFDD9FD8F3AEC1E196BADC8FCDEDA1CFEEA2C5E196C7E197D2EAA09DB36A
8A9E56D6EAA2C7DB93D1E79ED6ECA3CFE79DCAE29899AF6490A352D9EC9BD0E298D1E29C
D7E7A8C4D698DEF2B54E6223CDE4A0C2D993D3EDA3C7E398C0DC8FCDE99CCDE99EC8E79B
C8EB9BC8EB9BC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99D
DEEBA5BBCF87C8E499D3F1A7C3DD96536823DEEEADD8E8A7D3E8A7DBF0AFBAC88B96A064
7D8047878A51E8F2B6D4E2A4CFDE9BD4E59FCDE49CC6E49AE6FFBCABD082C6E89BD3F2A6
C5DC94D0E49DDBE7A5E1ECAA8993548793539CAC6DDCF0B5C0DAABE2FCD5F6FFE5ECF7D9
FFFFE8F8F8DCDDDEBCD4DBAF5B6832536827BDD98FD4F3A7CCECA0C5E79BC1E198CDECA8
D3F0B0CCE7A4C2DB8AC1DE84CDEB91CDDB90BEA97A7E6441B3AF8AC1CD9DCFDFA0CCE89B
C6F599C3F294CEE796D5EA9FC8E69CC9EEA1C7E99DC5E79BCBEDA1C9EB9FC4E699C8EA9D
C9E99DC5E599C4E596C7E899CCED9ECCED9EC7E696C4DF9295A65F8B9B54D2E29BCADE96
CCE49ADAF6ABB4D387C3E397C8EA9DC6EB9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DCAE99D
C9E49DC0DB94CFE6A0D6EBA6D5E6A2DBEAA7C3CE8C868F4E858A4A6C6E2F525214454507
44440652521478783A9E9C5F847E4250470C4D490C949456B0B676DCE7A5E2F3AFCFE6A0
CDE8A1C4E49BC2E49AC8ECA2CFF3A9CEF2A8C9EDA3C7E99FDBF6AFCBE29CC9E09AD2E9A3
D1E8A2C7DE98C4DB95D0E7A1C9E09ACBE29CCFE6A0CEE59FA6BD77637A345F763095B167
C5E898C8EB99D5EDA1D7ECA1CCE299BED88EBCE194C8EDA0CFEAA3D7E8A4DDDBA08E834B
685F26A2A367CADA9BCEECA6CFF1A5BDDF92C6E89BD4F4A8C4E095CEE89EAEC67C859D53
D8EEA5C4DA91DDF3AAC3D990D0E69DD6EEA4C8E096D5EC9EC1D07F899646A8B46AE8F5B0
CCD79BCEDCA1DBEAB1B5C4899BAE6E7D914CCDE39AD0E89CD8F0A2D8F3A2CFEA9BC4E393
C8EB9BC6EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EA9DC8EA9D
D4E39ED3E9A1D2F0A6BDDD94CEE39E314000A0A96AD3DFA1D0E6A5BBD492D8ECADCDD89C
41440B5F6229D9E4A8CEDE9FD8E4A2D1E19AD1EC9FC7EA9AB5DC89CBF59FD3FBA5B9DC88
D3F0A0CAE598C8E096ACC27A596C2A91A162485619CBDCA6CFE4BBD5EBC7F7FFE8F9FFE8
F7FFE1ECF3D2D4DCB5D1DDADABBC855C7031ADC682C6E099CDE7A0D3ECA8C6DC9BCEE7A6
C3E29FCBECA5D1F0A0CFF099CBEB96D4E49BD0BB8C897249898C5FA0B17BBCCA8CC5D991
C6E894C7E792D0E296D9E9A0CDE79ED0F0A5CEECA2C9E79DCBE99FC8E69CC6E49ACEEDA1
CFEBA1CBE79CC8E499CCE89DD0ECA1CCE89DC1DC8FB7CF837F934BC3D48DC7DB93D1E99F
D3EDA3CDECA0C5E599D0F2A5C8EA9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DCAE99DCCE89D
D2E9A1D4EAA2D6EBA6B2C880869A5591A25C9DAC69818E49A1AC6A979E5B959A5A9A9F5D
979C5C989D5BB4BA7ADDDFA0BBB77AAEA86C908E51A5A5679A9F5F8E995792A15ECFE39E
CCE39DD1ECA5D1EFA7CAE8A0C6E69DCAEAA1CBEBA2C7E59DC7E19AD0EAA3CCE69FCAE49D
D7F1AACAE49DD0EBA4CDE8A1CAE59ED8F3ACCCEAA2C6E49CC7E59DA6C47C88A65E92B267
89AC5CA6C778C8DE93D5E79DD3E79FD1EBA1CBEDA1C6EB9ECDE8A1C5D491ECEAAF9B9058
645B229C9D61CCDC9DCDEBA5C4EA9DD1F6A8C4E096D3EBA1CCE39BD5EDA390A75FADC57B
CFE9A0CCE89DC7E399CDE79DCCE29AD1E79ED0ECA2C5E093C9DC8B9DAB5C9CA85EC9D490
EBF5B8CBD99ED2E1A6CDDFA3C9D99A839251DCE9A4D0DD95D1E196CCE395C8E797CDF09E
C8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EA9DC8EA9D
8DA15CB0C47FD8ECA7D6E7A3D7E3A197A36191A05DADC27FC8E6A0C8E9A2CBE9A3D2E7A4
B6BF80A9A76C413600746931E1DDA0D1D694CFDE99D4EBA3C3DF95DFFBB0CBE59BC6E096
C1DF95CFF1A589B46588B165D3F3AADAEDABBABA7E5F5D2CDCE6C3E3F3D6F7FFE8F7FFE4
F7FFE1E4F7CAC6DDA9CDE4ACCFE5A7C7DD9DBDCF9195A567AAB57BE0E9B2DDE1AECDDAA2
C4E5A0C2ECA0CBF6A6BCE394CDEDA2D2E19ED9C996EDDDACD4E3AA9BB375868E52B0B273
DEE5A2DDE4A0D3D693DFE6A3D3E49E91A8628DA45EB7CE88C7DE98CEE59FD5EAA5C9DF97
D5EAA5C4DA92D4EAA2D9EFA7C9DD96DAEEA7CFE39C8CA25ACFE79DCDE79DCCE89DCAE99D
C9E99DC9E99DC8EA9DC8EA9DC4E699CBEDA0C4E699CDEDA1D5F4A8C8E499CAE49ADEF4AB
D2DF9994A15B95A66096AE649EBA70C9E89CCFEFA4C7E69ACDE99FD1E99FCCE29ACCE098
D4EAA2D4ECA2CDE79ED2E9A1CEE29DDAEBA7D8E9A5D7E8A4D2E39FB1C27E9CAD69ADBC79
929E5CA1AD6BB8C381CDD695DBE1A1DDE3A3DCE1A1D7E09FD2E7A2C4DF98D9F4ADC5E39B
D0EEA6CAEAA1CEF0A6C3E79DC0E49AC5EBA0C9F2A6C7F1A5C2ECA0BEEA9DBFEB9EC3EC9E
D4F6A987A3585E6F2893A05AD7E6A1DAF0A8C3E197C7E79CCCE39DDAE6A4D8D4978F8349
71662ED9D99DD7E6A5C4E39DC5F4A6BBE496DEEAA8D9DE9CD3DF9DC7D8924F631ECBE29A
C3E39AC4EA9DBAE498CAEFA2D9EAA6D3E29DC6E49CC7EC9FC9E59ACAE0979BAA654B5715
D9E8A7D5E8A6BCD591D8F1ADD8E8A7E7F0AF706C2F817B3DD2D493DFF0AAC5EB9EBEEB9A
B7DC8ED2F2A6CAEA9EBFDF93CFF1A4CFF1A4BEE395C2E799
A0AF6C83924FDCE8A6D2DE9CCCDB98CDDE9AD5ECA647621B8FAD65D3F1A9C2DC95E3F7B2
CAD090D5D3966A5E2458491063591EDDDB9EE3E9A9C0CF8CD7ECA7B8D28BD2ECA5D5F0A9
D5F3ABC7E99F7CA257D1F5ABDFFAB3B7C884D2D7975B5B27C9CEAEEAF4DBF5FFE6F6FFE3
F5FFDFE1F9C7CAE6ACCBE7AAD5EFAECAE3A1C4D899D9E7AA3039004B501AE6E6B4D2DBA4
CBE9A3C5EB9EC2E89DD6F8AEBDD893DDE7AAE5D5A2ADA16DCAE3A2B6D591E9F5B7ACAD71
454507A7A968D6DD9A2E3900D3E4A0CBE09BBED28D99AE698EA25DC5D994EAFEB9D2E6A1
D5E6A2E4F8B3BBCC88C5D692E2F3AF7A8B4751621ED5E9A2CCE89EC9E99DC9E99DC9E99D
C8EA9DC8EA9DC6EB9DC6EB9DCAEC9FCBEDA0C9E99DCAE99DCCE89DC1DB91D7EFA5BFD38B
A7B26DC8D28DCEDF98CCE49ACBEB9FCAEFA1CCF3A4C9F0A1C2E497C9E99DD0ECA1CFEBA0
CBE79CC7E69AC7E99CCBEDA0C4E49BC9E9A0C3E199C4E29AD0EAA3C9E09AC6DB96D8ECA7
D4E3A0BCC886909B59626B2A535919747939B8BA7BEBF1B1D0DF9CD8EDA8C2D792C3DA94
CAE49DD1ECA5C2E098C7E79ED3F5ABCAEEA4BDE398B7E195C2EEA1D0FCAFCCF8ABC0EB9C
BBDD91C3DD93D9E9A2D6E39D8E9D5841570F66843AD3F3A8D0E7A16A7634312B005E5218
9E935BEDEDB1BECE8DD6F7B0BAEB9CC8F1A5D3DE9CE1DFA2D9DE9EE8F3B193A762CFEAA3
C8EEA3C2ECA0C1EDA0CBEFA5C6D793D3E29FCEECA4C5EBA0CBEDA3DCF7B0BACE89D8E7A4
535F1DD6E7A3E2F7B2BAD18BCEDF9BBFCA88EFEDB0989659818646C0D18DCFF1A7BDE69A
D2F2A7C8E79BC2E195C9E99DCCECA0C3E598C5E79AD2F4A7
909253A0A666DAE9A6C0D590CDE8A1C9E9A0B5D58CD6F4ACAEC57F6C7D39BFC887DAE0A0
F1F3B4DCDE9FE2E7A7E2E2A4676326504C0FDDDD9FF7FFBFC6DB96CAEAA1D4FDB1ADD68A
C6E69DBED58F7E89478B9151CCD292D4E3A0D1EBA4D4ECB2A2AB8EF2F5E4F5FDE6F4FFE1
F8FFE1DFF5C6D2EBB4C9E5A8CFECAAC9E7A1D7F1AAC8DF99C8DC97DAE9A86F7B3B9CAB6A
D3E49ED9EFA6B9CF87D6EAA5E2F1B0CFD094A99361635621D5F0ADBCE49DCDE2A1D1E09F
ADBE7A8DA35B91AD63A3BF75CEE59FD8EFA9DDF2ADBBD28C93A86397AC679EB36E869B56
889C578CA15CA0B46F9BAF6A8B9F5AAABE79D0E49FCBE29ACCE89EC9E99DC9E99DC8EA9D
C8EA9DC8EA9DC6EB9DC6EB9DC9EB9EC5E79ACCECA0CAE99DC9E399CCE49ADEF6ACA9BD75
6F7C36D4E19BD6EAA2CEE89ED7F7ABC0E597BFE697C4E99BD2F2A6C5E498C5DF95CBE59B
CEEA9FD2F1A5CFEFA3C0E295C9EDA3CCF0A6C6EAA0C6E89ED0F2A8D0F0A7CAEAA1CFEDA5
CBE9A1D8F3ACDBF6AFC5E099A0BA73839D567E954F859954939C5BA9AE6E949959B4BA7A
7A8342A7B270D4E3A0E8F9B5C5DA95D4EBA5D9F3ACCBE9A1BDDD94BEE096C6E89ECAECA0
D7F7ACD0EAA0CFDF98DDEAA4E0EFAABBD1898EAC6281A1568BA55E98A764C0BC7FA79D62
786F36D3D498D2E5A3CAEBA4BCE89BC9F2A6CEE29DDCE2A2DEDEA0C8CE8ECDE29DCCEEA4
CBF5A9BDE79BC5E79DD4EEA7C7DB96DEF3AED2EDA6BFDF96C6E69DBEDC94CCE19CDCEBA8
CBD4935C6222C2C888E7F2B0D6E7A3D6EBA6CBE09BD3EAA4ABC07B839752E2F6B1CEE39E
CBE59CC8E69CD2F0A6D2F0A6C6E49AC5E59ACEEEA3CCECA1
E0DEA1989D5DCBDC98CBE69FD5F9AFDBFFB6B5D98FD0EEA6CEDF9BD5DE9D7072336D6D2F
CFD494CFD897E0F1ADC5D491CDD292676528565417CACC8DD1DD9BC5DF98C8EEA3C3ECA0
CAEAA1D6EAA5989A5B322E00E9E9ABD1DD9BD4F6ACBCDEA1828B70F9F7EAFEFFEDF9FFE5
FBFFE3DDF0C2D3ECB3C5E2A2BCDB97DDFDB2CFEEA2C6E295CDE89BD6EEA2C8DE93182D00
64712BDEE9A4E5F0ACD6E19DC8D190EFEDB2AD96645B4E19C3E09DCAF6ABCFEAA5CCE39D
D3EFA5C9E99DBEE596D0F7A8CCEAA0BFD992CCE39DDCF6AFD5ECA6CCE39DD3EAA4DAF1AB
D4EBA57D944E8BA25CCCE39DC6DD97C4DB95DCF3ADD4EEA5CAE89EC8EA9DC8EA9DC8EA9D
C8EA9DC8EA9DC6EB9DC6EB9DC9EB9EC2E296CEEDA1CCE89DCAE298D9EFA6B6CC839AAB64
8F9F58D9E9A2D1E79EC0DC91D0F2A5C8ED9FC3EA9BCBF0A2C8E79BC8E499D4ECA2D3EBA1
C3DD93C4E095CFEEA2CFEFA3C4E69CC9EBA1C6E89EC2E49AC6E89EC8EAA0C4E69CBFE399
BFE399C2E69CC5EBA0C7EDA2C7EDA2C8EEA3CBF1A6D3F1A9D9E8A5D2D8984F5515555E1D
565F1E636C2B3A4503253000DEEAA8D5E19FD0DC9AD2E19ED6E7A3D5E6A2D3E4A0D1E79F
C0DC92D3EDA3D6E69FCBD892D1E09BDAF0A8D0F0A5C9EB9FC9E49DCDDE9ADADA9C574E13
A59F65DBDFA2E2F7B4B4D890C5EFA3BCE599D5F0A9D4E09ED9D79A6D6F30D5ECA6C3E99E
BFEEA0C0E99DCAE19BD8E9A5CEE39ECFE6A0C8DF99D5EFA8CFE9A2CFE9A2D5EAA5C0D18D
E2EBAAACAE6F535315D4D999DDECA9C2DC95CDF3A8C1EA9ED2F4AAD4EBA5808646DCE2A2
CCE099CFEBA1CEEAA0C8E69CCFEBA1D2EEA4CDE99FC8E49A
D6DB9BA9B271CDE19CD4EFA8B5D98FABCF85DFFFB7B9D38CCDDC99E6ECACC3C586757738
B1BC7AD5E6A2D5EFA8D0EBA4D1E5A0D9E4A279773A615D20989659D4DA9ACCE19CC7E59D
CCEAA2CAE19BD9E4A2A5AB6B8F9555DDECA9B4D28AD8F4B980846BFDF9EDFFFFEFFFFFEA
FCFFE3DCEDC0D2EBB2C3E29FCEF0A6A9CB7ED0F3A1C8EB97C9EB95C3E58ED3F49DD9F29F
D5E3988E9851D8E39E8F9A56E9F2B1CCC88BDDC69280733CD5F4AEB8E499C5E39DD1EBA4
C7E59BC6EB9DC5F0A0B8E192D4F4A9CDE8A1C8E29BC4DF98C5DF98CCE69FD0EAA3CAE49D
DFF9B2CFE9A2C8E29BD2ECA5D9F3ACD0EAA3C6E099C3DF95C9E99EC8EA9DC8EA9DC6EB9D
C6EB9DC6EB9DC6EB9DC6EB9DCCEEA1C5E599D0ECA1CBE59BCAE097D8ECA47687408FA059
D3E49DD6EAA2D6F0A6C1E094C4E99BD0F7A8C3E89ACDEFA2CEEA9FCFE79DD3E79FD5E9A1
D0E69DD0E89ECFEBA0CDE99EC9E39CCBE59ECDE8A1CAE59EC7E59DCFEDA5D6F6ADD4F6AC
CCF0A6C6ECA1C0E99DBFE99DC2ECA0C1EDA0BEEA9DBCE599CFF1A7D8F3ACC2DD96E3FDB6
BFD690C9DD98E9FAB6CEDA98AEB7769CA2629D9F60B5B577C6C487CAC689D6D094E5E7A6
D0E69ECCE69CD0E099D8E59FE1F0ABD5EBA3C3E398C5E79BCCEAA2CFE39ED6D899C3BF82
7B793EE9F2B3D5EEAAC9EDA5C9F2A6B9E296CFF1A7CEE39EC5C184514F12CBE69FBDE99C
B5E697CDF3A8D5E19FD9E2A1CCE19C8FA96297AB66CFDE9BD3DF9DDCEBA8D0E5A0C4D994
DBEAA7D0D998C3C184979759949F5DD5EFA8C4F0A3B2E596C2ECA0D2EDA6A5A7689A9A5C
CDDE9AD2ECA5C2DC95BFDA93D9F3ACD4EEA7C5DF98D5EFA8
CFDE9BC9DD984A5F1ACBE59EDFFAB3C6E19AD4EEA7DBF0ABD8E7A4C9D593EBF6B4D2DE9C
8FA35E3D540EC3E199C0DE96C9E39CD3E4A0EDF2B2918D507C73389A9659B6BB7BD9E5A3
C8DC97C9DE99E0F5B0D5E9A490A45F40540FCAE19BD5E6AF9A9D80F9F6E5FFFFECFBFFE3
F9FFDDDDEFBDD0EAADC7E6A2CDEFA3CDF2A2CBF19CC0E68FBADE86D1F59BC7EB91C0DE88
DFF4A7D2E299DFF0A9AABB748E9B56BDBD7F9A855092874FC8E6A0CEF8ACD0EBA4CBE199
D4EEA4D2F1A5C6EB9BC9EEA0C1DF95CDE8A1D2EDA6D0EBA4D0EBA4D3EEA7D0EBA4C8E69E
C0DB94C0DE96CFEAA3D0EEA6C3E199C5E39BD0EEA6D0EEA4C9E99EC8EA9DC6EB9DC6EB9D
C6EB9DC6EB9DC6EB9DC8EA9DCBEB9FC5E498D0EAA0CCE49AD2E69ED6E7A06F7F38A8B972
DAEEA6C1D98FD3F2A6C8EA9DBEE395C8EFA0BCE193C8E89CD1EBA1DAF0A7D4E59ECFE099
D3E79FCEE49BC5DF95CEE69CD6EAA5D5E6A2DDEEAADCF0ABCEE39EC9E09ACAE19BBFDA93
C7E59DC9E9A0CAECA2C8ECA2C4EA9FC0E99DC2EB9FC7EDA2B4D68CD6F6ADC1DF97C5E39B
D7F2ABCBE29CCCE19CD0E49FDAE9A6D5E19FDBE4A3E2E8A8CACF8FA5A7689EA061ABB471
CFE69ED8F2A8DBEBA4D1DE98CDDC97CAE199C7E99DCFF4A7C7E59DD6EBA6E2E7A78A884B
929256BFC98ABFDA95CEF4ABC2EB9FC4EDA1BFE399D1E8A2AEAC6F959557CBE9A1C0EFA1
BEED9FD2F4AAD1D797DEE0A1D8ECA75D742E606F2C767F3EA6A668CDD292DBECA8DDF4AE
C3DA94DFF0ACDDE3A3DBE0A09CA765869D57BEE79BCCFBADBBE498C0DB94DCE2A29FA162
93A460CEE8A1E0FAB3CAE49DCBE59ED1E8A2CDE49ED4EBA5
D4F6ACBFDF964F6922D5E9A4CFDB99E1ECAAC7D290D4E09ED1E5A0D6EDA7C6E19AC1DF97
91AF679BB66F8CA65FB3CA84DBF0ABD5E6A2C2CE8CDFE5A5CDCB8E52490E85793FE9DFA4
EEF0B1CEDD9AC1DF97C1E59BA5C77D5D78317C8B48899158BEC49EE7EECFECF6D3E3EFC7
E3F5C5D8EFB7CBE5A4C9E8A2C5E79ACDF0A0BADD89CCF099D8FAA4C9EB94CBED96CDEF99
BDDE8DBFE091BFDF93D4F3A7D0E79FC7D08D65561D6E652AC5E39BB9DF94CFE39EE1ECA8
D7E49ECADA93CBE196D4EFA2D0ECA2CFEDA5CAE8A0C7E59DC6E49CC0DE96C3E199D1F1A8
C5E39BE6FFBDD6F4ACBDDD94CEEEA5CEEEA5BEDE95CAEA9FC8EA9EC8EA9DC6EB9DC6EB9D
C6EB9DC6EB9DC8EA9DC8EA9DC9E99DC4E397D0EAA0CAE298DAEEA6C7D891A4B46DCDDE97
CCE49AC6E297CDEDA1CCF1A3C8EFA0C9EEA0CAEC9FD2EEA3C0D68DDCEDA6CBD892AAB771
A2B36C97AB63A2BA70D3E9A0DFEAA8D0D696D5DB9BDEE4A4D5DE9DD7E2A0E1ECAADDE9A7
CFDE9BD3E4A0D5E9A4D3E8A3CEE39ECAE19BCDE49ED1E8A2DFF3AED3E4A0CEDF9BD2E6A1
C9DE99D4EBA5D8F2ABC3DE97C9E79FBFDF96BFE197CCF0A6CFF5AABBE498A1CA7E92B86B
6E8E43ABC57BD8E9A2DBEBA4D8E9A3D3EAA2C4E69ABBE194D3F3AABBD08BDADF9FCCCA8D
BABB7FE8F4B4CEECA6C1E9A0C0E99DC7EDA2C1E399D0E7A1ACB171D9E2A1C4E49BC6F2A5
C8F4A7CAEAA1CFD494E2E0A3E0EBA954632085914F6D7232766A30E1D89DD5E09ECCE69F
C5E79DB2D289D7ECA7DAE9A6D5E19F768542A2B973D7F5ADD5F3ABC3DE97DDF1ACCCDD99
889D5AA1B874C9E09CD3EAA6C6DD99D0E5A2D8EDAAC8DD9A
BBE79ACBF4A8C9E49D4F601C7A8040E6E8A9E4E9A9D7E2A0CCE19CCAE8A0C0E49ACAF0A5
D2F6ACCAE8A0A2B973758642B0BC7AD1E09DD9EDA8D5E6A2CAD392CBC98C8071385C4B13
DBD196E0E5A5C9E39CCFF3A9C5E99FCAE8A0D2E19ED8E2A6D3E1AED3E4B7D3E7B4C7DEA8
CEE7ADD1EEAEC4E29CC9E9A0CCECA0BBDC8DDEFDAFC3E292D3F0A0BDD889D3EE9FCDEA9A
CCF29FC7EE9DCEF5A6CAEC9FC4E096D6E39EAA9E645B52178FAA63C5E99FCAD996B9BE7C
DBE09DE1EBA6CFDB93D9EBA1C4DE95D1EFA7D1ECA5C5E39BCCEAA2D3F1A9CDEBA3C5E59C
C8E89FC0E097C4E49BCCECA3C9EBA1C5E79DC8EAA0CCEEA2C8EA9EC8EA9DC8EA9DC6EB9D
C6EB9DC6EB9DC8EA9DC9E99DCEEDA1C8E499D2ECA2C6DC93D8ECA4AEBF78D0E099D7E8A1
C7E197D7F7ABBDDF92BEE395C8EFA0BFE496CCECA0CCE69CDDF1A9C1D18A717C37525D18
85954E95A961859D5398AE656D76354B5010444909585D1D6C7131959A5AC7CD8DDEE4A4
DAE0A0D5DE9DD4DD9CD4DF9DD8E3A1DAE5A3D8E4A2D7E3A1CCDB98D6E7A3D5E9A4D4E9A4
C9DE99D3EDA6C1DF97CCECA3C0E49ACAF0A5CBF5A9C1EDA0B9EA9BBAED9EBCEFA0BCEB9B
80A5588DA75DA5B66FC8D891DEEFA9D0EAA1C1E699CCF2A5C0E097E0F5B0D9DF9FA6A668
7B7C40DEEAAAC3E19BC6EEA5C5EEA2BFE399D1ECA5CDE19CB7C280E9FAB6B3D58BC8F2A6
C5EEA2C9E49DDBE1A1E2E0A3CFCF91595E1EE9F4B2D9DE9E95894F64581EB5BA7AD9EEA9
C3E59BCAEEA4CEEEA5C1DB94D1E29EDAE6A494A05EAFC07CCEE39ED1EBA4CBE69FCEE9A2
DCF3AF5C732F627935C6DD99D9EEABCEE3A0D7EAA8CDE09E
C2F1A3C7F0A4C7E29BD8E9A5A5AB6B505213DADF9FDBE6A4C9DE99D1F1A8BAE095BFE89C
C1E59BD4F2AAC9E09AD6E5A29C9E5F575C1CC7DC97D2EDA6CDE8A1D0E19DE7E7A99E9258
64511964581EDFE4A4C7D894D2EDA6D4F2AAC4DF98D2EDA8C6E3A1CDECA9C5E5A2CEEFAA
CAEBA4BDDF95CAEA9FC9E99EC4E298D5F1A7C8DF97D8EEA6DDF1ACCFE09CCCDB9AD6EBA6
BDDD91D6FBABC0E597CAEC9FD3EFA5D6E19FE3D49DA0955DD0EBA6C8EAA0E1EDAB515312
3B3E00CED591DBE59ED4E49DD4EBA3C8E39CD3EDA6C3DE97C5E099D5F3ABCBE9A1D0EEA6
C5E59CCDEDA4C8E89FC4E49BCCEEA4CFF1A7CAECA2C9EB9FCCECA1D0F0A4CEEEA2C6E89B
C4E699C8EA9DCDEDA1CDEDA1C8E79BCCE89DC4DE94D7EDA4D5E9A18B9C55D2E29BCCE098
D2EEA3C0E295CAEFA1C0E798CAEFA1BFE194C4E397D0E89ED5E59ED0DB9659631E96A15C
D5E59ECCE098DBF5ABC2DA90D1E09DD9E4A2DEE9A7959E5D4A5312636C2B010A00757B3B
D1D797E5EAAADEE3A3DBE0A0E1E6A6CACF8FEDEFB0CBD694CBE59EC3E39AC3E39AC7E79E
C9E9A0C6E69DC6E69DC9E9A0C5E59CC1E198CCECA3C9EBA1C3E59BCAECA2CAECA2C7E99D
C8E89DC7E39893A75FD8E9A2CDE19AC9E39AC6EB9EC3E99CCFEFA6D2E7A2D5DB9BC9C98B
87884CDBE7A7CDEBA5BFE79EC5EFA3BEE096DAEBA7D6E2A092A661D2EDA6C6E89EC6EAA0
D3F5ABC4DE97D6E2A0DEDEA0E7DDA2504A0EDBE6A4D7E2A0EFEDB0544E1258581A5B6624
CDE49EC0E097CBEFA5C6EAA0C9E49DCEDF9BDCE5A4979D5DD7E2A0C5DA95E5FFBDBFE399
CFE8A4CFE4A1C8DD9A495E1B8EA15FD8EBA9CFDF9E4B5B1A
C0E69BCBEDA3CAE59ECEE39ECFDE9B9BA7659AA664A6B773D7ECA7C9E39CDCFAB2D0F0A7
CCECA3C5E39BDAF5AECEE29DB9BF7F939959A6BA75BFDA93D0EEA6D7EEA8C7D08FECEAAD
A99D6375692F756F33ABB070D0E19DC2DC95CCECA3BBE093C6EC9FC3EC9DBCE596C1E899
C6ED9EC8ED9FCDEDA1C8E79BCBE79DE0F7B1CBDE9CC9D897CDD89CD9E3A7DBE3AACBD799
DDF3ABC8E499C8E499D0EAA1CBDF9AD7DB9ED0BC8782753ED3ECAAAED28ADCEBAADEE4A4
CED592C0CB8687975071853D465C14435A147B924CAAC47DC1DB94C6E19ABDD891C7E59D
C3E199D4F2AAD4F2AAC7E79EC6E69DC6E89EC4E49BC6E69BC5E399C7E69AC9E89CCCECA0
CDEDA1CBEB9FC8E89CC6E69AC6E599D4F0A5D5EFA5CCE49AC3D78F92A35CD8E9A2D8EEA5
C6E599C2E799D1F8A9C3EA9BCDF2A4CFEFA3D8F4A9D4EAA1D6E39D3D4702939A56EBF5B0
BBCB84CFE59CC7E197D7F3A8D5ECA6CADF9AD9EEA9D0E49FC8DC97ADBE7A94A3604F5E1B
56611F4A5513464F0E6B7131CBD191EBF0B0DEE0A1E4EAAACFE09CD5EAA5DCF1ACD9EEA9
CFE49FC9E09ACBE29CCFE9A2CEE8A1D7F1AACEE8A1D4EFA8CDE8A1C8E69ED8F6AEC2E297
D6F6ABB6D287B2C67E8C9D56B1C57ED3EDA4C6EB9EC6EC9FC4E49BD5EAA5EAEFAFC3C184
B9B97DCFD899C3DE99CFF5ACC5EEA2CDEDA4EBF6B4C6CF8EBCD68FC6EAA0B8DC92CAECA2
CBE69FDCF1ACD8E7A4DCDE9FB2A1695F5017E0EBA9D2E6A1C3CF8DE2E8A8B5B577454708
788140D8ECA7CEEEA5C4E89ED0F2A8C2DC95C6D18FEDF2B26C7232ADBE7AB9DB91C5EBA0
CDE6A2CCE19EDEF3B0A6BB788EA15F899C5AA1B170B2C281
DBEFAACEE39ECEE8A1D1ECA5BFDF96C8E89FBDD891BED891839752A7B673CDDC99C9DA96
D6EBA6C1DB94C5E59CCBEBA2CDE8A1CDE29DCADB976A7936C1CD8BD0DC9AD4E3A0CEDA98
D7DD9DDFE1A2797538423E019CA161E6F5B2C5E099D1F8A9C5F19CC0EE94C4F097BEEA93
C3EA97CAF09DC5E599C6E298C7E19AD9EEABC7D5979DA76B6A713B696E38959765A7AA73
8D9353969F5CD7E29EE2EBAACBD191EBE5ABE7CB9B9D8C58D1EAA9CAEFA9D0E5A2D8E7A4
D1E29ECDE49CD2F0A6BFDD93C8DF99CDE19CDEF3AEC0D59096AB6694AB6597AE6893AD66
859F58ACC780C4DF98C2E098C7E59DCEEEA5D2F0A8D5F3A9CFEBA1CAE49ACAE69BD1EDA2
CFEEA2C8E79BC4E397C7E69ACBEA9ECDE99EC6E0969AB2688EA45B879B53CCE098D7EFA5
CAEA9ECAEFA1D1F8A9BCE193C5E79AC4E397C0D88E98A962636D28A6AD69D5DA97CED893
D1E19AE5FBB2B7D388D0F0A4C7EBA1BEE298C1E59BD1F3A9D7F9AFCBEBA2CAE8A0C8E39C
D1E8A2CADF9ABCD08B98A965A5B4718D9C59424E0C949959877D42615018352600382C00
6C63289E9A5DA5A768909958E0ECAAB2C681CAE19BD4EFA8CDEDA4C5E99FB4DA8FD1F7AA
C9EEA1CFEEA2D0E69DD2E39CADC17A7D974E63883BC3E89BCFEDA5C3D792DCDE9FE8E2A6
B1AC72E5EBADCEE5A1BCDD96BFE399CEE9A2D3D8987C8141C3E199C0E99DBEE499D6F6AD
BED891D8ECA7C9D895D2D29476612A746129D4DF9DC4DF98CCEEA4D6F0A9E7ECAC999055
8E84498C8A4DA6B773D6F4ACC9EDA3CFF1A7CEE39ED0DC9AB9C482A2B16ED0EBA4C1E198
D7EEA8CCE19CCCE19CDCF1ACC7DC97C7DC97BBCF8AD7EBA6
CCD594D3DF9DC8DF99D4F4ABBDE69AC3EDA1D7FDB2C2E098B9CD885D69276F7535DFE5A5
DDE9A7D8EDA8CFEDA5C0E69BC4EDA1D5F7ADD7E8A4979D5D999B5CD7DC9CE4F3B0CDE29D
D8EDA8CAD996B7BC7C807E41656527AEB474CFE39EC5E498C1E993BCE98ECBF79EC7F299
C5EB96C7EA98C2E195D2ECA3DEF3AE94A7678E995D545D246C713B2629005B5D2B4B4B15
69692D5D5D1F959758DBDB9FE6E4A9DCCF9ACEAD80A4905EC1D799C6EBA6CAE09FDAEAA9
D1E6A3C3DE97D1F3A9CAEAA1D6EBA6D2E19ED3E4A0C9DA96C8DC97E0F4AFC8DD988A9F5A
546B258FA660BDD790CBE69FD3EEA7D2EDA6C3DE97B8D48AD7EEA6CCE49AC8E096CCE69C
C9E59AC3DF94C9E89CD9F8ACB9D88C89A85C738F445F792F90A85EBBD188D5EBA2C1DB91
CBEB9FC4E99BC7EC9EC0E597D2F2A6D3EFA4C7DD94889851434A06F6FBB8DEE3A0D6E09B
DFEFA8C6DE94C9E89CC2E799BEE499D8FFB5C5EEA2B4DA8FB8DE93D5F9AFBCDE94CAEAA1
C4E49BC8E69ECBE69FBCD68FCAE19BCDE29D8DA25DE9F2B1BFB379CBB47EB7A26B88753D
605118554B1058541759591BA3A868DBE6A4E0EFACDEF2ADC7DE98C1DC95E2FFB8C2E297
C1E397C6E69AD2E89FC6DA92DEF4ACC0DA91375C0FCDF2A5DAF5AED1E09DDEDC9FD8CF94
716B31D1D296DCEFADD3EEA9CDEBA3DEF3AED1D394696E2ECDEBA3CDF7ABC4EA9FB8DA90
D5EFA8D7E8A4D8E3A1D3D1946F5A23AA9961DAE6A4D1F1A8C5F1A4B1D58BE6F1AFDFD99D
C2B37A6B61267A8040CADF9ABCDC93C1E399DBF5AED4E8A3C9D895A7B874B6CD87D3EDA6
C5DC96CFE49FC6DB96DBF0ABD4E9A4E7FCB7CEE39ED2E7A2
DCE1A1EDF8B6CCE19CB9D990D4FDB1C1EDA0B8E296C3E59BD7EEA8B0BF7C838C4B9EA464
B4BD7CCFDE9BC8DD98D0F2A8C8F9AAABD78AD3E8A3E8EDADB8B2769A985BAFBB79D5ECA6
BEDE95D4F2AAC8DC97BFCA88797B3C616123D8DD9DD9E6A1CBEA9AC1E792C7ED98CCEF9D
CCED9ECDE99ECDE79EDBF0AB90A3617F8F4E627032DAE5A9C8D296F1F9C0D0D89FD9DEA4
D4D498B3B3776C6D3185844BCCC992EDDFAEEECBA1AD9768E1F5BAD1F1B0D0E2A6D0DB9F
D3E3A4D3EAA6CCEAA4D0EBA4CFE09CD0DB99DAE5A3E1EDABD2E19ECDDC99D5E6A2D0E19D
CFE39ED7EBA6BED38E95AC66859C5687A15A8FA96296B06795AB638FA35B90A45C94AA61
91A95F8DA75D9DB96EB4D085D2F1A5C6E599DBF7ACC8E298C1DB91C3DB91CEE69CD5F1A6
CBEB9FC4E699C5E79AC6E89BD1F0A4CDE79DD4E59E97A25D575E1AD7DA97DEE3A0DEE8A3
CEDF98C4DE94CCECA0C6EB9DC3E59BC7E99FC5E79DCFEFA6D3F3AAB6D68DDDFDB4CBEBA2
CDEDA4CAEAA1C5E39BC9E79FCBE9A1DBF6AFB8D38CD1E6A1CFD897DADF9FDEE0A1DBDD9E
E1E3A4E7E9AADADC9DC6C8895658193E4001888A4BCACC8DE9EBACE7E9AAC8C88ADCE5A2
D0ECA2BFE194DDF5ABCDE199CFE59DCCE69DC0E2963C5E12B0CA83D5E19FE8E4A7A89C62
988D55D8D69BDBE7A7CEE3A0CCE19CC8D995B7BC7C798241BFD992CAEEA4CDF6AAC6ECA1
CCE7A0C5D692DADF9FA69D6257460EBCB277CDD997C6E69DBCE89BD0F9ADC1D691E7ECAC
DBD2979E94595D5B1EB8C180D7EBA6DFF6B0CEE8A1BCD68FD4E9A4D3E8A35A712BDBF2AC
D8EFA7DCF3ABCAE199D0E79FCDE49CC8DF97C3DA92D4EBA3
E0E9A8C0CC8AD3E7A2C3DE97CCEEA4C9EFA4B9DF94D8FCB2C5E39BCDE49EE3F2AFA3AF6D
7982419CA564E2EDABC7DB96CAF0A5B6DF93D8F2ABD1E09DDBE1A1929B5A94A561A3BA74
CFEDA5CFEDA5D4EBA5CFDE9B959B5B69692BB6B275D3D896D5EBA2D4F3A7C6E297C9E59A
D0EAA1D0E7A1D2E7A2BED18F415110718140ABBB7AD7E6A5D3E2A1C3D291D4E3A2D9E5A5
DCE5A6E4EDAE858D516E7339989862AB9F6DB4936A7B6337C4D39ABAD497D8E1AAE2E2AC
E5EAB0DBE5A8C2D092D8E7A6D6E19FE1E7A7D6DC9CD5DE9DD8E3A1D5E19FDDE9A7D4E3A0
CFDE9BDBECA8D6EAA5CCE19CD0E5A0D2E9A3CEE59FD0E69ECBDC96CCDD96D0E19AD1E59D
CCE299C6DE94CCE69CD9F5AACDECA0B7D68AC4E095CFEBA0D9F5AADBF5ABD4EEA4CDE99E
CBEB9FC9EB9ECAEC9FC7E79BC4E095BED68CD5E59E9BA6614D520FE4E7A4DFE4A1C9D38E
D1E29BD6F2A7CAEC9FC3E598D1E8A2C5D994CDE19CD7EBA6D3E7A2CEE39EC3D893D0E7A1
C5DF98CEE8A1D2EDA6D6F1AAC2E098CAE8A0D2F0A8C9E49DD2ECA5D2E9A3CCE19CC5DA95
C9DD98D5E4A1D8E4A2D2DB9A999F5F8C8E4F717133908E519F9B5EA8A266E2D99EE8EAA9
C1DD93C3E598E4FCB2BED28AD2E8A0E3FDB4BADC908AAC607F9952B9C482DBD599BAAB72
9A8B54E2DCA2DCE5A6D5E5A4DAE9A6CFDA98CBD493C6D290CCE09BBDDB93BDE79BC9F3A7
CDEDA4D8E9A5E1DDA08E7F46685C22D0CE91DBE7A5D1ECA5CDF1A7CBF1A6BFDD95D8ECA7
E4EDACBABA7C858144939154DADC9DCCD594D4E5A1D3EAA4CFE9A2D4EFA8B3CD867E9851
C1D890D9F0A8CCE39BC8DF97D7EEA6CFE9A0CDE79ECAE69C
AEC37E728742A1B570E1F5B0CBE09BCFE6A0C4E29AC6E89ED0F4AAC3E79DC5E59CC3DD96
DCE8A6B6BB7BB0AA6EB8B477C7D290E4FBB5C0E298C3ECA0BEE79BDDFFB7BCD790B2C681
97A361CCD795CCD896CDD997E9F4B2A4AA6A454306A6A668A7B373DAEDABCFE2A0D0E3A1
CFE2A2CEDE9FD6E6A79AAA69718140B0C17DD1E5A0D2E69FD4E8A1CCE299DAF0A7CFE69E
C9E29ECDE6A4C7E09FE3F7B8D4DFA58C895674572F69502759632E314309464310786A39
8B7E4A736832837C45D6D499737536C6CB8BE4E9A9E4EAAADDE3A3CAD392D2DB9AD9E4A2
D2DE9CD6E5A2D2E39FCFE39ED6EAA5D1E6A1CADF9ACEE29BD7E6A1DAE7A1DAEAA3D9EAA3
D3E9A0CFE79DCBE59BC9E59AD2F1A5CCEB9FCCEB9FD0EFA3C3E296C0DC91CAE69BC8E79B
C4E498C8EA9DCAEA9ECBEB9FD0ECA1D3EBA1E3F3AC8A944F636623D8DB98D0D592EAF4AF
D6EAA2BCDB8FD3F8AAC2E195DCE2A2A9A5688A884B6765287A7A3CE4E6A7D6DC9CDDE6A5
DBE7A5D0DF9CD0E19DC9DE99CEE59FD3EAA4D4EEA7BDD891C8EAA0C6ECA1C8ECA2CAECA2
CBEBA2CDE8A1CCE69FCDE29DDCF0ABCAD996E6F2B0D9E4A297A05F5D6323505515798641
DCFAB0CDF2A4B8D288DCF2A9D1E79FC1DB92C7E79CCEEEA3DDF4AEB4BD7C887E4398854D
7C6833E7DEA5C7CD8FBBC787797F3F8E9756AEBD7AD6E7A3DEEAA8CDE29DBCE69ABCED9E
C0E69BCFE09CA4955C857039958F53CED494D4E3A0C9DD98CADF9AC8E39CDCFFB6B7DD92
CBEDA3C9DE99D6D6988E844964531BB6AA70D4D697E5F6B2BDD891C0E298CAECA288A85F
728C43CAE298D5EFA5C8E298C6E096CBE59BCFEBA0C7E69A
C1E19E8BAA674D6625C0D594D8EBA9D3E7A2D0E7A1CFEBA1C5E79BCCF1A4C0E598D2F0A6
D6EAA3D9E4A097955859571AE2E7A7CDDC99C7E79ECBF5A9C5F4A6B3DD91CAE8A0D5E6A2
565F1ED6DC9CDDE8A6DDE9A7C3D28FDFEAA8A2A767515518586024CAD698D8E4A6DBE7A9
D2DEA0CDDB9DDFEDAF8D9D5C97A864C9DD98D2E8A0C8DF97D1EBA1CBE79CCFEB9EC2E195
C7E99FC9EAA5D2F1ADC2DC9BC6D89AE5EAB2CFBF8E8E8250D6E5ACC2D6998B8E57625D26
5E57215B541D5D561F5E5C215254156A6F2F4B50104A50105D63235D6323949A5AD9E2A1
DBE4A3D8E3A1D2DD9BD5E09EDBE7A5D6E2A0D4E09EDFEBA9D1E09BD0E19ACEDF99CCE098
D1E79FD6EEA4D1EBA2C8E499C4E298CBEA9EC5E399D0EFA3C9E79DC8E79BD5F1A7C6E298
D0EAA1D2ECA3C8E299C8DF97D3E9A1D4E8A1C3D08B3742004E5512DEE5A2DCE5A2CBDA95
D5EBA3CDEBA1BCE194D3EFA5D5D798655C21A19B5FDDDB9EA8A86A292B005C6222232C00
D7E2A0D2DE9CE3EFADCAD996D4E8A3CDE29DCEE59FD5F0A9C4EA9FC0EB9CC2EB9FC5EEA0
C5EBA0C3E599C6E69DCEECA2CEE9A2CDE79EC8DF99CEE49CD7EBA6D0E19B9CAB684A5E17
3E550D647E34D4E8A0CFE099D8ECA5C9E098D2F0A6C7E59BC3DA94DFEBA9DBD99CA39860
685D25565016606628D1DB9CCFD897E4EFADD4E8A3CADE99D2DB9AD7E6A3CEF0A6C2E89D
D3F1A9CEDA98655B20998A51D7DC9CDCEBA8D7EBA6CBE09BCADF9AD5F0A9B9E296B5E496
C9F3A7D2F2A9D7E09FE0DA9E5E4F163E3200D7D99AD2E19ECCE69FD4F4ABBFE197CAEAA1
8CA35BD4EAA2C9E098D2E9A1D1E8A0D6EDA5CCE69DCAE49B
A2CF96BCE8ADC7EDB27D9C60CCE6A5DAF1ADC4DA92D3E9A0CFE59ACDE597CBE697CFEB9E
C8E497CDE99ED9F5ABC8DF9781924E9FB06CA6BB76CCE69FCFEAA3C7E19ADBF0ABCBDF9A
A0AF6C9BAA67D9EAA6C8DC97D5E9A4DBEFAAC7D894D9E5A398A162404608565F20A2AB6C
9AA4658995558C9B5A748541C6DB96D8EFA9D3EDA6C5E099C6E49AC6E69BC7E79CCAECA0
C5E79DCAE9A3D7F2ADCFE8A4CBE09DD9E9A8D1DB9C8F9E5DC8E5A2CBECA5CBE9A3C9E29E
D2E7A4D9ECAACEDD9CB9C5839AA3628D93539DA363959B5BA1A7678388484D5212979C5C
989A5BA7A96AB6B678E1E1A3DBD99CD5D396F6F4B7D0D595D5E6A2CFE9A0CFE9A2D0EAA1
CFEAA3CEEAA0CBE69FC8E69CC7E59DC8E69CC9E79FCAE89EC9E79FC8E69CC8E69ECBE59E
D0DF9CD6E19FE4EFADD1DC9AD8E4A2C5D18F7B87457F8B49D6E2A0D4E3A0D1E5A0CFE6A0
CDE7A0CAE8A0C8EAA0CCE7A0CED899878D4FAAB475DAE9A8D4E7A5B2C784869B588FA461
5B6B2A879655D3E2A1D6E5A4D4E4A3DCEFADC1D693D0EBA4C4E69ACEF5A6C1E79AC4EB9C
CAEFA2C2E799CAECA0CBEB9FCCECA1C8E89CC6E49ACAE99DCEECA2CCE89DC0DC92B8CE86
909956606221646927ACB572DBE7A5D5E9A4CBE59ECFEAA3CDE6A2CDE29FD5E4A3BBC588
888E52D7DDA1DFE5A9D1DB9CD7E8A4CDE19CD1E5A0D3E29FDAE3A2DCE5A4D3DF9DD5E19F
DBE6A48F9857636526D7DD9DD9EAA6C9E39CC7E59DD0F2A8B9DD93CCF5A9CEF8ACB5DF93
D1F7ACC2E299CBE09BD4E3A0D3DC9B505918C0CC8AD5E6A2C7DE98D6F0A9BCD68FDAF1AB
CDE19C7C8D49889955D1E29ED8E9A5CFE09CD7EBA6D1E5A0
3F703988B780C1EAB083A76A4B6929C1DA96D1E79FD8EAA0D8EA9EDAED9ECEE595BDD889
D0EFA1C4E99BA5CE80D0F5A8E0F7B1C8D99596A7639DAE6AB4C581C9DA96C5D994D7EBA6
C2D691ADC17CD8EDA8D3E8A3D5EAA5CFE49FC9E09AD8ECA7D6E19FBDC383A1A767919A59
8A95538D9957A7B673C7DB96D7ECA7C7E19AC4DF98C7E59DD4F4ABC0E298C8EAA0CFF1A7
D6F6ADD0EEA6B3CD86CEE59FD6EBA6CBE09BD7EEA8BDD891C4E69CC8EEA3C6EFA3BFE89C
C0E49AC6E69DCAE49DC8DD98D3E4A0D8E7A4D7E6A3C9D895D5E19FE2EDABD5DE9DD7E09F
9EA464949959747637696B2C50501269692BCDCB8EE3E8A8CBDC98CBE29CCFE6A0CEE59F
CAE19BC9E09ACEE59FD4EBA5D5ECA6D0E7A1CCE39DCEE59FD2E9A3D4EBA5D0E7A1CDE19C
DBE4A5D8DC9FD9DFA1A7AD6F727B3C505A1B5D6929C6D594D1E4A2D0E5A2CDE6A2CCE7A2
CAE8A2CAE8A2C9E8A2CDE6A29CAB6ABAC686E0F3B1D3EAA6BBD993CDECA6D0EEA8C9E49F
B8CF8BB8CB8981904F566524AABA79CADD9B98AF6BC4DF9897B76CCDEFA2D3F5A8C8EA9D
C8EA9DC6E89BC9EB9EC5E79AC8EA9DC4E699C3E598C6E89BCBEDA0CBEDA0C5E79AC4DE94
D9E09DDADA9ABCBE7D838A476772308D9957BECF8BCDE19CCFE4A1D1E6A3CEE1A1C4D797
788648CDD99BD0DA9DD8E7A6CAE39FCBE69FD6EDA7D4E8A3D3DF9DD8E1A0DFE4A4E8EAAB
E8EDAD464C0CD7E2A0C3D490D7EEA8D1ECA5C5E59CC1E59BD6FFB3ADD78BB2DB8FC8ECA2
BEDE95D4F2AADDF7B0CEE39EDEF2ADA9BA7662732F9AAB67D7EBA6C8DC97F3FFC2C1D590
D7EBA6C9DD98C6DA95ABBF7A8397528B9F5A91A5606C803B
49743E84AD75C2EAAEC2E4A7658242D0E9A5C8DE96CDE297D1E699C5DA8BD6ED9FE1FCAD
C1E092C0E094DBFFB3CFEFA6C6DB96E3F4B0BECF8B84955198A965D9EAA6D4E8A3D7EBA6
CCE19CA9BE79C1D691D4E9A4D6EDA7C8DF99D5ECA6CDE19CCCD795D6DF9ECDD695CFDA98
E2EEACD9E8A5CCDD99D8ECA7D0E5A0D1E8A2C0DA93E3FEB7B9D78FCAEAA1DFFFB6B8D88F
B3D38AD9F4ADDAF1ABDAEFAACCE09BDCF0ABC9E09AB2CD86C6E69DC5E99FC5EBA0C4EA9F
C6E89ECAE8A0D4EBA5D7EEA8C7E19ACEE9A2D3EEA7D9F4ADC5DF98C0DA93D8EFA9CADF9A
CEE39EC9DD98A8BC778B9C585665224D5C198B9A579BAA67B2BD7BC5D08EDBE6A4E3EEAC
DDE8A6D5E09ED3DE9CD5E09ED7E2A0D4DF9DD4DF9DD7E2A0D4DF9DC0CB89A0AB6986914F
8E975697A05F8C97554F5A184652106F7E3B96A763D8ECA7D0E5A0CFE6A0CDE7A0CCE7A0
CAE8A0CAE8A0C9E9A0CDE7A0ABBA77E1EDABE6FAB5D3EAA4C3E199C8E89FD2F2A9C8E69E
D4EEA7D7ECA78FA05C60712DB8CC87CFE49F95AF68C4E29A6D8B41B8D88CC9E99DC1E195
C9E99DCAEA9ECDEDA1CEEEA2C9E99DC7E79BC4E699C5E79AC8EA9DCBEDA0CBEDA0CDECA0
D6EAA3D5E49FDAE7A2B9C68169743247500F8F9857EFF8B7E0E9AADBE4A5D2DC9FC1CD8F
808E50D9E9AAD6E9A9CEE5A1C4E59EC5EBA0CEF0A6D1ECA5CDE29DD3E29FD8E3A1CFD897
A8AE6E5E6726E8F3B1DBEAA7C9DE99CFE9A2D4F2AAC1E198CEF0A6C7E99FD8F8AFC8E69E
CEE8A1D5ECA6BDD18CD5E6A2D1E09DD5E19F535F1D535F1DC2D18EC3D28FD3E29FD5E6A2
CDE49CCFE9A0D2ECA3C7E198BFD990D3EDA4E0FAB1D2ECA3
96BC83C1E4AACAECB0D5F5B6C3E09EC5DF9894AC6297AF6381984A9BB264869E508FAA5D
BBD58BD3EFA5D2F0A8B4CF88C5DA95DCEDA9E3F4B0CCDD99CDDE9AB4C581C7DB96DAEEA9
E0F5B0BACF8AAEC37EA5BA758EA55F8BA25CD1E8A2D5EAA5DEEAA8DDE8A6DEEAA8D7E3A1
CBDA97D2E39FDAEBA7CEE29DD5EAA5C3DA94D7EEA8C1DB94CEE9A2DDF8B1A4C27ADFFDB5
D3F1A9C3DE97DBF2ACC8DC97D5E6A2D3E4A0C8DD9893AD66CFEDA5C6E89EC1E59BC7EBA1
CEEEA5CEE9A2CDE49ECCE39DD8F6AEC7E99FBFE197D0F2A8CFEFA6C9E9A0D1F1A8C6E49C
C9E79FD3F1A9D7F2ABDAF5AEBCD68F9BB56E98B26B8297523E47065A5F1F7B8040909555
979C5C989D5D9BA0609FA4648D92526F7434494E0E323700343900434808535818595F1F
A1AD6B909F5C9CAB68B3C480D9EAA6DEF2ADC2D792CEE39ECFE6A0CDE7A0CCE7A0CAE8A0
CAE8A0CAE8A0C9E9A0CDE7A0A1B06DD2DE9CC2D38FCEE59FD8F6AEC2E299C8E89FC3E199
C4DE97CDE49ED7EBA6CADE99D4E9A4D6F0A9BDDB93C8E69C93AF64CFEBA0D3EFA4CCE89D
D5F1A6C9E89CC7E69ACEEDA1CCEB9FCBEB9FCAEA9EC7E99CC6E89BC7E99CC9EB9ECBEDA0
C6E69BC6E298CFE69ECEE29BB7C3819EA4648C8E4F7E7C3FBBB97ED3D397F1F5BAC8D094
8E9A5CD0E3A3D8EEADBFDD97C4ECA3C0EC9FBFE89CCBEDA3CDE8A1D3E8A3CBDA97A0AC6A
5A6523BDC886C3CF8DE3F2AFC7DC97CBE29CD1ECA5D1ECA5C0DB94C9E49DD9F3ACC1D892
D6EAA5DDEEAADAE6A4DDE8A6D2DD9BDAE3A2B2BB7A66712F85904EC5D08ECFDA98DDECA7
D8F2A8C9E89AC4E397CDEC9ED0EFA3C2E193BBDA8EC5E496
708D53CCEAAEBEDA9DB7D492D5F0ABCEE9A2CCE69CC9E497D9F1A3CCE496CEE69A8AA258
90A75FCBE29CC3DA96ECFFBFD6EAA5CADB97CEDF9BD4E5A1DAEEA9869A55CDE19CCCE09B
C7DC97D8EDA8E1F8B2B7CE8869803A516822B1C882C9DE99CDDE9AC6D592D0DF9CE0EFAC
D9EAA6CADB97CBDC98D4E8A3D3E8A3C3DA94DEF5AFBAD18BD2ECA5C4DE97D7F1AAA8C27B
99B46DBDD790CBE09BE1F5B0CEDD9ABCCB88F2FFBF879C57D3EDA6CBE9A1C7E99FC9EBA1
C9E79FC7E19AC8DD98C9E09AC9E79FCEF0A6CBEDA3B6D88EBBDD93C9EBA1C4E69CD0F0A7
C5E59CC3E39AC0DE96CBE9A1CEECA4CDEBA3CFEDA5C7DE989DA866A3A868A3A8689FA464
999E5E949959949959969B5B989D5D959A5A939858959A5A9A9F5F9DA2629CA161969F5E
DEEFA9CBE199C5DB93C2D991C5DC94C6DD95C6E097DEF8AFCCE89ECCE89ECAE89ECAE89E
CAE89EC9E99EC9E99ECDE79E82914CDDEAA5D2E39DCCE39BD0EEA4C3E599D6F8ACCAEA9F
D5F1A7C3DD94D8EFA7D8EFA7C1DB92CDE99FD1F1A6C1E1969AB46AD4ECA2D4EEA4C9E399
CDE79DCAE49ACDE79DCDE99ECCE89DCCEB9FCDECA0CAEA9EC7E79BC6E69AC5E79AC5EA9C
C2ED9EC7F2A3CBEDA1C6E097D3E29FE1E6A6B6B2756C63288F844CB6AD74E7E2AAE0E1A7
949E61D1E4A4D4EDABD3F4ADC3EFA4BEEFA0BAE699C6ECA1C9E9A0D2ECA5CDE19C8F9E5B
4F5B19D8E4A2E2EEACC8D995D7EBA6D1E8A2BFD992D5EFA8D0E5A0D3E7A2C3D490E5F4B1
8B9755ABB674DAE3A2D8DE9EE0E6A6DDE3A3E5EBABB2B878545A1A8A9352E9F2B1BFCC87
C0D88CD2EF9FD3EFA2C9E696CCE89BCDEA9ACBE79AD0ED9D
8DA267DEF6B8D4EDACD9F2B0C0DB94C8E49AD9F5AACAE699C7E494DCF7AAC1D98FD2E9A1
98AD68778A48D2E5A5C1D494D4E4A3E0F1ADDBECA8D3E4A0D8ECA7819550E1F5B0D9EEA9
DBF0ABCBE09BC4DB95C7DE98CCE39DC2D993C7DE98879E5840540FB2C681DBECA8C2D691
D7E8A4E3F7B2D4E8A3D4E8A3CFE49FD3E8A3CFE49FE7FEB8CFE49FCBE29CB7CC876F8640
86A059536D26E1F6B1C5D692E5F1AFD1DD9BD5E4A1A9BD78C8DF99CCE7A0CFEDA5CCECA3
C9E49DCAE49DD4E9A4DCF1ACC7E19AC4DF98CDE8A1D0EBA4DCF7B0D3EEA7BDD891D6F1AA
D5F0A9D2EDA6CBE69FC8E39CCAE59ECDE8A1D2EDA6D8EFA9D0DF9CD1DC9AD0DB99D2DD9B
D5E09ED8E3A1DAE5A3DBE6A4D7E2A0D9E4A2DAE5A3DAE5A3D8E3A1D5E09ED3DE9CD0DF9C
C2D991D7F3A9E0FCB2D1EDA3CAE69CD6F2A8D2F0A6C2E096CAE89ECAE89ECAE89ECAE89E
C9E99EC9E99EC9E99ECDE79E909F5AE7F4AFDBEFA8CBE59CC7E79CBDDF93CFF1A5C5E79B
D3F1A7CAE69CC6E097C5DF96C4E096C8E89DC9EB9FC4E69A9AB268CBE198D5EBA2CDE39A
CAE097CFE79DDAF2A8CCE69CC9E399CAE69BCDE99ECBEA9ECAE99DC8E89CC7E79BC3EA9B
BCEB9BB2E392C2EB9DD3F1A7D1E29ECED494DAD89BE8DFA491844D6A5F27534C1584834A
656D31D3E1A3C2D796C4E29CC0EAA0C3F2A4C0EA9EC8EEA3C2E299CFE9A2D9EEA997A864
4F5E1BCCD896E2F1AED0E19DD0E5A0D3EAA4CBE59EC9E09AD7E8A4C9D895EFFBB9434E0C
D6E19FAAB372323800E0E6A6DEE3A3D5DB9BD7DD9DD9DF9F7E8444555E1D9DA363E1EEA9
CAE49AD3F2A4CCEB9DBFDE90C6E597D0EFA1CCEB9DC6E597
93A364B0C383C9DE9BE5FCB6C7E198D1EDA2CBE79ACAE99BCCEB9DC1DD90DFF9AFCCE29A
DCEFADC1D1924F5D1F5B692B99A968C4D893C7DB96D5E9A4C9DD98536722869B56C8DD98
CFE49FCCE39DD5ECA6D1E8A2D4EEA7CCE69FDDF7B0CEE59FC8DD98899E59556924829752
D4E8A3D0E5A0B8CD88D2E7A2DAEEA9CCE09BCEE29DC6DB96D9EDA8D7ECA7354904CADF9A
C7E19A9FB6703A4E09D9E8A5D8E3A1D8E1A0CFDA98B8C784C8DC97CCE69FCFEAA3CDE8A1
CEE9A2D2E9A3CCE09BC2D38F54632037460345541197A663CDDC99D2E19ED5E6A2CDDE9A
C8D995D1E29EDAEBA7D9EAA6D9EAA6D2E39FC6D793C8DC97CEE59FCDE7A0D0EAA3D3EDA6
D4EEA7D1EBA4CCE69FC8E29BCDE7A0CDE7A0CDE7A0CCE69FCDE7A0D0EAA3D4EEA7D7F2AB
DAFAAFBDDF92B6D68ACCECA0D1F1A5C4E498C3E397C4E498C9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCDE79D97A760CAD791C7DB93CBE59BCFEFA3C1E698CAEFA1CCEEA1
C2E195CEEA9FCFE99FD3EDA3D2F1A5C9EB9EC6EB9DCBEDA0CDE59BC0D48CBFD38BDAEEA6
DBEFA7CFE59CD5EDA3C6E096CBE59BCAE69BCAE69BC9E89CCAE99DC9E99DC9E99DC4EB9C
C6F5A5BEEF9EC1EA9CC4E499C9E09ADDE9A7E9EEAEE4E2A5E0DAA0908A505F5A225D5B22
63642AD0D89CE1EBAED5E8A6C5E49ECBEFA5C5E79DCFEDA5C6E099D1E6A1D9EAA6849350
55611FCFDE9BC5D692DFF3AEC5DC96CBE59ED8F6AEC4DE97CFE09CD9E5A35B6624626D2B
D3DE9CD5DE9D909958949D5CDDE3A3D8E1A0D4DD9CE2EBAAD2DB9A879250586120D4E5A1
CEECA2C1E698BEE395C3E89ACAEFA1CAEFA1C6EB9DC2E799
909C5CA1B06DD6E7A3C8DC95CFE79DD9F3A9BEDA8DD2F1A3C9E89ACDE99EC2DC93D2E7A2
D0E3A1D2E2A3E6F1B5C6D4964F5F1ECDE19CDBEFAAD0E49FCFE39E93A8638FA45FD3E8A3
D5ECA6C8DF99D0E7A1CAE19BD3EDA6C4DE97CBE59ECDE7A0D0E7A1D5EAA5C8DD989AAF6A
8BA05BC5DA95E8FDB8C8DD98C6DA95DCF0ABD8ECA7869A558CA05B90A45FCFE39EDBF0AB
D1E8A2CBE29CD9EAA66E7A38DAE3A2D8DE9EE0E9A8919D5BD8E9A5D2E7A2C9E39CC8E39C
D1EBA4CDE49EA7BB767C8B48CFDA98DBE4A3D4DD9CDCE5A4A1AA6987904FBCC78598A361
D9E4A2D9E4A2D7E3A1D0DC9AD6E2A0D8E4A2D1DD9BD6EAA5CCE7A0C8E89FC6E69DC5E59C
C5E59CC7E79ECBEBA2CEEEA5C9E9A0C8E89FC7E79EC7E79EC7E79EC7E79EC5E59CC3E599
C1E699CBF0A2CFF1A4CBEDA0C1E396C7E99CD4F6A9C7E99CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCDE79D95A65FCCDC95DAF0A7D1EDA2C9EB9EC5EA9CC8ED9FC0E295
CFEFA3C7E69ACEE89ED4F0A5C2E195BFE194CEF5A6C6E89BCAE2987788416A7B34C1D28B
DEF2AAC7DB93CFE59CD3EBA1D3EBA1CEE89ECBE59BCAE69BCBE79CCAE99DCAE99DC6E89B
C1EA9CBDE899C7EDA0CCEEA2C9E49DCDE29DD2E19ECDD896E4EAACD5D69AEDECB3737239
5452197F7E45D7D69DD7DD9FD1E4A2D1E8A2C6DB96D6EAA5D3E29FD9E5A3CDD8965E6927
727D3BD3E29FD8ECA7C9DE99CEE8A1C8E69EC9E9A0CCEAA2CEE29DD6E5A2919D5B4B5715
DAE6A4CDD997E0ECAAA5B16FD4E09EDFEBA9CBD795D9E5A3E0ECAACEDA987682404B5A17
AFC07CC6DA95DEF2ADD8ECA7C7DB96CBDF9AD5E9A4D2E6A1
D8E3A1B7C47F95A45FD7E8A1CFE59CBFD98FD8F4A7C7E396C8E79BD2EEA3CBE59CD3E8A3
D1E4A2CBDB9ADAE6A8D6E4A6B4C483CFE39EDDF2ADCADF9AC4D994D1E6A1657A35AEC57F
C8DF99D5ECA6CFE9A2C8E29BD0EAA3D0EAA3CBE59ED2ECA5D3EAA4D1E8A2CBE29CCBE29C
D7EEA8687F397E934EA2B77265793453672291A25E98A965CCDD99CFE09CDAEBA7D3E7A2
D0EAA3D4EBA5CBDC98D5E19F9BA161B6BC7CD4DA9A9BA664D5E4A1CDE19CCAE19BDAF4AD
C1DB9492A96397AC67AEBF7BDFEAA8D8E1A0C5CE8DE1EAA9DCE7A5D0DB99D6E19F95A05E
96A2608894528F9B59E9F5B3C9D895E4F3B0CEDD9AD2E6A1C9E49DCEF0A6C9EBA1C3E59B
C8EAA0C9EBA1C5E79DC8EAA0C6E89EC8EAA0C7E99FCAECA2C7E99FC9EBA1CAECA2CCEEA2
C3E89BC8EFA0C9EEA0C2E799C1E698C9EEA0CDEFA2C9EB9ECDEDA1BADA8EC9E99DD4F4A8
D3F2A6C9E89CC8E79BCDE79D8E9F58CBDB94D7EDA4C4E095C9EB9ECBF0A2C1E899C7EC9E
BEDE92D7F6AAC6E096D4F0A5CEEDA1B3D387D5FAACBFE194D9F1A7CFE099899D5597AB63
8B9F57D8ECA4CDE39AD1E99FCDE59BCBE59BDAF4AAC9E59AD2EEA3C2DE93CEEA9FC9E89C
C8E89DD1F1A6C9E99EC5E59AC7E79ECCECA3CFEDA5C3DD96D4E9A6CCDB9ACFD79BE2E3A9
938E56867D46645722C0B77ED9DA9ED9E2A1DBE1A1DFE5A5D5DA9AD9DE9E686D2D9DA363
D8E1A0D4E3A0D1E5A0CDE7A0CAE8A0C8EAA0C5EBA0C8EAA0D3EAA4D1E5A092A661CBDF9A
D5E9A4D3E7A2C8DC97B9CD884F631E96AA65CCE09BD4E8A3D1E5A0CFE39ED6E7A390995A
6358227B6534887241CCB6859C8655A38D5C6C56255C4615
DBE8A3CFDC9786964F9CAD66899F5696AE6489A457ACC87BC6E297D3EFA5CBE59CCFE49F
D7EAA8D9E9A8D0E09FAEBE7DC7DB96D5E9A4CADF9ABFD48FE8FDB8D9EEA9A7BE787C934D
D5ECA6CAE19BD1EBA4D1EBA4BFD992C7E19AD4EEA7C6E099C7DE98C6DD97D3EAA4D2E9A3
C4DB95B2C98398AD6896AB668498538DA15CAABB77DBECA8C7D894E2F3AFC3D490CFE39E
C1DB94CDE7A0DBEFAAC6D290DEE4A4777C3CC2C888828B4AD5E4A1D3E7A2C4DB95B3CD86
87A15A69833C9DB26DD4E8A3CDDE9AD7E8A4D6E5A2DFF0ACCFE09CCADB97E6F7B3D4E5A1
CEE29D9FB36E687C377E924D718540BBD08BD1E5A0D6EBA6CCE69FD2EDA6CCE7A0C6E19A
CEE9A2D0EBA4CEE9A2D1ECA5CCE7A0CDE8A1D0EBA4C6E19AC6E19AC1DC95C8E39CC7E59D
CAECA0C7EC9ECBEDA0CEF0A3CEF0A3C9EB9EC6E89BC8E89CCCECA0CDEDA1CBEA9EBDDC90
C4E397B8D78BE6FFB75E782EA5B66FD0E19AD2EAA0C0DF93CBEDA0CCF1A3C1E899C7EC9E
CBEB9FCFEBA0D1EBA1BAD48ACCE89DD2F1A5C9EB9EC7E79BB6CE84F2FFBEC9DD95879D54
51651DABC178CDE39AD5EBA2CEE69CC9E197BDD78DC9E399C7E197D1EDA2CFE99FD6F0A6
CDE49CCDE49CCCE69DD2F0A6CBEDA3BCE297C4EA9FD1F5ABCBEAA4D1EAA6D4E2A4C4CA8E
928D55AE9E6A7C66347C6833908A50A5A366D6D497DAD89BE9E9AB7A7A3C393B00B7BC7C
D8E1A0D4E3A0D0E5A0CCE7A0C9E9A0C6EAA0C3ECA0C5EBA0C7E29BCDE49E94AB65CCE39D
D1EBA4D0EAA3CDE7A0C6E0998EA86159732CCCE39DD3EAA4CBE09BD6EBA6DBEFAAD5DE9F
7E723E412B002F19008C76476C5627503A0B4832038A7445
CDDD96D5E69FE2F3ACD5E9A1C9DD95DDF3AA7F954C748C42AEC57DCBE59CCDE49CC9E098
D1E6A1D8EDA8C7DC9794A964DCF1ACC4D994D2E7A2D8EDA8D5ECA6B0C781D1E8A2C3DA94
86A059637D3678924B859F58718C459DB871D5F0A9C8E29BC4DB95DEF5AFD3E8A3DBF0AB
DBF0ABCBE09BCEE39EC7DC97DDF1ACCEE29DCDE19CD5E9A4C6DA95D7EBA6D2E39FD9EEA9
D6F1AAD3EEA7D2E6A1DCE8A6D3D999D4D999C0C6867F88478E9D5A90A45F98AF69C0DA93
D9F4ADD6F0A9D9F0AACFE9A2C4DF98CAEAA1CDEBA3C9E9A0C0E097BEDE95C4E49BC4E49B
CBE9A1C8E69ECAE8A0D7F5ADB8D68EB9D9909AB87079944D9EB26DA3B26F97A6638E9D5A
93A25F94A3608F9E5B909F5C94A36083924F91A05D9EAD6AD5E4A1DDECA9E6F5B2D2E6A1
D1EFA5BFE195BADA8FC3E398CAEA9FC7E79CC7E79CCEECA2CDEBA1C0DE94D1EDA3DCF8AE
D0ECA2D4F0A65E782F91A860C2D38DD6E7A1CEE59DC1DF95CDEFA3CAF0A3C1E699C9EB9F
CFEDA3C4DE95D8EEA6CBE199D1E8A0BDD98FCAE89ED3F1A7D0E89ED0E69DCAE097DDF5AB
C6DC93B3CB8192AA608FA75D7C944A8BA3598BA359CDE59BC4DC92DEF8AEC3DB91CFE59C
DCEBA6D2E19CCFE59DD2EEA4CCEEA4BDE69AB7E396BFE99DBDE39ACEEDA7D5EAA9B4BE81
918C54DFCF9BD4BD8BB39E69887D45413D007C783B9E9A5D5856195E5E20ABAD6ED3D999
D7E2A0D3E4A0CFE6A0CAE8A0C8EAA0C5EBA0C2ECA0C3ECA0CAEAA1D4EFA89BB971CFEDA5
CDEBA3CAE8A0CBEBA2CBEBA2C6E49CA7C57DAFCA83C6E099DDF4AEC5DC96BED38EE2F5B3
DAEAACCAD89DB5C388BFCD92B1BF84CAD89DD2E0A5D9E7AC
C9DD95E0F4ACC7DB93CBDF97D3E79FC1D58DDBEFA75E722A99AF67C6DC94D2E9A1CDE49C
C8E299CCE69DC9E59BA9C37AACC37DD7ECA7DDF2ADC7DC97BFD690D2E9A3DFF6B0D4EBA5
DAF4ADA3BD768BA55E738D4655702985A059CBE69FD1EBA4DEF5AF8A9F5AD1E6A1C8DD98
C3D893D3E8A3D2E7A2DAEFAACFE39ECEE29DDFF3AECEE29DCEE29DCADE99D2E6A1C5DA95
BCDA92B0CE867B904BDAE9A6E7F0AFE1E6A6C4CA8A9CA564D9E8A5D8ECA7C7DE98C6E19A
C7E29BC2DD96CCE69FC3DE97C7EBA1C6ECA1C9EFA4C4EA9FCDF3A8D2F8ADC6ECA1CCF2A7
C3E79DB8DC92C1E59BCDEFA5C0E298BDDF95C8EAA0D4EFA8ACBB78B1BA79A2AB6A97A05F
9CA5649CA564969F5E969F5E929B5AA3AC6B9CA564495211606928959E5DDDE6A5D3E29F
CCE39BCDEBA1D7F3A9D9F5ABD1EDA3C8E49AC9E59BD0ECA2CBE59CC6E097D3EDA4CDE79E
B6D087B7D188B8D289CDE49CD1E59ED5E9A2CAE49BC6E49ACBF0A3C6EC9FC0E598CCECA1
C9E59BDCF3ABCEE29BCEE29BE8FCB5CFE69ECAE49BC4E096D9F3A9D1EBA1CAE49ACAE49A
CAE49AC7E197C5DF95C8E096B1C97F88A0564F671D869E5498B066D1E99FC0D68DCDE199
D3E09BD4E19CD1E59EBFD990BEDE95CBF1A6C6F0A4C4EEA2C7EDA4CBEAA4D2E8A7D0DC9E
99985FEADFA9F0DFABDECF98AEA86E9E9E609797595B5B1DA8AA6B999E5ED2D898DAE5A3
D4E3A0D1E5A0CDE7A0CAE8A0C8EAA0C5EBA0C2ECA0C3ECA0CAECA2D3F1A99ABA71CCECA3
C9E9A0C5E59CC9EBA1CAECA2D2F2A9C7E59D89A45DADC780C1D892D4E9A4E3F7B2BED591
C9E8A4CBEEAACAEDA9C4E7A3C4E7A3D0F3AFCDF0ACBBDE9A
E1FBB1B3CB81C9E197CFE59CE0F4ADCADB95B7C681A0AF6AAFC07ACDE19AD6ECA3D4EEA4
CBE79CC5E599CFF1A4C7E79B6D873ED6EBA6C0D791CDE49EEFFFC0CCE39DC5DF98C5DF98
C6E099C9E39CD0EBA4D2EDA6CEE9A2D2EDA6D4EFA8CEE8A1C0D590C2D691869A559EB26D
CCE09BDEF2ADC5D994CCE09BCFE49FCEE39EC0D590CEE39ED4E9A4EAFFBAC9DE9995AC66
7A9A5181A158E9FFBA637430CED796E3E9A9D7DD9D99A261B2C17ECFE39ED7F1AAD8F3AC
CBE69FC2DD96CFEAA3CAE8A0C6EAA0C3ECA0C5EEA2BCE599C0E69BC3E99EBEE298CDF1A7
D7F9AFC7E99FC9EBA1CEEEA5D0F0A7C4E49BC7E59DC9E39CD6E5A2DDE8A6D4DF9DCDD896
D5E09ED8E3A1D5E09ED6E19FE0EBA9C4CF8DDDE8A6DCE7A5D7E2A0899452949F5DB0BC7A
CBE09BCFE6A0CCE39DC5DC96CBE29CD6EDA7D3EAA4C5DC96DBF2ACD6EDA7ABC27C8AA15B
819852A8BF79D1E8A2CDE49ED3E7A2D1E6A1CCE69FCBEBA2CAEEA4C2E89DC1E59BCDEDA4
CBE59EBDD28DE1F2AECCDB9847561396A763D5E9A4DFF6AEB5D488CCECA0DAF9ADC7E69A
C9E59AD3EFA4DAF6ABCFE99FCAE49AD5EDA3D4ECA2E0F6ADAFC57C93A9607F934B93A75F
70813B9EAF69DBEFA8DEF5ADCFEAA3CBEBA2BCDE94C2E49AC8E6A0C5DE9AC9DE9DF3FFC1
ADB377EFEEB5ECE5AEDCDA9FE2E8AAE0ECAAC9D593E3EFADC8D492D5E4A1D4E5A1CADE99
D1E5A0CFE6A0CCE7A0CAE8A0C8EAA0C6EAA0C5EBA0C5EBA0C1E198C6E49C8DAD64C3E39A
C5E79DC6E89ECAECA2CAECA2C5E59CC9E79FA7C17A637A34B4C883C8D995DEEDAAC3D893
CAEBA4BEE69DC0E89FC3EBA2CDF5ACC2EAA1C2EAA1C7EFA6
7A994DDFFBB0DBF5ABC6DE94CEE29BDEEDA88F9C577E8B46D3E09BD8E9A3CDE39AD0EAA0
CCEB9FC2E797CBF2A1C8ED9DC8E299485D18D3EAA4D9F0AAB7CE88D2E9A3CBE59EDBF5AE
CDE7A0DCF6AFCEE9A2C2DD96CCE7A0C9E49DC1DC95CFE9A2CCE19CD0E49FD7EBA64B5F1A
D6EAA5CDE19CCDE19CD8ECA7D1E6A1D6EBA6DCF1ACD0E5A0CADF9AAEC37EA2B772718B44
A9C980C1E399BBD58ED5E9A4505B19DDE3A3DAE0A09CA564C4D390CCE19CC0DA93C1DF97
C7E59DCEECA4D9F4ADC8E69ECBEBA2C8EAA0C7E99FCEF0A6D0F0A7CBEBA2CAE8A0C7E29B
C2DD96CCE69FD1EBA4CCE39DCEE39ED0E5A0D4E8A3D1E5A0D1E29ED9EAA6D5E6A2D0E19D
D6E7A3D7E8A4D3E4A0D6E7A3D5E6A2D1E29EDBECA8CBDC98DEEFABCCDD99BECF8B9BAC68
788C47AEC27DD9EDA8D7EBA6CADE99CEE29DD7EBA6D8ECA7BFD38EE2F7B28BA05BCDE29D
D1E6A1BDD48ECBE29CDEF3AED0E5A0CCE39DCCE7A0CEEEA5C7EBA1C2E69CC6E89ECEECA4
D6EDA7E3F4B08692505E6927C7D2904E5A18CEDD9AC7DC97E3FFB8C2E799B9DB8EC8E89C
CEEEA2BFDE92BFDE92CFEBA0CEE89EC4DE94C8DE95D8EEA5DDF1A9D3E79FC8DC94C8DC94
BBD189637931364D054158108CA35DD2E9A3D1E8A2D6EDA7D5EAA7D6E9A7CADA9BCAD89A
747E41B4BC80DAE0A4E3EDAECDE29FD1ECA5D2EDA6C9E39CD4EEA7C2DC95D2ECA5D9F3AC
CDE7A0CCE7A0CAE8A0CAE8A0C9E9A0C8EAA0C8EAA0C8EAA0C9E79FCBE9A190AE66C5E59C
C9E9A0C9EBA1CBEBA2C8E89FCBE9A1D8F2ABBCD38DD7EBA64B5C1896A260DCE7A5D1E29E
C2E096D0F5A7CBF0A3B7DC8EBEE396C7EC9EC8EDA0C4E99B
ADCF83C6E69BC9E59BCAE199CEE29BCBDA9565702CDBE6A2DAE5A1DAE9A4CADE96CCE79A
CAEB9CC2E996C4F19CBCE694C8E49ACFE6A090A761869D57BED58FC6DD97D6F0A9C5DF98
C1DB94D2ECA5CBE69FC4DF98CFEDA5CEECA4C7E59DD4EEA7D3E8A3D9EAA6C0D18DC7D894
798A46A3B470DDF1ACC6DA95D2E7A2CBE09BC7DE9892A9637289434B621CA7BE78D3EEA7
DAFCB2C2E49AE1FBB4CBDF9A4C5715C9D291E7EDAD889150C2D18ED5EAA5D5EFA8D3F1A9
C9E79FC1E198CCEAA2C7E29BD6EDA7D3E8A3CADF9AD8EDA8CBDF9AC5D692E1F0ADD6E5A2
D1DD9BDDE8A6DCE5A4DBE4A3D5DB9BD3D999D2D797DAE5A3C6DD97CFEDA5CFEDA5CAE8A0
CCEAA2C9E79FC4E29AC7E59DC6E49CCCEAA2D1EFA7C5E39BC6E49CC5E39BD0EEA6D4EEA7
92A563A1B06FB1C07FC4D392D8E8A7DDEDACC0D08F9BAB6A94A463657836D7EAA8CDE09E
D3E6A4DBF0ADDDF2AFC7DC99D2E7A4CCE39FCCE7A2CBECA5C5E9A1C5E9A1CAEBA4CBE9A3
D0E5A2C5D493A2AC6DD0D99AE3ECADD7E1A26E7A3ACDE29DBCDC91C2E99AC7EC9ECDF2A4
C6E89BCAEA9ECBEA9ED4F0A5D0EAA0CEE89ECEE49BD2E89FCFE39BD1E59DD7E8A1DDF3AA
DCF8AEBDDB91D2EEA4D5ECA4D9EDA8CCDD9994A05E8C9755535D1E8B9556C8D295D0DC9E
96A667ABBE7ED1E6A5C6E19CB7DD94D1FBAFBBE599C1EA9EBEE499D6FAB0B8DA90C7E99F
C9E9A0C9E9A0CAE8A0CAE8A0CAE8A0CAE8A0CAE8A0CAE8A0D3EEA7D6F1AA9BB66FCCEAA2
CDEBA3C9E9A0CAE8A0C7E59DC0DA93D6EDA7E4F8B3CFDE9BB3BE7C6E7736C0C585D8E19E
CADC92D6ED9DD4EB9DDAF1A1D9F0A2D0E797C5DC8ED7EE9E
869E62D7EDAFCFE5A7CCE0A1D8E8A9CFDE9DADBC79B4C17CCBDB94D9EBA1D2E79ACFEA9B
CAEC98C6EC97CBF59FC2E996C8E89CD4F0A6C9E39AAEC57D889E56B4CA8290A45DB2C67F
CFE09AD4E8A1D5E9A4D1E6A1D0E7A1CEE8A1CDE7A0CCE69FD2E7A2CEE39ECEE29DD6EBA6
D0E5A0859A5599AE69CCE39D95AC667E98516A843DC6E19ACFE9A2D3EEA7C7E19AC7E59D
BDE197C8ECA2C6E49CCBE29CD4E3A09AA563CCD594B7C280B9C885CCDD99CBE09BD1E8A2
CDE7A0C9E39CD4EEA7D0E5A0D2E39FD0DF9CB0BF7C9AA66454601E3D480688935197A260
9099587E84446F7535959A5A9DA2628E9353737536798442B7D18AC5E59CCCECA3CAEAA1
CCECA3CAEAA1C7E79ECCECA3C8E89FCBEBA2C7E79EC6E69DCAE8A0D2F2A9CCEAA2C2DD96
CEE39ED2E39FB7C884758642364703344501748541B7C884D6EAA5CCE09BCFE39ED3E8A3
CEE39EC8DD98D4E9A4CCE39DD4EEA7C8E69EC8E7A1CAE9A3C5E6A1CBEAA6D0EEA8CAE5A0
CDE29FD2E6A1A7B673E0ECAACAD694D8E7A4AFBE7DAEC380CFEAA3CDEDA2C2E498CCF1A4
C6EB9DCFF4A6C5E79AC4E499C9E59BD0EAA3CCE19CD5EBA3C9DF97D3E9A0CCE299CDE89B
C3E296C0E094DAFCAFC3E197C2D991DDEEA8CFDC97DDE8A6DDE9A7D1E09DCEDD9C909F5E
727E3E7C8C4BCBE09DCBE9A3D2FBAFAFDB8CC7F3A6CAF6A7C2ECA0C4ED9FC6EFA3C3E99C
C5EBA0C6EB9EC8EAA0C8EA9EC9E9A0C9E99EC9E9A0CAE89EC7E19AD0E79F97B16ACDE79E
CCE7A0C8E69CCBE9A1CBE99FDCF7B0C6DD95C8DD98D8E9A3DCE8A6D4DD9A585D1DA0A764
A3B36ACCE196D1E399D0E298CEE096DBEDA3CDDF95D2E49A
615D40AEAD8ED5D9B4CDD6ABD7E5B2DBEDB3CBE09FAAC179BFD78BD9F2A1D2EB98CAE38F
DBF7A2D7F39EC7E58FCEEE99C6EC99C1E696CFEEA0D1EC9FD4E99EB3C078A1A862909650
9EA15EAEB16ED9E09DEAF3B0D1DD9BCEDF9BD9ECAAC9E09CC9E39CC3DE97D6F0A9D1ECA5
CBE69FC7E29BDBF6AFA4C27A8CAA627D9D549CBC73C9EBA1D0F0A7C7E99FCCECA3CBEFA5
CDF3A6CAF3A5B6D88CD6F4AAC4DB9593A460D9E5A5ACB677ADB778CDD798DEE9A7D8E3A1
CFDC97DCE9A4E3F0ABCAD792CCD8969CA866AAB6749CA86697A3618A9956D9E8A5D0DF9C
D4E3A0B1C07D97A66396A56291A05D7E8D4A72833F738742B2C983C5DF98D2ECA5C0DA93
9EB56F859C56889F5995AC66B6CB86BCD18CE0F5B0D2E7A2CADE99D4E9A4CBDF9AD5EAA5
CFE9A2CDE99FCDE79EADC77E819B528CA35BB5CD83C8E096D0E69DD0E69DD0E69ECFE69E
CFE69ECFE69ECFE69ECCE89EC8EDA0C8EEA1D0F4ACC2E19DC7E1A0D3ECABC9DF9ED1E8A4
D1EBA4C8E49987A358D2EEA3CDE99EC4DE95D7F0AC647938AEBC7FD8E8A9D0E9A5C6E89E
C7F0A2BFEC9BC1EC9DC2E89DC9E8A4CDE6A5D0E4A5D0E5A4CFE6A0CCE89EC9EA9BC9EA99
CCE89BCAE99BC3ED9BC2ED9DC8EA9DCCE89DD0E69DCFE69EC8E89DCAECA0C8E29BD0DF9C
9398585E6021D3DE9CD6ECA4C3E197D0F5A7C5EA9DBFE496D0F6A9C8F1A2B8E193C1EC9C
C0EB9CC8F3A3BCE597C9F2A3C1E79AC7EE9FBCE295D0F0A4CCE29ADAEBA481954EDDF3AA
CEE89FC3DF94CDEDA2CDEDA1C2E297D1F0A4CFEBA1C6DE94D2E69FD7E8A1A3B06B566520
738845E0F9B7C9DF9FC2D898DCF0B1C9DD9ED3E5A9D5E7AB
1C1200322D10D7DBB8D6E3B7D3EAB4C2E0A0C6E7A0A8C87D95B164A0B7679BAE5FAABB6D
CBDC8EC9DB8FC1D68BD3EEA1D7FAAAB7DC8CC4E596C0DC8FCFE59AD6E89CCEDB93E2ECA5
E0EAA39AA45F7B8642909D5896A5628FA05C8EA15F8EA561A6C079C5E099CDE8A1C9E49D
CDEBA3C5E39BCFEDA5C6E49CC5E59CD1F1A8D9F9B0CCEEA4BDDF95C2E49ACAECA2C4E69A
C3E89BBADF91CAECA0CEECA2D5ECA6D8ECA78C9B5A929C5DADB677E3E9ABD7DD9DD3DC9B
D8E39FD8E39FCEDB958A975162712ED1E09DD3E29FC6D592D9EAA6DEEFABC7DB96D3E7A2
DEF3AECDE29DC4DB95CAE19BCCE39DC5DC96C2DC95CAE49DCDE49ED1E8A2D4EBA5D2E9A3
CDE29DC8DD98C8DD98C9DE99D5E9A492A661223300D1E29EDAEBA7CCDD99E2F3AFC4D994
CDE99FC6E69BD2F1A5D3F2A6C7E398CBE79CD5F0A3CDE89BCDE89BCDE89BCFE79DCDE79D
CDE79DCCE89DCDE79EC9E99EBEE798B3DE8FB3D78FDEFBB8D2E8AACADCA0F0FFC3C1D693
C8E299A8C97ABCDF8DC6E997C6E89BD2F2A7C3DE9994A96898A266D2DCA0D4E9A6C5E59A
C0EB9BBCEC98C1F09FC2ECA0C8E9A4CCE6A5D0E4A7D0E4A5CFE6A2CAE99DC6EC99C8EB97
CDE899CCE999C1EE9BBEF09BC3ED9BC9EA9BCDE79DCAE99DC5F0A0B6E191D0F0A5E3F4AE
939252A8A465939A578F9E59DCF4AABEDA8FC8E499D7F6AAC9EB9EC7EC9ED1F8A9C8F1A2
C4ED9EC7F2A2BFE899CAF3A4BEE798C9F0A1C1E899CBEB9FD3E49DE2EFA999AA63BCD289
E5FDB3CFEBA0C7E79BC1E396C0E295CCEEA1CFEFA3C9E59ACDE59BDAF0A7DBECA5CEDF99
B4C4857A8C4E8C9E628EA06493A267B9C88DD2E1A6707F44
080A000009006B8347C5E8A4B1E195C9FEACB7E896C8F2A0BAD588ECF9B1C6C986777739
8E9257DEE6ABEBFABFC5DB9BC7E19AD9F5AAD2EEA3D3F2A6C8E89CCDEE9FCCEEA1C1E396
C3E598CEF0A3D2F2A7C9E79DC6E298CFE9A0D1EBA4CBE29C879E58D6EDA7CFE6A0C0D791
D0E7A1D3EAA4C7E19AD0EAA3D5EFA8C9E49DBDD891C4DF98D7F2ABDAF5AECFEDA5CCEAA0
CCE89EDCF8ADD9F3AAC1D78FD6E7A3D3E29F919B5C555F20CFD899C6D091D9E4A2D1E09D
9DAE684E621B3E540B8DA35AB1C580E0F4AFCDE29DD6EBA6C9DE99D4E9A4C6DD97CAE19B
CBE59ECBE59ECDE8A1D1ECA5D2EDA6D0EBA4D2F0A8D8F6AECEE9A2C8E39CC4DF98C7E29B
CFE9A2D4EEA7D2ECA5CEE8A1CBE29CDAF1ABC5DC964A611BCBE09BD3E8A3C4D994D4EBA5
CCE89EBEDD91C3DF94CEEA9FD0EC9FD2EEA1CFEB9EC3DF92CCE89BCCE89BCDE89BCCE89B
CCE89DCAE99DCCE89DC9E99DD5FCADB9DF92DCFEB4CCE7A2BFD493DAEAABC9D99AC8DD98
8AA45A89A85ADEFFAEC4E795C4E498CEECA2C4DE97D3E8A58F995ACEDA98D5EDA3C6E796
BFE993BCEA92C4F19CC5EF9DC8EAA0CCE7A2D0E5A4D0E5A4CDE7A0CAE99BC6EC97C8EC95
CFE799CDE89BC2ED9BBFEF9BC5EC9BCAE99BCDE79DCCE89DD6FFB1B9E494C3E398CFE09A
909052ECE8ABD5DE9DDBEAA5D8ECA4C6DE94D0E89ED2ECA2BEDA8FC0DF93CCECA0BEE093
C7E99CC4E99BC4E699CCEEA1C0E295CDEDA1CBEB9FC9E59ACFE099D0E0998A9E56CEE69C
CFE99FCFEEA2BEDE92D0F2A5CEF3A5C9EB9EC6E69AC9E59ACAE49ACBE198D1E29BDAE7A1
DEE3A1F7F7B7D8D8984F5110666827505512525714ADB470
6C6A3A5B622F4861277CA762C6FFB3A7E793ACE793C1F0A0E1FBB2D6E19DD2D093E1DFA6
D9DEA69FAE756D894E728E51A9BC7CCFDE9BC8DC97DBF2ACCBE79DBADA8FC8EDA0C0E699
C4EA9DC2E89BC2E79ACEF0A4D8F6ACCFEBA1CBE29AD6ECA43A4E09C6DA95E9FDB8DFF3AE
D1E5A0D5E9A4C8DD98D1E6A1C0D590CCE19CCEE59FD5ECA6DBF2ACC8DF99BCD68FD1E8A0
D4EAA2C2D68ED5E6A0D6E5A0CAD694E0EBA9BDC687788142646E2FC9D595AEBD7A8DA15C
8DA45C9CB86ED5F4A8CCEB9FEDFFC0BDD48EC3DD96E3FDB6C5DF98BED891E0FBB4C9E49D
C6E49CCCEAA2CEECA4C8E89FC3E39AC3E39AC3E39AC2E299CBEBA2CAEAA1C9E9A0C7E79E
C6E49CC6E49CC8E69ECAE8A0C8E39CC8E39CCBE69FA7C27B4F6922AAC47DE0FAB3BAD48B
D5F1A6CBE79CC8E499C9E59AC6E295C4E093C9E598CEEA9DCCE89BCAE99BCAE99BCAE99B
CAE99DC9E99DC9E99DC8EA9DC0E597D6FBADC7E59BC3DD96D1E4A2D7E7A6D6E7A3BBCF88
7A9248A1BD70CAEB9CCAEB9CCEEDA1C5E196D2E9A1DAEEA7A6B36ED4E49DD4EC9ECAEC96
C8F097BDEA8FC1ED94C5EF9BC9E99DCCE7A0CFE6A2D0E5A2CDE79ECAE99BC6EC97C9EB95
D0E799CDE89BC3ED9BC1EE9BC6EB9BCCE89BCFE79DCCE89DB7E091C2ED9DD0F0A5D9EAA4
A6A668A9A76AC3CE8C96A761AABB75DCEDA6DEF2AAC5DB92CEE49BD4EEA4CEE89ECFEBA0
C9E89CC3E296C5E498CBE79CC4E095D0EAA0D4EEA4CCE49AC9DD95EDFEB78BA158D1E99F
CFEBA0C5E599D8FAADB3D588CBF0A2C3E598C3E397CEEDA1D5EFA5D1E99FCEE29AD4E19B
DFE59FC6C783F6F7B3D2D590D8DE96DCE49BD4DF93D0DB8F
E6CCBB95897100070000150082B97FBCFDB9C5FFBAB5E7A0C1DE9BD2E1A0DADEA1D7E0A1
D8EDACCFF4AEBAF2A7BAE9A1465617727339DADEA3CCD498E3EFAFD2E2A1CADE99CFE49F
DEF5AFD4EBA3C6DD95C6DD95D3E9A0D3E79FCCE098D1E29B98A762CBDA97C6D592CDDC99
CAD996E0EFACDBECA8D1E29ED4E8A3DFF3AED0E49FC7DB96D9EEA9CCE19C8A9F5A546821
45540F69742F515C18DDE6A3DEE4A4CAD090DEE4A68B9455C2CC8DD2E1A0D8ECA7BDD48E
C7E59BD2F4A8B5DC8DC9EEA0BAD890CFEAA3C9E79FC9E79FC8E69EC4E29ACEEEA5C7E79E
CCECA3CEF0A6CDEFA5C8EAA0C7E99FCBEDA3CBEDA3C6E89EC5E79DC9EBA1CCEEA4CBEDA3
C8EAA0C7E99FCBEBA2CFEFA6D0F0A7CEEEA5BFDD95CCEAA2CAE8A079974FD1ECA5D7F3A9
C8E499CEE99CD2EDA0D4EFA2D0EC9FCAE699C9E89AD1F0A2CAE99BC9EA9BC9EA9BC8EB9B
C8EB9BC8EB9BC8EB9BC8EB9BC8ED9FBFE194C2DE93DCF2AADAEBA5CFDE99C3D28D8A9E56
B9D187D6F2A7B9D88CCEEDA1D5F1A6D0EAA0D3E9A0C1D58DBFCF86D8EA9ECCE592CBEC93
D0F79ABFEB8CBFEA8EC8EE97C9EA9BCCE89ECFE6A2CFE6A0CCE89EC9EA9BC6EC97C9EB97
D1E699CFE79BC5EC9BC2ED9BC8EA9DCDE79DD0E69DCDE79DC1EA9CCAF5A6C7E79EC6DA95
9EA0618D8D4FEEFAB8D6E7A1919E59CDDA94DDEDA6CEDF98D4E59ED1E79EC7DD94CDE59B
DBF3A9D4ECA2D5EDA3D2EAA0D2E89FCFE39BD1E59DCDE199D1E59D000F008DA55BCDE79D
BAD98DC2E296CEF0A3CCF1A3C4E99BC9EB9ECBEB9FCAE99DCAE49ACDE59BD5EBA2DCF0A8
DCF0A8C9DF96D1E79CCFE59ACBE395D4EC9ED5F09FCBE695
4D362E6158495C6A51648A6348824F9BE0A1ABE9A6C3F6B1C7E7A4D3E6A4DAE5A3D4E19C
C7E398C0ED9CB4F49DB7EE9BD9EDAECCCF98323500E8EBB4D8D9A0E7EAB1E3E4AAE4E8AD
C8CE90DAE3A2E2EDABD6E39ECDDD96D5EA9FDDF2A7D8ECA4C0CF8A8C9856636F2D8B9755
AAB674C1D08DD5E4A1D1E29ED5E6A2CCDD99B2C37F99AD6896AA6599AD689EB26DA7B872
E1EEA9CFD994CAD390A1A865DFE5A5E9EFAFD9DFA1B8C18298A263D2E1A0C7DC97D8F2AB
D8F8ADBDE295D3FCADCDF4A5BCDC93E8FFBEC3E39AC6E69DC6E69DD4F4ABBFDF96C5E79D
C9E9A0C6E89EC4E69CC2E49AC6E89EC9EDA3CAECA2C5E99FC3E79DC0E49AC0E49AC3E79D
CAECA2CBEDA3C7E99FC3E59BBFDF96CCECA3D9F9B0C4E49BCEECA4A7C57D85A35BA8C47A
BED88ECCE498CBE699C8E396CEEA9DCDE99CC4E395C6E798C9E99DC8EB9BC8EB9BC6EB9B
C6EB9BC6EB9BC6EB9BC6EB9BC2E497DCFBAFD6F0A6BBCF87E0F0A7B2BF7761712AB8C982
D2EAA0DFFBB1C7E59BCCEAA0C5E197D9F1A7D0E69DD4E8A0B7CC81CFE698C4E08CC7EA90
D1F699C3EB8BC3EA8FCAEE97CAE99BCCE7A0CDE6A2CCE7A4CAE8A0C8EA9EC6EB9DC9EA9B
D1E69BD0E69BC5EC9BC3ED9BC9E99DCFE79DD1E59DCFE79DC4EA9DBFE89ACBEBA2D5E9A4
969B5B9FA162CBDA97CEDF9B98A56097A25DC0CD87E3F3ACD6E7A0CDE199D7EDA4D5EBA2
C4DA91C6DC93CCE299CEE49BE2F3ACCFE099CFDF98DBECA59CB2698CA45ACAE49AC3DF94
D3F3A7CAEC9FC7EC9EBEE395C9EEA0C9EEA0C7E79BC4E397C8E499CEE89ECDE59BC3DD93
CBEDA1CBF1A4BCE394CBF2A3C6ED9EC7EC9ECEF3A3BCE191
636758505F4AA6C7A8B0E3B860A16B458B4C95D790BEF3ABCAEEA6D0E89ED6E499D1DF90
C5DE8AC4E890C1F495BEF097C5E5A2D0E5ACE6F5BE89925D94925FA29A699B8D5C766635
EBDBA89B905A8D894CC6CB89D9E6A0C3D98EC0DF91D6F2A5D8ECA5C8D794C5D491D7E6A3
C7D69391A25E93A4609DAE6A9CAD6985995496AA65C7DB96DEF2ADD4E9A4CBE09BCDE19A
C4D38EE4F1ABE5F0AC9DA663DAE3A2D7DD9DDCE2A48A9354CED899D0DF9ED5E9A4CBE59E
C7E59BC8EA9EBAE192B9DE90CDEDA4C9E79FBCDA92D3F1A9CAE8A0CBE9A1D2F0A8CFEFA6
CDEBA3C9E9A0C8E89FCAEAA1CBEBA2C9EBA1C9E9A0C8EAA0CFF1A7CBEDA3C9EBA1CAECA2
CEEEA5CEEEA5CAEAA1C6E69DC6E49CCCEAA2B2D088CFEDA5D3EEA7CFEAA3A8C37C8DA75E
B6CE82D2E99BD3EB9FC6E194CCE89DCEEDA1C8E89CCAEC9FC8EA9EC6EB9DC6EB9DC5EC9D
C5EC9BC5EC9BC5EC99C6EB9BC8E89DBCD88ECAE298E7F9AF9DAB60839146D5E59CCADB94
C3DA92CEE9A2CEECA6CBE9A3C4DF98CDE49CD4E8A0D4E8A094AB63C5DF95C9E898C5E791
CAEE94C6EA90C8EC95C7E897CAE89ECAE7A4CCE6A7CAE7A7C9E7A7C6EAA4C5EBA2C9E9A0
D1E59DD1E59DC6EB9DC5EC9DCAE99DD0E69DD3E49ED0E69EC5EA9DB9E294CBEBA2D7ECA7
959B5DB8BC7FCCDC9BD5EAA5ACBB7685924C99A660CEDE97D8E9A2D0E49CD3E9A0D0E69D
D6EEA4D9F1A7D4EAA1C5DB92CFE09991A25B7787408B9C559BB369D1EDA2CDECA0D9F9AD
C3E397CFF1A4B8DD8FD1F8A9C5EA9CC1E698C3E397CCEB9FD8F4A9DBF5ABD6EEA4C8E69C
B2E193BEF3A5C2F7A9BEF1A4BFEFA3B2E095C9F3ABC0EAA2
C0C8BB6C7A695B745ECDF2D362926A194E206BA06CB3E2ABBFE6ADC2E4A8CCEAAECDEBAB
C3E8A5C4EFA8BFF3A9B0E89FB3E8A4C5F3B5BEE1A7C6DFA8BECB96525423635B2C382A00
A092614E420E4E4C13A2AB6AD0E69DCFF0A1C6F09CBFE695CFE69ED7E8A4D3E4A0D2E39F
DBEFAAA6BA7595A964899D58899E5990A560B2C782CCE19CC9E09ACEE59FD7EEA8CFE69E
D3E7A0DDEEA7C2D18CDAE7A29AA563D3DE9CD0D99AB8C182CDD798D8E4A4D2E39FD8EDA8
CCE69DC4E298DAFAAED0F0A4CDEBA3BFDA93B8D38C89A45D89A45D76914ABDD891D0EBA4
CBE69FC8E39CCBE69FD1ECA5D0EBA4C8E69ECAE59ECDEBA3C5E39BC9E9A0CDEBA3CAE8A0
C5E39BC3E199CBE69FD1ECA5C8E39CD6F1AACEE8A1D6F0A9C2DC95CAE49DCDE7A0AAC179
8FA459C4D98EDAF0A5CFE79DCEE89ECBE99FC5E59CCBEDA3C6EAA0C6EB9EC5EB9EC5EC9D
C5EC9DC5EC9BC5EC9BC6EB9BD2F0A8C9E39CDCF2A9C1D389A2B065BECC81D4E49BD0E49C
CFE6A0D0EDAABFDE9BC9E8A5DEF9B6C3DD96D3E79F99AF67738E49BFDE98D5F5AAC6E999
C5E793C7E995CCED9CC3E398CAE7A4C9E7A9C9E6ACC8E7AEC6E7AEC5E9ACC3EAA9C8E8A5
D1E5A0D1E59DC8EA9DC5EC9DCCE89DD0E69DD4E39ED1E59EC9EB9FC7EDA0CCEAA2CADF9A
8F9557A5AB6DD4E7A5CDE49ECFE39CADBE7782934C8A9E56ADC37A96AE646B8339688036
6781377C964C8FA75D9DB56BCADE9697AB638A9B54B1C57DD3EDA3CDECA0C0E094C9EB9E
C0E295CDF2A4C9EEA0C1E899C5EA9CC9EB9ECEEEA2CCEB9FBDD98EB1CD82C0D88ED2EEA3
D3FAABB2DD8DC9F4A5BDE698CFF5AAC4E59EC9E8A492AF6C
FFFBFFF5EBEC645E5E3A3B36C3CAC2CDDDD230483A5F7E6C79A08B95C5AD6AA08887C1A9
77B79D76B79F62A68D70B893A0EEB2B3FFBAADF0ADB3EBACC7F0B6CFECB6D5E7B3CCD9A4
D3DCA7D6E1A791A163B0C985C0E598BFEC9BC3F9A3B6E692C8E69CCFE49FCDE29DD6EBA6
CAE19BC3DA94D2E9A3CCE39DCFE9A2CDE7A0CCE7A0CDE8A1C3DE97CBE69FD1ECA5CEEAA0
D7F3A9B9D389CDE49CE5F9B281924EA0AC6AD0DA9BC8D293A5AE6FE0EAABDAE6A4CCDB98
D7EBA4CFE59DCCE49AD3EDA3CAE19B96AD678CA35DB5CC86D0E7A1ADC47E99B06ACAE19B
E0F5B0BBD08BD5EAA5D4E9A4D4E9A4C0D791DCF1ACC8DF99C4DE97D6F0A9C0DA93617B34
8FA660819852E0F7B1C8DF99D6EBA6CBE09BD7ECA7CBE09BD1E5A0D3E7A2CDE19CD3E7A0
A7B8719BAD6396AC63CFE69EDEF8B1CEECA4BEDD97D0F1AACAEEA6C3E9A0C1E79ECDF3A8
C4E99CC1E698D0F5A5C3E598CDEBA5BFD896DEF3AE869750BACA7FD1E196D6EBA0D0E79F
D0EBA8D1EFB1C3E2A6C5E4A8D3EFB2D4EFACC7DC97324B0782A565C8ECAED1F4B2C2E39E
CEEEA5CBE99FC4E29ACDEAA8CCEAAEC6E4AE8EAE7C6284526287544A703D254C15214307
8DA05E9DB1696C8E41456C1DB7D389C5D992E2EEACC3D792C7E99FBFE59AD6F4AED3E6A4
9FA567B6BC7EC5D896C8E29BCCE39BCEE69CCEE69CCBE59BCAE49AC9E59ACCE89DCDECA0
D0EFA3C8E79BC7E398CCE89DD1E99FCEE69CD0E69DD3EBA1CEEDA1CAEA9EC6E89BC0E295
CAEC9FCDF2A4C1E698C4E99BCCEEA1C9EB9EC6E69ACFEEA2C8E4998AA65B92AA608A9F52
D2DF8FDFE895DDE695DBE294E8EFA2D5D891989957424202
FFFDF4FFFEF3FFFDF451473D685F56C9C9BDE3EEE0BBD3C358826E0013004788700E543C
28705A3479660949390F513508581D277931428D4AAFF4B3B6F0B3B4E6ABABD49CD8FBC3
CCEBB2CBE9ADCCECADD0F3AFB7DF96CFFBACBCEC98C1EC9ACFEDA3D0E7A1CAE19BD3EDA6
CFE9A2CAE49DD8F2ABCEE9A2D0EBA4CBE9A1D2F0A8C7E59DCEECA4D2F0A8D3F1A9B8D88D
BEDE93DCFCB0C7E399C3DD94E2F6B1475814DBE7A78E9859A4AD6ED7E0A1D8E1A0D4DF9D
DBEAA5D0E19BC7DB93C7DB93E6FBB6798E49D8EDA8CDE29DC9DE99C4D9945E722DD5E9A4
C0D48FD9EDA8D1E29ED7E8A4CDDE9AE5F6B2D5E6A2D2E6A1CEE39ED7EEA87489443E530E
8CA15C5469247C904BDBEFAACCE09BD6EAA5D2E39FD4E5A1D7E8A4CADB97DDECA9D3E29D
E7F7B0C0D18A9AAE67CAE19BBCD591CAE7A4C9E8A5C9E9A6BADD99CDF2ADC5EAA4C5E9A1
C9EDA3CAECA0CFF1A4C8E89FC2DF9FD3EDAE6279359CB069CFE195D0E598C8DE95C8E39E
C5E3A5BFE0A7BFE4AEC9ECB6B9D89FC4E0A394AD6B8AA765C0E7AEB9E4AEBDE3AA84A669
D1EFAFD5F2B0D3EDAEBEDA9FB9D7A3001100BFE3B5CEF5C9B6DFB35B84581D471785A872
D3E8A7C2D88FCFF4A6C3EA9B829E54D5E9A2D5E19FE1F2AED4F4ABBCE096C0DB96C9DC9A
9CA063ACB274CEE19FDCF6AFCCE89ECDE99ECCEB9FCBEA9ECAEA9EC9E99DC7E99CC7E99C
CDEFA2CCECA0CDEDA1D0EFA3D0ECA1CCE69CC8E298C6E297C0E094C6E89BD2F4A7D0F2A5
CAEFA1C8ED9FC5EA9CCBEDA0C1E396C7E79BC7E69ACEEA9FC7E39890AA60C6DE94D9EBA1
2D3500DCDF98DEE19CD7DC99B9BE7E676D31E0E5ADD9E0AA
E1FAC3D0E5ADE0ECBADEE5B2484A1B080B00DBE7B5C7DFABC4EFB7A6DEA1BBFDBFB0F2B5
CBFFCEB0E5AFBBE5B5C5EFBDC3FAC0B1EFB065A2661653172B682C64A165A5E1A5A6E0A5
BDF0B5B2E2A46B9555668B48C2E19DD3EEA7D0E89ED5EDA3BED58DCAE49DCDE7A0D1ECA5
C9E49DC9E49DD0EBA4B7D58DC2E098C1DF97D3F1A9C3E39AC4E49BBCDC93D2F2A9CEEEA3
CAECA0B7D98CD9F7ADC1DD93C4D994DFF0AC8A96567E88496E77388F9859919A59949F5D
97A45F8A99548898517F904970843FCFE39EC5D994CCE09BD4E8A3D6EAA5C9DA963E4F0B
ADBE7AE9FAB6DAE9A6CEDD9ACFDE9BC8D79491A05D91A05D8CA05B859A559EB26DDFF3AE
D7EBA6BFD38ECEDF9BB6C78399AA66899A566F7E3B95A461C8D794DCEBA8EAF6B4CFDB99
C3D08BDAE9A4A2B36F98AD6AB2CB8ACFECACCDEBADBEDE9FCAEDADDCFFBFBEE19FBDDD9A
D1F0AABDDB93B9D78DD1EFA9CFEBB187A36987A05FC7DE98D1E79CC8E094D5F1A7B5D491
5F8248759C6789B08198BF90CDF2BEBBDCA36D8A4ABCDEA178A4734E7D4F89B3816A8F5B
819E6699B57BD6EFB6D7F2BD94B4830010007CA57BB2DCB6C3F0C9729F7689B68DCAEEBE
C3D999DCF3ABC1E699C0E699A2BE74A6B771D1DC9AD7E6A3C5E39DD1F2ABD0E9A5CEDE9D
909157989C61CADA9BC6DF9BC9E79DC8E89CC8EA9DC9EB9EC8ED9FC8ED9FC5EA9CC3E89A
C2E799C6EB9DCBEDA0CBEB9FCAE99DCDE99ECCE89DC9E59ACCECA0C4E699C4E699C6E89B
C3E598C7E99CCDEFA2C9E99DCDECA0CCE89DC5E196D3EDA3D7F1A796AE64D1E99FCCE2A1
AFCA95829D707D9A6C94B38963865EA1C9A4ADD9B687B493
C8E9A2CEE9A2E5F5B4D3DE9CD4D999555A1A000B00D4EBA5C1EA9EC0F5A5ABE996B9F7A4
A9E08FC6F5A7CBEFA7C6E5A2BEDFA6AFD69FC4EFB9B8E9B1B5ECB346814742814848884C
AAE6AABCF2B6CCF8BB7B9E5ED2EBAAD7E6A5C7CD8DDFE8A5D7EBA6E1F8B2D6F0A9CAE49D
BDD790C7E19ADCF7B0CDE8A1DEF9B2C6E19AC6E49CD3F1A9D8F6AECCEAA2C8E69EC0E095
C5E59AD0F0A4C3DF95DFF9B0C0D590D9EAA6CFDB9B959E5FC9D293D9E2A3D5E09ED7E3A1
D4E39ECFE09AD4E8A0CBDF97DBF0ABC7DC97D4E9A4D2E7A2C8DC97D3E7A2D6EAA5D7EBA6
5E6F2B3C4D097E8F4B6D7E3ADAE9A6495815606F2C839450D9EDA8DDF2ADCFE49FD9EEA9
C9DD98D6EAA5E2F6B1C8DC97CCDD99D8E9A5C7D89493A460566522E0EFACB5C481E1F0AD
E9F5B3D7E6A3D8E8A7C2D79698B07285A164C6E4A8CCEBB0BEDDA2C4E3A7C5E5A6D1EFAF
D4EEADD5EEAADCF3ADC5DE9DCFEAB56C8855CFEBB0CBE6A3D5EFA5D4F0A5D2F1AB4D7131
133B0658835500120000120052794A3A5F2BD5F4B890B67B437749ADE4BCC9F6CBC0E6B7
C1DFADDFFAC5C6DEAABBD7A6517245C1E8BC8CB992C1F1CBB4E6C073A37DC2F0C9B8DFB0
D3EDAEC8E299B8DE91CCF5A7809C5296A761D6E19FD3DF9DBFDA95D3F2ACCFE6A2DBE7A7
9E9D649FA066D8E6A8CDE6A2C8E69CC4E699C3E598C3E89AC6EB9DC7EE9FC6ED9EC4EB9C
C4EB9CCBF0A2CCEEA1C7E79BC7E69ACFEBA0D3EFA4D2EEA3D6F6AACAEC9FC3E598CBEDA0
C7E99CC8E89CD4F4A8CAE99DD1EDA2D4EEA4CEE89ED0E89EC2DA907C9249CFE59CCFE8A6
C3E1AFD1F5C9C2E5BBC0E6BD67916900300A548A660F4923
D5E3A8D4DFA3D7DCA4DEDFA6FFFFCAA1A2686D77387D914C59792EBBE696D5FFB4B5ED94
CCFFA8B9EB92C5F198C1E195D8E7B0E7F3C5CADDAFC6E2B1BDE3B0A6D5A177AC7849824D
538A53A1D29AB8DFA6AECB91909F667D8347F4F2B7DEDEA0D8E4A2C1D691BBD08BD7ECA7
DAEFAACDE29DD5ECA6D1E8A2D3EAA4CCE39DC5DF98CEE8A1C3DD96D1EBA4D1ECA5D0ECA2
D3EDA4CAE298D0E69ED1E59ED6E5A2CEDA98E5EFB0C0C98ACBD495DBE5A6D6E2A0D3E4A0
CFE59DCDE49CD6F0A6CCE89DCEE8A1C4DE97CEE8A1D4EEA7C8DF99C8DF99D3E8A3CDE29D
C3D792DEF2ADD9EDA8CCE09BCADB97D7E8A4CFE09CCBDF9AC2D792D4EBA5C6DD97C7DE98
E1F8B2CDE49EC7DC97D9EEA9D7ECA7D6EBA6D5E9A4CCE09BD6EAA55A6E29CEDF9BE1F2AE
C0CF8CCBDA99CEDEA0E2F6B9B5CA913E571E0010001734003C5923537038A3BF85D8F2B5
C5DB9DD9EDAED4E7A56076382A4616C3E2B6D7F6BDCDEBABC2E098B6D68DC3E8A340682A
CBF7C6ACDAB3BAE9C7C6F5D1C6F3CA3F6939B2D89F80AB7359926792CEA877AA81CCF6C8
C1DEAECFEAB7BBD6A393B17FA7CB9DB2DDB0002B03588C656DA47C84B891B3E6BDCCF6C4
C4E1A1E0FCB2C9F2A4B8E394B6D48C60742FF4FEBFD1DD9DD8F1ADCDEBA5BBD08FD4DEA1
A09E6599985FD1DD9FD1E8A4CCEAA0C8EA9DC6E89BC3E89AC4E99BC6EB9DC7EC9EC7EC9E
C4E99BC8EA9DC8E89CC4E397C4E095C8E298CBE399C8E298C2E296C7E99CC2E497D0F2A5
CBEB9FBFDE92CDE99EC7E197CBE59BC7DF95C6DE94D3E9A0CDE39A9CB068DDF1A9CCE099
CFE4A3BDD395C7DD9F6E8849000F0037561A94B87BB6DEA0
D2DBA2D8E1A8DDE5ACFFFFCFFCFFCBD2DBA2D1DFA4B3C589B7CD8D0018005A7A37B7DC96
C9EFA6C7EDA4C2E89FD7F1B0C8D09DDEE1B4D6E2B4D6E9BCCEEBBDB7DEAFBCEABBC3F5C4
B3E8B470A16A48733DAECF96D3EBB1E3F1B6AFB77B898F5186925051621E546521A8B975
CFE09CB9CA86BFD38ED0E49FC4D893D9EDA8E2F7B2D7ECA7CDE29DDBF0ABCDE49EAAC078
869751D7E7A0D6E5A0D7E49FD5E09EE5EEADD3DC9DC0C98AAAB475D1DD9DD1E29ECCE19C
CAE69CC4E499C7E99CBFE194D5F5ACC9E79FBFDD95CAE8A0D3EEA7D2EDA6D3EDA6C2DC95
D8EFA9C0D791D1E8A2CBE29CD6EBA6C0D590D9EEA9DAF1ABD8F2ABBAD58ED6F1AAD8F3AC
C8E39CBCD790D8F2ABC2DC95C5DF98C4DE97DAF1ABCFE6A0CAE19BC8DF9997AC67819550
BCCB8ADDEBADD1E0A59FB378455A22A4BD86A2BD8AA3BF8C7C98678BA6732E4710132800
64763C758547879557D5E6AF112C03DCFCD3B8D8A6B8D79BD1F2ADD5F9B1CFF6B3305C21
3F6E406D9F7C81B39683B6979AC9A56C976A87AF7A5D8C5609471E49896400310A396437
5575461E390657723FB1CF9DCAF0BFBEECBE699E726CA57A30693E7FB88DBBF0C4B1E0AC
BCDA9AD3F3A8C1EC9DB6E192C5E39BD1E5A07F894A97A363BFD894D9F4AFDFF2B2D7DFA3
959058A3A168D7E1A4CFE4A1D0ECA2CEEEA2CDEDA1C9EB9EC6E89BC5E79AC7E99CC9EB9E
CCECA0C9E99DCBEA9ED2EEA3D6F0A6D5EDA3D4EAA1D3EBA1D0EFA3D3F5A8B6D88BC6E69A
D7F6AAC9E59AD2ECA2D1E99FD9F1A7D0E69DD0E69DD1E59DB6CA82A3B76FD1E59DC3D790
CFE2A2DBEFB0A4B879000D003C50119BB171C0D696DFF8B6
97AA68AEC382D0E6A5E7FFC1D0EAADD5EEB5C3D7A4DAEABDC7D2AA8A906C5B5E3F999E80
6B71559EA88DE9F8DBD5E4C3F1FED2E6F4C3DBEDBDCFE6B8DDFDCEB6DCADBEE9BBB9E9B9
B6E8B7A4D9A345784088B87CBBE7A8B9E2A0B9E19BE8FFC3D2E2A19CA76579844296A15F
97A3617E8A488D99579FAB69DCEBA8CEDD9ADBEAA7C2D18EDCEDA9C5D692AFC07C6D7C37
646D2AB9C07CD9E09DD0D794D4D999D3D898D2D699B6BF8096A061D3E3A2D8EDA8CBE69F
D0F2A6C9EFA2C4EF9FC0EB9BABD186D0F4AACFF3A9C9EDA3C4E69CBFE197CDEDA4CAEAA1
C5E39BCAE8A0D1ECA5CFEAA3CDE7A0D0EAA3CFE9A2C4DF98C6E69DCBEDA3CDEFA5B6D88E
C1E198CBEBA2D3F3AAD1F1A8D3F1A9CBE9A1D0EBA4C8E39CC6E19AD7F2ABBDD891BED58F
576726C5D395DAE9AE65763F3D511CD1E9B5C2DCACC6E2B1DDF7C8799363314814293B07
1F2E003F4A109FA96DD3E1AC6A865E96B893D5F7C5CBEDB1C1E4A0C0E8A1BBE5A51F4E17
417449578D6D41775D3D725887B898C9F8CEAAD5A0C5F5C161A2788ED2AB81BA919AC89A
7294622D49168FAA77C7E5B1C9F1BDA9D9A97AB283A2E0B17EBC8D5B966694CC9DC7F8C1
D4F4B3BEE096C5F1A4CCF8ABD3F1A9D7EBA6AFB879545E1FA3BA76BFD894DEEEAFD2D89C
938C55AEA971D4DCA1D1E4A4C7DE96CAE69BD0ECA1CEEDA1C9E89CC5E599C7E79BCAEA9E
D7F6AAC8E499C1DB91CBE399D1E79ECCE098CEDF98D2E89FC1E094DFFFB4C2E296CBEB9F
D9F8ACB9D58AC2DC92D4ECA2C8DE95CFE39BDDF1A9C1D28B778841899A53C9DA93E7FCBB
CAE5B28CA97D3F5A2F213B0E98AE80DAEBBECDDAACAEBA8A
A9BF76526921B3CE89BDDC99DBF9BBC2DFA7C6DCABD0DFB4DEE4C0D3D2B4E2DCC6F4EBDC
706961645F5C7A787B858881E4EDD2FBFFE3F3FFDEF5FFE4D6EFC8CFEEC5BADDB3C4EBBE
BBE5B7BFEDBCA0D19A4C82487DB576BAF5B3BEFBB6ABE2A1C0E6ADCEEAB7CEEAB7D2EDBA
C6DEAAC0D7A1D2E7AECCE0A3B0C584869A5594A861485C14566A23354902A4B775DAEBA7
D1DE98929D584A5511C5CE8FD8DEA2DEE1A8DFE2A993985E848E51D1E09FD5EAA7C1DC95
C9EB9FC3EC9EBFEB9CC2ED9ECFF4A7C1E397C9EB9FC2E498CFF1A5D1F1A6B6D68BD6F6AB
C6E69BCCECA3C6E69DC1E198D1EFA7CAE8A0C6E49CCCECA3C2E69CC7EBA1C7EBA1C6EAA0
CDF1A7CDF1A7BFE195C7E99DBEE094D0F0A4C5E599CCEB9FC7E69AC9E89CCFEEA2C6E097
D1E4A25B6B2D4B5D21142800647B43CCE5AEC3DEA9D3EFBCC5E1AED0EBB6CCE5AECEE6AC
CDE1A6D0DFA4DAE8ABC8DDA58EB28C315D397FA97BC8EFBABFE5A8CEF2B5BADDA51D4310
49724ACAF6D3BBE8CBB8E5C653815D4C794EC9F5C0AEDFA8ACE6B457915F3D6D3BC3ECB4
CFEEB35C783D779358C8E7ACB4DAA1D8FFCE6597625C915DBBF1BD9FD4A061935E638F54
96B371C6E19ACDEFA5C2E79ABBD991D0E7A1E0ECAAD0DC9AD2E7A28BA25C859954A3AC6B
7C733870672C7A7B3F98A361BBCA85C6D791D2E39DD4E8A1CFE59DCBE199CDE39BD2E89F
C7DB93A6BA7290A15A91A15A939E598B954E8D975098A55F657B33C6DD97D6EAA5DBECA8
C0CC8A76813F838E4AB4BF7A929F598C9C53AABB74BCD088A2B870D6ECA4D8ECA7C3DCA2
C0E5BA1C46221236124E6E49D4EFC69FB48993A07294A070
D1E697D9F0A28CA25AC4DB97CBE1A3E0F5BCBED199DDECB5E0EAB6D1D7A9D7D9B2FFFFE8
FDF9EEFEF8FCFFFAFF82798A0F0609D0CBC5E1E1D7FEFFF3F7FFE9EEFDE0DBECC8D4EAC3
C9E4B7CBECBDC4ECBAB3E3AF17521A3E82493A854C3B8955347E59397F6370B199AEEAD1
B1E7CFB5E6C8C1EBC5C1E7B4C3E7A7C1E399C7E897D1F19EC8E797C7E69ACBE8A5D5F3AD
C6E599CDECA0C6DF9B9FB1734F5924959B6BD6D8A99EA06FCED19CCCD499E2EEAECFE39E
CDE99FC4E69AC7F0A2C8EEA1D4F0A5C2DA8ED8F0A4D0EB9ECEE89EC9E59AD3EFA4BFDE92
CDEDA1C5E59AC2E498CDEFA3C6EAA0C6EAA0BADE94CBF1A6C3E9A0C7EDA4C9EFA6C6ECA1
C2E89DC2E89BC6EB9DC8ED9DC2E895C2E591C6E894CBEB98C4E48FCBE894CFEC98C9E495
CEE7A3D3E9A9CBE4A3000E00678142C2DEA1CEECAECFEDAFBFDD9FD1F1B0C9E7A7BDDC99
CFEEABCFECAAC4E19EC0E6AB80B98E06441F558E65B0DFB5BDE2B7D7F2C7C3D5AD283710
000900293914D5EBC4C2DDB2214517C5EDB9C3F0B9C1EDB0CDF4B5ADD08CCEEDA7628036
001100001600C8E49AD0EEA8CAE8A8BBDA9E608148567941D1F4BAB6DA9DC2E4A7CAE9A6
CEE19FD5E29DDEE9A5DBEBA4C7E399C5E498D2E69ED1E29BD8EAA0CBE095C9E195D4E199
A59C5B62521458530F62611E535212646426535315525415040900D3D898696E2E575C1A
585D1B5F621F4A4B096564215E5B18595410605B17605D1A4C5013585B225C5622685A29
624C1D6D55255D49146E6226595A16959F56DAEFA4D8F2A8C5E099D1ECA9D1E9ABC7E5B1
84B48C4D835F114119C3ECC0BBDDAB88A36CD0E8AACFE4A3
CEE492D2E798667A326A7D3B97A96B93A56966753A88985A7B894CF0FBC1E1E9B8F3F7D4
FFFFF0FFFDFFFFFAFFFAEEFFC3B6C7796F785A5559BFBEBA75786DF7FFEAF9FFE8BCCAA7
CDDDB8C4D9B0C5E1B8BEE5B9BEF2C494D3A463AD7C66B5887AC8A172BF9F7BC1A976B7A3
4A83727EB19E81AF937FA983A9D19CCEF6B7CDF5AEB8E097C8F1ABC1EAA8BFE6ADB3DEA6
C4F6B7B5E7A8C1ECB6CBECBFBFD5AFAEBC9B979D7B5E603B9B9C709C9E6C939B5F4B5715
96A761C3DB91DBF7ADC7E198D6E5A0D4DD9ADEE9A5CBD893D9E8A5CEDF9BCBE09BDDF4AE
C1DC95D1EFA9D3F4ADB8DC94D1F6B0BDE29CCAF2ABC2EAA1C7EDA2C0E49ABFE399C7EC9F
CDF2A5CAEFA1C5EA9AC4EA97CBEE9CC8EB97D1F39FD1F19EC2DF8DD3F09ECBE695D5F1A6
CEEBABC1DEA4CFECB23552181D3B003654166D8B4DBDDD9CCCEBA8C5E6A1BADB94DAFCB2
B8DA90CBEDA1C4E69ACBF4B2669A6A3D744D1F4D260A3009102C06384A24939E76D2D9B0
9EA47858613265764262794392B37ACAF3B7ABDB9DB0DD9CCEEEABCFEAA3DCF8ADC6E295
D2F1A1C3E493DCFCB1C0E19AD0F0B1E0FFC4B9D7A12F4D17739259D5F4B9CCECADC5E4A0
CFE9A0C3D88DCBD78FD4E69CCAF1A0C8F3A1CEEFA0CAE598C7DD92D8F0A4D7F3A6D1E59D
9E9657C4B478ECE2A4DAD595E9E7AACDCD91F0EFB6EAEBB1D8DCA1E2E6ABD2D89AE2E8AA
DDE3A5C8CD8DEDEFAEDDE09DDAD998DBDA97E6E3A0E0DF9EDDE2A2E8ECB1DAD59EDBCF9D
F3E1B1F3E1AFD6C790DFD69BE1E4A1C9D58DC8DE95C8E69EC9ECA8C4EAADB8DDA7C0EBBD
5F936CB4EBC44F7D56688F62CAEBB6A9C588E1FAB6CBE399
D5EC9CC4DB8D93A9608499568EA062899B5F8E9E6093A36499A867BCC88A96A06BE7EEC4
FFFFEAFFFFF6FCF7FDFFFCFFFFFCFFF4F2FDFEFFFFA2A6A7868D862D382A69725F8C967E
FBFFECF9FFEAF7FFEAF1FFEAB1D6B4BEEDC9ABE3BEB9F2C5B8ECAEAADA9CBCE8B54F7850
6D90726888716E8B757391797A9C7B6F936D3962361846181A4A200016000F4523559271
1A61433E846A45846F03382811372C1B372B162717000600010500191A00787842DDDFA0
C5CA87A1A862879349757C39A39E678E8355756D3E5A56268C8A578588536B723C828F57
9DAF75C8E0A4C3DFA2C7E7A8C6E9A9C7EBABCBF2B1BFE7A1CCEEA1CAEB9ACDEE9DD1F2A3
CCED9EC3E495C5E697CFEFA3C9E99DBDDB91D5F3A9C5E197D1EDA3CBE59EC6E099C4E1A1
C2E2B1CAEDC3BADBB056774A446634CEEFBACDEEB567864A88A764C2E09AD2F0A6C3E294
D9F6A4DAF6A2C8E48FC1DB91D1E5B282926B5F7046B2C295D2DEB0CBD4A5DEE8B4DFECB6
AEBD84D4E8ABC6E0A1CCECABAAD18ECBF8B3BDF0ABCCFDBBB4DC9ECAEEB1C2E9A8BBE29F
CAF3ADC5EEA8ABD394C1EAAEAED6A1CFF6C7C1E8BC2A51252A5124ACD4A2C0E8B4C2EFAE
BEF09BCCFB9FD9FDA5C7EF97A9E689B0EF94C1F39EBEE596D0F2A6B9D990B9DD97DAF3B2
8D8A55A79968DAD39FDDDDA7D1DAA1D4E3A8C7D99DC3D79ACEE2A5D4EAACD7EFB1BBD493
CDE6A5D1EAA9D1E7A6C3D998DEF1B1D1E4A2D7E7A6CBDF98D5EC9ECBE395CCE69CCBE59C
CBE69FC3DD96D3EAA4E0F6AEC8DC95E7FDB5E0FBB6B2D593BDEAAFCCFFCC88C89648855B
376944C8F0CBA1C19A728D60CEE2AD889A5ED1E5A0C3D58B
D3EA9CCBE196D6ECA4D4E9A6C5D799CADC9EE4F4B5D9E9A8D1E29EDEEDAA9CAA6DBBC795
F0F7D5FBFFEAF8F9F1FEFFFFECEFF6FBFFFFF9FFFFEAF4F5F8FFFF7B867E6E766B23291D
7E8072B0B3A2F7FEECF6FFEED6ECD5BFDDC3B8DCC2BEE7BDCBF0AAD1F3A7C8E8A9D7F3C3
F2FFECF4FFF4ECFEF2E6FAEFD6ECDFD6F1DE85A58D476E5149745854826674A68D6AA289
5D9C8773B2A17BB3A6548379678A84718A866273695F6A5A313A1F636A48586136C4D09E
C2D09BBBCE97D9EDB87B8C589597668783549E9C6CB5B486DBDEAFB5BD8C8D99699FAF80
93A97AD5EFC0CDEDBC4F734397BD8C8BB585B2DEADBDE7B5C2E9B0C0E6A9BCE2A5BCE2A7
C0E6ABC5EBB0C5EBB2C1E7AECDF3BAC8EEB5BCE2A9BBE1A6CBEEB4C5E8AEC9ECB2C2E9B2
BBE5B5CBF6C9B5DFB176A07029511F92B984CBF1B8A1C38787A76894B16FA6C17CC1DB94
DDF4ACC8DE95C4DA8FE6F5B2D5DAA4807F4F6C6E3CDADFA9D7DFA6D5E0A4E0EEB09EB16F
9AB16BC3DE97D6F4ACD3F5ABC6EAA2B4DA91C4ECA5BDE4A1C9EDB0C1E4AAC7EBADD0F7B4
B1D895D6FDBAC0E7A8CAF2B6CBF2BDB0D6A7C3E8BD0B3005012700D9FFCFBBE3AEC3EBAD
7BA45695B864BED988CEED9DBCF09BBBF29EC9F2A4CAECA2D5F0A9CCEAA4CFEFACD3E9AB
96935EACA070DED8A6D4D7A0C9D99BE6FFBDC2DC9BD7F4B1BCD997CFEEABCBEBA8CFF2AE
C4E8A2C1E59FC4E5A0C2E39EC6E5A1CDEBA5C4E29CCAEAA1C3E89BC6EFA1C3F1A6B4E89E
C8FDB5BDF2ACC6F5B1B6DF9BCDEDACC2E0A2ADCA90A5CA96C2F4C3A4E3B837835C034925
82B18DCBEBC697B289778A5CDEECB7A0AE71BBCA85E7F7AE
CAE097DCF2AAD0E5A0C8DD9AD6EBAAD5EAA9C0D48FC8DC95D1E59DC1D28BD3E4A0C8D79C
8B9968828E68E9F3D8F9FFF2F9FFFFF8FFFFE3EEF4F5FFFFF1FFFFF2FCFBFBFFFFD0D2CF
EBE7E4746F6B57524C78756E7F8277C7D2C4F5FFF4EDFFE4CBEEAEC5E9A1D5F4BBF1FFE4
DDF0DCEFFEF7F5FFFFF8FFFFF8FFFFF0FBF7CFDCD2D0E1CEC1D8BED6EFD1E6FFE2C7E5C3
CAE5C2DAF4D1E1F8DBDEF0D8D3E0CEEEF6E7EEF6E7EEF7E6BDCBB4BFD3BAC1DEC200260B
3A675087BCA88EC8B9CBFDE2C7E8B3D2EBAADCF4B6B8D295BDDAA0D3F1BBB8D8A754784C
95BB9218421E002403083619002B11002B151A4E38598C79487D6D3469591A4F3F174C3C
326757437868255A48002B17043A2353896F73AA8BB5EDC8BDF7CEA6E1B5B8F3C5BDF8C2
ADE5A6C1F8B4C3F8B4AEE19E568746568444A2CB8FC7EDB2BADBA4C5E2ACADC5918BA170
000B003E4E2195A578C4D09E7C8147CED393D3D999E4EFABCCDD96CDE398C9E49799B666
829F4FC9E696D1EC9FC8DE93D3E79FE3F3ACD2DF9AD1DD9BD8EBABC6DC9BC9E09ACAE298
8CA45AC8E298C8E299CCE5A3DDF5B9C7E0A7C3DBA798B07C5C753E7C985D708D4D85995A
D7DAA1ABA16CA3915FC6BD86D2DDA1CCE1A0D3DDA0D8E1A2D4DA9CD0DC9AC5DA95A2B16E
9A9156A8995EE5E1A2E5EAA8D0E099D0E69BD1E99FC9E497CFEBA0C6E599C2E296C6E89B
D4F9ABB4D98BE3FFB9D1F3A7BEE094C9E99EC0E095D4F8B2BCEAACBAEFB799D49E77B681
64A47012501D0A42112252224268395475486C8C637BA17C81B29264A386529C838CD0B7
9DCCAAD6F6CD7893685E7143CCDAA5B2BD815E6A28CAD791
CCE19CCDE29DD2E7A4CADF9CD2E7A4DBF0ADD3E7A0DCF0A8CFE497DBF0A3DEF2AACADF9A
CEE2A7859763AFC094F2FFE4ECF7EFF1FAFFF7FFFFE7F5F8F7FFFFF0FAFCFBFFFFF7F7F9
FFFCFFE8DCDE5A4C4C291E1C18110B636359737769E3EDD2C9DEA6F3FFCBE8FCCBF7FFE5
FBFFF4F0F4F3FEFEFFF6F6FFFEFEFFF6F7FCFBFFFCEEF6E9D6E2CEF6FFEBF5FFEAC1D6B5
C7DBB8F5FFE6F8FFEAF9FFEDE5EDD8FEFFF1FEFFEFE5EDD69AA78DD7EBCFCCE9CB4B6F53
44715C2156443E786C6CA28B88B2849FC28AC6E9B3CEF3BFB9DEABA9CFA08AAF84001200
3055334D7457547C622A523A85AF9B4B7462436C5C85B1A03D705D376E59346955407764
679C8C81B7A770A5954A807050877472AC94104B2F85C19F6DAB84BEFDD299D8ABAFF0BA
C6FFC3A8E59FA7E39DBBF4AF86BD7A3062236C995EC6EFB7CCF3BEC8EAB8CFEABDCDE7BA
33481F4459328C9E78D1E1B4899857E6F4A9DCEEA2C7DE8ECDE897D2F29DC1E38DA1C56E
89AB57D2EF9DDAF1A3C8DA9068722DA0A5639A9A5AA0A4678C9C5EB6CC8CD0E7A3CDE49C
9AB46AA9C379A0BA73AEC785C3DB9FC4DDA4DEF6C296AE7A59743D91AE748BA96BC3D89D
E5E7B5B7AC7F8C794F80754887945FA0B57DAAB88599A67192A36D8AA1697CA063557439
707A48818757C8D9A5CEE6ACDDF6B5BED996CEEBA8C5E4A0D5F6B1C9EDA7C2E7A1C7F0AA
ADD690D5FFB9A7D08CACD591E3FFC8B5DE9CC1E8A7C1EDB2C2F6C6AAE4BB85BF974A845E
08401B1549236191694B764B87AC80B6DAAACFF3C5BCE3B7C1EFC8BBEFCB6FAA8C3A7353
8DBB96CCF3C76080515C7646D3E5B1CFDEA3495817DFEEA9
DDF4B0BCD38FDEF5B1CBE29ED0E5A2C6DB96CEE29ABFD489CCE395CDE496CFE698BED68C
D0E9A5CAE3A2C5DFA298AA80D9E4D6EFF5F5F9FFFFF8FFFFF2FCFDF9FFFFFCFFFFFFFEFF
FFFAFFFFFAFDFFFAFBF3E4E1FFFCF6E9E3D7B3B1A27F7F657370453430018B8660847D63
8C8276FDF3F1796E768A8089B9B3BD828085B8BCBBC8D2CAF1FFF0E8FBE7ECFFECEAFFF0
DCFFF1E4FFFFD3F7EDEBFFFFF1FFFBF7FFF6FBFFEFD7DDC1D0D4AFEFF5C7DFE7B6D9E3AF
D5E2B4EAFBCFD4E6BE96AE8A769075314E3815331B446049254128051F06738B716D8468
8FA68AC2D6BAAEC1A5D1E1C4E5F4D7DBEACBDAE9CACDE4B8C5EAA5C1F0A0C7F3A8C5F2AD
C4EEAFC0ECB1C3EBB7C3EDBDCEF8CABFEABDBAE8B97BA97889BA8345783F45783D4C8349
8EC991AEEAB4C3FFC9B4EFB9B4EDB69BD09A87B9844A794384B07B80A874709762577946
85A872A9CA95CCEAB6CCEBAFC5E39BC4E393CDEE9DCAED99C7ED98C3EB95CBF39DBCE28D
B2D583708C3F879D5494A55F969F60979B60E1E0A7D1DAA3C3E0AACAF1BABEE6AABDE5A7
C5ECADC5ECADC7EDB2C4EBB4CCF2C1BFE4B8A6CCA3BBE1B8C1EABEB2DEADB1DDA8D5FFC8
BDE0A6CCE9AFD7EBB8C7E2AFB2E5ADBBF6BEBDF3C2A5D8ADB1E8C0B5F3CE96E0BB44896A
3B6C566F9B8AA5DECB70A88D5E8864567B507BA27586B082336132001900001500164C1B
0034065991620D45184A815773AA807EB58D84B8927DB38F629C7638714E5B8C6CD8FFE2
DCFBDCBCD5B5D4EAC3C7DFADD2F0B4CDEDAAC7ECA6B2D791B8DD98D0F3B3CFECB4C9EBB8
76A6762B5F2E416D3CA9CE9BB9D6A0ECFFCBC3D79A7F9453
1127000B21003E551149601CD1E6A1D3E9A1D3E79FD8EDA2D8EFA1CEE597CDE599D4EEA4
CDE99FC8E69ED0EEA8C9E0AA979C88FFFFFBFAFCF9F7FCF8FBFFFFEEF2F1FEFFFFFFFFFD
FFFCFBFFF2F1FFFBF6FFF8F1FFF6EAFFFAE8FFFFEBFFFFEAEADBC68774639C8A7C8F7D73
0E00000D0000C8B8B96B5F610700002E2B26898B80040B000009000008003146274F694E
000B0088ACA2C4E2DAD2E9E1F5FFFAFBFFF4F9FDE68584659D9A71CFCB9BE5E2ADD8D7A1
E4E4B0D4D6A5ECEFC2FCFFE3EFFFEDF2FFFAC5DACBCADCCCCFE1D1D3E4D1F3FFED525E46
AEB89FE1EACFE6EDCEADB292010500030400D9DBB6D2DAA9D4ECA0C4E58EC3E390CBEA9E
C7E4A1C1DDA0D4EFB8F2FFDCE7FFD2D5F1C1BDDBA9D0F1BABFE3A6CDF4B34B74304F7D3D
1B511F3F784B87C093ABE5B5B9F1C0B6ECBBC7FBCAB3E8B4BBEDB8B9EAB3C0EFB8C1F1B7
C2EFB4BEEBB0BFEDAFBBE8A7CEF8AEBBE495CDF6A7BEE798C0E99ABEE798CCF3A4C6EB9D
C0E296D5F5ACC5E29FCCE5A4D7ECB1C2D79ED7EAB2C5E0ABC7F1BFB4E6B3B6E7B0C0F1B9
B9E9AF87B77D80AF794F7D4C001200001A000E3C18255430487A5551865C538B5CA3DCA9
BFF6BCB1E3A8BDE5B0BAE9B57ABE853D864F3A794A4F8C62407C580D4E2C003F20002C10
0010000D392C5A8E81467968000E00506D4FC5E4C5D1F2D3BDE0C0B0D8B5D4FEDAB4E2BE
BCEBC9ADDCBCBBE9CCBAE8CC0013004C7A6000140000110042785EDFFFF8D8FBE7BAD1BF
D7E2D1DEE2CBCBD0B0DEE7BAD1E5AAC2DB97D0EFA3D3F2A4D0E89ED4E5A1D1D99DCFE0A9
C3EDBBCDFFD156845328501E8CAA78C1DCA7C9E0A8D8F0B6
D4EDACCAE3A1C1DA96D4EBA5DAF0A88CA2594F631BCCE098DBF1A8CEE49BCDE49CCBE59C
CEEAA0CDEBA1C5E59ACFE4A99C9A83FFFCF6FFFEF6FCF9F0F8FAEFF8FBF0FFFFF6FFFFF4
E2DFD0DFD8C8D7CEBDE4DDCAFFFBE2FFFFE3FAFFDFFFFFEFFFF3FFFFEEFFFFEDFFFFEDFE
E0CCD7EADADBFFFBF6F5E9DDD8D0BDD8D4B9EFEECFA9AB86A9B0848892606B78436E7A4C
696F4D54573C5E5C47665F4C746957847764908268AFA184948765B6AD86A7A47BA1A17B
CED4B2B0B99C9CA8909EAA94A0AA91AAB3988F987D8D967B98A1869FA88D8A9074C4CAAE
D8DCC1686C517C806575785B686B4E595C3F3134174D5331A5B085D0E0B1E7F4C9EEFAD6
EBF4D7E0E8D0ECF4DDF1F9E4FCFFEDDEE9CBE7F7D2DFF2C4DEF6BCCFE9A8CCEAA2BEE39E
9FCE9A79AE8233683C9FD4A6ABE1B0C5FBCABAF0BEB5EEB9A9E2ABBCF6BCC0FAC0B1EBB0
B2EEB2BAF6B8B1EDAFB3EAA9BDECA8BEE9A2C7EFA9BBE09BC6E9A5D5F5B2C8E7A4C9E9A8
C7EAAAC5E9ABCDF5B7BDE9ACB8EAAFBAF0B6B7F1B77BB67E7AB07C8BC18D396E384E844A
16490E1F50186999656E9E6E5E8C65A9D8B47FB0906DA07F407654488059457F565E996B
44804D7FB5835781532C5A2B55936039774400280082A97CC5E6BBC0E1B6C5ECC0CDE9C0
A3A9877B78596C72504249287D8065D7D9C1D7D9C1D7DDC1D4DDC0D4E2C1CEDDBCCADBB9
D1E4C4D5EACBCADEC2C7DBC0CCDFC9E5F8E4F4FFF4F0FFF8E7FFFFE3FFFFE7FDFBCDD7D8
C0BFBD6D645D564F3F0602000007002734002C3E023D4D0F7D864D767642585022878A5F
95B689CBF9CAE8FFE2E1FFD5759063758D5DCBE3B3CEE6B4
C3DD9CD6F1AED1ECA7C8E29BD7EFA5C3D990879B54D4E8A1D2E6A1E1F6B3E6FCBBCEE7A5
C1DC97CAE8A0CFEFA3D7EBAEC5BEA4FFF7EDFFF3E7FFFFEFFFFFEFFFFFEDFAFFE8E7EBD2
D1D4B7A7A889949374A1A280B2B691C8D0A7D4E1B6CFD7BFFFFCFFEDE2FFFFFAFFFFFBFF
F4ECEAF4ECDF8F8772AFA88CC9C3A3FDF7D3FFFFDBFFFFDCFFFFDAE4DFB7D5D0A6B5B088
988E6BC1B295A49379B8A38E8F78664A332370594767513C4F3E2487795EABA4889B9A7E
FAFDE8F1F8E8F9FFF8D5DDD0E9E8D699947ED6D4BDADAB92FBFBE1FFFFE6C5CAAA6B7250
636D486D795198A77ECFDEB3CFE0B3E6FAC9B5C89A9BAC7F35441B56603D70795A6A6F59
7A7C6E909189EAE9E5FFFFFBFDFCF7FFFFF6FCFFEFF7FFE2F8FFDDD2E6B1CAE2A4D2F2B3
C7EFBABDEDB99DCD994577425E905B92C791A2D8A4A3DCA79CD7A1A9E5AF71B07976B57E
88C9918ECF99BBFCC6B1F0B7BEF6B9B8ECAEB1E1A5D7FFC4C1E7ACA9CA91C3E0A8D0EDB5
CFF0B9B3D8A2B7E2ACC8FBC387C48B89CE95428B545198606BA46D82B37B5F8F53BFEDAF
CBF7B8B5E1A4AAD39BC9F1BFAFD5ACBCE4C1CEF7D7C2EDCF5E8D6BB5E7C1A6DBB1588E5D
457C4579AA7297BC88C2E7B3B0E3AAB3E6ABD2F3BEE0F4C3D2DEB0D8E1B4D7E4B6E6E9BE
DFC9A48463426E5632E3D3B2FFFEEAFFF9E9FFFFEDFFFBE8FFFFECFCFEE6FEFFEAFCFFEA
F3FDE2FBFFECFBFFEFFBFFF1FBFFF4FBFFF6FBFFF8EAF6EAE7FFEF5C7464031507222D1F
828477CAC7B6C8C4ABE7E4C1FDFFD3ECF3BDDDE5ACD7DFA4D8DBA6E4E2B2FDF8CEFFFFDC
D8EFC3BFDEB2CCE7BCBFD6ACC7D9AFAEC0961F3409B4C99E
C8E5A2CBE8A5CAE59EC8E299D5EDA3D3E9A093A762D4E4A3CDDCA1F7FFCDF9FFD3D7EAB2
C1D99BD0EBA8D1EFA7C2D49AA49880FFFAEFFFFCEDFFFFE9FFFFE6FEFFE3E9F3CECCD9AE
8E9A6C636C3D6972438A946297A371B7C894D0E4AFB9D0A49FB29FE6F8ECF5FFF3F3FFE5
A1AD85DFE8BB5A6030A8AA7BAFAC83CCC3A2E6D7C0FFF1E2FFF8EDF6DAD6CFB3B0D1B8B1
AC9D88D5C9B1B5A595E8D6CAE7D0CAB9A09CF3DAD5E0C7C05C4438867364A09080716654
8C85757D796DCCCCC2F5F2EDFFF1F0FFF9F9FFF2EDF6ECE2837D6D85876F656C4A29380D
5A713DCEECB0C8EDA7C3EE9FBFEF9BB7EC92AEE588CBFBA5A6C57F859A616577472C3A16
26301822281C6A6C6B6F70757E7E86B0B3B8E4EAEAF9FFFAF7FFF4D9EDD2DEF6D4B6D3A5
B5DB9ECCF7B2C1EBA983B06F74A5644F814487BA7F2A5F2709420D3A7442316C3E39764A
33714836774F8BCBA6B8FBD0ABF1BBB1F6BDAAE9B2B9F0B9B1E0ACE4FFD9DBFBCAB1CE9E
AFCC9CA4C495496F40487647649C6B2C6C387BBF8EB8F7C2B2E0A2C6E9A7C6E7A2BAD993
C8E6A0DDF8B5D0E8AAC4DBA5E7FDCFE2F8D1D6F0CDD3EECD9FBF9AACCFA7C7ECC1C1E8B1
CBF5ABDAFDADBBD186D3EBA1CAF0A5C3E79FCDDFA1D0D59DD5D3A2EBE8BBE0E1B7A59B78
957159956855B38E7BFFFAEAEFE6E1FFFFFDF8FAF5F8FDF7FBFFFAF3FDF28F9D8EE0F1E1
F2FFF3EEFFF0EDFDF2F5FFFBF2FFFCE8F7F4F6FFFFF0FEF18EA076001400698048758E57
E0F9C0F5FFD3D5E7ABD3E2A1FFFFC6FFFFC2E6E7A5DFE1A0CFD599D9E2ABFBFFD6F9FFDA
C3D0A2DDE8BDD9E0B6D3DAB1DFE5BFE5EDC64F5E3798AA82
CFEEAAC3E29CC4E298CBE59BCEE69AD4E8A08F9F5ECFDDA2D1DEA9FCFFDAFBFFDCE3F3C6
D5E9B6D8F0B6C7E1A09DAB76A59983FFFAEFFFF5E4FFFFE4FEFFE0A0AD81657743B7CA92
D8ECAFC6D89AD3E3A5DBEDAFCADEA1C8DEA0CCE6A9BBD6A3CEE6C6B4C8AD9BAF8AA0B385
F9FFD3F4FFC6D2DDA1D0D7A1D1D4A7F3F0CDB9B19AB3A797C3B2AABFACA6F7E2DFF4E3D9
FFFFE8FFFDE2F3ECD9FFF5E9FFFBF6FFF9F7FFF9F8FFF9F6B7A39CE3D1C5F5E5D5F1E4D1
C7BFAC7D766443402F241C0FA8938E7D64605C453D362416756A566E6A4DF6FBD3F6FFD3
D3E8ADCDECA8C3E99CBDEA95B7ED8FAFE985D3FFA9BBEE91CFEFA4C6DA9FDAEAB9F4FEDB
FDFFEEE3E2DDD5D0D697919F8881919894A2313038000100535B507A8773A1B1969CB389
97B67BB6DB98CCF3B2BFE6A5D0FABBB7E3A696C38AA0CF9892C28E9DD1A0BBF0C2ABE3B6
8DC69B669F7638724A3F8055418E5A2F7E4763AC7782C28E72A8768DBB8C4D734481A172
57724577926758774B5F83578AB486B5E3B5C4F5C8BBE9B8CCF0B37D9C59CBE8A5C6E19C
D3EAA6C9DE9DDCEEB4D5E5B4DEEDC4F8FFE6F2FFE7F3FFECE5FEE1678465C3E2C0C0E0B1
C0D89AC0D18D858A4A747A3C899D5E62783A353C08A09C6DBAB18AC4BC97E4E1C0FFFBDE
FFF0DFFDD5C9E8CBBBF3E0D2FFFEF6F1F4EDF8FBF2D3D9CD121A0B25301F3B4A353F5139
041600000C00000700010F0000080000050017221C27331D74814BCADB94C1D890DAF8B0
C5E9A1C7E99FCBE99FD4EAA1D5E197D9DC9572712E5D5F20929B6291A26C88A2727C9464
959F6D7B7D4B484717969569B7B58CCFD4ACDCE6C1ECFBD4
C5E69FCBEDA3D3F2A6CAE699C7DF93E4F8B19AA86AD5DFAAD8E1B6FDFFE2FCFFE6F3FEDE
E5F4CDD7E8BBC4DBA59CA97DC2B7A5FFFBF1FFFAE8F9FCDFEFFCD19BAF7A6B8546C6E49E
C8E299D1E99FD2E89FD0E69ECEE5A1C9E2A0CBE8A8DCF3BFE3E9CFE3E2CEB3B495D5DAB2
E3EAB7DAE3ACDEE7B0D8E2ADDEEABAEAF7CCF9FFE38A9875A1AF8BDFEFC8E5F6CAEFFFD3
E9F8CDDAE9C2F7FFE1EDF2DCEAEADEF9F4EEEFE6E1FFFCF6CCC0B4FCF1DFF8F1D7F6EFD2
F5F0D0EAE7C6AEAE8C6C6644927B5B6B4E2E7A603FA9936ED6C49CF8EDC0EBE5B5F8F8C4
D4DCA3CBD99CD2E5A5D7F0ACD3F1A9CBEDA3BFE497C5E29FD0DFA8D0D5ACD9DABAFFFFEC
F9F0EBFFF7FEFFF8FFFDE7FCFFECFFFDE8F7B3A2A860564D2C27110D0D003F4217283404
3D5426537042A2BF91C7E7B6B1D1A0CAECBAC2E7B4BBE0ACC3EAB5B3DBA6C6EEB9BEE9B1
C1ECB4B5E2A987B47B89C08776BF8869B98458A26F2165320B47144378441A46136A8F5C
B1CE9ECCE3B5E1F4C7CFE0B4CBDCB0DAEBC1DDEEC47187595D7B49001C005C7B429BB880
C6DFA8CDE3B2D5E7BDE5F6D4EFFFE7F4FFF4F1FFFAF0FFFFD4EFE65B796DDCFEEED1ECD9
F6FBE7B3AB984C392A493828757761878C75908B77F0E5D1EBE3D0FFFFEAF6FEE6FFFFEC
E1D1C1837262746D5A807E67908C737E7D5F7F7E5F7577528A8F67A3AA7ED2DBACA4B07E
778351737F4F727B4E80875D767C567074518F90719C9E77CCD199CED899DBEFB0D1EBAC
ABCB8CD8F8B9D7F4B4A8BE7E919D5FCFD59991945B919864D8E5B7CFE6BCC3E3BECFEEC4
CDDCA3BEC4869A9B618F8F59A7A676B4B78AC7CFA6EBF6CE
C7EBA3C3E79DCBEB9FD2EEA1CAE296D6EAA37E8C51DBE3B4DAE0BEFEFFE9FEFFEDFCFFED
E9F4D6CDDBB7D5E8BAC9D5AF746C5FA89D97A5A4929AA3849FB285C6E4A8CBECA5CFF2A2
CBED99D6F39FCAE594C7DF91D4EBA3CEE7A3C3E09ED3E7B2FFFFE6FFFFEAFFFFE1E5E7BF
E2E8B8D6DFAAE3F0BBC5D6A2C6D9ABE5FACFF3FFE0BBD6A9D1EFB9BFDFA0CCF0AABFE197
C0DF9BCAE4A7D3EAB6D4E6BECDDABED0D8C3E6E9D8FDFEECD2D2BAFAFBDCF8FAD5CAD0A4
D9DFB1CCD4A1DFE9B5D8DFABD7D49FD9D29BFFFEC8FFFFCDE0DDA6D4D39BD5D69DDADDA4
DBE3A897A16598A367B1BF82546328CBDD9FDEF0B4C7D99FD2E0ABD9E5B7D9DFBDFFFFEC
F3EEE8FFFAFFFFF8FFFFF7FFFFF5FFFFF8FFFDEFEFFDF3E7FFFFE4DADCB4CAD19DD4E1AB
7E946592AD806E8A5A627E4E6581513B5727365221314D1A5C784568854F59764058753F
5A773F64814999B67EBFE4AEB4EAB9C4FFD3A8E3B5B6F0BEC0F6C4C4F6C1AFDBA6D0F7C0
BDDEA9C9E4AFA4B6827682508086581B1C00827F54A2A578B1C592A6C18C99B07A7D915C
6B7C488A976959643C596245343B29B7BFB48C97934A5858516462142A27011B12273B2F
212514877E6D8B7869A99989767A6327301529271038321A59553A7E8164778763758360
403D1E3E371A898F6D666E475E633A909366A1A875C1CA93E5EFB3CCD898D5E4A1CAD994
CFDE99D1E09BCEDA98D5DFA0CED69BCFD49CE2E6B3DCE0ADC2C791DFE6B0D2DCA7DFEDB8
D9EAB4BDD099AEC189AEC0848D9B5ECAD698D6E1A5DDECB3DCF0BFC3DDB0C4E2BCC2DFB1
D0E7A3C2D488D7E49EDFEAA8D7DFA49299659CA475E8F1C6
CBF1A6BBE194BEE191D3F2A2CEE69AC4D8935F6A32D9E0B6DADDC0FFFFEFFFFFF4FEFFF4
EBF3DED0DABFEDFBD7F2FBDCFFFFF6FCF7F3E3E7D8DDEECEBEDAAACAEEAEC3EC9EBBE58F
C5E98FC4E58CC7E58FCFE897D3EBA1D6EDA9D0E9A8C8DDA5F6FFD8DAE5BDCAD7A9E7F5C2
C6D7A1D0E3ACC2D6A3F0FFD8F4FFE3EDFFDDF2FFE3CDE7B8D5F3B7C3E398BCDC87DDFFA2
C8ED8DCDF295C1E291C7E4A1CCE3ADD2E5B8F3FFDEF9FFE3E1F0C7F9FFDAE9FCC5C9DFA1
DDF6B4C3DE99CAE8A2D7F6B0CBEFA7CFF3ABB8DC96CEEFAAD1F0ACCEEBA8D0E9A7CDE3A2
4F64238DA060BDCB8DDCE8AA636D31D4DEA1D3DBA0DCEAACC7E59FC7EAA6C4E1A9F4FFE1
F7FFEFF9FFFAF7FBFEF8F8FFFFFDFFEDECF2FEFFFDFBFFF3F6FFE5C4D6ACC6DDA7C6E0A3
DDFABAA7C484D7F4B4CEE8A9C8E1A7C7DEA68EA26D889C69000B00000F00000900000800
010B00000700000700000A006F8360B6CEAACBE7BFCDEEC3B9DFAEC0E8B3CAF6BBB0D99D
C9F0B1D1F4B45A7435000C002C3400E9E9B3E2DCA8E1DBA7CED198E5EDB1D9DDA0DBDCA0
DCDA9FDCD7A0C9BE91D5C8A685765FCCBEB18176709B9390D9D6D17C7D77393C33B0BAA1
51632FD5E5A6D3D89EE3EBB0D1EAA9B7D492D9E7AAE5EDB260682D27320021370057692B
565620908D58F4FCC3C5D398D4E5AED7EAB2BCD093DEF4B3BED58FD2ECA2C6E393DBF8A6
D1ED99D6F1A0CDE597CCE498CEE49CD8ECA7DEEEADBDCB8E7E87520306002A2900080300
6C633A90895BD4D29FDBE1A5E4F1ACCBE095C5E093C8E499C2DD98D2EAACDFF2BBC2DA9C
CCF29DD3FC9ECCEE98CCE79AC9DD98D0DEA1E9F3BFC0C99A
C0E295CFEFA3CDECA0CAE49AC9E098DAEEA96A783BD3DDABDADEBBFFFFECFAFCEFFFFFF8
F4F6EBDDE1D2FEFFECFEFFEBFBF9ECFFFFF3EAF2DAD2E2BDC1D9A7D4F2B2C5E79BC8EB97
D4F29CC2DE89D2EA96D8ED9EC4D58ECEDF9BDEF0B2CBDCA5F9FFDAF0FFD2D1E3AFBFD49B
D6EBB0CCE4AAD6EDB9D7EEC2E6FCD8F4FFEAE4F9D8CEE5B9CBE4AAC7E399D4F197C2E07E
CCEA88CBEA8CD2F49DCAEA9EC5E2A0D0E7AFDEF0C0F5FFD6AFBD8CF9FFD4E1F7B9CDE6A4
CCE7A0DCF6ADC6DD95C6E298BFE39BCFF9AFC0E89FBCE49BC8ECA4C7E8A145641E8FAA65
C3DC9ADAEFAEDAEAACCED99F565F28C3C892E1E3B1D0DAA5CEE8ABCAECAFC6E5ACE6FFD1
F2FFE3F1FFE7F5FFF1F7FFF6F7FFFAF2FFF5F7FFF6EDFFE7E8FED8D3EDBDCDE9AECCE6A5
CBDE9CDFEEABD5E4A1D3E2A1C8D698E0EEB1D4E1A9DAE4AFDBE5B3CBD4A5E8EFC3D4DBB2
DBDFBADFE3C09CA07D9B9F7E404121181C006D7550CBDAB1D2E8B9C1DCA7C3E2A9D2F4B7
577A3A2C4A0A6D8746DDF2B18E9C5E51591D6C7035A0A165A7AC6C9395549A9B599C9B58
ACA767736A2F7D703C493B0EDFCFADFFFBE1FFF5E2FFFDEDF4EBDCFFFBEBF0EBD8161F00
82A06AC0E39FD4EAA2D1E699BFDF8AD3F59FCFEA9BC3D98EC8DC94C8DC94CCE79ACCE194
ABB36AA0A660C6D38ED3E8A3D1EEABBADA97C8E9A4CDF1A9BBE093D3FAABBEE592BEE690
C1E58ECDEF99C5E592C8E394D1E99FDAEEA9C6D695879759889A6098A56F9DA4719E9C6C
9B9565BFB786D3D29AE0E6A8D3E39CC9E193D7F6A6CFF09FC2DE93D5ECA4F0FFBFF8FFC6
C4EA93BEEB90C1E993C9EC9CC7E29BDAF0B0C5D8A0C5D8A1
C7DD8BDFF4A7C7DB96D7EAAAD5E7A9405313BACB85D1E1A0D9E4ACFCFFDBFFFFEDFFFFF8
FFFDFDF9F3F3FFF9F3FFFFEFFFFFE6EEF2CDF3FAD1DDE6B7CFDCA6D6E4A9D6E5A4D2E19C
54611994A058D2DE96C9D38E949D5AAAB070E0E9AAD3DCA3FCFFDAE1F1C4D3E4AED3E7AA
CDE29FD2E8A7C8E0A6DFF5C6F2FFE3F5FFECF4FFEAD4E5C3CCDEAED6EAABD3E899D0E391
D2DE94DAEAA3CCE39DBEDB98D5EFB2D1E6AEF3FBCAFFFFD2C2C193DEE2B0D2DFA9CEDDA2
DDEBAEB9C1858A884FA9A46CE4E5ABACB4789BA568929E5E7F8B4B9DAC69CFE09CD5E6A2
CDDD9CDDEDAFC9D69ED4E0AEBFC89BF5FCD3FBFFDAFFFFE3F7FBE2FEFFEAF5FFDADAEABB
C3D69ED7EFB3CEE7ADCAE5B0C7E0B6F2FFE4E8FEDACBE1BAC9DFB0D6EBB2D0E7A1D6E39D
B8B477A49760B4A971908750A39E669A985FBDBE85DADDA4DADFA7D9E1A8D1DAA3DDE6AF
D0DAA5E5EFBADAE4AFCFD7A6D5D6ACD1CFA897987082855A5F65372D370509160044531C
85975D9EB2759BAF7093A969C6DC9BD4EAA9DCF2B1C1D894CFE39ED1E09BD3E09AD6E19C
DBE29EDDE2A0DDDFA0DCDBA2BCBA879C9A6A89865D93916BAFAC89C5C2A1B4B394859276
8BB399E0FFEACAE7B1CDE29DD3EC98C9E791C3E696C6EAA0C5E4A1BCDA94E0F8AACFE593
B6C87698AB5CBED58FD2F1ADB9E296CBFAAAC0EFA1B4E498C5F5ABC1F1A7B1DF94C4F0A3
BDE698C6E89BD1EDA2CCE19CD1DFA1E0E9B08C905D717C44D3EEA7BEE093CCEAA0D6F0A7
C2D792D7EAA8C9D998E3F6B4D2E5A3D2E7A2D3EAA4CAE49DCCE69FD7EEA8D7EEA8ECFFBD
C4E096DCFAB2BCDA92C9E8A2D7F8B3BFDF9ECCEEB1D4F6B9
E2EF9FD0DE91DAE6A8D2DFA7ACBB825E6E30CBDC95CFE197DCE8A8DFE7B8ECEED8FBF6F0
FFFBFFFFFAFFFFFAFDF9EFE3F6F6D2F5FBCBEAF1BECCD39FD8DDA7D5DAA0CAD094C2C888
A6AB6BCFD492DDE2A0D3D8969297558B904ED9DE9ED6DBA1FAFFD5EAF5CADBE8B2B8C889
D9EAA4D2E6A1CCE0A3E1F5C2F5FFE2F8FFECF9FFEDD2DFC3D7E4B9CBDAA1D3E39AD3DF93
E9E9ABD6D79ED7E6ABD4EAACC2D79CCBDAA3F7F6C6FFFFD4BAAF82E6E0B0D6DDA9CFDAA2
CFD89F7B7B453E31006E5C2A9E945F85804997955CABAC70A3A868B8C180D9E4A0D3DF9D
D4E3A2CBD99CDEEBB5DDE6B77E855CE1E7C3FFFFE4FFFFECFFFDF4FFFEF1F6F5D7D0D6A8
ECFABCC3D78FC3DD94D4EFAACEEAB0EDFFD7F4FFDFD9EFC1D2E6B1B8CA8CCCDE94E1E9A0
7D7137B49E6C9F8E5A7D6D398D824C5F58216A682FDFE0A6DBDFA4E3E9ADD5DDA1D8E2A5
DCE6A9D1DD9FCAD698EBF0B8E7E3B6EBE2B9DAD1A8D4CDA1918A5E646031757343AEAE7C
CDD09BABB37A949F63C0D091D3E8A7BDD694C4DF9CE0FBB6D4EEA7D4EBA3D3E9A0D2E69E
D5E59ED9E6A0DCE7A3DFE8A5DDE3A5D2D89CD9DEA6E3E7B4DCDFB0DADDB2E9EBC3EBFCDC
487264CAFBE8D0F1C4D2E8A7CBDE8DDFF7A1C3E598C4E9A3CFF3B3CCEBA8CBE196CBDD8B
B1C36FA0B364CCE5A1C8E7A3CAEFA2BDE495BEE497C7EFA6B7E09ACCF5AFBDE59FCFF4AE
D0F1AACAE8A0CEE39ED3E2A1E7EFB4CECE9C837F529CA16BC3E397CAF69FBEE894C5EC9B
D2F4A8C9E79FD8F3AEBCD593CAE0A0CFE5A5CAE0A0D1E7A6D2EBA7C1DB94D2EDA6CEE59F
DAE6A8C6D094E0EEB1C8DA9CC6DC9ED3F0B0BBDB9CE1FFC4
CCD789DBE59CD7DFA4959E69B6C08BD1DCA0E9F6B1C4D18BD7DFA3D3D6A9FFFFECFFFDF8
FFFAFFFFEFF9FFF9FBFFF9EDE5E2BFDADDAED7DBA9E6EBB5E8EDB5999E649BA165D7DD9D
CDD393E7EEABDAE19EE0E7A4A4AA6A888E4EDEE4A4E1E9AEDCE2B4D7DEB2D1DAA3EBF7B9
D0DD98DFEEA9C5D597E1EFBCE3EFCBFBFFE8EDF6DBF4FBDCEEF5CBDDE6ADDEE8A1DAE096
A29C6088834C555D24536126A0AB73D3D8A2DCD1A3E8D7ABBFAE82F5EABCAAAC7A616C34
A3AE74DBE0A8E6DFA9F0E6B1E7E6AECED399D6DEA2DDE6A7C7D290CCD994DBEAA5D0DF9C
D9E8A7D4E2A4D1DCA4DDE5B2E1E7BB9D9F78626240F5F1D6F2E9DAEDE5D2DDD9B6DCDEAD
D9E1A5D9E6A1D4E3A0DBEDAFD5E7B3F8FFDDE4F4CDD3E2B7BCCA97F5FFC6CEDE9398A357
C4C083D7CE97E5DCA5DED7A0DFDDA4E0DFA6E2E3A9B9BD8290965A767C407D834791975B
999F63868C5080864A807F4957481D3C2901513E16A69369907D537564389B8D60B5A979
BEB481DED9A2DCDBA3EBEFB4D5DDA1E5F1B1DEEDACC5D994CAE199CBE59CCDE79DCDE59B
CCE098CDDE97D2DF99D5E09CE1ECAAD5DE9FE6EEB3FEFFCFF0F7C4D5DBABD5DDAEDEEFCB
93BAA8C2EDD9C6E7B8C2DB99D8E999DAEC9AC8E096CDECA8B8DB99D2EFADCFDF96E3EB9E
B3B76BA5AD64D1E4A4C9DF9FD5E4A1E3EEA9E0EDA8E0EFAECFDFA0CCDF9F90A363D0E3A3
D0E09FD1E09DE2EBAAD7DB9ED2CF988F8854635629979763CEECA4D2FDADBDE698C3E79D
CCEDA6BBD895D1EBAACDE7A8E1F9BDECFFC8D4ECAEC5DFA0DBF8B6D0EDAAC9E8A45E712F
A8A36B9F925DA39964C5C089DADBA2D7DFA6DAE8ADDEEDB2
BAC174949B55A3A86E505724B0B784899158ADB675BDC683A8AD73A1A276F5EEDBECE1DD
CFBEC4C3B0B6F9E5E6EADDCD8886609DA16FABAF7CABB07A989D65666C30797F41979D5D
9CA3609DA6638E9754959E5B767F3E747F3DC3CE8CDBE3A7DFE2B3D4D6A7E4E9B1B5BB7D
CCD691D6DF9CDFE9ACBEC894DFE7C0FFFFE4E8EBCEFFFFE3CDD0A3CACF95C4CA82AFB168
80763BA097608081485D652C9A9F69BCB986E8D5AADBC2999F885EA294658484506B763C
89975C8892569A9960B3B279BEC68BA2B073A0AE70A0B06F97A864A8B973BECF89BACB85
C6D793A2B170AEB87C909761C5C7987472496A6640A8A282E8E1C7BBB498B0AB85D4D2A1
9E9F63999E5EA8AE70C7CF96DDE4B8BAC29BD1D9B4AFB78EA0AA76818D4F93A156899549
9A9F5FA4A56BBABB81B3B77CB9BD828C9256A1A96D9EA66AC8D0944D55196A7034A8AE72
92965B6F703694955B8F8A53796C3F6251265B4A1F7F6E42665529625425AB9D6EC2B684
948D57A5A068B0AF76C0C487969F608D9957A4B370ABBF7A829C5388A65C95B16699B369
97AF6593A75F92A35C93A35CAFBC7797A361A0AA6DBAC589B6C1899CA6718C996485976F
73947F4B735B8AAE7E9AB473E0F0A5C6D384DAE9A4CBE1A0C8E8A7D1EEABCDD893E0DD96
9D934EABA666CED99DDAE8ABDFDDA0D5CD8FDCD69ACCC88BB6B67A9A9E614E5418828B4C
717A397F8545E4E6A7DEDEA299945C7A733DAA9E6CBFBC85CBDB9CC5DE9ACCE2A1C8DC9D
D1E3A7EDFCC1CCD9A1D7E4AEFAFFD1EDFAC4DAE9B2BFCE95D7E9ADC7DB9CAFC3842B3700
7C733CA4935FAC9C699E915DC4BA85EDE8B1DFDEA8D2D59E
4D5107757A3793965FDEE0B19395669FA3708D9357B9BD80B5B67D99966DE2DAC7DACCC9
CCBCBFCDBABEF7E4E0DFD2C19D99739EA06FADAF7DB0B37C8F945A989E62AAB37498A160
939C5996A15DB0BB77ABB8738A965474803E636F2D5660236A6C3A5755244E4F16868849
CFD58FA1A6635E64268A8F59B2B48CB8B997919071A9A985A09F6FCECF95C5C6805E5B14
81753BA89D67D3D29ABABD84989761857B48F8E0B4B7966DC6A67D614C1F6B69369CA76D
B3C28793A1649CA266A7AD71CFDFA1B8CC8DB2C786AEC581A6BD77ABC179ADC37A9FB36B
BFD08AA0AF6CB2BC7D889055A3A671979666CDCA9D7D7850C7C19DD3CEA8D4D0A195925D
939156A19F64D6D39CDFDDACF9F7D1E7E7C5DFDEBF9FA17A808754BAC485D6E497BFCD80
889351BDC78AB7C1848E9A5CA0AC6EC4D092C7D395A6B274CCD699B8C285E1E9ADC3C78C
98995FBDBC83E8E6AD928F58A3A16ECBC996CCCA97BDBC86BBBA84C9CA91EAEBB2D9DDA2
9CA46899A364C0CF8EE6FAB5D0E5A092AC63A2BE74ADCB81B4D489BDDF93C9E99ECFEDA3
CEEA9FCBE399CAE097CBDF97DEEFA8D1E29CD3E4A0D9E9A8D0E0A2CBDDA1D2E4A8D1E7B8
5F7B623E60459DC39094B4738C9C536B732AAAB16E97A766A1C07D88A562979E5AA99E5E
775A20A48F5694996197A06791864E48330096854DA89C629A9156A8A467A4A468969B5B
9EA363B2B7779EA3638A8C4DD1D195BAB87D878248918C54807B446E68348F88549D9564
C7BC8ED2C598BDB084C3B68AA99E715F5426756D3E8B855396935E68672F8A89519E9D65
A09E65D2D0979290579F9A629D965F4B440D625B25857E48
A5AB61D3D896E1E4AFCACB9FD7D8ACD7DBA9E4E7AED9DDA2E7E7B1CDCAA1FFFFECFFF4EE
FFF4F4FFFAFAFFFBF1FFFEE8E3E1B8CDCF9DD8DBA6DBDEA79FA46AD2DB9CE3ECABDEE9A7
DFEAA6D2DF9AE7F4AFD5E49FCCDB98DAEBA7CBDC98D1DD9F5F5F2B63622C525216979958
535611E1E7A1DADF9FD0D59DDEE0B1EBECC4DBDBB5C2C097D4D4A2EBEBAFD4D58F57540D
B1A96BBFB881DADEA3DCE1A7D2D19BA59967FFE3B9D2AF87A07D55715B2CDAD7A2E2ECB0
C2D496C6D697DFE7ABD0DA9DD0E4A5C6DF9EC8E19FCDE6A2D0EAA3D9F0A8D6EEA4C9DF96
C4D890E0F1AACAD694DAE3A4EBF0B6CFD29BD0D09CA4A4725E5D2D52522045440E6D6C33
99975C5C571F655E2AE0D7ACDFD6B5FFFFE3E7E2C4D2D2AC5A612DDAE4A5C7D588D2E393
E6F5B0DBE9ABC9D99ADBEBACCDDD9EE7F7B8C6D697D6E6A7D4E2A4D3DFA1DCE6A9D5DDA1
D7DBA0D9DAA0E2E1A8D5D99EC7D195D6E4A9D8E6A9C8D699DFEDB0D9E7A9D0DEA0CFDF9E
D1E4A2D2E9A3D3EDA6BFDD93C7E79CBDE295D8FEB1C4EA9DC0E699C4E99CC9EB9FCBEBA0
CAE99DCDE99ED1EBA1D6EEA4D0E69DCDE39AD0E69ECEE39EC6DD97CDE4A0D5EBAACEE5AF
D4EDCD809F8085B07BC5ECABC9DA96D9DE9BEBEDACC2CE8ECAEBA6B2D18BD7DC9AD8C58A
AE8452F8D6A6DDE0A9D4DFA7958C5377662EDACE94E3D99EDCD89BD8D89AE6EBABD7E09F
DCE7A5C9D492D9E3A4DFEAA8D6E19FD1DA99E0E7A4DBDCA0D4CA97E3D5A6ECDBAFD7C69A
FFFFD3FFFFD4EAD9AE4332076052259B8E61EFE3B3D4CC9BD8D19DEDE8B1F5F2BBCDCE94
E2ECAFBDCB8DD7E1A4DDE3A7E6E5ACA5A068625922D6CB95
8F974E949B58868A57797C51E0E2BADEE4B6CFD49CDFE4AADBE0AADCDDB3FFFFEAFFFEF4
FFFDF8FFFDF4FAF2DFFFFEE0D3D2A6ECEFBAE0E3AE9EA1684F5519D4DD9ED6DF9ECFDA96
CEDB96C8D792D3E49ED0E49DD1E5A0D6EAA5CFE4A1D6E4A6BDC087EEEDB5C0C283929754
93995399A05A6F76339DA5699DA16ED5D8A9DCDFB0E0E2B1E6E9B2D9DB9CBDBF76C6C87F
D2D493E8EEB0DBE9ABD2E0A2E6EBB1C1BA84C2A77ADCB98FB69369644C1ED7D19DD8E2A6
D0E2A4E0F3B3DDE7A8D1DD9DD1E6A5CEE7A6CEE7A5CAE39FCCE39DD3EAA2D5EDA3D0E69B
C5DB90DCF0A8D0E19AE1F0ABCEDA9AE1EBAEEAF4B7C8D295A8B276ADB579999F61D8DA9B
E8E8ACD4CF97A79F70DDD4ABFFFFDFFFFFE3CEC9A95D5E36454E17D4E3A0E9FCADC4DA88
C1D08BD1E09FE1F1B0ABBB7A8FA2608B9E5C7F9250C8DB99CFE2A0D2E2A1A6B574849050
7C86477C85466C7536707C3CA2B7769EB775CAE3A1C8E19DDBF4B0CBE4A0BCD591D8F3AC
C9E79FCDEDA2C4E69AC9F0A1D2FBACC0ED9CBEED9CBAE796C7F0A2C8EEA1C6EC9FC5EA9D
C8E89CCBEA9ED0EC9FD2EEA1D2EDA0CCE79AD0EAA0D5EFA5D3EFA4D5F1A6CEECA2BDD99C
BFD8B1A4C49F8ABD85DDFFCBD2E8A8D2DB9ADADC9DDBE7A5CFF5ACCBEDA3DBE09EB49E65
8A572AEAC195EFF2BDC8DAA07E8448AAAC6DE1E6A6D4DD9AE4F1ACD0E19BC7DD95DAF1AB
D6EDA9C6DF9BCAE3A1DAF3AFC4DE97C8DF97D6EEA4D9EAA4F1F4BDD6D2A2DAD6A6EBE7B7
C7C393959360D2D09DE3E3AFD5D8A1D5DAA2DCE1A7E0EAAEDEE8ABCAD696D4E3A2D7EAA8
C2DF9CD6F5B1D5F0ADC7DA9AD3DDA0D0D197A39C65847B42
DDEBA0D1DE99DAE4B08C956AB1B990CFD6AADCE5AED6E0A4D2DBA4DCE2B6FEFFE6F9FAEA
FFFFF3FFFFEFD6D5B9E4E4BEFFFFD4FFFFCFD4D7A0969B61565F20E1ECAAC5D08CE6F3AE
D7E6A1D8E9A3CBDF98D6ECA4D3E8A3C3DA94CFE6A2D4E7A5E9F1B5D0D497D2D898E1EBA6
D8E29BDEEAA2D0DB97D6E2A28E975E838C55343D089AA269D2DA9ED9E09D777D33D6DE93
DAE7A1CDE29DC5E09BC7E09ED4E4A5E3E4AB97825396774BAB8A5F634D1CE3E0A9D7E1A4
D5E8A8D6E9A7A7B2709CA765CBDE9ED3E9A8D6EDA9CFE6A0CBE199CDE39AD0E69DD0E69B
D7EDA2CDE398CCE297CEE29AD1E59ECBDF98CCE09BD7EBA6DFF0AAC9D992DCE7A3D0D996
D9DDA0EDECB4E6E0B08E865F857C5B6F6949A5A27FD1D7A9D4E2A7D9EDA6BDD484D9F0A0
DBEAA524300094A060B3C281D1E4A2C8DD9AD9EEAB92A7648EA561ABC27EC7DC99E0F5B2
C9DC9AD3E3A2D0E09FD3E6A4D4EBA79BB56E92AB67556F28849B55CFE6A0D2ECA5C9E39A
C1DD93DBFAAEC3E397CAEC9FC0E798C0E99ABBE694C7F2A0C5EEA0C4ED9FC6EC9FC7EC9F
CAEC9FCAEA9EC8E79BC5E496CEEA9DC8E497CDE99CCEED9FC6E597C5E697CCED9ECCEBA7
CFE9BACEF1C779B0798CC284BCDA9EDCE7ABE4EAACCCDB98B9E495D0F6A9DBE09EB59C66
925D35E1B58ECCD09D556F32CCE0A1D7EAA8D6ECA4C8E096CBE79CD4F3A7CCECA1BFE197
C9EAA5D4F4B1C2E19ECCEBA7C6E69DD5F4A8CAE999C6DE94CBD99BDBE4ADDFE6B0C9D299
727B42D3DEA2D6E4A7D2E0A2D4E4A5E0F3B1BDD28FD0E7A1D4EEA7C3DD96D4F0A6C8E69E
C9EDA5C4E8A2C0DF9BD3E9A8D4E2A4DCE2A6E2E2A6B2AD73
D4E99CC7DB94CEDFA9E0F0C3556439C9D6A8DEEDB4CDDCA1D0DFA6D8E4B4F8FFE2F8FFE8
FCFFEDF9FFE7DAE5BDD8E2B0FCFFCDFFFFCDD9DEA48A92565E6829C6D290D8E5A0D4E39E
D3E49DD2E69ECBE199BED58DD5ECA6D3EDA6C8E19DD1E8A4D4E0A0D5E09ED4DF9BDBE8A2
D8E89FD8EAA0D3E49ED1E5A0D7E7A8ABBB7D8D9D5F5A682A94A05E8B96519FAB61C7D78C
CEEA9FC0E49ABDE79BCBF3AAC9E6A3D4E0A29A905B816B3AAA8F60AE9C6AD8D79FD6E0A3
D1E4A2AEBF7B717A39969F5ED5E1A1B6C685CEDE9DD5E6A2D0E49DD8ECA4CBDF97D0E69B
D0E799DCF4A6C6E192CDE99CD1EDA0C1E094CCEAA0CCEB9FCEE99AC7DF91CCE196DDECA7
DBE5A6DDE2A8EBEBB9C8C79BAEAC86AFAF89D5DAB1D4DEACCADC9ED5EFA6C7E492D2EB9A
B6C17D525818CED796EAF5B3CFDE9BCDE19CDCF1ACC6DD97CCE69FC7E29BCBE9A1C9E79F
D8F6AEC6E19AC7E29BCEE8A1D5E9A4D6E5A0C6D5928B9A559FAC678C9954E3F0ABD0DD97
C5D58EE4F5AEC5D991D4EA9FCDE599C8E396CDE89BD4F3A5CCF1A4C3EC9EC2E89BC8EDA0
CAECA0C6E89BC7E79BCCECA0C6E597CAE99BCDEC9CCCED9CCBEC9BC9EC9AC8EB99C6E89E
C9E5B2DAFFD17DBA8183C085BEE4ABD5EAAFC7D597D4EBA3C7F6A5B6E191D3D999E6CF9B
B480598C653E9BA46D9EC181C2E5A1C4E8A0C9EEA1C9F09FBFE693C5EF9DCCF3A4C2E89D
C7ECA9C3E6A6CBEAAECEECACC6E3A0D6F2A8BFDA89D3EB9DC1D691E5FAB9CFE2A2C1D695
9AB16DCBE59EC8E39CCAE69CD1EFA5C2E296CEEEA2C9EC9CC3E696C8ED9DC3E898CCEEA1
C8E7A1D2ECABCDE3A3D4E6A8D7E3A5D3DB9FE0E4A7DEDFA3
C7E293DDF7AED5EDB3C1D4A68FA275F8FFDAF6FFD1F8FFCFF8FFD0F8FFD8F1FFDCF8FFE8
CEDDBEA0B08BAABC8AB9CB91A5B076828C4FA2AC6F8A9455697533E4F3AEDEEDA8D1E29C
C4D890E7FDB4CCE39BD6EDA5CDE7A0D0EAA3CBE6A1CAE39FD0E19DDCEBA6DAEBA4CADE96
C3D990CDE39ACFE69EC9E098CAE19DD8EFABD6EBA8AEC37E9CB0699DAE67CBDB92DFF6A8
C7EC9EBFEE9EBBF0A0C0F1A2C5EBA2D4E9A8C1C0889D905CAC9A68D2C590E1E2A8DFEBAB
CBDF9A99AA64545D1ADFE6A3DDE8A68F9B5999A865AEBD7A6E7D386879339BAC658BA055
A2B86DC8E394CCE999CEEF9ECFF2A2C4E999C6EB9DB9DE8ECCEC99DAF7A5CEE698CCE299
C7D796D6E1A5E0E9B4EEF4C4F4FBCFF5FDCEDAE6B4CEDFA8D8EEADC4E096D7F6A6C5DD8F
9AA360565819E2E7A7CDD695CEDA98DAEBA7CADF9AD7F1AAD7F5ADCDEDA4C6E89EBBDF95
C2E69CC2E69CC8ECA2CBEBA2CAE098DCEBA6E7F4AFD0DD98D8E39FABB672CAD5909CA762
9CA7629CA963C9D990E2F4AABFD489DEF4A9D1E79CB7D187CBEDA0C5EB9EBDE396C6EB9E
C5E79BCCECA1C7E79CCAE99DCCEB9FCAE99BC5E496C0E190BFE290C4E793C8EE99CCF1A4
BCDBA2D9FFCFA0DFA87DBC85C0EBB6C9E6AEC8DE9ED2F0A6B7EB96CDF8A6DFE5A5E4CE9C
AA7D566F4E25C6D39BD8FFBCCCF5AFC0EAA0B8E393CDF7A3BCE690CDF7A3B5DC8DCCF0A8
C6E4A6B4CF98C4DBA5D6EBB3CADEA1CDE19C7F9243394C0093A961657C364C631D90AA63
B8D48AD3F2A6C5E697D2F3A4CBEC9BC7EA98CFF2A0CBEE9CC5E896CAED9BC8EB99C0E295
CDEAA7CDE7A8C3DB9DD2E8A8D8EAACD1E1A2D7E3A5CEDA9A
C7E794B5D389CBE4AACFE7B7D5EBBDF5FFD8E7FCC3F7FFCDF5FFCCF4FFD1F1FFD9EFFFDE
C2D7B09CB484C2DC9FDBF4B0DAEAABCBD799596729889756CBDA97CADB95BBCC86DCF0A8
D9EDA5C0D68DCBE29A9AB169BED891CEE7A3CBE6A3D0E9A5D1E79FCFE39BC2D88FDEF6AC
CEE89ED8F2A9CAE69CDAF6ACC9E59BD1EDA3CEE89FDBF5ACC2DA90CEE49BE5F9B1C2DD90
C4EB9CC4F5A3B4EB98B8EF9EBDE99EC7E29DD5DB9F9F9861ADA26CEEE7B0CCD498D0E09F
E1F6B1869751545B18D6DB99D3DE9AC5D48FD3E09BE2F1ACC9D893E5F6B0E0F1AA485C14
A3B970CCE79AD1EDA0C5E697C3E696C6EB9BCFF6A5C7EE9BC4E692DAFAA7CCE999CDE79D
D9EEABE5F7B9C6D59CD6E5AEEFFDC8F9FFD3D1E3A9CCE2A2CFE8A4C0DC92C9E89ACDE599
979E5B565618DEE0A1E2E8A8D4DF9DD0DF9CCEE39EC8E29BB8D68EC5E79DD2F8ADD3F9AE
BEE79BBEE79BC1EB9FC1E79CCAE89ECFE99FCCE49ACCE299D7EBA3C5D991E3F4ADC8D992
CBDC95879B538FA35BC3D990ECFFBAC7E197C3DD93D6F5A9C4E699CBF0A2C4E99BD0F2A5
C2E297CFEDA3C5E399CAE69CCAE69CCBEA9ED1F0A4D3F4A5D1F4A2CAED9BC1E792BCE194
D3F5B8CFF7C297D19F447F4FAEDCAEC9EEBACBEBAABEE497BCF199B7E18DE7EEAB6B5724
734C25B99E73D0E2A6BAE29CCAEFA9B8DE95D8FDAFC5E896BFE18BCEEE9BDCF8ADD3E9A8
D8E9B3E4F1C3D5DDB4D7DEB2E0E4B1D5D99CAEB16ACDD58AE5F5AECFE59DC8DE95D6EEA4
D4ECA0C5E091BFDC8ACCE997BEDB89DCF7A6C8E392BFDA89D4EF9ED0E998C6DD8FC9E399
BEDE9BD1F5B5C2E5A5B8D897CBE9A9EEFFC9F5FFCCD6EFAD
CDED9ADFFEB2D9F5BA6D8555EFFFD7C3D7A6DBEEB6CADE9FD7EBACCBE0A7E3F6C896AB80
BCD3A5B8D39CC1DF99CCE89DCADF9CE2F2B1D0E3A1CBDF9ACFE39CE8FCB4CEE29ACDE39A
CDE39AD7EDA493AA62A7BE768AA35F8FA86490AB68869F5B8DA45C8AA05796AE64A7C178
C7E198CCE89ECCE89EC0DE94C8E79BC1E094C5E196DBF7ACC8E298CAE298D7EDA5C8E298
C3E598C9F4A4A5D987C5F9A7C5F1A4CCEAA4DDE7AA9B9A619D9860F0F0B4D4E0A0C2D792
D8EFA762762E9AA15DDBE29EDAE9A4DCF0A9CCDD97D0E19BCBDC96A7B87295A65F879B53
BED28ACFE79DCEE89EC9E598C9E89CC6E798C7E99CCCEF9FC6E595C7E494C2DE91BDD78E
CBE4A0DAF0AFC5DB9BD2E8AAD8EEAEDAF0AFCFE6A2D5EFA8C6E097C7E3998FAB60BAD087
B9C27FE2E4A5E3E8A8C9D291DDE9A7DAEBA7D9EEA9CBE69FD5F5ACC5E79DBDE197C5EBA0
BFE89CCAF3A7C9F2A6BFE89ACCF3A4C8ED9FC0E295CDEFA2CDECA0C6E599D7F3A8CAE69B
CEEA9FD8F4A9658136C7E69AB7D78BD3F5A8BDDF92CCEEA1C2E595D0F3A3C7E79BCEEEA2
BCDA90D2EEA4CEE9A2D6F1AAD0EAA3C8E49AC4E096C2E195C4E596C6E997CCEF9DCFF4A6
BBDE9EDAFFCCD6FFDC74AB83BAE8C1CCF6C6C7F1AFBEEA9BC0F397C7EB94D7D9985C4815
7352299C875AD5E9AAC2E7A1BFE09BC9E9A0C1E092D1EE9CDDF9A4C3DC8998AC64808E51
8991628C906B989778D6D3B0DAD7ACA19E67908C4CEBEEA7C5D991CEEA9FD6F5A9BFDE90
C8E99ACEEF9ED5F7A3C3E58FC9E996D0F09DC7E492CEE998D5ED9FD2E89DDDF2A7D4EEA7
BEE3A0D4FEBEC9F1B2BDE6A4CCF3B2E8FFCAECFFCBC4E5A0
C1DE8AC9E59AB6CE94F7FFDADFF0C4C9DBABD9EAB3D3E5A7C8DA9CD5E9AEBDCF9F7D9062
CDE5B1DBF7BACAE99BCBE896CEE59DC9DE9BC8DD9AD4E9A4CEE49CD3E9A0C9DF96D6EEA2
475F13536B21BCD38BC7DE96E1FAB6CBE4A0BFD896CDE6A2BED68CF1FFBE738B41486219
001A00C3DE97CBE69FCDE99FD5F1A6D0EC9FD3EEA1C7E295CEE69CCBE29AD0E5A0D6ECA4
B5CB82ECFFBBC0E597CCF5A7B4D88ECDE7A0DDE7A896975BD8D89CDBE1A3D5E8A6CDE7A0
D3EFA59AB067D5DF9ACFDB93C8E096C9E59AD0EAA0DEF8AEDDF3AB859B5362732DC9DA94
E1F2ACD4E59FCDE19AD4E8A0DAF0A8CBE399C1D890D1E99FD3EB9FC9E197E2F9B1DEF8B1
D0E9A5C0DB98C9E49FC9E49FD0EBA4C6E298CEE89ED5EFA5DBF3A9C1D89092A762BECF8B
CED995CED794CED995EFFCB7CBDC96C5DB93CEE89FCDE99FC2E297C1E196CCEEA2D3F5A9
CAECA0BFE195C4E69ACAF0A3C4F1A0BFF09EBCEB9ACBFAA9C2ED9DBCE797C0E99BBDE396
C2E89BCAF0A3B9DF92CFF8AAC7F0A2B1DC8DD6FFB2B2DB8CC8EB9BCAEB9CC0DF93CAE69B
C5E197D4EEA7C8E19DC3DC98D7EEAACEE7A3CCE69FCFEBA1CEEDA1C8E99AC6E798C7E99D
C2E2A1E0FFCFDBFFDE7DA88A8AB695ACD9AEBBECAAC8F9A7BFEC91D0EC97E1DD9D67511F
7C6136A49665D0E3A3D0F2A8C7E4A1E8FFBBD2ED9EBBD481D4EA9550631282924BE6EFB6
E8EDC4FFFFE4FFFFE88C886B0804005E5A2AD7D696DCE69FD1F1A6BFEB9CC2F1A0B4E490
C8F8A4BDED97C2F29CB6E48CCFFBA6ADD783C3EA99DCFEB1BAD88EBCD790D8F2ABBAD794
BDE5A6B6E2A3BCE8A9E3FFCFE7FFD1C4EDABBDE4A1BEE6A0
D8F4A0C9E497889D62768858BCCBA0A3B082AAB77F55632595A566CEDDA25E6F3B94A674
C7DCA4D2EBA9CDEA96D1EF99CEE89ED8F2ABCCE39DD4EEA5C5DD93D3EBA1D1E99D627A2E
C9E195D8F0A4BFD68EE5FCB4BFD894BED793D5EEACE1F8B4D6ECA3C6DC93D3E9A1CDE49E
C5DC9891AA6695AF68A2BE74ABC57BCAE596CDE899C5DD8FD8F0A6D8EEA6D2E5A3AFBE7B
ACB671737F372D45009FBE72E3FFB5D1E6A1C8D192B3B478B3B4785962234F66205F7D33
6D8D41BCD68CD8E59DE0F0A7CEEEA2C3EA9BC7EC9EB9D98DCAE69CD3EAA2BDD18AE0F1AB
9BAA65A2AF6ABDC886D2DD99D8E4A2BDCA858F9C578796518A9B557A8E4794A964CCE39F
D0E9A5C4DF9AD5F3ABC6E599C3E294CBEA9AD1EC9BC2DA8CD1E69B8FA05AC0CF8EDBEAA9
D9E8A5DBEAA5D5E6A0C5D992B3C9819EB86F5E7A30B0CE8493B167A6C47AC3E197C3E197
D8F4AABFDB91C3DD94C9E99EC1EC9CB7E896B9E897C0ED9CB9E494BFE899CCF2A5D1F6A9
CAEFA2BFE497CAEFA2A5CB7ECAF0A3C7F0A2BAE395D5FBAECAEB9CC7E494CBE79AD6F0A6
DBF5ACC5DC96A1B874849B57788D4C8197569CB36FBCD68FD0ECA2CFEEA2C9E89CC6E69D
C7E5A5E2FFCCEDFFECC5E7CFA9CFB6B7E5BEBBEFADB4E895C8EF94C6DA85D4CA8C5B4412
897246EFE5B2CADE99C2E096D2EBA7C7DE98C7DF91DCF4A0D4EA9591A452CBDA95DDE8B0
F4FCD5F3F7DCF6F8E2E7EACF9B9D78B6BA88E8EEB0CEDE97C0E49ABBE79AC7F6A6BBEA99
C0EF9EB0E08CC2EF9CC8F3A1BFE997C6EB9DD0F0A5CEE9A2D9EFAED5E7A9C7D799E1F3B9
D5EEB5D0EDB5D5F4BBEEFFD4EAFFD0C2E6A8C3E7A7CFF4B1
D3EB97BFD688DEF0B4ECFAC9E5F0C5C5CEA1E5EEB7D0DA9D99A567D0DB9F515E29D1DFAC
D1E3A9D5EAA5D1EB94C6E389CBE699C9E49DD9F3ACB6D288CCE69CADC77D688336D0EB9E
DAF5A8BED98CDAF1A9CAE199D7EEAADAF1ADCEE4A3B7CC89C8DC94D5E69FE8F9B3CBDF9A
D0E5A2C2D995D4EBA5CCE69D879F53BED688ACC476D9F0A2CFE39BC4D893D2E2A37F8849
9F9A5AE6E19FCED893A7B871C8DC95D1E09DE9EDB0B6B67A8C8D51A5AF70C6E099D6F8AC
BFE194E1FDB2CBDB92D0E59AC8F2A0BEF09BC7F4A1C7F0A1C8EA9ECEEAA0D2E7A2D7E8A4
D7E3A1D5DE9DC1C588898E4E8A8B4FB5B778C7C98AD9DF9FE4EDACC1CD8D7D8C4BCADD9B
CEE5A1CBE69FCCEAA0C7E899CCEE98D6F7A0C6E28DA8BF6DA3B36A8C9954CBD397D9E3A6
C7DB96CAE199D9F3AA809A517E9A50D0ECA2C8E69CD2F0A6C1DF95ABC77D8BA55C6A8139
CAE098D9EDA6E0F1ABC8DE96C9E89CC3E598D3F3A8CFEFA4CEEAA0CBE59CCCE39BC3D991
C8DD98CEE39ED9EEA9243B00CBE29CD0EAA3CEE8A1CBE79DCDE89BC6E192D9F4A7CDE59B
C8DF9796AB668EA360879C5BCFE1A3C3D897BFD594C7E09CCCE7A0C7E59BC8E69CCDEBA3
C4E1A1DCF7C4F4FFEDDBF2E084A79373A17DB1E8A7C8FCA9CDEE95DFEB97A19153967C4B
B19C6FD3CC98D6E5A2DDF7AED1EAA6D4EEA7BDD887DFFBA4668027CBE490D2E8A0C9DCA4
DDEDC6F8FFEAF8FFEFF8FFECDAEAC5C0D2A0C3D897CCE39BCDE8A3CBE8A5CCEAA4C1DF97
CEECA4D3F1A7D6F2A8CAE298D0E69EE5F4B1D3DD9E8D915692915B8A845254491B837B4D
D9D2A8F3F0C5F2F3C7E8F0BFD7E5B0CDE2A9D3EDB0C5E3A5
D5E897CFE195E2F2B4C9D8A1D1DFACDBE9B4CCDC9ED1E1A08A9B579FAF7059682FD8E7AE
CEDEA0DBECA6C9DC8AA7BD688BA15691A862BFD68EDAF4ABCFEBA18BAA5E7C984DD0ECA1
C9E399D2EAA0D2E8A0D3E7A2C9DA96D8E8A7CEDE9DA0AF6CD8E59FD5E09BC5D28DE0EFAC
D0E09FD9ECAAC8DD9AD6EBA6D3E9A1C5DB905D7227D2E49AD8E59FD9E4A2E4EEAF4C5013
9D9759E2DD9DE4E9A69DA864DBE8A3CBD493E1E3A4ABAB6F515216D5E09ED1E8A2C2E297
CEF0A4C1E094D8EEA5C7E197B8E290CAFAA6B4E490BCE797CBF2A3C7E99DD1EDA3C6DD97
C9DD98E2F1AEC8D391686E2E5E6323ADB272D6D899E3E8A8D7E09FD3DF9F687736D4E7A5
D0E7A3D0EAA3C0DC92D6F5A7CFEF9CBAD7839AB3608FA6568A9A51E2EEACD5DFA2D8E4A6
D7EBA6CAE199C4DE9598B46ACDE99FCBE99FC6E49AC6E69BCAE89ECEEAA0AEC57D5C722A
B7C882C4D38EDFECA7D4E39ED2EAA0C4E095D1EDA3C2DC93CBE29AD1E79FDAEEA7D1E59E
D8E9A3D3E49EC8DC97576B24CBE09BCADF9ADBF0ABCBE29AD4EC9EC9E291D6EEA0A5BB70
91A75E667B36A4B976D8EDACDCEEB0CEE2A3C9DD9ED0E6A5D3ECAACEE7A3CCE7A2D1ECA7
D4F1AED1EDB3F2FFE4EBFFE79FBBA2769E79B1EFAEADEA9AC6E595DFE399AB9059876537
998153F4EDB7C0D48FC7E59BC5DE9AC9E39CDAF9A980A44DA8CA73CAEC98C6E298D4ECB0
E3F6C8F4FFE2EDFFDFF1FFE3C4E0B0C7E4AADCF9B6CCE69FD0E5A4D0E0A1D4E4A5D9E9AA
D5E5A6CBDB9CCEDD9CDAE6A697A260767C3CA2A36768672E413C05857D4C90885995895F
80724DA99B78C2BA93D7D4A9D9DCADD3DDA9D8EAB0CFE3A8
DEEBA3CFDF96CFE39ED6EBA8C7E09CE7FFBDB7D78EC8E89DBDDD92D5F3A9C6E099CBE09B
D4E3A0E1ECA7909A51727A31DBE4A18B975572833F95AC66607E36C7E79CD0F2A6C2E297
CAE49BD0E69ED7E6A3CCD795AAB070939959ACB171D6DB9BBBBE7B969B58C0C784939C5B
D1DD9DCCDB9AD6E6A7CFE2A2CEE1A1DBEBAAC1CD8B909956C3C886CACC8BA1A060D5D595
D9E09DE3ECA9D7E29ECBD6947A8040C0C585E0E0A2A2A264989A5BDAE0A0D3E29FCCE39D
D6F1AAC3E398CBEBA0C0E296D0F2A5C2E799C3E89AC3EA9BC9F0A1C6ED9EC0E798C3E89B
C8EA9ECAE89ECDE79ED0E69ED3E49ED4E39ED7E29ED7E29EDCEBA8DCEDA980944FD7ECA7
D0E5A0CDE49ED4EBA5D5ECA4CBE399B0C87E8EA45BCFE59CCCE099D6EAA5C2D291E2F2B1
DBEAA959682590A45FD2E7A2D6F0A7C2E096C4E498C6E89BCFEFA3C5E498CEE89FD5EBA3
95A662C9D593DBE4A3D4E09ECFE69ECAE99DCAE99DCCE89DCCE89DCCE89DCDE79DCDE79D
C7E197CEE89EC6E298D2EEA3BBD78D9BB76DBBD78DD9F4A7D0E795D1E794D1E795D0E797
D0E799D0E69DD0E5A0CFE6A2CEE3A2D5E9AACDE1A4819558C8DEA0C2D79CDEF2B7CFE5A5
CEE9A2CEEFA8B7E1A1C1E6B0D5E7BDB1D2A38DDD98A9FAAEBEE3A09F9D64764D21AB7A51
876639F3ECB6BBD895C7EFA6CAE19DC1D69190B56888B564B5E493BFEA9AD5F5ACD2E8A7
D2E4A8CEE2A7CCE8ADC0E0A1C3E6A4CAEBA6C5E09BD8EDA8CBDA99DCE6A7D7E1A5D4DDA4
DCE3AD7F86527D844E3F470C283100727D3B929D5993A05BDBEAA7D5E5A4D3E3A5F7FFCE
C4C69E807D5A4F4F2966693E90936699A06D959C66969F66
D3E09AC7D790D4E8A0C8E096CEEDA1B2D487CDF2A4CCF3A4CDF2A4BFE194D4F0A5D7EDA4
DBEBA4D9E39E8B904DE8EDAAE1EAA9D8E4A2CDE19CD5ECA6C5E099D7F5ADC5E39BC7E19A
D3E8A38798544F5A186B7433B4BD7CE3ECABE2EDABD2DD99E3EDA8D1DB94E0EBA6899853
0D1E00DCEFADC2D796DDF3B2D0E4A5BBD08FCDDD9CCCD8965F6825EFF4B1494C07E1E8A4
D4E59FBED38EE0F1ADDDE9A75D6625949959DCDC9E9595579A9C5DE1E6A6D9E4A2D6E7A3
B7CE88D9F7AFCCEEA4D2F4A8CFEBA1BCD68CD3F2A6DFFFB3B6DB8DCCF3A4C3EC9DCFF8A9
C3EC9DC5EC9DC8EA9DC9E99DCCE89DCFE79DD0E69DD1E59DBDD18CD2E7A28FA45FD8EFA9
CDE29DDCF1ACC3D893C7DC97D3E8A3849954C4D994D7ECA7CFE49FD1E6A1DBF0ABC7DB96
C9D8976A7636CEDF9BD5EAA5C3DD94DBF9AFC5E79ACCEEA1CAEC9FC8E89CD0ECA2D0E69E
869753A7B270D7DD9FDBE6A4CFE69ECAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99D
D2F1A5D1F0A4C1E195CEEEA2D1F1A5C3E397CCEB9FC9E598CFE895D0E894CFE895CFE897
CFE799CFE79BCDE79ECDE7A0DDF4B0CBE1A0CEE2A3879B5CD9EDB0DCEEB2C4D69CD3E7A8
C8E69CBEE596CDFFB3C2EBA7CFDDAAB8D4A13C8D4A99EFA8CFF7BBC7C594A37750BE8862
6C4A1CDFDAA2C6E6A3C6F0A8E2F5B3D4E5A1C4E89EB7E698C4F7A8BCE89BC6E49CC8DC97
CBDA97D1E29ECEE9A2D0F2A8D1F5ABD1F3A9CFE6A0C9DA96D7E3A1DAE3A4E5EDB2030800
5D612F4A4E1CA1A371DADFA7DEE8A9D1DE99DAEAA3CFE39BCAE298B4D086D6F3B0F4FFD1
FBFFD8FFFFDCF9FFD4D3DBACCED6A3E0E7B1CBD39A9DA56A
CBDB94E8F9B2C8DE95DCF6ACCEEA9FD1F1A5B6D88BC6EB9DC2E497DEFEB2BCD68CCFE59C
D2E39CAAB771A1AB66C6D18CCDE29DCFE9A2CFE9A2C7E19ADAF1ABC3D893D8E9A5E8F4B2
98A1609DA665B1BC7ACCDB98D6EBA6CCE7A0C0E298C1E397C4E095CBE699D2EEA3C3E197
C1E19859783290AF69B9DA93CDECA8CEEDA7C8E6A0D2ECA5C6DD95879D54CFE499CBE198
CCE89ED6F1AAC7DE98C9DD98D5E19FD2DB9AAFB474757738AFB172D0D595D3DC9BDCE8A6
D8ECA7A8BF7985A059435F1598AE669EB46B9FB76DD0EAA0B4D387CBEB9FC1E396C5EA9C
C6EB9DC6EB9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DCAE99DDCF6AFC9E09AD1E8A2758F48
D2E9A3BED58FD1E8A2E2F9B3D6EDA7859C56EBFFBBD1E6A1C5DA95C7DC97D5EAA5CDE29D
8EA15FBED18FD5EAA5BFD992D4F0A6CDEBA1C2E296CEEEA2CAEA9ECAE99DD0EAA1CFE59D
8A9B578F9B59D6DFA0D8E4A2CDE79EC9E99DC9E99DC9E99DC9E99DC9E99DCAE99DCAE99D
C5E498CEEDA1C7E69ACAE99DCCEB9FC9E89CD0ECA1C2E193CAE999C9EB97CAEA97CAE999
CAE999CAE99BCCE89DCCE89ECBE59CC7DE96DFF4AF3E530E869A55D3E4A0D2E39FD0E5A0
CBEDA0C2ED9EBDEBA2D2F5B5CFDBA9E5FBCA8ED4957ECB87B7E3A8C5CC99B08A63D1A078
765A2AE5E3AAD4F1AEBFE39DC9D595A2AE6CC2E098C0E99DC5F1A4C0E99DCFE6A0DAE6A4
DAE3A2D8E3A1CFE49FC7E29BB9D990BFDA93D4E8A3D6E5A2DEEBA6D6E19F8F995C575F26
8B925EE5ECB8D8DCA9D1D9A0DFE9AACBDA95D8E9A2D3E9A0D1E8A0D0EBA4D7F4B2BFD99A
BCCF97D8E7B0DFEEB7CFDEA5CBDB9DDBE9ABDCEBAACEDD9A
DAEEA6CDE39ACBE399C8E298C0DC91D0EFA3CDECA0CDECA0D6F5A9C0DC91D1E99F849A51
60712A3F4F08E1EEA8E6F7B1D1ECA5CAEAA1D0EBA4C8E29BDAEFAACBDA97D3DE9C8B9151
E1E6A6D7E09FD3DF9DD2E7A2CEEEA5C6EFA3C3F4A5C8F9A8C6EFA0C4E999C3EA9BC4EB9C
D0F6A9B6DC91486E23D4F8AED5F9B1B5D98FC9EBA1D4F6AAC7E79BCBEC9DC8E799CFEFA3
C9EB9FCBEDA3CCEAA2CBE59EE0F4AFDCE8A6CCD5948E9353C5CA8AE2E7A7D5DB9BDAE5A3
D4E3A091A560E0F5B0CCE19CBECF89D5E69F99AA63D0E49CDCF4AACFE99FCCE89DBEDD91
C8EA9DC6EB9DC5EC9DC3EC9DC3EC9DC2ED9DC3EC9DC5EB9EC9E79FC8E39CCEE9A2BDD891
C8E39CEAFFBD1D3700C5DC965F76308EA55FD4E9A4BCD18CD4E9A4E8FDB8869B564A5F1A
879E5AE8FFBDC9E49DB9D48DD9F7ADC1DF95C3E296CAE99DCDECA0CAE69BCBE29AD2E8A0
9DAE6A909F5CDCE8A8CFE09CCCE89EC9E99DC9E99DC9E99DC9E99DC9E99DCAE99DCAE99D
C8E79BD0EFA3D0EFA3CFEBA0CBE79CCBE79CD2ECA2CFEEA2C6EB9BC5EC9BC5EC9BC6EB9B
C8EB9BC8EB9BC9E99DCAE99DD0ECA1C8E396D3EB9F97AD622B4000D6E89ED3E59BCDE59B
C9F2A4BFEBA0C7EFA9C6E2A7CED6A5C1D3A14F874A408141C3F0B5D8E6B1A4875DAC825A
705C2ADCDDA3CEE7A5C5E09BE3E9A9979D5DCEE59FC6EAA0C1EA9EC6E89ED5E6A2DEE4A4
E9EBACCFD494DAE9A6D9F0AAD3EDA6D9F0AACEDD9AD2DD9997A45E55621D445010D4DEA2
E3ECB5D3DCA5C5CE97E4EEB2CAD696DCEBA8D9EDA6C6DC94CCE39DCEE9A6C9E6A6C4E1A1
DFF5B5D1E6A5CDE2A1D6EBA8D5EAA5C8DE96CAE097D6EEA4
A8C2798DA75E8EA85FE2FCB3BBD58CC8E299E2FCB3C6DD95CAE199D2E9A11A300097AD65
D2E69FD6EAA3CBDF98B5CB83C2E098CDEDA4C9E49DCCE39DDFF3AEE1F0ADCFDA98757E3D
CDD695D5E19FDAEEA9D4EFA8C2E69CB6E295B5E899BFF3A1AEDB88CAF6A1C7F19FBEE798
CCF2A5CFF4A7BADF927B9D51BDDF95C2E498CAECA0BFE195D1F3A6C3E696C6EB9BB7DE8D
B0D98BC7F0A4CCF0A6B8D68ED2E9A3CCDD99CED997A3AC6B969B5BE3E8A8D8DE9ED1DA99
95A15FA8B774D5E6A2D1E29EE2F1ACDAE7A2BECB86D7E6A1DBEAA5CDDE98D9EFA7CCE69D
CAE89EC8EA9EC5EB9EC2ED9EBFEE9EBEEF9EBCF09EBFEE9EBFE399DCFAB2D0EEA6C4E29A
8DAB63B9D48DCBE69F87A15A95AF68C2DC95CCE39DE3FAB4D4E9A48FA45F7C914CD9F0AA
C3E19BBDDC96D5F5ACCDEDA4BFDF94D2F0A6CBEA9EC9E59ACFEBA0CBE59BCBE29AD2E8A0
9BAF6A8FA05CDAE9A8CDE19CCAE89EC8EA9DC8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99D
D1EDA2C8E499C8E499CCE69CD0EAA0D0EAA0CCE49AC8E79BC3EC9DC1EE9DC1EE9DC2ED9D
C3EC9DC5EC9DC6EB9BC8EB9BC5E496D4F1A1D0EB9CC1D98BCAE193BACF82869B4EB4D385
C4F3A5A0CF87B7D798DBEEB6DEE4B4EFFBCBEAFFDA4D80457BAD70D4EFB8B4A17686663D
716531DCE2A6CDE0A0D8E8A7DEDEA08C8E4FDCF0ABD2F0A8C6E89EC7E29BD6E19FD4D496
CDC98C8E8E5095A05E7D914C768B46718540343F003A430068752D889851D2E19ED3DFA1
E2EDB3D7E2A8D6E1A7D6E4A7DCEBAACBDC98BFD38CCDE29DD5ECA8CEE8A7C8E4A9D5F1B4
C4DF9AC5DF96C6E097CBE59BD1EDA2D4F0A3CEEB9BC5E494
8CA85EA6C278324E04C8E299DBF2AAD5EBA3C6DC94C7DB94D4E8A1889C55B9CF87CFE59D
CAE098CBE29AD0E79FE3FAB2C9E39CD3EDA6C5DC96D2E7A2CDE19C9AAB6798A965D3E4A0
D7EBA6D0E5A0C5DF98BFDD95C4E49BCAEEA4CDF3A8CAF3A5D5FFADBEE592C8EF9EC9EC9C
BEDE92C2E096DCF8AE89A35A91AB62D4EEA5CDE79ED1EDA2C3E294CAEB9CCDEE9DCCF1A1
D9FFB4C0E99DCCF0A6CCECA3D3EAA4DBEFAAE0ECAA838E4C989E5EDCE2A2DCE2A285904E
677331D6E5A2DDEEAACEDF9BCBDA95A0AD68DAE7A2E5F2ADC7D48FCDDC97D6E7A1D3E7A0
CDE79ECAE89EC6EB9EC3EC9EBFEE9EBCF09EBAF19EBCF09EC6ECA1B7D98FD1F1A8CBEBA2
CFEFA6D9F7AFBBD991DDF8B1C3DD96DCF6AFCBE29CC3DA94CDE29DA2B772D1E6A1CBE59E
D9FAB3BFE59CBDE197D3F5ABC5E59ACCEAA0CFEBA0CCE69CCEE89ECFE79DD3E9A1CFE59D
879C578A9E59CFE2A0D1E8A2CAE89EC8EA9DC8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99D
CBE79CC4E095CFE99FCEE89ECEE69CCEE69CC7DF95CCEB9FC3EC9EBFEE9EC1EE9DC2ED9D
C3EC9DC5EC9DC6EB9DC6EB9BCBEC9DBFE091C0DF91DEFDAFCBE79AD3EFA4AAC67B668B3E
12480031641FE4FFC5CAD7A2CFD3A1EDF5C4D3EBB7D5FCC5194D0FBCDFA7D8D1A3705B30
706F39DBE5A8CEDD9CE1ECAA989457615F22CDDE9ACCE7A0C8E69EC9E09AD9E2A1C4C285
8680447A783B9DA665899A568CA15C9BAF6A828D4BB0B976E2F2A9D6E89CC8D993CBDC98
C4D496D0E0A2D5E5A793A3648999587B8F4A9DB36BC4DB95AEC484C2DA9ED3ECB5C2DBA2
CBE6A3D1ECA5D3EFA5CDE99FCBE79CCCEB9DC9EA99C4E594
C4E298D1EFA5607C325E782FD9EFA7C3D790CFE09ADFF0AAD8E9A3A5B670D8ECA5D4EAA2
CBE29AC9E39AD5F1A7C5DC94DBECA8D1DD9BD7E6A3DBECA8BCD08B718842738E47CEEEA5
BADC92C6E89ED0F0A7D3EEA7D6EBA6D7E8A4D4DF9DC8D792BED88EC5E496DBF6A9CDE599
DBF0A5D2E29BD4E19BB2BD78939E59D3DE99CEDB95D5E59CCCDE94CADF94DAF2A6C1DD92
BEE094C8ECA2BBDD93BBD68FD9F0AAD4E5A1C8D794B0BB79A7B270E0EBA9D5E09E97A361
8D9C59C3D792D1E6A1CFE49FDAEEA7C0D18BB6C580D3E29DDAE7A2E0EDA8D3E29DD1E29C
D1E59ECDE79EC9E99EC6EB9EC2ED9EBEEF9EBBF09EBEEF9ECBF4A8C2E69CD1F3A9C2E49A
C7E99FCEEEA5BAD890C7E59DD1ECA5CAE59ECFE9A2D0EAA3D2E9A38DA45EE0F5B0CFEAA3
C2E69ED5FFB5ACD589CBEFA5CFF1A5C2E096C9E59AD0EAA0D1E99FCFE59CD4EAA2D0E69E
839853A0B570CDE29FD1EBA4C9E99EC6EB9DC8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99D
D0ECA1CEE89ED8F0A6C6DE94C5DB92D7EDA4D5EBA2DBF7ACC5EC9DC2ED9DC3EC9DC3EC9D
C5EC9DC6EB9DC6EB9DC6EB9ECBF0A3C9EEA1DAFEB6A4CA81CAEFA9BEE39EBEE6A05E8D47
002200002000859C66DBE2AFE8EFBCCCD2A2D7E0B1F2FFD84D8045BEEBB0E5E8B94D4516
5E662DC8D698C9D492E0E7A4A7A366757537CFE09CC6E19AD0EEA6CFE6A0D5DE9D9C9A5D
50470CA6A265D7E09FD0E19DD1E6A1CDE29DCBD795EAF7B2C9DB8FD0E596CEE29ADFF3AC
E0F3B3CDE0A0CFE2A25C6F2D7488439BB169C7DC97C5DC98889E60A2B981CEE4B3DAF1BD
CFE7ADCAE2A4C9E2A1CAE5A2C9E49FC7E59DCFEFA4DBFBAF
C9E99ECAE89ECEEAA0849E5591A75FD7EBA4D9E8A3D0DF9AAEBD7891A25CD0E19BCDE39B
D3EAA2C7E399CAE89ECEE89F95A46178834199A56384935092A661BFD992D9F9B0C3E79D
C9EFA4CAEEA4CAE8A0CBE09BCDD695C2C083A3975D7A7436A4B46DD2EA9EB7CC81DDEFA5
D3E098D5DF98DEE3A0DDE09DD7DA97D6DB98E1E7A1DBE59ED2DE96E3F0A8C8DA909DB36A
7490465371298FAA63D8EFA9C8DC97D1E09DDDE9A78A9654B1BC7ACCD8965D6C29CDDE9A
CEE39ED2E9A3CBE59ECFE9A2CCE39BDBF1A92F450070843DD5E6A0D6E5A0D0DF9AD5E49F
D3E49ED0E69ECDE79EC9E99EC6EB9EC3EC9EC1ED9EC1ED9EC7EDA2C3E79DC5E99FC1E59B
CAECA2CBEBA2D4F2AAC5E39BCDE8A1C8E39CC8E29BD1EBA4D3EAA490A761CADF9ACAE59E
C3E9A0B2DC92D2FBAFD0F6ABB3D589D8F6ACC5E196D3EDA3D5EDA3CBE198D1E79FD5EBA3
91A862C2D993D2E9A5CBE59EC9E99EC8EA9DC8EA9DC8EA9DC9E99DC9E99DCAE99DCCE89D
D3EDA3BCD68CAEC67C92AA60A9BF76DAF0A7D1E79EC1DB91C9EA9BC8EB9BC8EB9BC8EA9D
C8EA9DC8EA9DC8EA9EC6EAA0C6ECA3B9E19BBFE8A6C9F6B5C4F2B481B1755D8F5477AE74
A7ECADBDF7BCA4BA89818757AFB784D6DEABD9DBACE5F5C488BA7FA9DBA0D4E2B1505221
818E56DFEFB0D2DB98DBDE9BD7D696969859C8DC97B2D088D0EEA6D4EBA5D1DA9979793B
645E22D9D79ADAE5A3CADF9AD7F1AACEE8A1D7E8A4CDDE97D4E99CD2E999CAE095D1E79F
C0D592B6CB8A6E8342CEE3A0CBE199DBF1A9CBE29CDCF2B1DEF3B8DAEEB9C3D6A8DDF0C3
E3F4C7E8FACAE1F3C1D2E7AFCDE5ABD3EDAECDE8A5BCDA94
C1DF97CBE9A1D2EDA6C9E09ADDF2AD415510768542CBDA978A995694A561CEDF9BDAEFAA
C9E39CC5E099DAF8B0C7E29B92A66151601DD5E4A1D3E29FCFE09CCEE39EDBF6AFC6E69D
C2E49AD7F5ADC0D791E9F4B2534F12635018805F2C604A114F5612E0F6ADC4D890D4E49D
DCE7A2D6E09BD7DD97E4EAA49FA25D999F595257145A641FCFDA95D9E6A090A0598C9D56
D0E49DD8ECA7C7D894556421D4E09ED0DB99DBE6A49EA967919D5B54632095A964B8CF89
DCF7B0BFDD95C6E89ECDEFA5D3F3AAB8D68EDCF7B0C9E39C465B16516520D4E5A1D6E7A3
DDECA9C1D28EEAFFBAC8DF99D0EBA4C4E29ACFEFA6C6E89ECCEEA4C6E89EC9EBA1CEF0A6
B9D990DBFBB2CEECA4CAE8A0CAE59ED2EDA6D0EAA3C7E19AC5DF988FA962DAF1ABCAE59E
CBEFA7C2EAA1C3ECA0CAEEA4CAECA0D8F6ACBDD98ED1EBA1D0E89EC0D88EC8DF97DAF1A9
667D37CFE6A0D5ECA8C7E19ACAE89ED1F1A5B9D98DD2F2A6CBEA9EC5E498C3DF94C9E59A
D0EAA0859F55D5EDA3CBE399D1E99F566E24798F46DDF3A8D1E99BD2EA9CC7DF91C7E295
D5EFA5CBE79DBFDD95CAEBA6CDF2AFB5DFA0BEEBB2BBEEB683B9877AB4847EBC8DACEEBE
A5F0B8AEEAB4D2E9BBD9E1B257642F545E2AD4D3A3D6E2B0BCE9B08EBF87CDE3B2596535
485A20CBDB9CF0FAB5CDD08BE3E3A3939C5BD0E7A1C7E99FC7E99FC9E49DCFDB999FA162
565417DBDD9EDBECA8C6E099D1F1A8CBEBA2CCE69FCEE49BD0E89AD2EB9ACDE599D1E8A0
DDF4AE455C1890A763D2E9A3CFE69ED0E79FCBE09BDCF1B0CFE2AADAECBAD1E2B6515F3B
FBFFE6F9FFE4FBFFE4DBEAC3C4D5A8D4E8B5CEE3AAD5EDAF
D2EDA6D2EDA6BFD992D9F0AAC9DE99D1E5A0899A5697A8648B9C58AEBF7BD6EAA5CFE49F
CDE7A0D1ECA597B56D5E7C34ADC881C7DE98D0E49FD9E8A5C9D593EAF6B4BBCA87DFF3AE
D9EEA9BFD38E818D4B7274358F8349B09560B28A59735521515815D6EDA5C4DB93DFF5AC
CDDE97D9E9A2D1DE98CBD890B0BC74A6B26A929F598E9B558D9D568596509CAD67D0E19B
D5E4A1C7D391ECF7B5B8C3816C7534828B4AB0B978626D2B6D793790A15DD3E8A3D5EFA8
CDEBA3CBEBA2CCF0A6BEE298BFE197C4E49BC9E79FCEE9A2A9C37C95AA65A4B8738DA15C
899A56AABB77BDCE8ADBEFAAC8DC97D7ECA7D1E6A1CAE49DC8E69EBEDE95D0F0A7C6E69D
CBE9A1CAE8A0C3E199D6F4ACC6E19ACFEAA3C5DF98DCF6AF92AC65C6E099CFE9A2C6E19A
C4E59EBFE39BC4E89EC0E298C3E398D1F1A6C2E195D2EEA3CDE79DD1EBA1CFE9A0C4DB93
859C567E954FCDE29FDCF3ADDEFAB0A8C77BE1FFB4C5E498C5E498D2EEA3DAF6ABC8E499
647E34728C42CFE79DCCE49ADFF7ADB7CF8596AE648DA3589DAF63D6E799EAFAAFCDDF93
C4D98ED5ECA4D5EFA8C2E19EB5D99BD8FFC788B8844B8150437E52A9EAC2B8FCD7A5EDC5
3E8C5C52905FA2BD92D0DDAFB6CB9395A66FD4D6A5D6E0AEC5EEB66E9D67809D6D8B9F6E
4D6028D1E1A2D4DE99E0E6A0D5DA988E9A58D3EEA7BEE298CCF2A7C8E89FD7E6A3999F5F
636325D3D999D6EAA5BCDA92C4E89EC1E79CCAEAA1D2EEA4D4EFA0C4DD8CCEE69AC1D890
516822BFD692E0F7B1C8DF97D4ECA2D4EAA1C1D78FC7DA9ACCDDA6E9F7C6FBFFDFF0FAD8
CCD1BBFEFFEFFCFFEAE9F2D5EBF7D3E1F0C5C8DAA8CDE0A9
C9E09AD2E9A3D0E7A1CADF9AD1E6A1CFE49FE5F9B4C9DD98C7DB96D4E9A4C0D590D5ECA6
BED891D0EBA4829D5683A35AC6EFA3BBE196D7F2ABD8E7A4ECF1B1D8D699EEEAADDAD89B
DCDE9F56581997995AD1CD90D8C990EAD19BF6D5A26D5821768240C9E9A0CDEDA4C4E499
C5E399C7E69AE3FFB4CEEA9FC8E499BBD78CC3DD94D8F2A9D9F3AACBE59EC8E29BD3E8A3
D0DC9AEDF6B5C3CC8BD3DC9BE6ECACA9AF6F485110636E2CCBD795D2E19EC4D893D1E8A2
CCE7A0C9E79FCAECA2D4F6ACCFEFA6DAF8B0C2E098C0DE96D3EEA7CFE9A2D2E9A3D8EFA9
D6EBA68EA25D50611DCFE09CEAF9B6D0DC9ABFCB89E9FAB6D0E7A1D4EFA8C9E49DCCE7A0
CAE59EDAF5AEBED992C4DF98D1ECA5D0EBA4C5E099CBE69F4B661FC8E39CC1DC95D7F2AB
D0EBA6D2EDA8DBF6AFC7E59DC5E59ACCECA1C6E69AC7E79BD1F0A4CBEA9ED0ECA2CEE89F
DDF4AE9CB16CC4D795D0E5A0C3DD94D1EDA2C4E095D7F3A8C6E297C6E096BCD68C526C22
D1EBA1CAE49AD3EDA3C1DB91C6E096E0FAB0CCE69CCCE2979FAD62A2AE62BCC87ED8E69B
D7E79ECDDE97CFE4A1D4EEADC0E2A5CBF4BC0C3C0A0016000026003A7C583D846207512E
39855E001800CCECC3DDF3C4D1EEB4C2DC9FC5CE99CFDBA9CBEBB983AB7967885995B180
455820DCEAACCEDB93D8E49AD5DE9B94A360D4F2AAB8E195CEF7ABC4E69CD4E5A1909958
656728BFC887DAF1ABC9EBA1CCF5A9C2ECA0C3E79DC6E69BC0DB8ED9F1A3DCF4AA4A6119
CCE69FCFE8A4CDE49ED9F0A8BED48BD6ECA3DDF1AADCECABE0EDB5E6F2C2F5FDD6FFFFE6
D9DACAAEAEA2FFFFF1E8ECD5FEFFE6D2DCB7D4E1B3D5E6B2
D6E7A3C9DD98CCE09BCEE39EDCF1ACBFD690CFE6A0C7DE98D8EFA9C5DF98DBF5AEC1DB94
D7F1AA92AC65B5CF88C2E299C4F0A3B9E397C3DE97CAD694D3D194E0D69BF4E8AE7F7339
625C20706E31CDCD8FE5E3A6E1D79CF5E2AAA88D5858470F91A05FCAE8A2D2F1ABC7E99F
CBEFA5C0E598C6EC9FBBE293CAF1A2DCFFB4C8EA9EB8D88FD0EBA4D3ECA8C6DC9BD1E4A2
DBE7A5D5E09EE2EDABDAE3A2D3DC9BD5DE9DC3CC8B858E4D9CA765DFEBA9D5E4A1CDE19C
CADF9AC9E09ACBE59EC6E099C4DB95CDE49ED2E9A3D3EDA6CEE8A1C7E29BC9E49DC8E39C
BBD58ECCE39DABC07B9CAD69C3D28FDDE8A6E6EFAECBD795CDE19CCEE59FC7DE98DEF5AF
CCE39DBDD790D3EDA6D4EEA7BDD891D4EFA8CFEAA3849F58435E17CEE9A2DBF6AFC4DE97
C3D694C9DC9AD6EBA6C9E39CC6E49ACAEA9FCDEFA2C2E799C2E497B7D98CD0EEA4C5E197
C2D993AEC27D9FAF6EC5D692D5EBA3DEF6ACCDE59BD0E89ECFE79DD7F1A792AC6288A258
D1EBA1C2DC92C9E399D3EFA4CDE99ED2EEA3BFDB90D4ECA2CDDA9297A158909C54BECA82
D4E199D1E19AD2E6A1D2E8A7CAE8AABAE0A7ACD8A5669A6A286239488863357B57A3EAC8
A2ECC97AB893B1D7AEC0DDAD8AB27496B97990A36B53612ECEE6B6BFDEB291B788759765
475A23D9E5A7D9EB9FD1E495D9E49F97A663BEDE95BCE599C9F2A6C4E69CD1E29EA5AB6B
555718919A59C8DF99C2E69CC9F3A7C3EFA2C6ECA1C9E99ED1EBA1C7DF93879E56C3DA94
CEE5A1D5EEAACDE49EC7DF95DBF1A6D4E99ECEDF98C1D08FD3DEA6F3FBCCFAFED9FFFFE5
FCFDEBF2F3E3A6A893E1E5CCFEFFE4E5F0C8E5F2C4CDDBA8
B0BA7B6D79399FAE6D6A7D3BC8DD9AE0F9B5C0DB96DAF8B2BBD993D4F2ACC5E39DCEE9A4
8DA662839A56C6DB98D0E9A5B9DF94E2FFBDDFF6B0DEE7A6EAE4A898895086773E7B7136
8F8D50E2E7A7E6EFAECAD090F0EEB1E5DBA0624F17AFA26BAFB97CD5EBABC0D998CDEAA7
C5E69FD0F6ABB8E193D4FFB0A8D183CAF0A3CBEFA5C0DE98CDE6A4D3E6A6CEDEA0D7E5A7
CFDF9ECFE09CE4F5B1C4D390CCD896DAE5A3E9F2B1B3BC7B97A05FD9E2A1DFE8A7D6E19F
E1ECAACBD795DAE6A4E2EEACDBE5A6D6E0A1D6E2A2D1E1A0D0E5A2D0E9A5C9E7A1C7E6A0
E1FFBACDEBA5CBE4A0A4BB77D5E5A4D7E3A3D4DE9FD2DC9DE1F0ADCBDC98D5E9A4CCE09B
8BA05B3045008FA45F9BB26CB5CF886F89425A752E7C9750C3E199D2F0A8CEECA4D0E7A1
E0EAABDCE5A6DCE8A6DAEEA9CAE69CC7E79CCAEFA1BDE495CCF5A6C2E99AD8FAAED2F0A6
C5DC96D4E5A1A9B575909C5AD0E19BC2D68ED6ECA3C7DD94CFE59C8EA65C8FA75DD3EBA1
CFE99FCBE59BD2EEA3C5E498C7E69ACBEA9ED0EFA3DBF5ABD4E8A1D4E39EC1CE8899A660
99A660D0E099E7F8B2C0D590D0EBA8CAEAABBFE6ADBFEEB8B1E5B4A8E1B4BAF7CDBDFED6
498F6DA2DFBECFFDD676A06E002B000D3A00CDEBAD899E66AAB98EDDF2C9B2D9AC567C4B
505E29CFD99CD3EA9CD8EF9DD6E19C939F5D98B66EC5EBA0C3E99ECDEDA4D6E5A2CED393
8F8F519AA060D2E9A3C5E79DC1EB9FBDE99CC5EBA0CCECA3CBE59CD5EBA36C813CD2E9A5
D2E9A5D0E7A3D3EAA4D3EBA1CEE499C4D98EDDEDA6E0ECAAD3DBA2E8EBBCFFFFDBFFFFE3
FFFFE8F7FBE0FFFFE4F4FCD7A0A87FC9D5A7FBFFD4D7E8B1
777D3F495213525E1E0F1F009EB370C4DD99D4F3ADBBDC95CBECA5CDEEA7C9E8A2C4DF9A
94AD69879C59DAEAA9D3E6A4D3EEA7CDE7A0B4C07E97995AB3A96E6A5E247B7237C8C88A
DFEBA9D1E5A0CFE6A0C6DA95DFE8A7B1AD70615018E0D19ADDDCA4D6DFA6D9E7ACC7DB9C
CEE9A6C4E39DB9DD93C5EB9ED6FCAFC5E79DCFEDA7DAF0AFCDDB9ED5DDA4E7EAB3DEE3A9
DCEFADC0DA93C7DE98DDF2ADDFF0ACD8E7A4C8D391AEB776A1A767CACF8FDBDD9EDBDD9E
DEDEA0A8A86A909052949255E2DDA3E3E1A6DCDDA1CBD596D4E4A3D1EAA6BDDC96CBEFA7
B7DB93BFE39BCFEEA8A1BC778DA25F96A6658C9858A1AB6CD0DC9AD7E6A3DBEAA7C6D793
7A8B4780944FCBDF9ACDE29DC1D892E0FAB3D8F3ACCBE69FD1EFA7BBD991C9E79FD4E9A4
E4E8ABD2D296C2C888E3F2AFCCE39BC7E79CC6ED9EBEE999BEE999B8E393BADF92C6E49A
DBF2ACD6E5A2C5CF905A6322CCD994E2F3ACDBECA5D5E9A1ADC1798EA45BCAE097CCE49A
CBE59BC5E196D1EDA2C6E599D2F2A6C2E296C2E296B8D68CC9E09AE1F4B2DEF2ADB1C27C
8C9C559EAE67C6D68DD2E69ED9F0A8C6E19CD3F3B2C0E8AAC2EFB4BCEFB7B4E9B387C294
70AF90ACEBCCA2D6AF386A35548D494D823AB5DE9CCFE8AF6D744BD3DFBBBAE3B7426C3A
434F1DDBE3A7CCE796C8E591DBE6A198A36186A059CDEFA5C0E49AD1ECA5D6E19FE3E3A5
B4B275969B5BDBEFAACEEEA5C6EFA3C0EA9EC5E99FC6E69DCFE69ED6EBA67E9350D0E5A2
C3D998D8EFABC6DD97DBF1A8CADF94B9CB7FCBD890E2EDABDADFA7DEE0B1F3F1CBECECC8
E8EEC8FDFFDCE8F3C8C6D2A2DDE9B7A9B881E9FBBFC6DA9B
8D8E52EDF1B4D9E2A3D9E8A796AB68607B36C4E59ED0F6ADC2E89FCCF0A8C0E19ACAE8A2
A1B874CCDF9DCDDC9BD8E2A3D9E2A19A9F5F6D6B2E5B551952480DCAC689D4DA9ACBDF9A
BBDF95D0FAAED2FCB0B6D88EDAEBA7C9C98B705D25B19A66ECDCABD0C695EAE7B2E6EBB1
C8D496E1F4B2D6F0A9BCD790C3DE97C8DF99D7E7A6CFD79BA7A66E8F85528A794B77713D
98AD6ABDDF95D4F4ABCAE59EBAD18BD5E9A4D1DD9BAFB877989D5DDFDFA1CBC78A6B6227
463C0181773C8C804688794066551F63541D958C53A9AA6EA9B575C2D995C9E8A2C8EEA5
C9F1A8C5EDA4C2E89FCDEEA7C2DD98C8DD9AA0B06F828E4EB4BF7DBCC785D4DF9D95A15F
93A25FDFF0ACD9EDA8D0E5A0D0E7A1CBE59EB8D38CC8E39CD0EEA6CAEAA1CDEDA4CEE39E
8C8C50797339727234D3DE9CC6DC94CCECA1C6EFA0C8F7A6C2F1A0CCF9A8CFF5A8C5E59A
D1E6A1C6D592EBF1B3BEC484B4BF7BC9D992CADA9391A25B70813AD5E9A1D0E69DD1E99F
D8F2A8C8E499C5E196C8E79BD5F5A9C9EB9ED3F5A8D6F8ACC7E4A1C4DE9DCCE2A1D5EAA5
BFD38C93A55B91A156B4C67AC7DC8FDBF1A6BAD68CCDECA6D6FBB6B6E09EBFECAB8EC38D
A8E3C36CAB905E986FB1ECB6AFEEA8ACE89EBDEFAAD5F2B881815BC0C6A4C9F2C6568251
5B6533E4EAAECBEB98BDDF88DDE8A3A3A9698CA15CCCEAA2C6E69DD0E7A1D8DE9EDFDB9E
A9A367707032C7D693C7E29BC5EBA0C5EEA2CDEFA5CDE8A1D3EAA4CADE9998AD6ACCE1A0
D6ECABCEE5A1C2D792D1E79E576C1FA4B66AB9C67E9AA360696C33696838B6B18BDDDBB4
DBE5B1BECD94DAE9AEE6F8BCC0D294C4D998829754DAF1AB
E6E6AAD5D69AD3DC9DDDECABC8DD9A4A6822C6E7A0C0E69DC0E89FC9EFA6CEEFA85A7832
7F9652D1E4A2DFEBABDBE1A39E9E60514B0FE1D79CEEE4A9E5DBA0D7D799E2EEACC7E59D
C3F2A4B3EA99B8ED9DCCF6AACCE19CD3D39566531B6A4E1C664E22463406261A0079763F
030800C9D897CEE19FDAF1ABCFE49FD8E9A5949E6153541A6258256C5A2A61481F645826
475D1C63893EB8DC92D2F2A9D1EBA4D3E8A3D5E19F959E5DC3C586DFDDA0AAA16662561C
605118E8D79FEEDBA3E5D099E6CF9B6F5A256A5D265452171A2400708743D0EFA9C2EAA1
C1EBA1C0ECA1BEE69DD3F7AFCBE9A3C4DB97E0F3B1D4E3A2909B59596221D3DE9C566220
E0ECAAD1E29EC6D793DAEFAAD5EAA5C5DF98D7F1AAD5F3ABC3E199C0E097D0F0A7CEE39E
676228554A12555316DDE6A5D0E69ED2F2A7BBE696BDEC9BC2F3A1B6E594C8EEA1C1E196
D1E6A1E2EEACCFD597DEE3A397A25EDDEAA4CEDE979EAE67C6D790CEE29ADBEFA7D0E89E
C5DD93D5F1A6D2EEA3CBEB9FC5E599CAEC9FC9EEA0BADE94C8E7A4D2EFAFC8E2A1CBE29E
E2F8B0CFE4998A9A4F516214D3E695DAEFA0D3EB9DBCD88DC6E89ECFF5AC85AE6884B67B
538C6C001600BBF8CFA6E5AEB3F5AE81C1757EB36DC6E5AADFDDB7B1B292D9FFD68AB685
9AA271D7DB9EC8EA96D0F49CD4DE99A0A66693A762C7E29BD0EEA6D3E8A3E2E7A7DDD79B
EDE4A9959356DFEBA9CEE8A1C3E79DC2E89DCAEAA1CCE7A0CFE49FC8DC9793A867D4E9A8
CAE09FCDE4A0E2F7B2C6DC934E6014D0E193DEEBA3CFD895DFE2A9D7D5A5ADA88255532A
DAE5ADD0E3A3D3E6A4C9DC9AD6EBA6D4E9A4465D15CEE59D
pop
P
% End of image
1 0 0 r
.03 w
.0089 .61289 Mdot
.03557 .61521 Mdot
.06508 .60999 Mdot
.08286 .57867 Mdot
.09297 .55837 Mdot
.10105 .58099 Mdot
.11156 .59897 Mdot
.12368 .56243 Mdot
.12934 .53343 Mdot
.13096 .51081 Mdot
.15198 .48935 Mdot
.16612 .47833 Mdot
.15319 .51951 Mdot
.16087 .54909 Mdot
.16935 .51661 Mdot
.19078 .49457 Mdot
.20654 .47485 Mdot
.22311 .48993 Mdot
.22149 .51313 Mdot
.25019 .49863 Mdot
.29303 .51719 Mdot
.32698 .51545 Mdot
.36255 .49805 Mdot
.38397 .46557 Mdot
.40418 .45108 Mdot
.42479 .42498 Mdot
.44419 .40816 Mdot
.45349 .3722 Mdot
.45955 .34958 Mdot
.46359 .31072 Mdot
.47006 .2852 Mdot
.48299 .3258 Mdot
.49633 .35422 Mdot
.49633 .3809 Mdot
.49875 .41802 Mdot
.49026 .45919 Mdot
.50966 .43542 Mdot
.51977 .41106 Mdot
.53351 .3809 Mdot
.53715 .40468 Mdot
.53998 .43194 Mdot
.54887 .45861 Mdot
.55493 .4244 Mdot
.56948 .4447 Mdot
.58767 .45629 Mdot
.57959 .42498 Mdot
.58444 .37162 Mdot
.59979 .34146 Mdot
.63253 .3171 Mdot
.66284 .32638 Mdot
.71539 .33392 Mdot
.76065 .33276 Mdot
.8334 .34726 Mdot
.89443 .35712 Mdot
.93808 .3461 Mdot
.96031 .31478 Mdot
.98254 .34262 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.65873 0.031746 0.97619 0.349206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
D7EBA3CDECA0BCEB9BB9EA99CCECA3D3E8A3BCCF8DA7AB6E86723DA69760D6E7A3BCDC93
D2F0A6C6E49AC9E99DCEEFA0D4EFA2C0D68B94A35E99A3649BA368929A5FD9E7AACCE19E
C0DF93C6E997D1F7A4C0E190CAE298D8E7A49DA166575B1EADB77298A85FD0E19BD4E9A4
D0E9A7C2E09ACEEDA7C8EA9EC7EC9FC8ED9FC4E49BC2E19DD5EEB4D5EDBBF7FFDFDAF2C2
C9ECA8C3EC9DC5EB96CAED99CFEBA1D0E79FD1E79FD4E5AF00040000050095A775CFE99F
C5E290D1F2A1C3E29CC8E8A5B9D791D6EDA7DAE7A2CFD693C5C7865A5F1F707A3B95A366
CDDEA8D9EDBCC8DEB7C6DBBCE7F9E3B7BFB2676362F5EFF3FAF9FFF6F9FFFEFFFFFBFCFE
FBFBFDFFFFFFFFFEFFFEFCFDEAE8EB7373716869634C534170795C79855D9DAE7AC7D8A2
DCEAB7C3D19ED9E7B4CFDEA7DAE9B0CDDD9FC6D999D7EBA6D0E5A0D0E79FC4DC9297B167
A8C47A84A056D2F0A6C5E196D2EB9ACBE896C5EC9DCAF4A89DBE798A95596B5120B09663
D7E7A0C6E798C9E696C5E194D5F5AACBE9A3D0E6A8A8BE80A6C381BCDF9BC5E8A8DCFFC2
BEE1A7729458CDEBADD1EBAACFE49FDBEFA7D1E198DDEDA4C9DA93D2E6A1D7EAAACEE3A0
D1E79FCBE196CFE59DD3E9A1D7EAA8CDE09ED2E2A1D9E9A8ADBC79BDCC8BD4E1A9D9E5B3
EFF7D2EFF5D9FEFFF1FFFFF6AFA3A5D8CFD0F8FFFCF7FFFBFAFFF9FFFCF9FFFAFFFDF1F5
FFFEFFF9FBF8FFFFFAF5EFE1FFFFE653542CBED59DD5F6AFCBEC9BCEEB97C6DF8ED0E69B
D6E7A0869A539AB067C5E093CBEC9DC3E898CFF4A6BEE29AC0E0A1D6F1BCD2E5B8E3F1CE
000500F7FFEBFBFFE8F8FFDFD9EBB7D8EEB0C3DC98D0EAA3
CFE39BCAE99DBDEC9CBAEB9ACAEAA1D5EAA5C9DC9AC0C48794804B95864FD8E9A5CAEAA1
CEECA2CCEAA0C5E599C8E99AC7E295D7EDA2D3E49ECCD8986E763BB1BB7FDCEAADD5EAA7
D3F2A6D0F3A1BEE18FCDEC9CDBF3A9C9D895979D6194985DE9F2B1929F5A95A463C5D799
DDF3B5D0EAABCBE8A5C8E9A2C2E49ACDEFA3D2F2A9C8E7A3CCE5ABC9E1ADF3FFDDE9FFCF
C6E9A5C5EC9DC7ED98CBED99CDE99FCEE59DD0E49DD5E3AE010900000600AEC08ECEE69C
CBE896CBEA9ACCEBA5CFEEABDDFBB5C6DD97D7E29EE3E8A69CA15F565C1CDBE7A9C8D79C
D2E0ABD1E3B3DBF0C9F4FFEAF5FFF1D8E3D5FFFEFBFFFCFFFFFEFFFEFEFFFBFCFFFEFEFF
FFFFFFFFFFFDF5F4F2F7F6F4FFFFFDEDEEE9FEFFF6F6FEE9D0DBBBC5D4A9C8D9A3EEFFC8
C3D49E74824F3846110817006D7C41CBDB9DE8FBBBCBDE9CD4E8A3DFF5ADD6EDA5C8E299
D6F0A9C1DC95D7F2ABC9E59AD3EB9DC3E08EBBE293CDF7ABD3F7B1CDD89CB69C6B7C6531
B2C27BD6F7A8D1EE9ECBE79AC1E196BFDD97CFE5A7CAE0A2CAE9A6C8EBA7C4E8A8A6CA8D
6C8D54AAC98EC9E5A8D1EAA9D1E6A1C1D58D8C9E5499A96091A25BDAEBA7D6E9A9A4B777
849A52BAD08799AF678095506D803EA3B676AEBE7FD3E2A1B0BF7EAAB678CAD59DD3DCAD
F6FCD8F9FDE4FFFFF1CBC8C1EFE3E5FFF6F9F9FFFDEBF8EFF7FCF6FFFEFBFFFAFDFFFBFD
FCFAFBFEFFFBFBF8F1FFFFEF897F64A7A87ECDE5ABBDDE97C2E392D3F09CD5ED9FD4EA9F
A5B972BACE87D2E8A0C9E59ACBEC9DC1E696BAE192CEF2A8CCECABC2DDA6EEFFD3000B00
F0FAE1F5FFE6E1EFCCE4F4C7DEF1BAD4EAAAC7DE9AD8F2AB
CBDF97CAE99DC0EF9FBCED9CC8E89FD4E9A4D3E6A4D6DA9D9E8A55897A43D1E29ED0F0A7
C4E298D0EEA4C7E79BCAEB9CC9E497D9EFA4DBECA696A56499A468D8E3A7CDDD9FD1E6A3
CCE89DC2E392C8E998C7E494DAF0A7D3E4A098A064DFE4AACFD49AAEB67DAEB782CFDCA7
C3D4A0CDE1ACCFE8AEC2DF9FC6E5A1C8E7A1CCEBA5C3E29FCDE6ACCDE5B1EDFFD4DEF9C4
C6EAA4C6ED9EC8EB97C9E996CCE69DD1E79FD7E8A2DAE7B2000400020800CAD8A7CEE49B
D1EC9BC3E292CEEDA7CCEBA8C7E59DCEE49CD4DB98BCBE7D656B2B717D3BE5F8B8D0E4A7
D6E3AED0DBB0EBFBD7F2FFE9E4F7E1F8FFF6FFFEFBFFF7FBF5F3F8FFFEFFF4F4F6FFFFFD
F9F8F4EDEAE5FFFFF8FFFFF8E6E6DED7D9CED8DCCDE3EBD3CBD9B5DDEFBF97AB70778B4E
91A46C6D7E472334006F81472938006B7B3D657536D5E5A4D3E4A0B9CD88D0E5A0E1F8B2
C9E09CCBE4A0BFDA97DEF8B1CEE698D5F2A0CFF8A9BFE99DBEE29CC9D79AFFEBB9A7905C
899952CFF2A2C4E393D4F3A5CDEDA2D5F3ADD9EFB1C5DDA1C9ECAAC8EFACBFE3A5D9FBBF
315017BFDBA1D9F3B6C2D898D4E9A495A9615B6D238A9C5273843EBBCB8AB2C284718143
90A45DD6EAA2BED28DD5E8A6E4F4B6CCDC9E93A164D8E6A89EAA6CAFB87FECF5C0D9E0B4
DEE2C1F8FAE4FFFFF3C1BCB6FFFBFDFFFDFFF8FFFDE5F5EBFCFFFBFFFFFAFDEFEFFFFBFB
F7F6F2FDFEF6FEFCF0FDF8E45F5939C3C697D7F1B2CBF0A3CEED9DCBE695CEE69AC7DD94
A1B56EC5DB93D1E8A0CEEA9FC5E697D6FCA9C4EB9AC4EA9DC3E29FD2EBB1E4F6C4000900
F7FFE2F9FFE3F9FFDDCEDFABD3E7AABDD490D2E9A3C9E098
CEE29ACCEB9FC2F1A1BDEE9DC7E79ED1E6A1D2E5A3D9DDA0A7935E9F9059CFE09CCEEEA5
C2E096CAE89ECBEB9FCDEE9FD4ECA0CDE398CADE9780904FDAE8ABE3F1B4C1D395CDE29F
D3EDA3CFEE9ED3F0A0CDE899CAE09797A864919D5FDBE3AAF8FACBC9C79EB5B78FFFFFDD
EBF6CED1E0B5CCE0AFD4EDB4D8F4B7C5E4A1C6E5A2CBEAA7EBFFCAF4FFD6F5FFDADDF8C1
C8ECA6C6ED9EC5E894C7E492D0E79FD7EBA4D6E39ECDD5A2000100050800D6E2B2D3E79F
D2EB9ACAE797CAE9A3C6E5A2BFDA93D9EDA6DDE2A0A9A9696A7332B6C685BAD392D1E9AD
CDD9A7BDC59C75805EE1F1D6F2FFEFF7FFF6FBF6F3FFFBFFFDF7FBFEFCFFFFFEFDEEEBE6
FFFFF8FFFFF4848276B2B2A6B6B6AADBDFCEF4FCE5F4FFDFC2D3A7D9EEB6C7E09FD9F2B0
B1C789889C61A0B47787995D94A668354506233300102000000C00DEEEADCBDE9CC8DD9C
D6EAABCEE4A4E4FCBEB2CB89CCE498D0ED9BC7F0A1B8E497CBEFA9D8E6A9E6CF9D866F3B
95A65FCAED9DC1E090CFEEA0C5E59AC7E6A0C7DFA187A16481A663B1DA98D7FDC08EB074
B4D199D6EFB6CDE2A7D6EBAA617530D7ECA1CFE197CCDE94CEDF99D6E5A4BDCB90E2F0B3
CBDC96D7EBA3DFF3AECCDC9DC8D79CDCEAAFD0DEA39CA76D576027919862CED5A2D9DBB3
F8F9DAFFFFECFCF8ECDFD7D4FFFAFEF9F3F7F8FFFFF2FFF8FCFFFAF8F5F0FFFAF9FFFBF8
FFFFF8FFFFF4C0BFAD4B472EA59F7BE2E6B3C7E29DC4E99BC0DF8FD4EF9EBCD48A5C722A
859954CCE19CDAF1ABCCEB9FC8EB9BC2E996C0EA96D1F8A9D2F1ABC0DA9B33460F738354
E9F8CDE3F3C6CBDCA8CADCA2D5EAA9E2F7B2DAF1A9D0E79F
D1E59DCBEA9EC0EF9FBDEE9DC8E89FCFE49FCDE09ED3D79AA38F5AB4A56ED2E39FCCECA3
CDEBA1C3E197CDEDA1C7E899D1E99DCAE095CADE97AFC280D3E3A5D0E2A4D3E5A7D3E8A5
CDE79DD5F2A2BFDA8BCBE697B9CF865C6D29B0BE80D2D9A5FAF6D1C8BEA39D977DFEFEE2
E4E8CDCAD5B3CBDBB4CEE4B5CAE6ACBEDA9DD0EEAED5F4B1F0FFCFF2FFD4F4FFD8DBF7BD
C7EBA5C6EB9DC6E894C9E694D5EBA3D4E59FB8C37F959C69010100090901D4DDAED6E7A0
CAE191D5F0A1C8E6A0CCE9A7D2EDA6CEDF99CBCD8C97975795A05ECFE4A1BFDC9AD7F1B4
DAE3B46C71494C5634F6FFEAF2FFF3F5FFF8F4F0EDFFFBFDFFFCFFFFFBFDF6F1EDFFFFF6
D3CFC3A7A495A4A293F6F7E5FFFFEFFEFFEDF8FFE7E6F4D0D6EAB9D3EDB0C2E09AC6E49A
C7E29FD8F1B0E0F6B6CCE1A0C2D595A5B5748595545A69283948078E9E5FCDDD9FCCDEA2
CFE1A7C9DDA2D6EBB2DDF3B5D0E89CC7E794BCE596BCE89BD3F7B1D9E7AA8B74426A531F
BBCC85C7EA9AD1F0A0CCEB9DBEE094C0DF99D9F1B387A1648AB170C6F0AE85AB6E608148
E0FBC4C8DFA7D7EBB0AEC181BBCF8ACEE398D3E89DDEF0A6D9EAA6CBD99BD6E1A9D6E1A7
DCEDA9D1E29CCBDB9ACFDDA0DCE9B1DBE6AED3DEA6CED7A05C632DC8CC99E0E3B4D8D8B2
F6F5D7F5F0DDB3ACA2D7CDCBFFFAFFFFFBFFF4FFFCF2FFF8FCFFFAFFFCF5FFFBF8F3E6E0
F3F1E5909382706F5A9D9A7BE6E3B8DDE5ACCCEAA0B8DF8CDCFBABD1EC9DBBD28A829752
B3C684D4E9A6C6E099BFDD93C6E999C4EB98BFE995BEE594C6E69DCFEAA7223600C3D49E
DAEBB7C7DAA3CDE1A4E2F7B6C5DB93C2D88FCDE39AB5CB82
D0E49CC8E79BBCEB9BBCED9CC9E9A0D1E6A1CEE19FD4D89B94804B93844DCBDC98C6E69D
D4F2A8C2E096D0F0A4C4E395D0E89CCBE196A2B66F748745CEE0A2C5D99ADFF3B4D0E7A3
C5DD93C6E192D6F1A29DB56796AC639FB36ED4E4A5E1E8B5EBE1C6D8C8B8AA9E8EFFFFEF
FCFDEBFCFFECF9FFE6EAFCD2C2DAA8C8E4AAF0FFCEE2FFC0D6F3B3C6E2A7CEE7B0D0ECB1
C3E79FC6EB9DC9EB97CFEA99D8ECA5CAD994959E5B5B5F2D030000070400D1D9AAD1E19A
C4D98AD3EE9FC5E09BD0EAA9C7E19AE3F4AEA7A767535212B8C484C1D796D1F1AEC7E3A8
A3AC7D81835ED3DAB9F8FFECEAFFECF5FFF8FCF8F5FFFAFDFDF3F4FFFBF9F3ECE6DBD5C9
A8A292DEDBC8FBF8E5F8F7E2F9FDE6E6ECD2DDE8C6D9EAC0F1FFD2DCF9B7CDEDA2C7E79B
D2F0A8C5E09BB7D08ECFE6A2DAEFACD2E5A3D7E7A6D7E6A5CFDD9F879558A2B075C3D299
EDFCC5DAEBB5DDEFBBC9DEA3CFE79DCDED9AC9F2A3C1EDA0BCE19BC4D295604917AB9460
D5E69FBCDF8FCFEE9ECCEB9DD2F4A8D1F0AAD1E9AB7C96598FB8768BB8775B8144CFEEB5
C5DEA7CADFA790A268697C3CD6EAA3CFE499C8DD90C7DC91E0F1ADD8E4A6E4EDB6CFDAA0
D2E19EDFF0AACAD998DEECAFCDD7A2DFE8B3D4DCA9F9FFCCD7DBA9727443999A70D8D5B2
B1AD92D1CAB8FAF1E8FFFCFBFFF7FFFFFEFFF7FFFFF0FFF7F6FDF5FFFFF6FFF1ECB6A9A1
575548DCDFCCFFFFE8F8F5D2D8D6A6CAD296CAEB9CDAFFACBAD9897E994C889E56D1E6A3
D2E5A5D0E5A4C2DB97D2F0A6C6EB9BCEF5A2CDF7A1C4EB98C1E195DBF6B1C7D99BDAECB2
BED297DDF1B4CFE4A1CBE199CDE398D7EDA2475D12AFC57A
D0E49CC8E79BBDEC9CBDEE9DC9E9A0D1E6A1D2E5A3DDE1A4B09C675F5019CEDF9BC5E59C
CDEBA1C5E399D2F2A6C6E597D0E89CD0E59A92A65F566927DAEEAFCADE9FCFE3A4C7DE9A
D5EDA3D3EB9DCDE597849C4E93A960DFF3AECADD9DD5DDACFBEFD9BCA9A280716AFFF7EE
FFFFF4F3F6E5FBFFEAF1FFDDD6ECBDD6F1BAF1FFD1E5FFC3D1EEAEC0DC9FC7E0A7D1EDB2
C5E69FCAEC9FCCEC99CFE897D8E9A3CBD893949B58565827040000040000E4EABCDCE9A3
D9EE9FD3EB9DC4DF9ACDE7A6C2DC95D7E6A1929151635F20D6E2A2C8E19FCFF2B0C4E2A6
2F3708E5E5C1FFFFE6F8FFECF1FFF3E0F2E4FFFEFBFFF1F4FFFBFDEBE1DF433A33A0988B
FFFFEDFFFFEAFFFEE7FFFFEAFDFFE6E9F2D3D7E6BFDDF0C2F4FFD3E3FFBBCCEF9FC1E492
C8E89DDCFAB2D4EFAAD2ECA5CADF9AC5D994D9EAA6D5E4A3D5E1A3E9F4B8CFDAA0172400
7C8A55F9FFD6DBEBBAD6E9B1CFE79DC3E390C1EC9CC6F2A5CEF3ADDAE8AB66501EB09B66
DCEDA6C1E494C6E595C3E294D0F2A6C3E29C869E60526E315D87474F7D3CBAE2A4C7E6AD
D9F0BAD7EAB345571B95A566D1E59ED2E79CDCF3A5CCE196BECF8BE4F0B2C8D19A2E3700
586424142300566224E7F2B8C5CD9AD4DCA9F0F6C6FFFFD2E8EBBCD8DAAB95936C383313
A49E86FFFEEFFFFCF6F2E6E6FFF6FEFFFDFFF5FFFFF4FFFBFAFFF7FFFFF6AFA099AB9E95
F4F2E3FFFFEDFFFFE6E7E5BFE2E0AFE0E9A8D6F8A4ADD57DD4F3A3D5EFA5CFE49FDBF0AD
BDD090D3E8A7DAF3AFC3E199D3F8A8B3DA87C7F19BC9F19BCEEFA0B6D18ADCEFAFCDDFA1
D5E9AAC7DE9AD2E8A0D4EA9FD6ED9F1E3500DDF2A5C8DD90
D1E8A0CCEAA0C3EFA0C2EEA1C9E79FCEE39ED4E7A5E1EAABEADFA7494007E4F5B1D2EDA6
C8E29BCAE49BD2EEA4C7E398C9E497D9F1A7C6DD97CCE39FCADE9FCFE5A5B9CE8DC7DC97
CAE097D9F0A2617A299DB567C5DD93C7DE98D0E6A5D4E0AEEBE5CDE2D4CBADA39AEEE5DE
D0CCC3B6B6AAFDFFEEFBFFE8D5E4BBBED29FD8EDB4C8E0A2CFE8A7D0E9A8CDE5A9CCE6A7
CAE9A3CEEEA3CDEA9ACAE294D3E79FD0E099A5B1696F7642010100010000FFFFE1EFFDC2
F9FFC6D9F1A7CBE69FCFE6A2DCE8A8777C3C777336C2C282D7E8A2C9E99EBAE299C8ECA6
132000CACDA0DADEBBDAE3C6DCEBD6CAD6C8C1BDBAC2B8B7E0DBD5ECEADDF6F5E1FFFFE8
CBCBA9DDDFBAE5E7C2CDD1ACD4DAB6DBE5C0CEDAB2CFE1B1D7ECB1C5E099C3E390D5F5A2
C4E298CFEAA5C0DA91D4ECA2D4EA9FCEE499D8ECA4CEE29DD8EAAEC4D59FDAE8B77A875B
39461A6B764BB7C095CEDBA5D6ECA3C7E492C9EB9EC3E79DC7E29FD1DB9F695926A19460
C8DB99CDF1A7CBF0A3C4E89EC8EEA5C2E39E79915390A86CA3C384D8FBBBB9D89C7E9C60
5773387E965ABDD393CEE3A0C9DD96D7E99FCADA91D3E39CACB974808C4C6A753B6F7A3E
93A2618E9D5C5F6A2E606932BEC592ECEFC0EBECC0FFFED5EBE9C0CDCBA5D9D6B5969277
DFDCC9F2EEE3FFFAF6FFFDFFFFFAFFFCF5FDF9FFFFF8FFFBFBFEF3EAE8DB6D6656DAD3C0
FFFFE8E9F0CFECF1C9EBEEBFDADDA6D0DB99CBE898CCEF9B7A9649C3DD93D4EEA7C6DD99
DBF1B1C7E09FD2ECABBDDC98CDEFA5C0E598C8ED9F597B2E92AE64D4EBA7CEDE9FD7E7A9
CBE09DD2E9A3ADC37B8BA156869D4FBAD183C1D78CD8EEA3
C2E299CCEEA4BEE298C6E7A0EBFFC1EAFFBCCFE2A0D4E0A0E0E6A8505618D5E4A3CFE2A0
DDEDACDAEEA9C3D893C8DF99C9E79DCCECA1CDEBA5D5F0ADDDF6B5F6FFCCC5DA9792A65F
D9EEA3ABC071B1C876C7E08FCDE89BD2EEA4CDE8A5D0E5ADE4EBCAE6E8D3F3F4E4FFFFF4
FEFBF4B3B0A7969487BDBCA7797D5C9AA177DBE4AFB7C588B9C887586925DEEFABCCE19E
CBE4A2C8E39ED0EAA1D5EFA5D1E99FCFE6986E8632B1C387000400000109F8FFF3F0FFDB
F7FFD6C5DE9CD4EEA4CEDE97655823816D3BE3DDA3E2EBA8C0DD8DBCE78ED3FFA9B4E087
AFCA7DD4E3A2D7DBA9DBDBB7C1C3ADC4C6B9FFFFFBFEFFFBFAFFF0F9FFE8E8F7CEDEECB7
D0DEA0DBEAA7D4E0A2DAE5ABD4DCABDFE8BDEEF6CDE7F3C3D3E2A7CDDE97D0E691CBE38F
D5EAA7D1E6A5CCE299D4EA98C0D880D6F097CCE796CBE9A1C6E3ABD1ECC3C3D8B9F3FFE9
343E25A8AD8F8C8C68656937D0E19BD5EC9ED3E79FCDDC99DEE6AB95955F5B5525BCBE8D
D2E9B1C4EBACBFECA9C5F4B06B98535F8441526A2C4F5F21767E43757F42586A2CC1DB9A
CBEFA9C6EBA5C1E59DC8E69EC0D48DDFEAA57F8441555A17757C39D2DD99D0E19DD1E5A0
DBECA8D8E7A6D2DCA09EA66D90905EE1DEB1EFE7C2FFFFDFF4EBCECAC2ABD9D4C0D9DACA
E9EFE3F0FAF2F7FFFDF6FBFEFFF9FFFFF9FFFFF8FFFDFCF873736750523DBCBFA2E9EFC9
FCFFDAE8F5C0C8D59DDCE7ABE0EAABCFDB99D7E8A28AA258D7F1A7C5E498D3F1A9C0DE98
DBF8B6CEECACBDDB9DCFEDAFC6E4A6405E20001800395113CCE0A1CADA9CD9E4AAD3E1A4
6477358FA45FBCD18CCDE39BCCE39BCBE59CCDE79ECBE59C
C6EAA2D2F3ACC9E8A2CEECA6EEFFC3ECFFBED5E8A6D8E8A7CAD998515D1DDAE6A6D8E7A6
C7D695C4D493D3E3A2E0F7B1C8E89DC5EA9DC2E19BDAF7B5D4ECAEB0C688EAFFBE617530
C0D18AA7BC6FC1D886D7F09FD2EDA0CDEBA1C4E39DC5E1A4D2E3B6D2E0BCEEF9DBF9FFEA
F5F9E8FFFFF3F6F4E5B2B29A636444757B4FC2C995DAE6A8B0BF7C3B4C06A5B670DBF1A9
DDF4B0C5DE9ABCD68DCCE69CC3DE91BDD8877E9A43C5DE9D000A0000030CF1FEF5F5FFED
F7FFDDC6DBA0D2EAA0DFE9A26C5625AA8F62D5CF95CDDD96DCFFABCCFDA1B1E583D4FFA2
BFDF8ADCEDA6E3E8B0CAC79EBAB69DF5F3E4F7FAF3F4FEF3ECFFE3F4FFDFC8DFA7C9E09C
DCF3A5CDE391CBDB92D8E7A6DAE4B0F3FAD0F7FDD9E1E7C1CFD9A7C7D395B1C17697AA5B
889B5991A4647A8B44DFF2A3D8EE99CCE68FC2DF8FCFEEA8C9EAB3B7D6ACDDF6D6F5FFEF
000700696B55C8C2A83A3811DDEDAFBDD38BE2F1B0D3DB9FDFE2ABA4A6744C5423A5B584
C0DBA6C9ECB4AAD29684AE6F93BA7BBEDE9FB2CC8D8B9B5D8D91568F9356889756C4DD99
CCF0A6BDE398C6E89ED2EDA6EFFEB9D6DD9A707030A8A868B8BF7BC7D790DCF4AAC9E39A
C2D993CCDF9DCFDD9F9DA56C7C7B4B7E794FF8EDCDFFFDE3F7E8D5CDC1B1FFFAEFF1EEE5
F5FAF4F8FFFDEDFCF7F9FFFFFFFAFFFFF9FFFFF8FEFFFDFA95938455583DDAE2BBE0EEBD
EDFCC5CEDEA0E3F3B4D2E2A1C7D693DAE9A6AEBA7A91A25EC0DA91D1EFA5C9E9A0CAE9A3
BDDC99BCDA9AD5F3B785A2685F7B41657E455D723A8C9F67CCDBA2E1EFB4DDE8AED0DEA0
91A663AFC680CBE29CD1E8A2CAE49DCAE59ECCE7A0CAE8A0
C5E9A1D0F1AAC9E8A2CEE9A4E3FCB8E2F7B4D2E5A3D7E7A6B4C382596827CDDC9BE5F4B3
DBEAA9D1E1A0D6E6A5BFD690CBEA9ED2F2A7C9E7A1C8E2A1BCD498E4F9BEB9CD90CBDE9E
96AA6594A860BED587D1EC9DC8E497C9E79DC8E7A1CBEAA7C1DB9ED3EAB4D7EABCD8EAC2
F2FFE0F9FFE8FCFFE8F0FAD7D9E4B9DAE8B5D9E8ADD2E7A6CBE29CC1DB94BBD58E7E9851
7C964F97B16A93AB618DA55991A95DCEE794C4DE85D0E6A5000700010B14EFFAF2E2F2D7
E4F5CBD0E3ABC5DB939BA5605D4D19CEBA88F4F4B8CBDC96B2D885C3F199B6E78BC2ED94
D2EF9FCFDE99DDE0AB7E7C539F9E80FFFFEDF5FDEEF8FFF1EAFED9E4FCCAC5DDA1D7EEA8
D6ED9FCCE192E8F7B2BBC98EADB68BD5DCBBD3D8C1B9BEA7C5CCABDDE5BCD8E5AFCADA9C
CFE4A1D2E7A4C3D69487975695A662AEC17FCBE29EE0FAB9E8FFC8B5D298C8E3B0F3FFDD
36411F21230BECE5D39B9B7FD1E3B1BFD99CC9DAA3DCEAB5C9D6A1B0C18D556C3857723D
A0BD8796B17A889C67869761D3E4ADCFE4A9C7E3A6D1EBACCBDE9ED9E9A8DDF2AFCDE6A2
CFEAA3CCE69FD7EBA6D0DC9AC8CD8B919352686828DBE09EDBE8A2C5DB92D6F6AAC3E598
C9E99ED7F2ABD9EFAEBAC78F9DA3736A6841D1C8ABFFFDE8FFEDDFFFF5EBFFF4ECFFFDF8
F3F0EBE2E3DEFCFFFBF4F6F3FFF8FBFFF6FAFFFDFAAFAB9F777963CFD5B3FCFFDCE3F1BE
CCDBA2D9EBADD2E5A5C2D593D9E9A8A9B978707E40BBCE8CD6F1AACFEFA4C2E098CDEBA5
D1EEAC95B2723953162841075D753BC5DA9FD3E8ADCCE0A3D6E8ACCADC9EA6B67795A866
BED58FCCE69FD5EFA8CFEAA3C8E39CC8E69ECCEAA2CCECA3
C2E69ECBECA5C7E6A0C9E49FD6EFABD4EBA7CDE09ED3E3A2DAEAA94656154E5D1C92A261
D1E1A0CBDE9CD2E5A3E0F5B0CDE99CC5E196CAE5A0CCE5A4D8EDB4CDE0A9DCEDB7D5E7AD
CBDD9FBFD491D8F0A6D7F2A5C5E196C7E59BC7E79EC8EAA0C2E297CEEEA5C8E5A5CEEAB0
E6FECCE0F6C8E6F9CCF7FFDCBFD19DC6DBA0D4EDABD4EFAAC0DE96CCECA3CCECA3C7E59D
D0ECA2D4EEA4C6DE92D4EC9EC4DC8ED1EA97D2EC93D5EAA900050000070FF3FDF4CEDBC1
DAE9C0D8E9B2D8E8A78F9855605720A69D66C5CB8DDCF2AAD1F6A8BDE896C8F49FCCF1A1
D9F1A7C4D090DFE2AD565529B0B18FFEFFE8F7FFEBF5FFEAC8DFB1CBE4ABCAE3A1CEE59D
CAE193CCE196D5E5A49FAC775C6341CCD1BBFEFFF6FEFFF8FAFEEFE5EAD4D4DDBEDAE7BB
CADEA3E1F7B7E0F2B8CCDBA4D3E0AA91A069CADCA2F7FFCFEAFFC3E1FBBACDE7AACCE0AB
58643C000400FFFFF1FBFAE8F8FFE4F2FFDDE0FACBCDE9B9D2F0BEC1E2AD001000648149
C5DCA4DAE8B3E2E9B5D2D6A3E8F1BACCDBA2C3DB9FD0EDADD4F1AEBCDA94C7E29DD1E8A4
E0F1ADD7E2A0D3D898E0E0A26B6A2A5E5E1E929755DCE7A3CBE198CEEDA1C1E899C1EC9C
C0E99AC8ECA2C8E5A2D3E7ACE2EBBCD0D0AC918A70FFF8E9BDA9A0FFF6F1FFF9F8FEEFEC
FFFCF8FFFEF8F9F4EEFEFAF1FFFEF8FFFEF47875663D3C27DDE2C2FEFFDDD7E5B4D0E1AA
CBDDA1D5EAA9C8DB99CADD9BD9ECAA445413E4F4B5B8CD8AD2EDA6B9D990C6E49ECFEDA7
C6E19ED3ECABB5CB8DD9EFB1CDE1A4D9EDB0D7EBAECFE3A4C9DF9E70864589A05CDAF1AB
CDE8A1D1EFA7D3EEA7CAE8A0C6E49CC9E79FCCECA3CCECA3
C8EAA0CBEDA3C9E9A0CCE7A0D1EBA4D1E8A2CFE49FD2E6A1CEE29DCBDF9A9DAE6A475B16
455914728641A2B671C3D991C8E092D9F1A5D9F0AABED295D5E7B3D0E0B1CCDCADDBEBBA
F3FFCFD6EAADD9F0ACD0EAA1C3DF94CBEA9ECBEBA0C7EA9AC9EF98BDE58DCCF1A1D5F7AD
CCEAAADEFABFE8FFC9CEEAAFE3FDBEC1DE9BC6E49CCCECA1CEF0A4C8ECA2C0E49CCEF0A6
CCE89DCCE498C6DE90E0F8AAD2E99BCEE593D6EF94D2E5A3000400000107FBFFF8DFE9CE
E8F3CBC5D29DD7E5A7A1AC6A5D5E22DCE0A3D8E7A6C1DC95D2F7AAC2EB9DD1F6A9BEDC94
D4E7A5D7E1A5EBEBB9959468E6EBC3FAFFDFE4F8D3D9F2C8B8D39CDBF5B4D4EEA7BFD78B
DEF5A7D3E79FA2B176C5D0A5E5EBD1FEFFF6F8FAF9F0F1F5FCFFFFFCFFFDE9EFE5E5EFD7
EDFFD5C8DCABE0F0C1E2EEC0BEC79ABFC997828F5AFBFFD1F6FFCBC8DE9EC8DEA0D7E9B5
758159000500FFFFF1AEAC9FF4F9E5F5FFECCBF1CC99CD9F72AB7685B87F4A6D35697E46
929963A1A16BBBBB85DEE3ABCFDAA0D0DEA3CEDBA3CEE4A6CAEFA9C9F1A8CDEBA5CEE19F
D6DC9CE1DDA0B0A66B847A3F635B1D939353CBD692D6EAA3C2E195CEF3A5BCE797C0EF9E
BEED9CBDE99ABDE19BCCE5ABEEFBCFFFFFE36B6350A19088B7A29FE0C7CAFCE2E5FFF6F6
FFF8F4FFFBF4FFFCF3FFFEEFF5F2DFCDCDB57C7F62797F5DEBF3CAE1EDBDC0D19ADAEEB1
D3E8A7D3EAA6D7ECA9BBD08D899E5DC8DB9BD3E5A7DFF5B4C0DE98D3F3AAA3C17BC7E29D
D6EFADCADE9FCBDD9FDBEBADD4E4A6CEE1A1CCDF9FC7DE9AB9D38C87A25BA3BF75C6E49A
C9E79FCAEAA1CBE9A1C7E79EC7E79ECAEAA1CAEAA1C8E89F
C9EBA1C9E9A0CAE8A0CBE9A1CCE7A0CEE8A1D0E7A1D0E5A0D0E5A0DEF3AED0E49FCDE29D
CEE29D96AB66495E194A60175F7425D8EDA0C4D893CEE0A6CFDFAED0DFB4CDDCB3F8FFDD
EFFFD1C5DAA1C3DC9BC5E099C2E096CFEEA2CDEDA1C9EA99C7EE93C5EC8FC4EA93C3E696
C7E79ED3F2AED4F1AFC4E19EB9D791C9E79DD3F3A7B6D68ABADC8FCBF0A3CCF0A8C2E49A
C6E194D5ED9FD2EA9CCDE597C4DB8DD1E697D6ED93C3D392000600000005FCFFF4FBFFE5
FEFFDFE4ECBBDBE4AB858F50D4DE9FE6F5B4C3DA96CAE9A3CDF1A9B8DC94C1E09CE0F6B6
CAD89DE6EDB7CACA98D5D7A8F4FCCDF9FFDCCDE7B7C6E3ADD3EFB2CDEBA5D4F0A5D0EB9E
C7DF93C5D994A2B178EFFAD2F8FDE7FEFFFAFEFFFFFEFEFFFCFFFFF6F9FFF4F8F9F9FFFA
F3FFEFF5FFEAF1FFDCDEE8C3D2D9AFD2D8A897A06B7A854DFBFFD3D1E4ADD1E3B3D5E6BC
76815F273015FFFFEFABAD9FFBFFF8E5FAE9D5FCE161956E80BA88C5FCC3AED69AC2DA9E
565E234E4E1276743BE1E0A7D3D89EEFF9BDDCEAAFC7DFA1AED890C9F5AAD0EEA8D7E6A5
DCDA9DE3D79DAD9C646A5B229E985ADCE3A0D3E7A0D1EDA3CAEFA1BEE798C8F1A2C1EE9D
C8F8A4C5F4A3CDF2ACC7E3A9DEEDC2FEFFE4A79E8F5644405B4245F6DBE0FFF6FAFFF7F8
FFEBE7FFFBF1FFF6E779715A2C2D0D545B32D2DBB0D7E0B3CBD7A5E7F6BFD5E9ACCEE4A4
C7DD9CD8EFABBAD18D788F4BDBF1B0D2E8A7C5D99AC4DD9BD4F3AD001200001100BAD38F
E5FAB9C8DB9BDAE8AAD8E4A6DDE9ABCFDE9DDAEDABCAE19B446016809F53E0FFB4CDEFA2
C7E59BC8E69EC9E79FCAE8A0CCEAA2CBE9A1C8E69EC5E39B
CAEAA1C5E59CC8E69ECAE8A0C9E49DCDE7A0CFE9A2CCE39DC7DE98D0E7A1CCE19CD3EAA4
D7ECA7DCF3ADB1C882BAD0874D5E102C3A00D0DF9CDDEAB2D0DDB1D2E1BAD5E3BFF5FFDE
F7FFDDD3EAB6D1E9ADD4EFACCBE99FCDECA0C7E698C6E595C5E68DD2F39AC1E18CBDD98C
CFEAA3C3DE99BDD893DEF9B2D4F0A5D8F4A7CDEA9AD2EF9FD2EEA1CEEDA1C8E69ECAE59E
D5EDA1C3DA8CC7DE90D6ECA1DBEFA7CEE396D0E48DE6F5B4000300020305FCFFEFFAFFE1
DDE4BBDDE3B3C4CB956C783ACEE29DC8E29BC2E19BDEFFB8CCEFABCAEAA9203A00000B00
CFD8A3E1E5B39D9F6EDCE0AEE5F2BDF3FFD0CAE7ADC8E8A9D4F3AFB2D088C4E095D8F3A6
849C52A9BC7ABFCE97E5F1C9FCFFEDFAFFF6F7FBFEFCFFFFFCFFFFFCFFFFF6FBFEF2FAFC
F5FFFFE5F4EDF9FFF1D9E3C1FEFFD6E2E7B1CBD098A4AB77D9E4B9EBF7D3CFDDC3D9E7D0
EDF9E3F9FFEBFEFFEA46523CEDFFF793AEA591AC9BB7D5BBC1E6BDB7DFABD0FCBDBDE59F
CCE7A0BAC781948E508B81444D4409969A5FBFD394CDEDAAD6FFB9C0EAA0C1DA96E1EAAB
D8D2968C7D448E7D45968D52CBD08EDFF0AAC6E49AC2E79AC7EE9FBFE697CDEFA2C7EC9C
BDE994BEE999CDEEA9CBE2AAEEFAD2FFFFE8FFF9EF9B87865E4549A78C91B89EA1AB9391
D2BEB5A998882E220A837E5EA8B081F0FDC8C5D49DCCDBA2E0F2B6C4D899C9DE9DD6ECAB
D2E9A588A15DA2BB77B0C985D6EFADCDE6A497AD6D6B86435A7933678640CEE9A4D3EAA6
C1D492DEEDACDCE6A7CFDA98DDE8A6D0DD9868793392AA60D3EFA2D4F5A49FC572D3F8A8
CBE79DCBE59ECCE69FCEE8A1D1E8A2CFE6A0CEE59FCDE49E
CDEDA4C5E59CC9E79FCDEBA3CCE7A0CFEAA3D2EDA6CBE59ED6F0A9C9E39CCDE7A0D5ECA6
BDD48EDCF3ADCCE39DD6EAA2B3C174505B0F5C6627D7E1ACD9E4B9C4D2AEDBEBC7F2FFDF
F5FFDFC9DFAECAE3A9D2ECABCAE59EC9E59AC9E598D2ED9ECEE796CAE191D5EBA0D8EEA6
CDE2A1D5EAA9DAEFACC6DB96C4DA8FD9F0A2C2D989D6ED9DC8DF91CDE39ACBE09BD6EBA6
CCE297D7EDA2DEF4ABC4D891CADE99DCEDA6D1E38FCEDD9C010500020403DCDFCCDAE0BE
696E45545A2A505421475216CAE49DD8FAAEBEE298C2E6A0BBDB98D6F2B5102500919F6C
DEE6B5DADDAE979B69D3DCA7E9FBC1F1FFCBD0F0ADC3E7A1C4E39DD2F0A8C7E398D0EAA0
778E46B3C887D5E6AFE8F5CAFBFFE7FAFFF1FCFFFBFCFFFFF7FBFCF9FFFDFBFFFDF8FFFF
EBF7FFF5FFFFF6FFF7FEFFEAFFFFD9C5C795E8EAB8C1C799DCE3C2FAFFEEEFFBF1F8FFFB
F2FEF2FBFFF3E3EBD3828E78536A627E999497ADA1D2E5D1DDF5D3F1FFDDC7EBADC4E8A0
D1EDA2D1E699D9E09AE4E5A1757535585E1E7A8D4DCEEBA8BAE097D2F3ACD1E4A2ACB274
AAA4688A7E44DCD398E1E1A3DAEBA5BDDB91CFF5A8B8E394BBE293D3F5A8C7E197CFEA9D
CBEE9CC4E999C7E4A1D0E3ACFEFFDFFFFFE8FFFBEFDDC9C8B89FA2B9A0A3B49C9AC1AEA7
AC9C8CA49A81A29D7DD5D8ADD5E2AACBDE9ECEE1A1DBF0ADC0D592D6EBA8D8EFABCDE4A0
B2CB87839C58A7C07CD5EEAAD3ECAAC8E19F637C3B233E00A5C480C7E6A0CFEAA5CEE5A1
E3F3B2CAD694DCE7A5D6DF9CCED995A2AF698FA059AFC57AC0DD8DCDF09ED9FFABBFE290
CDE79ECEE39ECEE29DD0E49FD1E5A0D0E49FD1E5A0D3E7A2
CAE89ECAE89ECAE89ECAE89ECAE89ECAE89ECAE89ECCE89ECCE89ECCE89ECCE89ECDE79E
CDE79ECDE79ECDE79ED1E59DCDD88CA1A95E414A0BCFD8A3D8E3B8D1DFBBCDDCBBF3FFE0
F5FFDFCDE5B3D0E9AFC9E3A2C2DC95D3EDA3D0E89CCFE39BD4E19CD7E1A2D4DEA2DDE6AD
D1DAA3DAE3ACC7D195E2ECADCED994DBE79BD6E394D4E192DFEBA1D8E49CD1DC98DDE9A7
D1E29CCEE29BD9ECAAC9D99AD2E2A4E6F5B2CBDC8CCEDC9E000300010300979B848E946E
32380C49501D7D8450849255C8E89FD2F8ABC3E99EC9EDA7CAE8A897AF75637440CCD8A8
DAE0B2DCDFB08B925FDBE6AED9EDB0DDF8B5C5E69FBEE298D0F1AAC2E098CAE59ED1EBA4
778E48CADF9ED6E8AEDBE9B8E4EEC9F4FDE0FBFFECFCFFF1FBFFF3F3FCEBFAFFF0F7FFF9
EEFAFFF6FFFFF9FFFFFEFFEFFFFFE1D0D3A8D7DAAFB3B995D2DAC5F9FFFAF7FFFFF6FFFF
F8FFFFEAF4EBEDF4E2C1C7B92B3534F5FFFFDEF4E8BAD2BCE9FFDBF4FFD8E2EDB5D7E1A2
DAE79FD9F0A0B7D686C6E997A2C175324800222B00B3BB7FD3E8A5D3EAA6D0DC9C777B3E
646023BFBB7ED9DE9ED1E29ECCECA1C6F1A2C6F7A6BFEE9EB8DD8FD8F2A8CBD892DDEAA2
D2EA9CC6E194D2E5A3E1EBB6F1F3CCFFFFE6FFFCEFFFFAF4EBD6D3FFF9F6FFF7EFFFF5E5
FFFFE6ECEEC9D6DDB1D7E4AEC6DB98D7EFA5C9E197CDE49CD0E79FCDE49ED5ECA8C8DF9B
829B59D3ECAABAD391D2EBA9D5F0AD9CB7742B46035A7734C4E19ECAE7A4D8F1ADC7DC99
DBECA8DDE9A7C9D490DCE7A269742F707D35DBEDA3C7DE90CEEB9BCDEE9DC5EB98C2E394
CDE19AD9E8A5DCE8A6CDD997DEEAA8C6D290E1EDAB9AA664
CAE89ECAE89ECAE89ECAE89ECAE89ECAE89ECAE89EC9E99ECAE89ECAE89ECAE89ECCE89E
CCE89ECDE79ECDE79ED1E59DD1DC90E3E9A14046083A430ED6E1B6D7E6BFBBCBA7F5FFE3
EEFFD9D1E9B5C5DFA2C9E2A0DFF6B0D6ECA4BED28AE0EFAAA1A66CA4A7728284535A5C2B
4B4D1E6468363B4008222800535A16596116575F12555C0F525810494E0B646627969C5E
D1DD9DDCECADCFDEA3D7E4AED7E4AF49571C3F4F06879558000300000200D7DDC1CED5AB
C4CC9BE5EEB9DAE3ACDEEEB0BFE197C1EA9CC9EFA4BADB96334D0E1F3400CAD8A5E2ECBA
DCE2B4999F6F68713CD2DFA7D1E7A7CCEAA4C8EAA0CDF1A7CDEEA7C1E09ACCEAA2C3DE97
AEC783D2E7A6CFE1A5CEDCA7D9E5B7E6F1C7F1FBD6FBFFE3FBFFE4FBFFE4F9FFE4F8FFED
F8FFFFF8FFFFFBFFFDEFF3E4F4F6DED7DABBE8EDCF98A088C3CEBEE2EFE6EEFCFCD7E5E6
505C5C535C598489827D827CB6BEC0C1CBCCEAF7EEF9FFF3F5FBDFFFFFDDF1EFBEE9EDB2
CBDB94D2EEA1C4EE9CC6F3A0C1E699A2B9758B9056A1A2698F995C4E5A1A5C6526484C0F
C0C283D7DD9DDAEBA7CEECA4BDE899BCED9CBDF19FB7E696D9FBAED1E59DDDE4A0D1D791
CBDB90DDF2A7E1EDADCDD49EE5E3BAF2E9CCFFF8E5D5C3B7D6C4BAFFF2E5FFFEECFFFFE6
FFFFDFE6F3C5D9ECB5CAE0A0D4EEA4D4EFA0D5F0A3D5EDA3CFE69EC9E09A7F9652B3C988
D2E8A8C6DF9EDDF6B5D7F0AEBBD693546F2C97B471CCE9A6DEF9B6C3DE9BD8EFABC9DE9B
C2D38FC2D18C99A6605A672196A35BD0E097C7D98FCCE297D3EEA1CBEA9CD4F5A6CEEA9F
D9E8A3DFEAA8D6DF9EB9C482BCC584969F5EA0A968565F1E
CCE89ECCE89ECAE89ECAE89EC9E99EC9E99EC9E99EC8EA9EC9E99EC9E99EC9E99ECAE89E
CAE89ECCE89ECCE89ED0E69DE4ECA3D2D5909B9F64555C28F1FDCFF9FFDFF7FFE1EEFFD8
F4FFDCD2EBB2D1E9ABCEE4A3C9DD98D8E9A5D6E5A0CFD99A64643248451A4B481D646239
515024404213676A35D6DA9FDADF9DE2E8A0DAE096D8DC92E5E8A3D2D493929158565920
333C05CFDCA6D3DFAF546032424D229CA876E8F7B2B1BF84000500070D01D7E1BED5DFAD
F2FDC5C8D399D4DFA5CBDE9ECEEEA5C3E99CCCEEA45A77348CA262E5F7BDD2DFAADEE6B3
DCE4B38A925F99A670F9FFCFE3F9B9CCEAA4C8E89FC3E59BBFDE98D6F5AFBCDA94D6F1AC
90A967000E00DBEDAFD9EBAFD1E0A7CFDEA7CEDCA7CDDBA8CEDCABCEDEADCDDDACCDDCB3
D9E5CFE9F1E4FCFFF6FEFFF4FFFFF4F7FBEDFBFFF4778473000D005A6F60566C6092A69D
000402050D0FEAEBF0FCFFFFF4FFFF9EACAC76726FF9E8E0FFFBEAFFFBDFFFFFD6F8FFCB
CBE8A5C1E79CCEF2A8C7E6A0BAD090CAD99EE2ECB7D5DEA7DAE2A6D8DEA0EAF0B2959E5F
E2EDABCDE19CC9E49DBEE499C4F3A3C5F9A7ADDE8DCDF6A8BEDA8FCBDB94EBEEABE4E7A2
E1EFA4C9D990D4DF9DD7DAA3DEDBAEDAD2AEFFFEE3C2B29BAC9D88FFF9E0FFFFE3F5F9D4
FBFFD8DFF4BCBEDB9BC8E7A1D0EFA1B6D383C1DD90C5DF95D5ECA6071E008DA162CADE9F
D2E6A9D8EEB0C6DC9EBED796DAF5B2D1ECA7C9E7A1CFEAA5C9E2A0C6DC9BC1D894DBF0AD
E3F7B281954E5C6D26CADB94DBEDA3D6E89ED9EEA3DBF1A8C5DB92C3DB91CAE49ACBE199
D7E3A1CBD4939EA464545D1C4B5111626828D2D898ECF2B2
CCE89ECCE89ECAE89ECAE89EC9E99EC8EA9EC8EA9EC6EB9EC8EA9EC8EA9EC8EA9EC9E99E
C9E99ECAE89ECCE89ED0E69DDEE59FDCDE9DD1D59A525B26FCFFDAF1FFD5F7FFDDF4FFDC
F0FFD4C5DFA2BFD897DAEFACE1F1B0C7D39189935454591F8F8F5DC3C294E9EABEDFE0B4
D8DBAEE4EBB8D7DFA6DAE3A4D4DE99DFE9A0D8E095CCD48BDDE2A0F0F4B9E0E0ACBBBD8C
747A4C2E370C262E077A815FA7AE8DEEF9CED5E3A5E5F2BA030B00000400D1DDB5C5D49D
D7E7A97D8D4EB4C485DEF3B2D3F3AAC0E2985F7D3778914FD0E4A5BFCE93D5E0A8D4DDA8
A2AC7793A06ADCEBB2F8FFCFDBF4B3D4EFACCFEDA7C4E39DD3F3AACBEBA2D1EFA9CAE5A0
A8C17F5D7332D0E4A5BED092D6E6A7D3E3A4DBEBACD8E8AAD6E8AAD9EBAFD1E3A7D3E4AE
F6FFD8F9FFE1FEFFECFEFFF1F9FFF3EFF6EEF7FFFA45574B000900ECFFF6EEFFF888A093
02110C555D60FAF8FFF8F8FFF7FFFFF9FFFFFFFCFBC1ACA77D6257C8B39EDEDAB5C8D4A4
D0E9B0B7D798CAE6ABD8F0B6E2F3BFFAFFD6FEFFDACBD3A2D5DAA0DAE0A2DDE6A7C3CF8F
D3E7A2CBE59EBDDF95D4FDB1C1EC9DBCE899C8EEA1D5F5AA7B934971813A969D59909751
8A9A4F9DAD6457621E575D21EAE8B7ECE5B9D3C9A5BFB290978C6CCBC5A1E1E2BAD8E2B0
C4D79FCBE5A6DFFEBAD2F4AAC8E99ADDFCACCBE79CCBE69F869D59B6CC8CE5F9BCC5D99E
C5D8A0CFE3A8AABE8396AC6CD8F1AFCEE9A2BDD891D1ECA5CBE29EDAEFACCCE19ED6EBA6
617830B6CE84CDE59BD4EAA1C7DD92CEE49BE0F4ACB9CD86DFF3ACD1E5A0D5E6A2D8E7A4
99A462757E3D485110404908828B4AB2BB7AE2EBAACAD392
CDE79DCCE89DCAE99DCAE99DC9E99DC8EA9DC6EB9DC5EC9DC6EB9DC6EB9DC6EB9DC8EA9D
C9E99DC9E99DCAE99DD0E69DC2C986E0E2A3E4E9AF545D28E8F6C5D3E7B4B9D09CCDE9AF
CAE6A9DBF5B4CAE19DD4E8A3CBD797626B2C4F5318BEC188E5EAB2CFD8A1CDD7A2CDD7A2
DBE8B2D6E5AACADA9BD9EDA8CEE398C9DE91D7E99DE5F5AEDBE7A9C6D199C9D1A2DADFB7
CED2AFFBFFE0FFFFE8FEFFECF4F9E2FEFFE3BBC98ECFDCA7000500020D00D9E9BC071900
000E005065209CB16EBFD692BCD79291AF6994AD69BCD18EDDEDAEE7F5B8949F6559642A
A0AD75C3D59BF8FFCFE0F8BAC6DEA0CEE8A7CBE5A4D0EDAAC4E49BB8D88DC4E29ADAF5B0
C5DE9CBED494536827D7EAAADBEBAAD2E39FDAEBA7CCDD99C6D997D0E3A3CADE9FDAECB0
CED99FD1D9A6DAE1B7D3DAB9E3EDD5F7FFF4F2FFF8203B2C3E5F4ED6F8E7EAFFFAD0ECDE
14251F6B7375FFFDFFFFFBFFFFFAFFF8F6F7FFFEFDFFFEF8FFFFF3A69F8D675F48D9D6B7
D7DBB6D2DDB3CBDDB3BED3A8C8D8B1F7FFDEFFFFE4E3E1BBE4E9B3D4DE9FCBDA99D9EEAB
CAE59ED7F7AEC3E59BC5E79DBFDF94D7F5AB92A961314700DEF2AAE2F6AEBDD189DDF1A9
D7EDA2C5DB90DBECA696A061494C13A09F69DAD4A46861337E774BE1DFAFE5E9B6D3DEA4
E7F9BBD1ECA9B4D48BBCDE92BBDB8FC8E79B67823B223D00C7DD9DE3F8BDC7DAA2D6E7B1
D0E1AB70834C000D00C7DD9FC9E29ED0EBA4D5F1A6C5DF96D4E8A3CDE09E99AC6A435A14
D1EBA2CAE69BD0ECA1BEDA8DDAF6ABC5DF95C8DE96D8ECA7E1F0AFCBD799CCD6990C1400
2832005A65238F9A58AFBA78CEDA98D1DD9BDDECA9D5E4A1
CDE79DCCE89DCCE89DC9E99DC8EA9DC6EB9DC5EC9DC5EC9DC5EC9DC5EC9DC6EB9DC6EB9D
C8EA9DC9E99DCAE99DCFE69EF3F9B9D5D69CDCE1A94D57228C9A67C4D8A3E4FDC4C6E2A5
BEDB98CBE69FC8DF97DAEBA5C5D08E82864B94935DE1E4ABD3DF9FD6E9A7E2F7B4C7DD9C
C9E2A0C6E19CC3DE97CAE99DDBF8A8C5E292BFDB8EC7E19AC9DFA1CFE1AFD9E8BFDDE7C5
D4D8BDF3F5DFF8F9E7FEFFF2FDFFF2D8DEC2E0EDB8D0DEAB0B17030006008092625A702F
96AD67CBE59CD0EAA3CAE39FD2EBA7C9E09CC4D996E3F3B2CEDA9AAFBB7D94A062C4D294
C9DB9DE9FFBFF5FFCFD6F0B1D0EAABD1E9ABBED69AD2EBAACAEA9FF0FFC5BEDE93BCDA92
D3EEABD3E9A9A8BD7CB1C48290A15D9AAB65C8D992D3E49ED8ECA7DFF2B0C5D99ACFDFA1
DDE8A6D8E1A0DCE5ACC8D2A0EAF9D0F4FFE8E9FFEA284B35C7EEDC70998B7EA298BEDCD4
6C7F79727876252120FFF5F6FFFBFFFFFCFFEBEBE9F6FBF5F6FCF2FFFFF3FBF8E98D8674
FFFFECFFFFEAFFFFEAFEFFECF3F8E1FFFFEDFFFEEBFFFFE3F3FAC6E2F1B0DDF2AFCEE9A4
BEE096C9EBA1D4F4ABC4DF98D2E69F4E5B16B0BB77F0FBB7D3E49DB4CC82DDFCB0CEEEA2
D0EFA1C6E297C3DB91DCEDA7E9F4B2B1B5786B6A3189874E6F6C35AEAD75CFD398D2DC9D
C9DA96C9E09ACCEAA0B6D68B65853A234300ABC681C6DF9ED3E8ADC5D8A0D2E3AFD0E0AF
6373421D2E007D8E57D8ECAFD3EAA6D4EEA5D1EDA2D4ECA2CADB976B7A396A7E39C9E098
D6F2A8BDDC90CDEE9FCDF0A0C5E599CBE99FCDE49ED9ECAAC9D597B3B87E91915B4C4F18
B7C182CBDA97D5E4A1CFE09CD3E4A0CBDF9ACDE19CD2E7A2
CDE79DCCE89DCCE89DC9E99DC8EA9DC6EB9DC5EC9DC3EC9DC3EC9DC3EC9DC5EC9DC6EB9D
C8EA9DC9E99DCAE99DCFE69ED0D698DBDCA3D4D9A1545E29A1AF7AD3E8B0D1EBAEBEDB99
D5F3ABCEEAA0DCF2A9C0D18A6A73327F8046E0DDA8D8DBA2C9DF94C2E28FD0EFA1BEDF90
D2F7A9D1F8A9C7EE9DC2EC98B8E08AC6EE98D2F9AAC6EAA2C1DEA4E2FCCDF2FFE4EAFADD
FEFFEDF8F9E9FFFFF6FFFFF8FEFFF8DEE3CDD3DFAD6977460006006F7C68ACC08DCAE49D
CFEBA0B3CF82D1EDA3D2ECA5C9E09CD9ECACC5D594AAB6768E9859B0BA7BE6F2B2DBEAA9
C3D897CEE7A5CCE6A5CBE8A8D4EEAFD6EEB2C5D8A0D4EAAAC8E79BAED17FCCECA0CBE9A1
E1FCB9C3D998D5EAA9C8DB99B0C17D93A45E91A25B6F803A63763471834564783D7B8A4F
CDD6959EA56198A25D889752B3C885BFDDA1C5E9BB89B2924773648EB8B483A9AC446165
465957B9C0B85F5C4B070000AFA5A4F2ECF0FFFFFFFBFFFFF8FFFBF8FFFAEAF2E7FCFEF3
C4BBB49889847B6663B19C99B19F9BF2E7E1FCF9F0FEFFECF9FFD2D2E9A5BEDC96BFE39B
D1F7ACBADE94C7E29BD8E9A59DA260D8D797DBD798DDDF9EC1D18ADBFAAEB8E594BAE998
C2EB9CCEF0A3D4F3A7C9E197CDDC97D2DB98DADC9BB4B373AAA969E4E4A4C4C98799A35E
9BAB6493A75F9AB268B4D085C4E29AC2E19BCEE8A7E0F8BAC5DAA1E8FAC6F2FFD3000900
1B2800CEDFABBBCC95EBFFC2C5DC98B4CE85D9F5A8A2BA6E778643D6E2A2D5E6A2C9E098
CFEBA1C8E89CC0E597CEF5A6C5EA9DB8D88DE0FAB397A768303A003E3E0A726E3ED3D19E
D6E2A4D8ECA7D2E7A2CFE49FDCF1ACDAF1ABC7E19ACBE69F
D0E5A0CFE6A0CDE79ECCE89ECAE89EC8EA9EC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC8EA9D
C8EA9DC9E99DCAE99DD0E5A0D9E1A5E7EAB3D1D6A05A632CAAB47FCCDBA4CEE2A5D9EEAD
CFE6A0C6DC94CEE29ABDCD867E8947A0A96AF5F8BFD0DA9BD7F2A1BFE38BCDF09CC1E794
CFF6A3B6E08CB5E18CCDF9A4C7F39CC0EA96C7EDA0C9ECA8CBE8B0E7FFD4F2FFE8F7FFEF
FEFFF4FAFAF0FFFFF6FAFEF0F7FEECD5E0C2657546283A0A000800C6D9BBDCF5BBCDE99F
C6E595D5F4A4CBEA9ECBE79DD1E8A0CFE59DB2C37F808F4CB7C383D4E0A0D6E2A2D2E2A1
D7ECA9D2EBA9BFDC99CAE7A5C5E2A2CFE9ACC9E1A7CEE8A9C9E79DD0F1A2CEEDA1CAE59E
C0DA93DCF3AFCBDF9AD7EBA6D6E7A0C6D790DEF0A6CEE29ACCE29AD1E8A4A9C281AFC483
DEE9A48D984C92A45299AF5CACC37376914A89A771C2E6C095C0AD89B2AC8CADB2788F95
9AA4A5888981948F7C2A23108D8680FFFEFDF9F9F9FCFFFFF9FFFFE8F3EDF8FFFEFEFFFD
F6EDF0E4D4D7CAB1B7DDC4C8A59193F2E8E6E6E7E1AEBBA17B9055C2E195C2E498A8CE83
AFD78EC4E8A0CBE6A1D6E7A3B2B975E9ECA7D9DA94E0E89FCFE497C9EC9AC2F29EBEF09B
BFE899CBF0A2C9EB9FC1DF95E3F8B3D0DC9ADFE4A48785489B975AD7D797E2E9A6D7E49E
D0E59AC6DD8FCDE597D5F0A3C6E49CD4F1AFC2DC9DC6DEA4D6E9B2E9F9C893A0721A2600
505C2CDCEAB7D0DFA8C6D89AD3E8A5DFF6AEA7C2758FAA5DAAC47ACBE59BCAE49BD2EEA3
C5E498C7E79BD3F3A7C2E096C6E298E0F7B1B9CC8A505E20737D418F945CC6C692DBE0A6
CCE09BD3EDA4CFE9A0C6E097C8E49ACAE69CBFDD93D5F3A9
707E41BACA8CD2E2A3D2E7A4C5DC98D5EFA8CDE99FCAE99DCAE99BCAE99BCAE99DCAE99D
CAE99DCCE89DCCE89ED0E5A0D9E3A7D7DCA6B4B983525721D2D4A2D1D5A2DBE0AADADFA7
DCE4A8949E5F77834192A15CCCE099D9EFA7BED48CD0EB9ECBE896CBED97C6E796BEE191
BFE496CAEFA1CBF0A2C4E999C5EA9AD0F2A5CBE9A1D0EAABC4D8A5F5FFDEFBFFEAFBFFF2
FFFFFDF9F9F7FDFFF0D3DEBED5E4BBD3E4B7A1B788677E50000C00CDE9B8C7E6A2CAEB9C
CBEB96C9E994CFEB9EC9E598CAE79599B66296B162CDE59BC9DE9BE0F2B4BFCF91D0E2A4
C7DB9CE0F6B5BCD794D5F4B0BCDC99C5E8A6C7EBADC5E8A6D7F6B0B6D288D5EFA8CFE69E
C4DA92CDE199D2E299D2E297D9E99ED0E394D6EB9CD8F1A0BAD787CEEFA0D1F3A6C6E597
D5EB98D4E891CAE88EC9E78FCEE394BCCD894B5924D0E5BCE7FFEDE9FFF9F0FFFFF8FFFF
FFFDFFFFFBFBBDB3AA9D958AFFFFF4FEFEF4FCFBF6FFFFFBFFFFFFEFEFF1FFFEFFFBF6FC
FFFCFFFFF8FFFFFCFFF9F0F1FFFFFAF9FCF1F9FFF4D6E7C3E0FEB4B5D97F8AAD5BA8CD80
C8ECA6C7E7A4D1EEABCBE69FCFE799C6DE8ACCE68BD6F397CDEE93C6EA90C7EF99CAF19E
CFF2A2C1E397CFF5AABFE49EC2DF9FE0F2B8D7D7A55A5424807849D2D19BD5E3A5CFE9A2
CCED9EC2E490D0EC97CEE998CBE9A3CEEAADCBE4AADCF3BBD6E8B4657642111D00F1FBC9
F0FAC6CCD6A1DCE7ADE0EEB0CADE99677D35BBD387C7E897B5E68BC7FCA0BDEB93BEE894
C6E798D6F0A6CBDF98D6E2A0D4DD9E565F20525B1C919B5CDDE9A9D7E7A6C8DB99CBE29C
CFEEA0BFE08FCAEB9CD3F4A5C9E89AC8E799CCEB9FC6E599
C7D29AA6B479D8E6A9D8E8A9D2E7A4D1E8A2C8E298CBE79CCCE89BCAE99BCCE89DCCE89D
CCE89DCCE89DCDE79ED0E5A0D5E0A4DEE6ADA5AA74565924F2F2BEE8E6B3E1DEABDDDCA6
D8D9A05B6125808A4BD7E8A4CFE69EC9E59AD4F3A5D2F3A2CCEC99CFEF9CD0F1A2D0F0A4
CBEDA1C5E79BBFE195BCDE91D3F3A7BEDC92C7E09CD8ECAFDDEDBCFCFFE1F2F8DCFAFCEE
FEFEFFF0F2F1FBFFECBDCCA3DCEEBAC9E0A8CCE4B4556F40001200C1DEA6CCEBA5D5F6A5
C5E68FC4E28CCDE99ECEE89EC0DC88506C17C7E494C7E398C9E7A1D2EFACC3E29FDCFBB8
D6F5B1BFE099CAEEA6C6EBA5D9FEBBC6EAAABBE1A68CB275B5DD97CEF6ADBFE59CD9FBB1
D2F0A6DAF5A8CDE398D2E79AD8ED9EBFD485CFE696CDE899CFEE9EBDDE8FC2E595CCED9C
C1DD89CEEC94B4DC83CCF49ED9F1A7C6D69799A371CCDAB6EDFFEDE8FFF4EAFFF6F4FAF8
FEF2F6FFF9FDFFFBFBFCF7F1CACBBDFEFFF2FBFBF1EBE8E3EDE7E7FFFDFFF4EDF5FFFCFF
F6EFF7FFFCFFFAF8F9FEFFFBFCFFF8EDF5E6F8FFF1D5EAC1CFF0A1CBF093BADD89C9E99E
CDECA9C2E0A0CEEDAACAEAA1D5F4A4CAED93CAED8FCBEE90C1E48ABADE87C0E295C7E79C
C8E69CC2E297C6EFA3C8F0A9C2E19ED1E5AAE3E3B1B6AE7F93885AF5F4BEC4D698D0EFA9
B9DE90D1F7A4C9E694CBE697CFECA9AFCB8ECAE3A9F1FFCE667942041200FCFFD6CFD9A5
D1DBA6E6F1B9C7D29699A7693D510CD6ECA3C3DB8FC3E694CBFFA4B1EA8BBBEE92D1FBA7
C4E395CEE29BDDE8A6DADEA1060700595A20D4DA9EDCE6A7CEE29DC5DF98CBE99FCEF0A3
C3E996DAFFABC7EA98C0E391D4F5A4CBEA9AC7E396D6F2A5
EEFCC18A985BDBEBADD0E3A3D2E7A2CDE49CCBE59BCCE89BCAE99BC9EA9BCAE99BCAE99B
CAE99DCAE99DCCE89ECFE6A0E0EEB0CDD59A989D657E814AE3E3ADD0D09AB5B47E6A6933
64652CB1B77BE7F1B2D3E4A0CAE199D5F1A6C6E597BDDE8FC3E292C3E294C6E69BCCECA3
CBECA5C9EAA3CEF0A6D6F8ACCAEA9EBEDC92D6EFABCCE2A4BECE9DD5E0B8D1D8B9FEFFF1
FDFFFCFCFFFBE9F3D8708053CEE1AAC7DFA5D3EBB95E7849001000C1DCA5D1EFA9C9E696
C2DF8BE0FCA8D0EAA1A8BE768EA056C6D88ECBE399C2E096CAF0A5B5E496C0F5A3B3ED99
AEE894B4EE9AC1F6A6CCFBB3B1D99A698C543B5828517642C6FFBAB4F7A8A8E699AEE79A
B0E396C9F5A6B1D689CFEFA3C5E196CEE89ED4ECA2CCE49ACDE79ED1EBA4C0DB94D3F1A9
CAEA9FD9FFB2B6E798C5F5A9C3E3A22E4710000A004C64448FB59C8DB6A6CEEBE6F5FFFF
FFFDFFF3E8EEFFFEFDFFFFFACFD1C4E0E2D4FFFFF4B4B1AA8A85824B4545867D82FFFCFF
FFF9FFFFFDFFFFFFFDF8FBF4FAFFF4FBFFF3F0FCE6C5D7AFBED992CFF19BD2F2A6D3F1AB
C9E6A6C2DEA1CEEBABCCE9A6BCD88DCBEA9ACFEF9CC6E595CCEAA0DDFCB8D6F4B8BEDA9F
D4EFACCDEBA1C2E89BC7F0A2C9E99ED0E49DDEDE9EBBB375ACA368DBDB9DD4E7A5CCEBA5
CEF2AAADD189DAF5B0D5EEACCCE6A7E2FEC1C5DFA2EAFFC68A9D6592A16AE7F4BFD7E4AE
C9D69EDFEDB2B4C28592A261D4EAA2D8F0A6D6F1A4D4F3A3BCE390BDE793CAED9DC6E297
CBE199DCEBAAD0D89C9CA2665C6127A2AA6EE2EEB0CCDC9BC8DF99CCEAA2C9EB9FBFE697
C5EC9BBEE491C3E694D5F6A5BDDC8EBAD689DCF6ACC9E197
D8E6A995A566DBEEAECBE09DCAE199CCE69CD1EDA0C9E89AC9EA9BC9EA9BC9EA9BC9EA9B
C9E99DCAE99DCAE89ECFE6A0C0CF8EE5EFB28E965AAEB379FFFFCDBCBC866E6E3885854F
BBBE85D2DA9FE4F0B2D7E7A6CAE19BCCE89ECCEB9FCBEB9FCFEEA2CEECA2CAEAA1C6E59F
C1E29DC0E19CC2E39CC4E49BCEECA2CAE89ED1EAA6CFE5A7D7E8B4DBE8BDCFD9B7F5FDE6
EFF4EDCAD2C55D6B48526432C3D89DD2E7ACC4DBA7647B4D000C00C7DFABD4EDABC6E194
C8E190CFE897A5BA75889B59C8D993CFE39CCCE7A2DFFFBFADDC96BCF5AEACF0A774BC72
8BD48B6EB66D94D792ADE7AABEEFB8C7EEBF54744B49734564A46776C17CB8FFBBB7FAB5
B4F1ACB5EAA6C2F0AFC5EFADC1E8A7C8ECACCCEEB1A2C487CCF0B3D4F7BDBCE2A9BEE4A9
B7DFA1BEEFADB1EAA681B978BCE7AF8EAF805F7A579DBEA3AFDCC83060544B726FB0C8CA
FAFDFFFDFBFFFCFFFFF6FBF4C5C9BBC7C8B8C0BEB2F8F5ECFAF5F1D0CBC8746B6E060000
817B7DB2AEADFFFFFAF9FAF2FEFFF4FCFFF1EFF8E3E1F1CCC9E2A1D0ECA2CEE9A6CCE6A7
CCE4AACDE5ABD1E9ADCEE7A6D7F0ACCFE9A0CBE59ECFE8A6C9E2A8BAD2A0C0D7ADD8EFC1
CDE5A9CAE8A0CAF0A3C0E796CFEE9ED5EB99D9DC8F726B239F9852D6D791D0E19BC6E49E
D0F3B1CFF1B45A733A4259213852159AB475B9D193EBFFC5F8FFD1C8DAA0D2E1A8D9E8AF
E3F2B764743691A162C2D593DFF6AEBDD88BC0DD8DD1EDA0CAE49ADBF3A9CEE49CCADB97
E1F0AFB2BC7F6D753A565E23D6E0A4D8E6A9D1E1A2C5DC98D2F0A8D0F2A6C2E89BC6EFA0
C2E998D3F9A6C2E593CAEB9AD4F0A3D4EFA2DAF0A7AFC37B
CCDC9DC2D593C6D997CEE39ECDE79ECBE79CCCEB9DC8E998C9EA99C8EB99C8EB99C8EB99
C8EB9BC9EA9BC9E99DCDE79ED5E6A2E7F1B2949D5ECAD094B8BD8370733A555821ACAF78
DCE1A7E7F1B5CBD99BC1D492DAF1ABD3EFA5C3E197CEEEA3C3E39ACBEAA4CEEDA9CAE9A6
CCECABD2F2B1D1F0ACC8E7A1CEECA2D1EFA5C3DC98D7EDADE1F4BDC3D3A6D9E5BFF8FFE7
F4FFEF4C5844000A00869962D1E7A7D1E7A7CFE6B0687E4F000D00C8DFABD1E7A6DEF4AB
CFE4978DA2556F7F3EABBE7ED1EAA6CFEEAAC6EDAEACDCA2BDF6C3BCFED067B28744946D
003D1733835E4C98726CB089A5E1BBB6EDC5B9E7C208381045825852956963A47999D8AD
BBF6CAA8E0B39BD0A499CCA1BDF0C5B0E5B9B6EDC347805772AC8476B48B8FD0A89BD8AE
BDF5C4A7E2ACA3E7AE4D905A8DC191C4EEC8BEE2C67BA591C3F9EB346D64558381A8C7CA
F3FEFFFBFFFFF2FEFCF8FFFBF7FBEDDEDFCFBEBCB0F5F2E9FFFEF8FFFEFBD5D0CD7B7575
38323244403D888880A9ABA0FEFFF3FBFFF0FCFFEFC9D4B4D9EBB7CDE2A7CBE0A7CBE0A8
CEE2ADCFE3AECADFA6CDE2A7C7DD9DD5EBABCEE4A6CADEA9E1F3C9F0FFDFE5F4DDD8E8CB
C3D7A2BED994D5FAADBEE393CFEF9AD0E48DE7E996544D00A69F51C8CA7FE8FAB0BDDB95
C3E5A89EBF8A000C005D7042ACC488D5EEADD8EEAED5EBADDBEFB2D4E8ABC3D599D3E5A7
A7B97B96AB6AACC17EDBF2ACC2DC92D7F3A6DAF7A7D0E89CE0ECAAD2D89ACDD397E9EFB3
D4DA9E727A3F51591E919C62CBD99CDEF2B3D4EAA9C7E59FCBEDA3C9EFA2BEE999C1EC9A
CAEF9FC7EA9AC2E394CDEC9EC7E197CBE399C2D68E7C8D46
D1E4A2D6EBA697AC67CAE199D7F1A7C7E698C7E897CEF19FC8EB99C8EB99C8EB99C8EB99
C8EB9BC8EB9BC9E99DCCE89EE0F1ABC1CD8B939E5CA1AA6B565E22A2A76DEBF0B6E1E6AE
DEE6ABC8D397C9D99AE4F7B7D8EFABC4DF98CCEAA2C4E49BC8E7A1CAE9A5C7E5A5C1DFA1
BFDEA2C4E4A5C8E7A4C8E7A3C0DE96CFEDA3C4DF98CBE4A29BB075334513445328596744
505E47A9B99EE4F8C7D9EFB1BCD38FD1E7A6E8FFC7455928000B00D5E7B5C9DD9ED7EBA3
CBDD938F9F5694A264DAEAACC8DE9ECDEAAAC3E5A9C4EBB4B4E2B191C69A104A245D9D7B
B5F6D8B1F1D6ADECCF2964463B7253BAEBCB527F5E2754336392706B9C7C4E7D5D275634
45734FCFFDD95684606594709ED2ACBEF4D0ACE5C2629F7D478A67ACF3D163AD8A175F3A
B2F0C9B2F1C667B0820F582A85BF97B1E2C290BAA414433188C6B946857C669A96A3C9CA
EAFCFFF7FFFFF1FFFAF5FFFAF1F7E9FFFFF3FFFFF4ACA9A0CDC8C2E8E3DFF9F4F1FFFEFB
C8C3C0A7A49F77776F7E7E74F7F9ECF7FBECFEFFF159624766724C5E6E4169794C67774A
65754665774360713A6C8045819355BED295D7E8B2CBDBAED8E6C3EEFAE2F6FFF3F9FFEF
E2F4C4CDE6A5CEEFA8C0E295D5F2A0CCDE8CE7E89860590B9C9449EDEDA5D8E8A1CAE7A4
8FB17527471591A87ED7EABDD3E8ADCAE09FC6DC9BD1E7A6DDF2B1C9DE9DE6FBBA4C6221
506625E1F8B4C7DE98BFD990E4FFB5BEDA8DCCEB9BC7DD92D0D497DED9A1E8E6ADD3D299
787B42868B51B9C387D5E3A6D5EAA9D8F1ADBED992C4E499C4E69AC5EC9DBFE997BDE493
B8DB8BDEFFB0C0DC91C1DB91E5FDB38FA35B586922BBCB84
CFE49FCFE49F869C54C4DE94D4F0A5C4E395C9EA99CDF09CC8EB97C6EC97C6EC99C6EC99
C6EB9BC6EB9DC8EA9ECAE89ECEE29BDDECA797A45F535F1D768041CFD79BE3EBB0C9D397
D8E3A7DBE9ACA3B57784995899B26EC3DE97DBF9B1C3E29CC6E5A1C4E2A2CDEBAFD7F5B9
D0EDB3C1DFA3C5E3A3D7F6B2D1EFA7D5F3A9D2EEA4C5DE9AB3CB8D98AD75C8DCABD2E4BC
C7DABAF5FFE4F3FFD2C5DE9ACEE89EC5DF98D1E6AD728655000A00DEEEBDCADA9CCBDA95
B2C27BA7B46ED7E2A6DDE8B0DBE5B0CCD6A1D1DEA6DBE9AEDFEFB1ADBF81000D00E6FBC3
D4EAB9CEE8BBCBE5BE6A8564092608749276001A000F2C105D75533F552F556B454A603A
061C00859E76112D044A6B40779C71C7F2C5BEEDC190C599033D14ABE9C06FB287488B62
92D0ABC1FFDF4B986E001B0076B28EA7D9BC5C87732959490036263B7D7172ABA4C9F2EE
F1FFFFF2FFFAEBFFF1F4FFF4F4FAECFFFFF6FFFCF3FFFFF8F4F1ECE6E3DEB2AEABF3EFEC
FFFEFBFFFEFBFFFFFAE6E6DEFFFFF6F5F7ECFFFFF46E72616A725A6D76597B846569734E
606D41697A4664733A6B7D3F98A86AB8CA8ED6E4AFD7E4B8AAB4926B735C8A9082F2FAE5
D8E5B9E8FDC2C5E3A3C4E39FD6F0A9D3E09BE1DD9D8E83459E9355D6D595DDEBAD859F60
2C4B10B4D29CC6DEAEC5D9A6C1D596E7FCB9CCE19EC6DB98C4DB97DCF3AF6C833F90AA63
A8C27BBAD48BDAF4ABD4F0A5BBD78AD4F0A3BDDA8AE4F9AEDBDB9FE2DBA4CBC68EA9A96D
5B5F24BCC687E9F8B7C7DA98C5DC96C7E399BDDC90DFFFB1CDEE9FC3E694CAED99CFF2A0
D4F3A7CAE69BD6EDA5D4EAA2C7DB9492A35D84934EEBFAB5
CCE19CCEE49C9CB46AC8E298CBE79AC0E192CCED9CC1E490C6EC97C6EC97C6EC99C6EB9B
C6EB9DC6EB9DC8EA9ECAE89ECFE59CCBDC95B6C5808D9C57D9E5A3DBE7A7D3DFA1DAE5A9
D5E3A64555174F632499AF6E415A16314C07B0CE86D1F0AAD1F0ADC5E3A5C9E7ABC5E2A8
87A46C29460C001600001B00001100537127CEEAA0D3EEA7CBE6A3D5EDB1EFFFD0D7EDBE
E4FAD3E1FBCED7F4B4D2EEA4D1EE9ED4EEA5C8DDA25F7342000A00D8E8B7D0DEA3D9E8A5
9AA76187944FDCE6AACDD8A0D5E2ACD1DEA6DEE9ADD2DC9FD2DB9CDDE5A9D5DAA2D8DFAC
9BA2782E3815485738617458253E21C1DEC2D1F2D538573793AB87E0F4CFCBDFBA94A883
1B3009CAE0B9CBE4BC000D003F5F36274C21517A5279A67F588862BAEEC8669E790F4825
7AB392A6E6C3AFFAD13D885F7FBB975386671D4932B5E6D15D9C877EC1AF3B746595BFB1
EEFFF7F1FFEEF2FFEFF1FFEAFCFFF3FFFFF6FAFAF2FFFFF8FFFFF8F7F6F1FBF8F3BEBDB9
CECAC7A2A19DFFFFFBFFFFFAFDFCF7F7F6F1FFFFFAFEFFF7FEFFF5FEFFF3FEFFEDD7DEBF
CAD5ABDEECB9D2E1A6CDDD9EC6D695E0F0B1D8E7AECBD7A7CFD7B2A7AD9162675341472D
889368ECFFC8CDE6ADCDE9AFCDE2AAD7E1ADE6DEB0D0C196A19366E1DBAB929F6930490F
658448BDDCA0CEE7ADD5E9ACDAEDABC8DC97CDE19CD5EAA5D4EBA57F995290AA63C8E49A
D4F0A6CCE89ECFEBA0C0DC91D6F2A5D3EEA1CDE89BCEDF98EAECAD948F554E4C0FA2A465
AAB372DDECA7C9DD96D6EEA4CBE79AD2F1A3C0DF8FD3F2A2BBDB88C9E996D6F39FC0DD8B
D3EBA1C2D991CFE59D93A76092A35DDCEDA7D6E7A1C9DA94
D7EDA5C5DB938CA45ACBE59BCAE699C7E899CCED9CC0E391CAF09DC2E895C6EB9BCBF0A0
C2E799BEE396C8EAA0D0EEA4D0E69DD0E59ACBDC95D9EAA4D4E5A1D2E1A0CADA9B6D7D3E
000C00CCE0A1D0E5A4D4EAA9C2DB978EA964D2F0A8C5E49ECAE9A56383421A3800011E00
193600809D63D3EFB4CAE7A5CAE8A0CAE89ECCE89DCCE89ECCE7A2CCE6A5CCE5ABCAE5B0
CFEBBBC3DFACC2E19BCFEE9ED1EE9CCCE79AD2E7AC627643000A00D7E7B6CEDCA1CDDC99
A0AD6784914CE2EDB1CAD99EC7E29FCDECA8CCE9A7C4DEA1D6EDB9C0D5AACADDBF4C5D4B
8A9B935F746F506B665B7B6E91B9A1AEDCB8C1F2C5194D1D95C39EC6F2D1D0FCDBBCE5C5
1A4220CDF5D3B7DCBB0011002D5233C1E6C7BDE4C9163C23000E008DB49FADD4C1548069
447557AFE9C3B2FACC387D5080B78F8BB9951F4627B6E3C6B8F5D600321443795F87AF95
CADEC5D7E4C6C5DAB3C8DCB7FCFFF1F9FBF0FFFFF6FFFFF6F9F9EFFEFFF7FFFFF8FFFFFA
FFFFFADBDCD7848580EDEDEBFFFFFDF8F6F7FFFEFFFFFEFFFFFDFEFFFFFBFFFFF3D2D8BE
C7D2A8D1DFAA96A6674B5F1A000E00000D00D9E9AAC4D199D9E2B3D8DFB6E9EFCD7F8561
5861342A3A09C6DCABCBE2B4D8E8C3D5DABCFFFCE7E2CDBAAD9883F5ECCFDDE8BE7E9760
C2E2A1CDEEA7CAE49BD9EFA6D9EAA4C4D591D5E9A2D7EDA560772FCEE89FC9E59BC5E498
D3F2A6C3E296CEEA9FD3EFA4C6E096C6DE94D7EDA4D2E39C8D94506166238D9450D5E09B
D2E49AC8DE93D3EEA1CCE999CCEC99C3E390D4F4A1CEEB99D0EC98D5EE9BC8DF8DCDE293
D6EAA2D7EBA68CA05B8A9B57D1E29ED7E8A4CADB97DEF2AD
C8DE96D8EEA68FA55DCEE89EC1DD92CFEEA0C5E697D0F3A1D1F4A2C9EE9EC3E898C3E89A
CAEFA2CDF1A7C9EAA3C0DE96D8F0A6D3E99ED1E59DD8ECA5D1E5A0CCDF9DAEC181041900
596D2ECFE5A4CCE2A1CCE5A1D0EBA6B5D089CCEAA2C5E59CCAEBA688A8658DAB6DC0DDA3
C9E6ACC3E0A6CAE6A9C4E19FCAE8A0CAE99DCCE89BCAE99BCAE89EC9E8A2C9E7A7C9E7AB
CBE9B5C5E4A9C6E89CCCEE9ACBEC95CBE898D1E9AB697D4A000D00D1E1B0D8E7ACD4E3A0
B0C079909F5ACDDB9EDBEDAFCEE9A4CDEDA4CBEAA4B2D28F6281452D4D1BA9C9A282A388
1B3B2C00150C22463C85AC9AB3DEC0C6F3CAB0E1AA00280005390B32673D52855C184820
518157B1E0B6A8D5AC012B03083109577F5A608563618665000E005A7E628BAF9521482B
0B37135186584B8B5743844E79AB7A7DA67A6A8C67779F7AA9E1BAC0FCD6001400698F6A
C7D8B4CEDBB0E8FAC8C9DAADF6FEE6FEFFF3FCFFF1FBFFF0FEFFF3FDFFF2EFF3E5F3F7E9
EDF0E5FCFFF6FEFFFAECECEADEDEDE8D8B8EE4E2E7FFFEFFF9F6FDEEECED999B8EA2A88E
303B119EAD769FB270DAF0A7DBF1A6D1E59DCEDF9B8E9C5E949F67878F5C939969FFFFD8
E2EAB9657342071A0095A984C5D2B8E5E6D8FFF1EDC9AFB0FFEAE6F7E9DCD8DFBEC8E0AE
D0F0AFC1E396CFEB97C7DD8BD0E19ADAE9A6DFF0ACC0D68E96AD65CFEBA0CCEB9FDBFAAE
BFDE92C8E79BD1EDA2C0DA90D8EEA5E6FAB3BFD08AB9C98279863E909E53CCDE92E7FCAF
CAE294C4E18FD1F19EC3E591CFF19DCCEE9AD7F7A4C0DD8BC1DA89DDF4A6DBEDA1D4E69C
DFF0AABDD18C9CAC6BAFC37EDDEEAAD9EDA8CADE99CBE09B
C1D590DBF1A995AB63CDE59BCEE89ED2F1A3C1E293CAED9DB6D989CDEFA2D2F4A8C6E89E
C2E39CC6E7A0CCEBA7D6F4AEC4DE95BCD48AD2E8A0CCE29AD2E7A2607733182E00ACC281
BCD291CDE6A4C9E29EC6E19AD7F2ABD1EFA5C4E397CBEB9FCEF0A6B9DD97C4E4A3D9F7B9
D6F4B8CDE9AECEE8A9CBE6A3CCE7A0CCE89DCAE999CAE999C9E99DC8EAA0C8E9A4C6E9A7
C6E7AEC6E9A9CCEEA1C9EB94C7E88FCBE896CFE8A76F834E000D00C1D1A0D3E5A9D6E7A3
CEE09699AA637F8F50889659D2DEA099A56373883DA4C06CBCE088BAE68DC8F9A7001C00
417336B4E4B2B9E4B9B8DEB5C4E5BAC9E6B6C0D9A2BFDCA2BCE4A6BEEAADB9E5A69AC687
C9F6B5BAE7A4C1EBA9C5EFADC9F3B1C4EEAEB5E1A2D2FEC1739F643F6A32C9F4BEB7E2AC
B0D8A4BFEBB696CD93B0E8ABBFEAB2B6D9A3CAE7B78BAF812054240B4312184818000F00
9DAD7EA7B17CD2E2A4D9EAB3CFD9B7F6FEE7F6FEE6EFF7DFFBFFEAEBF5DADCE6CDF8FFEA
FCFFF1FCFFF3FCFFF6E1E4DDD4D4D2C5C5C7DEDBE2D7D4DBCAC8CDADADABF2F6E7CCD5B6
D8E8B9B0C487DAF1A9CBE397C0D88ADCF4A8D3E9A1D5E8A6D2E0A2BEC98D879155B3BB82
9FA670C6D2A086976B7A8B69F0FCE8FFFFFAFFF8FFEACEDADEC3CAFDEEE9F6FCE2EAFFD2
C1E1A0C2E595E3FFA6CEE48FD3E39CD4E3A0A0B16D6F853DC7E198D7F3A8C5E498C0E192
CAE99BD4F0A3CFE99FBBD188E1F2ACCFDB995A652353601BA5BA6FBDD887DAF5A4D4F19F
C3E390CCEE98D3F59FC2E591C4E793C8E998B3D284DEFAADDAF2A8BED48CD7ECA7CADE99
99AC6A859A57A9BC7CCBE09DCCDF9DD1E6A3D6EBA8D3EAA6
D6E7A3CFE39E93A762C5DB93D4EEA5CCE89DC9E89CC2E296C6E69AD1F3A7CBEDA3C1E29B
C7E8A3CAE9A6C6E5A2CBE8A5DAF4ADDCF3ABD9F0A8CEE8A1C9E09CA1BA76667F3DD4EFAC
D8F1AFC7E29DCBE69FC8E49ACCEAA0CFEEA2C2E193D1F2A3C0E295D2F6ACD1F2ADBBDB9A
BCD89BCCE8ABD1EBAAC8E39ECCE89ECCE89BCAEA97C9EB97C8EB9BC6EB9DC6EAA2C5EAA5
C5E9ABC5EAA7CCF29FC4E88EC7EA8ECEEB99CBE4A3728651051600CEE0AED4E6A8C7DD95
D1E79CAAC075869B588A9D5D9AA467A0AB67ACC172BEDF86BEEA89C2F994B2EF90001F00
417E38B0EAAFC3F5C4C1EBBDABCB9ADCF4C0CFE1A7C4D496D9E8ADD7E6ABC7D799D2E5A5
C7DC99D4EBA7C6DD99C3DD96D3EEA7BCDA94D0EFAB9EBF7A9CBF7B143900CCF0B0C2E6A6
CBEDB1CBF1B4AEE19CAFE29DCAF1B0D2F0B4D3ECB3CCEAB44F804852895056834C65864F
69783F879154BCCC85D3E6A4CEDBAFF2FEDAFBFFE3F9FFE1F9FFE1E1F1CACBDBB4D7E7C3
EDFADCF9FFECECF5E2F3F9EBD8DBD4FFFFFFEFEEF3E6E4E9EBEAE8EAECE1EAF2DAD9E5BF
CADDA6E1F7B6D6F0A6CCE89BC9E598C4DE95D1E8A4CDE2A1CFDFA0DDEBADDCE6A79CA566
80884DA4AE79D0E1B4C8D8B4F6FFEAFFFFF8FFF8FDF7D9E3AA8C94FFEFEBFFFFECD1E6BB
D6F6B7CAEC9FBDD984DCF29FCDDC97DBEAA993A3625B702BD0EAA1C2E195C7E698D0F1A2
CAE99BCDE99CCBE399D6EAA3D5E19F9DA365515216747D3CDCF4A8CEF09CC2E490BFE28E
C8EB97CCEF9BCAED99CAED9BC8EB9BDEFFB4C9E9A0CAE9A3C5E2A0D3EDAEC5DFA28EA86B
9BB4739EB775D1EAA8DDF3B2C4DA99CDE4A0D3EAA6CCE39F
E3F2B1C9D9988A9D5BD1E6A1C7DE98C9E39AD1EDA3CDEBA1C0E095C6E69DCAE9A3CFEEAA
D3F2AFD1EEAEC9E5A8CAE4A5B2CB87D8F2AB5F7932C5E09BDEF7B3BED996CBE6A3D2EFAC
CCE7A2C7E59FCAE8A0CAE89EC7E698C7E696C9E898CCED9CC6E999C7EC9EC7E99FCDEEA9
D7F4B4CDEAAAC6E09FD0EBA6CCE89DCCE999CAEA95C9EB95C8EB99C6EB9BC6EAA0C5EAA4
C6EAAAC3E8A3CCF29DC2E78ACAED91D1EE9AC6DF9D7A8F57000C00CADEA9DAEFAECEE69C
D3EE9FC2DD8EC8E39CCEE7A3D9EEABC8E299D6F7A8CCF8A3BCF29CB6F4A1AFF3AA77BD81
26693D80BD9B83BA9B51805E335A2EAACB94C0DB96AFBA788D7B4D78573474542E60441C
654E226755257668376056214E4912DCDBA3CED19AEAF2B9000A0055622A94A36CD1E3A9
CFE8A7D0F1ACC6F4A9B9E89ACCEEA4CCE5A1B7CD8DC7E5A7BAEBAAADE4A3BBE7AAC7E6AA
BFCD8FC5D08C9EAF61CCE196D0E2A8CBDCA8CDDEAACFE2ABCCE1A9D1E6AED5ECB6D2E9B5
D1E4B7EAFAD5F9FFE8F9FFEDF5FBEDFEFFFAFFFFFDFFFFFBF4F6EBFEFFEDFBFFE3C8D8A7
CEE4A6C8E39CBFDE92C6E599D0EEA6CEEBA8D3EDB0C8DDA4D7E9AFC4D398DAE6A8C4CE91
CED498ADB67D9CAD77A0B184EBF4D5BBB8A5DECAC3EACECDD6BAB70D000061654CD2E7BC
D0EDB5C1E09DD4EEA5C5D991D7E3A3DCE8A893A362758A45CDE79EC4E397D0EFA1CFF0A1
C3E296CCE69CCCE099E4F1AC949A5C65642B99945CDFE3A6D0EB9EC9EF9CC5EB98CCEF9D
D0F3A1C2E595BDDF92CFF1A5C8ECA4B2D591CAEDADBCE0A39EC189A8CD9984A878C8EDB9
C9ECACC5E5A2CCEBA8CCE9A6CBE6A3D0E9A7CFE4A1CBE09D
CDDC9BCCDB9A8C9C5BE9FCBAC8DD9AD7EEA8C9E39CCEE9A2DAF8B0CBEAA4C6E3A0C4E19F
C1DE9EC6E2A5BED79DA3BD8096AF6D78914D183300C9E49FD5F0ADBAD794DAF7B4C6E3A0
C5E39DCFEDA5CBE99FCBEA9ECBEA9ACBEB98CDED9AC2E490D1F4A0C2E895BADC8FC3E59B
CFECAAC6E3A1C4DF9CD3EEA7CCE89BCAEA97CAEA95C8EC94C6EC97C5EC9BC5EB9EC3EBA2
C6EDAABEE69FCAF29CBFE689CCEF91CFEF9AC5E09D8EA56D0D2100C8DCA7D2E8A7CFE99F
D1EE9CC9E996D4F2A8C6E49ECFEAA5B7D58DC5E79ABCE694C2F1A0BEF2A7ACE2A4C3F9C8
8BBE9D184830032D1914381E17370E79965E88A25957621D523D1076542FA5855FAF9268
BFA77B947F50968452A59863857C45E7E2AADAD89FDDDEA463662DC0C58BA2A76FD9E4A8
C9DE99C3E296B9E492CBF6A4CBEA9CCAE298E0F5B0C9E6A3C4F3ADC5FAB4BAE7A6D9F9B8
D6E5A2D3DF97899C4A90A755D0E49FCEE3A2DFF4B1DEF5B1C5DF98C2DD98CFEAA7CCE6A7
D2EBB1D2E8B7F4FFDDEDFADCFBFFEFFCFFF4FEFFF8F7FAEFFEFFEDFCFFE4F8FFDBD1E6AB
DDF6B2C8E79BBFDF93D6F8ACC0E09DCAE8ACC9E4AFD2EAB8D4E6B4CFE0AAD9E6AEDFE9AD
DAE0A2E7F0B1CFE1A5788953D5DEB38E8B6A53412BC5A99BE4CABB1D0E00969B7BCADFB6
B6D2A1C7E4ACDFF7BBCBDDA1DCE7ABCEDA9C95A5649AAF6ACDE7A0D1EFA5CEEDA1B9D88A
D1EDA2D4ECA2CBDC96D6E19F626329635E27CCC08CE0DFA6C4DE95CAEF9FCCF1A3CAEC9F
CBEDA0C8EA9EC5E69FCBECA7C1E4A4E4FFCBB4DBA4A0C8969FCA9CBEEBC0AADAB2B5E4B6
BDE9AAC7EFA9B7DC97C0E39FCDEAA7C7E09ED4E9A8DBEEAC
D1DD9FDDEBAD8E9C5EB9C988D5EAA7D7EEAAC7E09CC7E29DC3DE99BFDC99D4EEADD5EFB0
C2DC9FBBD49A889F672A42085B7534DCF7B4D4EFACC8E3A0C9E6A3D5F2AFB9D693CBEAA6
C8E7A1CEEEA5CEEEA2C3E495CBEB98D1F19CC6E691C8EA94C4E891C9EF9ACCEF9FC8EA9E
CBE8A5D1EEABCFEAA5C6E097CCE89BCAEA95CAEB94C8EC94C6EC97C5EC99C3EC9DC3ECA0
C6EDAABCE49DCCF49EC0E78ACBEE90CBEB96CAE5A2AEC78E9FB584DCF3BDC7E09EC4E095
C2E28FCAEC98C9EB9EC6E59FD2ECABD5EBAAD7EFA5C9E193CEE796DAF0A5CEE3A2D5E7B5
C9D7B4D7E3CBD4DDCA59634A3C48206F7E478A9B5499A960A5B375D6E1A5D6E4A7C9D897
D0DF9EE6F5B2D9EAA4D0E19A85954CB6C67DD7E79EE2EFA7DCE9A3E6F1AC97A25ED7E7A0
D9EEA3CFEC9CB9E38DC9F49BC2DF8DC2D98BE2F6AEBEDC94C6F5ADAEE39BBEEDA9C3E6A2
CADB95DDE99FD1E794D1EA96627929829A4CABC473C7E291D3F09ECEEE9BC8E797C9E89C
C7E59FCFE9ACD4E8B7F2FFDBF6FFE3FCFFEFFCFFF2FEFFF1FCFFE6CCD9ADD2E5ADC2DB99
D2EEA3BFE091C2E799C1E59DCDEFB2C5E6B1DEF9CCF2FFE1E8FAD0F8FFDCEFFDCACCD79F
E2E8A8C1CA87D9EAA6D8EBABB0BB81B3B3811D0B00775F3DFFECCD0D0000595F39D3E8BF
DCF7CADFFACDE4FACCE3F3C4D0DBA3D5E1A3C7D796C9DE99C9E39CC4E298CBEA9ED3F2A6
D2EEA3CDE59BD0DF9AD4DD9C67662D9C925DF2E2B1D5D099D1E8A2C8EDA0C7E99DC3E39A
C7E79ECFEEA8CFEEABC8E8A9C1E2A9C7ECB84973432150241549232C6441609B7BC9FFDA
94C88ACCFBB5C8F3ACD0F8B2CBEBA8C3DE9BD7EAAAAABA7B
FEFFCFF5FEC789925B5B662CD7E6ABC6D89AD7EBACD0E6A6CEE4A4D4EDACC3DB9D5D7537
011B00435D20BAD298D6F0B3CCE9A6CFEDA7BEDC96CCEAA4CFEDA7BEDD97CEEDA7CAE9A3
C9E9A0C8E89DD3F3A7BDDE8DC3E591CEF09AB9DB85D7F7A2CAEA95CCE997D1EDA0CFEBA1
C7E19ACBE4A0D4EBA5D1E8A0CDE89BCCE997CAEA95C9EB95C8EB97C6EC99C5EC9BC3EC9E
C6EEA7BBE39ACEF6A0C2E98EC8EC94C7E897CDECA8C5E1A6CBE6AFC3DFA5C7E4A1D6F6AA
CBED99CDF09CB9DE8ED0F2A6C2DD9ACEE4A3CFE59DD8EA9ED3E194D6E298DFE6A3D7DAA3
D9DAB02E2E0A555636929671CFD8A9D3E1A6D8E9A2CBE196D7F1AABEDD97CCF2A7C7F1A5
C3EFA0B5DE8FCFF0A1CFEA9D9AAF628FA052CFE195D4E69ACADC90D6E89C9BAB6292A45A
C9E092CFEC9ACBF39DC4EC94CCEC99D2EA9CCAE296C9E79DC1EDA2C2F0A7C5EDA7D0EEA8
D3E29DDAE69CC8D989D9F19DCFEB97BFDC8A90AD598CAA54C1DE8AD5F29EC8E593D0ED9D
D3EDA3D1E8A4C7DCA1E3F5C3F6FFDAF6FFE0FBFFE6F9FFE4F8FFDDC7D9A5CFE5A7DBF4B0
B8D489D1EDA0D8F6ACC6E3A0D0ECB1BED9A6E4FBCFF2FFDEF7FFDFF5FFDAE1F2C5D7E5B0
D6E2A0D7E49CD7EBA3CDE19ADCEDA9CCD29470602F5D441CB59C7D372809777F58C8DFB1
C6E0B1E5FED4EDFFE0F1FFDFD6E1B7CED8A6C4CE9AC4D199D0E2A4CEE5A1C3E398C9EB9E
C7E79BC5DD93DEEBA6D2D7975C5A21A09965E7DDACD8D8A2CEE5A1C2E498CCECA1D5F3AB
CDEBA5C5E29FC8E5A5CAE6AB607D471E3E0C001A000010004E7B54B9E7C31B4D2A3D6F49
548450B1DEA5BAE6ABC4ECB0C1E3A7D1EDB3D6EBB24F6328
C8C69F7071496B6C4232350A4046187F87567D8753727F4964753ECFE3A8D5E9ACA5BB7B
97B06FAAC381CAE5A2C9E7A1C2E49AC3E79DCDEFA5BDDF95C9EB9FC7E79CD1F1A6C9E79D
CFEEA2C6E599C3E495CCED9ED2F3A2CCEF9BC6E995C5E494D7EC9FD4E49BD1E19AD9E9A2
C4D58FD6E7A1CDE19AD5E9A1D0E69DCAE296C7E396CEED9FD0F1A2CBEC9DC6E89BC5EA9C
C1E899C7EE9DC5EC99BFE693C9EE9EC6EB9EBADE98CBEEACC3E6A6C7EAA8C5E9A1C7EC9F
CAEF9FBEE491C4EB98CEF3A3C1E198CAE5A0D4EEA7D2E8A0C6DA92D2E19CE6F1AF677132
5E682C6F7A4094A169B4C68ABCD292D6F1ACC2E096D4F0A6D2E39FD9F0AAADD98CBDF6A5
B5F3A0BFF4A2C8E89DD5E49FA5A565989756DEE5A2D2DF9ACAE098DCF3AB899D5693A961
DBF5ABBCDD8EC6E999C9EE9EC7E899D4F3A5CCEB9FCBEA9EC8E89DC7E79CC2DC95E0F4AD
D5E29CDCE69FD8E29BD2E297C8E799BEE393CBEE9ED8F7A7A2BE71789044A1B66BCBDD93
D9E9A2D0E19BCADB97D3E6A6D9EDAECDE3A5C7DFA1C8E2A5C6E2A7D4EDB3C9E1A3CBE1A1
D6EBA8D3E4A0DAE9A6D6E5A4D0DB9FE9F4BCC8D4A2D5E3B2DFEFC0F7FFDBE5F8CBC8DFA9
D3EAA4CEE698D0E69DD4EAA1C8E595D5E59EDCCF9B3E21004526147E6D5BD3DFB9CCE7B4
C7DEA6DAEDBFF5FFEFEAF8E9F8FFF1FEFFECCDCCB0DBD7B4FFFFD8D6E3ABBEDD97C4ED9F
C1E897CCEB9DD8E39EA0A06257521ACECB98CED5A1D2E1A6C8E49ACBEA9CCCEB9FCBE79D
CAE5A0CDE6A4CBE3A5C7DFA363784098AC77BDD19EBBCF9E90A174A8B98D94A5795B714A
95B4946487676284631F411C5F7F56113004000E002C4818
41411B7A7A548888628D8F67969C702830015E6836818E59829158CEE2A5D9EDAEC9E09C
C9E29EC8E39CD0ECA2CAEA9FD2F8ABC5EEA0BDE396CCF1A4CBF0A2CDEFA2C5E599C9E89C
C8E799C9E89AC9EA9BC9EA9BC4E795C3E694C6EC99D0F1A0C3DD93D3E9A0CAE097DFF5AC
D3EBA1D7EFA5D4ECA2D1EBA1CEE89ECCE69CC9E59AC8E79BC9E59AC7E69AC9E89CCCED9E
CAED9BC9EF9CCBF0A0C6EB9DC9EDA3CBEFA7C8EBA7CDF0ACCCEFABCAEEA8CEF2AAC1E699
C2E799D2F7A7CBF19EB8DB89DDFDB2BAD58ECEE8A1D8EDA8D3E7A2CDDC996975334E5917
9BA765C4D390CFE09CD8EDA8D9F4ADC3E39ACEF0A6CAE59ED4DD9CD9E8A5C7F1A5BBF6A4
A7E894B4ED9CCBE9A1DCE5A492894EACA368E0E2A3D2E19ED6F0A9BDD891B7D18A829951
C3DF95CFEEA2C6E599CDEDA1D1F3A6B8DA8DC7E99CC3E598C8EA9DD0F0A4C8E499D1EBA1
BFD78DC8DC94CEDF98D8F0A6CAEC9FC8EFA0BCE193BCDC90C9E399DAF0A7C6D7907B8B44
B9C680CADA93DEEFA8C7DB93C7DF95CCE69CCFEEA2D8F8ADC4E5A0CBEAA7D4EEADC6DC9E
D6E5AAE5F0B68D945E525721A5A7753A3E0C8C9262DBE4B5E2EFC1F7FFDADEF1C3DCF5BE
C8E69ECBE79ACFE59DD3EAA2CBED99D6ECA1E8DDA76142232C0A005A473994A37ACBE8B0
DCF2B2E6F8C4F1FFE9F5FFFAF8FFFAFBFEF3B8B1A1B3A791FFFAD6D4DCA9C6E5A2CBF6A7
BFEA9ACCED9ED5E09B8F8F5169642CD6D6A2D8E6B1D2EAAECCE89ECDEC9ECFEEA2D2EEA4
CFEAA5CEE7A5CDE5A7D0E5AAE5F8C0E9FAC3DFEEB7EFFCC6D0DAA5A2AB769CA36FE1ECC1
D1E8CCC9E6D0EEFFF1C9E8C9B3D1ADCCECC3C7E6BA88A97A
C0C899D2DCAACDD7A5E0EDB8D9E6B17D8C55B6C58CCFE1A5BDD192D4EDABCCE5A1CDE99F
D6F4AACBEA9EC9E89CCCEEA1C3E99CBEE79BC0E99BC9EFA2C6EB9EC1E397C3E397CCECA0
C1E094C7E69AC8E99AC5E697C2E595C6E999CAF09DCAF4A0BDEC9BCCFDABB6E594C3F2A1
C1EE9DBDE898C1EA9BC1E899C6EB9DCBEDA0CCECA0C8E79BC7E398CBE59BCEE89ECFEB9E
CDEC9CC5E695CAEB9CCBEB9FC4E49BCBEAA4CFEEABBDDB9BD4F2B2BDDC99BEDD99D0F0A7
C9E99EC0E192C3E493DAF9ABBFD990DBF2ACCADF9ACDDE9A9EAD6A8C97555A632298A160
D3DC9BEAF5B3CAD694CEDF9BCBE29CD2EDA6C4E29AC7DC979193549AA060CFF1A7BFF2A3
AFE897BEEFA0D2ECA5D8DE9EB1AB6F8F894DE2E8A8C7DB96D3F1A9CEF0A6B6D68D7D994F
ABC27AD8EEA5DBF5ABB6D287D2F2A6C1E698C4ED9ECAF5A5C2EF9EC5F4A3BAE998C2F1A0
C8F7A6D1FFAFC0ED9CBDE898BDE495CFF4A6D1F3A6D1F0A4CCE89DD2EAA0D0E69DA9BD75
90A15A889952DEF2AAD4E8A0D0E89ED6F0A6C3DD93C0DF93D4F6A9BADC90CCEAA4C5DD9F
D1E2ABFCFFD6A9B086ACB08BF0F1CFACAD8B7B7F5CC6CCA6F2FDD3F7FFD8E4F6C6C3DAA2
C8E5A2CFEDA5CDE3A2CDE6A2C8EB9BCDE39AE6DAA67B5C3D2E0C008C7968A5B588A7C386
C8DD98EEFFC4EAF9DAF2FFEFF8FFF8F9FCF3BBB3A6A19682FFFBDBDAE2B3CAE8A8C3ECA0
C4ED9FD1F1A5D1DE989A9C5D232100C9CC95E0EFB8C3DB9DC3E199C0E094C2E297C8E69E
C6E49EC5E09DCCE6A7D8F2B5EDFFCBF7FFD3F7FFD3F8FFD1D1E3A999AB718C9B62C2D4A2
F2FFE6EEFFECE1FCD9D9F8CFCCE9BDCBEBB9BBD9A3CCEDB4
E0F2B8C6D89EDCF0B3D4E8ABB8CC8DCCE2A29DB372C1DA96DAF4ADD4F0A6C0DE94C1E094
CAEB9CC2E392C1E293CDF0A0C1EA9CC2EB9FD2FBADC0E699D0F5A8C4E69AD3F3A8CCEB9F
D1F0A4D3F2A6D0EFA3CBEC9DCDEE9FD0F1A2C9EC9CBAE492BAEE9BC1F8A4B8EE9AB7EB98
BEF29FC3F4A2C2EF9EC9F4A4BFE899C8EFA0CCF1A3CAEC9FC9E99DCCEB9FCBEA9EC7E69A
D1EDA0C4E093C9E59AD2EEA4C5E09BCCE7A4CDE7A89AB475546E2FC6E0A1D2EDAACEE9A4
C6E298C7E398CEEA9DC8E396CEE49CE0F4AFC9DA96B9C885384301697231E0E6A6D1D797
D4D999EBF1B1DFEAA8D1E09DCBDF9A9AB16B8CA65F90A15D767235676729CCE39DC5EEA2
BFF0A1C6F0A4D3E8A3D4DA9A9C985B4B490CD5E09ECBE09BC1E399D4FAAFC4E89ED0EEA6
94A55F83904ADCECA5BFD38BD5EDA3D7F6AABFE194C9F2A3BFEA9AC6F5A4C2F3A1B1E592
B1E592B8EE9AB1E793C3F2A1CBF0A2C7E79BC2E195D4F3A7CFEBA0BED88ECFE99FDCF4AA
CCE299D9EFA662782F687E35D2E89FC7DF95EDFFBBCBE79ACAED99B9DC8ACEECA4D7F0AF
D0E2AEFBFFDDC5CAAAEFF1D9F1F3DDE6E5D0E4E6CEEFF4D6B8C09BEAF5CAE7F5C4CADFA6
C8E5A3D2EFACCAE2A4CAE3A1C8EA9EC7DD95E7DBA9927354543226DAC8B4CDDAAC698342
869B50D7E6A5F2FFDAF8FFF1F9FFF8FEFFFAD9D1C6A8A08DFFFFE2DAE3B6CBE7AABDE29C
BDE398C5E399CDDC979A9F5FE6E5ACF2F7BDD1E0A7D0E8AAD0EEA8CEEEA5D6F5AFDFFEB8
D7F4B1C5E2A0C2DF9FCDE9ACDEFABDDCF8BBE0FABDD9F3B4CCE6A5DAF4B3B7D08F698248
C1DBACDEF9CEDAF5C8EDFFD8C0DDA7C8E5ABD1EFB1C6E4A4
BDD893C5E09BCEE9A2CAE59ED9F4ADD5F3A982A056C7E69AC5E498C7E698C9EA9BCAEB9A
CDEE9DCBED99C5E695CAED9DCBF1A4C1EA9EC3E99EC1E59BCDEFA5C8E89DC8E69CC3DF95
C5DF96C8E298C9E399C7E398CAE69BCDEC9ECDEC9EC8E99AC3EA9BBCE597CDF3A6BDE396
C4EA9DCCF2A5B9DF92BCE295C2EB9DC3EC9EC3EC9EC1EA9CC2EB9DC5EEA0C3EC9EC2E799
D2ECA2CAE097CCE29ADAEFAACCE1A0D1E5A6CBDFA27D9156001100DCF0B3D7EBACCADF9E
D1E6A1D0E69EDFF5ACD0E69DD4E59FC4D390B7C38175803E6E7434C1C686DEE3A3D9DE9E
DFE1A2E4E9A9CAD392D6E19FD9E8A53A4E099CB16CBAC684C3BA7F837A3FD6E5A2CAE8A0
C7EDA2C4E69CD0E49FD9DF9FC6C6885B5D1ED1DD9BCFE6A0CBEDA3B0D98DC5EEA2BEDC94
BBC4815B5A1AC9C989E1E6A4D9E29FCEDD98CBDF98CAE49BCEEAA0C5E59ACCF1A4C2E89B
CEF4A7D6FCAFC2EB9DC4E99CC7E69AD1EBA1C3DF94C7E398CFEBA0CAE99DCEEDA1C4E397
D5F1A6C8E298AFC97F8EA65CB3C980D0E49CD5E9A1C0D88AC3E78FD2F9A0C8E89CCCE6A5
C8DCA9F7FFE1D0D5BEC9CBBDFFFFF4FFFFF4F9FAEAFFFFECE4E9C9BEC69DCDD9A9D5E6AF
C4E1A1CDEBABC8E2A5CCE6A5CBEFA5CDE49EF2E6B4A283665A3628E2CDBADCE8B6A7C07C
A0B163DBE8A3CDDAAED9E3CBF8FFF5FFFFFBF1EAE2B6AF9FF8F7DBD7DFB6D5EEB5C8EBA9
C8ECA4D6F4ACD0DF9C828B4AC9CD92D0D89DC7D69BD3E9ABC5DF9EC9E6A3DBF8B6ECFFC7
E6FFC3CFECACC4E2A4C9E7A9C7E5A7CBE9A9DEFEBBD2F3AEB8D992C0E19AD3F5ABC3E29E
7F9B61C1DAA3C3DCA3D2EBB1CFE9AAC8E3A0CEE9A2C5E197
CEEEA3D6F6AABCDC90CCECA0CCECA06C8C40A8C97AD9F8AAC1E092C6E595D5F4A6CDEC9C
C8E797CEED9DC7E696C8E799C4E69AC5E99FC1E198D6F6ADC4DF98C8E39CC6DD97DCF3AB
D8EEA6D8ECA5D8EEA6D5EBA2CDE59BC9E197CFE79DD7F1A7D2F0A6C2E297D1F1A6C1E196
C5E59AD1F1A6D5F5AACAEA9FD0EEA4CCEAA0CAE89ECBE99FCBE99FCAE89ECEECA2D6F2A8
CFE59CD1E29CCEDF9BDBEBAAD0E0A2D5E4A9D0DFA679884F000B00D5E4ABC5D499D0E0A1
E0F0AFCDDE9ACCDD97CBDC9662712E9EAD6A7D89478B9654EEF4B4CED494D5DA9AD4D999
DFE4A4C3C989BBC483808B49859451D6E7A3CEE39EDFEBA9EFE6AB9B9257D5DE9DCFE49F
CFEDA5C7E29BD1E29EDCE5A4D5D7984E5313E0ECAAC7DE98DCFCB3C2E89DD2FBAFCAE8A0
D6DF9CE0DF9F949454636524B3BA779CA56298A560D8E7A2DFF0AAC0D48DD6ECA4C9DF97
CCE29AD3E9A1CCE39BCEE59DCAE097E1F7AED5EDA3CDE79DCBEA9EC6E69ACAEA9EC3E598
C8E89CC0DF93DBF7ACD8F2A8A6BC738CA058A3B46DD2E99BC9EC92D6FDA2B5D886C9E6A3
CEE5AFE4F4CDE2ECD3DDE1D2D2D4C9FFFFF6FDFEF0F8FAE5FDFFE353573292996DD5E3AE
C8E5A5CAEAA7C8E2A3CCE9A7C8EDA0CCE39DEDE1AF8E6F52D8B4A6FFFBE8D4E0AEC4DB95
839144D5E09BCCD5A8E7EFD7E1E6DFF6F6F4FFFEF8DAD7C8FFFFE7E6F0CBE3FAC6D0EEB0
C6E5A1CCE7A2D0E19DBDC788535C1D9EA86BBFCF91C8DE9ECFE7A9CEE8A9D4EEAFDAF4B7
D5EFB2CBE5A8C9E5A8D0ECAFD1EFAFC5E5A2B5D691B3D78FD6FCB1C7EE9FBDE697D1F6A9
D0EAA9A0B87A8EA464BED795D5ECA6C5DF95D9F1A5D0EB9C
C1E396CBEE9ED5F6A7BDDE8F8FAE604B6A1CC0DF91D0EC9FD1EDA0CAE699D7F1A7C8E396
C3DB8FD1E99DCBE397CDE59BCCE69FD2EDA8DBF2AEC3DA96CFE2A0D3E7A2E0EFACD2E19E
D9E5A3CDDA95CCD994D9E6A1DBEAA5D2E29BCCDD96CEE49BCCEAA0C7E99DC6E69BCEEEA3
CBE79DBFD990E9FFB7B6CA83CEDB96CFDA96DAE19EE6E8A7E0E0A0D4D393DBD798E8E8A8
CDD894D9E8A3D0DF9CD7E6A5D0DEA1D9E7ACE0EDB793A06A020F00D1DEA8E0EEB3D7E5A8
D3E1A3E1F0ADC0CF8AA1B06B5C6B2841500DD3E29FCDD997D2DD9BE9F2B1D2D898E2E8A8
D4DD9CA5B06E4D5917D2E19ECEDF9BD0E49FD5EAA5C8D794D9D79A9B975ACCD594D2E6A1
D4EEA7CBE59ED0E49FD9E5A3DCE2A2575D1DD3DF9DDAEEA9C6E099BADA91B7D98FD6F4AC
CEDF99DCE9A4E3EEAAE1EEA9D4E19CD0DD98D4E19C8B96523F4A064E5714C4CB88E6EBA9
DEE09FD4D695D8D898DDE2A0CDD893D7E8A1C6DC93CAE49AD7F6AACDEDA1C8ED9FC7EC9E
C8ED9FC4E699C7E69AB9D389E1F7AECCDD964D5D16D5EA9DC1E289C8EF94BDE08EDAF8B0
DCF4B8C7DBAACBD9B5D7E1C6CBD0BAA0A390FFFFEDFFFFECFFFFE6D6D7B7C9CBA6D4E0B0
CFECAAC5E99FC7E4A1CEECA6C3E89AC9E098E4D8A66C4D2EFFDBCFF9E2D0D5DEAFD3E8A5
8D994FC6CF8CD7DEB4D9DEC8DADDD6E9E9E7FFFFFAFDFBEEFFFFECFCFFE3EEFFD3CDE6AD
D2EFAFBFD896CFE2A0DDEDACCEDD9C7A8948354808324607CFE3A6D2E6ABD4E8ADD4E7AF
D1E4ACCEE3AACBE3A7CCE4A8C1DB9CCFECAAD1F2ABC2E69CD9FFB1BFE995B7E38EC4EB9A
BED992C6DD9992A7628DA45CC6DC91D9F1A3CAE191CDE693
CCECA0C5E599C6E599668539839F54D7F1A7D0EAA0CDE59BD3EAA2C4DA92D6EAA3D1E59E
D2E39DE1F2ACD6E5A2D5E4A1DAEAABC9D99AD2E0A26F7B3BD0DA9BD2DB9CE3E9AB767C3C
5D62224D52125E63239AA15ED2D996E1EAA7DCE5A2D7E49FCCDD97DAEEA7C8D993DDEEA8
B6C5806A79348D98542029002C3300353A004E500F6161215453133A39003D39004E4E0E
454E0B5E6B26515D1D535F214E591D5C672F6E78432E3804010B00606A356D78406A7539
4753155864224E5A1874833E8C9D59D6EAA5D6E7A3D0E19DE0EFACC6D290EAF6B4CCD896
9DA9676E7D3AB7C884CEE29DD2E7A2CCE39DCBE59ED4E8A3D5DB9BA9AE6ECFDB99D2E6A1
D0E7A1CAE19BCFE49FD5E6A2DBE6A44B54132E3900D5E19FD6E7A3DDF2ADD6F0A9C3E199
D3F1A7C0DE94CAE69CCCE69DCCE69DD6EDA5CDE39BDAEBA5D8E7A2838E4A9EA76499A05D
9A9C5BA4A464A4A4649496558A944FC8D891D7EBA3D1E99FCCE89DC1E396C7EC9ECBF2A3
C5EC9DCCF1A3CCECA0D7F3A8C0D68DE0F1AAB0BD77B2C47AC8E893D4F8A1CAEB9ABEDD91
C9E4A1CFE7ABD6E8B4D0E0B3CCD6B1B3BA99C5CAACE6E9CCEEEDD1FAF9DDD4D3B7E9F2C7
CDEBA5BFE494C7E59BD2F0A6C7ED9AD2EAA0EADEAA644324C49E93856E5EACB389C0D497
A6B06BA0A668E4EAC6E3E7D6ECEDE8E9E8E6FFFFFAFBFDF0FDFFEBFBFFE4F3FFD8CFE3B0
C6DEA2D3ECABD1E6A5CBE09DD2E5A3DCEFAD9FB4716376366170357E8D56A6B57EC8D7A0
DFEEB7E6F5BEDCEEB4CFE3A6D4EAAABFD896D0EEA8C6E69BC0E595BCE48ED4FEA8C6EC97
D7F1A7CCE29AD2E89FB6CC81647B2DA1B868DAF19FC5DC8A
8DA75E7791488EA861D5EFA8C6DD97DCF1ACCBDE9CD6E6A5D2E0A2D4E0A2E0EAADD6E0A3
6D75399CA2669B9E65969960A4A96F313400686B329D9E647A79409F9D64EDEBB29A955B
59541ADCD89BA3A164615F22B8B87AE3E5A6929455A9A76A63591E6051185E52187E7439
ABA267918D509F9F619BA060DDE6A5CBDA97D9EAA6D2E7A2CFE9A2D2EDA6C1DF97D1ECA5
B7C88294A15C919D5D95A16395A0648D9860949E6957612D06100096A06B8D986099A468
B8C486DCE8A6CFDB99D5E49FD5EAA5D3EAA4C5DA95D3E8A3CADF9ACDE19CE1F5B08DA15C
96AA65D4E9A4D4E9A4CEE59FD6F0A9D7F2ABBBD991D4EEA7C7DB969CAD69AABE79D5EAA5
C9E09AC7DE98E4FBB5C1D691CBDA97BBC684505616696F2FE4EAAACCD795CEDD9AD7F1AA
C6F0A4C2F3A4C3F2A4C1F0A2C2ECA0C3ECA0C7EDA2CBEDA3D1F1A8C9E49DC1DB94D4EBA5
CDE29DDBEFAACDE19CDDEEA88C99537B884274853EA5BD73D2EEA3C9E99DC0E597CCF3A4
CBF2A3C8ED9FCAEC9FC7E69AD3EBA1CCE098D4E49D8FA059789447D2F3A4C2E394C6E597
D6F2A5C7E197C8DF97CFE4A1D1E0A5D4E1ACAFB68AD6DAB5E4E3C7FFFFEACCC7B4F7FDD9
C1DF95CEF59CC6E693CCEB9BCEF49DCAE193DDD09C6F4D31D2ACA3140000646A44CEE1AA
B3BC7DA8AD77FFFFE8FFFFF6FFFFFBF2F1EDFFFFF8E4EBDBFBFFEDF7FFE2E6F5CCD3E3B4
CDE0A9D2E8AAD4EAAACDE6A2C9E29ECEE59FD3E8A3D5E5A493A16689945C58612C8C9560
C4CD98FFFFD3DCE7AFDBE6ACCADA9CDEF1AFCEE59FCBE59BD4F3A5C2E591CCF29DC9EB97
CAE49AD0E69ECCE299D3E9A0C7DD9292A95B8EA557CAE191
8196532D4200CDE2A1CCDF9FD4E4A5D2E0A2CED99DDDE7ABDFE7ACDCE1A9D2D59EBDBD87
2B2A0055541E5C592673703B89865158531CB7B27BDED7A1B4AA75817841B2A7717F743E
5C511BE9E0A7B9B0775A5418AEAA6DE2E0A3525214524E11695D2397884FAA9E64C1B77C
E4DEA2E8E8AAE9EEAECAD593D6E7A3C8DF99D0EBA4C5E79DC2E89DC7F0A4BBE599C9EDA3
D4EAA2CEDD98DAE9A6D7E6A5D4E2A5D4E2A7DCE9B399A670000A00CCD9A3E2F0B5DAE8AB
CBD99BD0DF9CCEDD98DBECA6CEE59FCBE59EDBF5AECDE7A0DCF6AFD1EBA4A8BF79809751
CAE49DD3EDA6C8E39CC3DE97C0DE96C7E79EC9E9A0D7F7AEDCFAB29FB9728AA15BCDE29D
DAEFAAD2E9A3B9D48DDEF8B1DEF3AED9E8A55359193A3C00E5E5A7E3E5A6DAE3A2CFE49F
BBE196BBEA9CC1F0A2C4F0A3C1EB9FBFE89CC1EA9EC7EDA2C7EBA1C9EDA3CEF2A8C3E79D
C7E99FCAECA2C3E79DBFDD93D8E9A3A6B66F93A45D82984F94AE64C4E397C8EA9DBEE395
C3E89AB2D789D7F7ABC9E89CC6E096DAF0A7DAEBA4D2E69F738D4698B66ED5F4A8D2EF9F
C6E38FCEEC96D5F19CD2EB98C2D78AE5F6B2C6D19963693DFFFFE4FAF5E2BEB6ABFFFFE6
CDE99ECBF093C5E28EC6E391C3E78FD0E799EADDA968462BD2A9A56D524B939977DAECBA
EBF5B9A3A775FFFFECF6F7EFFAF5F1FFFFFAFEFFF6E4EDDAD4E1C7F0FEDDFAFFE0D7E2B7
DAE8B5D6EAAFC4DE9DC5E39DD6F4ACCDE99FC4DA92D5E6A2DAE5A9D1DAA1929B646B723C
6A713BCDD49EE9EEB8D1D9A0D4DEA2DBEAA9D7E8A4D4EAA2BCD78AD4F1A1C9E996C4E393
CCE69CD4EBA3CFE59CD2EAA0D2E89FA6BE72879D5298B064
CDDD9FE9F9BBBECC8FD5E3A6DFEAAED6E0A49DA56C22270040430C6C6C38CDCB98BFBC89
5C56244B4312F1E6B8E3D9A8E0D6A3F2E6B4CEC290F0E3AFF0E3AF5D4D1AB4A4718B7B47
6457228E834DFEF5BEE9E3A9757036C2C085DCDCA0EBEFB2CBDA97D9EDA8CBDF9AD0E5A0
CEE39ECAE19BC9E39CCAE59ECEE9A2C8E69ECDEDA4C4E69CC4E69CCCEEA4C4E89ECBEBA2
C7DD95D0E19BDCEDA9D0E09FCFDFA1D2E1A6CDDCA379884F000F00D8E7AECFDEA3D0E0A1
D5E5A4D7E8A4D5E6A0D1E59ECCE69FCEE9A2BED992D1ECA5D0EBA48CA7606A853EDCF7B0
D1EFA7BFDD95C9E79FD5F5ACCFEFA6C8EAA0C9EBA1BEE096B8DC92D0F2A8A4BE77D7ECA7
C1D691E4FBB5BFDD95C1E198C1DC95C9DD98E0E6A69494564F4B0E403E01DBE1A1DBE7A5
D5E9A4D0E7A1CFE6A0D2E9A3D6EDA7D5EFA8D1EBA4CBE69FC6E49CBFE197CCF0A6C2EB9F
CCF6AAB6E295C5F4A6CFF8AAC9E098DFF0A9DAEEA6D8EEA5A5BF7590AC61C7E69AD0F0A4
C6E89BD7F7ABC8E89CCDECA0D2ECA2CBE399C4DA91D4EAA2D3E9A894AD6BBDD78ECEEB9B
B4D27AD1F093D0F08FBFDC7FD7F198C9DE8FDFEDAF8F9766DADBBBFFFFEDE6DDD6FEFEE4
D0EAA1CAEB90CAE692CBE695C6EA93DDF2A7F3E5B666442BFFD8D6614541727757BED0A0
D6DFA6B5BB8BFEFFECFFFFF8FFFEF6FFFBF0FCFFF3F5FFECC8D8BBC0CFAEC7D1ACCDD4AA
D2DCAAD5E6AFD0EDABC7E8A1C1E59BCCECA1D5EDA3D1E29CD3E2A1DCE8AAD8E2A6D2DA9F
ABB37A6F743C656831999C63DAE0A4D5DE9FD7E2A0D1E09BE1F5ADBFD78BDBF6A7CCE999
C9E399D4EEA5CDE49CCAE49BDCF3ABD3EDA3C4DC92C5DF95
CEDCA1CBD99EEFFAC0CCD79DD9E2A9D8E0A7575C244D5019666632D7D5A2EBE8B5E8E2B0
E8E0AF998F5E5046153A2E00D9CB9CEFE1B064542363532211010062521FA39360DCCF9B
F2E5B19F965FD1CA93E3DEA65A5A1E9B9C60D2D699D1DB9CD4EDA9D1F1A8C2E299D5F7AD
C9EBA1C3E59BB9DD93D0F4AAC3E79DC5E99FC8ECA2C2E69CC2E69CC8ECA2C5E99FC5E79D
D5EFA5D4EAA1D3E9A1C7DC97D3E8A7D5E9AAC1D598677B40000D00CFE3A6C2D697D3E8A7
D8EDA8C7DD95CBE198CCE49AD3EDA4D3EDA6CEE8A1CBE69FCCE7A08DA861C4DF98C4E29A
D1EFA7C1DF97C7E59DCBEBA2CCECA3C8E89FCFEFA6C6E89EC9F2A6B7DB91546B25879854
DAE9A6C8DD98CAEAA1CAEEA4CFF1A7D5EFA8D2DD9BE5E5A7EBE7AA5E5C1F414A09596422
DEE3A3DDDFA0D7DC9CD4D999D4D999D8DE9EDBE6A4DCEBA8DEEFABCBE29CBFDA93BEE096
CBF1A6BCE69AC4F0A3C1E79CD6F0A7C2D68EC4D890CBE198D1E99F819B51496319B9D58A
D9F5AAAFCE82C8E79BDAF6ABB5D186D8F4A9D2ECA2C3DD96D3E9A9819556D5ECA6D0EB9C
E2FEA9CAE98CC1E082D8F799CDEA90CFE696DBEBAAD8E0AFD1D2B2FFFFEDEDE4DBFFFFEA
D0E7A3D2F09AD2EA9ECDE59BC9EA9BCCE09BD3C297633E2BF4CACC1F0300727759C8DAA8
D7E1A5939A67000500DEE0D3FFFFF3FFFFF1EDF6E1F7FFECF5FFE8B3C39FF4FCD7EBF0C7
D4DCADC3D29BD0EEAECEF4ABB1DA8EC8EA9DE4FCB0C9DE93D8ECA5C7D894DDECABD5E1A1
D6E0A3E9F1B5CACF954E5118575B20E3E9ADCCD596D9E5A3E2F3ADD7EBA4B8D086D8F2A8
CAE69BD5F1A7CDE99FC1DD93C6E298CAE69CCDE99FDAF6AC
E4EFB5D4DFA5C8D399D9E4AAD2DBA2D6DEA5E0E5ADD0D39A6F6F39292800A19E69DFD9A5
CCC692EFE8B4C4BD897C723F716535E6D8A9A99B6C554716AFA170E1D3A2D7CB99F8EEB9
63592466612A8F8E55A8A96F50561A919B5EE1EDAFD7E6A5C3D895CEE7A3C4DD99C7E29D
C1DF99D4F3ADC5E69FCBEFA7C5EBA2C9F1A8C7F1A7C6F2A7C6F2A7C4F2A7C5F3A8C2ECA0
CDEDA1C5E194C0DC91BFDB91D2EDA8CDE8A5C3DD9E839D5E001700DAF4B5CBE6A3D0EBA6
CCE89EC5E196D2EEA1D0EB9ED1E8A0CAE19BCAE19BD8EFA93E550F748E47E7FFBAC7E29B
C9E49DD5F0A9CFEAA3C6E49CCDEBA3CFEDA5C9E79FCCECA3C5EBA0CCEEA48B9C5856611F
D6DF9ED0DF9CD0F0A7BAE397B4DD91CEF0A6CDDE9AD3D999D7D99AD7DC9CC6D5928E9957
76703692834CAA9B64ADA069A1945D92874F8E854C8E894FD5D398E7EBAED8E2A3E2F1B0
D2E7A4D0E9A5D4EFAACBE69FD0EAA1D7EFA5D2EAA0D5EBA2B8CE85D1E79EE3F9B06C843A
ACC47ADFF9AFBDD78DD3EFA4CBEA9EC3E296D2F2A6CEEAA0C8DD9CE4F4B5384C07B3C980
BDD887C6E38FD5F29EC8E591CBE898C9E09AD0E2A6D5DEAFDADEBDFFFDE6FDF5E8DBDBC1
C9DDA0D3EDA4D0E3A3CADE9FD6F4AED1E1A3DECCA8AB8676FFE0E4B99D9AAAB190D6EBB3
CFDB9BE3EDB1C1CBA8CFD4BEFFFFEDF2EDD9F6FFE7EFFFE3F4FFE6BDCFA98E946EC6C79F
E3E6B9CFDEA7C8E6A6CAF4ACC3EFA2C2E99ACEE69ACEE396CDE89BCAE49AD2E9A1CADE97
E5F6B2D0DC9CD8E2A5E5EDB1969E63545C21A1AB6EAEBA7CC8D796D0E3A1DAEFAAC9E39A
C3E296CAEA9ECDEDA1CCECA0C8E89CBFDF93BFDF94C9E99E
CBD69CDBE6AAD4DFA5E0EBAFD5DFA3D8E0A5D3DBA0D4DA9EE4E8ADA5A66C5B5A2148470E
F4F2B9DDDBA2D5D098EDE6B0A69A68544818E8DCAC6D61314E421082784540360366602C
D4D19ADEDFA663692D4953169EAC6ED5E5A6CDE0A0C8DE9DDFF6B2D9F2AED1EAA6CCE5A1
CBE6A1D3EEA9C0DE98CCEAA4C4E39DC7E8A1C0E19AC9EAA3C7EBA3BEE29AC5E9A1C1E59B
CBEE9EC9EA99CBEC9DCAEA9ED5F5ACC8E7A1D1F0ADB5D393001000C3E29FC6E5A1C5E59C
BEDE93CEEFA0D8F9A8C7E396D7EDA5CEE29DBCD08BDAEEA98FA45FDAEFAACAE19BC5DC96
C9E09ADCF3ADC6E099C7E19AC8E29BD7F1AAC4DE97CAE59ED1F3A9C6E49CDDE8A6DADC9D
999B5CDEE9A7BDDD94C4EEA2C3F2A4D1FAAEC7DE98E2EEACDDE6A5D8E3A1CAE19BD3E7A2
838347796E366459215A4D165C4F1863561F655A22665B23655C235D581E59591DBDC184
DFE8A9D9E5A5D1E09FD1E5A0CFE69EC2DC92D0EAA0CEE69CE2F6AEE1F5ADBCCD86D6E7A0
7C9048D6ECA3D4ECA2D3EFA4DBFAAEBFE194B2D789D1EFA5CDE19CDDECA9D7E8A491A55E
DAF1A9D0ECA2BFDD93CEECA6CDE7A6D9F1B5D7E9B5FCFFDDF9FFDD68684E595440D9DABB
D2E3ADD1E7A9CFDDA8C6D7A1D3EDB0D3E0ABEFDABBDCB6ABF7CDD1140000656D48E9FEC3
D9E6A0C7D391CDDAAEA4AB8CFFFFE7EAE6CDE0EECDC3DBB7C9E2BBF7FFE3ABAF8AECEAC3
CBCCA0FCFFD4EFFFCEBCE79FC6F5A7C6EFA0C0DB8EDCF3A5CCEE9ABADD89D7F8A9CFEBA0
C1D890BFD38EDFEEADCCD89ADAE4A8BFC98D454F13A1AC70CEDEA0C3D696E0F5B4CFE9A2
C8E89CBEE491C4E797CFF4A4D5F8A8CDF2A4CCEEA1CCF1A3
E0EEB1C5D395D1DFA295A1638B97592E3800646E31D8E1A2D1D799DFE3A69CA161808243
D4D496C0C082C6C585D5D096817744605625E9DFAE9389587169383630007F7945B8B781
DBDEA5DFE7ACDBE6AAD0E0A2CDE2A1C3DC9AD4EFACCEEDA9C2E19BBCDD96CBEAA4C3E19B
D3EEA9D1EAA6C4DB97D1E4A2DBEBAADAE9A8CFD99AE0E9AAE2E8AAD2D89AE1E5A8DEEAA8
C5E194C5EB98C7EC9CBFE496C6EAA0B7DB93C5E8A4B5D894002100B3D791D2F6AEDFFFB7
C1E698BFE494C1E794C1E090BED28BDDE9A7C8D79461702DD3E4A0D0E19DD4E8A3DDF1AC
DFF4AFC3D89394A964AABF7A9DB16CD1E5A0D2E6A1DBF2ACC1DF97CDE49ED6DB9BE5DFA3
666024DDE3A3D9F7AFB9E598AFE293C8F7A9C3E199C8DC97D5E4A1D6EAA5CBEBA2CFF1A7
D8EDAAD0DF9ECCD898D9E3A4EAF0B2E3E7AAC2C387A2A266A2A0658A884D626226757539
5253172D2E00797D40CAD593D4EBA3D5F4A8BDD78DC7DF95D4E8A0C7D891D5E59EE0EDA7
A9B97265762FD8EEA5C0DA90ABCB7FE6FFBDBEE596CEEEA2D4E59EC9D490D1E09B7F9250
A0B676C4DE9FC6E2A7C8E5ADC5E0ADCAE1B3DCEEC4FBFFE1FFFFE3FFFFE4F5F1D6D1D2B2
DEEEBFC9DBABDCE9BED9E6BBC9E0ACCCD8AAE5CFB7AF877FD5AAB1D4B8B4F1F9D2D7F0AF
D9EA9ADFEDA0DFEEB7939B748D886AFEFADDC5D3B0D3ECC4C9E2BAF6FFE0FDFFDA89855F
C2C195F9FFCFEDFFCCBEE9A1BAEB9CC5F0A0CEE99CDAF3A2BCE48CCDFA9FC6F09AB7DD8A
D3F2A6D5ECA4CEE19FD2E2A3CAD89BD5E0A4FCFFCDA2B07592A468BFD394C6DC9CC6E19C
D3F6A6C3EB95BFE592C1E895C1E794C1E897C2E797BDE493
AEBA7C7682424F5B1D9FAB6BACB878D1DD9DD9E5A5D2DE9E828D4B8C9755E4EDAA47500D
E2E9A6DDE4A1757A385F642477783FEFEFB9D4D49EE0E3ACDADAA4D8DBA4DDE0A7E0E5AB
DBE5A9D0DEA0DAECAEBFD594D7F2AFCFECA9C6E5A1C8E7A3CAE8A2D1ECA7C3DC986D8440
70854291A4629AA968919B5C999F6192965982824699945A9A945A887F469B92599D9D5F
CFE59ACFF09FCCED9EC4E397D2F0A6CAE8A2D5F0ADBBD693BED897EBFFC3BAD590CCE7A0
C8E49AD0ECA1CBE79AD3EEA1E0F1ABCBD795667532849350E1F0ADD2E39FCEDF9BD6E7A3
CEDF9B94A5616E7F3BAEBF7B95A461D7E6A3D5E4A1CCDD99C5DC96E1F5B0D7DC9CE0DC9F
D9D79A565F1E9AB46DD1F7ACCDF9ACB6E094D0F0A7DBF2ACCFE49FC3DD96D2F6ACB6DC91
CBEDA3CCEAA2CCE7A0CDE49ECEE39ED2E39FD5E4A1DAE5A3D6DF9EE0E9A8D3D999D8DE9E
E5EBABB4BA7A9CA56454601E697F37A2BC73DFF5ADD8E9A3C7D691DFECA7E1EEA9C8D58F
DAEBA4D0E69D627C32759146D2F1A5B9D88CD3F2A6C7E398CEE096DAEAA1D5E6A0D9ECAA
889C5DA5BD81D5EEB5CDE8B1CEE9B6C8E0B0DAF0C2C5D4A9F0F8D1F8FCD9D3D2B3C7C8A9
CBD5B3B2BD9DF0F6DCFEFFEAF5FFE0FFFFE6FFF7ECB48B89FFE1E2FFFBF1F7FFD6E6FABB
DBEBA0CFE092CADE9FD4E2AFBBBC94959571AFBE95C9E0B4CEE5B9F5FFDAFFFFDDFFFFD9
E4E5B99CA672A2BF7FD1F6B0C4EDA1C0E597D8EEA3CAE191C6E894C9F199C3EF98C0EC97
C8EF9EC5E599C7DE96D3E7A2D3E3A2DCECABCFE3A4C1D596697D40687C3FCEDBA3D9EBAD
C3E397C2E996CBF19ECAEF9FC2E797C7EC9CCCF1A3C5EA9C
7B8143575D1D929B5CE0EBA9D9E4A2CEDA98DBEAA7CEDF9BB1C27E4E5F1B839450677834
DCEBA8D5E4A1A6B57295A662AEC380CAE09FC8DE9DD4E9A8D4E7A7CFDFA0DFEFB0D1E1A2
D8E8A9C6D997CEE4A3C8E19DC9E7A1C9E8A2CAEBA466813C8B9A59AAB374B0B6786F7537
848A4C9A9E61969A5D9FA0649C9C60A3A367A2A0659C9A5F9893598B864C888349909253
B7C47EAFC47992A35C92A25B8A975297A2608E97589DA6679BA165919759959B5DA2A86A
8E9756848D4C767F3EA2AE6CDDEEAAA3B772596A26B5C682D3E4A0C8D995E3F4B0CDDE9A
D7E8A45D6C299EAD6AD2E19E919D5BBECA88D2DD9BD5E19FD2E6A1CCE09BD1DD9BE3EEAC
CFDA988594517F934EC9E39CCFEAA3CEE9A2D1EBA4CDE7A0C5E099C5E39BCDEFA5C3E79D
C5E79BCDEDA2C7E79CD3F1A7C6E298D0ECA2C7E198CCE69DCBE29AD1E8A0CBE29AD2E9A1
CEE59DD7EEA6D4EBA3879E56677B36778645BDC788D7DD9FDCE1A1D5DB9BDCE7A5D6E7A1
CFE9A0CAEA9FA5C77B638338DAF4AABDD189D5E09BDBE8A0CADF92C9E193D9EFA6CBE199
C2D69197AC69D9F0ACCAE39FCDE8A3C9E6A3CEE8A7D0E5ACE4F2C1F7FFD6A2A384FFFFEA
FFFFF1ACACA2FFFFFAFFFAF7FFFCFBFDE7E9FFF0FAFBCED5F2E5DDFFFFECFBFFDBEEF6C3
CEDA9CD8ECA7C0DB98D8F0B2D4E1ACB2BC8A8D9B6AC8DAA8DDEFBFF5FFD6FEFFDAF6FDD1
FEFFD777844F6F8147D5EBABD2E7A2CDE39AD6E69DD0E095D2E29BD1E99FBFE695C3F39F
C3F59EC1ED98D2F1A1D1E89AC0D58ADDF5ABD6F6ADBBDA96A5BF8075844BB1AD7EE6E6B4
D5EEAAC5EA9DC1E397C5E59CCFEFA6BFDD95D5F3ABC3E199
919757BCC282D7E09FD8E3A1D2E19ECEDF9BCEDF9BD4E8A3D7ECA7D5EAA5D9EEA9BED28D
D6E7A3C4D591E3F4B0CCE19CD8F3AEC4E39DE0FEB8C7E29DC2DB97D7EEAABED390D3E8A5
CDE09EDBF0ADC8DF9BD9F2AEAAC5808CAA64587731849F5A96A665C3CF8FE5EFB0C7D393
CED899D7E3A3D0DA9BD8E4A4D6E0A1D4E0A0D6E0A1D9E5A5DAE4A5D5E1A1D3DD9ED3E29F
CBDF98D4E8A0CEDF98DAEBA5D6E2A0DEE9A7D2DB9CDBE1A3D1D598DFE3A6E6EAADCFD597
A5AB6D8E9758838C4D96A2627B8F4AB6CB86CADE99E3F7B2D8ECA7CCE09BD8E9A5CEDF9B
ACBB78BCCB88D0DC9ACCD896C2CE8C95A05ED5E09EDBE7A5D1E5A0DAF1ABD2E7A2CFE49F
E3F7B2D5E9A49CB06B70843F667A35DBF0ABC7DE98CEE8A1DBF6AFC8E69ED3F1A9BBDB90
CDEDA2C9E99DC0E094C5E599C6E599D1F0A4D0EFA3D1F0A4DDFCB0C2E195C6E599CCEB9F
C3E296C4E498CCEB9FD2ECA3D8E8A76E783B505419919258EEEEB2D9DDA0E2EDABC9DD98
C6E49AC8EDA0C1E79AA4C67AA7BF75E4F1ABEBEEABD0D690D1E89AD4F1A1D7F2A5D1E79E
D9EDA6A8BC74C1D58DDCF4A8CDEA9AC7E698CAE69CC9E2A0D5E6B0E0EBC0959978FDFAE7
F9F4EEF8F2F2868080FFFCFDFFF8FBFFF5FBDFA9B6AB7E83DEDCCFF8FFECBABD9EDDDFB8
EBF5C3B8CC8FD3F1ABC6E49EC8DD9CDBEDB1A0AF743D4F15C5D49DD9E7B2BFCD9AE1EFBC
D5E2ADC4D39CA7B57A9AA86ACCDB9AD8E7A2D7E79EDAE5A0E2E9A6E3F2ADBDE295C5F7A2
B1E68EC4F59CC8EA94C1DA87DFF4A5C5E091B4D98CC1E79ED3F0B0A0AA75A99D73FFF9CB
C5D99AE2FFBCF1FFCAD1EFA9D9F4AFD0E9A5BBD28EDAEFAC
D0DF9CDEEDAAD1E29EC9DD98DBEFAAD7ECA7C8DD98CEE39ECBE09BC6DB96D5E9A4D3E4A0
CCDB98E2EEACDFEAA8CBDA97C8E29BC3DE97B5CF88D9F0AADCF1ACC1D590D4E8A3DAEEA9
D5E6A2CBDF9A243800475C178DA45ED1EBA4C6E19AD6F6ADBEE29AC6EEA5D2F8AFCCF4AB
C8EEA5D1F9B0C4EAA1C3EBA2CCF2A9BEE69DC1E79EC6EEA5C7EDA4C6EEA5C9EFA6C4EA9F
C7EE9FCDF2A4C9EB9ECDEFA3C5E39BCBE69FC4DD99C7E09ED4EAA9D1E7A6CDE3A2C9E2A0
D3ECA8D6F1ACD7F2ADCCE7A2D4EBA5D7EEA8D4E9A4C5DA95D2E7A2D0E5A0CFE39ED4E8A3
97A864D2E39FDCEBA8D5E4A1D1E09D8F9B59D1DD9BD1E29EC2DC95CDEBA3D0EBA4C6E19A
C6E099D0E7A1D2E7A2CCE09BDFF3AE8A9E593F540F99AE69CDE49ED2E9A3CAE19BD4EEA5
C9E39AD0EAA0DBF5ABD4EEA4D0EAA0C3DD93C6E096C7E197C9E59ABDD98ED5F1A6CDE99E
CDE99ED5F4A8C3DF94CFE9A0D4E4A3F9FFC6AEB476565A1DA0A165D2D699D2DD9BD6EAA5
C4E29AC7EBA1CCF1A4C8E89D8DA45CC7D48FD2D493DFE6A2CAE193D0ED9DC6E194C3D990
D5E9A2A5B9718A9E56CDE599D2EF9FCAE999CAE99DCBE6A1CFE2AAD2DEB09B9F7CFCFBE6
FFFFF6FFFFFAA8A69ABBB5A58E8371FFF9EAFFD1CAF0C7C1F4F5E5F3FFEDDEE0CB717157
C9D1AAD2E3ADE7FFC1C2E096D8F0A6C4DA91C6DA93CADF9A596C2CDAECAECCDEA2CBDDA3
D5E4A9DDEFB3E1F1B3C1D19245551497A864DBECA6D1DE99CCD594CFDE99C3E599DAFFB6
C0F29BBAE890CAEA95D8F19EC9DE8FC8E094D8FAAED5F9B1C0DA9B727C475F5427FFFFD3
CBDFA0D9FAB3F2FFCAD5F0ABD8EFABCEE19FC3D392DAE9A8
D7ECA7C9E09AD1E8A2D6EDA7C4DE97C2DC95D2ECA5D9F0AAEAFFBBC4D994D1E5A0E9F8B5
D3DF9DD9E2A1D3DC9BD8E4A2D7ECA7E1FBB4CBE29CCEE39ECFE39ECADE99DCEDA9C8D995
90A15D71823E91A25EB6CA85C2D792D6EDA7C3DD96C2E299CCF6ACBCEA9FB2E095BFEDA2
B2E095C4F2A7BDEBA0C2F0A5C5F3A8B8E69BBAE89DBEECA1B7E59AB8E69BBFEDA2BBEA9C
BFEC9BBCE996BBE697BCE798BAE397C7EDA4CDF1ABCAEEA8C7E8A3CDEEA9C1E59FC0E59F
BFE59CADD58CC6EEA5D0F4ACD9F4ADC0D791C3DA94C5DA95D8EDA8D1E6A1D9EEA9CADE99
93A762C1D28ECDDE9ADFF0ACC5D692A8B7748D9C59D4E8A3D2F2A9BCE096C1E399D1F1A8
CDEBA3C8E29BD3EAA4E1F6B1B9CD88DBEFAA8CA05B94A8635D712C7A8E49D4E8A3D1E5A0
D9EFA7C9DF96C8DE95C0D68DD8EEA5D4EAA1D9EFA6CCE49AD7EFA5C6E096CFE99FD2ECA2
D0EAA0C2DE93B9D58ADFF6AEC7D796D9E3A6E1E7A993975A606427BCC284D7E3A1D0E49F
C4DF98CCEEA4CAECA2B6D48AD8EFA95F6C27A0A565D8DF9BD1E89AD0ED9DCBE59BCCE29A
D7EBA4C1D58E8AA057D2EA9ED1EE9EC9E898CAE99DD0EBA6D0E4A9CEDCABB1B791FFFFE8
F6F8EDFFFFF6D4D6C0BEBD9EE7E2BCE1CDAAD1A48DD9B4A1D9DBC6F7FFF3FFFFF47C7A6B
3C4123DEEEC1B6D093D7F5ADD5F0A1C8E18ED5EC9CDBF3A5A0B66D798F47CDE29FD6EBAA
BCD190D9EEADB9CE8DF2FFC4D5EAA7A6BB785A6E29A0B16DE4EFADD7E6A1C2E297BCE795
BFEF99BBE790D4F4A1CDE695DAF1A3C5DD91BFDF94BADB94D5EDAFAFBA82554D1FE3DFAF
D4E9A8CAE9A3CAE5A0CFE8A4CDE29FD1E09FEAF4B58E9758
C8E39CC5E39BD0EEA6CEECA4C2E098CBE9A1D2EDA6BED992BAD18B677C37071B00374603
56611F4F58178E94546B7634435710E1F7AFD3E9A1D5E9A2D4E8A1CEDF99D1E09B283700
495813DDEEA8DBECA6BED28BE0F4ADC2D890DAF0A8DBF5ACC2E299C5E99FC6EAA0DBFFB5
C2E69CC3E79DC2E69CCAEEA4C8ECA2C6EAA0CCF0A6CFF3A9C8ECA2C4E89EC8ECA2CBF1A4
C5F0A0BBEB97C5F1A2C7F2A3C6F0A4CAF2A9CAF2ABB7DC97B6DB96DBFFBBBDE59FC5EFA7
D4FFB5C5F3A8C7F6A8B0DA8EC5E39BD1EBA4DEF8B1D6EDA7CDE49ECAE19BC3DA944E631E
96AB66DAEEA9CEE29DD1E5A0CBDF9AB5C682556622D3EAA4CDF1A7C1EA9EC2E89DC4E89E
CAEAA1D3EEA7CFE9A2BFD48FE6FAB5D5E9A4C9DA96DAEBA7DEEFABCEDF9B495A164E5F1B
3E4D0875843FC3D48ED7E8A2DCEDA7C3D48ED1E59EDBEFA8CCE29ADEF5ADCBE29AC7DE96
D6EDA5DBF5ACD9F3AAC1D890E1F1B0C7D192D9E2A3E3E9ABB9BF81A0A96ACCD898D9ECAA
D1ECA7B6D58FDBFAB4D6F1AAC0D592CDD997282C00D6DF9CD2EA9EC8E595D5EDA3D7EDA5
D4E8A3E2F6B1ACC27AD2ECA2C9E898C4E594C5E599CFEAA3CFE3A6CCDAA7C5CCA2FFFFE6
FEFFF4FCFFF4ECF3D48C92648A8B52ECDCA8B58E67CEAD8EFEFFE7F7FFF3EBEAE5DEDBD4
676A57DBE9C6CCE4B0C4E19ECBE793CCE98FD0EA93BEDA85C5DE8BD3EB9D40580ED5ECA4
D5ECA6D3EAA4D6EDA7B8CF8BD2E9A5D5ECA8C8DF9B90A45F94A05ECFDE99D0EEA4C2EC9A
BAE691C7F19BD1F19EC5DE8DC6DD8FD3EB9FDFFDB3C8E6A0CAE0A0A1AC74534D1DEBE9B6
CCE1A0D2F2A9CCE7A0CCE39DD0E49FD9E5A3DDE3A3515616
CFEDA5CDEBA3BFDD95C7E79EDAFAB1C2E299A3C179A7C57DB6D089B5CC86BFD48FDCEDA9
E8F4B2CAD593EAF3B2D2DD9BC1D58E869C548AA0588CA25A93A76098AC6597A862CEDF99
E7F8B2BBCC86C7DB94E0F4ADCBDF98D7EDA5CAE098C5DB93D3E8A3D6EBA6C6DA95D1E6A1
D5E9A4D5EAA5D3E7A2C8DD98CEE29DD1E6A1CDE19CCCE19CD4E8A3CDE29DC7DB96CDE79E
C7E99CBAE190CBF0A3C5E99FC1E29BBDDE99C0DF9CA1C07D072600B2D28FC6E9A5C9EEA9
B8E099B8E298CCF8ABC6EFA3C6E49CC7E19AC0DA93C5DF98CAE49DDFF6B0D2E9A34D641E
B9D08ADFF6B0D0E5A0CBE09BD7ECA7C1D69193A863A1BB74C0E49AC8F1A5CAF0A5BEE298
BCDC93C9E49DD5EFA8DEF3AEBDD28DD9EDA8CBDC98D5E6A2CEDF9BD7E8A4C0D18DC2D38F
94A35E8B9A558C9B5691A05BA3B26D9EAF6993A45E80944D90A65EC4DB93D1E8A0D6F0A7
C5DF96BBD58CD6F0A7CDE49CC3D490EDF9B9D1DB9CD4DD9EE7F0B14E581999A867C9DE9B
CFE8A4CBE6A1D2EDAAC8E19FDDF0B0DBE7A98A9054BDC788CEE69CBFDB90D1E8A0D1E5A0
C5D596D9ECAAA9BE79A9C37ACAE99BC7E899C6E69ACDEBA3CEE4A4CDDCA5D6DDB1F1F6D6
FBFFF2F7FFEFBAC5A3E2ECBA8B8F54A5995FCCA679D9B895D0D5B7DCEBD6FFFFFAFFFDF9
87897B687559D3E8BDCAE4A7C1DE8ED5F19AC8E48FDDF9A4D6F29ED5F09FA2BD7093AF64
AFC97FC2DE94DDF7AED3EEA7D0EBA4C5E099CFEAA5D2E9A3697835ACBB78A3BF75CBF0A2
C7EE9DCEF4A1BCDB8BDBF6A7D4EC9ECEE69ACEEAA0C9E49FCFE3A4969F665D5A27D5D59F
CEE3A0CDEBA3D2EDA6CAE19BDBEFAABAC6849CA564929757
C9E49DCBE69FD3EEA7D3F1A9B4D28A87A55D91B168C7E59DCAE8A0BCD790D8F2ABC6DB96
D2E6A1DFF0ACCDDE9AD0E19DD1E79FCBE399C9E197C8E096CAE097CCE299CDE39AD0E69D
C4DA91DDF3AAC6DC93E4FCB2BED68CCCE49AE0F8AECFE39CE0E6A6D2D4959A9A5C8D8F50
C0C082D6D899E1E1A3C8CA8B9E9E6097995A7676387173349B9B5DA3A5669D9D5FACB370
A4B56EA4BA6FCFE39CD4E8A3D7E7A6D6E6A7E3F3B5C5D499000B00CEE0A4CCE2A4D3ECAB
C8E3A0D2F0AACCECA3BBD991D5F0A9D1ECA5D2EDA6DDF8B1CEE9A2C0DA93A3BD768AA45D
D8F2ABC2DC95CDE49ECEE59FD2E9A3D1E8A2D9F0AA738E47C6E89EC9EDA3C6E89ECDEDA4
DDF8B1D1EBA4C3DA94CCE19CE0F5B0C7DC97DBEFAAD0E5A0C6DB96ECFFBDD6EDA7C4D994
D8E9A3D7E6A1D1E09BD9EAA4DAEBA5DDF1AAD2E69FCBE199D0E79F7D974E728C43BEDA90
DEFAB0C6E298C3DF95CFE9A0E4F5B1C8D492C9D492E1ECAAC0CA8B687434D0E0A1D1E6A5
D0E6A5D2EBA9C9DF9FC7DB9CCFDFA1D1DCA0ADB57AD4E0A2D5EAA5CDE7A0D6EBA8D2E5A5
D0DFA4D1E1A39CAF6F8DA45ECEEA9FCDECA0C8E89CCDEBA3D0E6A6D2E1AAE3EBBCE1E7C5
F0F9E8F9FFF4F0FDDFE0EBC1E9EDBADDD19D8D6740A88764D9DFBDD9E9CEFFFFF4FFFFF6
A5A799858F77E4F5D3D8F0C0CCE7A4D2EEA1CBE79AC2DE91BEDA8DC6E297D9F5AAB6D589
8EAA5FC3E296BDD98ECEECA2BBD98FDDFBB1C0DE96CCE69FDBECA8C0CF8C6C833B77964A
CCED9ECEEFA0BCD88BD3EEA1D0E89CC5DD93C1DB92D1E8A4DEEEAF9EA86C979660E4E7AE
D4E9A6C6E19AC2DC95CEE59FD8ECA793A4609AA664DCE7A5
D6EBA6C5DA95D8EFA9C3DD96819B548DA861C4E29AC5E59CC5E39BD7F5ADC5E39BCFEAA3
CFE9A2C5DF98D2E9A3D1EBA2CBE59CCFEBA0CAE69BD0ECA1D1EBA1CBE59BD0EAA0CBE79C
C6E096DDF7ADC6E096CCE69CD3EFA4D1EDA2C0DC91D5EBA2CED592C1C183727234414103
7474368787499D9D5F8A8A4C8181436F6F313333003030007A7A3C9D9D5F9F9F61BDBF7E
6C732F818D45CAD48FDDE6A5DEE4A6D0D59BD3D8A0ABB07A010800E1EAB3CED9A1DEECAF
CDDD9ED3E6A4CFE49FD9F0AACCE69FC8E39CC8E39CCCE7A0CEE9A2C9E49D9AB46DCFE9A2
D3EDA6C1DB94D4EEA7C8E29BC9E39CCEE8A1C1DB9478934CAAC57ECDE8A1CEE8A1C5DC96
D0E7A1CFE49FCADF9ADCF0ABC7DC97E1F6B1C9E09ACBE59ED7F2ABBCDA92C4E29AD5F0A9
C9DF97D6E7A1CEE29BD7EBA4C3D991CDE39BC9E098D4EBA38AA45B8BA75DC4E096CDEBA1
BFDD93D0F0A5CCECA1C9E59BD2E39FD3DF9DDEEAA8B4C07E687736B3C382DDF0B0CDE2A1
CCE0A1D1E5A6D2E4A8D0DFA4DAE7AF98A36B818A53DEE9AFCBE09FD0E6A5CFE1A5D0DFA6
E2EFB9CEDBA593A569889E5DCBE69FCCEAA0C6E49AC9E79FCEE4A4D3E2ABE8F0C1D4DAB6
FBFFF1EAF7E6F9FFEFFCFFE6FDFEDCD5C7A47B5437A28064E3E9C5D5E6C4FFFFEAFFFEEB
F2F4DF7A846CF7FFEDDBF1CDD2EAB6CBE5A8C9E1A3CEE8A7D3EEABD0EBA6C5E099D1EFA5
A0BE749BBA6EA9C87CCEEDA1C1E195CAEA9EC9E99DCBE79DD4E8A3DBECA8A5BB734D641C
D2EEA3C5E194D8F4A7C8E396D0E89CD3EBA1CDE39BD1E5A0D2DE9E8E965AA9AA71D0D59B
C9DE9BD6F1AAC1DB94D7F1AACAE19B92A762D1E5A0CCDD99
D8E3A1D2DE9C475613A0B16DC7DC97D4EBA5CAE59ECDEBA3CDEDA4C9EBA1C2E49AC6E89E
D0F2A8CBEDA3C4E69CCCECA1CAEA9FCBEA9EC9E99DC9E99DCAEA9ECAEA9EC9E99DC7E99C
CAEA9EC2E296CCECA0CCECA0CBEB9FCCECA0C2E195CFEBA0A1B56EBECD88D4E39ED6E5A0
D3E29DD4E39ED3E29DCDDC97D7E6A1D4E39ED2E19CD4E39ED5E49FD4E39ED2E19CD4E19B
D8DF99DDE39DA9AC698E905197985EAAAB728684519292600C0E00C9CD9ACFD6A0E0E9B0
E0EBAFC9D897D7E8A4CCE099C9E09ACFE9A2CFE9A2CAE49DC8E39CD4EFA84E6922D0EBA4
CEE9A2D2EDA6C1DC95CDE8A1D3EEA7CBE69FD3EEA7C5DF988B9F5AA4B571CBDA97BDCC89
E4F3B0CEDF9BD8E9A5CFE09CC2D691DEF5AFC9E39CD9F7AFC2E49AC2E69CCAF0A5CBEDA3
CEE9A2C6DD97CDE49ED8EFA9C7E19ACEE8A1CFEAA38AA55E819F57CBEBA2BFDF96C6E69D
CCECA3CCEEA4C4E69CC7E59DC8D993ECF9B4AEBA7856652293A362D8EBA9C1D695CFE3A4
A4B67A87965B5E6B336D7A42B4BE8979834EB8C28ED2DFA9A1B37997A96FCCD9A4A9B381
6A73445B6435515F2A384C11D6EFAEC9E7A15F7D37CAE5A0CFE3A6D4E3ACE8F0C1979D79
F6FFEAF8FFF6F5FFF4F4F7ECFFFFF4FFF5EB986D64D1AE9BD6DCB6D9ECBFEDF2CAF8F5D2
FBFEE1BFC7AFF4FFF0EBFEEADFF2D2E2F7D0E6F8CED1E7B8CAE1ADD6EFB6D1EBACC7E29F
C8E69E8AA85E7E9D51C6E597C5E697C7E899CDEE9FCCE89DD8EEA6D2E39FD0E19B8DA15A
AEC47BCCE49AC7E197D6F2A7CCE69CCEE69CD6E7A1CEDA98D4DD9E8B9155A5AB6FD1DB9E
CEE39EC1DB92D3EFA5D1EDA37F9B51C1DD93D6F2A8D0ECA2
E4E9A9CDD3939FAA68CDD997D7E8A4D5EAA5CEE8A1C8E69ECEEEA5CBEFA5C6EAA0C3E99E
C5EBA0C1E79CBEE499C5E99FC3E599C5E599C7E99CC9EB9ECBEDA0C9EEA0C7EC9EC5EA9C
C6EB9DCDF2A4C7E99CC6E89BBADC8FCCEEA1BDDD91D8F8ACA0BE74B6D48ACBE79DCBE99F
CBE79DCCEAA0CFEBA1C9E79DCDE99FCAE89ECCE89ECBE99FCEEAA0CCEAA0CEEAA0D1E99F
D8E59DE3EDA6D1D894D9DF9FE2E8ACCED39B7375434345140307000C13005C65303F4A10
526023718140C6DA95D5EBA3D0E7A1DDF7B0BDD790DDF7B090AA633E5912D6F1AAC5E099
C5E099D1ECA5C8E39CD0EBA4CCE7A0C3DE97D1ECA5CFE6A0D0DC9A858E4DA6AF6EE5F0AE
D5E09ECCD896E5F1AFD3E29FDAEEA9CCE39DC8E39CB8D88FC4E89EC2E89DC0E99DC1E79C
CDEBA3D2EDA6D6F0A9C6E19ACDE8A1D2EDA68CAA62C4E29ACDEDA4D5F5ACC2E299D0F2A8
CDEDA4CFF1A7C7E99FCEE9A2DBECA6818E4943520F9DAE6AD8EDAACEE5A1CEE2A39AAC6E
000B002E3B03D6E0ABDDE5B24B5521E0EAB8D2DEAED8E6B5556330748050E3ECBF767D54
060A002F360D8B9469E0F0BFCBE0A7D0EAAB607A39000F00DCF0B5C6D39EFFFFD8737754
FCFFEDF9FFF6FBFFFBFEFFFFFFFCFFFFF7FFBA8B91654037CED2ADDCEEBAD1D5A2F2F1C1
FFFFDFEDF6DBF7FFF4F1FFF6F7FFF4F0FDE9F7FFECECFDDDD0E2BCCAE0B1CFE6B0C9E3A4
D9F4B1CBE79D94B065D3F2A4CCEB9BCBEC9BCBEA9AC7E396CCE39BD4E8A3D7E6A1DAE7A2
586722DBEFA7D5EFA5C2DE93C8E298D1E79FD7E6A1D9E2A16D71343A3E018F9859D4E3A2
D5EAA5D3EDA4C9E59B87A35999B76DCCECA1B7D98DC0E296
AFB172909555CDD695D6E19FCEDD9ACBDF9ACFE6A0C6E19ABEDE95C2E69CC6EAA0C5EBA0
C4EDA1C6EFA3C9F2A6CCF2A7CEF0A4CFEFA4CCEEA2CAECA0C5EA9DC3E89BC1E699BEE497
C5EB9ECBF1A4BADF92D1F6A9CCEEA2CEF0A4A1C176C1E397A9CF82B8E193C6EC9FC3EC9E
C3E99CC4ED9FC8EEA1C4ED9FC4EA9DC4ED9FC7EDA0C4ED9FC5EB9EC3EC9EC6EC9FC9EB9E
B9D485CFE698D3E9A0DBEFAAD0E2A4D1E0A7C1CF9ABBC996031100CDDEAACADDA5D5EAAF
DCF5B493AE69AFCA838CA85E91AB647D944EAFC680DCF3ADC5DC96C0DA93DFF9B2C6E099
C5E099CDE8A1C8E39CCCE7A0C7E59DC1DF97CDEBA3D1E8A2E2EDABCDD292646A2A656B2B
ABB171E5EEADC6D18FDAE6A4CDDE9AD1E6A1D0EAA374924ADCFEB4CDF3A8BEE79BCAF0A5
C0E097CBE9A1C2DD96CFEDA5B5D38BACCA824B6921D2F0A8B7D58DD9F7AFC6E49CBCDC93
CEECA4D0F0A7AFCF86D7F1AAA8B7724F5C176D7E38C0D48FC9E09CCBE4A0D5EBABC3D599
5B68303039046F7643777D4DA7AF809BA475000900212E02192400000600494D2CFFFFE3
AAA98D181800A3A987CCD7AFD4E4B5C9DEA6A9BE852A3F065E6F39D7E0B1DFE1B9959674
F1F7DDDBE2D2F4F6F3FFFDFFFFF9FFFFF0FFBE8B9CA67E7C848863D6E9B1D7DDA1F3F4BB
E1E7B9F5FFDDF7FFF3EFFFF5F9FFFDEEF5EEF3FDF2F9FFF1DFECD0CEDEB7D5E7B7D3E8AF
C0D695D3EDA6839D53C6E295C6E393CBEA9ACCE89BCAE69BC4DB93D7EBA6D0DB99D2DB98
414C08D5E49FD4EEA5C4E298D3EFA5C3D991D4DF9BC8CD8B888A4B5F6424C8D391E0F1AD
C6DC94C8E299A5C17782A056BCDC91D7F9ADCAEFA2D9FFB2
989E5E87904FDDE8A6D7E3A1D2E39FD0E5A0D8EFA9D1ECA5D0EEA6CCEEA4CBEDA3C3E79D
BFE399C5E99FC9EDA3C4E69CC6E49AC7E59BC7E59BC6E69BC5E79BC8EA9EC9EEA1CCF1A4
C5EA9DC3E89BBBDD91D0F2A6D5F5AAB8D68C92B066CAEA9FBCE295C3EC9EC7F0A2C3EC9E
C0E99BC1EA9CC3EC9EC2EB9DC1EA9CC5EEA0C6EFA1C2EB9DBFE89AC0E99BC1EA9CC2E99A
D1F4A2CEED9DC7E69ACBE9A1C4DE9DCFE7ABDBF2BACCE3AD000D00CEE5AFD5EEB5D0ECAF
B7D693BBDC95C8EAA0BDDD92D1EBA4D1E8A2CDE29DC7DE98C9E09ADFF6B0BDD48EDBF5AE
D3EDA6D0EBA4CAE59ECDE8A1D1ECA5CFEDA5D0EEA6D1E8A2D7E2A0D2D898DCE2A2D6DC9C
5E6424525B1A5A63224E5917576321889955CEE39ED5EFA8B4D28ABDDD94C0E298CDEFA5
CCEAA2BED992DCF7B0D6F1AACCE7A086A15A8DA861CDE8A1E1FBB4C1DB94C8E29BD1EBA4
C1DB94DAF4ADCCE69FD4E9A458652087944FDFF0AADFF6AECAE39FD2EDAAC5DB9BD6E8AC
DFE9B4CFD6A3040600040500D9DFB3E0E9BE2D3A0E606C44D7DEBC010400FFFFEAEEE9D5
FFF8E83A35220303005F6645CFDBB3DCEEBEC3D5A3556632030F00DEE5BBDDDDB7989876
D9DCBFD1D4BFFFFFFAFBF4FBFFF8FFFFF2FFC893A5C29899B0B18FD6E7B1CCD095ECEBB2
CACD9EE5EFCAF7FFEDEDFBEEFAFFFEFEFFFFFCFFFBFCFFF4F8FFE8D9E5C1CCDCADCDDEA7
DAEFAECEE39E94AC62CDE89BD4EFA2D2EDA0CDE79DCDE79ECAE49DDDF1ACD7E09FD4D999
6A6F2DCCD994D3EAA2D5F3A9CBE79DD1E79FDBE4A1ECECAC585619959758CEDA98D8ECA5
E6FCB4BED58D89A35ACBE79DC6E69BC0E296C9EEA1B6DC8F
BCCB88C2D18EDCEDA9D4E8A3D7ECA7D2E9A3CBE59EC9E49DCDE8A1C3E199CAE8A0D3EEA7
D1ECA5D6F1AAD5EFA8C2DC95C8DF99CDE49ECFE9A2D0EBA4CCEAA2C8E69EC5E59CC5E59C
C4E49BCEEEA5D7F5ADBDDB93C3DE9797B16A8EA55FBFD990CBE99FCDEDA1CDEDA1C9E99D
C6E69AC7E79BC8E89CC8E89CC6E69ACBEB9FCBEB9FC7E79BC6E69AC9E99DCAEA9EC6E999
CAF09DC6EC99C4E99BCFF1A7CCEBA8C9E5AACBE6AF9EB682000D00C9E4AFCBE6AFBDDB9F
E1FFBDC5E69FC8EA9ED1F1A6C3DA94CEE39EE0F4AFD7ECA7DAEFAAC7DE98D7EEA8CAE49D
CEE8A1CBE59ECBE59EC8E39CC9E49DCBE69FC8E39CC9E39CD2E39FE0ECAAD9E5A3D5E09E
D1DC9AD7E09FD6DF9EDEE7A6E0EBA9DCE8A6D5E19FD2E39FD0E49F9FB46FB2C983CCE39D
CAE39FD2EBA7D8F1ADB9D28EA5BC78B5CC88CFE4A1D6EBA8BCCF8DD4E7A5E1F1B0D8E8A7
B5C4838291504A5918849350AEB975DEEBA5C5D992C7E198CEE9A4BBD895D2EBAAD9EBAF
D5DEA9DEE0AF7C794E4E4C23393B13CFD7AE9FAE830716003D41266D6A575C544791897E
B9AEA8FDF4EBB9B6A73F412B9AA180DAE6BECCDBB0F7FFD8384017848661E8E5C4BCB799
DCDCBAD4D5B6FFFFEFFFF9F2B1A1A4AC8B96F8C0CDFFF2EFF9F8D9ABB98891945FDCDAA7
DFE2B3D6E1B7DAEBC9899881B1B3AEFAF9F7F8F8F0F5F8E7FFFFE8E0E8C1CEDAAADEEBB3
E0F0B19BAC689CB068CAE097D7EDA5CEE59DCAE19BCCE39FCAE49DD2E6A1D7DD9DE4E4A6
808042CDD695D2E9A3C2E299D2F0A8C6DB96E6EDAAC0BF7F474304A9AB6ADBEAA5C7DD94
C4DA9180964D80984ED5EFA5CFEBA0CCEB9FD6F6AAC0E295
CDE49EDAF1ABC5DF98C3DD96D0EBA4CCE7A0C1DC95C4DF98E0FAB3B1CB8494AB65889D58
879B56A9BA76D0E19DDAE9A691A05D9FB06CB3C782C4D994CDE49ECEE8A1D0EAA3D0EBA4
D2EDA6C5DF98ADC780687F398FA45FA2B671C7D894E1F5B0CEE89FCBEA9ECCE89DC9E89C
CBE79CCAE99DCDE99ECBEA9EC8E499CBEA9ECCE89DC6E599CBE79CD1F0A4D2EEA3C8E99A
C0E391C6EC99C2E799C5E79DCAE8A8C6E2A7D3ECB59BB27E061C00B1C894E3FAC4C3DCA2
BAD493DAF8B2C2E096CFEBA0DEF3AEC6DA95D6EAA5C7DB96C4D893E1F6B1CEE39ECEE59F
D0E7A1CEE8A1DBF5AED3EDA6CCE7A0CEE9A2CAE59ED5EFA8C9E09AD5EAA5DDF1ACCADB97
D4E3A0D7E3A1DBE4A3C6CF8EDAE0A0CED494E7EDADDEE7A6959E5D838E4CDEE9A7D0DF9C
C4D795E2F7B4C0D5925F7431798C4ADAEAA9CCDC9BD0DF9ED8E4A4D7E1A2CBD596969F60
4F55177D8345BBC183E1E7A7DEE7A4D2DF99CADE97DAF4ABDCFAB4CFECA9CBE4A3C2D49A
9AA16D6B6A3CB7B28ABDB9930D0F00D9E1B8D4E3BAB2C09D575944120C00080000D7C9C6
FFF6F6BCB1AFF7EEE7BEBCAD74785FD6E0BEF0FCD6E8F3CBFAFFDA1F2000686346E5DEC1
8E8C65E4E2BBFFFADCFFFFEAA9978D452321BE8689FFEEE8FFFEE1B7C499ACAB7FDAD7AA
E4E7BAD8E4B6D5E8BB586746A0A295FFFEF8FFFFF3FFFEEAFCFDDED1D6ADC5CD9AD4DFA3
C8D49482914CAFC07ACADE97D5E9A4D1E6A5D5E7A9D6EAABD2EBA7D1E5A0BCC181969457
BBB77ADDE3A3DEF5AFC1E198D4F2AAC9DE99C5CA88615D1EC3BD7FDADB99E0F1AACCE49A
A2B66E8CA058D1E79EBFD78DCEE89ECAE49AC2DE93CEEA9F
C9EBA1C9EBA1C5E79DC0E298D1F3A9D0F0A7CCEAA2D5F0A9B8CF8998AD689DAE6AAAB976
9FA8679CA262A1A6669499598E9758929C5D96A26292A1608898577C8F4D748946728744
91A66393A865A7BA789CAC6BCEDD9CE1EDADDEE8A9CFDE9BCEE89FC8E89CC8E79BC8E89C
CBEA9ECAEA9EC9E89CC8E89CC9E89CCAEA9EC7E69AC1E195C7E69ACFEFA3CCEB9FBFE091
CEED9DD8F7A7C8E499C5DF98DDF3B5D0E3ABC2D2A16A7749000900DDE9B9CFDBA9CFDEA7
D9E9ABD0E3A1D2E69FCDE199C1D590E5F6B2C9DA96D5E9A4D2E6A1D1E6A1CFE49FD7EEA8
CDE49EC3DA94CDE7A0C9E39CCEE8A1D7F1AAC6E19AC9E49DD7F5ADB3CE87C6E099DAF1AB
D5E9A4C9D895E0EBA9E2E8A8D9DE9EDEE0A18E8E50B9B97B808042D9D99BC7C789DEE3A3
D8E4A4CFE2A0B2C281354504B9C887C6D292DEE8A9CFD899E6ECAEE0E4A7919256636327
737136BEBC81DFDAA0D7D799DEE5A2C5D28CE0F4ADC6E097B2D18BC9E8A4C6DF9EE1F3B9
727946110E00A09871FAF5CF040400D4DCB5CFDFB8CAD8B7ABA99A1F1611150706B7A7A8
FFEEF44E3F42F2E7E5BDB9AE71735EE2E8CCEDF7D4AFB792787C591C1B00342D13F6EFD2
5A552BEFEDBDDDD8AEE8DEBAE7D6BAE0C0ABFFCDC4FFF2E6FFFFE6F0FAD8D3D0AFD2CEA9
D3D5ADCDD9A9D1E5B06D7E51959781F3EDDFFFFBE7FEFADFF3F3CDDADDAEE4E9B1DBE4A5
AEB975B6C37EDBE8A3D8E7A4CDDD9ED0E2A6D6E5AECDE1A6D0E9A7C7DB969FA162676326
E3DDA3D3D79AD0E7A3CDECA6B9D990DBF0AB8085437A7436EAE2A3E6E7A5B3C47DD4ECA0
748840A7BB73E8FCB4C0D68DD8EEA5D2E89FDAF0A7D0E69D
D6E6A5C2D291DFEFAECFDE9DD6E5A4D3DF9FD3DD9EDCE2A4D8DC9FBCBD81CECC91EBE6AC
E2D9A0DDD49BE9DEA6E5DAA2E3DAA1E2DCA2DFDAA2D7D59AD0D197CED295D4DA9EDAE0A2
DBE3A7D3D99BE0E4A9DCE0A3D2D198C5C589C3C188DBDCA0DAE5A3D4E39ED4E19CD6E39E
D8E39FD7E09DD5DC99D4DB98DDE4A1DBE4A1D3DC99CBD692CEDB96D3E29DCBDC96BCCD87
909D55C8D58DD5E09CCAD392D5DAA0C6CA97D9DBACA1A2780705002B2900C7C89CC4C695
D5DAA2C4CD8EC6D18D98A35EDCE8A6C3CF8DCDD997A2B16EC7D6939DAC69ADBE7A8FA05C
A5B672879B56899D588DA15CA9BA76BBCC889BAC688A9F5A9FB972A7C27BA0B57091A05D
A6B16FCCD292CBCD8EAAAA6CB2B27459571A5C5A1D979356E1DB9FDFD69BC0B67BC6BD82
D7D59AD5D69A61622698995DD2D397DEDEA2E3DEA4E6E0A69A8F5783763F6A5D269C8F58
A79A63BEB37BE1D89FE4E2A7B8BD7BD5E09CC9D893D0E19DCEE3A0B5C888C0CE91CCD59C
7474425753245D562A3C350B737148DADCB4D7E0B5D1D2B2E0CCC3A8888B69464AC4A0A4
F9D5D9AD8B8C6849476D514DDFCBC0FAE8DAADA08D968A748879628C7C63958169FEEBCD
5F5027B3A576D9C89CEBD5ACEED1AFFFDCC3B57A6A9F695DEDD6C4C6BBA594826CC3B298
DDD5B1A1A374606B330D1700CDCCADF2EBD1ECE1C5E5DABABEB58C9894649696605F6529
444D0EA4AA6CB9BA7EADAE749A9A64AEB37DB7C08BAEB981A7B77897A162837E449E915A
A99A63A198619DA166B5BF82D9E2A3ABAC70564C11A7965EEBDAA2DAD294E9EEACD6DF9C
9FA162E5E5A7CFD190E6E8A7E3E5A4D0D090DFE09E7D7E3C
654E1C977D4C9E8453644818624314755526B08E60603E106E4C1E826032B79567735324
6B4B1CA384558465369F80516E4E1F6141128061336C50205C44146E58268C7846594814
65552263531F917F4D998854654F1E5B4513735B2B654F1D634F1C55410E6D56249A7E4E
6B491B5933067E5328956A3F73481D5F360A684316705122937C4A5D491673632F63561F
64531B69582047360099864E64501D5F4A1B5F4C226A56311603005C4C2B5C4E2B5D542B
817B4B605F264B4D0C5E611E5156165F63264B51135E64269EA466959E5F5D6627515A1B
525B1C4C5214646A2C484C0F9A9B5F6565294F4F138D91545766254E5D1C575B1E656026
5447106E5D2761501A61521B52470F746E34565117827D436A6128B5A87185743E735C28
6448187B5F2F5E4715604A18B09C698B7543664C1B745526734E21795326744E217D5B2D
553B0A6C5B275950195C5C20454B0DC9CF8FDADF9F797A3E5F5D2286814960592289824C
5F5824615A26847C4B5E56255E5627585021928A5B9F8668B17678883B4B61151FBB7074
71272477302AC7817FB06E6F6A292F753840A86F76774045B17E7A98685CBA8B7790674B
6E4A266D4A227D562F9569466330136F351F6A26198D4A42AD746D68373074453BDEB7A6
EFD1B5624F275A4E1C8B85538C895E99916A9B8764C9AF8CCBB18C6B5A2F474314828452
868B555855226856288C74486A52265C4A1C67612F51511B85844C5D561F645420634C1A
6B4C1D603E116F4D206442156B461A815A2F72481E6E471CD4B285B99D6D9B875467511F
917244A78558654315A482529775459E7A4874501C6A4612
B09566DCC192A98D5EBA9B6DCAA97CAE8C5FA27D51BC9A6D805E31A68558C4A577A38758
9E8354B39D6CA79160A99362B99A6CAF9062C7A87AB69B6CAB9564B6A270CCBA88A79764
A0935FD5C894F5E5B2C3B380A2905ED9C593ECD6A5A89261AA9262A58A5BAC8D5FE2BD91
8F643AAF7E569D6942EFB993BE8862B07F57C5986FB0895EB99A6C725A2AAF9B69CBB784
AC95616E551FEED59FEFD6A0EAD09DFFE6B7EAD1A8E9D1AD120000493616B5A584F4E8C2
E6E0B0DFDEA6EAEAAAD2D592D7D99AEBECB0DBDCA0CDD194DCE0A3D4DA9CCBD193E4EAAC
DDE1A4E1E2A6E6E6AAC6C489A9A46AA7A1679C935A969459B9C384CDD999D8D99DF1E8AF
ECD8A3E1CA96FDE6B28A7641D2C78FD0CB91A9A96DAFAF7399945ABAB178A89761A68F5B
B29263523203C0A675B39D6BECD8A5C0AC79A38958694A1B754F22C1966BA87F53AF8D5F
D8C18FBDB27CDDDCA3D8E0A4C0CA8BDEE7A8DADB9FE5E3A8DDD49DF8EDB7D7CA956C612B
E1D7A2DED9A2F2EDB6DBD8A1E3DDA9DFD8A4FFF5C3FFF0CEFFEAEAE99FACFFE8EFFFE9EA
FFEAE4FFDAD3FFE8E2FFE5E6FFE7ECFFDEE6FFEDF4FFE1E5FFECE6EDC3B3FAD5BAFAD9B6
DFBF96C7A67BF5D0A6FFDFB9EEBD9CFFD0B7E0A593EEB2A7CA8D88C58E89FFEAE0FFF5E4
FFE9CD544119AB9F6DE2DDA6DDDDA9C9C693F2DDB2FADDB3E2C59D432E03A09E6DDFE6B2
D6DDA9EAE7B4EBD4A8F4D5A9F4D3A8DCC494E7E0AAB7B87F7B7841E1DCA5E1D5A1F7E5B3
E2C798EDCB9EFFDAAFC0946D7F522B8A5D36A67A53B38C63C2A176EBD0A3D6C0915F491A
C7AA80CAAB7FAC8D5FC3A475D2B2819B7B48B69761AB8C56
D3DFA1DCE8AAE3EDB0D5DDA1D9DFA3D8DEA2D9DDA26E7237A7AB70D8DEA2D6DEA2DAE4A7
D9E5A7CFDFA0DAEAABC9D799DADBA1D7D69DE2E1A8D7DBA0D6DCA0D6DEA2E1EBAED0DC9E
D6E2A4CFDB9DD9E3A6DFE9ACD7DFA3D8DEA2E0E4A9DFE0A6E2E0A7E7E2AAE1D8A1E8DBA6
988753CDB785765F2DC2AB79E2CC9AFFF2BFDCCC98DFD49EA7A26AD3D299D9DDA2EEEFB5
DED59CECE0A672632AC5B67DE4D59ED2C591FCEEC19F92680D00007A724EDED8B4E7E6BA
D3D6A1D0D89CCED893E0EAA3D5DB9BDFE5A7DBE1A3D5DE9FDAE3A4D8E1A2D9E2A3E6EFB0
D8DEA0D5DB9DD1D59898995DDDDDA1D6D499F3EEB4BDBE827E8D4AEDFFBCD8E1A0DCDC9E
E1D89DF3E7AD6E6228E0D79CE6E6A8D8DE9ED2DD9BD5E09EDAE0A0D7D799DED89CE8DDA5
948953F2E9B2CFCD94D2D399D7DBA0DEE2A7D4D299645B24E0CF9BF6E2AFFFEFBCE0D39E
E0DEA5D2DA9EDFF2B2D1E7A6CCE19EC0D18DCAD593ECF2B2C8C98DDEDEA2EDEBB08E8C51
DFDEA5DBDFA4D8DCA1D6DCA0DDE0A7D8D9A0D8D79FE3DAAFF4DFCEF4D7D3EFD2CEFFF3EF
FFF7F3FFF4F0FFF8F4FFF9F3FFFBF1FFFCEFFFFEECFFFFE6FFFFE2F8FDD5E2E9BFD0D6A6
DEDDA5BBB67CA89F668E7E4AD0BA8BE7CBA4775637916F56A27E6EFFE9D9FFF6E4C1B198
544E2CBDC093D7E0A9D0DB9FE1EBAFEEF2B7DCCF9BD1BD8AA18F5DE9DFAACED399D6E4A7
D0E0A2DAE2A6E2D7A1EFDBA6F1DCA7FFF4BD7E7F43C0CC8CD6E2A4D6E2A4D1D99DE2E3A9
D4D299F0E7B0C5B8837866346A5624EDD9A7F4E2B0E7DAA6EBE1ACE7E2ABA6A56DDDE0A7
D9E1A8D2DBA2D3DDA1CFD99CD9E3A4919C5AD4DF9BD0DB96
D3F2AEBAD993C9E6A3C7E59FC9E4A169843F849D5B9CB571AEC785D0EBA6BDDA97C9E8A2
CCEDA8BBDF97CEF3ADC3E49DCFE8A6D1E8A4D1E7A6CDE6A2D1ECA9CAE8A2C9E8A4CCEBA5
D1F0ACC4E39DC0DD9ACBE9A3D2EDAAC7E09CC6DC9BD6E9A7D2DEA0DBE5A6D0D89CA1A769
A6AA6FDFE0A4909157A2A36785894E9FA56791995D87935395A365CDE09ED5EBAABFD290
D9DF9FE5E5A5808040A9A8689B995CECEAB1CCCA97EBE8BB0E0C00979870D6DBB2C2CA9B
CED9A1EFFFBED1E399D1E399DBE6A2D6DFA0D7E1A2DDE7A8DEEAAADAE6A6CEDA9ABECA8A
E2ECADDBE5A6A9B273B5BB7DE4E8ABE6E7ABD6D69A909656B3C883DDF4AEBCCD89CBD493
EEEEB0C6C4879D9B5EE7E9AAD0DB99C9D895D3E7A2D9EDA8E4F5B1D7E2A0DDE3A3E1E6A6
757B3DDCE6A9DAE8AAD4E4A5CCDF9FD1E4A4D4E0A250581CEBEAB1CECC93DDD8A0E7E8AE
D0DA9DD6EBAABFDC99C2E39CD6F4ACCAE199DDF1ACDBEAA7D1DD9BE3ECADC6CF909FA869
D9E3A4DDE7AACCD89AD7E5A7DBE7A9D8E4A6CBD599E3EAB7D2D3B4FFFFEF8A887CF7F4EF
FFFEFFFFFDFFFFFEFFF5F6F0FCFFF1F9FFEAEDFDD6F0FFD7EEFFD6F1FFD8DDFEC9CBE8AE
DAF1ADCBDC9694A15C444A0A7C7B42908A58584C22AA9B7ABEB096FCF1DBFFFFE87B7E61
404C24D0E4B3C8E1A8D3EDAED3E6A4C1CA89C5C1847C7338DDD499E9E9ABD0DF9CCCE39D
D2ECA5D4E59FD8DA99E3DD9FDDD597ABAA6A9CA963C6DC94CFE6A2C8DF9BE5F8B6D1E1A0
DFEBADB0BA7D6D733763672C91955AD9DCA3D9DCA3DCE1A7CBD599CCD79B929D61DAECAE
CBE5A6C9E9A6D3F4AFC6E7A0AED086A5C77BCDEFA2D0F2A5
C8E9A2CAECA2A9C8828CAC636D8B4584A25AACC782C1DF97C7E59FD1F1A8C6E59FC8EAA0
CBEFA7C3E99ECAF0A7CBF4A8C2EAA1C5EEA2BDE59CC1EB9FC5EFA5BEEA9DB6E297C2F1A3
BFEBA0CDF9ACC7F1A7BBE599C3EBA2CBF1A6C6EAA2C7E79ECDE29FCCE09BA7BA7880944F
B9CC8AE5F9B4CDE29FC6DD978DA6628AA45D97B26DA6C47CBEDD97C8EAA0CDEEA7D3F1A9
DBF1A9CFDF98D6E69FD0DD97929F5A9BA76789945A838D59000800D7E2B7E0EDC190A16D
A1B57893AD66658031D3EB9DD3E49ED2DE9CD6E5A2D5E4A1C7D894CCDD99D8ECA7D9EDA8
8B9C588796539CAB68DBE7A5CED796CFD595DEE4A4788442C8E29BC7E59BE0F7AFD9EAA4
CBD692646D2AE3EEAAC5D48FD4E8A1CFE9A0C6E49AC6E49AC4E096CCE39BCBDF98CBDF9A
98AD6ACBE1A0D7F2AFC5E09DCCE9A6D0EBA8C4DA994E5E1F4B5518D8E0A4D9DFA3DAE4A7
C8DB9BC9E2A0D5F6B1CBF1A8CAECA0C9E99DC9E59BBBD58CCFE69EDFF4AFBFD38E95A964
CBDF9AD5E8A6C6DB98D9EEABD2E9A5D7EEAAD2E7A6F9FFD1F5FFD9F8FFE6ACB2A4BEC2C1
FCFFFFFCFEFFEFF3FCF7FFFDE7F4E0CEE2BDCBE3B1D1EFB3CEF1B1BFE3A5D3F9BEEBFFD3
C0E699C2E593D9F8A8CFE79BD0E19BD6E0A3C8CC9AD7D8B0E5E6C6E0E3C8F7FFE394A382
D2E8C1E3FFD0C6E9B1C1E4A4C7E19AE0F0A9868C46BFC07CE3E6A1CAD68ECBE397D1F2A3
BEE191D8F5A5C7D78CDFE9A0555D14929E54D5EBA0CFEB9EBDD98FD9F3ACB9D38CC7DE98
D1E8A4445B17455A17B8CD8AD3E8A5CFE4A3D3E8A7D7ECABC4D998E4F9B8C1D596BBD493
C2E19EBFE29EC9EDA7A1C57D86AA60C1E79AC3EA9BC0EA98
C3DE97B7D3898FA962839D54BED891CFE9A0CDE49ED3EDA4CAE49DCAE69CCBE69FC4E298
C9E9A0C7E79CBEE096C5EA9DC3EDA1C5F1A2BBE79AC5F1A2C0EFA1C0EF9FB6E597C3F2A2
BFEB9EBFEB9CBEE89CC4EFA0C9F2A6C1E79ABEE298CFEFA4DEF3AECDDE9896AA65B3CA82
C8E29BD0ECA2CAE8A0CFF1A5C8EAA0C4E99CBDE197D1F7AAC1E59BD4F9ACB8DC92C5E79B
D2F1A5BEDA8DD5F0A3CEE69ACAE298B6CB868A9E5F566931001000899B6B92A675889F69
829C5D8CAA6284A554AAC7758DA35A8FA05C93A76293A7628CA15C9AAF6AB3CA84C1D892
99AE69A9BE79D2E6A1D5E9A4DEEDAACAD694EBF7B5889955D0EEA4CDEDA2C7E399BCD38B
DDEEA84A5B15CCE099C9E098C8E49ACDEDA2BEE396C4E99CBDDF93D5F5AACEECA2CEEAA0
ABC681BED996CDEAA7C1DE9BC8E5A2D2EDAACEE4A392A2634B5719A9B175D3DB9FDCE8AA
D8E8A9C9DF9ECBE8A5C0DF99C2E498D1F6A8C2E497C9E99DC5E59AC2E096E1FDB3849E57
CBE29CD2E9A3C7E09CD5EEAAC5E09BC8E6A0CBE9A3EEFFC7FBFFD8FCFFE1E5EAD6B3B5B0
FEFEFFFEFDFFF0F3FCFBFFFFE2EBD8CEDEB9CDE4B0C1DB9ECAE8A8C0E09FDAFCC0ECFFCE
C9F3A1C1EC93BCE28BC5E592D5EDA3E3F3B2D1DCA4DCE3B7C2C8A6FEFFE8F7FFE6DDECCD
E1F7D1D2EFC3CCEEBBC9EBAE9CB571C1D28BA8B26BD1DB94D6E29AD9EB9FE3FFB2B2D885
CAF19EC5E894D4ED9CA4B96A86994AADC476D4F1A1CAE99BD4ECA2CEE49CCDE39BDFF6AE
A6C079728D46708B44BAD590C4DF9AD7F2ADCEE9A6CDE6A4CEE4A3C3D897AABE7FD2E6A7
D9F2B1C7E29FC6E3A08AA86291AF67CEEEA3CCEEA1C3E696
B7C47F8E9B55CEDB96CEDB95D9E6A1C7D48EEDFAB5C3D08AD4E19CDBEBA4D6E5A0D5E69F
D7EBA4D2E69ECEE29BCFE79DCAEA9FC9EEA0C1E699CDF2A4C1E699C9EEA0C1E699C7EC9E
C1E397D0F0A4D3F1A7C7E69AC8E49AD5F1A6D7F1A8CFE59CD2DD99AAB46F8D9854DCECA5
D5EBA3CAE49AC2E096CAEC9FCBEDA1BEE395D3F8ABB1D386CDEDA2D1F0A4D1EDA3BEDD91
B9D98DD6F9A9C0E192CAEB9CD7F6AAD1ECA5BCD695859E64001500BFD6A2CCE4B0D5F1B7
D6F3B1CDEDA2B9DB87CBEB98D2EAA0D1E6A1CDE49ECCE39DCCE69FCFE9A2CFEAA3CFEAA3
C0DB94E6FFBAC5DF98D2E9A3C1D691E1F5B0C5D99490A560C4E298CCECA0CFEBA0CEE89E
E4FCB2314900D3EDA3DCF8ADC7E79BCCF1A3C8EFA0CCF3A4C4EB9CCCF3A4C3E89AC2E297
B1CA86455A17CCE19ED9EEABDCEFADC8D897D6E2A2D6DFA0D3D79A5E5F23545519B2B679
DDE3A5ECF6B7C9D595D9EDA8C8E79BCAEF9FBDE292CFF4A4CEF3A5BDDF92C6E69A3E5C12
D3EDA4CFE9A0CDE7A0D3EEA7C1DF97C2E49AC5E99FD2EFACD6DFAAFFFFDAFEFADFD8D2C4
FFF9F7FFFCFFFFFCFFFFFEFBFFFFF1FFFFE6F4FBD1D6E0ACD8E7AEDBEDB1D9EDB2C0D997
BBDE8CD9FDA5D0F19AC6E28ED2E79CCDD9978B905ACFD0A6E7E6C7E5E3CAF8FAE4FBFFE9
F9FFE8D5E6C2D6EDC1C6DDA975874998A764D8E39FDEEBA6CCDD96CFE79BC2E394CBF19E
C8EF9CBFE592809F4FC5E292D7F2A3CCE79AC7E899C6E194D7E49CD8DF9BE7F1AC85924C
495A14C4DA92D7EEA6CDE7A0DAF4ADC3DA94C4D996DEF1AFA5B375A7B375CAD296D7DFA3
F8FFC5E3EDB0C3CF91ACB878C2D18ED3E29DD9EAA3D2E69E
CFDC96E0EDA7DCE9A3D2DF99DDEAA4DAEAA3CADA93DFEFA8CDDD96DEEFA8CDDE97D0E49C
D4E8A0CADE96D5E9A1CFE59CCFE99FCFEBA0C9E59AD7F3A8C4E095D3EFA4CEE89ECEE89E
D4ECA2CBE198CEE49BD4E8A0D2E39CD1E29BD5E69FD7E49ED8DD9A9499568F9652D3E09A
D3E79FCCE69CCEEDA1C6E89BC9EEA0C3E89AC5E79AD8F8ACBFDB90D5EFA5BFD78DDFF9AF
CDF0A0BFE494CCF29FC8EB99C2E296C7E59BCCE9A7597336000D00CDE5B1CDE6AFC4E0A5
BCD997CEEEA3D0F29EC4E491C8E298D1EBA4D1EBA4CEE9A2D0EBA4C9E79FC6E49CCBEBA2
CBEBA2BEDE95D1EFA7D4EFA8C5DF98CEE8A1D7EEA88AA159D0ECA1CDE99EC9E399CDE79D
C3DD93E1FDB27B9A4EC4E498C8E89CC5E79AC6EB9DC4EB9CC5EC9DC0E798C6ED9ECEF0A4
BED58FE2F5B38B9B5AD2E1A0D3DF9FD9E3A4D5DB9DDFE3A6E0E0A4E6E4A9504E135C5C20
6D6D31DCDDA1E2E3A7D8E3A1CDE59BCAEB9CD0F3A3BADF8FC4EB9CCBF0A2CCEEA18DAC60
D1EBA2C6DD95CCE39DD3EDA6C8E69ECBEDA3CCF5A9C6E59FDBE6AAFFFFCDFFFFDCAEAB8C
DED9C5FFFDF2FFFDF4FFFBF1FFFFF1F8F8E0EBECCCE1E8BED1DBA9CAD7A1CFDEA3DCF1AE
D0EFA1BFE18BCCE894D0E797D2E299E6F1AF898C57BEBC937873557B755FFFFFEDFFFFED
F2F7E0EEF9DBD2E0BDD0DFB48B945FE1E9AED3DDA1CEDC9ECCDF9DD9F0AABFDD93CBEDA0
C7EC9E496E1E84A757C1E293C4E095CFEBA0CFEEA2CFE59CDFE59FDEDD9A94975459601C
A9B46FC8D992CCE29AD2E9A1C7DE98D7ECA7D3E6A4CCDB9A5D672A8C9256E1E2A8E0E1A7
FFFFCAF6FCC0B0B97AD8E1A2E2ECADCFDB99D1E09BD8E7A2
CCE89BCCE89BCCE89BCCE89BCCE89BCAE99BCAE99BC9EA9BC9EA9BC9EA9BC9EA9BC8EB9B
C8EB9BC8EB9BC8EB9BCAE99BBED98CD3E99ED0E69BD3E99ECBE095DCF1A6CDDF95DAECA2
DAEAA1CBD890DCE9A1D3E098D8E49CD4E098D1DD95989F597D803BB5B873D5DF98D4E199
CDE297CBE699C7E698C6E999D0F5A5BEE393C3E696C9EA9BC4E093CEE69AD9EEA3CCE498
C7E899C8EB9BCCEF9DC3E493CEEDA1CFEBA1C3DC9B768E52000C001E3200CFE3AED8F0B6
BAD392DAF6ACCAE795CAE795D3EDA3C3DD94CBE59CCCE89EC5E399C7E79CC5E79BCAECA0
CBEDA1C8EA9ECBEBA0CAEA9FCAE89ED0ECA2C6E097ABC57C748A41D2E89FCEE49BCAE298
CAE49AD2EEA367863AADCC80CDECA0D2F1A5C8E79BC8E89CC2E497D3F5A8BCE193CCECA1
D0EAA3D3E7A2A2B16E5A6624D5DE9DE2E8A8DBE0A0D6D899E8E8AAD2D294E2E2A49C9C5E
3F3D00656326B9B77ADFE4A2D0E19ACFEA9DC3E294D2F5A5CAEFA1BFE496D3F3A7C5E196
94AA62C6D791D7E8A4DDF1ACC2DC95CFEFA6C7EDA2C3E79DCBE09FD6E4A7D6E1A7A8B27D
616A3BDCE3BAE5EACCFFFFECFEFFF1FCFFF1FCFFEFF6FFE5E7F8CED5E9B6CCE4A8CDE8A3
CCEB9FC7E698D5EDA1D8ECA4D2E19CD6DEA2ACAE7DCBC9A3706A50CDC6B3FFFBEDFFFCED
FFFFEEEFF4DDD5DEC1D4DBB9989971C2C195E1E7B7CBD5A1DBEDB3C8DEA0D9F2B0CBE6A1
ACCA82A8C87FC5E59CC5E59CCFEAA5D5EEAAC9DE9BD5E19FE9EAA6D7D48F686925959B55
D5E09BD9E9A2D0E49DCBE199C8DF99DDF2AFC2D293B4C082BEC68BDEE1A8FFFFCDFFFFCC
DAE6A88898599EAE6FD0E09FD7EAA8D8EDAACEE59FD1E8A2
C6EB9BC6EB9BC6EB9BC6EB9BC5EC9BC3ED9BC3ED9BC2ED9BC2ED9BC2ED9BC2ED9BC2ED9B
C2ED9BC2ED9BC2ED9BC5EC9BDDF9ACD4ECA0CCE297D1E69BBED388D6E89ED5E79DD2E299
C9D68EA6B36BD7E49CD5E29A98A55DB0BD75A4B16995A159B6C079D3DF97DDEDA4D4E99E
D1EC9FCFF0A1C7EC9CC5EC9BACD684D0FAA8CCF3A2C1E494D4F3A5D3EEA1C7DF93D4ECA0
D1F0A2BBDC8DCFEEA0D1EDA0C3DD93C9E09ADBEFB092A56D0819008A9A69C6D8A6D4E7B0
D7EDADC7DE96CBE695D1EC9BC1DB91DDF7AECCE89EC9E79DD2F0A6C6E69BC8EA9EC3E89B
C8EDA0C5EA9DC9EB9FC9EB9FC8E89DCEECA2C6E298AEC87F90A15AD2E29BDCF0A8C6DC93
D7F1A7D2EEA3CBEA9E78944997B167D0EAA0C8E096CBE59BD8F4A9CDECA0C4E498D0F0A5
CDEBA3D0EAA3BDD28D92A35FBAC684D4DF9DD5DE9DE3ECABCFD897DBE4A3D8E1A0D8DE9E
DFE4A4989A5B5656188F9150DEE9A4CFE499C0D88CC2E193C6E89BCBEDA0D4F3A7CCE39B
83944E6B7632C0CB89CFDB99C8DD98C8E69EC7EDA2C6EAA2CFEAA7D9EEADCEE39ED1E5A0
C3D69498A76EEAF7C9DBE6C4F5FEE9F7FFF4F8FFF8F6FFF2EEFEE1E0F5CAD3ECB3CAE7A5
C7E6A2D3F1ABB9D28EC3D895E4F4B6D7E2AAA1A77B737452828069E5E2D3FFFFF4FDFDF3
F7F9ECF7FEECECF6DEEBF1D57D785BB7B191ECEEC9ECF4CBF2FFD3C9DBA7C8DBA391A568
8DA363C4DD9BDEFBB8CEEBA8C6E09FD3E7A8DEE9ADDAE0A29B9E5B52530DB1B771D9E59D
D1E19ACCE098CFE69ED2ECA5C9E49FCAE3A1DEF3B295A567D3DEA2D2DAA1D8DBA4F7FFC4
B0C08198AE6DC2D897D8EEADC8E19FC3DE9BC2DD9ACBE8A5
C5EC9DC5EC9DC3EC9DC3EC9DC2ED9DC1EE9DC1EE9DBFEE9DBFEE9DBEEF9DBFEE9DBFEE9D
BFEE9DBFEE9DC1EE9DC2ED9DC2E497C6E599CBE79CDDF9AED4EEA4D3EBA1CCE49AD2E89F
9DB36ABED28AD1E79ED3E9A0889E55B4CC82BAD288D6EEA4CBE399D0E89EC8E499C1E195
C7EC9EC5EE9FBCE998B9E897D7FFB5BBEA99B7E493C5F0A0C8EFA0C1E396C2E296C9E89C
CCE89DC5E093DAF2A6D2EA9EC8DE95D2E6A1D5E5A775824C000900D8E4B6D0DCAED7E5B2
CDDFA3D5E9A4CFE698D7EE9ED7EFA5C6E097C9E59BC4E298C1DF95CCECA1CEF0A4CEF0A4
C7EC9FC4E99CC9EB9FC9EB9FC8E89DCDEDA2C7E59BB7CE86909F5AD8E39FCEDD98D8EEA6
CDE79EB4D288D8F4AAC6E097B5CC84D1E59EDBECA6C6D791CAE098CFE69ECCE89EBFDF94
C9EFA4B1D78CDDFDB4DBF5AE6B803BD8ECA7D7EBA6C1D590D3EAA4CAE19BC4DB95CCE19C
DCF0ABB1C07D6871305F6623C1C884CED994DFF3ABD6F0A6C9E79DC8E89DC5E197CCE19C
BDC8868A9050A7AB6EBCC586D6E6A5CAE39FC3E79FC0E49EC7E1A2CEE4A4CBE29CD8EEA5
D0E69D9EB16FD3E4AECEDDB6EBF7E1F4FEF5F8FFFDF7FFFBF6FFF2F0FFE3E1F9C9CEE9B2
C6E8ACC8EAAECCEAAED3ECB3BACF97CCDCADA7B38B000600B5BAA6F7FAEFFCFFFAF9FFF8
F5FFF4F7FFF4F4FFF0FBFFEFB0A494D1C1B1FFFEE7FDFFE5F6FFDECEDFB3D4E2B194A16C
96A36BCCDEA2CCE6A7C7E1A0CEE6A8DBEAAFD3D69FB7B87E77823D8B9B50C5DA8FCBE397
DFFBB0CAE99DBCDC91CCEEA4CAEBA4C6E5A1809D5B8FA769CFE3A6D6E8AEE1EEB6C6D59A
8FA565A5BE7CCBE4A3CEE8A7CAE4A3D2EFAFD1EEAED5F3B5
C8EA9DC8EA9DC6EB9DC5EC9DC3EC9DC2ED9DC2ED9DC1EE9DC1EE9DC1EE9DC1EE9DC2ED9D
C2ED9DC2ED9DC3EC9DC5EC9DC4E99BD7F9ACC3E598BADA8EC3E296D1EDA2D0ECA1C8E298
385208D8F2A8C5E196D8F7ABC6E599CEEEA2C9E99DD3F5A8CCEEA1CAEC9FC1E698C2E99A
CAF5A5C6F3A2BEEB9AC0EF9EB1E08FB1E08FC9F6A5CDF8A8BAE394C8EFA0D8FDAFC5E599
CEE89EC5DB92D4E8A0D4E8A0D2E39DD1E09FD3DEA4848E5A000700E0E9BEB5BE939CA674
8B995EB7C8849EB366798E41D1E79EB3CA82CAE49BD8F4AAD3F1A7D3F3A8C2E297C0E296
C8EA9EC2E79AC8EA9EC9EB9FC7E79CCBEBA0C9E79DBED58D939E5AE1EAA7D3E29DCFE59D
C5E197DFFFB4CCEAA0CCE89EC6DC9482934D8D9A55A1AE69D9E8A3D2E69FBDD48CDCFCB1
BFE99DCDF9ACB3D98ECCECA3D2ECA55A712BB8CF89CAE59ED3F3AAC2E49AD5F7ADD4F4AB
C1DC95D7ECA7D1E09D97A05D656A28949B57CFDE99CBE29AC3E197CCEAA2C6E099DCF0AB
DAE3A2DBDCA0707034979B5ED5E1A1D2E9A5C6EAA4C7EAA6CCE5ACCFE2ABD4E6AAE2F5B5
DAEAA9BBCB8DC8D4A2DDE7C2E8F0DBF8FDF6FCFFFFFBFFFFF9FFF8F8FFF1F2FFE0DEF3CA
D4F1C5DFFFD0D3F0C0E4FECFF5FFDDE0F2CA5F6D4C232D15F1F9EAF8FFF7F7FDF9F8FFFE
F7FFFDF5FFFAEEFFEEFBFFF3FEEFE8E0CDC7FFFFF1FAFFEBEFFEDFE3F3CCF8FFD6DBE3B4
DEE6B3DAE9B0C5DD9FC6E0A1D7EDAFCAD59B8683507B7A41B9CA83D8F3A4C3DF92C8E89C
C2E296CFF1A5CBEFA5C2E69EC3E7A16F8F4C819F5FD5F1B4D8F2B5E1F6BDC7DAA2DBEFB4
AEC484CFE8A6DCF2B2C8E0A2C6DEA2C9E3A6C2DBA2C4DDA4
D0E69ED0E69ECFE69ECDE79ECCE89ECAE89EC9E99EC8EA9EC8EA9EC8EA9EC8EA9EC9E99E
CAE89ECAE89ECCE89ECAE89EC1E397D2F7AAC9EEA1D3F5A9DBFBB0C0DE94C6E49AD6F4AA
49671DD7F5ABC0E095C7E99DD4F9ACCBF1A4BFE89AB9E294C6EFA1C8F1A3C5EB9EC4ED9F
C7F0A2C0E99BBEE799CAF3A5CFF8AAD3FCAEBFE89ABCE295D1F6A9C8EDA0BBDD91CEECA2
DFF5ADD8E9A3D5E49FC9D893D6E2A0D9E3A6CFD8A1808857010700676E447982573D4617
94A169B6C685B9CE8352671A849850F5FFC2DBF1A8C6DE94C8E499B6D589D2F2A6CDEFA2
C8EA9DC4E699C9E99DCBEB9FC7E69ACBEA9ECDE99EC5DC947A8541A9B271D0E19DDEF5AF
C5E59CBADE94CBEDA3C8E69ED3E8A3D2E19EA0AB69677230939F5DB9CA86D2E7A2C0DE96
C4EFA0CBF7A8B8DE91CCECA1C7E1988EA55D829C53B6D48AB9DE91C0E699BCE597C1E79A
CBEBA0CCE69DD4E59FDCE7A3888A49B5B776DEEDAAD0E7A1CDEDA4D8F7B1C3DE99CFE2A0
D7DD9FE2E1A87C773FA09F66D8E4A6D0E6A5C5E8A4CFF2B2D5E6B9D7DFB8DAE1B7FAFFD5
FFFFDAAAAC84C1C19DD6D5B9EFECDBFFFDF4FFFEFAFFFEFBFFFDFAFFFFF8FFFFF4F5FCEA
F4FFEDF1FFECEDFFE5E5F8D8F7FFE8E2EFD31F271273796BFCFFFBFBFFFEF2F6F9F8FDFF
F8FFFFF5FFFBEEFEF1FCFFF8FFFAFAC2AEAFFFFFF6F9FFF3F2FFE9F7FFE4FDFFDCFFFFD8
ECF3C0D4E1A9D7EFB1CDE7A6D1E7A7C4CE925D56228D8850CFE59CC9EA9BC9EB9ECEF0A3
C3E599CFF1A7BCDE94DBFCB5D4F3B093B171C0DC9FCFE8AEF1FFCFF4FFD3C9DEA691A66D
9CAE72C6D89AD3E2A7CCDEA4D3E4ADD3E4AEDCECBBEFFFCF
D4E39ED3E49ED1E59ED0E69ECFE69ECDE79ECCE89ECAE89ECAE89ECAE89ECAE89ECCE89E
CDE79ECFE69ECFE69ECDE79ED0F0A5B6D88CC9E99ED8F8ADBEDC92C1DD93D0EAA1648036
C7E399C6E49AD0F0A5BFE195B9DE91C9EFA2C4ED9FCCF7A8BFE89AC6EC9FC4E99CC1E699
C6E89CC2E498C4E499D2F0A6BFDD93CAE89ECDE99FCAE69CCDE99FCDE99FC9E59BCBE59C
9DB16C3B4A07707C3AD7E3A1DFE9AAC5CF93B7BE8A494F1F010600D5DCB3C9D1A8E9F5C5
E0EDB5CBDB9CD4E8A0D2E79CC4D890667A32BCD088DAF0A7C2DC92DDF9AEC5E498D2F2A6
CAEA9EC6E69ACAEA9ECCECA0C6E599C8E79BCEEA9FCBE199D4DF9DB8C3816B7F3AC3DE97
D7FBB1C4EA9FC4E89EC9E9A0CADF9AC9D895CAD392EEF7B68D9856546320D9EEA9CBE9A1
C4EA9DBCE597D7F7ACCDE79ECBDF98D7E8A2CAE0984B651CCFEFA4D8FEB1C1EA9CC3E89B
D8F6ACD6ECA4D5E29DD6DD9A5555179D9F60CAD694C1D892C4E39DCEEFA8C5E39DD3E6A4
B9BF83A1A067C2BD85CDCC93E3EEB2C9E2A1C0E5A0D6FABDDDEDC8E3E9CDF1F5DCFFFFE9
FCFBE6D6D4BFACAA95E5E0CDF8F2E2FFFEF0FFFEF4FFFEF8FFFBF8FFFEFFFFFDFFFFFFFF
F7FEF6EAF7E6F9FFF3FBFFF1F0F5E1CACDBC4F4D41FFFFFAFEFAFBFFFDFFFFFDFFFBFAFF
F7F8FCFBFFFFFBFFFBFFFFFBFFF6FDB9A4ABFFFFFAF7FFF4F1FFECEAFEDBE3EBC4F1F4C7
D3DAA7C6D499DBF4B3C0DD9ACCE2A1D7E1A4625721A9A369C6DA93CEF1A1C9E99DC1E196
D8F6AEC4DF98D0E9A5C0D69532480AACC085E1F4BCE9FCC5ECFFC8DCEEBAAFC18D82955E
C3D599D8EAACD2E4A8DDEFB5ECFDC9E0F0BFDDEDBEE0F1C4
D3E4A0D1E5A0D0E5A0CFE6A0CCE7A0CAE8A0C9E9A0C9E9A0C9E9A0C9E9A0C9E9A0CAE8A0
CCE7A0CDE7A0CDE7A0CDE7A0CCE69FE2FCB5BED58FCCE39DCEE39E374C07425611D0E49F
E0F4AFBBD08BD8F2ABD5F0A9C1E198D1F3A9BEE298C4E89EC7E99FD0EEA6CFEAA3CEE8A1
D6EDA7D4E8A3CADB97C9D895D5E19FD8E4A2DBE7A5CBD795D2DE9CF4FFC0B8C7842C3D00
546322E6F5B2CFDB99505C1A545E1F5D672B7B824EA0A6780C1300000700F3FBD2C8D4A6
BDCC95D8EAACD2E69F889D524B5C15DFF0A9D7EBA3D1E79EDDF5ABC1DB91D3EFA4C4E397
CDECA0C7E69ACCEB9FCDECA0C7E398C8E499CFE99FCFE59DD6E2A0E2EEAE96AD69C3E29C
B3DB92C9F3A9C0E89FD3F4ADE9FFBCD2E1A0CFD899E1E7A9576021435211D6EBA8CEE9A2
CBEBA0BFDD93CAE098DCE9A4C9D08DF4FBB88994508D9C57C4DB93C5E399CAEA9FD0EEA4
C9DF97DBE8A3CBD08E6463236D692CC6C78BE3F2B1D2EBA7C9EAA5C2E6A0C7E6A2D2E7A6
8F975C93925AE1DCA5DEDFA6DEECB1D2ECADC9F2AEE7FFD3F3FFE7F8FFF2F9FFF8FBFFFB
E6E8E7FFFFFDAEADA8FFFFF4FCFDEBFFFFEBFFFFECFFFFF1FFFEF9FEFDFFFFFDFFFFFDFF
FFFDFFFFFCFCFCF4F1FFFBF6EEE3DD655852271717FFF8FCFFF2FCFFF8FFFFF8FFFFF9FF
FFF3FDFFFDFFFFFDFDFFFBFCFFF7FFD8C7CFFCFFFBF4FFF6EAFFE7D0E8C4D7E2B8CFD5A7
DEE5AFD8E6A9D5F0ADBEDC96CFE6A0D7E2A0584D15988E53DFEEA9CBE79CCDE79ED7EDA5
C5D994C5D493F5FFC3909A5EE7EFB6E4E9B3F5F9C6FBFFCFDCE2B2E0E8B9828A5BE4F1BC
CEE4A6D1EBACC4DEA1DEF7BDF4FFD8F4FFDAF1FFDAE2F9CB
D0E69ECFE69ECFE69ECDE79ECCE89ECAE89EC9E99EC8EA9EC9E99EC9E99EC9E99ECAE89E
CAE8A0CCE7A0CCE7A0CCE7A0CCE7A0CAE59ED4EBA5D2E8A0B2C67FA1B26CE6F5B0CEDE97
CFDF98DCEDA6CDE199D1E99FC9E59AD0EFA3C4E699C9EB9FC7E29BCEE7A3CDE29FCBDE9C
D4E3A0CAD694ABB674959E5B7D8844A8B36FD1DC98DCE9A4B9C6817F8C47899553CBDA97
D4E7A5C9DE9BD4E8A3D2E39DD1E09DD6E2A4E8F1BCB0B78B010500808565BBC2A1D9E0BE
E0EBC0D8E7B0CFDFA090A45DD9EAA3C1D28BD9EDA5D4EAA1C3D991CEE59DCDE49CD1EBA2
D1EBA4CBE59CCFE9A0D3EAA2CAE298CBE198D2E89FD2E69E778643374A08A3BC78D8F7B1
C8EEA5BCE49BC9EDA5C5E49E9EB5719CAD6997A162B2BD7BD1DD9DE4F5B1BDD490CFE9A2
CAE298D7EBA3D9E9A2D0DA958C934F7D8440ADB873DDEDA6D9EFA6CEE69CCBE59BD6ECA3
CEDB95E1E7A1CDCA874D4909939856DCE7A5D6E9A7C5DE9DCEEAADD4F0B6E7FBC6E5F3C2
B4B78CFAF8CFF6F3CAEAEBC1DFEBBDE5FBCCD5F5C3EEFFE3F7FFEFF9FFF6F2F7F3F8FCFD
FEFFFFBDBCC1B6B4B5FCFCF4FFFFF1FDFFEBFBFEE9FFFFF3FEFFFBFEFFFFFBFDFFFEFDFF
F9F3FDFFFBFFFFFAFDFAEAEBD8C8C8A79394D0B7BBD3B9C2FFF8FFFFF1FDFFF0FFFFF8FF
FFFAFFFFFBFFFFFCFFFFF6FAFFF9FFF1E5E9FFFFFDF7FFF8EFFFF2C6DFBFE1EBC8C1C499
D8D8A4DBE5A8CAE59EC9EB9FDAF6ACD1DD9B63561FADA069D2DF9ACEE69CD4EAA1CCDD96
DAEAA3E5F0AC99A263C1C78BD4D7A0D8D8A4F6F6C4F4F4C2D5D7A6B8BA89A9AD7AC6CF9A
DFF0BAE9FFCADFF3C0E8FCC9E7FBCADAEEBDE6F8C8DBEDBD
CCE89BCCE89BCCE89BCCE89BCAE999CAE999CAE999C9EA99CAE99BCAE99BCAE99DCAE99D
CAE89ECAE89ECAE8A0C9E9A0CCF1A4BBE093CFEFA4C9E59AD2EA9EAEC3787D8D42CFDD90
DEEC9DD3E494C2D583D5ED99D2EE99D4F29CC5E790C9EA99C4DD99DCF2B2CFE1A3495719
7B8546ABB674D9E6A1CEDE97D6EAA2CAE298ACC67C96B066A3BD73C8E096D9EDA6CFE6A0
C5E4A0CEEFAACBE99FD1EDA0C5DC8EDEF2AAD2DDA3D4DBAF070A00646553E9EADCFCFDED
EBEFD6DCE4BDF3FDC98795573E520AD1E79CDCF2A9D2E8A0CBE09BD3E6A4D3E6A6CDDD9E
D7E7A9D5E5A68897567A86449CA964929D58909C5492A259CBE199CFEAA3C9E79FC9E79F
C5E39BD3F1A9C7E29B6A813B7D924DD6EAA3DCEDA9CBDC96C8DC97DAF0A8C1D892D7EDA4
D8E89DD1DF92B2C07389974A94A459D2E79ADEF5A7C7DF91D3EB9DD1E99BC3D889E2F0A3
D3DB90BCBC72868239909247D0E797CDEC9ECDE6A4C5D8A1D7E3BBF5FADCF2F1DDDAD7C8
F4EEE2EFEBDFFFFFF1FFFFF1F8FFEDF3FCEBF8FFF4F5FDEEFAFAF0F5EEE6EDE8E298938F
D9D4D1C4BFBBFBF6F2FFFEF8FFFFF6FFFFF6FFFFF8FFFFFAFEFFFFFEFFFFFCFFFFFCFFFF
FBFFFFFBFAF8FFFBFBF5E5E6928785C0B0B0E4C7CBF2D7DCFFFCFDFFFEFDFFFAFFFFFBFF
FFFFFFFEFFFFFFFDFFFFFDFFFFFFFDFDF9F6FFFCFDFFFFFBE7FDF0C3DCC7D8E1C6C9C5A2
F7EABDDBDB9FC9E89CCDF8A6BADC8FD3E4A0615521A39662D6E19FC8DE93DFF4A9D2E79A
D8EB9C8D9E50E0EDA5CCD793DFE7ABCDD59ADEE3ABD6DBA392975D999F63DCE1A1D4D9A1
FFFFDFF4F9DBFFFFE4EEF2CFD8DDB4A7AD7F9DA16F8F945E
CAE99BCAE99BCAE99BCAE99BCAE999CAE999CAE999CAE999CAE99BCAE99BCAE99BCAE99D
CAE89ECAE89ECAE8A0C9E99EC2E89BC3EC9DC9EEA0C5E697D2EDA0CFE59AAABA6F9AA85D
CBD78DEEFCB1D2E299CFE499C7DF95C4E095C4E397D2F0A8D2EBAAC9DDA0BFCE93768244
B4BE7FD2DD99DDEAA5D3E79FC9E195CAE99BC6E798BEE191C6E599D4F0A5D5EDA3C6E097
C4E8A2C2EAA3CBF0A2C8EA96CAE692CCE297D3E1A6DAE3B8010300030300FFFFFAEEEEE6
EBEDD8B1B7958E98667C8A4C687E35C8E092CBE397CCE49AD0E69ECEE19FD7EAAAD5E5A7
D3E1A4909E60A2AE70BBC586C3CE8ADCE7A2DAE69ED8E8A1D3EDA4CAEAA1CAE8A0C6E49C
C9E39CC6E099CFE49F596E299DB16AC5D992CBE199D0E69ECAE199D2E9A1DEF8AFC1D78E
C7D58AD9E599A9B76A92A458CFE497DDF5A9B9D487CAE598CFE79BCFE59ACDDD94EAF4AB
CBCE8797975166621BE8EEA4D2F1A1C3E89BC5DFA0EDFDD0E9ECD1F1EBDDFFFDF88A8081
FFFAFBFFFEFDFFFFFDFAFCF9F8FAF7FEFFFFFFFFFFFFFEFFFFFCFAD8CBC59C918D7B706A
E0D7D2FFFBF6FFFEF8F8F3EDFFFFFAFFFFFBFFFFFDFFFFFDFEFFFFFEFFFFFCFFFFFCFFFF
FBFFFFE7E9E6FFF7F7FFFAFABDB3B1FFFBFAF5D6DBFFF0F3FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFF2F7F1FAFBF5FFFAFDFFFAFEF4FFFFE1F8E8F4FCE7D2CDAF
FFFED6D2D097C9E99DBDEA97D5F5AAD1E09F645A299F9361D7E6A3D3EEA1BAD586BCD584
B7D07DA5BC6CCCE196D8ECA5D4E4A6D0DDA5D8E2AED9E3AF67703B969F66E0E8ACDBE2AE
FFFFE4FFFFECFCFFE4B8BC9B94966E919465A2A56EA3A76C
CAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE89E
CAE89ECAE8A0CAE8A0C9E99EC6ED9CC4EB98C2E895D2F3A4CFE99FCDE39BD3E4A0B0BE80
4F5A1EC7D29AC7D49FD8E8B7EBFED0E3FACCDAF4C7DDF5C5ECFFCBD2E6A9C3D29795A163
C5CF90E4EFABD5E29DCFE39BCDE599CEED9FD0F1A2CCEF9FCCEB9FCEEA9FD1E99FCDE79E
C8ECA4BEE49BCCF1A3C1E291D6F1A0C8DE95E2F1B8EBF3CA0B0E00000200EBEAE59A9C8F
B9BFA5EBF6CEDFEEB7D0E49FB3CB7FCFEA99C8E394CDE899D9F1A5C5DD93D5ECA4D0E7A1
D0E5A0A3B772CEE29DE3F4B0CDDE9AD9EAA4D4E59FC6DA93D4F0A6C2E297CAE89EC6E49A
D5EFA6C7E198D9EFA7728840CCE09BD0E49FD0E5A0DAEFAAD1E8A2DBF2ACC1DB94AAC17B
98A8619DAA64B7C780D6E7A0DEF2ABCADF9ACEE39EDEF3AEC5D896D1E1A09EAA6A889054
5F632886854CB5B37ACAD094D3ECAAC5E3A3E2F6C3DEEAC6FAFCE6D5D1C6BFB7B4F5ECED
FFFBFBFFFFFDF6F8F5FEFFFDFCFEFDFDFDFFFDFAFFD0C9D0A79D9CE5DAD6FFFCFAFFFCF8
FFFCFAFFF7F5FBF3F0FFFEFAFFFEFBFFFFFBFFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFCFFFF
EFF5F3FEFFFDFFFBFBB7A9A9BDB3B1FFF7F6D4B5BAFFF1F4FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFFAFFFCFEFFFBFFFAFFFFFBFFF8FFFFEFFFF4E7EAD9B5B093
FFFFD8D5D89FCEEEA5B8DE91D3E8A3BDC58A7A7243C2BF8CC7DE98D4F9A9C3E996D0F39F
CFF19DD3F4A5BDDB93CCE6A5C7DEA8D3E6B8C9D9B2D6E6C196A4809CAB84B7C499CCD8B0
EFFDDAD8E6C5A5B38F9CAB82BBC998D7E6AFCFDFA1CFDF9E
CAE8A0C9E99ECAE8A0C9E99ECAE8A0C9E99ECAE8A0C9E99ECAE89EC9E99ECAE89EC9E99E
CAE8A0C9E9A0CAE8A0C8EA9ECAF09DC5ED97C4E795D0EFA1CBE59BC9DE99DBEBACD2E0A5
53602BEBF7C7D5E1B9D3E1BDF1FFE2F2FFEAF4FFEDF4FFE6F0FFD3EBFFC2D7E6AB8D9B5D
9BA566D8E5A0CEDD98CEE29AD1EC9FCBEA9CC8E99AC5E898C2E296C4E095CDE59BD3EDA4
CBEDA3C2E89DC8EB9BC0E190DBF6A9D3E8A3ECFAC5E5EFCA00040000020050534AFCFFF3
E2EDCDCBDBACC3D798D1E99FDDF8ABD2EEA1CCE999CEEB9BD9F5A8C0DC8FD3EFA2C7E396
829C52CAE49ACEE89FCBE59CD0E7A1C9E09AD5ECA8CBE59ECDEBA1BFDF93CBEA9EC8E69C
DAF4ABCEE89FC3D991A7BD75CFE39ED8ECA7CDE29DCBE09BC8DF99D1E8A477904CA2B975
CBDF9AD9EAA6DEEFABD1E4A2D4E4A5C9DB9DD4E4A6C4D398FCFFD147511C5C6431575E2B
BFC293C7C99AEBEABEE9EFC1C0D2A0E8FECDF9FFE3FEFFEAFFFFF1E6E2D9FFFEFAF8F4F1
FFFFFBF9FCF5F8FDF6FCFFFBFFFFFFF1EFF2FFFCFFB4A9B1E7DDDEFFFCFAFFFBFBFFFCFA
FFF6F5FFFDFBFEF9F6FFFEFBFFFEFBFFFFFDFFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFCFFFF
FBFFFDFBFDFAFFF7F79A8C8CF7EDEBFFFBFAF7D8DDC9AFB2FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFF7FDF9FEFFFDFFFAFFFFF4FBFCFFFFF9FFFACCCABBB3AF94
FFFFD8DFE9B4CBE8A5CBE9A3D3DBA0A8A572968F61D6DAA7C7E59FC2EC9AC9F39FBCE390
B6DB8BCCEEA2BFDF9CC5E2A8F2FFDFECFFDEF5FFEDF7FFF1EEFBE7F8FFF1EAF6DE465538
60714DC2D7AEDAF0C2C8DEADBFD69EDDF5B7D0E7A3CAE49D
C9E8A2C8EAA0C9E8A2C8EAA0C9E8A2C8EAA0C9E8A2C8EAA0C9E9A0C8EAA0C9E9A0C8EAA0
C9E99EC8EA9EC9E99EC8EA9DC1E696CDF3A0CFF0A1BCDB8DCCE69CE0F5B0CDE09EC4D398
1F2D00CCDAA9CAD9B0CFDFBAE9FADAE3F7DBE0F4DBDAEFCEDAF1BDE4F8BBDCEBB0839153
7F894AD4E19CD3E29DD7EBA3CCE79AC5E697C6E999CCEF9FCEEEA2CBE79CCCE49ACDE79D
C7E99DCCF1A3C3E696C7E698D6F0A7D0E4A5D1E1B2B5BF9D0E1503000300DAE2D3D1DDC5
E1F1CAD3E8B0CAE49BD3F0A0CFEBA1C1DF97C7E59BC6E599CEED9FC2E191D6F6A3C5E592
83A350DCFBABD0EFA1BBDB8FCEECA4CAE8A2CEEBA8D1EEABCAEA9FC6E798CCEB9DC6E599
CFE99FC9E3998EA45CCAE098C8DC97D8ECA7CEE3A0C7DC99CFE6A2B0C6858FA866BFD896
D7EEAAC0D594D1E6A5CCDEA0C9D89DDDEAB2E1EBB75E663549512281865D888D65D4D8B3
D3D7B4E2E6C5D1D4B5CACFAFD5E0BEF4FFDFF4F9E2F6F7E7F6F3EAD2CFC8F7F4EFFFFFF8
FCFFF6F0F8E9F9FFF2F3F9EFFFFFFBFFFCFFF1E5EFDCCFD9F4E8ECFFF9F8FFFCFDFFFCFB
FFFCFDFFF9FAFEF8F8FCF6F6FFFEFDFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFCFFFF
FBFFFDFEFFFD9185854F4141FFFCFAFBEDECF8D9DEFFF3F6FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFFBFFFFF4F6F5FFFAFFFFF6FDFBF9FAFFFFFBADA79BC3C1AA
FEFFDFD4E6B4C0D99FDFF1B7F1E9B88C7D52B1AC82D1DBA7D0EDAABAE093CBF2A3BDE294
8DAF63C3E29ECEEAAFD5EDBDF5FFE6F7FFF1F4FFF4ECF5F0FBFFFFF0F6F4FCFFFFFBFFF4
ECFED8E8FECDC6DDA7CEE6ACD0E8AACCE7A2BED88FE2FEB3
C8EAA0C8EAA0C8EAA0C8EAA0C8EAA0C8EAA0C8E9A2C8EAA0C8EAA0C8EA9EC8EA9EC8EA9E
C8EA9DC8EA9DC8EA9DC8EA9DC5E79ACCECA0CFEEA2C3DF94CEE89ED6EDA5C8DE96DCEFAD
516325DBEDB3DBEEB7D0E4B1C9DFB1C5DAAFCBE1BAD3EABED1E8B2CEE2A5D6E5AA8A985A
899555DAE7A2D1E09BD2E89FCDE89BC6E798C5E898CAED9DCFEFA3D0ECA1D0E89ECDE79D
C5E697D1F4A4C6E798CDECA0CEE7A3B5C98EAFBE938E99790005000E1607D1DDC9E3F2D5
CDE3B4C9E3A2CDEC9CC2E28FC9E3A2CAE4A7D4EEADCDE8A3CBE79DC9E89AD1F0A0C5E791
D0F29CB9DB85CCEF9DC6E999C3E59BCDEEA7BADA97BDDE99C5E599CDEE9FC9E89AC7E698
CAE49ACAE49A81974FD6ECA4D4E8A3D5E9A4D3E8A5D0E5A2D8EEAD869C5BD5EEACD1EAA8
C3DE9BDEF7B5CBE1A1C8DC9FE8F5BD808A56545A2A53562BE5E5BFC7C7A5FFFFE4F4F7DC
FFFFEAFEFFECFCFFEDFCFFEFF5FAE4FCFFECFFFFF3B2AFA68F8A84EEEBE4FFFFF6F5FCEC
F6FFECF8FFEDF8FFEFEEF7E4FFFFF6FFFDFBB6A7AEFFF9FFFFFBFFFFFCFDFFFCFDF6EDEE
FFFCFDFFFDFFFFFDFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFCFFFD
F0F6F2F7F9F65D5151998B8BFFFCFAFFF8F7FFEEF3FFF3F6FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFFBFFFFF8FCFDFFFBFFFFFAFFFFF9FCFFFEFBA79E95E1DECB
F8FFE4C6DDAFC5DBAADBE1B1E6CEA86B512ED8D4AEF6FFD3DCF4B6CBE9A3CBE9A1DAF8B0
7C9752D4ECAEE4F8C5F2FFDBF9FFECF6FCF0FCFEFDFFFEFFF5F2FBFFFCFFFFFCFFEAEBE5
CEDAB2E3F6BED7EBB0CADE9FCEE5A1D9F0A8C9E195C3DB8D
C8EA9EC8EA9EC8EA9EC8EA9EC8EA9EC8EA9EC8EAA0C8EA9EC8EA9EC8EA9DC8EA9DC8EB9B
C8EB99C8EB99C8EB97C8EB9BCFEDA5C7E59FC7E29BD7F3A9CCE79ABFD789D1E99BD7EE9E
566D1DB2C97BCCE297D9F1A7D0EAA1D1EBA4CAE39FC7E09FD4ECAEC5DB9DD6E8AC879557
8C9858D9E6A1D0DF9ACCE299D0EB9ECAEB9CC5E898C2E595C4E498CAE99DD0EAA0D0EB9E
C6E796CAED9BCBEA9CCEEAA0D2E8A899AB77B8C79EB1BEA0000A00061200DDEBD2CBDCB8
CBE4ADC9E9A0C8EC94C3E493E1F8C2ECFED4EBFED0E2F6C1CFE7A9D0EBA6C8E499C9E996
C9EB9575974198BB67C8EB99C4E99CD2F6ACD2F6B0CEF2AAC1E396D0F1A0C5E496CBEA9C
CFE99FCDE79DA6BC74C3D991D4E8A3C9DD98CDE29FC9DE9BCCE2A18BA160C0D998C5E09D
CDEAA7C8E5A2CAE3A1D7EBACC9D69E545B27868859D8D6ADE2DEB9D2CFB0FFFEE5FFFFEC
FEFFEFE3ECDBF8FFF4ECF4E7FFFFF4FFFFF4A7A09AD1CAC4FFFAF4FFFFF4FEFFF1F4FFE7
EAFDDDF5FFE4F7FFE6FBFFE8FFFFEFD0C7BED3C1C1FFF9FDFFF5F7FFF8F9FFFCFFFFFDFF
FFFAFCF9F3F7FFFDFFFFFAFEFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFDFEFFFDFCFFFD
FBFFFDFEFFFD080000928484F6ECEAFFFBFAD0B1B6E1C7CAFFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFEEF6F8FBFFFFE8DDE5FFF9FFFFFAFFFFFBFBCDC0BAFFFFF1
F3FFE9D6F0C9DDEFC7D6D2ADA47F65856046F0EDCAF9FFDCE6F7C3D9EBB1C1D095CDDD9F
808E53D1DBA6EAF1C5FFFFE3FDFCE8FFFEF6FFF4F8FFFAFFFFF9FFF5E7F6FEEEFBFFFDF8
D4D9B0C9D597D1DD9DDAE6A4DCEBA6C9D990CEE094DEF1A2
C8EB9BC8EB9BC8EB9BC8EB9BC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EB9BC8EB9BC8EB99
C8EB97C8EC95C8EC94C9EA99CEE9A4D2EBA9C4DD99DAF4ABC9E497C9E493DAF6A2809A43
CCE68DDCF69DD0EA93CCE891C1DD88D4F09CD1EC9BCDE79DD0E9A8C8DEA0DDEFB3748445
778645D2E19CD8E9A3D1E79EC7E396CCED9ECEF1A1C8ED9DC8EA9DCDECA0CEE89EC9E497
C9EA99C1E291CEED9FC9E39CD9EFB18EA06EDCEBC4F7FFE6000600000700DBECCCCDE2B7
CAE6A9CCEEA1C1E88BD0F1A2F3FFDDF9FFEDF5FFE4EEFDD6D5E7B7D7ECB1C3DC98D2EEA3
C8E59389A95486A854CEF19FCEF1A1B6DB8ED0F4AABCE096C5E898D3F4A3C2E193CCEB9D
D0EAA0C8E298C8DE96A0B66ED6EAA5D1E5A0D8EDAACFE4A1D2E8A7CCE2A18AA362D3EEAB
C4E39DCFEFA6D0EBA6C8DD9CCDDB9E929963CFCE9EE3E0B5FFFFDDFFFFE1FFFFE6F9FBE5
FCFFF1F8FFF4EBFBEEF9FFF8FDFAF3B1A6A2AFA4A0FFFDF8FEF7EFFFFFF1F2FAE2E7F8D6
CFE6BACEE8B8C4DAABE5F4CBF4F9D95E5744FFFBF1FFF3EFFFFCFAFFF9F9FFFAFAFFFDFF
FFFCFEFFFDFFFFFDFFFCF7FBFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFDFEFFFBFCFFFB
FBFFFDEAECE9090000E7D9D9FFFCFAFFFBFAAF9095D7BDC0FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFF2FAFCFCFFFFDCD1D9FFF8FFFFF8FBFFF6F6D5C6C1FFFCF0
ECFFE9F0FFECEEFDDEE0D6BB764737CDA08DECE7C7D0DFB6CFDAAFD8E1B2D6DEADDCE5B0
C4CB97D7DEABDFE2B7DEDEBCFFFDE9FFFEF3FFFBFAF1E2E5FFF9FFFFF1F9FFF9FFF7EBDF
DADDAEDBE6A4E8F3AFC7D28DB2BF7798A65B9BAC5E8C9D4F
C9ED96C8EC95C9EC98CAED99C9EC9AC8EB99CAED9DCDF0A0C8EB9BC8EB99C4E793C6EA93
CBEF97C4E88EC1E689CEF09AC5DE9ADBF1B1CEE4A3CAE49DC9E497D0EB9A9AB6616E8A33
CDEA90CAE78DCEEA93D0EC95C9E590CAE692D1EA99CDE59BC6DF9ECFE5A7D3E7AA859556
758443CEDD98D5E6A0D0E69DCCE89BC8EB9BC6EB9BC6EB9BC8EA9DC9E99DCCE89DCCE89B
CDED9ACAEC98C4E397D4EDA9CBE0A595A777D3E2BBFBFFE6041100000800D4E6C0D3EBB9
C0DF9CC9EC9ACDF497CCECA1F9FFECFEFFFBF9FDEFFBFFECD1DCBACFDFB0CDE1A6CDE4A0
D0E89EA7C2738CA957CAEA97CCEB9BC9EA9BCDEDA1C6E89BCCED9EC5E697CDEC9ED0EFA1
C3DD93D6F0A6CEE49C6F853DD4E8A3C9DD98D0E5A2CFE4A1D3E9A8D4EAA9869F5DA8C37E
BBDD91D2F4A7CBE79DBED38ED6E5A4737B3FB9B983DEDAAAFDF8CEFFFFDDFFFFE2FDFFE6
FBFFEDF6FFF2F0FFF2F8FFF8FFFCF6CBBDBACBBDBAFFFBF5FFFBEFFFFFEDFBFFE6E9FBD1
CDE8B3BDDB9FC6E2A7EFFFCCF4FDD0908D6CD4C8B0FEF1E1FFFBF4F9F6F1FFFEFBF2EEED
FFFEFFFFFEFFF9F7FAFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFBFEFFFB
F8FEFAB2B4B1706464F1E3E3FFFCFAFFF9F8D7B8BDF6DCDFFFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFFBFFFFF8FCFFE9DEE4FFF9FFFFEEF0FFF6F6D8C6C2FFFEF4
F4FFF3EFFFEFF8FFEEB6A9987E4C43C09084FDF6D9CFDBB7DCE6C3CED8B3DAE3B8CAD3A4
8A9261909666B2B88A82845D8E8D6FF4F2DBFFFCECFFFEF1FFF6ECFFF9EFFFFDF1FFFFE2
DCE5ACD7E7A0CFDF96AABA6F899B4FA1B465CBE091D5EA9B
CDF096CAEE94C9EB94C7EB94C6E894C3E694C5E697C6E999CCED9ECCEF9DC9EB97C9ED96
D0F29CCBEF95C8EB91CEEE99AFC68082965794A9668EA55F90AA606A85367A9745C3E38E
CFEC9ACEEB99CBE79ACBE79CCFE9A2CFE8A6CEE4A4CDE3A5D1E9ADD4EAACD6EAADC7D798
BAC988B9C883CFE09ACCE49ACAE99BC8EB9BC6EB9BC5EC9BC6EB9DC9E99DCCE89DCCE89B
BFDF8CD0F09DD2EEA3CBE4A0C7DAA291A172FBFFDFFBFFE34B5636717F5BD1E4B7CBE4AB
D2F0AACAED9BC8EF92B2D289F8FFEEFCFCFEFFFFFAFFFFF3E3E9CFC5D0A8D6E4B19EB072
859A55778F43799445C0DD8BCBE898CBEA9ACFEEA0C8E99AC9E99DCAEA9ED0EFA3D4F3A7
C9E399D0EAA1C6DC94798F47879B56D4E8A3D5EAA5CDE29FC9E09CCAE19D98B16D89A45D
DBFBAFC0E192D6F2A5DAF0A7D5E49F626B2A626329DBDAA4F0EEBDCBCA9EE1E3BED4D9B9
F9FFEAF4FFEAF2FFF3F8FFF4FFFFF6D5C8C2DCCFC9FFFDF4FFFBEDF1F3DBCEDAB6C6DAA9
CAE6ABCFEFACC7E6A2C4DD9CDCE9B3C4C79ADBD5B1BCB297C8C5B6FBFBF1FFFFF8FDFCF7
F8F7F5FFFDFEFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFEFFFB
FBFFFD888A87FAEEEEFFFBFBF6ECEAFFFBFAF5D6DBE3C9CCFFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFFBFFFFF5F6FAE5D9DDFFF9FDFFFAFAFFFBF8E0CDC9FBF2EB
F8FFF6EBFCECFBFFF4AC9E937B4A46ECBBB4FFFEE4EFF6D5F6FFE3F6FFE3FBFFE1FBFFDC
E5F3C2C7D3A1D6E2B0D8E4B4D7DFB6C1C9A4C8CDADA6A98CA9AC8DD6D9BAFFFFE3F5FED1
A3B674A9C175B0C87AB1C97BB9D183CEE99AD7F2A3C9E696
CAEB90C9EC90C9EA91C8EA93CAEA97CCED9CCFEEA2CFEFA3C6E599C7E79BC7E698C5E695
C8E797C9EB95C8E893C6E3918FA35EBBCB8AC2D593CCE19CDAF1A9BEDA8FDAF8AECEEEA5
C5E39DCCE9A9C7E3A9D1E9B7EEFFDAF5FFE6F4FFE7F7FFE4F3FFD6E3FBBDC9DDA0D6E6A7
D0DF9E8FA05AD4E8A1DAF2A8CAE99BC6EB9BC5EC9BC5EC9BC6EB9DC9E99DCCE89DCCE89B
CBEA9AC9E898CAE69CCDE6A4D0E4A99DAD7CCCD9AEF8FFDCE2EEC6E0F0C3BFD19DC2DA9E
CFEAA3C5E695D0F79EDAF7B4F7FFEAFBFAF8FFFFF8F2F5E4F4FAE0FCFFE19EAC7BB2C488
D8EBA9CDE39AC3DB8FDFFAABD4EF9EC9E694C9E696C3E294C2E296C7E79CC3E197C7E59B
CAE49BD4EEA7DEF3AEBED38E6C8039D5E9A2D8EEA6D0E5A0CEE59FCBE29CBED8918EAA60
C4E395BAD989CDE899C6DC91CFDF9699A45F5C611F96975BDDDEA5D7D9A7DEE4B6CAD5AB
F9FFE4EDFFE0F4FFEDEFFDE6F3EFE4AFA59CBEB4ABFFFAEFFFFBEBF5F7DFD3DDBAD6EAB9
C8E4A7CAEBA6CBEBA2CAE59ED2E5A5D7E0A7DDDCACD5D3ADBABAA2ACAEA0FFFFF4F4F6EB
FFFFFAFFFFFDF9F9F9F6F6F8FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFEFFFB
F3F9F5696B68FFF3F3EFE1E1FFF5F3FFFBFAF8D9DEC7ADB0FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFEFFF7FBFEF9F9FBE4D4D7FFF4F6FFF7F4FFF3EDECDAD6FFFBF8
F8F9F3FBFFFAFBFEF7E2D5CF714544633630F1DFC9FEFEE2F0FDE3F5FFECEAFFDAE1F8CA
E9FFCDD7EEB6C9E1A7C6DEA4CEE5AFD2E9B5D2E8B7C1D5A4D3E7B46D814CC7DCA4496324
91B166BBDE8ED8FBABD5F8A8CAED9DC0E595C0E595C6ED9C
C9E78DC9EA8FCBE993C9E994CEEB9BD0EFA3D2EDA6CDEBA5CDE8A3CDEBA5D2EDA8CCEAA2
CAE69CCEEDA1D3EFA2CDE79DA5B672A3B271ADBD7CCEE39ED1E8A0E7FFB9B1CF87C2E19D
C7E5A7D1EEB6C4E0B0CCE5BEF4FFEDF7FFF3F2FEF2F7FFEFF0FFD7E4FCBED1E5A8D4E7A7
DBEBAA899A54D3E7A0C5DF95CAE99BC6EB9BC5EC9BC5EC9BC6EB9DC9E99DCCE89DCCE89B
D3F2A2C6E595C7E198CEE4A3CEE2A7C7D5A06F7B4BD0DCAEE7F3C3CDDBA8D4E6ACE3F8B7
CDE7A0C2E193C1E291CCE7A4FBFFE6FEFFF3FBFFEAF8FFE6FCFFE4ECF9CEA2B37FE8FAC0
D2E7A6CBE09BC3DB91C8E396C4DF90C7E494D1EE9ED6F5A7CEEEA3D5F4AEC6E49EC5E39B
CAE49DC8E29BD7ECA7D5EAA59EB26BACC079D3E9A1D0E69ED8EFA7CBE399D5EFA5B3CD83
ACC87BD1EC9FDAF2A6C7DC91D7E79CD9E59DA7B16A5C63208B9153E6EEB5D6E0ACCCD9AB
DAEBC1D1E2BED2E7C6D3E1C7FFFDEECFC6BDC3BAB1FFFEF3FFFFF1FFFFECF4FEDCE9FACD
CCE8ADBFE09BCCECA3DAF8AECCE39DD3E3A2D8E2A6FFFFD6FFFFE4CED1BCADB09DF6F8EA
FFFFF6FAFBF5FBFBF9FDFDFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFEFFFB
FBFFFD0C0E0BFFFBFBFFFBFBFFFCFAFFFBFAD3B4B9CAB0B3FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFDFFFEFFFFFFFEFFDBC8CAFFF6F5FFFDF4FFFEF4F1DFDBFFF9F7
FFFBFBEFE9E9F9F9F7FFFAF8BA9897855E57A58A79FFF9E3EEF6DFF5FFEDEBFFDCCBE2B6
CEE7B0C8E2A5CCE6A7D5EFAEC4DEA1D7F3B6C0DCA1D6F2B7C4E0A3CCE9A7C7E4A1C6E69D
C4E69AC8ED9FB7DC8EB0D587C6EB9DCFF4A6C8EDA0C9EFA2
CDE992CEEC96CEE998C9E598CBE59CCCE7A2C9E2A1C0DA9DCDE5A9C8E1A7D0E8AECDE7AA
C4DD9CC9E4A1D2EBA9CDE3A2D2E0A2D6E2A28C9C5BD2E6A1C6E097B7D58BC7E79ED5F6B1
C6E6A7D0EFB6C4E0B0CCE5BEF4FFEDF7FFF3F2FEF2F8FFF1F5FFDCDEF6B8D9EFB1CBDE9E
DAEAA993A45ED3E7A0CAE49ACAE99BC6EB9BC5EC9BC5EC9BC6EB9DC8EA9DCAE99DCCE89B
C6E595CBEA9CD6F0A9D3E9A8C6D89CE2F1BA7C8953A1AB76D4DFA7CBD99ED5E5A6C8DB99
C5DC94D8F2A9DAF6ABBFDA97CFE1AFD1E0B5CCDCAFDDEDBECFDFAE60733CD5EAB1BED496
D6EFADD4EDA9D5F0A9CEEAA0D1EDA2C9E89AC4E395C4E498C0DF99CFEEAAC7E4A1CEECA6
D6EFABC5DE9AC9DE99CDE29DC8DC95778B44D3E9A0CCE299D4ECA2C8E094D0EB9EC9E497
8FA75D96AD65D2E89FD8ECA4D8E89FD4E199DBE79F97A25D5A66249BA769D1DEA6D4E2AF
C5D6A9C9DBB1C5D7B1CEDDBEFFFFEFFFFBF0D5CEC4FFFEF4FFFFF3FFFFEFFEFFE8DDECC5
CEE7B0C5E3A3C8E9A2C6E69BBAD58EE0F7B1D4E4A3EFFCC6FAFFDDFEFFE8F3F8E1E4E9D5
000300EEF1E8FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFB
000200000100FCF0F0FFF7F7F6ECEAFFFBFAFFF5FAE4CACDFFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFDFFF9F9FBF6F2F3988485E5D2CEFDFBEEFFFFF3C1B2ABAD9897
FFF7FDFFF9FFFFFEFFFFFEFDFFF0EEDDBCB57C5B4CB8A18FFFFFEDF6FEE6D9E3C1D6E3B8
D5E3AEC6D89CCFE2A2D5EAA7D6EAABC4DA9AD3EBADBFD799D8F2B1D4EFAAC7E29BD4F0A6
C5E197D8F4AAD8F3ACD1ECA5D4EEA7CAE49DC1DB94CBE69F
CEE794CFEA99CFE79BCAE49DD1E7A6D8F0B4D9EEB6CFE6B0D6EAB9C4DAA9CEE2B1D6EDB9
CEE2ADCEE5ADD6EBB2CBDFA4D6E1A7D7E1A5C1CF91B4C785C1DB92DBFAAECEEEA2C2E79A
C1E59DC8EBA7C5E4A9CFEAB7EDFFDCF7FFE8F5FFE9F8FFE8F5FFD8D2EAACD5EBADC6D999
D3E3A293A45ECEE29BDCF6ACCAE99BC6EB9BC5EC9BC3ED9BC6EB9DC8EA9DCAE99DCCE89D
CDEC9EC5E498C6E099DCF2B1D4E6AACFDDA2D8E3A9AEB97D9DA96BD6E2A2DFEEABDCEDA7
CFE59DC3DA94D0E9A5D2EBA7C8E19DD8F1ADC6DD99D1EAA6CFE8A68CA764E0FBB8C2DD9A
BFDC99BEDB98C9E8A2BEDE95CFEFA4CBEB9FC3E598CEF0A4C8E7A3CDECA9C2DF9DCBE8A5
D5EEACCBE4A0D3E8A5D6EBA6CEE29B798D45CFE59CD1E79CD4ECA0CEE698CDE899CEE69A
9DB26D6C7F3DC3D792D3E49ECADB94CDDD96DEEEA7D5E59E9CAD674D5D1CD4E3A8DCEDB7
D9E9BADEEFC3D1E1BAD8E6C5F5FAE6FFFFF4DAD6CDF3EEE8F4F0E7FFFFF3FFFFEDE0EBCB
CCE2B3CAE6ACCBEBA8C6E7A0BADA91DAF5AEC8DF99D3E5A9D2DDB2FEFFE4FEFFE6DDE2CB
DEE2D1D7DACFF2F3EDF3F3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFB
0E1410666865FFFBFBFFFAFAFFFCFAFFFBFAD2B3B8FFF1F4FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFDFFFFFFFFFFFCFC917C7BDAC7C1FFFFF1FEFFF1DED1C9C8AEAF
DCB8C4FFF5FFF6F4F9FAFCFBFFFBF8F8DDD69C7468BC9787FFF2E3FFFAE5F5EED1EBE7C1
DCDCAADBDEA5E6EAADD0D696D5DE9FD1DB9ECED99DE8F6B9CEDC9ECEDE9DD5E6A2C9DA94
D7E6A3D4E0A0CCD898CFDB9DDCE6A9DBE5A8D3DDA0D2DC9F
CDE398CFE79DCEE39ECCE2A1D9EDB2ECFFCBF5FFD9F0FFD6F4FFDDD3E5BDDBEBC4F3FFDB
F2FFD7EEFFD3EBFDCDD6E6B5DBE3B0D4DBA5909B61BCCF8DCFE99FBFDE8ECFF39CBDE48B
C9F097C8EE97C7EA98C8E89DCEE9A6D1E7A9CFE2AACEE1AAD0E9AFC5DFA0D7EDAFDBEEAE
DCECAB94A55FC5D992C9E399CAE99BC6EB9BC5EC9BC3ED9BC6EB9DC8EA9DCAE99DCCE89D
D5F4A8C5E498829C559FB574CBDD9FC3D194F2FEC0D2DC9DD4DF9BA1AC677F8C468E9E57
97AB66DCF1AECEE4A4C6E099C4E58ED1F496BFE085BDDF88CAEC98E0FFB298B86DD0F2A8
D4F5AECCEDA8D3F7B1BBDF97CCF0A8C4E89EC3E79DDCFFB8F0FFCDE6FFC4CAE7A7C7E4A2
C9E2A1C5DE9CD2E7A4CDE29DCCE099AFC37B97AD62C9E092D6EEA0D2EB9AD0EB9ACFE79B
DDF0AEB5C587CADA9BD4E4A3CEDF9BD6EAA3D4E8A1C9DD96D4E8A350632197A96DBDCE97
EBFBCAEBFBCED9E8BFE2F0CFFCFFEFFFFFF6FAF7F0EBE6E2DED9D6FFFBF5FDFEF0F5FDE5
DCEEC6D8F3BEDBFBBCD9FDB7C7E8A1C6E69DC1DF97D8EEAECEDBADE4EEC9E3EAC9DCE2C6
E8EDD7FBFFF0D0D3CAFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFB
565C58C7C9C6FFFBFBFFFBFBF6ECEAFDEFEEEFD0D5C8AEB1FFFFFAFEFFFAFFFCFDFFFCFD
FCFFFFFBFFFFFFFEFFFFFDFFFCFAFDFFFAFB998181BDAAA3F8FFEBF3FCE7FFFAF0FFE8EA
FFDDECFFEDFEFFFDFFEAF0F0FFFEF8FFFAF18C5D539E6D5FC6A095F6D9C9E7CBB39D8561
5E491C51400C5D4C14483C025F541C4A400BA59F6B989560DAD7A2E0DFA7DEDDA4E9E7AC
D6CF98B6AD769087506C622D51451154481470632F867945
D2E89FD3E9A1CEE3A0CADE9FD8EBB3F0FFD0F8FFDCF8FFDFF8FFE1CDDDB6D4E4BDF8FFDF
F8FFDDF6FFDBE9FDCCCCDDA9D8E1ACD3DBA295A163DAEEA9C9E399D0EF9FBDE08CCFF69D
C5ED94C3EA91C9ED96CDED9AC9E497CDE39AD5E6A0D1E1A0CADE9FDAEEAFD5E7A9CDDD9E
C2D18E8C9D57D5E9A1D2EAA0CAE99BC8EB9BC6EB9BC5EC9BC6EB9BC8EB9BC9EA9BCCE999
C7E293DDF2A5505D173E4706A5A96EE1E4ADD1D69ED3DBA09AA4676A7435B8C180A2AD6B
445010DCECABCADF9ED0ECA1C7EF8FBFE882D1F394D1EE94CCE591C3DE8F88A65CCBECA5
C3E3A0BFDF9ED4F1B1BFD99AD3EDAEC6E3A1C3E3A0E4FFC5F1FFD7E0F6C8C8DEADCCE3AD
CEE6ACCFE7A9D9EFAEC9DE99CFE39CD9EDA5495E13AFC57AD1E99BC8E092CCE796CBE397
D0E09FDFEDB0A7B578D3E3A4D2E5A3CCE09BD8EEA6C5DB93CEE29B889B59495B1D9CAB74
FCFFDAFCFFDFF4FBDAFCFFEAFBFFF1F4FAEEFFFFFAD3D2CEBEBAB9F5F1EEEAEAE2FEFFF3
FAFFE9F7FFE3F0FFD8D9F6BCCAE8AACAE9A6CBE8A6C6E0A1D2E7AFCCDCADD9E6BBD7E3BF
DAE3C6ECF1DBF8FAEDF2F3EBFFFFFDFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFDFFFFFD
080D09B7B9B6F8F3F0FDF5F2FFFEF8FFFBF8D3AFB3DDBABEFFFEFAFEFFFAFFFCFDFFFDFD
FCFFFFFBFFFFFFFEFFFFFEFFFFFDFFFFF8F99F8A89AC9B91FFFFECEEF6DEFFFEF1FFF3F3
D0AAB9FFF3FFFFF9FFFBFFFFFFFEFFFFFBF6AB89806841329A7966A68C717E66446A542B
8B7745A3925CAB9C63A4985EA1965EABA26B5A531D59541DA6A16A98965D8F8D52929055
A49D66645D26433C055A531D847A45A399649E94617D733E
D2EAA0CDE49CD3EAA4CEE3A2D9EDB2CDDEA8E0F0BFEEFECFF7FFDAEBFBCCF8FFDAD0E2AE
D1E6AECDE5A9BED899D5EBAA88934F9BA560D4E49DCBDF97D5EFA5BDDC90D4F6AAC2E79A
C5EA9DC7E99DC8E89DCDE79ED1E59ED3E39CD6E19DD7E09DD6DFA0D6DFA0B9C2838B9654
8F9B59C9D893E3F4ADC7DD94CDE89BC8E799CCED9CC3E694C9EC9ACCEF9DC2E591D5F39D
D2E68F9BA04E5E540D705C216C52215B461B3730064E5126000800000800E8EAB9D1D19D
C2C38999A25FC0D48CD1F19EC1EE91C9F596C7DF8BDDE89CDEE19C939A57D5E8A8C7E1A2
D2EEB3E0F7BFFCFFD6F1F7C7D8DEAED3DFADCBE2ACE4FBCFFBFFF1FEFFF4EDF7DFD3E3BF
C7DDACCDE5ABD1EAA9CEE59FD9EFA7CADE97CDDE988A9E57C7DD94D7F1A7CCE89BCEE99C
CADE97D6E5A294A463819150D4E8A3D1E5A0D1E59ED1E59DD3E49DD0DF9C545F239EA673
FFFFDEFFFFE6FFFFEFFFFFF3FBFFF4F6FFF4F8FFF5F4F9F2DFDFDDCECCCDE1E0DEFFFFFB
FEFFF5FEFFF1F8FFE7E8F8D4E6F9CCE7FDCCDBF4BDC7E3A8CAE7A5C8E5A3D7F0B6BCD09D
D2DEB6FEFFE6CCCEB9E1DDD1FFF9F3FFFDFBFFFBFCFFFCFDF6F0F0FDF7F7FFFEFDA8A7A5
666467FEFFFFFBFFFBFBFFF8FEFFF4FFFCF3FFE0E4E4B5BBFFFBF8FEFFFAFFFEFDFFFEFC
FBFFFAFBFFFAFFFFF6FFFEFAF8F2F6FFFBFFFAEBE8B3A799FFFFEAFAF8E1FFFEEFFFF9F6
E4CEDAE2CFE3FFFAFFF8F5FFFFFBFFFFFCFFFFFCFAFFFAE7E9E7C0C8CD97D9DEA6D6DBA1
D8DEA0D7DD9DECF5B4D7E09FD8E1A0D2DD9BDBE6A4D9E4A2B7C28096A35E909D5896A35E
B8C784D0E09FCFDF9EDDEDAED9ECACCCDF9FD7E9ABCBDE9E
CBE59BC6E096CEE59FDDF3B2C8DA9ED3E4ADCCDAA7FBFFD8F9FFD8F9FFD6F7FFD3C3D89F
D0E6A8D6EFADC1DC97B6D087D4E99CD9EC9DCEE396CCE297DEF5ADCCE69FC2DB97D2EDAA
D2EBA9C9E2A0D6EDA9CCE19CC3D490E8F7B2C9D99254611B55601C5C6524909B59D1DD9B
E0EFAACCE099C7DD95CFE79DC4E095CDEC9ED5F6A7C6E796C7EA98CDF09EBFE28EC9E591
DCE491A59D52665412B5A069D8C396FBEDC6A8A8843F46241F2907040B006A6842E3DFB2
DAD7A2A3A868D5E29ACDEA98BBE991C4F099D3E599E7EAA7D6D0929D9B60D8E6ABCBE3A9
BFDBA1D6EDB9FEFFDBF1EFC9E0DCB9E1E3BED4E4BDE1F1D4FBFCF7FCFAFBF5FBEDE9F6DA
D9EFC1D0E9AFCEE7A6D0E7A1D0E69ED1E29CC1D08DA2B36FCEE49CBFD98FBEDD91CEEA9D
D7EDA2D2E39C94A861596D28CBE09BD0E5A0D7EDA5CCE299DBECA5CEDD9A535F219EA571
FFFFDFFEFAE1FFFDF1FFFDF1F9FFEFECFEE6F8FFF1FBFFF4EEF1E8C4C5C0C9C8C6EEEAE9
FFFEFBFFFFF8FFFFF3FAFFEBF6FFE3F4FFDDE6FCCED5F0B9D0EFACC8E9A4CCE9A9D4EBB3
D5E2B6FEFFE3DBDAC5D6D0C2FFFDF6FFFCFAFCF0F2FFF8F9FFFCFDFFFDFDEAE6E5060203
FDF8FCFEFFFFEEFBF2F5FFF8F3FCEBFFFCF3FFDBE0E5ADB6FFF9F9FFFFFDFFFEFFFFFFFF
FBFFFBFBFFF8FFFFF6FFFFF8FFFBFFFEF3FBFFF9F7B1A79DFFFFECFFFFECFFFEEFF7EEE9
DCD1D9E1D6E6F9F0FFFFFBFFFFFCFFFDFEFFECEEE9FBFFECEDFFC9C7DE9AD5ECA8D8EFAB
D1E8A2BDD48ECEE59FC6DD97D4EBA3C9E098C9E098CDE49CCBE399CFE79DD2EAA0CAE49A
CDE79ED8F4AACAE59EBAD890C2E09AC9E8A2CBEAA4CFF0A9
DCF7AAC4DE94D6EDA7C4DB97CEE0A2C7D99FE4F5BFCCDDA9CCDDA9CFE0ACB0C38B72874C
7F9555A6BF7DC6E19CC6E49AD4F7A7A7CA78CDEE9FD6F0A6C6DA93E1F0ADE2ECAD697135
949A5E8D95598894548495518DA25DA8C279C6E599D6F5A9CBE29ACADF9AD0E7A1D0E7A1
C4DE97C6E298CFEDA3D0F0A5D7F7ACC5E79AC1E396C2E497D2F2A6D4F5A6C3E495D5EA9F
E5DC9B564309DDD69FD7DEAAD2E6B5A7C297CDE9C3D4EECB273619000600666342EAE5BD
CAC6968D8E549AA15ED4EA9FC6F09EC4EE9CD4E59ED8DD9BABA96C92965BCEE2A5CBE9AD
C8E9B0E3FECBFBFFDFFFFFE3FBFCDDFFFFE8F4FFE6F6FFEEFFFFFAFFFFFAFCFFF1EBF9D8
DDF3C2DBF5B8DAF3B1D7EEA8CADE97DCEDA7DAE9A68D9E5AD3E7A0DDF5ABD9F8ACC6E597
CEE99CCDE599C5DC94839A54D7F1AACBE59ED1EBA4CFE9A0C6DC94DCF0ABE3F3B46D7840
F0F6CAE2E3C3EEE9D3EAECD4E7F7D2DAEFC6E5F5D1F9FFE8F8FFE9E4E7D6E2E2D8F4F1EA
FFFDF6FFFFF6FFFFF3FEFFEFF7FFE8EAF8D7DBEDC7CFE6B8CFEBB0C6E4A6C1DAA1F0FFD2
DDE9C3F9FDE2E4E3CFD1CAC0FFFDF8FFF6F5FEF4F5FFFBFFFFFDFFFCF8F9EEEDEB52514F
FFFEFFF8FAF7E7F4EAF7FFF6FBFFF4FFF8EFEBB4BAEBB3BEFFFAFDFFFFFFFFFEFFFFFEFF
FBFFFFFBFFFDFFFFFBFFFDFCFFFBFFF9EFF8FFFCFDC4BBB6D3CBC0FDF5E8FFFEF3FFFDF6
FFF7F8E6DDE2F5EEF5FFFEFFE0DFDDFEFFF8FEFFF3F1FFDEDEFABFB8D992BEDF98CAEBA4
D0F2A8C8EAA0D1F3A9C6E89EBDDF93C9EB9FD8FAAED3F5A9C3E598C4E699C9EB9EC3E397
C4E093CBE699CDE79DC9E59AD4F0A6D2F0A8C4E29AC8E89F
C7E295D0EB9EC8DF97C9E09AF3FFC74D5F2340511A53642D94A56FC7D8A2D4E8ADC9DDA0
D0E6A5D7F0ACDAF5AEC3E398CBF0A2D1F8A7D5F7AAB5D187D8ECA7434F0F4F571BDDE1A6
D3D79CE7EDAFD9E2A3C9D895D3E9A1CFE99FBEDD8FC5E498D7EEA6CBE09BD1E6A1DCF3AD
D7EEA8CFE9A2CEE8A1CAE59EC3DE97D2ECA5DFF9B2D0E7A1C9DF97CBE199C5DB93DEE7A6
A896645C4B1FE2ECBAC4E4B3BFEFBFCDFFD6B6E2BEC1E0C16B79600408004D4C304F4C29
E6E7BB939563A9AC73CBDA99C9EDA3C1E699D4E59FD2D898949657939B5FCAE3A2C9ECAC
C9EFB4D7F8C3F1FFDBFBFFE5FFFFECFEFFEFF8FFF3F8FFF4F4F7EEFFFFF4FCFFECF9FFE1
F5FFD6F4FFCFECFFC1CDE49CD3E7A0C8D993E3F2AF81924ED0E49FC8DF97C8E79BC9E89A
CBE898C5E292E1FDB2C9E59BC8E6A0C9E7A1C5E39DCFEAA3D7F1A8C0D78FD3E6A491A163
97A16DDAE1B7CDCEACE8F0CBCFE1ADCDE4ACD2E6B3DEEDC2F7FFDEFEFFE8FAFBE9E4E2D5
FFFFF4FFFFF4FFFFF4FFFFF3F2FAE5DFE9D1CFDEC1CADBB7D2EAB8CEE7B0C7DBAAF9FFDF
F2FBDCFFFFECDCDACDE3DCD4FCF4F2FFFCFDFFFBFFFFFAFDFEFAFBFFFEFFD4D4D4747472
F5F1F2FFFFFDF8FFFAF7FFF6FBFFF4FDEEE7D49CA5C38B98FFF9FFFEFFFFFFFDFFFEFDFF
F9FEFFF9FFFFFDFDFBFFFCFBFFF8FFFFFCFFFFFDFFF4EBECAEA6A3FFF9F4FFFBF4FFFEF6
FFF8F0A9A59ABAB8ABFFFFF1FFFFEFFEFFECFEFFEAF9FFE1E9FFC6D2F1ABCCEBA5C7E6A0
C0E097C2E299CCECA3C7E79ED8F8ADC3E398B8D88DBCDC91C8E89CD8F8ACD7F7ABC7E698
D3EE9FCFEA9BD0EB9CDCF7AAD0EAA0C5E197D0EBA4C7E29B
C8E595D2ED9ED2EAA0C5DC94A8BD7A819655A5B77BD8EAB0CBDCA5DCEEB4CCE0A3C9DD9E
CDE3A2D0E9A5CEE9A2C4E096C2DE94D3EFA5C1DB92617B3497AE68AFC481DBEEAECEE1A1
DCECABC7D796CADA99D0E19DCCDD97DCEDA6E5F7ADCFDF98D4DF9DD2DB9CD5DE9FD2DC9D
CDD798D5DFA0DEE8A9D8E2A3D5DFA0DBE4A5D1D79BB3B77CC4C58BDAD9A0ACAA71807945
6D5F38C1C19BBBDAAEB3E8BAA3E6BABCFDD5AEDBBECDE6D00004000D0C00858771555C3D
5C673FAAB388646738E4EEB9C5E2A0C3E19BD9E8A7D8E1A09BA46399A867CBE8A5C3EAA7
C4EEAFC1E6B0CEE4BDEAF7DBFBFFEEF7FAEFF6FCF8F9FFF9FEFFF4F4F9E3E2EDCBDBECBF
E4FCC2EEFFC6E4FEB7D4EAA2DBECA6D9E8A3C4D08E9FAE6BD2E6A1CFE69ED9F8ACC0E192
D3F3A0C1E18EC3E495CDEDA284A35DCBEAA6C9E8A4C7E59FCCE7A0CFE9A0CAE098B0C47F
49581D9AA771ECF4C5B9C593CBE1A0CEE8A1D1E7A7D5E8B0E7F4C6F3FBD6E0E3C8C1C3AE
FDFBECFFFEF2FFFFF6FFFFF6FBFFF1EBF2E2E4EDDAE4F1D7E4F6D0E7F9CFE1EFCBFBFFE6
FEFFEDFFFFF3C6C2B9F8F0EEFFF8F9FFFCFFFFFCFFFFF9FDFFFEFFFCFCFC868887A4A4A4
FFFEFFFFFFFDF6FFF9F7FFF8EFF5E9FFFBF4FFD3DEB47B8AFFF9FFFEFFFFFFFDFFFDFCFF
F9FEFFFBFFFFFFFFFDFFFFFDFFFBFCFFFDFFF9F4F8FFFDFFC7C1C3FFFCFDFFFDFAFEF7ED
FFFFEDEBE9D0A7A8888A8E6BE5E9C4FEFFDFE1E9C2DEEABCD6E5AAD1E1A0D5E5A4D5E5A4
B1C27E91A25E8C9D5999AA6682934D96A761C1D28CDEEFA9D4E59EC5D68FC8D992CEE398
D0E797CFE897B9D281AFC7798AA25899B36ADEF8B1C4DE97
D0ED9BC3E090CDE89B627A30738843E0F5B2E9FBBDC8DA9CD4E6AAD9EBAFD1E3A5D2E7A6
CDE4A0D1E8A2C7E198D6F0A7D3E7A2899D58869B56C9E09CCEE7A3C0DB96C0DB98CAE5A2
CDE6A2CFE8A4D6EBA6DFF0AADCE9A3CED994CCD68FDADF9CDCDC9EEFEDB2EDEBB0BEBE82
898A5076773D666A2F4F50172F300043420A5F5C275F59255C521F5F53216F6130999163
B0B58DC8DEB7B8E7BBBCF9CD4A8B612E6643204028546150201E120400004C543F313F25
0B1E00778864D2DCB76E7B4DD2EAAED5EBAADAE6A6D0D9989BA662859952C6E69DC0EAA2
C8F2B0C1E8AFC2DDB2E7F7DAFCFFF4FFFFFBFFFFFFF9FBF8F4F9E5C9D0AFA8B58AA5B783
A0B9788DA760849B538AA057768741A1B06D667232C2D1909AAD6B7B924CBFDD93D2F3A4
C4E690CEF09AC1E291C8E89D61803AC3E29ED2EFACCDEBA5D3EEA7C3DD94DDF3AAD3E7A0
B0C07F576528859058D5E4A9D7EEA6CDE89BCDE49ED3E7AAD7E5B2D5DDB4D7DCBEE0E2CC
E0DECFEEECE0FBFBF3FFFFF8FEFFF7FAFDF4FBFFF5FBFFF3F4FFE7F9FFE8F7FFE8F8FDE9
FFFFF3F0EDE6B6B1AEFDF4F7FFFCFFFFFAFFFDF6FDFFFDFFFFFFFFB4B5B7565A59FEFFFF
FCF7FBFFFFFFE8F3EDF7FFFAFCFFF6FFFAF6FFD8E3DAA1B0FFF9FFFEFFFFFFFEFFFEFFFF
F9FFFFF9FFFBFEFFF8FFFFF6F9FBF0FFFFF8FEFDFBFFFEFFDCD7DBF1EBEDFFFEFAFCF9EA
F8F7DBFFFFDCFFFFD6E1E8B5E2EAB797A16F778355A9B283D2DBA2A8B1728891529BA465
949D5C8F9857A1AA69D3DC9BC7D08DA5AE6B949D5A969F5C8F99548B9550949E599AA75F
8DA253AEC776ADC6759AB264849A51A4BA72E1F6B1CCE19E
CFEF9CC8E5957E994C213900B1C77FD5EAA5B3C684D5E8A8CADA9CCBDE9ED5E8A8D5EAA7
C9E09AD5ECA4BAD48BD8EEA6909F5E9BA767A4B372CEE1A1C3DC9ADDFAB7CFEEA8C4E59E
BFDE98CEECA690AA63637730939E59A7AE6A848744777636ADA76D988F588D864F7D7840
4D4A132625002E2F00474711A4A470918F5C999766A5A171A39B6D93885BA3966ADADDB0
CDEFBDB0E6B4B2ECBA93C89A1D47217C9679848774AFA79A16090006000077836F627A62
000C005E7B5DCEE5C871865FC5D8A1DAEAABD8E3A1CCD793A6B36D758A3FC5E697C4ED9F
C0EAA2C4ECADC0DDADDDF0D0FCFFF3FFFFFBFFF8FFDCD8D5979B829AA57BB2C38FD2E7AC
DDF6B2D2ECA3CDE59BD4E8A0C1D08B7B8745252F00CAD698BED18F97AE68BCDA90CDEE9D
B9DA83DAFBA4D0EF9FCFEDA396B46EB4CE8DC8E1A0D2EBA9BED58FD7EDA4CADC92D1E198
DFEEA9B9C583455113DBE9ABD6ECA4C9E39ACBE1A0D8EAB0E1EFBEE4ECC5F1F5DAFFFFED
CCCABDE4E1D8FAF7F2FCFBF7FAFBF6FCFEF9FEFFFAFCFFF8F9FFF0FCFFF1FDFFF2F8FAEF
FFFFFAD2CECBCAC4C6FFF8FDFCF5FCFFFCFFFFFDFFF9F7FCFBFBFD828385464A49EDEEF0
F9F4FAFFFEFFF9FFFFF3FEF6FCFFF8FFF4F2DAA2ADE7AFBCFFF9FCFEFFFDFFFFFDFEFFFA
F7FFF2F0FCE8EEF3DCEBEFD4E9EFD3F1F9E1FEFFF4F5F6F0E4E2E3DEDDDBE6E3DCF4F3DF
F9FAD8F0F3C4F1F6BCD3DB9FD1DAA1DEE8B3BBC799899263979C64969A5D9DA164D2D699
E4E9A9E7ECACD4D999E1E6A6E5EAA8DADF9DD1D694BCC17F979C598489468C914E949E57
8D9F53B0C777CDE496C2D88DCCE099C5D896B3C686E1F3B5
9BBB68BEDE8B9EBB6BD0EB9ED0E89ECCE29AE2F6B1D1E4A2D7E7A6CCDC9BD2E5A3D1E5A0
CBE199D5ECA48EA65C8BA25AB4C785C5D596D7E7A8DEF1B1D2E7A6C7DD9CC8DF9BD0E9A5
D6EDA98BA25C566A256677318E9B569BA66297A05D979C5C95935AA5A26BABAA729B9C63
969B61B7C087D3DEA4CDDAA2D1E0A9D6E4AFDAE8B3CDD9A7D5DFADDFE7B6D7DAABD2E6B3
B4EAB098DA9D8DC48D406738E5F9D4FFFFE6FFFEEACAB9A90B0000120C002D38270F2711
2D4D3670937BA6C8B0A0BD9E94A473C9D597DAE5A3E3EEA9CCDC91809747D3F09ECFF2A0
C0E699D2F7B2C9E7B1DCF1CAFEFFEDFFFFF6FFF1F4C5BAB6AFB593CDDBA8DDF1B6D0E6A5
C4DE95CCE79AD6EEA2D4E8A0DBEAA7D1DD9DD1DB9FB8C3878A9A5BACC37DD7F5ABBFE08F
CDEB95D6F49EC0DD8DC6E096DCF5B3A9BF7FB2C687CADD9DD9EDA8DCEDA6C9D68EE0EDA5
D3DE998B9652586122D5E1A3C8DC9DCEE4A6D9ECB5E8F8C9FBFFDFFCFFE6FAFEE7E6E9D8
D0D0C6F0EDE8FFFEFBFFFFFDFEFDFBFFFFFDFFFFFBFAFDF6FBFCF4FFFFF8FEFFF9FFFFFB
FFFEFDC6C0C2F0E9F0FFFCFFFFFCFFFFFAFFFFFCFFFFFEFFFCFCFE3334363A3E3DFDFEFF
FFFBFFF7F4FDF9FFFFF5FFFCF5F8F1FFFAF8EBB3BCF2BAC3FFFAF7FEFFF6FFFFF4FEFFEF
F2FFE3E4F2CED9E4BAD1DAADD8E5B7DCEBC0F7FFE3FCFFF1FDFFF7FFFFFABCBDAFCED0B8
D0D5ADDEE5AFD4DD9ED1DC9ADDE8ACFEFFD4E4EFC4DDE8BD9AA56BCBD797D9E5A5DDE9A9
CBD795DAE6A4D1DD9BD7E3A1D1DE99D2DF9AD9E6A1D9E6A1D4E19BDBE8A2DFECA6D2E29B
D4E99ECBE196DBEFA7C6DA93DEF1AFA5B77956652AE1F0B7
BEE08CD4F4A1D3F0A0C6E194D2EAA0C5DB93D6EAA3CEE29DD9EAA6C6D793000E0093A762
41570F5D742CC5DC94CBE69FCEEDA7C6E5A1CEE9A6CEE3A2E1F0AFD0D99AD6DA9DE1E2A6
060800636828CFD897CDD997D9EDA8CBE59EC9E49DCFE8A4CADA9CE3F1B6CDDFA3D3E9AB
C8E2A3BCDC9DD8FCBCB4DC9DC4EEAEBBE7A8C4F0B3BAE6ABB9E2A8D0F9BFB9DFA68BB87D
13500D001A00BDE3A8CEE0AEDBDCB2948A6760523564583E0800000D0B00E4E8D7F7FFF4
F0FFF84769581A4635C1E8CDCFE1B1C5CD91DDE8A4D6E39BCFE2938AA14FD8F19DC9E692
CDEE9DCFEFA6C2E0A2D8EEBFFEFFE6FFFFEDFFF5EFAA9A8DDEE3BBD0E2A8CDE3A3CFE9A2
CDE99EC8E396CEE499DBECA5D4E09EDEE8ABDBE3A8D2DDA1CCDC9DCEE59FD0EFA3C8E797
D0EC97D6EF9BCBE294C9DF96E2F5B589995B485619D6E2A4DBE6A4CFD994DDE7A0D6DD97
D5DA989EA363999A60D4DBA5D0DDAFF1FFD8F2FFDAFAFFE5FCFFECFCFFEFEDEFE28D8E86
FFFFFAFFFFFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFBFFFFFBF7F6F2FFFFFDFEFDFBFFFEFF
FFFAFEF5EEF5FFFCFFFFFCFFFFFCFFFFFDFFF3F1F6FFFEFFFFFFFF000002818584FAFBFF
FFFBFFF4EEFCFBFFFFF5FFFEFAFCF7FFFAF6FFCDD4693237FFFBF2FEFFEFFFFFECEEF5D4
D8E8BBD0E3ACD3E3A5D4E4A3D0E5A2D2E8AAD2E2B3E5F3D0FBFFEFFCFFF1F8FDE7595E40
666D43D1DAA3E8F2B5CFD99CC8D39BFCFFD6F2F9D7D1E0B7C7E1A4CBEAA4BDDC96D8F7B1
CFEFA6F1FFC8E0FFB7CAEAA1CFEFA4BEDE93CDEDA2C8E89DC6E69ACBEB9FBDDD91CFEEA2
D4EBA3CFE59DCCE09BD5E8A8D0E0A296A56C4B5823EDF9C7
DCFDACB3D483C1E090D6F2A5CBE59BCDE59BE0F6AEC2D68FD7E8A482934F8FA35E98AC67
C2D68FCAE098D6ECA4D8F3ACC1E29BC3E7A1CEE9A6BFD290D0DA9BEFF3B6E4E2A76A6428
6862269B995CE1E6A6DBE7A7C9E09CCDECA6BBE09AD3F6B2D0E8AAC7DD9FC4DCA0C6E4A6
CDF1B1C0EDACABDC9AC2F9B5B7F0ACB2EDABC2FFBC9CD89882BD7D467E3F255B1F5A8E50
5889489DC183D3E5ABA9AB79948C5D888052A1A07491936B252906010400767560858779
E8F4E8BCD8CA6896898AB69DD8EBBDA2AD71D8E7A4D7EBA3C9E092A1B866C7DF8BCEE793
CAE594CFEBA0C7E4A1E3FAC2FCFFDDFEF9DBE3CEBDC6B69DCFD7A6D5E9AAD5EEAACBE59C
C8E497D2ED9ED4EA9FCDDE98DAE6A6D4DCA1D8E0A7D7E0A7DBEBACDCF3ADBBD78CD5F4A4
D6EF9CC0D684D4E99CDBECA69FAE6D9BA769D4DEA1D9E2A3E1E7A7D4D997E7EAA7DBDD9C
7C7D4165642CE2E0AFE3E4BADCE3C2DFE9D0FBFFEDF8FFEDF4FAECDEE1D8C2C3BEEDEDEB
FFFFFDFFFEFFFFFEFFFFFEFFFFFFFDFFFFFBFFFFFBFFFFFBFFFEFFFFFDFFFDF8FCFCF7FB
FFFCFFE7E0E7FBF4FBF6EFF6F6F1F8FFFDFFFFFEFFF4F2F5A2A2A44A4B4DB6B8B7FFFEFF
FFF8FFFFFCFFF2F7FDF7FFFFFFFFFBFFEFEBFFD6DDD19A9DFFFCEFFCFFECF9FFE1E6F1C7
D3E6AFCEE3A2D3E49DD3E899D2EB9ACBE699CFE5A7E7F9C9ECFAD7F1FCDEFCFFE8C9D0AE
B6BF947F87549FA871D7E0A9EBF5C3FEFFDDE6EDCECCDAB6D6F5B9C0E89FB5DD94CAF2A9
D3FCB0E6FFC3D6FFB3BFE89CCBF4A6C9F2A4C4ED9FC1EA9CB9E293C9F2A3BEE798C7EC9F
CBE69FD3E8A5D0E5A4D2E4A6D6E5ACC3D29B5A6634DEEABA
C6E999C8E99AD0EFA1CBE79AC6E096D2EAA0D2E8A0D6EAA3ACBD799CAD69DCEDA9C5D994
E2F6B1D9EEA9CADF9ACBE29CCAE39FD6EFABD1E6A3E2F1B0E4EDAE747939565819808042
D9D99BCED393D7E1A2DCECADC6DC9CDBF8B6AFD290C1DF9FD1E6ABCBDFA4DBF0B7C6E2A7
BDE1A3C9F5B6BCEDAC98CF8C80BB7944813E38753288C5823E7937B1E9A8ABE1A3D6FEC2
DEEDB6D6D4A16E6431807945A2A16BB3BC83CDE5A9C2DEA34D5F2D575E35A79D84988B7B
CECCC0DAECE092BEAF608E74BED8AB87995FBBD493CAE8A0CBE79CC9E495CFE495CCE290
CAE191CFEA9DC9E79DE6FFBFF4FFCCF0F1C5C6B392DFD1AAD6DFA8CDE4A0C7E198C9E59A
D8F4A7D3EEA1A3B9706C7D3996A0637D824A4C511B5D662D6C7C3DA2B973C2DE91C1E090
C9E291D8ED9E596B214E5D18B9C384E0E9AAEBF1B3D1D696E6E8A7D5D796E9E9AB8E8E52
72703DBAB689EFEAC4FCF8DBFDFEEEF2F5ECFEFFFAFEFFFBFEFFFD9F9F9FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFBFEFFFBFFFFFBFFFEFFFFF8FFFFFCFFFBF4FB
FFFCFFD8D1D8FEF7FEFFFDFFFFFDFFF9F4F8F3F1F4FEFCFD0B090AD6D6D6FFFFFFFFFCFF
F3E8F6FFFBFFFCFFFFF2FBFAFFFFFBFFEFECEDB4BBF6BFC2FFFCEFFCFFEAF7FEDDE4EFC4
D2E6ABCDE49ED1E697D2E895C9E78DCCED96CBE79CD1E9ABDAEEBBF8FFDDFBFFE1DFE9C4
D4DCB3D8E1B4D3DAAE80875B9CA47DFCFFE1FEFFE8F8FFE2D9F5BAC4E8A0C8ECA4CDF1A9
CEF2A8C7EBA1CBEFA5C6EAA0B5DA8DC7EC9FBEE396C7EC9FC1E698CFF4A6CDF2A4C4E69A
CBE69FD0E7A3D2E7A6D2E4A6D3E2A9DBE9B45A6634E0E9BA
CAEC9FC5E898C9E99DD2F1A5D3EFA4C7DF95B6CC84E2F6AF94A561D8E9A5CFE09CDEEFAB
C1D590C9DD98CDE09ED1E5A0DAE9A8C7D391D9E3A4C4CF8D9099584E57146D7633B3BC79
CDD896E6F2B2D6E6A7BED2938AA06287A16494B075D8F0B685945D8F9C6693A46E89A068
7D9A605C824589B374497A398FC1826B9F5F83B576B7E8A7CAF6B9CAF3B7C0E8ACC2D9A3
EBDFB5BAA27C533E13736938DDE2AAD7EDADABD08BD2F7B25E773D8E9667DACDADE8D6C0
C3BCACDAE5D5DCFFEF6692775F7E528BA870CCF0B2D2F9B6C1E6A0C1E198C3D990D3E59B
D1E69BD2EA9EC7E79BD7F7AEDFF5B4E0EAAECEC290CEC491D9E5A7CCE69FCBE79DCFEBA0
CAE699BBD689AEC47CA9B877DFE7AEB2B7819DA16E9EA56F5B692B778E489BB76A8DAC5C
8EA658DBF0A58FA0598C9B56D3DE9CC9D291D4D999E6E8A7D3D693DEDE9E9C9C60777640
C1BE93E0DCB9FEF8E0FFFFEFFFFFF8F8F7F5EFEDEEDAD8D9BCBABDDDDCE1FBFAFFF8F7FC
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFDFCFFFBFEFFFBFFFFFBFFFAFEFFF9FDFFFCFFFFFDFF
FFF9FDDFD9DDECE6EAF6F0F2FDF9FAF9F5F6FFFEFFFFFFFD030000FFFEFFFFFEFFFFFAFE
FFF7FFFFFBFFFCFFFFF4FAF6FFFFFAFFF9F6C58C93EAB3B8FFFCF1FCFFEDFAFFE2EAF6CE
D9EEB6D3E9A8D1E69BCCE391C9EA91CBEE94C5E494C3DE97D0E8AAF7FFD4E0F0C1D3E0B5
D3DEB6D2DAB5DAE0BCB5BB99BCC3A2ABB293C1C7ABFBFFE1E6FBC0D0EBA6C5E09BC8E39E
C4DF98CBE69FCBE69FC5E099CDE99FDAF6ACCDE99FCDE99FCCE89DBEDA8FD3EFA4C7E398
D0ECA2C7E19ACEE5A1D6EBAAC7D99DD1E0A74A5722ECF6C2
D2F4A8C0E295CCECA1C6E49AC3DF95E4FBB3D4EAA28A9E57AEBF7BCEDF9BD3E3A2CBDB9A
D8E8A7EAFDBBD2E5A5DAE6A6C2C2849A9657929053525715767F3CCBD892DDEEA7D3E9A1
D6EDA7C8E19D9EB7769DB577899E657F925B8FA16D82905D858B5BA0A472929A69697543
6375411932007D9A60C3E5A9BFE1A5CCEEB2C6E3A9C2DBA1CDE0A9D8E9B3DAE7B28F8E62
6D533886664FEDD8B9E2DDB3D4E3ACCEEBABDBFFB9A1C27D000F00E1E8B2E6DFB5E4DAB7
EEEACFAEB69F7E97814B7051001000487240B4E7AEB9EFB1BEEFAEBEE5A494AA6AD0E0A1
D4E8A3CFE9A0C3E99CC6EFA0CDEDA1CFE39BE3E2A1939252D5E6A2CCE7A0CCE89ECBEA9E
CCE89DC7E197C6DA95C6D496FFFFD1CACC9AE0E2B1E7EEB8C6D496D5ECA6BEDA8DCBEA9A
BFDA8DD5EDA3C9DF97D3E7A0E0EFACD7E49FDEE8A3D8DF9BD9DF9983854458591F9B9A6A
F7F4D1F7F2DCFFFFF4FFFCF8FFFEFBFFFBF8C9C5C4868283E6E2E3F5F3F6FAFAFCFFFEFF
FEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFBFFFDFCFFFDFEFFFDFFFDFEFFFEFFFDF8FCFFFEFF
FFFCFDFBF7F8C9C5C6ACA8A7E8E4E3EEEAE9DBD7D67C78754F4949FDF9F8F7F1F1FFF7FA
FFFAFFFFF9FEF5F7F4FBFFFAFFFFF8FFF7F4E5ACB5F6BEC7FFF9F4FCFFF4FEFFEFF6FFE3
E8FAD0DCF3BDD4E6AAC9DE99CFF09FC0E691C5E896CBEB9FC7E29BD9F2B1CBDEA7FBFFDC
FBFFE2F0F9DAFEFFEAFEFFEAF8FEE2CAD1B2C6CDAB8F986DB0BB81D3DF9FDCE8A8D9E5A5
99A5639AA664939F5D9AA664929F5A8F9C57919E59909D58A8B56F93A05ACDDA94D6E7A0
D0EB9EC7E398CDE79ED4EBA5C7DA9AD3E3A549571CE7F2B8
C2E498D0F2A6D0F0A5B7D58BCAE69CD4EBA3C7DD956A7E37BCCD89CDDE9AD2E2A1D3E3A2
DCECADC0D0919FB2729CA86A7575375852145C5B1B595A18ADB470DBE6A1C6D68FD6E7A1
C7DC97C5DC9877904F849E61CBE2AAD5ECB6CDE4B0DCEEBCE2EBBC848C5B6D7947132400
000C00536C35DBF7BDC7E4AACCE8AEC6DFA5DEF1B9DAE7B1D4DBA7DBDBA7D4D0A0463A14
7D6352ECD4C8FFFEE8D5D9B6F9FFDABED39ACAE0A0D1E4A2353F00DDE0A7CBCB97E1E2B6
F0F6D0D1DCBA98A88D082506001900306839ADEDB9ABECB4BAF4BAB3E0A76C854ED4E5AE
D2E4A8CBE6A1C1EC9DC0F09CC3ED99C6E391E6EEA172782ECDE19ACBE9A1C6E49AC2E195
D2EEA3DDF7AEC0D391949F63D2D6A3F6F8C7D1D3A2C7CE9ADDEBAED6ECA4DAF6A9C4E594
CFEEA2DAF5AED3EDA6C1D691C7DB94D8E8A1D5E29AD4DE97939A54545B188F925BC2C399
FEFEE2FFFFF3FDFCFAFBF6FAFFFAF8FFFDFAA49C99DFDAD7FFFEFBFFFEFDFFFDFEFFFFFF
FEFFFFFCFFFFFCFFFFFBFFFFFBFFFFFBFFFFFBFFFFFCFFFFFEFCFDFFFEFFFBF7F8FFFEFD
F7F3F2FFFEFBDDD9D6CCC8C5D3CFCCF7F3F0E4DFDC6D68654F4A47D7CFCDEAE1E2FFFCFD
F7EBEDFFFDFBFAFDF6FBFFF8F9F9EFFFF5F2FFE6F2E5ADBAFFF7F8FCFFFBFEFFF8FBFFF3
F4FFE7E9FED7DEEEC1CEE3AAC6E7A0C4EB9CD0F5A5C9EC9CC1E094CFE9A2CEE2A7F5FFD6
FBFFE4FCFFECEDF2DEFEFFEFFCFFE8CDD4B3C3CBA4889260707A3E98A26396A0618D9758
515C1A828D4BAFBA78E1ECAAE1ECA8D4DF9BDDE8A4D2DD99D8E39EAEB974CAD590D3E59B
CAE596CDED9AD0ED9DCFE79BD1E79FDFF0AC586726D3DF9F
C9EDA3C4E69CBCDC93D2F0A8E6FFBA79904A9AAF6ABED28DBFD08CE0F1ADCAD998E4F2B4
C7D79966763889995B8C9A5CA0AB698D9752CFD491EEF1ACDBDC98E1E09DF7F6B5B1B070
ABAD6E777F4395A368DBF3B9C6E3ABC2E8AF7AA26D436A357A9562B3CA96A6C18C89A670
83A46BC6E9AFB9DFA2C1E5A8C7E6AAD9F5BAB7CA92E4EFB7979C66A19E69696130BEB490
DBD3C8FFFFFAF9FFF1F9FFEAF7FFDDABB183908A567D743B696025E4E4A8D7E2A6CADEA3
E0F7C3F6FFDCF4FEDCBFD2B2B7E6C279BC915CA87966B281B3F6C3C3F5C492AF8196A878
D3E6AFC6E4A4BCEB9DC0F6A0BBED94C5EC93D8E79299A455ADC57BC8E69ED6F4AAC4E298
BDD98FCCE69FD6E9A9D2DDA3A9AD7BEDEFC0FFFFD6E8EFBBD5E3A6B8CE86DFFBAEC0E190
CAECA0B8D791CEECA6D6F0A9C9E098E1F5ADD0E0957A883D576319B8C17ED7DEA8E5EAC2
FEFFECEBECE6FEFEFFFFFDFFFFFEF8C5BBB1F3E9E0FFF8F1FFFEF8FAF7F2FBFAF6F5F5F3
FEFFFFFCFFFFFCFFFFFBFFFFFBFFFFF9FFFFF9FFFFFCFFFFFDFBFCFFFEFDFFFEFDFFFEFB
F1F0ECFFFFFAFDFCF7FFFFFAFFFFFAFFFFFAFFFCF8EEE9E5675F5DFFFCFBE8DEDDD4C8C8
E6D8D5F4EDE5FEFFF4FBFFF4FAFAEEFFF8F5FFD9E7D39AABFFF8FFFCFFFFFEFFFFFBFFFD
F7FFF6F2FFECEAF9DADEF0C6C0E2A5C6EEA5D3F8ABC0E393C6E595D5F1A7D4EAACC8D8A9
C5D0B0FCFFEFFCFFF2FBFFF0FEFFECFCFFDFEBF4C5DAE7AFCEE1A1CEE3A0C8DD9ADBF0AD
D2E7A2E7FCB7D6EBA6C5DA95CDE39BC9DF97D4EAA2D9EFA7CEE49BC1D78EB3C980BED68A
C8E591D0F19ACFEC98CCE796D4EB9DC8DA90576720CBDB94
C9E79DC6E49AD6F2A8D1EDA3B7D1885B752ECBE29CD6EDA7D4E9A4CDE19CDEEDACD2DEA0
D9E5A75D672AC0CA8EE0ECACD0E69BDAF1A1CCDC93D9E09DE5E5A5DAD697D9D494605F1F
4E5011DFE9ADDBEEB7C2DFA9CAECB97FA772001500C1E8AFC9E6AE5B743A193500D1F1B2
BFE2A0CCF0B0C7EAAAC6E5A9CFE8AFC5D7A5E0ECBE676D4128260065603AAEA681FFFFE2
FFFFF8F9FFFDF8FFF6DEECD35960417B79538B7C5166532884724CD7D0A6E0EBB3CAE0A2
E8FFC4F8FFD6DEE3BBDFEDC9BFE8C0AFEABE4988593F7E4F4B83544E774BCEE7BFCCDDB3
D7E8BBC6E3ABB8E5A4C0F6ABB3E99BC5F6A7BFE194CDE8A196B071AECA8FC7E7A8CFF2B2
CAEDADC6E5A9CAE3AAD0E4AFD5E2B4525D32F4FDD2DAE7BBC0D4A3DBF6C1B7DAA0C9EFB4
C0E3ADCBE9B5C8E5AFCFE8AFCEE3A8C5D8989CAB684B5612D5DE9BDBE1A5E1E5B3CFD3B0
FFFFF1FFFFFDF8F6FFFAF7FFFAF2EFF3EAE1F9F0E7FFF9F1FFFEF8EDEAE5FFFFFBF9F9F7
FEFFFFFCFFFFFCFFFFFCFFFFFBFFFFFBFFFFFBFFFFFCFFFFFFFFFFF8F7F5FFFEFDFFFFFB
FFFFFBFFFFFBF2F1ECFFFFFAFFFFFAF5F2EDFFFDFAFFFEFB635E5BFFFDFBFBF2F3FFFCFB
FFFBF8B4ABA4F9FDEFF7FFF0FFFFF4FFF4F0D49CA7F1BBC8FFFCFAF9FFFAFAFFF7F5FFF1
F4FFEFF2FFECF1FFE2E8FFD3CEF0B3BAE29BC6EC9FC5E79ACDEE9FBFDD93D2EAACD1E3B1
DDEBC7EEF8DDFCFFEFFCFFEDF1FADBFCFFDDEAF7C2CBDB9DD7ECA9CBE29ECEE4A3D0E6A6
CADFA4C6DBA2D0E4AFD2E6B3D2E6B1D0E2AECADDA6D5E9AEBED293E3F8B5C5DA95D8F3A6
CBED96CBEF95C9E994CFEA9BCFE39B9EAD68495515D9E3A6
E3F3AAC8DA909EB26A89A1578FA95FCAE69CC9E49DCEE9A2CCE69FC9DE99D6E6A5CBD596
606427606024E1DCA2DEE3A0D3F499C0E78ACFEA9DD1DFA1DEE3ABA1A46B535A17B5C27C
D3EDA6BCDC9DBCE2AF6C95691B401716370CC4E0ADCDE2A74A5A1B8E9F59CFE39BCBE196
CEE69AD9F1A7C7DA98D3E0A8D5DBAFD7D7B577725C665F4FA0988BFFFFF3FFFFF3FBFBF1
F9FBF6FCFFFAFEFFF39DA18AFFFFEAFFFFE2F1E9C5A89A7F0B0000F4E7E1CFCDA78C9159
A9B175858D5276794AD5DEB1C4DCA8CFEDB7C9E7B3C9E5B42D44163041172E3813000700
000900495F3834592D336333154E1B2C68347DB985A2D6A55A7950374F2B9EBE97CFF5CC
B5E2B7BCEBBFC3EEC1C2E9BDC3E3BA8AA67E8EA885B6D0B3EBFFF3E6FFF8DCFFF9DFFFFC
E4FFF7EBFFF7E2F9E5C8DCC1C6D6B2A3AE8478804FAFB17FD5D5A3E0DDB0FFFFDDFFFEE4
FFFBEFFDF8F5FFFCFFFFFDFFEAE6E7BAB6B3F4F0EDFFFFFBFFFFFDFBFAF8F3F3F1FFFFFF
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDF2F1EFFFFFFDCFCECC3B3A38FFFFFDF7F5F6FFFCFC
FFFBFAF3EAE5F4F7F0CDD5CAFEFFF8FFF8F1C89699C79A95D6D5B9CBE0B7CFE5B7CCE7B4
C5E6AFC4E5ACC9E6B0CBE9ADC6EAA2C7EDA0BEE396C5EA9DCEF0A6C5E49EC7E4A4CEE5AD
D5E9B6D3E6B8CADBAFF9FFDDF9FFDACDDBA8E7F5C0F9FFCFE6FAB5D8EDA8CCE0A3D1E3B1
E3F1CDF3FFE4FAFFF2F8FFF3FBFFF8F8FEF0FCFFEFFCFFE6CCD4ABD1DBA7A6B177CADE97
C8EB97BDE58DCCED9ED6F0A9EAF9BEA3AB7895966CDEDAB5
8A9A5197A75EBACC82CDE39AD3EBA1C7E198C7E19AD3EDA6D5ECA6E6FAB5CFDB9BB8C182
646627888649D6D295DEE49EC3E285CAF292D9F4A7D1E4A4929D65B5C28AD7ECABC4E19E
C1EAA685B3756C9C6A7BA87DACCFA7B6CFA77986589FA873CAD296D8E19EDFEAA599A960
69793084914C929A5E909261716B494D422CCABCB3ECDDDAFFFBFBFFFEFBFDFCF8FEFFFA
FEFFF8C7CBBD9FA38CDADDC2FDFDE3FFFFE4F7F5CFA09A84070007070005928D6F999A61
C1C684D6DD9AE8EFB98F99647D8B50BDCC91C7D49CD5E2AC8692608490628A976B95A47B
D1E6BDC4DFB6CBEEC6C3EDC5B7EABF95CEA3518E6277AC822846242E462635543289B18E
366842437A50669B6F84B58888B1853C61364A69475F806592B7A696C1B88EC0BFB9E6E9
DEFFFFEDFFFFE0F7EFE2F7E6DCECD2ABB694404620E0E2BAE4E2BBEAE6C3F2EDD0FFFFED
FBF7EEFFFEFDFBF8FFFDFAFFC4C4C6CECECEFFFFFFEFEFEFF0F0F0FFFFFFFFFFFFF2F2F2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF2F2F2131313767676FFFFFFFAFAFAFFFEFD
FFF7F7FFFCFAFEFFFBCCD3CBA3A69DD7C8C1FFD7D3794F3FDEE4B8CAE6ABC5E29FC4E49B
C3E99EC6ECA1C9E8A4C7E6A0C5E79AC5EA9AC6E89BCBEDA3CCEBA5C7E6A3CDE9ACD2EBB1
C8DFA9CFE3B0CDE1AEF8FFDAF9FFDACEDEAFDBEBBAE1F2BCD2E4A6D3E5A7D9EAB6E5F4CD
F4FEE6FBFFF8FCFFFFFAFDFFFBFBFFFAFBFFFFFFFBFFFFF1E7EACBFBFFD7C4CB97C6D697
CAEA9EC0E597D9F8B2E1F6BBE5F1C1A8AC87777356FBF3DC
CBE59BD2ECA2DAF2A8C9DF97D9EDA6D1E29CE1F0ADD0DC9ADFEAA8BAC583D8E1A07E8746
47500FC8D190E0E9A6D3E09AD1E697CDE492C1D68B8BA05B657B3BC9E5A8CFF3B6B7E3A8
B1E4AB093E068DBD89CAF2C0AAC59869784DBEC098DAD7AEE3E2B4D6DAA8C2C995646D36
18210039420D53562936320F73675199897AFFFAF4FFFAF6FFFCF6FFFDF6F8F4E8FFFFF1
F4FBE9768067FCFFE4F0F8D3FFFFE3F1F5D083895B8A8B6C0601070503069B9F7AD8E2A3
E9F6AECFDF96DAEAAC859358242C00ACB479ECF6BAC9D89D798C5498B178C6E3ABC7E8B1
D0F3BDB9DEAAB9E0ABC9EFBCC6ECB9C3E8B5C6EBB889A978657B4D81986A9BBB8CBDE5B3
4E7E4A99CE985D90588DBC859AC18A6C8E5B1E3D115878517EA2864B756173A196618F85
86AC9F87A798DDFDE8F0FFEFF2FFEA9CAD894E5D34D2DDB5CDD3AFDCE1C1FFFFEDEDF1E3
F7FDF9F3FBFEF8FFFFEAF1FBC9CACEC8C8C8FFFFFFFFFFFFFFFFFFFBFBFBF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFF4F4F4000000828282FFFFFFFFFFFFFFFBFA
FFFBFBF9EFEEF1F3EEFBFFFA9A9D9494867DF9CAC2B48B77DADDAECBE6A3CAE69BC9E898
C9EC98C9EF9CCDEC9ECEEA9DCAE999CCEB9BD1F0A4CAE89EC8E3A0D2ECADD0E8AEBED29D
CADEADD4E5B9D4E4BDF8FFE2F7FFE2D5E0BED8E3C1D3DFB9CDDDAED8E8B9EAF6D0F7FFE6
FBFFF4FBFFFDFCFFFFFCFFFFFEFEFFFEFFFFFFFFFAFFFFEFF5F8D9FFFFDCC9D09DA6B479
D5EFAEC0DE9EC0D99FF6FFD6FBFFDEA7AC8C67654EF2EDDA
CDEFA3C5E59AC2DE94CCE39BDAE9A4C7D28EDCE1A1DFE1A2D8D89A8C8E4F63682867702F
D0DC9ACBDF9ACEE49CD0E49DD9E29F9AA45F818E46C8E096DFFFB9B7E4A3AEE3ABB6F0BE
518C5C467E4DD1FFCCC1E4AE556735BBC193FFFFDAFFFFDF86806059563571714DB1B590
DBDFBAF6FAD7FFFFE4FFFFEAFFEFE5FFFAF4FFF9F6FFF2ECFFFBF2FFFEEFB2AD97A4A78C
CDD8B8C7D5B1CADAADD1DEB0EDF8CD889464D7E1ACB0B891000100D5DAD4D6E2B4CBDC96
D0E596C4DB8DD2E9A5CFE1A3CDD79BDBE0A69CA76B85975BBED899D2F2B3BEE2A2C7F0AE
C2EAABC6EEAFCDF1B3BBDA9EAEC78D798E55879861ACBB82DAECB2CBE0A5C9E7ABC2E8AB
D7FFC4B2E3A2C0F1AFB8E5A2B3DA9989AB6E81A067A8C595CFEFCACAEED2C0E7D4C0E9D7
82A88F91B599587B5B53725084A07A61775120320CE9F9D5ECF9DBDCE8D0EDFAE9F7FFFB
F4FFFFF2FFFFE8FAFFF4FFFFEFF4F8E0E0E0FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF323232909090FAFAFAFFFFFFF9F5F6
FFF6F8FFFCFBFEFFFDFBFFFBFEFFF8EFE1D6A7786EA37B62D5D7A5CFE9A2D9F1A3D5F19C
C9EB94C2E48DC6E28ECBE493D8F0A2C7E295CFE79DCDE49ECAE0A0DCEFB7E9FBC9EEFFD2
E4F3CCE9F7D6E5EFD4F6FFE7F6FFE8E5EED9EAF2DDE1EBD3E5F0D2ECF7D9F4FEE6F9FFF1
FAFFF9FAFFFFFCFFFFFCFFFFFEFFFFFEFFFFFFFFF8FDFFEDF7FADDFFFFDDC6CC9E9BA570
97AB70D9EEB3C2D59DDFEFBEFCFFDDFDFFE0E5E8C9C8C8AC
B7E094D0F6ABCFEDA5D1E6A1CBD795E1E6A6E9E7AAE6E0A4B7AF715D591A9A9C5BB2BD79
E1F5AECFEBA1C0E296CDE7A0D2D19B524D16CDD792C2DE91AEDC91C7FFC19DE1B064AB83
3E805C7FB88FB3DEA9B7D399B6C189E3DFAFFFFEDCBCA88F6E614EA69F8CDAD5C1EEECD7
E7E6D1DDDCC8F3EBDEFFFCF6FFFAFAFFEEF0FFF8F8FFF9F4F8E8D9FFFFE6B1AE8BD8DDB4
C8D5AAE1F3C3D2E5ADD9EDB2C0D19A91A26BD8EAACA2B283010B02D6E2D6BCD09BD9F4A7
D1EE9AD1F19CC0E097D8F2B1EBF9BEC2CD95D2E1A8E2F8BACFECACC4E4A1C8EDA8B4DC95
B7DC96D0F4ACCDEBA3D3EAA48E9D58616A27E7ECAAE0E5A2CCD993DEF2AAC8E49ABEE096
C8F0A7BBE79CC4F0A3BDE698ACD184AACA81CCE9A7CAE6ACC6E1B4D0EECAB6D7BAC7EBCF
B9DFBABFE5BC83A87F8AAA83819D7746603B182D0C869A7EF4FFF1F4FFF6F2FFFDF0FFFF
D5EEF2E7FFFFE4FFFFEEFFFFF5FDFFE4E4E4F3F3F3FFFFFFF1F1F1F3F3F3FCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FBFBFB0C0C0CCDCDCDF4F4F4FFFFFFFFFEFF
FFFBFFEBE2E3FCFFFFF8FFFAE3E9DFFFFCF1C99A90724830CCCC98C3D991CADF90CEE690
CEEC94D1EF97D8EF9DDDF0A1C6D88ED0E49CE2F3AFCEDE9FD8E7AEFCFFD8FCFFDDF1FBD9
FCFFEAFCFFEFF7FEEEFAFFF4FCFFF8FAFFF8FEFFFBFAFFF8FCFFF6FBFFF5FAFFF6F9FEF8
F9FDFEFAFEFFFDFDFFFEFEFFFEFFFFFCFEFDFBFCF4FFFFF1FDFFE6FFFFE3DCE1B9C7CF9C
A9B779DBECA8E2F1B0DBE9ACE6F4B9F1FEC8F5FFCB8E9866
C9F1AAC3E8A2C3E09DD8EDAADEE8A9E5E7A88E8A4D584F14847C3EE9E5A6D5D796D7E49F
CFE69EBADA8FCAF3A5D3EEABF2ECBC5F5225CBD694DDFDB2B7EFA47EC58379C597357F5C
A3E4C6BDF1CDA1C595ACBF87D4D79EDED4A1A4906D645037CEC1B0FFFEF1FFFFF1F5F2E3
F8F6E9FFFFF4FFFDFAFFFAFAFFF9FFFFF8FDFFF1F3FFF0E9FFFDEA595532B9BB8CFAFFCE
FBFFD4BDD098D0E4A5ABC07F1C3000B5C98AD9EEAB849865000800000700DBF4BDBBDA8C
C6E891CCF099C4E89EC0DE9EC1D69EDAEAB9F2FFD0DFF4BCCDE6ACC4E1A1C5E2A0DBF9B3
CBE69FCEE89FD2E79C8A9A4FA0AA61D9DF95D0D48ADEE598D8E596D7EA99C6DF8ED4F1A1
C2E595D0F7A880A7568AAF5FA7C877C5E496C8E29BD1E9ABCBE1B0DBF1CAE7FFDFE3FEDF
C2E1B8CBECBFD2F1C7BDD9B189A380364E2E5D71589BAE9A94A99A83988F91A7A4617B7C
7C979E90AEB8AACAD79FB7C1CED6D9B1B1B1BFBFBFFFFFFFFFFFFFFFFFFFFBFBFBF4F4F4
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF9F9F9000000E3E3E3F7F7F7FFFFFFFFFEFF
FFFBFFFFFDFFFCFFFFF9FFFDFCFFFAFFFAF1EBBAB3BF927DCAC898AABD7B96A85E8CA152
8CA5548AA25482934C788540E3EFAFAAB67898A369A8B27EE2E9BDFFFFDFF2F7D7FFFFEC
FFFFF1FFFFF6FFFFFAFEFFFDFFFFFFFEFFFFFFFEFFFEFFFFFEFFFFFCFFFFFBFFFEFCFFFF
FCFFFFFCFFFFFEFFFFFBFCFFFBFCFEFAFCF9FCFDF5FFFFF3FFFFEDFCFFE5F3F6D9F3F8CF
B9C18588934ED2DD98E2EFAAD3E29FCCDB98D6E6A5CFDF9E
D6F6B3B8D794DBF4B3CADD9D8690515B60206A6A2CDFDE9EE2E1A1D8DA99CFD895E1F2AC
C3DD94D3F3A8C0E99DCDE8A59A966761582DD5E3A8B8DD9ABBF8B57DC78C37845A408767
B2EACD001900778E64A7B17FE7E6B0EFE5B29D8E63E0D1B0FFFFE5FDF8E5F3F2DEFFFFEF
FFFFF3ECECE2FCF8F5FFFCFFFFF8FFFFF9FFDECCCC7264594B452BE2E3B9BCC38DFCFFCD
FBFFCFD2E4A8CCDF9D203500DCF1B0D2E6A7C7DE9ABED29F000600C7D9CBC4DFAAD2F2A6
CBEF98CFF29EB7DB93CDECB0DAF6C6CBE4BAF2FFDCF7FFDDDDEDBED1DFACC9D49CD5DDA2
5962234F58155C631D99A35AC6D286E4F1A2E3F1A2CFDE8DD3E28FD5E793CFE593D3EC9B
C2DE913758098BAC5DC7E899CFEC9CC3DE91D9EEA9CEE2A5D4E4B5F9FFE1EAF7D9F7FFEA
ECFFDAC6DBB2C7DCB5CCDDBB4B5B409EAD96F4FFF0F7FFFAF5FFFFF4FFFFF1FFFFE0F8FC
5972771431370D2B33677E8461696BB4B4B4F7F7F7FFFFFFE8E8E8F7F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFBFBFB0F0F0FE2E2E2FDFDFDFFFFFFF9F7F8
FAF1F6FFFCFFF7FCFFF3FDFCFCFFFDFFFBF8FAC8C7835548E5E1BBCEDFA8C8D699CCDC9D
D6EAABE0F2B8E2ECB8DEE4B4D6D9AAD5D8ABA6A8805A5C37939475FCFCE2FFFFEDFFFFF3
FBFBF3FBFAF6FFFEFFFFFFFFFFFDFFFFFEFFFBF8FFFCFBFFFEFFFFFDFEFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFEFFFDFCFFFEFEFFFFFFFDFFFFFBFFFFF8FFFFF4F9FBEDFDFFEFFEFFE2
DEE1AAA1A663D8DF9BD9E49FC4D48DD9EAA3CFE39BD6ECA3
CCE4A696AC6E8B9D5F2D3D00414D0D909B59AFB875D9E29FD2DB98D9E6A1D2E39DD2E8A0
D1EBA2C4E29AC2E49ACAE3A29395649F9E72D6EAB5BFE8B0B6F3BA589E6A51986EB4F1CF
001300516E4F26320EB8B98FD4D0A1DFD7A65C5622E6E2B3DDDDB7D5D8B9D4DBBCEDF6D9
F6FEE7FCFFF3FFFFF8BAB9B5CAC1C4A89E9FECE1DDE9E2D2CFD0B0D2DAA9E0F0B1CEE29D
D0DEA1DAE8AB52611EB8C985C9DC9C6A7C3E475C1B6B7F4E000600000D03CCE6B6C6E49A
D0F1A0BEDF90D3F4AFCAE7B1EDFFE2ECFFE4BDCDB08A98779FA782D8DAB3AFAE82979564
9A9760E2E2A6D4D695E0E7A1D4E297CDE091D0E797D0E694D1E391DDEB9CA8B96B96AB60
93AB61C9E39ACDE99FCDE99FC2DC92E1F8B0C6D999ECFBC2E8F3C8F0F7D5FFFFEAFBFFE8
F3FADBE2ECCA9FA6874C52388B907CFEFFF4FEFFFAF5FAF6F6FBFEECF6F8F7FFFFEEFDFF
F1FFFFEEFFFFECFFFFD5E9E8ADB3B3ADADADBEBEBEFFFFFFFEFEFEFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFEDEDED000000FFFFFFFEFEFEFDFDFDFFFEFF
FFFBFFF8F3F9F9FFFFF3FFFFF9FDFEFFF8F9FFE3E8D4A39EE4DDC1DFECC1EAF3C6EAF6C8
E3F2C9E1EDC9E5E8CBE9E8CCFDF9DEE7E3C8EEEAD1E3E1CCCDCAB9888478767269F7F4EF
FFFEFDFFFCFDFFFDFFFFFEFFFFFDFFFFFDFFFCF9FFFFFEFFFFFEFFFEFFFFFFFEFFFDFEFF
FDFCFFFDFCFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFDFEFEFCFFFFFBFFFFFBFFFFFBFFFFEE
ECE9C0A2A16995985FD0D89CD6E4A7DBEDAFCADE9FD2E8A8
4F581F4B561CB7C286D5E3A5D8E8A7CDE19CCBE199D9F0A8CEE69CDBF5ABC4DE95D2ECA3
C9E39CCFE8A49AB3714B5F20ADBA82DCEDB9C2DFB1B1DCAF71A87E93D0A6A7E0B5528157
BCD8B2CAD8B51C1B009B9575DBD6B0DDDBAA515719D7E1A2CFDAA2D4E0AECCDCABDFF0C3
F0FFDADEEFCFF9FFEFD4DACCFFFFF8FFFFF8FDFBEEF3F5DFCFDAB2D1E2ACBED793D4EBA3
CDDB9DBDC78B828D4BC7D391D8E6AB65723A93A267425126000804000C08D3E8BDCEE7A5
CDE99FCCE89ECFE9AAC9DFB1A4B2999EA697F2F9E9FFFFEFFFFFEAFDF9DCF7F3D0EDE8C0
D5D3A3E5E5AFDBE1A5E4EEAFCCDD99C9E098E1FDB39EB86E90A2589BA860BBC883D1E09F
CADD9DD1E5A6D6ECACC9DF9FC9DF9ED5EBABCCDEA4FCFFD8FDFFDDFFFFE7FFFFEFFFF9EC
C9C2AF504936B0A997FFFEF1FFFDF6F6ECEAFFFCFFFCF6FAFFFDFFF7F6FCFEFFFFFBFFFF
ECF6F5F7FFFFEAF9F27F8A82A6AAA9CCCCCCEFEFEFFBFBFBFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FAFAFAFFFFFF
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFF3F3F3A2A2A2747474FFFFFFFFFFFFF8F8F8FAF8F9
FFFCFFFFFEFFF9FFFFF5FFFFF5F9FCFFF9FFD19DA9BB888DDFD6C5E6F0D5FCFFE8FEFFEC
FBFFF1FBFFF6FFFFFBFFFCF8FFFDF5FFFEF3FFFDF4FFFEF6FFFDFAFFFBF9EEE5E6D6D0D2
CFC9CBD0CACEFFFDFFF9F4F8FFFDFFFFFEFFFCF8F9FFFFFDFFFFFDFFFFFDFFFEFCFBFBF9
FFFFFDFFFFFDFFFFFFFFFFFFFDFDFDFAFAFAFFFFFFEAEAECFFFEFFFAF9FEF9F8FEFEFAF7
FFFFEAAEA888918E6DD2D6B1E0EAC5E0EFC8F7FFE1F1FFDD
A0A06A9DA067D1D99EC8D698CDE19CD0EAA1C8E69CB9DB8FC8EA9DBBDD90C6E69BCCEAA2
C8E19DBACF8E7F91557C9053CEE6AACAE8B2C1E8BCCDF9D51446239ACAA4B9E4B6214110
CBDCAFB3B8900E0700AAA085E0DCB9D6D9AA596825CADF94D6EAA3DDF2AFD6ECABBDD599
C6DFA8F0FFD9C6DAB7E2F0D6FBFFF1F6FDEBFEFFEDE8F3D3D2E3B6D8F2B5C1E399D5F3A9
D6E2A4B5BA80BDC385EDF6B7626B345A642FC6D39BB5C19B000204000304E8F8D3CADEA1
CDE49EBFD692D9EEB5B0BC94ACAA9DFFF7F4FFFDF7F0ECE0FFFFEDFFFFE8FFFFE0FFFFDC
D6DEAFDEE8B3C7D49CCADA9CCEE2A3D2E8A7CBE4A293AA6670813DAAB674CDD99BDFEAB0
D0DDA7CDDCA5CADBA4E3F6BEDDF2B9CEE3AACEDFABFCFFDCFFFFE3FFFFEAF7EBDFCAB9B1
77665C6C5B51FEEDE6FFF9F7FFF2F4FFF9FFFFF5FCFFFAFFFFFAFFFFF6FEFBF5F9FFFFFD
FFFFFBF7FAF1F1F7EB262C20CDCEC9E7E7E7FDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBF9F9F9F9F9F9F5F5F5FFFFFF656565FFFFFFFFFFFFFFFFFFF0F0F0FFFEFF
FBF5F9F9F7FCF9FFFFF7FFFFFBFFFFFFFAFFFFCBD896646DF7EDE4F5FEEDFEFFF3FEFFF6
F7FDF9F8FDFFFFFCFFFFFBFFFFFCFFFFFCFDFFFBFCFFFAFDFFFCFFFFFDFFFFFCFFF9F3F7
E1DBDFB3ADB1FFF9FDFFF9FBFFFEFDFFFBF8FFFFFAFFFFFAFFFEF9FDFCF7FFFEF9FFFFFA
FEFDF8F5F4F0F8F7F3FFFFFDFFFFFDFFFFFFF0F0F2FFFEFFFAF9FFFFFEFFFFFDFFFDFBFC
FFFEEEB3AD95A5A38AD8DBC0D7E0C5D6E3C9F7FFEDF5FFED
D1D098DFE0A7EAF2B6CFDE9DC8DF99C9E79DD4F9ACCFF8A9BBE495DEFFB9C8ECA2CFEEA8
58713094A66AB3C08ACBDEA6C3E7A9B4E1A899C69D5682615F8868BDE1BB6B87566E8149
D9E0AA615F2F080200110A00E0E1BFC8D2A097AC675C7524DAF3A2BCD584C9E495CCEAA0
CEEDA9D4F2B68AA474AFC49DE7F6D7E8F5D9F9FFE6DBEBC4C8DFABCFEDADB8DE91C6E69A
D4DFA3A9AC75DDE3A7DBE3A76B743F626C38F0FDC8BDC8A604090F6B7278DAE8C7D9EBB1
E3F6B4DAEDABD0DFA8525633FFF4EDFFE5E8FFFAF6FFFDF3F0EDDAF3FADBC2D2ABEBFFD3
C7E2ADC1DEA4D6F2B7C7DFA3E4F8BDA8B77E4D5A22D3DEA4D3E1A3D1DFA2DFEAB2D0DAA6
E9F2C3D5E1B1D0E0AFBBCF9AC9E0AABCD39DD2E4B4F9FFDAFFFFE4FFFFECD6C4BA907B76
BBA6A3FFEDECFFF8FAFFF7FAFFF2F9FFF1FAFFF8FFFFF5FFFFF8FFFFF7FCFFFBFDFFFCFA
948D85989488EAE8D9FDFEF0F3F2EEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF8F8F8
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF595959767676FFFFFFF6F6F6EEEEEEFFFFFFFFFDFE
FFFDFFFFFEFFF7FFFFF7FFFFF8FDFFFFFAFFFFEEFBE2B0B9FFFDF4F9FFF4FCFFF6FCFFFA
F7FFFFFBFFFFFFFCFFFFFAFFFFFCFFFFFCFFFDF6FDFAF3FBFEF7FFFFFDFFFFFCFFFFFBFF
FFFDFFFFFDFFFBF7F8B1ADACFFFAF6FFFCF6FBF7EEFFFFF6FFFFF4FFFFF4FDFAF1FAF7EE
FFFFF8FFFFF8FFFFFAF8F7F3FDFCFAFFFEFFF9F9F9FFFFFFFBFAFFF6F5FBFEFFFFFFFFFB
FFFFECB4B395B2B394D3D8BAD7E0C5E4F0D8F6FFEDF7FFF1
DFE2A9DFE5A9D1DB9CD3E4A0DAF4ABC8E89CBDE294B1D889BEE798B4DA8DCDF1A997B673
31490DB8CB93BECC97DAF1BBB4E0A3D9FFD42E5D33143C1A8DAF8CC7E2B96C7F48BDC88C
D7DB9E85854F7472495D5D37D2D9B0E2EEBC92A7641F3700AEC573C3DC88D9F6A2CAEA97
C9E99DCBEAA6BCD89D445C2ACADBB1E9F9D2F7FFE0E6F9CBC9E2A8CFF0ABC3ED9BC6E999
CBD99BD3D89E999F61D3DDA0939C67808A56D2DFAADDE8C6000107080F15EBF6D6D0DFA6
C1D28ED0E19DE8F5BF5D5D37C0A89CFFF7F3FFFAEFFEF6E3DBDEC1CBDBB4D1EDBCC6E9AF
CDF5B7C9F0AFBCDF9FC3E0A0C8DCA19AA56D929963D7DFA6D8E6A9CDDD9FDCE9B1D6E0AC
CBD4A5D9E5B7F7FFD8EFFFD0DFF8C1E5FEC7EFFFD0E5F2C6E9EAC8F6EBD5A69083876E69
D7C2C1FFF9FAF8E4E6FFF0F5FFF9FDFFF1F7FFF9FFFFF0F6F9EAEFFFFAFDA89D9BC0B5B1
B8AFA6CBC3B8FBF5E7FFFFF3FFFFFBFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6F4F4F4
FFFFFFFFFFFFFEFEFEFFFFFFFCFCFC363636C3C3C3FCFCFCFFFFFFFFFFFFFFFFFFF5F3F4
FFFDFFFFFEFFF8FFFFF5FFFFF0F9F6FFFAFAD2A0A9F5C7CAFFFEF0F8FFEFFAFFF0F7FFF2
F5FFFAF7FFFFFCFBFFF9F7FFFFFDFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFEFF
FFFEFFFAF5F9FFFEFFD2CECDF3EEEAFFFEF8FFFFF6FFFDF2FDF9EEFFFFF4FFFFF4FFFFF6
FCF9F0FFFDF6FFFFFAFFFFFAFFFFFBFCFBF7F3F4EFFEFFFAFFFFFBF7F8F3F5F7F2FFFFF3
F1F5D4BEC498CED5ACD6DEB9D4DDBEF1FBE0F8FFEEF9FFF1
D5E5A6DAEAA9C7DA98C9DE99C9E399C7E396CEED9FD7F6A8D4F4A89FBF7490AE686D8A4A
C8E1A7C2D9A3DDF1BEC0DEAC5484500016001C491E8FB489D4EFC4B1C594A5B378D4DE9F
E0E9A8949E5FE5EEB7D1DBA7DEE8B4D2DFA97F8A504A591696A85CD6ED9BD5F19DC7E492
C5E494C7E59BE2FCBB5F773D9EAE7DDDEDBEDBEBBCE9FDC8C3DD9CC8EA9ECCF6A2C7EA98
E9F9B8CDD79A545F1DA8B776E7F4BCD5E4ADC4D59ECFDFBA000A0C000A0C82906CDCECAE
D4E59ED3E39CECF7BDBFC094938268947F6AE6D8BDE4E4C0CDD8ADCFE8B1CBEEAEC2EBA5
BCE79FBCE69CD0F4ACCFEDA7D8EBAB929C605B5E27D7DCA2CEDE9FDBF0AFBFCE93DDEAB4
D6E0AEFCFFD6EBFDC9F0FFCFEFFFD0F1FFD1EDFFCCCEDFA9D5D8ADCBC0A28D7762D0B9AB
FFFBF4FFFCF8FFFCFAFFFCFAFFFCFAFFFCFAFFF7F6FFFAF9F9F1EF9A928FFFF7F4FFFEF8
FFFEF6F8F1E7FFFEF4FFFFF6FFFEFAFFFFFFFEFEFEFCFCFCFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFCFCFCF4F4F4FAFAFA7777770A0A0AFFFFFFEAEAEAF3F3F3FFFFFFFFFFFFFFFEFF
FFF9F9FFFEFCF1FCF6F5FFFBF4FEF5FFFAF4C99999F1C4BEFFFFE6F7FFE4F9FFE4F5FFE5
F5FFEFF5FFF6FBFFFDFCFFFFF7FCF8F9FEFAFEFFFDFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFF9F7FAFFFEFFF7F6F4E0DCD9CAC7C2CFCAC6F2EDE7FFFFF6FFFDF4FFFBF2FFFEF8
FFFEF8F8F5F0F7F4EFFFFEF9F2F1ECFFFFF8FDFFF4FFFFF3FDFFF0FEFFEF8B907A828967
CDDAA4D1DFA1F9FFCEE7F3C1CAD7ACE6F1CFF9FFEAFBFFEF
C5E39DD3F1A9D5F0A9D0EAA1C5DD91D6EEA2D0E799CADF94C7DD94566C24CCE2A1C5DDA1
DAF3BACAE5B0D2EEBD89AD7D001700568B5D517B4DC5E5B4CADEA9DAE9B0CBD69AE2EEAE
D3E4A0829651BCD18CE6FBB8B6C688E3ECB5696B3A565B25879351D4E69CC5DC8ED1EC9D
D2EF9FCAE69BC0D995CBDFA094A36CCEDBA6D0DEA9DEF0B6C0D995C0E192C7EF97BFE38C
C6DA93C6D592BACB848DA15AC1D596D5EAAFD5EAAFC9DBB30009095A6664091900C7DA98
DCEEA4D9E99EC7D695D8DFA9F2EFC4DFDCB35355263B4510C2D699CEE9A6CBEDA1BBE092
C0E796D6FBABBBDC8DCCE69CD2E39DCFDB9BC6CF90555F2092A860D0EAA1D9ECACC4D496
EDFAC4D6E5AEC1D49CDDF7B8C9E8A5D2F3AEC9E6A3CBDFA0D9E0ACB1A87F7E6748EFD9C4
FFFCEFF5F5EBF4F4EAF4F6EBF6F6ECFCFCF2FFFFF8DFDFD7ADADA5EAEAE2FFFFF8EDEAE3
FFFFFAFFFEFAFFFEFAFAF6F3FEFDFBFDFDFDFDFDFDFEFEFEFFFFFFFFFFFFFEFEFEFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF9F9F9FFFFFFFFFFFF
FAFAFAF9F9F9FFFFFFFFFFFF373737FFFFFFFBFBFBFFFFFFFFFFFFF9F9F9EDEDEDFFFFFD
FFFEFBFFFFFAF1FDF3F5FFF8F9FFF4FFFEEFFFEADFE8BFABDADBB3CCE3AFCCDEACCADEAD
D0E7BDE0F6D2F0FEE5F5FFEFF9FFF4F9FFF6FBFFF8FBFFFAFBFFFBF8FDF9F7FBFAFBFDFC
FCFDFFFFFFFFF5F3F6F8F6F7FFFEFFFFFEFDF0EAEAFFFEFBF5EDEAFFFEF8FFFEFAFFFBF7
FFFDFAFFFEFBFFFEFBFDFAF5FFFFF8F8F8ECFEFFEEF4F8E1FEFFE6F0F7D59CA47DD3DFAF
C9DC9CD8EDA8F8FFCEEBFCC8D8E4BCECF5D8FCFFF1FCFFF2
C4F0A3B5DF93C8EDA0D6F5A9CAE296D4E69A96A2586B752E66702BC1CC8AD9E9ABCEE3A8
C7E2AB82A36E5B814E547F52002C0950805AA8CE9BCAE8ACBED191DAE6A4D8E4A6CCDC9D
C8E19D7C9C51CFF19DC8E593DEF2AACED39979714A1D150072773FDCEBA8DAEBA5C7DD94
CFE79DDCF4AAC7DC97DAEDADA9B77CB9C48CE2EDB3CAD89AD1E79FCFEC9ACCF096C9ED95
D6EEA4DCF0A9C7DD928BA359647D3BC8E2A1D8F2B1BFD9AA00060001120A91A779CCE39B
CADF90D5E897D8E7A2D5E5A6C8DC9DCFE5A5C7DE9AC2D991BFD78B8AA35289A24ED7F19A
CFE791D8F09ACFE592C2D886D8EA9EE6F8AED7E8A2D1E59D7F9C4C8EAB5BACC27A90A15D
D6E4A7C5D597D5EAA9C9E49FBEE094C4E99BC2E296D3EAA2DCE4A8B6AE7D79633AAA9777
FFFFECF9FFF1F9FFF1F8FFF1F9FFF1F1FDE9F9FFF39AA595FAFFF3FBFFF6FCFFFAFEFFFB
FEFEFCFFFFFFE7E5E8FFFEFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFF
F0F0F0FFFFFFFFFFFFDFDFDF636363FFFFFFFFFFFFF2F2F2FFFFFFF6F6F6FFFFFFFFFFFD
FFFEFAFFFFF8F4FFF2F4FFF3F9FFEFF9F1DAEDC3ADB28E6EDADFA7CFE8A6D1E8A4CFE8A6
D3EFB2E2FDC6F4FFD9F8FFE3F8FFEAF7FFEEF6FFEFF8FFF3F9FFF6FBFFF8FBFFFBFCFFFD
FDFFFEF1F1F3FFFDFFFFFEFFF4EFF5FFFDFFFFFCFFCAC4C8C7BEBFF6EDEEFFFCFFFFFCFF
F4EEF0FCF6F8FFFEFDFFFDF8FFFFF6FFFFF1FFFFEA7A805E848D62B9C391D4DFA7C5D499
D5EBABCFE7A9D5E9B4E9FAD0F2FCE1F8FEF0FFFFFDF5F4F9
CAF2A9B2D88DD3F3A8CCE79A899E5195A35699A559CDD98FD8E49CD7E3A1D7E9AB96AD75
5D7B473F633557825545744A84B28DB6E4B6C6F2B5C4E8A2D6E7A0DAE5A0D4E8A3CFEAA5
CCEDA67D9F537C9746B5CC7AC8DE93DDE7AB786C460D0000969E65C9DD98D1E5A0D1E79F
E1F8B0BED38EDCECADD6E1A5A2A9738A8F59DCE1A9A2AC6FD0E19BD2EA9CC6E892CDF19A
CCE89DC1DB91D0EB9CB1CD808AA560718C49CAE5A2CCE4B4000700000500D1E4B6DFF5AD
C6DB8C9CB162798A4662773664813EC6E59FCEECA4D7F1A8CCE498CCE393B5CB788A9E49
B6C874CFE18DDBED9BDBEE9DD2E596CBE093D1E69BCEE69ACDEC9CC5E592D2EA9ED1E79E
697D389BAF6ACEE39ECDE79EC9E89AD1F2A3C8E799CDE59BD5E19FDBDCA0A29863877C4F
DCDEB9BECCA9DCF2CCBBD3AFE3F8D7F6FFE9F7FFE9D8DFCDF8FFF0F9FFF6EFF9F0FBFFFD
FDFFFEF3F1F4FFFDFFFFFEFFFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFEFEFFFFFDFFFFFEFF
FFFEFFFFFFFDFFFFFDFFFFFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFF2F2F2FFFFFFFFFFFF
F7F7F7FFFFFFE7E7E77E7E7E818181F9F9F9F8F8F8FFFFFFF6F6F6FFFFFFF5F5F5FFFFFB
FCF8EFFFFFF0D9E8D1C9DEBFCCDDB9E3E1BBA4805ED2B387D4DE9FCCEAA0CEEA9FCAE69C
C4E59EC8E7A4CDE5A9CFE3AEC9DFB1C7DEB4D0E6BFE3F7D4F2FFE5F6FFEBF6FFF1F9FFF6
F9FFF8FCFFFDFFFFFFFDFCFFFFFEFFF9F4FBFFFDFFFFFAFFEFE6E9BBB1B2B6ABB1F2E9EE
FFFDFFF3EDEFCDC9C6C6C6BCD4D7C28D94759BA67ECEDAAAD2E1AAC9DB9DCFE2A2DAEFAC
CFEAA5C6E0A1C2D9A3EEFED7FBFFEDF2F5ECFFFEFFFFFCFF
D6EBAACEDE9DBCC98498A45C4F5B0F8E9D4CD8EE9BC5E18CC7E494C5E399C3E0A067844E
153408A2C6A24E795B54805CD4F6C3C0E9A7B0EA9DCAFDAEC7D891D4DF9AD0EEA4BDE698
BAE395CEE89F5D5D1D9C9C5CDAF1ADC4DA9C837C4E2E260092A35DD0EF9FC7E698C9E59B
D6EFABC9DB9FE0EAB5DCE0AE939063979366E0DEAE7D804B6A7437CCE09BCDE99EC8EB9B
C9EEA1D0F5A8C5E695D0EFA1C9E39C2C4300BDD28FDBEBBC000500000200D8E3B9CEDE9D
D6EBA08FA35B5C7031000D000010006C844ACBE0A5C8DEA0C8DC9DD7ECA9CFE39ED7EBA4
8E9F58ACBD76E1F3A9CEE096CCDE94E2F4AAC5D78DD1E79CC6E597C5E695D2EEA1C4DF92
B0C87E82984F9BAF67CDE199D1E79ED4EAA1D5EBA2CFE39CCEDF99E3F2AF8F9B5952581A
BCB77FE2E5ACC7E5A7BCE2A5EAFFD5F3FFDBF9F3DBD3CAB9FFFFF3F1FBF0F7FFFBF4FFF9
FFFEFFF9EEF4FFFAFFF8EFF4FFFFFFFEFFFFFCFDFFFEFDFFFFFEFFFFFDFFFFFDFFFFFDFF
FFFEFDFFFEFBFFFFFAFFFEFBFBF7F6FFFEFFFFFDFFFEFBFFF6F4F7FFFEFFFFFEFFFFFEFF
F6F4F5FFFEFFBBB9BA676566CECCCDF4F2F3FFFEFFF9F7F8FFFDFEFFFEFFFBF9FAFFFFFA
FFFFEFFFFFE8C8DDB6C4E0AFD2EBB2DAE2A9AF9564D7C28BD2E5A3BEE29AD1F2ABCDEEA7
C3E79FCAEBA4C5E09BC8E19DC6E5A2C3E6A4CBEBACDCFBC0F0FFD9F2FFDDF5FFE3F4FFE5
F5FFECF9FFF3FCFFF8FDFFFCFFFFFFFFFEFFFFFDFFFFF8FFFFFCFDFFF5F5BFB3B794898F
A89FA4A39F9E9B9B8FBEC3ACD3DFB7D1E2ACD0E4A5CDE6A2CCE7A0CAE8A2C9E8A4C9E8A2
C8E79BCEEAA0D3E8ADE4F4C7FCFFE8FFFFF3FFFBF8FFFDFF
87904F9EA766B7BE7BCAD48FDEEAA0CADC90DBF3A5D3EFA2D3F3A8CDF1ABD0F2B5789B65
62875B2A502995C19EB0D6ADB1CA90D4F6ACB6F6A0B6F09CDEEDA8E0E7A3C0E295C9F6A5
CBF4A6CBE199A0935C9C8F5ACBE1A1CDE5A7726C3A3F3801CAE095C8EE99C2E595CAEAA1
D5EFAEC4D79FC7D19FDDDEB4A7A27A7A73497F784C7573428F945C778645A3BA74BBDB90
BEE499C3EC9EBCE191C4E596D2ECA570854270813D879365000100000100D9E1B8E5F3B5
C9DA93D3E9A1C2D79CDAEFB7889D656F844CDDF0B99FB27A3E521792A669C6D89AD3E6A6
C9DC9CC1D4928D9E5AC7D892D6E7A0C9DB91E5F7ADCCE297D2EEA1C7E899D3F2A4D2EEA1
D0EB9ECCE498B3C77F788C4494A55ED3E49DC0D18BDBEFA8DDF1AABBD189D6ECA49CA963
86813DD2D38FC9E59BCCF1ABC3DFA4DFECBEE3DCBFB5A895F6F4E5FCFFF6E0EDE3E8F3ED
FFFEFFFFFBFFF7E7F1FFFAFFFFFEFFFCFFFFFEFFFFFEFFFFFFFDFFFFFCFFFFFBFFFFFCFF
FEF9F6FDF8F4FFFCF6FFFEFAFFFDFCFFFDFFFFFDFFFCF9FFFFFEFFFFFEFFF6F4F5FDFBFC
FEFCFDFBF9FA807E7F010000ECEAEBFFFEFFFFFEFFFFFDFEFFFEFFFFFEFFFCFAFBFFFFFA
FFFDECFEFFE4CFE5B7CDEAB2CCE9A7D2DE9CA79259B5A267D6EBA6C5EDA4C9EAA5C2E39E
BFE59CCBEDA3D2ECA3D6F0A6D0F2A5C9F0A1C6EB9EC6EAA2C9E9A8CAE8ACC7E2AFC5DAAF
D5E6C2EEFCE2F9FFF1FBFFF6FBFEF7FDFFFCFFFFFFFFFFFDFFF8F3FFFCF8FFF9F8FCF3F4
FFFDFDFFFFFAEFF3E2FCFFE4D1E1B0CFE5A5CDE79DCAE999C9EA9BC8EA9EC6EAA4C6EAA2
C6E69ACCE89DD0E5AAE2F2C5FEFFEAFFFFF3FFFBF8FFFBFE
E2E9A3D5DF98C8D891E4F8B1CFE4A1E0F5B4C5D99CC3D79CC4DBA3C1DEA8B1D6A08DB580
0013008EB984B9E1AFCAEBB6D9EDAECFEDA5BAF1A0B4E896D3DE9AD8DD9BCBE79CC5EC9D
D0F2A6CBDC96BAA973A3935FD5E7A9DCF0B37C7241443A05CAE097CBF0A0D1F6A9C3E49F
CCEAACF5FFD4F8FFD5FBFFD7B0AC8659512A231C007A7646D6D6A04B5317112000E4FBB5
C4E59ED2F8ABD4F7A7C0DF91D2E9A3D2E5A35F702C8E9A6C000100000100D9E2B7D1E1A0
D3E89DDEF4ABC3D99BCCE4AACDE2A9D7ECB3BED39AC8DDA295A96E7F9356D5E9AAD6EBAA
E2F5B5B5C886DDEEAA93A45E99AA64CCDD96D0E19AD8ECA4C4DF92C5E496CAE69BC8E499
C1DB91CCE49AD2EAA0D3E9A0CADE96879B53DFF3ACCCE099CADE97E1F5AEC8DC95D1E19A
898F49636A24CDDE98D3E9A8CADFA4D3E3B2D7DEB5D7D6B8504E39FFFFF3FCFFF6FBFFFB
FEFFFFEEE9EFFFF9FFFFF6FFFEFCFDFCFFFFFEFFFFFEFFFFFFFDFFFFFCFFFFFAFFFFFAFE
FFFEFBFFFEFAFFFEF8FFFEF8FFFEFBFFFEFFFDFBFFFBF8FFF4F2F5FFFDFEFFFEFFFFFEFF
FFFEFFFBF9FA8D8B8C070506FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFEFCFDFFFEFFFFFFFB
FFFCF0FEFFEACADFB6CEEBB5C8E5A5D2DC9DA38D53806C31C6DA93C9EFA4C6E59FC6E59F
CBECA5C8E89FC9E098C1D98FC7E899C4EA97C6E999C6E69BC5E49EC6E3A3CAE3A9CDE4B0
DBEEC1F6FFE1F9FFE8FBFFEDF3FCE9FAFFF1FCFFF4FDFFF3F9F6E7FFFFF3FFFFF6FFFFF8
FFFFF8FFFFF4FAFFEAFBFFE3D0E2AECDE6A4CCE89DCAE999C9EA9BC8EA9EC6EAA2C8E9A2
C7E79ECBE6A1CCE3ADE0F0C9FCFFEDFFFFF8FFFCFDFFFBFF
DFE79CC5D187DEF4ACCDE8A5BDD99CCDE5B1D7E8BC35441D000E00D1E7C09DC191406B35
BBE8ADBCE9A8CDF2AFC8E5A2D8E8A7BBD28CBDEE9FCCF6AAE1E8A5DEDE9ED1E99FCBEDA0
C9E79DD4E19C85713CA5945EDBE9ACD5E5A7A09261473B07A3B772B7D98DCAEBA4C8E8A7
B6D59AD8F3BEF7FFDBFEFFDCE9E9C3A29D77A49D73D7D0A2E5E3B0E7EBB0BEC788CADD9B
D0EEA8B1D58BC9E99DD5F1A6CBE29EB1C484000C003743150002000409035F6A3FC5D692
C1D88AD1E99DCFE8A7D1E9ADCDE2A7CEE4A6DBF1B3D1E7A9BDD194E0F4B5D2E6A75E7332
2D4000CADD9BDAEBA7CBDC98BACB8799AA64D0E19BC5D991CCE49AD5EFA5C5DF95CCE69C
DDF7ADD2ECA2BFD98FD7F1A7D6EEA480984E7F954D9CB069D0E49DDEEFA9CFE09AD0DF9A
BAC7819FAA655A6320CFD99AD6E5AACEE1AAD4E6B6D4E0B8E5E5C9CDCAB7F9FAECEBEEE5
EFF5F1FEFFFFFFFAFFFFFAFFFCFAFBFCFFFFFEFFFFFEFFFFFFFCFFFFFDFFFFFBFFFFFDFF
FDF7F7FDF8F2FBF7EEFEFAF1FFFFFAFFFBFAFDFBFEFFFEFFFFFEFFFFFDFEF3F1F2FCFAFB
FFFEFFFAF8F9979596020001FFFEFFFFFEFFFAF8F9FFFEFFFFFEFFFBF9FAFFFEFFFFFFFD
FFFEF8FFFFF1C1D5B2CAE6B6C8E1A7D9E2A3A68D545D470BD2E39CD8FAAEC8E69EC4E29C
CBEAA4C9E7A1D5EAA5D2E89FCDEA9ACCEE9AD0EF9FD0EFA1D1EDA3CFEAA5CEE8A7CFE7AD
C1D8A2CEE1B3D0E1B7CBDBB6DBE9C6F6FFE5F9FFEAF6FFE5FFFFEAFFFFE9F0F1DFD9DCCB
CACEBDD2DAC3E8F3D5F4FFD8CFE4ACCDE6A4CCE89DCAE999C9EA9BC8EA9DC8EAA0C8E9A2
C9E8A4CCE6A7CDE3B2E1F1CDFCFFF1FFFFFBFFFDFFFFFDFF
DAE597D2E297CBE69FBDDD9ED8F6C4CCE6BF0007005059448E9A8494A88C000F007AA56F
C7F6B2D3FFB2B7DA88D0E998D5E29DDAEDABC7F1A5BADE94DCE19FDBDA9ABACE86DDF9AE
D0EAA1DCE5A25A4611AD9964CDD79BCCD69AB0A06F5C4E1DCCD89AE1FCB9C3E1A1CDECB0
C3E1ABE2FECDF5FFDDD9E8BDE4E8C3DFDDB759542C9F986ADCD9A6DBDAA2C0C489E2EEAE
D5F0ADBBDA94CFEBA1C5DF96CBE09DD8EBAB2D3D00000900030801000200CCD9AB4B5F18
728B3AD6F1A2CCE7A2CEE8A7D2EBAACBE1A1D0E6A6D1E7A7D0E6A6CEE4A3CADF9ED4E9A8
6D803ED6E9A7D4E7A5DEF1AFBFCF8E899A564C5D19D5E6A2CFE39CD3E9A1CDE39BC3DA92
C9E39AD0ECA2CBE99FC2E096C3DF95CFE9A0576E268CA25ACEE29BC2D38DE3F0ABD3E29D
CEE49CD3E49E636124666127D8E0A4D2E6A9D0EDB3BFD7A5F9FDD8BDB79DFFFFEDFFFFF4
FBFFFBF5FBFBFCF2FDFFF6FFFCFCFCFCFFFDFEFFFFFCFDFFFDFAFFFFFDFFFFFBFFFFFDFF
FFFCFCFFFEF8FFFFF6FFFFF6FFFFF8FFFDFAFAF8F9FFFEFFFAF8F9FFFEFFFFFEFFFFFEFF
FEFCFDFFFEFFF5F3F4918F90F1EFF0FEFCFDF6F4F5FFFEFFFFFEFFFBF9FAFFFEFFFFFEFF
FFFDFDFFFFF8D0E2C8D6EFC7C8DFA9DEE4A8B2955D705619CCD991C8E799C8E299CBE59E
CFEAA5CEE7A3D6E7A3D4E59ECEE698CBE695CBE695CBE697CDE89BCDE79ECCE69FCAE3A1
D2EAACD3EBAFCEE3ABC9DDA8DCF0BDF7FFDAF5FFDCF3FFD9FAFFDEF1FBD6E9F2D3D8E3C5
CBD6B8D9E7C6F1FFDAF6FFD9CDE5A9CCE7A2CAE99DCAE999C9EA9BC9E99DC9E9A0C9E8A2
C9E6A6CCE5ACCDE3B5E1F0D1FBFFF4FEFFFDFEFCFFFFFDFF
CBE697DFF9AFB4CD8C6E8750000D000B1F03415742000A00000800001000D0ECC4C5E3AD
C0E19CBDE08EC9EE91D0EE94D9E6A0CFDF9EC9EDA5CAEAA1D4D999FAFABAD1E29CC5DF95
D1E8A0DBE4A1786930CEBF88D2DA9ED8E2A69F91606A5A29D4D9A1CFE1A79CB178CEE7B0
CEE9B6D4EEBFECFFD7F2FFD9D4DCB5DBDDB6CECCA3A7A477CDCB9AD8D9A0F5F9BEC7D395
C2D898D5F2AFC7E19A4F661E061B0037490B445413374315000200192018D0E0B1DBF1A8
A2BB6A627F2D35530B284502869F5D8EA561D1E8A4C4DB97C6DD99E3FAB6C3D897DAEFAC
A7BA780A1D002B3E0096A967D6E6A5E3F3B2CBDB9C97A76683924F859650C9DD96E1F7AF
D0EAA1BEDC92D6F6ABBFDF94D2F2A7D8F6ACBED88FBAD1898DA15AB1C07BE0EBA7D2E39D
CBE69FC5D994BAB4789B8F55727337DCEFAFB7DA96D9F8BCCDD9ABDCD9B8B5AD96E4DED0
FCFFFAF5FBF9FFFDFFF5F0F7FCFEFBFCFFFDFEFFFFFAFBFFFEFBFFFFFDFFFFFCFFFEF8FC
FFFAFAFFFEF8FFFFF6FEFAEFFFFFF6FFFFFAF9F8F6FEFCFDFFFEFFFDFBFCFBF9FAFFFEFF
FFFEFFE8E6E79A9899010000CECCCDFFFEFFFCFAFBFFFEFFFFFEFFFBF9FAFFFEFFFFFDFF
FFF8FFFFFFFFF2FFF1ECFFE2CBDFAEDCDFA8B89963A7894DEBF5ACC6E194D3E9A0D4EAA2
CFE6A0D4EBA7CFDE9BCEDD98D4E99CD1E898CEE597CEE597D0E69BD1E99FD3EBA1D2ECA3
CCE69FD1EAA6CEE7A5C4DE9DC3DD9ECAE4A5CBE5A8C6DFA5D4E8B3D2E6B5D7E8BBD7E9BF
DBEDC3EDFFD3F5FFDAEEFFCDCCE6A7CCE7A0CAE99DCAE99BC9EA9BC9E99DC9E99EC9E8A2
C6E3A3CCE5AECFE4B9E0EFD2F9FFF2FCFFFBFAFAFCFEFDFF
A8DD8FC8F1AB0314001D2200424528929E8641634B1541265582651D4020CEDCB8E2E8B8
E1EAABD0E694CCF896B7E583B1C57D6B7B3A61823B7B9951595F1FB4B675C7DB94D3EDA4
C9E098D9E4A0978D52DCD199DEE8ABE0EAAD9C925D615322D7D3A35A5E2C0009006C7C4D
C7DDAFD7EEC2BFD6AADEF0C8FBFFDFF8FFD7D9DEB5E0E3B4363A07E2E7AFD0D89DD9E7A9
D9EFAFCAE3A1CDE49ED0E5A0C0D294ACBE80B2C281B4C291000500000300D1E1B0D4ECA0
DCF8A4B6D37FD2F0A6CDEBA5D1EBA4D7F1AA526C25819B54ECFFBDC1D892C2D995D5ECA8
DBF0ADA8BD7A8598583D5010A3B676C3D696D0E2A4CCDC9DBFCB89939F5D91A25E8CA15C
C6E099B9D78FD0F2A6CDEFA3BFE195BDDD92CCE89EDAF1A98A9E568A9A53E2EDA8CCDD97
D6F4AECEE5A1EDE7ABEFE0A7797838828F4AD5F7ADC6EAA4E4F7BFC9CFA3D2CBAECFC7B4
FFFFF4FEFFFDE7E8ECFCFFFFFAFFF9FCFFFBFEFFFFFBFCFFFFFDFFFFFDFFFEF7FFEFE9ED
DAD4D4E4DFD9CFCBC0C9C5BAF1EEE5FFFFF8FFFFFBFFFFFDFFFEFFFFFEFFFFFDFEFEFCFD
FFFEFFFFFEFFFAF8F97F7D7EA5A3A4FFFEFFFFFEFFFBF9FAFFFEFFFCFAFBFFFEFFFFFEFF
FFFAFFFFFEFFF7FFFAF4FFECCEDFB3DFDDAAB38F5DCDAA72D2D8907B93478CA0588A9E57
80955096AA658894528A9551D0E097D5E79BD8EDA2D8EDA2D3E79FCDE39ACAE298C9E399
C4DE95C9E59BD0ECA2CFEDA5CBE9A1C9E9A0CDEDA4D2F1ABC9E6A4CAE6A9CAE3A9CFE8AF
E3FCC5F4FFD6EFFFCEE0FABDCAE7A4CAE8A0CAE99DCAE99BCAE99BCAE99BCAE99DCAE8A0
CAE4A5D0E9B2D5EBBDE5F4D3F7FFEFFAFFF5F9FBF6FEFFFD
59894B547B423C52249FA9848A937693A3883253366D947584AC8989A87FD8E8BBD6DFAA
D8E1A0C5D887D2F798A5CA6D6E823B6275358CAB67D1EFA9929D5B99A2617E944CC7E198
C8DF97DAE9A4848245BCBA7DD3DF9FCDDB9DA9A66F5A4E1C83784B7B744838360D353A11
657247CDDFB5CFE4BBE8FAD0F2FFD8EEFBD0D1DAADCFD9A7ABB5808E9C6183935596AB6A
ADC385CBE1A1D0E5A0D5EAA5D6E8AAD2E4A6D5E5A4CEDCAB000700000400CEE0ACD3EB9F
BFDB86D4F29CC9E89CC9E79FD3EFA5B9D3898FA96091AB62ACC37BC6DD97DBF2ACCBE29C
C4D996DAEFACC5D8984C5F1F2C3E00D4E6A8D1E3A5D5E5A7D3DF9FDAE6A494A362465A15
D3EDA6D2F2A9C3E59BC6EB9ECEF3A6CEF0A4C1DF95CBE59CDBEFA797A760A7B26DDCEBA6
C6E19CD6ECABCACA8EE7DFA19E9A5AA9B36EBFD98FCAECA2C9E3A2D5E3AEFFFFDDB5AB92
FFF9ECFDFDF5F9FFFDF3FFF9F9FFF6FCFFF8FEFFFDFCFDFFFFFDFFFFFDFFF7F0F8E2DCE0
F3EEEBF0EBE5C3BFB4AEAA9FDDDAD1FFFFF8FFFEF9FEFDF9FFFDFEFCFAFBFDFBFCFFFDFE
FFFEFFFFFEFFFFFEFF848283878586FFFEFFFFFEFFF2F0F1FFFEFFFCFAFBFFFEFFFFFDFF
FFFBFFF6F4FFF7FFFDEFFFEBD3E2BBE5E1B2AB8256D3AE7A888B482F450075864095A662
8FA35E94A8635662203A4501909D58A5B46FC0D18BD2E39DD2E69FCFE59DD0E69ECFE9A0
D2ECA3CBE79CC8E79BCCEB9FCBEB9FC6E69AC5E79ACAEC9FC8EAA0C9EAA3C2E39EC8E8A5
E5FFC3F1FFCFDFFEBBCBE8A6CAE7A4CAE8A2CAE8A0CAE89ECAE99DCAE99BCAE99BCAE89E
CDE7A6D5EEB5DCF2C1E9FBD5F8FFEAF9FFEFFAFFF1FCFFF4
566440B3C9A29FC69A8EBC8E23512391B48ACADBB74E5631959C73D3E1B0CDECB0C2EAA4
CAF0A3D4F3A34E5C0D9FA75EC7D391ECFFC0BCDD98CAE9A3DCEDA9D0DF9CA7C178A4C278
C3DF95DAEEA7686E2E9FA565CEDE9DD3E6A4D8DEA25C552168552B635028827650E6E2BC
ADB28A2B380DCEDFB5ECFDD39BAC80566639E0F0BFE2F3BFD2E5ADCFE7A9CAE4A3C8E5A2
ACC486657B3B6A7F3AC3D991D6E9A9DDF0B0C6D997DAEAB90004004E5A4ECADCA8D6EEA0
CCE891C0DE88DCF8ADC6E19AC7E197CFEA9DD0EAA0CEE89EAAC47A8AA45BDCF3ADCBE29C
CDE4A0D1E8A4C1D695D2E7A69BAF7023370074864ACDDD9FD5E1A3D7E3A3D5E3A5AFC280
B5CE8AC4E29AD7F7AEBADC92C5E79BC2E297CBE99FD6F0A7C7DD94D9EAA38D9A54B9C883
D7EDACD2E7A6CFD899E2E2A2DFDB9B595C1785954CDDF9AEBEDF98CFE9ACE8EEC0CEC5A6
FFF9E6FFFFF1E1F2E2F1FFF8F8FFF3FCFFF4FEFFFAFDFFFCFBF9FEFFFDFFFFFAFFEBE5E9
FFFEFBFFFEF8FBF7EEFFFFF4FFFDF4A19E97BAB9B4FDFCF8FCFAFBFDFBFCFFFEFFFCFAFB
F7F5F6FFFEFFF4F2F3F6F4F57C7A7BFEFCFDFEFCFDFEFCFDFFFEFFFEFCFDFFFEFFFFFDFF
FFF8FFFFFCFFF8FFFFF7FFF3D1DCBADFD8AEA1754E683F11E0E0A2D2E6A1D3E29FD3E29F
CFE39ECFE39ED4E19CD5E09CD3DF9FCEDD9CB1C1808E9E5D8093518BA05DAABF7AC9E39C
CCE69FBBD78DDBFAAEC3E296C0E094CDEDA1C8EB9BC9EC9CCBF0A2C5EA9CC2E79AC6EB9E
D2F4AAD7F9AFD4F5AECFEEA8C6E5A1C8E7A3CBE9A3CBE9A1CBE79DCAE699CBE898CCE89B
CEE9A4E4FEBFF5FFD4F7FFDCF8FFE3F9FFE6F9FFE8F2FCE1
D6DEC6C6D9BB4F7850548858C3F5C2C6ECB9889869DFE1B0E0E0ACDAE5A9BBDC97C2ECA0
C2EB9D7C984ED5DC98D8D898E3EFB1C6DC9CCBEAA7D2F1ADC1D693DAEFAAD0ECA24C6A20
CFEDA3D0E79F909C5A9BA765CFE4A1C8DD9AD2DC9FDFDCA56954296E542FA99771E9E0B7
D3D4AA636A40051200000A00000D00415122E9FBC7E4F9C1DAF4B7B9D797CCEFABCBECA7
C1DB9ADFF5B4D3E9A11C3200E4F9B6BBCE8ED6EAA5CEDEAD000500000900D2E6B1D8F0A2
C5DF88D5F19CBED88ED4EEA7D0EAA0D0EB9ECDE89BCDE89BD8F2A8BBD58B758C44D8EFA9
D5ECA8C5DC98E8FDBCC0D594D8ECAD849859000C00D3E3A5CEDC9FE2EEB0C9D99AD2E5A5
3A500FD3EEA9C6E49ED7F7AECFEFA6D8F6ACC1DD93CDE79ECDE39ACEE29AC6D790B3C47E
C8DB99CDE0A0DCECABC6D18DDDDE9C686724929953C6DA92D4F6ACD2F1AEDCE6B29B9670
FFFDE3FAF2DDF4FFEFEAFFEBF8FFEDFBFFEEFEFFF4FEFFFAFFFEFFFFFEFFFFFCFFFEF8FC
E3DEDBFFFEF8FAF6EDFFFEF3FFFFF6F7F4EDECEBE7DFDEDCFFFEFFFDFBFCFFFEFFFCFAFB
F9F7F8FFFEFFFFFDFEFFFEFF7E7C7DFFFEFFFFFEFFFFFEFFFFFEFFFFFDFEFFFEFFFFFAFF
FFFAFFFFFCFFDCE5E4F7FFF3FCFFE8B5AB88DBAD8C744821DCD9A4D3E3A5D6E4A6D6E4A6
D0E5A2CEE49CD2E29BD5E29DDFEDAFC9D99BD4E6A8EEFFC1BACD8D5469284A601F93AC68
DBF4B0D5F0A9C8E49AD2F0A6CCEAA0C4E498D6F6AAC3E598C8ED9DC3EA99C0E794C3EA97
CAEF9FCDF2A4CCEEA2C8E9A2C6E5A1C7E6A3C9E6A4CAE7A4CCE7A0CCE89DCCE999CDEA9A
C9E59BE0FBB6EEFFC8E0F7BFCFE3B2CCDDB1D4E5BBDAEBC1
68856789A6876F8A67C0DBB087A26F8FAB71829C5BC9E29EC6DD95CFE59CDDF1A9D5E6A0
8A995695A161E3EFB1D0DEA1CEE0A4CEE4A4CDEAA8BBD895D7EEAACCE39DCCE89E97B56B
88A75BCDE79DC6DA9397AB64D4E9A4DBF0ABE3F2B1E1E2A8AB996B654E2468572CD7CFA1
DAD9ABB7BD8D878F60969F70ACB888CAD8A5D0E1ABE1F6BDE3FFC2CEF1AFC1E9A3C4E9A3
D4EFACC9E09CCBE399ABC379819852B1C683D2E7A2CFE1AD081408000500BBCD99D6ECA1
C9E18DD3EC98D4EBA3C8E29BC9E399CDE99CC9E598CDE99CCEE89ED9F3A9B4CE85CCE69D
C8DF99D5ECA6C8DF9BD6EDA9C5DA99D0E5A4D4E9A8E1F3B5D4E4A6D6E6A8DCECAEC8DB9B
BFD4937B924ECAE39FC5DF98C1DC95CFEAA3C5DF96D4EEA5DDF5ABC6DE94CFE59A98AC64
909F5CDDECABD6EDA7D9EDA6E5EAA77A79385A5B19DCE7A2C2E299C2E39EC1D097E8EABB
998C69E1DCBCF3FFE3D4F2CCE8F7D6E9F2D7F1F5E4FCFFF4FFFFFDFCFAFDFFF9FDFFFDFF
D0CACAFFFEFAFFFEF8FBF7EEFFFDF6FFFFF8FFFFFBEAE9E7DDDBDCEBE9EAF9F7F8FFFEFF
FFFEFFFDFBFCFFFDFEE7E5E67D7B7CFFFEFFFFFEFFFFFEFFFFFEFFFFFDFEFFFEFFFFFAFF
FFF6FFFFFBFFFBFFFFF7FFF5A0A58EB6A88DFFD1BAD7A88ADBD7AAD3E2ABD7E4ACD6E5AA
D0E7A3CEE59DD2E498D3E59BD1E4A4D0E4A7C7DB9EC5D99AD3E7A8D2E8A7C1D796B4CD89
9CB571D4EDA9B2CC85DDF8B1C5E099D1EDA3C4E096D0F0A5C7EC9EC4EB98C3EB95C3EB95
C5EB96C6EC99C6E89BC4E59EC9E7A7C8E6A8C9E5A8C9E6A6CDE8A3CEEA9FCDEA9ACCE997
D1EC9FE7FFB8F3FFC8E6FEC0D1E9AFCBE0A8CFE4ACD3E8B0
CBF1CCB2D2ABA7BD96415124D3E1ACD8ECADBCDC91D6F9A9CCED9CDCF5A4CEDA92A2A562
5E5E22D4DA9EC5D398DAEEB3D2E4A8C7DB9ED8EEAECFE8A6D7EDACC4DB95D8F2ABCFEBA1
D2EEA3BDD78DDFF6AEA0B66EBFD48FCDE19CD1E09FD0D698E3D7A39E8E5D544A197C7946
91915FD2D6A3E6EDBADFE6B3D5DCA9D9E1AEE2ECB7E5F7BDF5FFCFC6E6A3BFE7A0C3E8A2
C3E19BCDE7A0D5EDA1D1E99DDEF5AD8BA25C6D843CC2D4A0000500000500DEF0BCD2E89D
C2DA86DBF2A0CADF9AD5ECA8DAF4ABC2DE91CDE99CC9E598CAE49AD5EFA5C7E1983B550C
526923CAE19BCEE5A1CFE6A2DAEFACD5EAA7CCE1A0C6DB9A687A3C596B2D5E7032CCDEA0
D5E7A9DDF0B0425515DBF0ADCDE29DCEE59FD1E8A0C4DE95CCE69CC9E59ACAE699CEE69C
929E5CD1DD9BC7E19ACEE59FC9D4908E904F696828D9E09DCAE19BE0FBB6CBDD9FDAE3AC
E6E5B5909364C8E0AECEEABAD6E6BFECF5D6FCFFEAFEFFF3FFFFFAFFFDFEFFFCFEFFFDFF
D1CBCBF7F2EFFFFEF8FFFEF8EFECE5FFFDF8FFFFFDFFFEFFA6A4A5FFFEFFFFFEFFFFFEFF
FAF8F9ECEAEBFFFEFF807E7F7C7A7BFFFDFEFEFCFDFFFDFEFFFEFFFFFDFEFFFEFFFFFDFF
FFFAFFF9F2FAF4F8F7F9FFF6A2A590F2E1CDBD897BFCCCB8E4DCB8D5E2B4D3E1AED1E3A9
CDE6A4CCE89DD0E797D0E799D0E7A3DBF4B3D3ECABC7E09FD0E9A7DBF4B2D2EBA9C6DF9B
A6BF7B566F2BE1F8B4C3DA96CEE59FD3EAA4C6E099CCE89EC9EB9EC7EE9DC8EE99C7ED96
C6EC95C5EB96C7E99CC8E9A2CCEAACCAE7ADC9E5ABC9E5AACDE8A5CEEAA0CDEA98CBE894
C3DE8DCCE79AD1EBA2CFE8A4CBE4A3CAE2A4C8E1A0C3DD9C
C6EBB8BFDFAD7E9561CEDFA8D1E1A3D1E6A1D3EFA4CFEE9EC6E391C1D6879AA45DABAE6B
D1D193E5E9AEDBE6ACCCDBA0D3E2A9D2E1A6D7E7A9C7DA9ACBE09FD3E8A3D5EAA5C9DF97
BAD087637930D1E79FB8CC85ADBE7AD4E3A0DCE8A6DEE7A6DEDEA2EAE8ADC5C68C6C7035
565E236E763B6E733BB0B37CDFDFABD3D39FD7DAA3CFD89FC5D799D7F0AFC4E5A0CAEBA4
C4E29AE2FEB3CAE596CEE99ACBE59CC7E19A839D549DB17C000A00010D018A9C6A94A860
C6DC8AD6E99ADDEDACC4D797C6E097C4E095E3FFB4C1DD92BFDB91C7E399D8F2A9D8F2A9
CEE8A1567029728943ADC47ED3EAA4CEE59FC3D895DEF3B0C8DEA0DEF4B60E2400000D00
9DAD6FC6D496BAC88A536221879653C7D894DAF0A8D7EEA6D7F3A8D2F2A6BBDE8ECDE99E
99A661828E4CD9EEA9D8EFA9E3F4B0C9D291BCBE7F4C4E0FD8E2A3CFDF9ECADF9ECDE2A1
D9E9ABDDEDAF667C3ECBE0A7BFCC9EEEF8D3FEFFE8FEFFEFFFFFF8FFFFFBFFFDFFFFFDFF
CEC8C8C8C3C0F9F4F0FFFEFAFFFEFBFFFEFDFCFAFBFFFDFED4D2D39E9C9DFFFDFEFBF9FA
FFFEFFFFFEFFE6E4E5FCFAFB838182FFFEFFFFFEFFFEFCFDFFFDFEFEFCFDFFFEFFFFFDFF
FFF7FFFFF9FEFEFFFBF8FFF3A6A998FFFBEBFFD7D1A8766BF1EACEDAE9C2D0E0B3CBDEA7
C8E5A2CBEB9FCDEA96CAE793B9D78DC2E19BCAE8A2D0EEA8CFEAA5C1DC97C5E09BDEF8B1
BED891ADC47E8DA25DB9CE89CEE29DD2E6A1CFE39ECDE49EC9E99EC7EC9ECBEE9CCAED99
C9ED96C8EB97CAEA9ECCEBA7CAE6ABC8E3AEC7E2ADC7E2ABCAE4A5CCE89ECCE997CCE995
CFEA99CFEA9BCCE89DCAE59ECCE7A2D1ECA9D3EEA9CFEDA5
A5C383759252A8C180E2F7B6CBDF9ACEE49CD2E89FCAE095B5CA7F9AAA61909A53BABF7C
E1E6A6D6DA9DE0E8ACD6E0A46A733A9CA56EDCE5ACEBF6BAEBFBBCD2E6A1C5D692DBECA6
CEDF989EAF68A8BC75BFD08A7B8745788341D8E3A1CEDA98CCD793D5E29DD1DD9BCEDD9A
DDE9A9ADB778878D5164652BA09B649F9A63EFECB5EEEFB6D6E0A4D4E6A8BFD896CEECA6
C9E59BCFEB9ECBE896BCD987CAE69BDDF7AEC9E399C6DDA5010F00000500CFDFAE8FA059
9AAD5EB1C176899759DEEEB0CDE7A0D8F4A9B8D489D2EEA3D2EEA4CEEAA0C4DE95C0DA91
CFE9A2E3FDB6D4EBA589A05AA8BF79D5ECA6E0F5B0BCD38FD0EAABBCD699D4ECAEB6CA8D
607032081300ADB77AD4DD9E899354DEEAA8CEDF99C2D991B7D68ABADC8FCFF6A5CEEFA0
D3E49D8B9652ABBF7ABFD48FCCE19CD8E7A6DAE0A258571E636229DDE3A5C6D997D1ECA5
C3E39AC2DE94C9DD969CAA6CA7B47FE3EEC4FEFFE4F7FCE6FDFDF1FFFFFAFEF8F8FFFBFD
D7D1D1B3ADADF9F4F1FFFEFBFFFEFDFFFEFFFFFEFFFDFBFEFFFDFEDBD9DAFFFEFFFBF9FA
FFFEFFFCFAFBFFFEFFF4F2F3898788FFFEFFFFFEFFFFFEFFFFFEFFFDFBFCFFFEFFFFFDFF
FFFBFFFFFCFDF8FBF4DEE4D8C1C2B4F5E1D6FFCECFF1BEBBFFF7E2E6F4D3D7E6BDCCE3AF
C7E7A4C7EC9ECAEC95C8EB91DAFDABD8FDB0C8EA9EBADA8FC5E59AD0EEA4CCE89EC7E198
D7EEA6CEE39ECEE29D6879358FA05CE3F2AFC3D28FDBEFAAC7E59DC7E99CC8EB99C8EB97
C8EC95C9EA99CAEA9FCCEBA8CAE6ACCBE6B3CBE5B5C9E4AFC9E3A6C9E49DCCE997CFEC98
C7E291CCE798D0ECA1CFEAA3CAE5A0C4E29AC3E197C4E298
96AC6189A155BCD78AC5E196D9F3A9C8DE96D7E8A2919E59949F5B97A25ECCD793E1ECA8
CFDA96DDE4A18B8D4C9A9C5D373A014C511BCECE98F1F6BCE7F3B5CCDB98DCE8A6D5E09C
CCD792C3D08A7E8F48E5F5AEB8BF7C707533B0B978D5E49FCDE39ADDF8ABCCE69CD0E89E
C8DE96C7D691ECF2B29593588C834C534812A297617B743DDDDEA4CCD699DDF0B0CFE8A4
DDF9AFBBDA8AD0F09BD9F9A4CAE99BC3DF94CAE69BDBF2BA000600000800DBEBBCCCDD97
D1E196B6C479939F618F9F61C8E29BD4F2A8BDDB91DFFDB3B9D58BBDD98FE9FFBACAE49B
C3DD94CEE89FCBE29A869D559AB169C9E098C0D78FDFF8B4C5E3A3CCEAACD2ECAFCDE1A4
9AA86B6A74382C3200E3E7AAA9AF71C0C988DAE9A4DFF6AED3F2A6C1E897D2FDABBADF8F
D1E59DB9C68199A563D9EAA6D3ECA8D3E9A8C1CC90A7A86F514511CCC58ED5E6A2C2E498
C7F7A3C6F09CE1F2A4CCD38FA4AF77D8E4B6F1F8D6F4FAE0FFFFF3FFFFFAFFFDFDFFFDFF
EFE9E9B4AEAEFFFEFBFAF5F2FFFCFBFCF8F9FFFEFFFFFEFFFFFEFFCBC9CAFFFDFEFFFEFF
FFFEFFF8F6F7FFFEFFFFFEFF807E7FFFFEFFFFFEFFFFFEFFFFFEFFFFFDFEFFFEFFFFFBFB
FFF6F9FFF4F2FFFFF8D8DED2A1A294FFFAF3FFD4DAEAB3B6FFFEEFF3FFE4E6F6D1D6EEBC
C7EAA6C3EA99C7EB91C9EE8FBCE28BBBE28FC0E693CDF3A0D3F6A6C3E495C0DF93D6F0A6
D0E89EC8DE96DDF1AAB3C47E4E5B16B9C681E3EEACC6D793CBE69FC8E89DC8E99AC8EA96
C9EB95CBEA9ACBE9A1CAE7A7DCF7C2DEF8C9DCF6C7D5F0BDCDE6ACC8E39ECBE898CFEC98
D1EC9DCDE89BC9E59BCAE59ECBE9A3CDEBA3CEECA2CEEEA2
CAEA95CAE795D4ED9CDAF1A3C4DC92CEE49C7C8B48B3BF7DD5E1A1CFDE9DDCEDA9CBDC98
D3DC99C5CA88555815757A388F995C97A0677C7F462F3000B6BA7DD8DD9DD9DB9AE4E9A7
DFE6A2D9E49F8FA0598B9C55919C57B8C27D798440CFE39BD1F0A2B9DF8CCBEC9DC9E598
D8EEA5E0F0A9CAD18EE8EAABD5D396EBE6ACA39E647671393736009EA2678F9559B9C585
D4EAA2C2DD8ED9F5A1C2DF8BCFEBA0CBE69FD0ECA1C5DEA4000800000F00CDE1ACCAE098
D7ECA1D5E79DD2E39D8C9D5990A560748B43CCE69FD0EAA1CAE59ECEEAA0C6E19AC8E69C
CCEAA2CCE89ED5F1A7C9E39A778E4691A860CDE39BD0EAA3D3F2AEBADA97CDEAA8CCE2A2
CFDFA1CFDB9DA3AB6F676D31CED496717B3CC6D592CCE29AC9E79DBEE395C5EE9FC4EB9C
CFEDA3CADB95B6B879DADC9DD0E5A2C7E29DE3F8B7CED89BEBE2AB574E15999F5FD7F3A9
ADE18EC4F3A2C9D992E1E2A699A06DC1C89FD4D9B9E4E7D2FFFFF4FFFFFBF8F4F5FFFEFF
FFFCFBA9A5A4FFFEFBFAF6F3FFFDFDFCF8F9FFFDFFFFFDFFFFFEFDC3BFBCFFFEFDF9F5F4
FFFEFDFFFEFDFFFDFCFDFCFA72716FF7F6F4FBFAF8FFFEFCFFFFFDFFFFFDFFFFFDFFFBFA
FFFBFDFFFCFBFEFFF8CFD5C7ADAEA0FFF1E7ECB4B7F4C0C4FFFDF3F8FFEFF3FFE5E1F6CD
CCEBB2C2E6A0C7E897CDEF99C8F09ACDF7A3C8EF9EC0E595C7EA9AC9EC9CC7E899C9E89A
C5E194D8F3A6C7DF93D2E69ED1E09B76813FAEB778DAE6A8D0E9A8CAE9A6C9E8A4CAE7A4
CCE9A7CFE9ACCDE5B1CBE2B4F4FFE4F4FFE6F2FFE1E4FBCDD3ECB3C9E49FC9E694CDEA96
CEE69AAEC47C8DA25D879E589EB571BBD28CCCE69DD3EDA3
C4FAA4C3ED9BCEDE95D3D895D8E39ECFDE9996A763C8DD98CAE49DD8F3ACC9E79FD1E5A0
E1E1A1938F509DA762CEE29BC9E49FD3ECAAC2CE90A5A66A675E25DED298EBDFA3E2DC9E
DDE29FDDEAA4C9E195C6E2954F6A1D40580CA8BD72BFDA8DC9EE9EC1EB99CCED9ECBE699
C6D88ED6E39DE0EBA6CFDA96D0DF9AD8E7A4D7E6A5D8E2A5D9DDA257541D695D29312A00
666F2ED7E8A1D8EE9CCAE193D2E8A7C2DA9CCCEAA2CBE9A9001400000C00D3F1B3C5E399
C8E69CC5E194D1EF97CFE894D2E29B97A361CCDB9AD8ECA7C9E29EDCFAB2C2E39CC3E79D
C6EAA2C5E99FD0F0A5CAE89ED3EDA3D3E9A0BCD088576F25C5E599C6EB9EC5E59AD1ECA5
CFE6A2D2E5A5C9D99A000B006472357E8C4FD8EBABC0D592CCE5A1D1EFA7BCDE92CDF6A8
C3F3A7CEECA6B5A26AAD9660E0EDA8C6E69BC7E99CCDE79DD5DC999E9A5D675C2494985D
B8E39CCAF9B5CDDAA4E1DEB3C9C6A5AFAB92FFFFEFFBF9EDFFFFFBFEFCFFF5F3F6FFFEFF
FBF9FAA6A5A1FFFFFAFCF9F4FFFEFAFEF6F4FFFCFFFEF4F5FFF8F5DAD3CBFFFAF4FFFEF8
FFFEF8FFFEF8F5F0ECFFFFFA6B6764FFFEFBF9F8F3FFFFFAFBFCF6FFFFFAFFFFF8FDFCF8
FFFAFFFDF4F9FAFFF9D0DBCBD3D8C4FFFAE9FFDAD6F4C4C2FFFBF0F8FFF4F9FFF3F8FFED
F0FFE0E0F8C8D4E7AFC6DF9EC5E99FC1EA9EC5EBA2C6EAA2C9EAA3C9EBA1C5EA9CC4EB98
C7EF97C1E991CEF29BCFEE9EC7DD94D6E2A290955DD6DFAAD7EBB6BFDBA8EBFFD8F1FFE1
EAFDE1F7FFF1F7FFF8EDF9EFF3FFF5F7FFF4F1FFE7F5FFE1D0E9B0C4E29AC9E994C5E18D
D3E49D8F9A58CED899D6E2A2DFEBABD7E3A35B672547540F
A7DE8AB9E494D9EAA3E6EBA8DEE5A2222D00DEEFABD1E8A2C5E59CC1E399BDDD94CEE39E
DFE4A296965698A25DD4E8A1BEDC96C9E7A1D8E8A7E0E6A8A7A16781753B8E8248EEE8AA
DEE09FCBD892DBF1A8DFFBAEBCDB8DC9E898C2DD90D6F2A5CBEE9EBBE092C6E599DBF6A9
DBF1A6D1E69BD1E59DD6EAA2D2E69FDDF1AACFDF9EB9C384797C43716C35A193625C521D
575B1EBAC782CDE091C8DD92D9EDB0D8F0B4D3EEA7BBDA97000D00001300C8E6A8BCDB95
D3F0AECFEAA3C0DE86D4EC94D8E49CCDD6957F894A8A9A59C3DC98C1DF99CAEEA6D5FBB2
C7EFA6BCE297C0E296BEDE93CDE79DD8EEA5E2F4AA9CB267CCED9EC3E898C3E598CCEAA0
C9E39CCEE5A1D9EDAE536527334207D1E3A7CCE0A1DCF2B1DDF3B2BBD691E1FFB7BBE196
B8EEA2BADB96A68F5B80612BD3DD98D1F2A3D0F7A4C1E492D7E7A0E3E2A2624E199B965F
CBEFB1BFE8ACD7E4B6D4D1AEE2DCC4BFB8A6FFF8EEFBF6F2FFFEFFFFFEFFFAF9FEFFFFFF
FFFFFFACADA8FEFDF8FFFFF8FBF6F2FFFCF9FFF9FAFFFCFDFFFDF8FFFEF6ADA49DFFF8F2
F9F2ECFFFEFAFFFEFAFFFEFB5C5855FFFCF9FEFDF9FFFFFBF9FAF5FFFFFBFEFFF9F9F8F6
FFFAFFFFFBFFFCFFFDCDD8CABDC2AEFFFCECF8C5C1EFBDBCFFF9F3FAFFF9FCFFFAFBFFF6
F2FFE9E8F7D8E2ECC7D8E8B7C7E5A7C9EEA9C5E8A4C7E7A4C5E4A1BFE099C5EA9CC0EA96
BEEB90BFEC8FCBF39ACBEE9ACBE29AD6E4A7919563A4AA7ECBDCB2B8CEA8E1F4D6F7FFF1
F8FFFAF1FAF9FAFFFFFBFFFFFBFFFFF1F8F0F9FFEFF2FFDEC7DEA6D0EBA4DAFAA5CFEB97
D5E59EB0BA7BD7E1A2DCE6A7CBD596D4DF9DCBD694DCE7A5
CDF2A2CDF2A2C4E498C8DE95D4DB975E6320CAD792C9DF97D1EDA3C8E69CD9F0A8DAF0A8
C9E0988596508F9452E4E9A7D6E9A7CEE4A3C8DB9BC8D796D5DFA0999F5F77793A626423
8A8F4DECF5B2D3E09BBBCF87D5EDA3D6F2A5C1E195D0EFA3C7DE96DCF2AAD4F0A6BDDD91
B9DB8EC4E699C9E89CCDE59BD0DF9AAFB8757C7D4189874C939059A3A26AA7A670979A61
8F9B5DB5C682D1E397D9EEA3D5E9ACC5DA9FC8E29BDAF4B3000C00000A00CDE1ACD9EDB2
CADBA5DCEBB2C7D79095A3588B9550C5D08C8E9A58AABE79E5FFB8C1E198BEE298C2E89D
D4FAAFC4EA9DCCEEA2CBE99FCFE79DC8DE95D2E39C97AD62CEEFA0BEE393C6E89BCCEAA0
C8E39CCCE39FE0F4B5B1C3857D8F51DBEDAFC5D99ACBE1A0D2E8A7D3ECA8C2DD96CAEEA4
B6E99CCFF3ABE9DDA3AB955CCAD18DC0DB8EC3E996C7EA98CFDF98EEEEAE5A4D18615B27
C9E5ABC0E1AAFBFFDAFFFFDFFFFFE8DBD4C2EAE3D9FFFAF6FFFEFFFFFEFFF9F8FDFBFBFD
F9F9F7B0B1ABFFFFF8FFFCF3F9F4EEFFFDFAFFFCFDEDE3E4F6EEECFFFEFBB6AEACFFFDFD
FFFBFBFFFEFFFAF6F7FCF7FB4D484CF5F3F6FFFDFFFEFCFFFBF9FCFFFEFFFFFEFFFFFCFF
FFF8FFFFF6FFEAEAEAC8CEC4FFFFF3FFFAEFFFE8EBF5BEC4FFFAFAFEFFFDFFFFFFFFFFFD
F9FFF4F7FFEDF8FCE3F4FED9EEFFD0E0FFC1C3E1A3CDE9ACD3F0AECAE9A3D4F6A9C5EB96
C3EE94C5F096C8F098C4E596CAE19DD4E1ABA2A57A7F815CFCFFE4F9FFEAF6FFEAF4FAEC
FEFFFAFFFFFFF5F4F9FAF9FEFCFCFAFEFFF6E0E8D0E8F4CCD9EAB3B6CD87D2ED9CC5DE8B
4E641BC2D691D9EDA8C7DB96D9EDA8D7EBA4D1E59EDEF2AB
C3D98EC7E396C9F2A3CCEEA1D3DE998B904DD4DF9BE0F1ABCFE69EC3DD94D7EDA5D1EBA2
BEE49797B56B969857D7D396D9E1A5D6E4A6E4F7B7DDF2B1E0F6B5CBE09DBECE8D515D1B
5E6424D2D795DAE0A0DBE6A2DEEFA9C6E096CCECA1CDEBA1D3E29FDEEAA8CFE6A0C7E79C
CFF8AAC9F2A3C2E799D1EDA2BFCC87767837575316898349EAE8AFE3E4ABCCD49BD9E7AC
D3E3A5D2E5A3D7ECA1C6DC93C4D89BD5EBADD1E8A0C8DE9D031300000800DCEAB9C4D19C
DCE3B9E2E8BAE4E9B15C6222969F5CADBA74D2E39DD8EEA6D0ECA2CCECA1C2E79AC6EC9F
BFE598BCE194CEEEA3D2EEA4D4ECA2CEE29AD0E0998CA058CAE99BBFE292CCECA0CDEBA1
CBE69FCEE5A1D3E8A7D6E8AA92A466BBCD8F5E72339FB473D5ECA8BAD38FC3DD96D8FAB0
BFEDA2C6EAA0EBEBADD9CF92BBC07DD4E99EC9EC9ACAED9DCDDD96D4D695B2A9725E5B26
DAE8B3CFE3B0FBFFDAFFFFDEF8F6DDD1CCB9C3BFB3F6F3EEFCF8F9FFFEFFFFFEFFFFFFFF
FFFFFDBDBEB8FFFFF8F5F5EBFFFFF6FFFBF5FFF9F79D9495AFA9A9CDC9CAD3CFD0FFFBFC
FFFDFFF9F7FAFAF5FBF1EFF4747277FFFDFFFFFDFFFFFDFFFBF8FFFCF9FFF7F4FDFFF7FF
FFF8FFFFF6FFFFFEFFB8B9B3F2EEE3FFF9F3FFC9D1F3B7C3FFF8FFFFFEFFFFFDFFFFFDFF
FEFFFDFEFFF8FFFFF3FFFFE8F8FFDCE5FEC7BDD49CCDE5ABD4EAACC0D997CCEB9FC4E793
CBF299C7EF96C4EA95C2E296CDE3A5DDEBBAD6DAB7A5A589FDFFE9F5F8E5F5F6E8FFFFF6
F2EFEAF5EFEFFFFDFDFFFEFBFFFFF6EDEEDCE3E8CADBE4B9D9E6AEDDF1ACC4D98CDDF6A5
526C22D3EFA5D3EEA7B7D389D8F4AAD3EFA5C0DC92C1DD93
E1ECA7DDF3AAB7E292BDE697E1F5ADC2CC87727C37D8E39EE1F1AACBE198C6E097BEE094
BFEE9EB8DD90898B4C81783DD8D79ECDD59AE3F5B7F4FFCCDFFFBDB8DC96D4F3AFC4DB97
939D5E535818929256C3C586C8D391CEE29BBFDD95CFEAA3D3DFA1D5DDA1C9DC9CCAE8A2
C1E79C8FB568638539657F364F5E19747937D3D194E4DFA5DAD9A0D3D89EDBE6ACD1E0A5
DDEFB5CADE9FD8EEA5DEF4ABD4E8ABD0E4A7CEE29AD4E7A5000800000600D4DCADF1F4C5
F5F2CF898562ACA87BD3D49BE3ECABBDCD84E3F7AFCFE79DB7D388D4F6A9C9EEA0C8EFA0
C1E698C3E598CEEDA1C7E197CEE49CD8E9A3DEEBA690A15AC9E497C7E698CDECA0CAE69C
CCE69FD5ECA8C7DC9BD2E7A68DA162C7DB9C6B803F3449086A813DAEC581CDE4A0C2E09A
C4EDA1BEE298CDDA95DADD9A797C37CFDC94C9EA9BC9EA9BE0F1AACFD595F4F3BB8A8855
BFC190D3DBACFAFFD9FBFFDEFFFFE6E5E0CDCFCBBFFFFFFAFFFDFEFFFEFFFFFEFFFFFEFF
FFFFFDE5E6E0FFFFF6FFFFF4F2EEE39F9B92DCD5CFBDB8B5D8D6D7F8F8FAF5F5F7FDFDFF
FFFEFFFCFBFFFFFDFFACA9B09E9BA2FFFCFFFFFDFFFFFDFFFFFDFFFEFBFFFFFAFFFFFAFF
FFF6FFEFDBE6918B8BDCDBD6FFFEF6FFF6F5D896A4AB6B7CFFF3FFFFF8FFFFF7FFFFF7FF
FEFBFFFFFDFFFFFCFBFFFFF3F8FFE0E5F6C9CCDCADDAEBB7D9E8B1C0D393CDE59BD1EE9C
C9ED95C3EA91C0E693CCECA3D4ECB2ECFBD0FFFFE8EFEEDCB9B2A8FFFDF6FFFCF7FFFCFA
FFF8F6FFFCFAFFFDF8F5ECE3FFFFEFFFFFE8CED0ABDDE3B3C5CE95DAE9A6B5C57C162D00
CCECA0BCE193C8EDA0D1F6A8C2E799BFE496CCEEA1CDEFA2
D1D895D6E7A0C9EB9FC5EC9DC1DB91ECFDB6757C38D0D793D0DB96D7EBA3CEECA2C5EB9E
C3EFA0C7E99D8E94545E581EDBD69EE5E8AFD5E5A7D5EFAED1F6B0BFE9A1C0E59FD5F0AD
D9E7A98C90536E6C3189874CDBDFA2E8F4B2CDE4A0DDF4B0DBE6AACCD69AD0E0A2DBF0AF
A3BE793C5A121935003F560E697A34B8C580E8F1B0DDE3A5CAD094E4ECB1D9E4AACCD9A1
CEDFABC6D9A1C9DE99D3E8A3D1E5AAD0E2A4D6E89ED2E39D061100000600DEE4B4F4F6C5
EFECC9575330A49F75E0E0AADBE6A2D8EAA0D0E69BCAE598CFEEA0CFF2A2C4E999C0E796
CDF2A2CFF1A4D5F4A8C6E096CCE099D6E5A0D6E19D808F4ACDE59BD1EDA2CAE69CC6E298
C8E29BD8F2ABC8DF9BCEE3A2ADC182ACC081D5EAA9C1D695122700283F00DDF2AFC6E19C
CAECA2D1F3A7D1EBA1DCECA571722EC6CD87D0EC9FC9E99DDCEDA7D4DD9CE1E6ACB4B480
7C7144C3BC92FBFFDAF8FFDFFFFFE4EEECD7E7E3D7FFFFF8FFFEFFFFFDFFFCFBFFFCFBFF
FDFDFBFFFFFAD8D8CEEEEEE2B4B2A6A39F94ECE8DFFFFFF8FFFFFBFCFFFDFCFFFDEEF3EF
F5F7F4FEFFFFA4A6A5262626C6C6C8F7F5F8FBF9FEFFFCFFFFFDFFFFFDFFFFFCFFFFFAFF
FFF8FFDDCACCCCC7C3FAFAF2FFFEF6FFEFEEE7A5B3FFD7E8FFF4FFFFFAFFFFF9FFFFF9FF
FFFBFFFFFCFFFFF9FFFFFCF6FFFFEAE7F1CCD1D9B2CED5ABDCE4B1E3F1B4D8ECA5CCE594
C9EA93C5E992C4E797D2F1ADD0E8B4EDFDD8FEFFEDFFFFF6A29795FFF8F8FFFBFBFFFBFB
FFF7F4FFFDF4FBF1E5FFFFECFFFCE2FFFFDFD7DAAFD5DCA8F3FDC0CBD7956B7B3491A95D
D2F7A7AFDA88C5F0A0CFF8A9C2EB9CC1EA9BBCE394C6ED9E
EAF6B4C1D08BD4E8A3D9F3AAC0E094C2DE93E5EFA8595C17989F59CBDD93CAEFA1CBF6A6
C6E69BD9F0A8C7D391A4AA6CA09F66D7D89FECF7BBC5DB9BC1E19ECDF2ADC8E8A5C6E19E
C6D697E5EDB1A09F66817F46DEDCA3E3E4A8D0D89CC4D294CFDEA3E0EFB6B4C287576125
444D0E99A462DAE7A2D2E39DD3E9A1D8F2A9BBD58EC5DC98F1FFC2B8C2865B5E27363A08
5E693EC1D1A2D6E8AA9EB17166783E748648B2C576B8CA80ABB785A7B083879059A4AD74
3F4519DADCB4E2E6B4D7DFA3C8D792DEF4A9C4DC8EC5E091D3F2A2C0E391C4EA97D2F8A5
C1E492C0E192CFEBA0CEE69CD6E7A1D8E7A2D8E3A18C9856CEE49BD7F1A7C6E097CDE79E
C7E19AD3EDA6CCE5A1CFE6A2DEF4B3849A598BA05FD6EBAAD3E8A796AB6A3F52129BB26E
D0EEA6C6E89CBFE496CEE89EC0C17FC4C583CEE69CCAE99DCBDF98D2DE9ED9E4A8E0E0AC
695229B6A47ED5E2B4C8DEB0D0D7B5C5C5ADDAD8C9FEFBF2F7F6F4FEFCFFFFFDFFFFFEFF
FFFFFDFFFEF9B4B4A8C9CABCCBC9BCFFFFF4FFFFF4FFFFF3FCFFF4EEF6E7FBFFF4FBFFF4
FCFFF4EFF5E96D7367686B60FBFEF5FFFFF8FFFFFAFFFFFAFCFBF7FFFFFDF5F1F0C9C1BF
C3B4AFFAEDE4FFFFF3FBFFF0FFFFF1FFF6F0FFD4DCB57985FFF8FDFFFEFFFFFCFFFFFCFF
FFFDFFFFFDFFFFFBFFFFFDFBFFFFEFEDEDD1D2D1B3999975A8A97DE3EBB2D7E49FC0D588
CDE995CEEE99C5E79ACFEEABC6DEACF3FFE1F5FEEDFAF9F4FFFBFF8D7C849B8B8EFFFBFA
FBEEE8FFFEEFF9F3DDD9D5B8DDDDB7EFF2C5E1E8B4A0AA6E687736798A46E2F3ACC9E497
BCE392CDFAA5C6F3A0B1DC8AC4EE9CCCF6A4BDE493CEF5A4
455A1992A263CDD697D6E5A4C8E89FD8F8ADBECE87E0E7A199A35CD1E399C3E89AC9F0A1
C4D891DDECA7DEF3AEC5D594565C2060632AC3CD91DBEBADD1E7A7C7E1A0D1EBAAD1E7A7
D9ECACC8D496DCE2A69291589E9961D9D49CE9E2ABE4E5AC69783F152800263100989D63
E0DFA6DEDEA0D5DB9BD8E7A2D2ECA3BCDC93DAFBB4C9E8A4C1D797687339BDBD89FFFFD4
F5FDD8D0DFB4A3B57BD8EAACF6FFD0D2E4A6D6EC9AD5E899DDECB3C8D6A3CFDF9ECADA99
D7E5B0D3E1ACCFDFA1D2E39FD3E9A0D0E89CCBE699CEEB9BD2F1A1CAEB9AC1E490C6EC97
D3F6A4C6E796CFEB9ECFE79DD4E59FCEDD9AD5DFA099A563CCE099D9F0A8C8DF97D9F3AA
C9E39CCCE69FCDE6A2CEE7A3C5DE9AD4EAA9465C1B869B5ACEE1A1DFF2B26A7A3B000E00
CEE8A1C3E599CCF8A9C3E397D6D7956561218EA25ACDE99FD7ECA7C5D594DEEEB0D8D8A4
664921BFA580CFDDACD2ECBCDBE5C0D1D1B5F2F1DDFFFFF4FDFCF8FFFEFFFEFCFFFFFEFF
F9F8F6FFFFFAFFFFF4FFFFF3F9F7EAFFFFF3ECEADEFFFFF3FBFFEDF8FFECEBF8DEF9FFEA
F6FFE77F896E7B856AF7FFE5FAFFE8FAFFE8FEFFECFAFDE8FAFDEAFFFFF1FCFDEFB4B1A0
FFFFECFFFFE8FCFFEAF2FFE3F7FBE4FFF9EBFFDCDCEDB6BBFFFBF6FEFFF8FFFFFBFEFEFC
FCFEFDFDFFFEFFFDFEFFFDFBFFFFF1FFFFEAFAF2DB847E5E6E6B42C9C995D8E1A0DDEDA4
CDE695D4F19FC4E498C9E7A7C5DDADF7FFE8F7FFF1FFFFFBFFFCFFFFFAFFFFFAFDFFF4F0
C1B9ACB2AD97757455888A62D9DFAF88935B535E224D5D1CD6EAA5C7DD95D1E79FCCE89D
C8EF9EC2EF9ABEEA95C7F19DC7EE9DC3E898C9EE9EC7EA9A
A9C38671854AAFB27BE3E8AEC3D998CBE9A1D3EAA2D5E9A1D6E7A0495F16D1EDA2D0E89E
DDE6A3D4DD9AD5F0A9C3E19B889658596125BAC084DFE5A9DDE5A9C8D295DDEBADD3E3A4
D2E4A6C8DA9CD9E7AAD1D69C615E27998D59FAE4B33A2C004F5823ACBD86D0D9A2D1D49D
E5E3AAE0E0A2D9DF9FDAE9A4C7E198D4F6ACB8DC94CFEFAC627A3CD5E2ACCCCE9DFFFFDA
FFFFE4F8FFDEFBFFD4FBFFCFF9FFD4D7E9ABC5DB88D2EA96D9EDAECADFA4CEE89EC6E295
C4E19ED2EFACCBEA9CC4E393D1EBA1D1E8A0CEE89EC6E295C2E191C9EA99D1F4A0C2E591
CCEE9AC4E393CEE99CD5EBA2D3E7A0DDECA9D5DFA0B0BC7C8D9E5AA9BE79C8DD98D2E9A3
CAE49DC4DE97C6E19ACFEAA3D5F0A9C2DB97D9F0AC8DA25FC2D595DBEBACDAE8AB96A667
A1B874C6E89CC9F8A8BADF92D8D898A49E60465711D7F1AAD0E7A1D1E6A3D0E2A4E3E3AD
74542BAC9068CDDBA6C9E6B0D4E1B6BABE9DC7C9B3FDFEF0FCFBF6FFFEFFFFFEFFF8F6F9
FCFBF9FFFFFAFEFEF4FFFFF4FFFFF3FFFFF3FFFFF4DADFCBDCEAC7C3D5ABD0E1B7E1F2C6
D0E1B439491CDDEDBED1DEB0D4E1B3D6E1B6E7F2C7FAFFD9F5FDD8949A769DA381DBDFBC
E1E3BCD2D9AFC9DCAFD5ECC2F1FFDBFFFFE6E5B9AEE8BCB3FFFFECF3FFE7F5FCEAFAFFF2
F9FFF4F9FFF6FEFFF8FFFCF3FFFEF1FAF2DF7E715E786D51867E598C8859E1E5AADCE9A3
D9F0A2C3DE8FCDEBA1C8E6A6D2ECBCF4FFE5F5FFEEFAFFF8FFFEFDFFFAFBFFFBF8FFFFF3
FFFFECFAFFDFE9F2C7D9E6B1C9D89DC7DC9BC8DD98CAE199CAE49BCBE79DCDE99FCCEB9F
CDF2A2C0EA96C2E996CEF4A1C3E495D0EFA1BDD98CCCE89B
C9E4AFBDCF9B858957A0A270D3E1A6D9EFAEC1DF99C6E49AC3DF948DA55B687932CDD792
D4D695DCE7A3B7D78ED6FAB0DEF5B1838F4F3D430764652BE0DEA5E0DFA6D2D89CD6E2A4
D5E7A9A0B676D3E7A8ADB87C605F27978A56AD9162675122C8C896CCD6A1D2D9A3DCE1A9
E8EEB2CDD393CFDA96CADB95CEE59DD6F1AAC4DF9C92AC6DD4E7AFD7E5B2E3EBBCF6FDD4
F7FFDFDDE9C3C8D6A1C3D59BC8D9A3CDE1A2D3EA98D6EF9CCDE6A5BAD495D7F6A6D9FCA8
C9EDA3B4DA8DD7FFA7CCF29BC9E59BBED591DCF6AFD7F3A9C9E89ADBFCABBFE08FCBED99
C4E692CDEC9CD6F1A4CBE399BED28BC7D894D8E4A4D8E4A4A5B67293A762879B56A0B570
CDE7A0D8F3ACCAE8A0CCEAA2C7E59DCAE59EC8E19DD0E5A2E0F0B1849254CFDA9ED4E2A5
CCE19EC8E89FB7E698DAFEB4F0F0B2B8B276C3CF8DC5DC98D4EDA9CAE19DD1E4A4D9DAA1
6C4D21A78F63D5E7ADCEEDB2D9E9B8DEE4BED7DABDFFFFEFF7F7EFFDFCFAF9F7FAFFFEFF
FEFDFBFFFFFAFDFDF3FFFFF4FFFFF4FFFFF3FEFFF3D6DEC7C0D1A7DCF0BBD4E8B351662E
253800C1D59ABDCF93D9EBADDDEFB1CBDB9DEFFEC398A56D7D8A54DCE9B4E4EEBCD1DBA7
D7E2AACEE0A6CBE8AED1EFB9D8F0C0EAECC7DAB69EF8D5BFE6EAC7DDF2C9EAFAD5EAF9D8
E2F5D7EBFDE3F9FFEFFBFEEDFFFFEFFFFAEA50412E9A8C72FDF0D06C65399D9E65CFDA98
D8EDA2C7E295CEECA2C4E3A0C7E2ADE1F7D0EBFBE1F9FFF4FFFFF8FFFFF8FFFFF3FDFFEB
F3FDDBE6F3C8D7E8B4CEE2A5C8E19DC8E49AC6E599C7E69AC7E79BC8E89CC9E99EC9E99D
C6EB9BC8EE9BC7EA98CAE999CEE99CCEE69ADDF2A7D3E89D
B2C79CD4E7BAACB98D788051E1E5B3C7D29ADAFBB6B5DF93D0F6A9A6BE74323300E2DD9D
DEE3A0DDF1A9D5F5AAB3D78DD5F0A9C6DA95545D1E4141059E985EA29C6297975B9CA566
8FA262516A287B94525063234F52199B8F5B917647A98E61DBCEA1D1CF9EE8EFB9E3F1B4
C7DA98C7DE98F1FFC0D0E79FD1E29CDDECAB838E5295A068D4E0AECEDEAFCADBAFF3FFDD
F9FFE3D8E7BECFE0A9D9EBB1D8E9B3D7EBAED3EA9AC1D98BCDE5A9D4F0B5CAEA9EC0E693
C2E89DBEE99AC5F297B9E189D1ECA5C9DF9FC8E19FC3DE998BA75D84A35778974799B868
6887379AB969CAE598DDF5ABDDF3ABD4E8A3CEDE9DD1E09FDFEEADCEDD9C5D712C455A15
BBD58CDDF9AFB5D389D1F1A6D3F3A8CAE8A0D3ECA8CBE09DD0E0A18B965AADB57CDCE7AB
D0E5A4D8F6B0AED68DCCEBA5D0D195E2DDA3DDE7A8CADF9CD0EBA6C3DC98DDEDAEE1E0A7
6C5122A89462D5E9AAC7E7A6D2E3ACEBF4C7C7CDABF7FBE4FFFFF4FFFFFBFBF7F8FFFBFF
FFFEFDFFFEFBFCFCF4FFFFF4FFFFF4FFFFF4FCFEF3D4DCC5D5E6B9DEF3BACADFA4415719
9AB06FC2D993D1E79FCCE299C2D88DCEE398BDD1894D5E18B6C783CFDF9ED2E2A3CFDF9E
CADE99D0EAA3CAEFAABFE6A5C8E7AEE8F1C2CFB290D2B593D6E0AECAE7ADD0E9B2CBE3AF
C6E2B2DDF6CCF7FFE6FEFFE8FFFFECFFF2E1645542C4B49DEEDFC26259328E8C59CDD599
D6E7A1CEE69CD2F0A6C9E8A4C6E2A8D4EBBDE0F4D1F8FFECF7FFEBFBFFEDFBFFEAF4FFDF
E4F5C9D4EBB5CBE5A6C8E6A0CAEA9FC9EB9EC9EC9CC6EB9BC6EB9DC6EB9DC7E99DC7E99C
C4E797CEEF9ECBEA9CC5E093D5EBA2CEDE97EDF8B3C6D08B
BBC9A8778763AABF98DEEDC243461BE4EEBAC3E6A4C0EBA3B6DC91DFF5AC5C54159E9355
ECF6B1B7CF85B9D78DD2F4A8B8D68CE2F9B1D8E4A2D2D898E3E1A4E0DEA1BEC2858F995A
CCDF9DCCE5A3E0FBB8D4E9A8DEE6ABE2DDA69D8B596C5728817346E0DAAAD6DBA3BED092
D3EEA9CDEDA2BCDB8FD2ECA2D4E3A0D7E0A1959861F2F4C2FFFFD8D1E0B5D4EBC1F2FFE1
F3FFDDC4D8A5BFD396D2E6A7CADDA6CADEA3D8EEA5D4EBA32A3E0B617746C8E3A0C5E59C
D4F4B3C4E8A2C2E996D1F4A4D8F1B0C0D59C778C51BDD695C1DA96C8E49ADAF6A9CAE999
CDEC9CCCE999A7C376839D53829951899E5997AA68B2C281D2DE9EDFEBABB0C17D809550
9AB46BC6E49ACCECA1C6E69BC4E499C6E49ADAF4ADCCE19ED6E4A6D3DDA190955D9EA76E
C8DC9DCCE9A7A8C885BCD594D6DBA1B8B77EBCC488D1E4A4CCEAA4C6E19CDFEBABE1DCA2
614D18A69B63CCE19EC5E4A0D0E2A6E5EFBBA7AF86BBBFA4F6F7E7FFFFFAFDF9F8FFFDFE
FFFEFFFFFEFBFBFBF3FFFFF6FFFFF6FEFFF6FAFDF2D5DEC9CDDEB2C1D69D000D00A0B676
D1E8A4DDF4ACCCE297CFE696D1E89690A7559FB666D1E898DAF1A3CFE59AD0E69DD2E89F
D0E89AC9E89AC0E99DBBE69FC8ECACE2EFBAC1A87FC2AA7EDBEBADC3E49FC1DE9BC2DF9D
C3E2A6D2EFB9E6F9CCE9F3CEEFEBD0FCF1DB7A6B56C8B8A1FFFDE3EADDBA706C3DC0C58D
D0DF9CD0E89ED0EEA4CCECA3CCE9A9CDE8B1D5EBBDE8FAD4E2F2CEE6F6D2E9FAD0E1F7C8
D5EEB7CBE7AAC9E8A4C9EB9FC8ED9FC7EE9DC6ED9AC6ED9AC5EC9BC6EB9DC5EA9DC7E99C
C8E99ACCEB9DCEEA9DC6DC91D5E69FD6E19DCED391A0A261
E5EAD699A58D93AD8AC6DFB8929F7497A776C6E5A9C4E9A4C1DF99E6F5B0968E4FAEA466
CDDA94E0F8AEC0DA90D1EDA2D5F1A6C1DD92D0E69ED0E19BCAD792DAE5A1D5E19FD2E39F
D3E8A3D3EAA6C7DE9AC0D592CAD89AD8E0A4C7C88E95925B5E5625999663B7BF86E4F7B7
C3DE97CDEDA2CAE99DC5DF95DBEAA7CFD79B868652D2D4A5EEF5CBC7D3ADD9EDCAEFFFE0
F2FFDAD0EDADCBE69FD3ECA8CCE1A9D2E5AED8EDAAC6D89C031100000800CADAA9DAEDB6
C9DCAECDE1AECCE5A4CCE2A1CCDFA8B8CA98798C55CADFA6D1EAA9D1ECA7D5F1A7BBD78A
C5E292D4F1A1CFEB9EC9E399C7E198A9C07A7A914D687B39939F619FA96A5E6D2A3B4F0A
89A35ACAE89EC9EB9EC9EB9EC4E699D2F2A7BCD68FDCF1AED9E7A9D8E0A596996298A16A
D1E7A9C8E2A3596F31DCEBB0DCE4AB8E9359A3A86ED0E0A1C9EAA3CCEAA4DAE0A2CBC589
605619ADAD6DC6DE94D1EFA5C4D996E6F4B9C9D2A5BFC5A3FEFFEDFEFEF4FFFEFDFFFDFE
FFFEFFFFFEFDFBFAF5FFFFF8FFFFF8FDFFF7FAFFF6DCE5D2DBEBC6C8DAA8657743DAEEB3
BBD191C6DD97C5DD93DBF3A5B3CC7B48610ED2EB98CEE796CEE698BDD589D5EDA1C6DE92
D9F2A1C2E28FBBE697C7F2AAC9EDADC9D6A0AE966ACEB785D9EAA6C1E396C9E89AD4F3A7
CDECA6C5E3A3CBE0A8CFDAAFE2DFBEA89E838F8069E8D9C2FFFDE3FFFFDF8B865C969A67
CBD99BD3EAA2C9E89CC5E59ACCEBA5C8E5A3CAE1A9D0E7B3CFE3B2CEE5B1CFE6B0CEE7AD
CBE8A8C8E9A4C6EB9EC5EC9DC4EB9AC4EB98C4EB98C5EC99C6EB9BC8EA9DC8EA9EC9E99E
CDEDA1C4E397D0EAA0CDE39AD5E29DE0E7A4979759828043
FFFFF4FBFFF39FB79D2C4C27AECAA1385423C7E4AAD3EDAEDEEEADC9D28FE3E2A2979856
CEDE97CAE097DDF3AACFE79DC6E297C3E294DDF9AECBE79CD6F2A7D6F0A7C1DB92D8EFA7
D8EDA8C2D691D8EBA9D6E9A7CDE0A0DCF1B0D4E9A8D2E2A3BDC28A9C9F684953174B5B1C
607530B8D288D9F3A9D1E79ECBDC98DBE9ABA8B17CBDC596FEFFDFFBFFE4ECF9DBCEE3BC
CAE9ADC3E79DCAED9BCCEB9FC9E1A7CADEA9AEC0847B8956000400000300DDE2C2717753
ECF0D5D8DDBDCED5A9D7E1AFD4E1B5CFDFB2E0F0C1F1FFCDCCE1A6CEE7A5C0DA93DBF7AC
CBE79ACEEB9BC9E598C8E497CEEAA0CFEBA1CDE6A2D3E8A5D9E5A7CCD699E0EFAEE1F5B0
BDD78EC4E298D7F9ACBFE496D5F7AACCECA0C4DE97D1E4A2CCD89AD9E1A69396619AA16B
D4ECB0C5DFA23B451069703AD1DAA398A168767B43D2E0A3BDE19BCDECA6E0E2A3BCB476
979353CDD48ECAE296D3EFA2C5DB93DAEAABD4E0AEC0C8A3F1F5DEFFFFF6FFFEFBFCF8F9
FFFEFFFFFEFDFCFBF7FFFFFAFEFFFAF9FEF7FBFFFAE7EFE0E4F1D37B8C62C1D2A5D0E2B0
CBDEA6E5FBBBD5ECA6CAE298879F51C7E291D5F09FC8E595D3EEA1DFFBAEBAD68BE2FDB0
CAE390CDED9AC7F2A2BFEAA2C5E8A8D4E1A9A186598E7743D6E69DC4E692D0ED99D7F4A0
CAE99BC4E29CD3E7AADFE9B7D4D4AE9F987BD8CCB2FFFEE4FFFDE4F7E9CCCEC9A3797B4A
BCCA8DD7EEA6CBE79CC2E394CCECA0C8E69ECAE5A2CBE4A3CDE5A7CAE2A4C8E2A1C8E5A2
CBEBA2CCEEA2C9EEA0C6ED9CC2E996C2E996C3EA97C4EA97C7EA9AC9EA9BCAE99DCAEA9F
CEEEA2C1E094D0EAA0D3E9A1D8E5A0CFD5956B692E8A854B
FBF8F3F1F7EBF5FFF3C7E8C9447345C1EDB892AB74D0D9A2E7E6ADCDCD8DD0DD98E0F1AA
4E5B139AA75FC0D18AD4EAA1D3EEA1CEED9DC9EE9EAFD987D0FDAAC2ED9DC0E798C9E89C
D5EBA3C5D48FE0ECAADDECA9CCE39FC9E8A2B9E198CBF0AACCE2A4CCDA9FD1DD9FA2AB6C
505916707A35D3E09AD2E39CDDF2ADCEE7A5D0E8AE879D6CE5F4CDFAFFE4FFFFECD6E0BD
C4E7A3BEEA93C1EC92CAED9BCAE6ABCBDFACCAD8A3C9D1A8030000110809F8F0E3FFFEED
71675ECFC3B7B7AD94ABA887FEFFE1EEFDD4F9FFDCEEFFCED4E7AFDEF4B4C0D995CDE79E
CBE79AC9E598CCEB9DCFEEA0C7E59BC4E298C8E39EC7DE9ADDE9ABD9E1A5CFDB9BCEE29D
D0EAA1C7E59BC6E89BD4F9A9C0E597B9D98DE2FCB5D4E7A5DCE8AAD5DAA0A3A36F929963
D1E9AFBBD399777B49060600E5EFBA909D65595E26D5E0A4BEE29CC9E9A0E2E2A2948A4C
D2D590DDEDA2CFE897CBE695DEF3A8D3E4A0BFCC969FA77EA4A891FAFAEEFFFDFAFFFDFF
FFFCFEFFFEFDFEFDF9FFFFFBFCFEF9F7FCF6FBFFFBF3FBF0F5FFE95B684AF9FFE4D4E5BB
D6E8B8B4C78FD4EAAAC9E09C8DA75EDCF8ADCAE69BC6E599D7F3A9B5D389D2F0A8C0DC91
C4DD8CD5F2A0CCF5A7B8E29AC7E7A8E7F1BCA4875B715724D7E49CCAEA95CEEA93CAE68F
C6E391D2ECA2D7EAAACBD5A095966E67613FEADFC3FFFEE4F8EAD0E0D5B7EFE9C5252700
8A985DC9E09ACEEA9DC7E897CFF09FC9E89ACFEBA0CFE9A0D1EBA2CFE9A0CCE89ECBEA9E
CDEDA1CDF0A0CAEF9FC7EE9BC3EA97C3EA97C5EA9AC7EA9AC9E89ACAE99BCCE89DCAE99D
C9EB9FC5E59ACEEAA0D1E79FDBE7A59EA46658561BA9A26B
C9C1BED3D0C9DFE8D7C0D9BC3764398EBA897D9563DFE9B4D3D69DE7F0B1C9E39CC5E399
D0E49D94A45D7E924B9AB068D4ECA2BFDE92CCF1A3CFF8AAB9E598648E4490B46CA9C683
CCDF9FDBE7A9D2DA9ED5E1A3D6E9A7CBE6A1C8EEA5C4ECA5C8EBA9D1EBAED7E7A9ADB377
9D995C605A1C9E9D5CD6DD9ACCE09BC5E2A0CBEAAECEEBB580956AFCFFE4F9F7E0D5DBB7
D1F0ACBCE891C2EA92D4F7A7C6E2A7A9BD8CC4D1A3FEFFE40B08030B0207FFFAF8FFFCF8
D6C7CAB0A0A1C9BBB0FFFFE7CCD8B2D5EBBCE4FBC7DCF3BBCCE4A6C8E19FD0EBA4C7E398
D2EEA1C3DF92C7E698CEEDA1C7E59BCDEBA3D5F3ADCEE7A3CFE2A0D4E5A1D5E9A4D2E9A1
CCEAA0C9E99DC4E999C0E595C4E99BCDEFA3C6E19ACEE3A0D9E7AA878F56E6E9B4D9E2AD
CBE2AAD9EEB66F71426F6D3DD6DEAB9CA6714A4F19DBE6ACD1F4B0CAE5A2D7D195574B0F
D9E39ECEE69ACEEB9BCAE69BDFF2B2EAF7C1F4FDD2DCE1C19D9E8CFFFEF7F5EFEFFFFDFF
FFFAFEFFFEFFFFFCFBFFFFFDFBFDFAF6FBF7FBFFFDFAFFF9ADB8A72E3A22F8FFE7D6E1BF
CFDBB3D8E8B7D5E6AFB1C787ADC682C8E49AC3E197D6F4AAB9D78FD4F2AAD3F1A9C8E69C
D3F09EC3E591BDE697C6EFA3CEEBA9D3DBA2AF9364BEA56FD6E29ACFEA99D3E695CEDF8F
D5E79BE1F2ABBFCB8D7E8951515A2B979E75F6F7D5F7F6D8FFFFE4E4E1C2C9C9A59EA476
505E23AFC57DCBE697CCEC97D0F09DC6E595CDE99ECCE89DCCE69CCCE69CCBE79CC9E89C
C8E99AC6E999C6E999C4E999C7EC9CC6EB9BC6EB9DC8EA9DC9E99DCAE99DC9E79DC9E79D
C7E59BCEEDA1CFE9A0CBE199D9EAA66C78364F5517BCC083
FFFBF4FFF8EFC4C1B2BEC6AE7C9170254118738F5FCCE9B3C4E2A6CBEBACC8EDA8BBE09A
D5F4AEC6E19CAAC37F91AA668AA35F67803C6F8A47637D3E859E648DA46C83976495A574
939F6F8A9261848B58979E688A9257848E4FDEEAA8CDE3A2C7EFB0BCE4A8CFE4ABDEE3AD
ECE0AC7B673272632A857F43D2DC9DDEF4B3C2E0A2C0DFA6B4CC9CD1DDB7FBFCDDDADEB9
D6EEB0C7E79CCAE89ECDE8A3BBD399D2E6B5F9FFDFF5FFE400020009090BFAF8FBFCF7FD
FFFCFFFFFAFEFFFEFBF9FEEACAE6B3BFE6A3C7ECA7C9EFA6C5E99FD5F7AABCDD8ED0F1A0
C7E696CAE999D0EFA1BFDE92CEECA2BFDD95C6E59FCAE9A3C9E99ECCECA0CAEC9FC9EE9E
C9F09FBFE695BDE493CAF1A0C5EA9CC9EB9FD9F4AFC5DB9A49581DE3EEB6E3ECB7D1DBA7
CDDEAADDEEBA646A3C595B2CD7D9AA808354C5C997C4D19BC9E7A9D9EDB0A3915F675320
DBEAA9BFDF96C6EAA0D3F0B0F9FFDFFEFFEBF7F8E6FFFFF3E5E2DDF8F2F2FFFDFFFEF4FC
FFF8FFFFFDFFF3EEF2FFFFFFFEFFFFF6FBF7FBFFFDF3FAF27984746E7A64FCFFECD9E0C1
DAE0BCDEE5B9A1AE79728448D4EAA9CCE7A0C8E89DCCECA1CBEBA0C7E59BC7E399C6E599
CCF29DBFEA91C3ED97C6EC99CAE49AD8DD9BAF945FA78E58D8E39FCAE098E4E9A7E2E1A1
A8A86C424307585B2288955DC5DEA7C9E7B5C9E2B8E3F9D3EEFDDED5E3C2D3DEB6D8E4B4
92A264687C34ABC272CEE793CDE897DAF6A9CBE69FC8E39ECCE69FD0EAA3CBE69FC4DF98
C9E79FD6F4ACD1F1A8C0E298CDEFA5C2E69CCBEFA5C7EBA1C7EBA1CDF1A7C3E79DC7E79E
C3DD93E0F6ABCFE59CCAE298A1B96F546C22CCE49ACAE298
FFFAF3FFF2E8FFFEEFD3D2BDA7B093869773597447C1E3B0C4EBB2C0EAABB9E3A3C5EEAC
CEF3B0CFF2AEC5E4A1C3E09DC4DF9ACAE39FCDE6A5CEE6AAD1E8B0D0E4B1D7EABCD1E4B7
CEE0B6DAEDC0A5B88A899B699EB17A788B5383975C8AA66B82AF74BDEAAFDFF8C1CAD19D
ECE0AEC5B17EA79660413800BDC385C7DA9AD1EDB0C1DEA4CFE7B5A6B58AF5F9D6DFE4BC
C9DBA1CCE39FCFE5A4D6EAABE4F8BDABBB8AC4D0AAF6FFE7000200000100FFFEFFFFFEFF
FFFEFFFCF7FBFFFEFDFCFFEFC9E6AED7FDB2BDE295C5E79BCEEEA2C3E294C3DE8FD1E99B
D1E89ACEE499CBE196C8DE95DBF1A9D5EAA5D1E6A3CDE6A2D1EFA5C7E79BC1E494C2E595
C5E898CAED9DCDEDA1CAEA9ED7F3A9BFD992C8DB9BDEECAF454E17E1E8B4E9EBBAE8EBBC
CAD6A4D9E5B56F7547282900E9E6BB868557D4D6A7E8F5C0C6E2A7D9E8AF6D55277E6334
DDEBADB8D992CBEFA7BEDAA0F6FFE4FFFFF4FEFAF1F7F2ECC8C0BEFFFCFDEADFE3FFFCFF
FFFBFFEAE3EAFFFDFFFAF8FBF1EFF0FEFFFDF4F6F1FCFFFA828A7D939A8AFFFFEFE9EBD3
EBEACBE0E0BAA0A6766B763ECEE1A1C9E39CC5E39BC7E79CCEECA2D4F0A6D4EEA5D1EDA2
B8E08ABEEA91D0F8A2C7E897D1E69BDCDD9B9E804A705520DBE4A5DDEDACD0CB93A29560
776D386C6730A6A76EC6D499CCEAAEC5EBB0C4E4B3E6FFD8F4FFE4DDEDC9CFDBB3CDD7A5
AAB678626F29728033D7E898DAEFA2BBD189C3D999D7F0AFCEE7A5CBE6A1CFEAA5D2F0AA
CDE8A3BEDC96BCDB95C6E59FC8E9A2B8D992C9EDA5C8ECA4BBE198C6ECA3C9EFA6CAEAA1
D2E69FC6D38DD7E7A0CEE29A9AB067647E34C7E398D3F2A6
FFEEE7EBDDD4FFFEF1FFFFEDF9FFE7E2F1D092A97F4461319DC08AC7EDB4CAF0B5C4EAAD
A9D091C9EDAFC7E9ACCAE9A6D9F7ADB9D588DAF8AEC0DF99BEDE9DDEFFC4B6D9A1A8CE9B
8FB7854A754771A1718BBD8C75A97891C795BDF3C173A9757BAE755D894E8FAA73CEDBA5
D4D19EF1E7B2E2D9A28B894E545C20A2B476C6DEA0D1EAB1D7EBB8C8D8ABAAB08AEDF2C9
F3FFC6D2E2A1DBEBAAD5E3A5D2E0A5DEEAB8BCC49DCFD5B90203000C0C04FAF6F3FFFDFC
FEFAF7FFFBF5FFFFF4FAFDE2D0DFA8C7DB94DBEFA8D0E19BD6E39EE6F1ACDBE29EDCE19E
757A38C9CB8AD4D695A0A261949657CDD292E1E6A6CFD595CFDB99D2E19CE2F1ACE0EFAA
CEDF98D1E29BD7E6A1C8D794CDD798DAE2A6DEE1A8ECEBB5524C1CFFFFD4FFFED4CCC599
E6ECBCC3CD9B737949FFFFD2938F62E6E4B4DCDBABC1CB96D5EDB3CAD59D6A4D21A18254
E1E9ADD6F4AECAE8A2D4E9B0FFFFE4FCF9E8FFFFF1F7F1E59A918AFFFCFAFFFBFBFEF2F4
FEF2F6FFFBFFFFFCFFFFFDFFFFFDFFF9F8F6FFFEFA2D2E28656660F4F4EAFFFFF0FFFFEC
F3ECD0E0DAB88E8D61D9E0AAD5E3A5DAEFAAD8F2ABCCE89EC5DF96C9E098CDE39BCCE49A
CCED9EC6E999CEEDA1BED68CDDEAA5F0EAACB1905D735523D3D99B919F61625D268D804C
C6BC87E8E3ACE5E6ADCCD79BCBE4A2CBE8A8CBE2ACE7F9C9EFFBD3D4DAB4D6D9AEE5E7B6
EAEBB1B2B4737A8038636B226C7532DBE5A6EBF6BECCDBA2D1EAA8C7E59FC7E59FCBEAA4
C8E6A0C2E19BCDECA6DFFFB9D1F2ABC1E29BD3F7AFCEF2AABBDF97C3E79FC7EBA3C9E49F
D6E19FEFF1B2D1D797666F2E838F4DC0D18DDDF2ADC7DE98
E5D8CFFFF9EDF4EEDEFFFFEDF0F6DCCDDBBACCDEB859734696B482CFF0BBC7EAB2B3D9A0
D0F6BBCBF1B6B2D89DCCEEB2CDE7A8D5EBABCDE5A7D2ECAFC4E0A698B77EB3D49F709561
86AE7A598351689665457746396B3A699D6CABE1AFBBEDBAA2C8955C7943738551D9E2AD
F1EFBCC0B985FDF4BDB1AC744F50164C5117DAE5ABD5DFAACDD5A4FFFFDACCCDA5FFFFD5
FFFFCFD3DD9EE1EBACC8D295D3DDA1DDE6B1CCD2A6CCD0AF030200040100FFFBF0FFFFF4
F0ECE0FFFFEFFFFFECFFFFDFD5DAA0E4EEA9DCE3A0EAEFADD7D799CBC98CEAE6A9958F55
C3BA81EEE5ACE6DBA3CEC58CB5AC71C8BF84B2AC70A39F62A6A76B92985A94985B959B5B
9BA161CAD090ECF1B1DADEA1E5E6ACE6E3ACD4CE9ADFD5A45E5023F8E7BCF8E2BDE7D9B2
DDE0B19EA876929566FFFFD2A9A576E9E5B5E7E7B5E2EBB4CFE7ABDEE7AE664518BC9A6C
DDE1A4BAD18DD8F2ABCCDEA2E0E4BFFFFDE4F7F1DBD7CEBDB7ADA1FDF0E8FFFCF6FFFBF8
FFFBFAFBEFEFFFF5F7FFFBFCFFFAFBF9F4F1CCC8C546423FBFBAB7FFFCFAF8EBE3FFF1E4
FFFDE8C5BA9AA5A076DDE0ABD5DFA3D5E6A2CDE29DC4DB93CCE29ADBEFA8DCEDA7CEE29D
D1E8A2CAE49DD9F0AACADB97E5EBADE8DBA4A781526E4C1EB9BD827F8B4D656029B4A874
DAD39DE1E0A8DADFA5E3EDB0D8E7A2D9E8A5D7E2A6F4FBC7FEFDD1DFDAB0DDD4A9EAE0AF
E8DDA7DFD598C1B97A585313252000B3B07BCECC9CDEE2B0CDDB9ED0E3A1D1E4A2CFE2A0
D2E5A3D5E8A6CADF9CBBD08DCBE09DCADF9CD0E5A2C8DD9ACEE3A0D5EAA7CEE3A0E1EDAD
E0DBA3C7BC86A59C65746F37B6B57CE2E6ABD7E1A4D1DD9F
AFA999E6E0D0D6D3C0A7A993B4B89DA9B39184926E94A67C52693B000E004F6F3D86A973
8AB17A5881499BC38E6283546273511821060F180029321388926F929E78A6B3885B683C
8592647E8E5D6A7B474758228A9B658A9B644D5E2752602D040D002329003C3D11545021
5D5224A597665F4F1C645420A2925E5A4A1751431261532466592CD7CAA05F50299F9467
6D6C34A4A86B7D82425B5F22AFB3787A7D46A8AA7B70704A080700070200332E1AB0AB97
B5B196CCC9AAEFECC9868557A3A566989B56A9AA689F9F61A7A268A49D666D632E665A28
9A8C5BBEB07FCDC08CE3D6A1DCCF98DBD196BDB378B6B07496955CA8AC71BEBF85979B5E
585C1F6064279091559D9D6197955CAAA56E9D9662998D5D645629BFAE83B39D78AFA17A
93996988925E6B6F3DA7A775666232BBB8859E9E6AD0D9A0B4CA8A91995D674517775323
99995D9DB06E859A559BAB6D9EA174A6A27FAEA78AB6AF937A6F59B7AA999C8E81F7E9E0
F0E1DACFC0BDD4C4C4CEC0BFF1E6E4EDE3E26E6664BEB4B5E2D6DAD1C1C4B8A4A3D0BCB5
B7A493A8977BBDB48B8D8B58D6DBA1BFCB899DB16C90A45D9EAF69A8B772919D5B6E7A3A
78884A83935599A76A929C60B1B078CDBB899E7349724D20424309606C2E757038918851
74723975793E8A9457A7B2707C823C7E7E38858142C3BA83F4E6B7E8D5AAD2BB8FBEA676
B19A66E4CD97E9D39AB9A46D614D1B77653755421A342500786E397D793C878346979356
B5AF73D6D094EBE5A9F1EBAFE1DB9FF7F1B5ECE6AAD9D397EBE5A9CEC88C938D51A3965F
AD92635D3E1294774BF3DBADF1DFAFCFC190ECE5B1F0EAB6
F2F2DAFFFFE9FFFFE8E6E9CCFFFFE4FEFFE1C9D5ADD2E1B6D8EBBD6179490016005E814B
4B723B89B47E58854E567C4D0009000A1602F2FEE6F5FFE4FBFFE4E8F3CBB6BF94E3EBBC
D2D9A6D1D5A2EFF2BDD9DCA7E0E0ACE2E0ADE0DEABE9E7B798976B76744BA9AA7EA4A675
4D4D1BDEDCA9DFD9A5E4DAA5AEA16D685624B2A06ED9C797F3E2B4DCCEA1EFE2B6CEC695
8A8951AAAB6FDDDFA0D7D99ACDCE92E5E8AFC1C18DE0E1B50404000A0A00A7A6873C3C1A
E3E4BCDBDCB0D1D3A1AEB2774F5612DAE2999DA460585D1D908F56C2BF8A857F4D605829
A29A6CD6CE9FECE4B5E6DFABDAD39CE2DDA3DDD99CDADA9CD4DA9ED3DDA0DEE6AADAE4A5
CFD899D3DC9BC7D091A5AB6D5B5F22B8B97FEAE9B1D2CF9AB9B381DCD4A5DCD1A4E6E2B3
D9E3AFC9D8A1DCE5B0E2E5B0868451E3E2ACDEE1AACED99DDAF3B1CBD5967E5E2DA37F4F
DEDEA2CDE09EDCF0ABCBD99BDCE0ADD0CFA1D1CFA6EEEAC5E1DBBB5B5136E2D6C0FCEFDE
FFF6E9FFF6EDFFFBF6FFF9F6F9EEEAFFFCFA070000FFF5F7FFF0FAFFF8FFFDE7EAFFF8F4
BDA698FFF1D7FFFDD7E3E0ADDDE2A8D8E4A4D0E19DCADE97D2E39FDCEBAADCE6A9D2DCA0
DFEAB2E1ECB4DAE3ACD1D6A0DEDBA6FFEABBAD80576B4619A3A76CC2D190D8D89CEAE5AB
E1E2A6DEE8A9DCECABCFE09AE4F0A6DEE69BCACD8AD7D799DFDAA2BAB07B8F834F6E612C
A5965F83743BC0B47A655A22524612C6BC8B585022605829675E275B521759501560571C
5C5217554B10695F24887C4265591F6C60264536002718004F400755460D3E2F006C5823
624617A18256C0A379927A4C6752259B8B5AB7AB7B483E0B
E0E7C5E6EDCBEDF3CFF5FBD5E7EEC5E5EEC3F3FCCFD7E5B4CADCAABBD29CD0EBB6BADBA4
C2E9B0A7D29ABDEDB3BCE8B3DBFFD4D4F4CBE1FFD4DDFACAE6FFCDDAF6BCD5EDB1CEE2A5
D3E2A7D3DEA6D7E0ABCACE9CE0E1B5D6D4ABD3CFAADEDCB6D8DDB4D1DDAF94A6746D844E
A3BC832E470DC6DBA0DAE9AECBD39AB0B1786D6A33938E57D6D59FD8DBA4EAF1BBCDD59C
DBE1A5A7AB6E515616EEF3B1D8DD9DE2E8AADBDEA5B4B885A6A97CDEE1B6CDD0A55E6134
979E6AE9F1B6B6BF7EDDEAA2CFE495E3FAAACCE196C2D38FDFEDB0E2EDB5707845DBE1B1
DFE5B7D5DBABD0D6A6D1DAA5E0E9B0D6E0A3D6E2A0E0EFACCFE4A1CDE6A4CDE3A2C7E09C
CEE59FD9F0A8D8EFA9CDE29DA6BB76859954859554ABBB7CD6E4A7DDE8AECAD59DCEDBA3
CDE0A8D4E7AFD6E3ABC5CE958A8F57DDE2A8D3DDA0D6E9A7C8E6A0AEBD7A6F511D92723F
D9DA9ED9EEABCCE19ED2E2A1D9E4A8E1E9B0D7DCA6E6E8B7C9C89CC1BD975E5838F7F0D4
FFFBE7FFFEEFFFFDF3F2E9E0FFFDF8574F4C7E7674FFFBFFFFF5FFFFF7FFFFF7FFCFB7B5
F3DDD0FFF0D6F7EEC7DEDCA9D2DA9FD9E8A7DFF3AED8EDA8CBDE9CC8D89AD4DFA5E0E9B2
CED6A3D0D7A4CFD6A3E7E9B7CCC996D1BD8B7F54296C4A1ADEE4A4D4E9A4D7DE9BDCDE9D
D8E39FC4D58FC9E39AC0E094BDE292CDF2A2C6E89CCBEBA2D4EFAACEE7A5D3E9A8D2E7A4
C1D590DAEEA9C4D994DCF3ADD5EBAAC8E1A0DBF5B6CAE0A2D3DF9FD2DB9ADEE4A4E6ECAC
CED393A4A9699297579C9E5F9496579D9F60A0A0629C9C5EB1AF72AEAC6F908E519C975D
ADA06CAF9F6C9D8F5EA29662A29B679390599D9C66ADAE75
B4C193CAD6A8D3DFAFD4DEACD4DEAAD4DEA9D7E1ACD3E0AAD8EAB0D3E8ADCEE7ADCDECB0
C2E8ABBAE3A7B9E7A9C5F1B6EBFFDCEEFFDAC1E0A7C9E8ACC4E2A2C5E2A0AAC5808BA25E
90A5628A9A5BA2B075AFB985B4BC8D939A70868A676B6F4AC0C59C858E5FB6C894CFEAB3
A7C98D74985BCCEBAFC6E0A3D6E5ACEDF5BCADAD7777763E7E7F469A9F65D5DFA3DAE5A9
D8E0A4DDE3A3E3E9A98F98558E9754DDE6A5D8E0A4D7E0A7CED7A2D7DFACDAE2AFD5E0A8
B5C183ABB872E5F3A6CBE18FCEEB97C3E591C3E294DFFAB3C5DE9DD2E7AE859763D9E9B8
CCDCADF8FFD7F9FFD8CBDEA7C8DCA1CDE3A3D9F0ACC4DF98C7E6A0D0F1AACCEDA6C4E69C
C7E99DC7E99CC5E599C7E79BCDECA0C0DF93CDE99FD5F1A7C6E19AC8E39ECEE7A5D3ECAB
D4EEB1BFD79BE1F3B9D3E1A6B5BF83D0DC9ED5E4A3D1E8A2C7EBA1D0E49F634C16AD925D
E5EBADC7DE9AD5EBAAD2E7A4C7DB96DAEBA7D2E1A0D2DDA1E2EBB4D3D6A7A0A177B7B491
F6F2D5FFFDE7E8E2D2DBD7CB89857C68635DFFFCF7FBF2F5FFF9FFFEE9F8FFF8FFD4C0BF
FFF8EAFFFEE3FFFFD9FFFFD3D9E7AACFE2A0CBE29ECFE8A6D5EBADD4E5AED4E1ACD5DFAD
E1E9BAD8E0AFD1D7A7E3E5B3827F4C73612F7A5125F0D29ED0DB97CEE89EDBE8A2D4DE97
DBECA5C8E298D7F9ACC6EFA1BAE699CBF7ACBFE9A1BDE59EC6EBA5C5E9A3CAEBA4C3E29C
D1F0AACFEFA6CDEDA4C3E59BC5E99FCAEEA4C7EDA2C4E69CCCE69FCFE49FCFE49FCFE49F
D1E5A0D3E7A2D4E5A1D2E39FE0EFACCEDD9AD9E5A3D2DE9CCBD694D8E3A1D9E4A2DAE5A3
D1DB9CD0DA9DDEEAACDCE8AACCDA9CD6E6A7D4E4A5CEDE9F
6D7F458B9D61728146C8D699E4F2B5CCDA9CD3E1A3DBEAA9D0E3A1C0D793D0EBA8C5E5A2
BBE09DCAF3AFC6F3B0C3E7A9E9FAC4E6EEBBD2DDA5DBE6AADCEBAAD2E19C96A760AFC079
D5E9A1D0E49DCCE19ECDE1A2CCE1A8CDE1ACCFE5B6DAE7BBBEBB90827B4F747846D7E5B0
C9E0A80723005B743BD0E3ABD9E2ABD3D39DE7E0ACCFC38F605621554E17E7E5ACD7D89E
DAE3A4CDD997E2EEACCBDA9590A059B8C782CFDE9DD4E4A6D3E2A9D0DFA6CFDEA5D2E5A5
D2E69F8CA154DCF29DC9E38CC3E58FC5EB98D5F7AAC5E59CC9E6A4CDE7AA839C65C7DEAA
D0E6B5F5FFD8ECFFCFD1EAB1C9E5A8C5E3A3C8E7A3CBECA5C5E9A1C3E99ED1F5ABC3E89B
C1E698D2F7A7C8EB99C7EA98C1E492C8EB99CAED9DC5E898C3E598C8EA9ECDEFA3CDEEA7
CFEDADBCD89BCBE3A7D3E7AACBDB9DCEE1A1D5EAA7CAE8A0C0EA9EC4E096A19058A48F58
D2DE9EDEFBB8C1DB9ACAE5A2D3EDA3C4DF92D1E8A0D3E8A3C8DB9BDDEAB2D5DFAD9AA177
DDE1BEFFFFE6F5F7E1D4D5C5707064EDEEE6F2F3EDFFFDFEFFFAFFFBEDFCFFFAFFC2B4B1
FFFEECFEF9DBFFFFDAF6FFCBCEE2A3CDE6A4D1EEACBBD898D2EBB2CDE1AECCD9AEDEE9BF
D8E1B6CBD4A7D9E1B0B7BE8B777743D4C7936D4919EAD19BCCDD96CCED9ED4E99EDBEBA0
DBF3A7C4E596B5DF8DC6F0A4C5E5A6CAE6ACCDE9AED0EAADC3DB9FCEE4A4D8EEADC9DE9B
D3E8A5D0E5A0CBE09BD2E9A1CFE79DC9E497D6F1A2C9E696C7E79BC4E499C5E59ACAEA9F
CEECA2CCEAA0CCE89ECDE99FCDE79ECDE79ECFE69ECFE69ED0E69ED0E69ED0E69ECCE89E
BAE395CBFAAAB9E596BCE899CEF9AABFEA9BBCE597C8F1A3
CDE29FCEE39EDEF2AD9AAE6772833D65762FE6F7B0C8D992E1F5ADCFE79DD0EAA1CDEDA4
D9FBB1BAE097C4ECA5BFDF9ECCDAA5E4EBB8E0E9B4D0DA9EC7D39392A15C697B31D2E79A
C9E092CDE899D2EDA0D1EDA3D0EEA8CEEDA9C6E6A5C4D99ECFD29DE7E3B3D3D7A4B7C68F
8AA36A2B4A0F0013007C985ED4E7AFCCD9A1C7CC96E2E1ABAFAC7559571E747237C9CD90
D4E0A0D7E8A4CBDF9AD1E59ED5E9A1BFD38C495D184C6120D6E8ACDBEFB4D4E8ABC1D693
D0E69D849B49718931C7E48AC8EA94CCEF9FB7D78BD2F0A8C4DF9CD5EFB091A96FCCE3AD
C9DDA8F6FFD5F5FFD6CDE6ADC9E2A8C5E1A4CDEBABC7E6A3CDEEA9BCDD96C2E299C6E69B
D8F8ACB3D284CAE999C8E895D0F09DD0F09DCCEB9BC7E897CBEC9DCDF0A0C6E89BBADC92
C1E1A06482465C7639EAFFC2778B4CD5EAA7CCE5A1C1E59BCDFCACB9D990E1D59B7B6A34
C5D395CBEAA7CAE8A8D3F2AECCED9EC4E692CBEC9DCEEA9FC6DF9BD5E9AAD2E3ACAEBC8B
CCD4ADFEFFE4E6ECD2CFD4C02E3224FEFFF8FEFFFBFFFFFFFFFCFFFFFBFFFFFCFFFFFAF2
B0AB97FFFFE1D7E0B1D2E4AAD0E8AAC5E4A1CCECADC6E5AAF2FFDCF5FFE1F5FFE2FBFFE6
FBFFE1EAF5CBC9D4A9C4CC9D4345145549176A4A1BF7E0AAD9EDA6BEE093CCE299CCE196
B8D487C9EEA0D7FFB3C0EAA2D2EEBBD2E8BADFF5C4EDFFCCE8FDC5D7EBB0C9DD9ED4E8A9
D0E3A3C5D898E1F6B3CAE098CFE59AD8F1A0CBE490C4E08CD7F8A9CAEFA2C6E89CC7E99D
C8EA9EC6E89CC6E69BC7E79CCAE89ECAE89ECCE89ECCE89ECDE79ECDE79ECDE79EC8EA9E
CBFFACB3ED96B3ED98C3F9A3B4E895C0F09CD4FFB0AFDA88
DCF4AABAD288D9EFA6CAE095B1C87AD5EC9C3D5404D3EA9AB8CF7FD9F1A3D5F0A1B9D588
D4F3A7BCDC91DAFCB2C6E5A2CAE2AED4ECBAB3CB97C9E2A9E5FFC033510B98B66CD0EFA1
CCEE9ACEF099C8EA93BEE089BEE089C7EB93CBEF97C9E898E3F6B4BBCA8FD2E8AAC5E5A6
B8E0A1C0F1B0BEF2B077AB69B0E1A0D2FFBED9FDBDC3E1A1D6ECACDFF2B2758443808F4C
D2E5A3CEE59FD1E6A1D5EBA3C7DD94E5FBB3B9CE89CBE1A07F9356C7DCA1CAE0A2D9EFAE
D6EDA5D8F1A08AA44DDAF49DCFE897D9F1A7CCE39BD0E5A0E0F3B1D0E0A15F6D32DFECB4
E1EEB8FBFFD2FBFFD3D0E1AAD0E1ABD0E3ABD4E9B0CCE1A6C9DDA0D7E9ABE1F1B2CDDD9C
DCEDA9DBEAA5D4E49BD4E499D1E397C8DA8EC9DE91D4E99CD0E69BC4DC90CDE59BE2FCB5
D9F5B8BFDBA0000E00BBD193D6EAABD3EAA6D2EDA8C4EA9FB1E293DAFCB2D9CE96796935
CFDEA3C6E6A7C3E2A6C2E29FC4EB9AC5ED97C9EF9CC9EC9CC8E69ECEE7A5D2E8AAD0E2AE
A2AF84E8F4D0F5FEE3CFD7C23A4032B9BFB5F4F9F3FCFFFFF9F8FEFAF7FEFFFEFDFFFFF4
B6B69ED1D7B1D6E4B1D0E5AAC8E5A5BCDF9FCAEEB1CAEAB8F2FFE3F5FFEAF9FFEFF8FFEC
E7F2D4F4FFDCD3DFB9ECF4CBA8AB8073683B64431AE7D1A0D3E8A7BFE399DCF1ACE4F8B3
C7E19AC0E19AC7F1A7BDE5A6B5D4A8C2DCB5E2FDD2F1FFDBE4FFC8C2DBA1BFD99CDAF4B5
CAE4A7D6F0B1B8D291D7F2ADC3DF94C3E390CEEF96D3F49DB8D789D0EEA4DBF7ADCAE69C
C1DD93CCE89ED3EDA4CDE79ECDE79ECDE79ECFE69ECFE69ECFE69ECFE69ECFE69ECAE99D
B9E492B2E48DB5E28FCAF6A1C9EE9EC3E493D5F1A4D3EE9F
CDE599C8E094D8F0A4C8E394E1FCABCEEA96E4FFAC5B772287A34FBEDA86C4DF8EA1BC6D
B5D083B0CB7EC0D88ECAE39FC6E3A3CCEAAED3F1B3C7E4A484A15EB8D38EC5DF96C5DD93
C8E094CDE496D3E899D6E998D6E797D6E797D8E697D6E799C4D58FEDFFC0DCF2B2B6D494
DCFFC0B2DF9EBDF1B1C1FCBA5A9553A2DD99A2D592C6F0AEC0E09DCAE09FD9E5A57B8745
3F5411A8C27BDCF3ADD2E9A1C5DD93D5ECA4D1E8A4CDE1A2AFC3885F723AA8BC81D3E7A8
C9DE99DBF2A49CB460869E4AC9DE93DEF2ABCFE09AC8D792D4E09EDFEBA9D9E3A4566023
D3DDA1D6DFA6D4DFA7D1DEA8DDEAB5FAFFD5F9FFD6FBFFD6F0FAC6CAD39EA5AC76B7BC84
8F945A999F61888D4DAEB572DCE39FD9E39EDBE6A1DFECA6E0EDA7D8E7A2CCDD97C2D593
C8E0A6C2D9A1CFE2AA0416009AAC6EA0B574B9D48FCDF1A7C1F2A3C9EAA3E0D59F6A5826
FBFFD1E7FFCABAD79DCCECABBFE899C8F29CC8EF9CC5EA9ACBEBA0C9E49FD4EAACEFFFCB
ADBD90F3FFDBF1FADDD2DAC5999D8F858881FCFFFDFCFFFFFEFFFFFEFFFFFFFFFAF2F5E4
FFFFE6808B61D7EAB3CAE2A6CCEAAACCEEB1E8FFD5E3FFD6F2FFECF7FFF3F8FFF7FCFFF8
FBFFF1FBFFECF5FFE2F0F7D6FFFFE1EFE2BF6D4A2AB49B73CEE0A6D3F1B3C6D89CC2D095
D9EDB2D3EFB2BFE3A5CBEEB8ECFFE0F5FFE8F5FFE3F4FFDCDDF4BECBE3A9ECFFC8C1D99F
CBE0A8D0E7AFD1E6AECBE3A7CBE29ED3EDA3C7E38FC9E692D9F8AABEDE93B6D68BCCECA1
D8F8ADCCECA1C5E399CCEAA0CAE89ECAE89ECAE89ECAE89ECAE89ECAE89ECAE89EC9E99D
C6E999D9FCACD4F3A5D1EDA0D4EA9FD2E49ACEDA92B0BA73
D6EEA4DBF3A7C2DD90CBE898C5E592CBEB96B8DA84CDEF99BFE18BC9E994D3F09ED7EFA1
D7ECA1C8DA9097A760D6E89ED7EE9CC6DF8BD0E795D4E99A7A8A3FD9E59DD5DA98EAEAAC
D6D197E8DFA8F5E5B2DFCA9BA38D5E6D52275E4117665220575518515717949A5CDFE9AD
C6D59AD8F0B6B8D9A0B6E2A795C98B79B06FC9FCBACCF4B5BED698E7F1B4E5DFA59A9659
5D6C2B94AB65BFD690CAE199C1D78FD0E5A0E4F9B85C6E32000B00CDDEA892A06BD1E0A7
D1DFA1DAE9A4C9D98EA3B569D4E59FC1D190E7F6B3D7E6A1D4E19BD4DF9AC4CE8956601B
D1DC98DCE6A7DBE6AADDEAB2CEDBA6FBFFD8EDFDD0F4FFD4E7ECC3EBECC2636236646335
797747D7D5A2E3E0AB57561E99985FCDCE92E7EBAED1DA9BC7D091DAE4A7E3EFB1D5E3A8
C3D19CE6F4C1CEDBA5000A006671374E5C1E93A865D2F2A9BCEA9FD3F1AB6B5B27B6A172
EFFCC6E4FFC7D8F3BECBE9ADC0E699CAF4A0C7EE9BC7E99CCEECA2C8E19DD5E9ACF9FFD4
6E7A4CE2ECC7E6ECD0D1D6C26B6D60000100F6F6F4FEFEFFFEFFFFFEFFFDEEF0E3FFFFEC
FFFFE396A274D0E3ABD1E9ABC8E6A8CFEEB3EEFFDDF1FFE6F5FFF3F9FFF9FFFEFFFFFEFF
FEFFFBECF2E4FCFFF1FFFFEDFFFFEAFFFCE4734A36634428949D72CCE2B1E2E9BDD5D8AD
DFE8BDD3E4B8BBD5A8CAE0B9E1E7CBFCFCE2F7FBD8FFFFDCF5FCC9D9E2ADCCD39F000800
0208005C63394F542B535B2C616834232D00C8D38FD9EEA3C2E799CAF7A6CCF9A8C0ED9C
BAE796C1EE9DC4F1A0BFEC9BC1EE9DC1EE9DC1EE9DC1EE9DBFEE9DBFEE9DBFEE9DC3EC9D
CDE79ED0E19BD6E39ECCD592BFC482EAEAAAE2DC9E675F21
BFD68ECDE49CD7F3A8C7E698C2E394CAF09DC3E994D7FFA9CBF19CC4E692CBE898D3EB9F
D3E39AD5E09B737A369BA55CD3E790CFE68CD9ED9894A5559BA75DE2E9A6E2E3A7DBD8A1
857D4C5F52253E2D02442E05654C24886C45A2845EAC9667AAA6696D702D5C5C1E94935A
A2A56ECEDBA5DDF6BFBAE1A880B4767DB878BBF3B2AFDC9BD0E8AAE2E8ACB4A56E695A21
4A5415C1D693D1E6A1D2E8A0EBFFB8C4D893BDCD8F88975E000C00D6E2B2767F50E6EEBB
D7E0A9D5DFA0EDF7B2A9B670566927CDE2A1CEE19FC6DA93D4E69CD1E196EDFEB0CCDD8F
8F9F54B6C780D9E9A8D7E9ADC3D5A1F7FFDAF7FFDFF9FFE1F9FFDDEFEFCD89896735330D
7D795338350A090600E0DEADD4D29FAEB17C7E834D5057212A33001A270034430A5A6731
6E7846929868797D4B40430E3E410A9BA367CBDB9ACDE8A1C6F0A67994516E5A28D1B98B
DAE2AFD9F2BBEDFFD2C3DFA5C3E79DCBF2A1C7EC9CC9E99DD0EBA4CBE29ED4E6AAF7FFD0
B9C297D6DCB8FEFFE6FFFFEFB9B6AD030000FFFEFFFFFEFFFDFFFEEFF2EBF4F6E8FFFFEA
D8DEB8D4E0B0C6D89ED0E8AAC8E4A7C5E2AAECFFDAEEFFE6F8FFF8FBFCFFFFFAFFFDF4FF
FAF9FEFBFDFAF8F9F3F8F5ECFFFBF0FFF9EDF2C3BBFFF5E65A5B3C707E5ABEBD9EFEF9DC
FFFFE6F7FDE1F6FFE6F8FFEAFFFFEAFFFFE6EAECC7DCE2B4D2D9A5D1DAA3E3ECB70E1600
0007009EA480BFC5A3B2B8948E956B919966ACB57C8E9E5D84A459B2DB8CD0F9AAC1EA9B
B8E192C9F4A4CDF8A8BDE898C2ED9DC1EE9DC1EE9DC1EE9DBFEE9DBFEE9DBFEE9DC5EB9E
DAF1ABD5E4A3D5E1A1E6EFB0E4E8ABE3E3A7D9D49AA39D63
DAEFACCFE6A2D0EBA4C7E79CC6EB9EC1EA9BCEF8A6ACD682C3EA97CDF0A0D1EDA0C9DF96
D4E19BE7EEAB999B5A969B59D6E69DCBE196637931CBE09DCADE9FC1D399D9E7B2CDDBA8
4B59268B9966CAD7A2DEE9B1D2DDA1CBD799D3DF9DDBE8A3D2DC95DFE6A0D1D191A4A468
83844B848F57CBE6AFBEEAAF488446579C59BFFFBDB7EEABD4F4B5C6D0946D5D29C7B881
CFD899D0E3A1C6DA95D5E9A4C7D894E1F0AFD1DCA2919B66040C00888E62E0E2BA535629
929463D6D9A0D5D798DAE5A3C6DC9B72914ECBE9A3DBF7ADC3E090CDE995C3DF8ACDE994
A0BC68A6C174D8F3ACCAE7A7C3E0A8DEFCCAD8F5C9D9F2CBFBFFE8FFFFE895997E838667
DFE3C2D5D7B2DFE1BA63663B6E7446121A00040E0073814ED6E7B3DBEFBAC5DCA6CDDFAD
6B7143302D02242000312D00E2DFAAE1E2A8D2DC9DD5ECA8C2E89F8BA16060481AF7DAB0
D6D9AAE4F8C5F8FFDCCBE2ACC7E8A1C8ED9FC9E99DCBEA9ED0EAA3CDE2A1D4E3AAE8F2BE
B4B990AAAB8BFFFDE6FFFFEFE5DED6060000988F92FBF5F7FFFFFBFAFDF2FFFFEFFEFFE7
CFD6ADD6E0AEA1B077BFD597D5EFB2CCE7B2F4FFE3F7FFEFFCFFFBFFFDFFFFF8FFFFF5FF
F9F2FFFFFEFFFEFCFFFFFDFDFFFBFAFFE3E1D69FA2FFEEE9F5EEDBA9AE97938876C5B5A6
FBF2E3FFFFF1FBFFF0F4FFEAE7F6D7E4F6CEDEF1C3C8DFA7CCE4A6C4DC9EE0F9BF718955
233A102F4521000F0099AE8DD2E6C1CEE4B6C0D7A3CCE2A4B1C68194A86096AC63C3D990
DEF4ABD0E89EC5DD93CCE69CCDE79DCDE79DCCE89DCCE89DCAE99DCAE99DCAE99DCAE89E
C9E8A4CAE9A6BBD896D1EAA9CAE0A087995B879759C4D295
D2DC9FDCE8AAC6D997D3EAA4CEEEA3C1E698C4EE9CC9F4A2C1EB99C5EA9AC7E69ACBE399
DEEBA6D6DB9BB8B87ABDC282D0E09F728945889D5CCDE1A2CBDFA4E5F8C0C8DBA4C8DCA7
49602A8FA86FC9E3A6CFE9A8C9E49FD2EDA6D3EFA4C8E094DBEE9FC5CF86EDEDADBEB97F
726C38D9E0ADC4E5AEBDF0B5619D5D9CDA97AFE8A4BFE9A7CCE0A1A3A76A777336E1DFA4
DDE8ACCFE1A3DEEEAFD3E1A3636E329FA8719197697779520909009B9B79D8D9B19C9E6F
94945EF1F2B6CED391DCE7A5D7EDAC5B7835D6F4ACBEDE92CCED9CCDEF99C9EA93CDEE97
CCE99592B161C5E498BFDE98D4F7B7C1E4AAC0E5AFCDECC2E5F5DBE5EEDBAFB39CA4A98B
CDD8B0D5E2B4D0DCACDAE8B3D8EBB46C7F48303D08677341BBCC98D7EEB8CDE9AFCBE2AA
D6DCAC9D9C6EA5A1729B9767E3E0ADD7D6A0DBE0A6D0DEA0D0E9A78B995B6C5728A88F66
DAD9ADE7F2C7F9FFDCDBEBBECBE8A8C8EAA0C9E79FCDE99FD1E8A2D0E3A1D2E2A4D9E4AC
C6CC9ED2D4ADE9E8CCFDF8E5FFFEF6978D8C63585EFFFCFFF7F6F4FFFFF8F5F6E8F6F8E0
E7EDC9CDD6A78D9A64D8EAB0CDE0A8CADEADF8FFE4F9FFF1FAFAF8FBF5FFFFF8FFFFF8FF
FFFCFFF5F3FEF7F1FBFFFBFFFBEEF5FFF6FBF4C2CBFFEEEFFFFFEDFEFFEAAEA190837062
CEC0B3FFFEF3FFFCF4FFFFF4EAF4DBCCDDB9D4EABCC0DBA4DAF8B8BFDE9BC4E2A2ADC98E
7B96635A73493E5835213E1F85A887A8D0ABBDECC2C2EDB7C0DE96D9EF9DCADF929DAF65
8E9F58B0BF7CD3DF9FDAE6A8D6E2A4D4E2A4D3E3A2D1E5A0D0E5A0CFE69ECFE79DCCE89E
CAE9A3C6E6A3C9E8A5CEEDAAA7C48288A562B0CB88D5F0AD
AA9F699B945DDCDCA0D6DF9ED6EAA3CAE69BBADF8FC7F19FBFE997C6ED9CCFF1A4CFE9A0
D0DF9CE2EBAC96975BDBE1A395AA698CA563C9DE9DCFDFA0D5E3A6D2DDA1DBE9AE7B8A4F
4A5C20E7FDBFBAD090D3E9A8CFE4A3CBDE9CE0F0AFD2E39DD9EEA1D4E297C2BE8160531F
7D6B43DDE0B5B0DFA983C587B8EEB0BAE2A3D6ECACD6DA9DF1E5A9564C0E8D9D54D5EFA8
CBDEA6D9E7B4CDDAA25E6931B1B487EAEAC8DBD4C18B8378080000928C76BEBC93E7EAB1
B5BC78C5D084EBF7ABC7D78EC7D6919DB16C89A058CAE49AC6E595D2F29FB7D782D9F6A2
D3EE9D87A251C9E497D3EFA4BADA91D3F9B0C0E8A1BFE2AC8EA48FADB7AEADAE9C8F9571
D3E8AFC6E49EC5DF95D6F5A7BFE899C9E9A0D2DA9EE3E2AAD9E3A7D0E2A4CEE9A6CBE6A3
DAE8ADD1DAA5D7DBA9D2D6A4E4E3B3DADAA8E0E0ACDDDDA7D5DAA0E5E6ADA39966695C30
EAE7BEE7E9C4FAFBDCE9F0CEE4FBC7C9E5A8CCE9A7CBE6A1CCE39DD5EBA3D0E49DD3E4A0
D2DDA1AFB784EFF1CCF6F4DDFFFEF4FCF3F4070005F3E9F4FFFBFFFDFBFCFCFCF4FDFEEC
E8EBCED3D9B3353D0E899361DFE8B9D1D9B0FEFFE6FEFFF1FFFFFBFFFCFFFFFAFFFFFCFF
FCFFFFFBFEFFFFFBFFFFFAFFFFF8FFFFF5FFC5A2A9FFF1EDFFFFEAFFFFE3FDF2D6817157
6B604ABDB4A5FFFBF4FFEEEAF3EDE1E8EAD5E6EFD0E6F7CBDAF3B9CAE5A2CBE29CD7EBA6
E0EEB0909D6793A67984A27C87B69625654A61B4988EDDAEBEF8A3BAE780C3EA8DD5F5A0
BDD48CD9EBAFBDC7936F7549575D3193996D939D6B8F9E65DBEFB0CFE9A2C2E193D0EFA1
C2D991E5FAB5A5BC765E78318AA55EC8E69CCCECA1C6E89C
5F4B185D4D196C632AD3D596D6E39ED7EFA5C6E999BFE695C8F2A0C4EE9CC0E295CAE69C
D2E39FD2DC9D5D6126565C20415414C3D998E5F5B6D2DEA0D7DFA3E7EDB1969E624D571A
D2E0A2BDD090D5EAA9D1E6A5D6E6A7D6E2A4D3DB9FD7E2A0CADF92D9E79C9690546E5E2D
B3A47DE3EAC0C1F2BB6DAD70C3F7B7D5F3B5D6D79DF2E2A7392000695E1E92AA5EBCE096
D1E9AFC6D7A35A692ED7E2AAEBEEC3FFFFE4FFFEF37C7270100501E9E2CF92936750591A
919E4FD4E692D1E795DDEFA3E8F5AF8E9B56CBDF98D7EFA5CAE699D4F3A5C2E191C6E393
5A7224D7EFA3DCF4A8BFD98FD1F0A4D0F5A8B9E296CAEDB361786469746C7B7A686F734E
C8E2A3D9FEAECEEE99C7EE95CAFBA2B0D788E5E7A8EAE4AAD8DEA0CBDC98C3DF95D3EFA5
BED18F6674378C975F131C00717542040600464614333100E6E3AC08050054511E5F5D2D
CFCDA6F7F6D7FFFFEAFBFFE2EEFFD5CBE8AECCE9A9CEE9A6CDE79ED3EB9FCDE496D1E69B
D0E19DA2AD73C9D0A4FFFFE6FAF8E9FFFCF990868E8D8590FFFCFFFFFEFFFFFFFBFBFBEF
D2D4BECFD2B360653D81865DD2D7AED8DCB9F5F8DDF4F5E5FDFCF8FFFEFFFFFCFFF7F7FF
F7FFFFF8FEFEFFFBFFFFFAFFFFFCFFFFFBFFD2B7BCFFF9F1FCFCE0FDFFDDFFFFDCE1D4B1
928D6D5E563FFFFAEFFFF8F4FFFAFAFFFEF8FFFFF1F7FFE6E3F8CDCFE6B0CDDFA3D9E5A7
D1D69CD0D59FC8D4A65B744CB7E6C287CDAB3893722B8758A8ECA3C0F7A3CEFFAEC2EB9F
DBFAB6BBD395D8E7AED6E0ABDDE6B1CCD59EE3EEB4D1E1A3CAE09FC5E0994363184A691D
576D24B8C982E1F5ADD3EBA1D5EFA5D1F0A2C6E798CEF1A1
EAD9A5CFC28D5C561CDBE0A0C6D590CDE59BCFF0A1CFF6A5C3ED9BCAF1A0C2E296D0EAA1
D2E6A1E7F1B2A9AF73989E62D5E3A5DFEFB0E1EBAED1D79BDEDFA58C8D536E7237989E62
D1DD9FEBF9BBD8E8A9B2C283434F11959F626E7438DFE8A7D1E69BADBA72877E45BBAD7C
D0D2A3D3E5B5ADD29EB4E6A9B9F0ADA7CC89DAD89D7F6A33847439919050DDF1AAC9E7A1
CBE4A3869C5C738843E1F1B0DCE6B1D3D8B0FCFBE79A988C040000E4E4CCB0B887869552
B7CA7BD5ED99BFDA89CCE498C7D691838F4DCDE19CCAE199C5E197CEEDA1D2EEA3CBE79C
8DA45CD6ECA4C3D893D8EFABC9E4A1C2E19DC6E9A5C4E5B05B715C6D776CB3B19C9A9E79
C3DB9FCCEEA2C2DF8FC1E492BFEC9BCEF2A8DAD9A0EFE6AFCED496C2D38F304A00466217
4A60174B5C18536123828D517E864D787D4562652E6D703754551C7E7F46929560B4B687
E7E9C2D9DCBDFFFFECF1FCDEF4FFDCCCEBAFC9E7A7CCEBA7CBE99FCEEA9DC8E394D1E99D
D3E9A1879759CFDBABF3FAD8F0F3DEFAFCF18988867A787DFDFBFFFAF8FBFFFFFBFFFFF5
E3E4D2F4F7DCCACDAEC4C8A5F6FAD7E5E8C9FFFFECFFFFF3FDFCF7FFFEFFF3F0F9FEFEFF
F9FFFFFCFFFDFFFBFFFFF7FDFCF7FDFFFCFDC4ACAAFFFAEBFFFFE1E0E9BCF7F0C4E5DCB1
E6E7BF8E8B6AA99A85FFFBF1FFF7F9FCF7FBF9FBF8F5FFF3EBFDE7E0F3D7E3F1CEF0F6D2
F3F0CDF5F1CCF3F3CD64704884A578A0D4A394DAA46FBB8A0A47257FB697B2E4BEB9E7B6
B7DFA1C5E9A1D1F19EC6E087CCE589CAE186D2E98FD2EA96C8E094EAFFBECAE7A5C3E09D
C7E295D2EB9AC9E493C4DF90CCE999CEEA9DC8E799CFEEA2
E4D7A2E5DCA3636126D5DB9BE8F7B2D6EEA4BFDF93BADF8FC4EB9AD0F5A5C7E79BD3EDA4
C3D792D9E5A5DFE7ABE2EAAED2DC9FD2DC9FDDE3A7D3D49AF0EEB5615F265A5920E5E9AE
D4DCA0C8D496D6E4A6879557E3EDB0CAD2969EA267545A1CD6E69F919C57605A20F7F1BD
BBC994C8E3ACD8F5BF85AB6EB9ECA7D2F7B298965B5B4A12B3AA6FDFE3A6D1DFA1D5EAA9
D1EAA67F9950E8FFB2C7DD92E1F1B2CAD6A6FCFFE6E9ECDB040700C6CDAED8E6B3E4F9B4
CDE695C5E38DCBED99D2EEA3CEDF9BD2DE9ECADD9BD3EAA4CDE8A1C3E199CBE69FCDE7A0
566B28C6D999D2E4A6D6E8ACC9DEA3D9F2B8B9D89CCDEABA596D54798271F2F0D7D9DBB4
D0E5ACCAE7A4C9E39CD8F6ACC3EDA3C7E8A3EDEAB38F834F575B2054652195AF65D4F1A1
D6ED9FD4E99ED4E59FCBDA99D5E1A3DCE6A9E5EDB2E1E9ADD4DCA0E9F1B6C7CE98C5CD9C
D0D8B1F5FEDFF4FCE5F8FFEAF1FFDDC7E9ADC4E4A5C9EAA5CAEA9FCBEA9CC7E494D1EC9F
D3EAA2839758E0EEBBCDD9B1F3FCE1F5FCEC676A638F8F8DFFFEFFFFFEFFFFFFFDFFFFF8
FFFFF3FFFFEDFFFFEAF6F9DEA7AA8FEFF1D9FFFFEFFFFFF4FAF9F4F7F5F6FFFEFFF2F2F4
FAFFFAFAFFF8FFFDFBFFFCFDFFFEFDFFFEF8D1BAB2FFFCE8FFFFDDDAE6B4CCCA97EEEBB8
D5DCA990966869613DBAAD9AFFFBF9FFFCFFFCFFFFF8FFFFF4FFFDF3FFF8F5FFF2FBFDEF
FFFCECFFFCE8EBE1C6DEDEBA55663988A972BCECAEBFF9C689C2B13C736D477C68B8ECC8
C6F7C0C7F5ACB6E188CCF491C7EC83D2F68CCEEE89C5E486C9E692B8D48ADDF7B6C5DF9E
D8F4A9CCE999CCE999D4F0A3D3EFA2C9E89CC5E399C2E096
DCD69CD1CF9453571A5F6A28C0D18BCBE399C6E599D8FAADC5E79AC5E79AC1DF95DBF5AC
CDE29DCDDC99D4DE9FCBD495E8EEB2D1D59ADAD9A0A8A66D534C157B743DB8B67DD3D49A
E3EBAFA9B57799A769B6C486D1DB9ED6DCA0A9AA7055591CDAE3A0666F2C66672DD7DFA6
DAF6BBB0D2965D763CB7D396C1EAA4CFEEA89E9E6081783DD2D198D2DAA1DEE7B0C4D297
CCE39D8EAB5BCDE995C3DC8BD6ECA4D0E1AAF4FFDD9FA991030D00D3E1BED1E6AEC9E49D
C7E794CDF199C9EF9CD1F1A6D7EAA8DDECABCFE2A0D9F0ACD0EBA6BFDD97CBE6A1CAE09F
4C5E20C8D79CDBE8B0EBFAC3E2F3BFF0FFD1D5F0BDE3FDD06A7D615C644DCAC4AACCCAA4
D6E7B3D5EFB2CEE4A6CDE7A6C1E8A7D1EFB1908A587062319E9F6592A15CACC77ACBE896
C5DE8DD6EB9ECEE398DAEBA5CBDA99DFEEADCEDC9EC9D897DEEDACB3C183FBFFCFE0F1BD
CFDEB5EAF9D8E6F6DCF4FFECEDFFDCC5E6ADC1E3A6C6E6A5C6E7A0CBEBA0C7E69AD2EEA3
C9E39CA0B676CCDFA8C7D6ABECF7D7FBFFEFC1C7B9595C55D5D5D5FFFEFFFFFEFCFAF9F4
FFFFF8FAFAEEFFFFF0FFFFF1B3B4A4B1B2A2E0E1D3FAFAF0FFFFFAFFFFFBEFEEECFFFFFB
FAFFF5FDFFF5FFFDF8FFFCF8FFFEF8FFFEF3C1AB9DFDEDD3E7F0C3DAE9B2EBECB3CCCD93
D4DFA3D4DFA550522196926FECE6D6F0EDE6F3F8F2F5FFFCF4FFFFF4FFFFF8FFFFFCFDFF
FFFCFDFBECE7FFFBEFEDE1C9EAE8C29DA977C5DDA1C5ECB7A6DAC34E887A569078417A57
77AF7EB0E6A8C5F9AEC6F8A3CCF99EBCE889C8F090C6EB8EDFFFA9CCE997C9E598D2EEA4
CEE9A4C6E19ECBE6A3C9E7A1BEDC96C2E19BD3F2ACD8F8AF
EEEFB3DFE3A68E9756495513B7CB84D6EDA5C4E095C4E397C9E99DC3E296C2DE94D6F0A7
D6EBA6D7E8A4DEEDACDFE9AAD3D99D75763C6462296B662E9E9760E1DAA3EFEDB4DBDCA2
91995D8E9C5EB0C081E0EEB0DAE6A8DCE4A890945998995DD2D7976B7131A2AC6FCBDFA2
A0C08192B575C9E3A4C2DB9AD5F0AB9FB56D5B6421A7AB6EE2EAAFD8DFABE3E6B7DBE3B0
D0E5A28DA95CC4E08CD7F09FD1E79FD0E3ABF9FFE478846C000700CDDEBACDE4ACC7E59D
CCEF9BCEF49DC1E897C3E599C8DB998E9D5CC9DC9ACEE59FC7E29DC8E39EDAF3AFCBE1A0
728446D7E4ACCCD6A1FEFFD6F9FFD6E9FACDF5FFDDEEFFDA93A281464D2E817A5D9F9B76
CEDBADD2E6B1CEDFA9C3DAA2CBEEB4C5DEA7595224F3E2B4CFCE95E6F5B0E0F8AAD1EE9C
D9F1A3CFE59AD0E69DCFE39ED4E7A5CADD9DD0E3A3D6E9A7C9DD98D9EEABC3D999C3DBA1
C9DFB0E4FAD3F2FFEAEAFFE2EDFFDDCEECBACCEAB4C7E6ABC5E3A3CDEAA7CCE7A2D1ECA7
C4DD9BB2C78CC8DAA6D1E0B7E8F6D5FBFFEDEAF3E22E342A8E8E8CFAF8F9FFFEFFF4F3F1
FFFFFBFEFDF8FFFFFAFFFFF8FFFFF8E6E6DEA6A69EE7E7DFFFFFF8F3F2EDFFFEF9FFFFF8
FBFFF4FEFFF4FFFDF6FFF6F0F8F4E9F9F1E4A28D7CD5C5ABE2EBBEC6D89ECFD599E8EEB0
D4E7A5D3E6A4E8F2B6565826BEBB98D3D3B7E7ECD6ECF9E7ECFEF2F3FFFFF7FFFFFCFFFF
FFFBFFFFF9FFFFF5F4FFFBEFFFFBE3FFFFDD9AA0729BB182C4F0CCB7F0CDBAF4CC82BD91
6BA5734D864F41793C97CE8BACDE97CDFDB3B9E397C0E798B7DA8ACAE999D0ED9DCBE79A
D0E9A7CBE4A3CBE5A4CBE8A6CCEBA7D1F2ADC8ECA4B3D78D
D0D998CCD795ADB977566723889C55D1E8A0D4EEA5CCE89ED5F1A7D0ECA2CEE89FC6DD95
C6DB96CCE09BCDDE9AD2DE9CD1D79937380058581C928D53E6E1A7E0DBA1D5D599A8AE70
4E5A1A99AC6AC9DE9BCFE4A1CFDF9ED4E0A0969F60E5E9ACE6E4A965692CB3C989BDDD9C
9EBE7FC6E6A5D5F5B2CFE8A4CFD89582894651651E8DA25FDBE6AED0D3A4DBD9B2D1D4A9
B3C58B91A864D2EAA0C9DF96CCE1A0CBDBAAF9FFE89CA892041200C3D4B2D0E7AFD6F4AC
C0E28EBFE58ECAF1A0D0F0A5D7ECA790A15DB8CD88D4EEA5CBE69FCBE69FD5EFA8CCE19E
475719E2EDB3DFE8B3DDE5B4F1FDCDE1F1C4E4F7CAE4F6CCADBC93464C265F5733948F69
D3DEB3CFE0B3E5F2C6EEFFD2D7F5C3CBE1B0595025E1D0A2E7E6ADC2D18CCBE395CBE898
CAE49BCCE39FC9DF9ED6EAABD4E8ABDCF0B3DDF3B3E7FDBCF1FFC4D2ECA5C3DE99E2FFBF
B9D49DDAF6C6D6F2CAF1FFE6F2FFE4E1F7D0E0F7CBD1E9B9C8DFABD1E8B0CFE4A9D0E5AA
CDE0A8B3C490D3E3B6D5E1BDE9F3D8FCFFEFD7DDCF3A3D34A4A5A0FFFEFFFFFEFFFDFBFC
FFFEFFFFFEFFF9F7FAFEFCFDFFFEFFFFFFFDD7D6D2B8B7B2C6C6BEFFFFF6FFFFF6FBFDF0
F8FEF0FDFFF4FFFCF6FFFCF6FFFEF4FFFEF1B9A493EBDBC2D0DBB0C8DBA4E2EBB2D1DB9E
C9E09AC0DA93C9DA96737E3CA3A468CBCE95EEF6C3EEFDD2E1F4D4E0F3DDEBFBF0F6FFFC
FBF9FEFFF8FFFFF9FFFFF9FBFFF5F1FFFDF1A59E8C838A68B8DC9ECCFFB6ABE09AB4EAAC
92C9906BA16F40754971A67C8EC196B3E4B7C1EDBADDFFCCBEE3A0CEEFA8DDFDB1BEDA8D
CAE19BD4E9A4D4EBA5C8E39CC0E097C2E69CCAF0A5CCF5A7
D6E5A2DEEFABD5E6A28296515B6F28BAD088D5EBA3CDE49CCAE199D0E69ED9EFA7CAE098
D8ECA7D9EDA8AFC37E96A56246501192985AE1E2A6D9D99DDDDDA1E6E7ABA8AE7098A464
D1E4A2D6EDA9C8E39ED3EEA9CFE4A1D3E3A2B8C484D3D99B958F5595965CC5E4A1D0F9B5
84A767CBEBAAC4E8A297AE685C5B1B767636C8E39CCEEFAAD6E8AEEDF3C5F2EECB9E9B78
C4D0A2EEFFC9CCDEA0CFE1A3E0EEB9D6E2BAF4FEE68B9384000700D0DFC0D1E5B0C9E29E
C6E595D0F29EC9EB9EC3E197CEE29BB9CA83849A51D2ECA2CDE99EC6E297C7E198D7ECA7
DBEAA9A7B276D1D8A2E9F2BDCCD6A4D0DEADDCEDC0CBDCAFD6E6B762683C645B34A29A75
E0E8BFC7D6ADE6F1C9F8FFDEDCF8C8C7DAAC5E5228F5E4B6D6D69AD4E49DD9F4A5C6E597
CCE5A4DCF1B9D0E4AFC9DDAAC6DAA7EAFFCBF4FFD2F4FFCDEAFFC0E1FFB7D4F4ABB7D692
D5F5B6CAE9B0C2DFAFF1FFE4F7FFEAF2FFE4F1FFE1DBEBC7CDDCB5D6E5BAD3E0B4CFDCAE
D7E4B8B7C29ACBD5B2D9E2C5E2E7D3FEFFF3FEFFF83B3C36CDCCC8F8F7F5F6F4F5FDFBFE
FFFEFFFFFDFFFAF7FEFFFDFFF1EFF4FFFEFFF5F3F4FFFFFBE0E0D8C4C4BADADBCDFFFFF4
FAFFF6FEFFF7FFFCF8FFF9F3FFFEF4FFFDF1B8A094E7D6C2D9E3BED4E7B9D1DBA7D4E2A7
D1ECA9D4F4ABC8DF97B5C27A5F63179C9E53D0DA95D7E7A9C7DEA8CBE2B8E1F6D7F6FFF2
FBFFF8FFFFFBF6F0F2FCF1F5FFFBFDFFF8FAFFFAFBFFFFEC90A967C5EB94C6EFA0C1ECA4
C9F7B9B4E4B0BCEDC05F926983B5901648228AB98FB2DDAFBBE2ADCBEEB4B6D89BD4F1AE
CFE79DD4E99CCFE698CBE697CFEEA0CCEF9FC2E99AC1EA9B
C0D68EE7FDB5D3E9A1D3E9A1465A15D1E5A0D8E9A5D8E9A5CEDF9BCBDC98D7E8A4CDDE9A
CDE19AE0F4AD162A004D611A475613E4EFADD7E09FDEE4A4CED494454E0D636F2DCADE99
C8E29BCCECA3CCEEA4BDDF95D8F3ACD1E8A250641FD5DE9F9B955B9D9E64C8E8A5BAE7A2
C7EEADD6F9B7BEDE9B8FA260605C1F9C9B5BCCEAA2C2E7A1EAFFC6FDFFD68B8865AAA587
FFFFE4F8FFDBD8E1B4D8E1B2D4DCB3DEE5C6FCFFF2777A73000300D8E0C9D7E4B6CBDD9F
D0E69DDAF2A6C8E29BCEE59FD8E9A28D9F55899F54D2EDA0C7E396D3EFA2C1DB91D5EBA2
CEDD98818D4D8F975BD9E2A9E1EBB6CAD8A3CBDDA9CEE0ACCEDFA8DDE4B1A1986F696039
E4EAC4FBFFE1FCFFE1FAFFE0F2FFDFF8FFDA53481BFFFFCFD9DA9ED0E099D3F0A0C8E69E
F5FFDAF6FFE1F6FFE1F7FFE3F3FFDFDCF1C6CDE3B2CAE3A9CFEAA7B7D58DCDEDA2D1F1A8
CDECA8C6E6A7C9E8AFEFFFDEFBFFEDFBFDEFFFFFF1FAFDE8F6FAE1FFFFE8FFFFE6FFFFE4
9EA385B2B59AFDFFE9FFFFF1FFFFF4FDFAF3FFFEFD64605F666563FFFFFDF3F1F2FDFBFE
FFFDFFF9F6FFFFFDFFFEFBFFFEFBFFFFFDFFFFFEFFF7F6F4FFFFFAF6F6ECC1C2B4C5C7BA
FAFFF9F1F1EFFFFBFBFFFAFAFCF3EEFFFBF2998079FFFBEDFCFFE8F7FFE3F9FFD8D2DEAE
CBE9ABC4E5A0D2ECA5D6E69B9DA051585A07D7DE8ED8E699CEE49CCCE6A5CEE9B2D1EBBC
E0F4D1F2FFE7FBFFF4FEFFFAFEFEFEFFFDFFFFFCFFFBFDF297A16DCFE197D5EBA3C7E29B
BEDF9ACEF5B4B9E5A6C1F1B5C3F6BD0D3F0A0014005C8A5CBAE3B9C7EBC5CDEFCCC0DEAC
DEF6AAC6DD83CAE388D1EB92CDEB93CBEB96C4E692C5E896
DAF6ACBDD98FC5DF96CDE49C576B26D9EAA6C6D290CBD694EBF6B4DAE5A3C2CE8CDAE9A6
6E7F39485C1571873F92A860DDEEAAC2D18ED8E4A2D7E3A1ACB8769DAC69C3D792C7E19A
CAEAA1CCF0A6C1E79CBFE399CBEBA2D1ECA5859A55E5F0AEA09B619D9E64CEECACB5E29F
8AB472A8CC8CD6F0B1859153BFBD82E2E4A5D7F2ABBDE19BC9E5AAE8F8C7A0A07AFFFDE0
FFFFEAFFFFEAEDF3CFEEF4CEE7EACBE9ECD7FDFCF7B2B2B2010100C6C8BADDE5BEE8F3BB
C6D594CCDD99D5E5A7CDDD9FD5E4A171823BB5CB80CFEA9DC1DD90CCE89BD0EB9ED0E69B
E4F5AE94A15C929D5BCED899D9E7AAD0E2A6D5EAAFD3E8ADD2E4A6C9D1989B9365393009
FDFFDDF4FFDAFFFFE3FCFFE1EFFFDAF2FFD2594C1FFFFAC7DEE0A1D1E29BCFEEA2C8E7A4
F7FFE4F5FFEBF7FFEDF8FFEDF7FFECE2F5D5D3E8BFCEE6B4D2ECAFDBF8B5C4E29AB8D68E
CAE7A4CCE9A9BAD69CF7FFE1F1F4E3FFFEFAFFFEF8FFFDF2FFFFF3FFFFF1F5F2E1FFFFED
C3C0AFDEDBCCFFFFF4FBF6F0FEF9F6FDF7F7FFFDFF767074030000F8F7F5FFFEFFFFFEFF
F8F5FCF5F2FBFFFDFFFDFAFFFDFAFFFFFDFFFFFEFFF9F7F8FFFFFBFFFFF8DADACEE3E5DA
B3B7B6FFFFFFFFF5FAFFF1F4FFFCFAFFFBF8B29695FDE9E2FCFFEDF8FFECFAFFE2DBE7BF
D5F2BAC3E6A4CCE7A2D2E39CB0B267706E239CA053E5F2A2D2E798D6F1A4C5E59AC0E09D
E6FFCAF0FFDCF4FFE6F4FFEEF4FFF4F9FFFDF9FFFFFEFFF8C6C6A0CFCF99AFB77CD8E6A8
E8FFBBBCDB95CAF0A7BCE79FAEDD97C5F6B4CBFBC188B7830730065B836084A88CD2F2C9
B5D08DDBF2A0D1EA99D5EE9DC2DD8ECFEA9BDEF9ACCFE99F
C2E497BFDF93D9F5ABD8EFA7738440D4E09EE5EEAFE0E4A7C8CC8FD6DA9DF7FDBD485311
4F5E1990A15BD7EDA4CCE29AD5EAA5D8ECA7D8E9A5B1C27E596A26CDE19CC4DE97D8F6AE
C3E79DC7F0A4C1EA9ECDF3A8C8EAA0CAE59E9FB46FD4E09EE0DEA3A3A46ACDE1A4C1E5A5
90C180CCF6B7C9D8A18B8E57D3DB9FD8E7A6C9DC9AD6F1AEC9E9AAC6E2A88B9266FFFFE1
F7F6E1FFFFECF6F9DAFFFFE3FFFFE8FFFFF1FFFEFDEBE9EE09070AD1D1C9FCFFE0D6DCAE
848B555A632A565E2D606835000B009AA966CBDF98CCE39BDAF6ABCFEB9EC6E194CEE69A
BDD2878C9C539BA862CFDC97D8E9A5D1E6A3D2EBA7CAE39FDBF0ADD1DB9EB1A9785E552C
C3C8A0E1EBC6DDE1BEFCFFDFE1FCC9E0F3BC5E5421E3D49DE1E6A6D0E49DCBEBA0CAE8AC
F8FFEDF9FFF8FBFFFAF9FFF8F4FFF0E0EFD8CFE0C0C7DCB3CAE1ADCBE3A7C7E09FD4EDAC
CFE5A7D5EAB1CADEABF7FFDFFFFFF4FDF1F3FDF1F1FFFBF9FFF7F2FFFDF8FFF8F1ABA29B
F4EDE7FFFEF8FFFDFBFFF9FAFFF6FBFFF7FFFFFBFFB0A9B09C98996C6B69FFFEFFFDFBFE
EFECF3FDFAFFFFFDFFFDFAFFFDFAFFFFFDFFFFFEFFF9F7F8FFFFFBFFFFFAF2F2E8FFFFF8
9DA1A2E2E1E7FFF9FFFDECF2FFFCFBFFFBFA7D5E63FFF8F8FFFFF6F9FFF3FFFFEDF0F9DA
E9FFD4CAECAFCAE7A4D5E6A2D9DA9EAAA86D8A8C4BDAE49DD9EC9DC6DF8CC7E792CAF09B
BEE596C2E89FC3E7A9C1E1AFC7E1BAD5ECD0E7FAE6F7FFEFFFFFE8FFFBDB98946ED9DDAB
CAD59BDCF1ACC3DF94CAEF9FC7F19FBEEA9BBAE8A0C9F5B6BFEAB492BC8E001000BADDB5
D1ECBFD6EEBCBFD6A2CAE1ABD0E7AFD5EAAFB1C38792A466
CDF4A5DFFFB4BBD98FC6DD95849350909958DBDCA0DEDCA1F0EEB3E1DFA42A2B00737939
D9E4A0CADB94E0F6ADC6DE94CCE29AC9DE99D4E8A35D712CBCD08BC0D590D6F0A9C3E39A
C2E89DC3ECA0C6EFA3CCF2A7C8E89FC5DF989BAF6AD1DC9AD8D89A44450B5D6B30D1EFB3
8CBC7EAFD89ED9E1B061612FD5E4A9CEE2A3CBDB9CD5EAA9C3E6A4C7E7A89CAA75E2E7BE
E8EBD0FFFFEAE7EBC8E5E9C6EAEDD0ECEDDBFBFAF8F4F1F808030AC3BFBCF7F6E1D7D9B4
FFFFDAF8F9CFBABA98DFE1BCE4ECB9BBC98CC8DA9CDBF1B0CEE9A2B9D78DD8F4AA6A8238
9EB36894A65CB5C57CDAEBA4D3E79FCAE199CAE89EC6E49AC8DF97E2EDAB645D29100700
BEC39BD1DCB4E3E7C2FCFFDCD5F0B9D1E5AA60571EBDB177DFE6A3CFE59DC6E7A0CCEAB4
F9FFF3FCFFFFFCFFFFFBFFFFF5FFF7E5F1E3D8E6CFD3E2C1CCDEB4DAECBACCDFA8CFE0AA
DCEDB9D1DEB2CED9B1FFFFE8F7EEE9FFFAFDFFFAFDFFF9FBFFFBFBE8DCDCACA0A0DAD0CF
FFFCFBFFFCFDFFF6F9FFFCFFFFFBFFFFF8FFFFFBFFF4EDF5E9E5E65A5955FFFFFDF6F4F5
FFFEFFFFFEFFF2EFF6F8F5FCFFFCFFFFFEFFFFFEFFFAF8F9FFFFFDFFFFFBFCFBF6FFFFFB
FCFFFFCDCCD2C2B3BAFFF9FDFFFBFBFFFAFAC4A3AAFFEBF0FFFFFBF8FFF9FFFFF4FCFFEC
F2FFE1CDEEB5CBE5A4D6E9A9DCE0ADADAD7B60632C727B3CD7E79EC4DB8BD2F09AC6EA90
C5ED94C4EE98C3EE9FC3EBA5C9ECB2D8F5C5EAFFDCF8FFE6D5D1B8DBD1B8BEB8984A4B21
DFE8B3C7D798C3DA92D9F8ACD1F4A4C5EC9BB0D98BCCF6AEBCE5A3B3DCA07FA671002300
000C001C33194E65482439181B310B384D225A6C3CAABC8A
B3DD8BCCF3A2BDDC90E6FDB5B1C07D4F551795935AECE5AEDDD49DA79E65534E14ACAE6F
CBD491D8E8A1C6DC93D7EFA5DBF1A9CDE19A586923CBDC96CEDF99E4FAB2C9E39AC5E59A
CAEFA2C1E79AC9EFA2BBDD91CBE79DCEE49C9BA863EBF2AFE0E0A0A4A5693F480FCEE6AC
CDF6BE5B804CD2DBB04E5124CDE0A9D2E7ACE6F4B7C9DC9CBDE09CD8FBB7BAD09284915C
919C72E0E8BFD5DEAFD2DBACD9DFB9D9DDC4F9FAF4E1E0E50300070B090AC1BFB0F9F9DF
FCFBDCFFFFE4FFFFEDDCDAC5D5DAB2BFC997CEDFA9D7ECB3C9E3A4CCE9A7647F3A8BA55E
C6DC94C2D68ED1E59DD9EDA5CAE298C5E196CDEFA2CFEFA3D3EDA3C8D590CBC68F676032
636A40D3DEB4DCE1B8D4E0B0CDE9ACC9E09C5C5618ACA163D8E19ECDE49EC1E59FCFEDB9
F9FFF4FDFDFFFDFDFFFEFFFFFCFFFFFAFFF9F7FFF0F4FFE8F6FFE1F2FED8FCFFDFFEFFDF
F7FDDBF1F4D7FFFFECFEFBECFEF3F1FFFBFBFFFBFBC1B5B5B6AAAAC2B8B7ABA1A0FBF2F3
FFFCFDFFFCFEF4EEF0FFFDFFFFFDFFFEF9FFFFFAFFFFFDFFFFFEFF8B8A865B5A56FFFFFD
F3F1F2F9F7F8FBF9FCFFFEFFFEFCFFFFFEFFFFFDFFFEFCFFFFFEFFFDFCFAFFFFFDFFFFFF
F8FDFFFFFEFFDDCED3CAB7B9FFFCFAFDEEEBC7A7ACFFF6FBFFFEFFF5FBF7FFFFF8FDFFEE
F4FFE3CAE8B2C5DF9ED4E6A8DBE3B2D5DBAD939A675C652CD0DF9CD2E79CD7F2A1D2F29D
C6ED94C4EC93C0EA94BEE798BFE59CC4E4A1CBE9ABD8ECB7E6EDC4DCDCB8F9FBD4E5EBBF
B3BD8BE7F6BFDBEFB4BBD493C7E4A1C9E9A0D7F9AFBDE295C9EFA2CEF4A7D3FCAEB9DDA0
6D876E667B726D837659705EB2CAB2CBE4C6C3DDB8CCE7BE
C5F09EC6ED9CCFEFA3CBE29AB1BD7B6A6B2F7F7841E3D8A2EADDA89C8F5A645B22979558
E6EDAAD1DE98E3F8ADCAE095CADE97D2E39D3A4B05E5F4AFCBDA95C9DD96CEE59DCCE89E
C8EA9EBEE396D0F2A6BDDB91D7EDA5D6E5A0929956C7C988D7D6969A9C5D646D349BAE77
BAD8A6759264F0FCD46E764DCFDFAEC4D7A0DAECB0CDE2A1CCEBA7D0F1AAC1DC99798F4F
6A7B44B1C089D7E7A9D1E1A3D8E4B2D5DFBDFCFFF6E5E6E8000005020003ADADA1FFFFED
FFFFEAF4EEDEFFFDF8FEF7EFDADDC0EFF7D0DBEABFC5D9A8BCD59ECBE7AC7B9556C2DD9A
DEF5B1D5EAA5D2E8A0D0E89EC9E59ACBEC9DCBF0A0C5EA9AC3DE91D6E39EEBE6AFADA777
636A3EDAE7BBD5DCB0DBE8B3C9E6A3CCE39B58530FB5AC69D4DE99CCE69FBFE49FCCECBA
FBFFF3FFFEFFFEFCFFFEFEFFFEFFFFFCFFFDFCFFF8FCFFF3FEFFEDFEFFE8F9FDE2F9F9E1
FFFFEDFFFFF3FFFDF8FFF4F2FFFCFAFCF1EFF0E5E3ADA3A1C9BFBDFFFDFBF5EDEBFFFDFD
FCF8F7FFFEFFFFFEFFFBF9FCFDFCFFFFFEFFFFFEFFFFFEFFFFFFFD8D8C88010000F5F4F0
FFFFFBFFFFFBFFFFFDEFEEECFDFCFAFFFEFFFDFBFCFFFEFFFFFEFFFCFAFDFFFEFFFFFFFF
FAFFFFFEFFFFF3E5E582706EFFFCF6FFFAF6B7949AFFF6FBFFFEFFF7FBFAFFFFFAFDFFEF
F4FFE4CBE8B2C7E09FD4E9A8C9D7A2E3EFBDB7C18C808B51A5B173D3E4A0C7DD94C1DC8D
CEEE9BCBEE9ACAF09BCBF19ECBEDA0C7E79CCAE59ED1E7A7B7C892DAE7B9F3FFCFFBFFD8
DFEDBAC2D39DD3E6AEDAEFB4C3D999D6F1AEBDD891CCECA0D0F1A2B8DB89C5EB96CBECA7
849E7BC4DBC795AD972D493069876B9FC2A1C7EDC8B1DAB2
BFEC99B7E18FD0F0A4D2E8A0E7F2B0D1D1958A814A564612AB9A66E4D4A0675C24A29E61
D0D593D4E19BD4E99EC6DC91CDDE98E4F3AE63702BBFCC87E7F4AFD4E39EDCF0A9C5DF96
C5E399C2E297D4F2A8CDE49CDCEBA6D6DF9C939353797536EAE6A6CDCF90B2C08551632F
8A996EC8DAB263795260754CD7E2B7D5E1AFC9E1A5CAE5A2CEE7A3C6E19ACDEDA2C9E9A0
C3DD96A1B870DAF2A4C0D88ECDE1A2D5E5B8F4FFECEDF3EF0B0F126162649C9C94FFFFF3
FFFFF3FFFAF4FFFCFFF1EBEDFFFFEFEDF4D5F4FFDFD5E7BFBDD5A57D9863C0DCA2CCE6A9
CEE4A4CBE29ECBE29CCCE69DCCEB9FCAEFA1C3EC9DBDE493D0EC9FE0F0A9ADAB72989262
808859000900D5DDACCFDCA4C7E59DD4ECA055520BCFC882D4DF9ACFEAA5BEE5A2C8E8B7
FCFFF1FFFDFDFFFEFFFEFCFDFEFCFDFEFEFCFDFEF8FAFDF2F4F6E8FFFFEE858472AAA498
FFFDF8FFF5F7C2B0BCFFF7FFBAAFAD817A72CBC4BCFFFFF6F7F2ECF6F3EEFFFFFAFDFCF8
FCFDF8FFFFFDFEFFFFF8F9FBFCFFFFFCFFFFFBFFFFFBFFFFF8F8F6EFEEEA85847F31302B
F7F6F1FFFFFAF4F3EEFFFFFAFEFDF9FFFFFBFAF8F9FFFEFFFFFEFFFBF9FEFFFDFFFCFBFF
FBFFFFFDFFFCFFFBF8FCEBE4DBD1C7E2D1C9FFF0F1FFF4FAFFFDFFFCFEFDFFFEFAFEFFEF
F5FFE4CEEBB5CDE3A2D5EAA5D8EDACD1E5A6B6C688B0BE80818D4FD3DF9FEAFAB9CCE19C
CAE49DC4E298C5E59ACAEA9FCBE99FCAE49BCEE49CD2E9A3D5EFB0CDE9ACEBFFC8DCF4B8
96AC6E99AF6FD4E8A9C9DE9DD0E5A4CBE29EDEF5AFC8E49ABCD88EE1FFB5C1E195C2E098
A8C285ABC48DC0DDA5B4D7A18AB5802B5D2A0A4414A4E2B3
CAF7A4C3ED9BC4E498D0E69ED3DE9CD9D99DE9DEA8A696625B4714B3A26E5F541C9C985B
E0E5A3D3E09ADAECA2D1E69BCEDF99DDECA7899450DEE9A5D7E29ED5E29DCCE099D4EBA3
D0ECA2C9E79DCEE89FCDE39BD1DE99D5DA98ABAA6A504B0BDDD999E7E9A8C7D69B4E5F2B
363E17D0DCB8000D00223D14949C73E8F0C1DCF6B9CDECA8CDE49ED0EAA1C5E79AC6EB9D
D3F2A4668132CFEB96CEE998F7FFC8F7FFD8EDF9E1DFE9E1000104D6D7DBADAEA8FCFCF2
FFFDF4FFFEFBFFFAFFFFFCFFFCFCF0FEFFEAF5FFE4F7FFE44A6135C1DBABD4EFB8C7E0A6
C9E1A3D1E7A6D4EBA7CEE89FC6E69BC3E89AC3EE9EC9F3A1C9E59894A45D3B3900514E1B
DCE4B5000D005D6532DDECB1C6E49ADBF3A5555309E5DE96D5E09BD2EDA8BDE6A4C4E6B4
FEFFF1FFFEFBFFFDFDFFFEFFFFFEFFFFFFFDFFFFFBFFFFF8FFFFF49795885B574CFFFDF8
FFFAFCFDEBF7C2ADC0B7A5B3B0A4A4FFFEF4FFFBF0FFFBF0FFFFF8FEFBF4FFFFFAFFFFFA
FFFFFBF6F8F3FCFFFFF7FBFAFBFFFFF6FCFCF7FFFFFBFFFFFFFFFDFFFFFBF9F8F3010000
FFFFF7FFFFF8F7F7EFFEFEF6FFFFFAFFFFFBF7F6F4FFFEFFFFFDFFF8F6FBFFFDFFF6F5FB
F4FAF8FEFFFBFFFCF6FFFBF3ADA397FFFBF1F5D1D3FFF3F8FFFBFDFAFCFBFFFDFAFDFBEC
F4FFE3CDE8B1CAE09FCFE59CCDE49ECCE39DE3F6B4D4E3A2243000515D1FD1DD9FD8E8A9
D4EAA9CBE6A3CAE5A0CBE9A1CDE7A0CBE29ACEE29AD2E9A1CBEAA6BDE09CC8E8A5C9E6A4
183300CCE5A3DBF0ADCCE19ED2E5A3D0E5A2CBE09BD0EAA3CEE8A1C3DE97D6F4ACCCE89E
CBE59C89A35ABDDD94C3EBA5CDFBBBB0EAAF001B00418957
pop
P
% End of image
1 0 0 r
.03 w
.02253 .33109 Mdot
.06939 .3189 Mdot
.11424 .30498 Mdot
.16757 .31194 Mdot
.20434 .29917 Mdot
.20959 .27074 Mdot
.22817 .23941 Mdot
.24716 .2632 Mdot
.27181 .24289 Mdot
.31261 .23535 Mdot
.33605 .19067 Mdot
.35665 .16688 Mdot
.35705 .20286 Mdot
.38089 .21736 Mdot
.43947 .23767 Mdot
.46331 .25218 Mdot
.47058 .27538 Mdot
.49644 .28467 Mdot
.51139 .30498 Mdot
.5328 .30962 Mdot
.553 .3276 Mdot
.59179 .36648 Mdot
.60755 .4187 Mdot
.6027 .46976 Mdot
.62815 .54113 Mdot
.64068 .59219 Mdot
.63704 .6415 Mdot
.61765 .67806 Mdot
.62654 .70475 Mdot
.60189 .74885 Mdot
.5728 .7912 Mdot
.51745 .79062 Mdot
.47907 .81267 Mdot
.48513 .83762 Mdot
.51624 .87069 Mdot
.52553 .93278 Mdot
.53523 .97745 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.349206 0.34127 0.666667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
CAEBA4CCEBA7CDEAAAD3EBAFE4F9C1EEFFCAE2F7BCC9E3A2C6E49ECCEBA5C8E6A8C7E2AD
F8FFE6FBFFF1FBF9FAFFFFFDF9FFF1F6FFE7F1FFE0F4FFDEF4FFDCF4FFD4EEFFCBE6FFBE
CCE5A1CCE69FD9F0ACCBE09F94A668CCDBA0D0DDA7FCFFD4FBFFDCC5D5AED9F2D2000F00
3F7B6299DEBFB5F0C29AD2A5659A80417B657ABFA0AEEFD7E2FFFFE6FFFFEDFFFFEBFFF7
F7FFFFFCFFFFFFFCFFFDF7F7FBFFFDF4FFFBEBFFF48D9F930B0D083C3C3A9EA9A5DFFCF7
DDFFFFD1FFFFB4EBE8B4DCDC8A96963C403F263031617472B0CDCBCCEFEBE4FFFFDFFFFF
E2FFFFDFFFFFDBFFFFA6E4CDACF3D59EEEC998EFC5B3FFD7A8E5B9C4F8C883B584001700
B0E0A6C8F9B8B2DF9ACBF9B0C6F0A4BFEA9ABBE696C0EB99C7F2A0C8F3A1C2ED9BC6E295
DBDC9A6E6325A09557DBD696E3E2A1CED893D3E49ED1EDA3C4E99BC6EFA0BFE899BDE294
D4EFA2CDDF95A2AC658E9853D1E29CDFF4AFCEE59FCAE19BD2ECA5C7E19ACDE7A0D4EEA7
CCE69FC7E19AD5ECA68DA45E9EB26DD1E5A0DAEBA7D4E8A3CFE6A0CBE59ECDE7A0CFE9A2
DAF1ABC3DA94D0E7A1ACC37D738843CCE19CE0F4AFCDE19CD4E8A3CCE09BAEC27D97A864
DAE3A4D2DE9ED9F0AABEDC94D6F0A9CADE99696B2C4F4B0EA4A063DDE2A2D5E8A6CCEAA4
C0DF99D8F3AED3E3A4CCDC9BC0D995D2F2A9D0EEA6C8E69ED0EAA1CFE9A0D2EAA0CFE79D
D2EDA0C4E093D3EFA2C1E293CEF19FCAF19EC5EC99C9EA9BB9C885565F20919C5AD1E09D
C8DC95D1E8A0D0EAA0D0ECA1D2F1A5BBDA8ED9F5AB7E9A50D8EFA9D2E9A3C4D795D1E1A0
DFEBA9CCD795B1BA79D5DE9DEAEFAFCDD292E3E5A6707233
C3E49DCFEEAADFFCBAEAFFC6E7FCC1DBF0B5D3E9ABCEE8A7C8E6A0CCEBA7C8E6AAC7E1B1
F8FFE8FBFFF3FEFCFDFFFFFDF9FFEDEBFFDADAEFC6CEE5B7CBE3AFCBE4AAC8E2A3C5E09D
C3DD96CFE9A2D7EEAAC9DE9B98AA6CD9E8ADD9E6AEFCFFD4EFFBCDD3E3BCD5EDCD789F84
18523A73B496ADE8BCB9F0C6B5E9D2B5ECD78BCCAA4F8B7183ABADE5FFFFEBFFFFEEFFFF
F0FFFFECFAFAFCFFFFFCFFFFF5FFFDEDFFF8E8FFF5AFC3B7000100030000494F4D293D3B
315A5412433F588281819DA09DA5A7979797A7B0AF97A7A629423F1E3E394C706C86ADA8
99C2BABEECDFCBFFEE8BC7AD82C8A683D1A974CB9E69BB8D7FBD9871A785225632001E00
7FB385BFF1BEC0F1BAABDBA1AFDFA1C5F3B2CCFBB7BBEDA8B6E5A1BCEEA9C2F1ADC6E9A5
E5EEADDED89A534D0FC9C586D7D394E0E2A1E0E9A8CBDC98D4EEA5C5E59AD5F7AAE3FFB8
BEDA8DC5DB90DAECA292A25B6B7F38C4D994C9E09AE8FFB9B4CE87D8F2ABC7E19ACBE59E
C2DC95E2FCB5D2E9A3CEE59FB6CB8692A661879B5672864189A05AD3EDA6D8F2ABC6E099
CCE39DE4FBB5C6DD97D3EAA4B1C681697E39ABBF7AD8ECA7C3D792DDF1ACD5E9A4A7B673
8D96579DA969CAE19BD1EFA7CDE8A1D3E7A2D5DA9AA8A669706C2F626727A2B573D4F2AC
CEEDA7C2DD9AE1EFB1D5E3A5DAF3AFCFEDA7B6D18CC4DF98D7F1AAC6DD95E0F6AEC6DE94
D2EAA0CEE99CD3EFA2C3E294BEE191B8DE8BBFE693CCED9ECCDB98C6CF90323D00F3FFBF
D2E69FC9E098D5EFA5C2E195BEDD91D7F6AACCE89ECCE89E2D4700758C46D8EDAAD8E8A7
96A5627C8846C7D290A1AC6A4C5514D6DC9C5D6323D4DA9A
C5E79DCDECA6DFFCB9EDFFC5E3F9B9CDE3A3C9DF9ED1ECA9C8E5A2C9E7A7C7E4ACC7E1B4
F8FFECFBFFF6FFFDFFFFFFFBF8FFE8E7FED0D4ECBCC8E1AAC7E0A6C8E5A5CBE8A5CCEAA2
DBF6AFBFD990C8DF99B4C986A8BA7CC5D499D5E2AAF2FCC8FEFFDAD1DDB9C9DDC1BCDEC5
00130074AF91C1FBD2AEE4C0B6E7D4BAEBD8A7DFB893C6A594B8B8E9FFFFD3F3F0E4FFFE
E3FFFFE2FFFFEEFFFFE4FAF7EAFFFFE7FFFDD0F5E46C847611120C251B1A918B8B7D8182
8EA2A1678180B5C7CBDAE1E7E6E2E3F3EDEDFEFFFFE8F2F1A2B5B1728D88304F4925493F
41675A6F9A8791C2AC4984642569422D7A4C3E95603C8D6240816D275E58033830001205
437A677BB29B7FB59B88BFA087BF9C7CB48F79B18A7DB78E7EB78E80BA919BD4ABC1F1C1
C4DCA2D3DD9E73773C78773EAAA16ACCC18BB8AF789E9C63DEE4A6C9D895CBE199B7D388
C8E799D7F8A9BDDE8DD4F3A595AC6490A560768D47D0E7A194AB658DA45E7A914BAFC680
CBE29CC8DF99C3DA94CFE6A0D3E8A3D4E9A48CA15C859A5594AB65ADC47E8BA25CC5DC96
D3EAA4CAE19BD4E9A4CBE09BE2F6B1BFD38E93A762AEC27DDEEFABD0E19DC6D793DAE9A6
EAF3B4879152B4CB85C8E69EC4E096D0E49DE1E8A5D6D696888747545A1A576C296F8A45
D9F6B3CAE3A2D2DDA1D7E1A5CADE9FDCF7B4D7F0AED8EFABD1E6A3E2F7B2BED28DD6EAA3
C9DD96CAE097C3DD93D2EEA1D8F9AAD4F9A9CDF4A1C3E495D6E5A2E3ECAD384301BCCB88
DEF2ABCEE59DC9E59ACCEB9FC4E397C8E89CC8E69CCDE99F92AC65809751BDD28F687B39
566723BECD8AC5D491D2E19E89985596A260889452D7E3A1
CCEEA4C9E9A0CBE9A3D4EDA9D6EDA9D0E7A3CEE5A1CEE9A4C8E5A2C6E4A6CAE6B3CAE3BB
F6FFEDF8FFF7FFFEFFFDFFFAD9EAC6D0E9B2CAE3AAC6E2A5CAE7A5CEECA6CFEDA5CFEDA3
BAD68CDBF7AD97AE66374C07D2E5A5E8F8BADAE5ABFEFFD4FBFFD6F6FFDDEDFFE4C8E6CE
548067457A5C0B431E679D7DBFEDE0BBE8D4BDECC0ABD5AF446665A3C1CB9ABDB9A4CEC4
B0E3DC8CBDB7C9ECE8D9F8F3C4ECE192BCAE5A816F374F41030000342424B9ABABFFF9FA
FBFFFFF7FFFFFFFEFFFFFBFFFFFBFDFFF9F9BFBBBA8B908CF3FFFBF1FFFFE4FEF5EDFFFD
DFFEEF688B775883678ABC99BBF8CCB1F5C2A9F7BDAFF7C7BBF0DCA4D1CAACDAD0001B0E
81B09E73A38D3F6F5584B597487B5A40745051855F76AD8585BC946CA37B4E855D477849
D0F6BDC3DFA2E3F4BD6B723E5E5828594C1F5E50238175454D4A15C7CC92D2E0A2D2E9A3
E0FEB4C5E79ABFE494BCDE91C5DF96D3E8A3AEC57F90A761859C56BAD18BC5DC968CA35D
B4CB85CAE19BE6FDB7C5DC96C6DB96E9FEB9BCD18CD3EAA4CEE59FC5DC9696AD674E651F
8EA55FB6CD87BCD18CE1F6B1C7DB96CBDF9ADAEEA96E823D677834D6E7A3D8E9A5D8E4A2
DEE4A6CDD798667D376D8B43D9F5ABC6DC94DBE4A1E5E7A6E9E9A9D8E19ED3E8A5597431
476120667A3B80884F0B13005C6E32D2E8A8C3D999C5DA99D2E5A5C9D998DBEAA9D7E6A3
D2E39FDAEEA7CBE29ACCE89DBEDD91B8DB8BC0E796C5E599CDDC99D2DB9C828D4B7C8B48
D8ECA5D1E8A0C3DF94D5F4A8CEEEA2CEEEA2C1DF95D0ECA2D6F0A9C6DD97859A57829754
CCE09BCDE19CD5E9A4BCD08BE6FAB5E4F8B3BDD18CC6DA95
CAECA0CAEA9FC5E399C3DD94CAE199D4EBA3D4EBA3C9E49DC9E6A4C9E7ABD4F0BFD5EDC9
F7FFF2F8FFF8FFFDFFFEFFFBCADCB2C4E1A1C5E2A0C7E4A1CAE8A0C9E99EC5E599C2E195
D0ECA1CCE89DA5BC746C813CA0B3738E9E60A4AF75F2FAC7FFFFDAFEFFE1F7FFEDC1DDC6
C3E9D089B79B407656497E62C4F2E7B2DBC9BEE4B5D8FCD051706B5A7882335753618C83
4B7E7931625F789A9B90AEAC87ACA46C92875577694A5E52160E0B412B2DAA9496FFF6F7
F8F4F3FFFEFFFFF3FCFFF3FCFFF7F9FFFBFAD5CDCBACADA8F9FFFDF5FFFBF4FFFBF4FFFA
F2FFF6C7DFC9CBE8CAB7DBB5B3DEB0BAEFB9BDF9BDA5DAA2CAEAC1C8DDBCDBF1CD000C00
D1ECC1C1DDAD8DAB79C9E7B18BAC73A6CA8CBCE0A0C6EAAACFF6B5BFE6A5769D5C224C0C
95C589C0EDB4C9E9B7AEC193959A7195916BA29A75AFA780A19E736A6E3CACB981C6DA9B
B2CB89D4F2AAD7F7ACC7E59BD5ECA6C6DB96CADF9ACADF9AD4E9A4CADF9AE4F9B4CDE29D
8A9F5AC9DE99D9F0AACAE19BCDE49EC3DA94D8EFA9CEE59FC9E09ADCF3ADD5ECA6AAC17B
607530576C27D4E9A4C9DE99D4E8A3D6EAA5DAEBA7B7C8847687439BAC68E8F9B5CDD997
D8DEA0D9E2A3C0D79175934B9BB96FD6EEA4D7E29DD0D592E2E4A3C4CF8BD5ECA8BBD693
829C5B5C6E325D622C04070046551C7C9053A2B47866753ABECC91D0DB9FCFD99CD8E2A3
D6E2A2D3E4A0CBE199CDE79DD2EEA3CDEDA1CBF0A2C8E89CCAD996E9F3B48D995790A15D
CAE098C4DE95CEEA9FC9E89CCDEDA1C4E498C8E69CD8F4AAB4CE87D6EDA7A4B976D8EDAA
CDE49EDDF4ACCDE49CD2E9A1C6E097C5DF96D6F0A7D6F0A7
C2E497CEEFA0D1F0A2CAE598C9E195D0E89ED1E99FC7E29BCBE8A6CEEBB1E3FED1E6FEDE
F8FFF4F9FFFDFFFDFFFEFFFAD3E6B8CDEBA5CCEAA2CCEAA0CDEDA1CDEE9FCBEC9DC9EA99
C4E093D6F2A5C5DD93DBF0ABD3E6A4B3C3859AA56BDCE5B0DDE0B5E0E6C2F7FFECEFFFF2
E0FFE9E4FFF4DDFFF40A3E278DB8AFE7FFFBDBFBCABFDCAE9BB6B1E9FFFFDCFFFEE3FFFF
E2FFFFE2FFFFEEFFFFD1E6E9CEEBE7EAFFFFE7FFF7A7B4AB2C1E1D4C3233C1A7AAFFFAFA
FFFDFBFFFDFDFFF9FFFFF8FDFFF8FAEEE0DFEBE1DFFFFCF7FEFFFAFAFFF9F9FFFAE7F2E4
F9FFF3C0CCB4CEDDC0D8EDC6D1EDBDBADDA7C2EBAFD2F5BBCBDCAFDBE6BCCDD8AE000900
D3E3B2D2E5AED1E6ADCCE4A8C3DD9CCCE9A6CCEAA4C3E39AC9E8A2CDEFA5ADCF857CA360
51864EB9EFBDB5E0B3A8C89FB9CDA8DAE5C3DEE4C2D6DAB7DDE3BDB6BF9437451452632D
CFE1A7D5E7A9C3D696D7EAA8D4E9A4D2E7A2CCE19CDAEFAAD0E5A0C5DA95D1E6A1CFE49F
95AA659AAF6AC3DA94CCE39DE0F7B1CDE7A0CFE9A2CAE49DDCF3ADC1D892C4DB95DCF3AD
CEE39ECBE09B90A5607A8F4AD6EAA5C1D590CBDC98CFE09CCCDD9998A9656F803CB8C482
E1E7A9D2DB9CC7DE98D7F5ABA8C67C9BB369DBE6A1E4E9A6D6DB99E4EFABC2D993CAE7A4
DCF5B4D6E8ACA2A5700606004C592183955B93A26B8D9A62313A03384007A2AA6FB0B87C
DFE9ACCDDC9BDCEDA9C2D991CBE79DC4E498C2E799C9E79DD7E6A3D8E2A38C98569CAD69
D1E79FC5DF96CFEBA0C5E498C7E79BC0E094D8F6ACB9D78DDAF4ADC9E39CDEF3B0C8DF99
CEE8A1C0DC92C3DF95D3EFA5C7E399D0EEA4CDEDA2BADA8F
C5E898CCED9CD0EF9FD1EC9DCFE799CDE597CDE59BCAE59EC8E5A5D0EDB5EEFFDEF2FFEC
F8FFF6F6FCFCFFFDFFFEFFFACEE2AFC7E69AC5E599C6E798C7E897C9EB97CAEC98CAEC98
CFEC9CCBE79ACEE69CD2E7A2C1D492EEFEC0CAD59B565F2AE8E9BFFFFFE1F6FFEAF2FFF3
E8FFEED2FADFDFFFF6568A7497C2BBE9FFFBDDF9C6D4ECBCD2EBE7E9FFFFDDFFFFE6FFFF
EBFFFFECFCFFFBFEFFF8FCFFEFFDFFEDFFFEF4FFFFD9DED80D000026090BB59D9DFFF8F8
FFFFFAF6F7F2FFFDFBFFF3F3FFFAFABCAEABFFF7F2FFFEF8EDEEE6F2F5ECFEFFF6FFFFF4
FFFFEED8DAC2E0E0C4CFD5AFD1DDAFD1E2ACD2EAAEC9DDA8CEDCB8E2EDCFD1DCBE000800
C1D3ADC7DCB3DEF5C9C9E3B3CFEDB9C4E5AEC0E3A9C6ECAFCBF1B6C8EEB1C6ECAFC4EFB7
1F542600160001330E477350527555000D001A3514CAE4C1C5DFBABDD6AE95AB7D4B5D2D
697341D1D3A1EEEBB6E0E1A8CAD998D7EEA8C8DD98D5EAA5CEE39ECEE39ECEE29DD1E5A0
C2D79293A863D0E7A1D7EEA8C8E29BCCE69FBAD48DDFF9B2C2D993DAF1ABD1E6A1E4F9B4
BED38ED1E6A1D7EBA6879B568A9E59DFF3AED6E7A3DAEBA7E1F2AECEDF9BCBDC9896A260
D0D497E6EFB0CDE49EC6E49AD0F0A597B16745520AD2D993E2E9A5D2DF9AC4DB95E6FFC0
C2DB9AC9DB9FDADDA806060068723DDBEAB3CBD8A3DDE7B2E6EDB7CBD098464B1361662C
343C00596525D7E6A5D2E7A2E6FFB7CBE99FC0E296D2F0A6D9E8A5BEC8899FAB69849551
D7EDA5D2ECA3C8E499CAE99DC3E397DFFFB3CEECA2BFDD93D1EBA4C6E099D6EBA8CFE6A0
D4EFA8CDEBA1DAF8AECCECA1C5E59AB7D98DD2F7AAD0F5A8
D2F3A2C5E793C1E18ECCE995D2EE9ACFE897CBE699CEEAA0C4E1A1CFEAB5F2FFE3F5FFED
F8FFF8F3F7F8FFFDFFFAFFF8CEE6ACCAEC98CAEC98CAEC98CAEC98C9EA99C7E897C6E595
CBEA9CCBE79CDCF6ADC1DB94DAF1ABC3D895DEF1B1CCDBA0626B36979E72B7C2A0C6D9B9
C6E6C1D0F5D3B7DFC44D746298BBB7E3FFF9E4FFE1EDFFEAEAFFFFEDFFFFEBFFFFE5FEFB
F5FFFFFBFEFFFCF8FFFCF9FFFBFFFFF8FFFFF0F9F6888984210F0F3D2324B49F9EFFFBF8
FFFDF6FFFFFAFFFFFAFFFDFAFFF8F6908581FFFCF9FFFBF7FFFFFAFFFFFAF4F3EEFFFFF8
FFFFF4FBF5E7FFFFECFFFDE4FFFFE3FFFFDDFCFFDCF7FFDBFAFFEBF8FFF0FBFFF4000700
EBF8E4F6FFECF0FFE6F1FFE9EFFFE8E9FFE1D6F5CBC1E3B1BCE2A9C4ECB0C4EBB2BBE3AE
8CBA8C4C7B51749F74638C6051764A5C80525A7E4E214613001200466B38709162718E62
6A80594E603A414C2A4A5932455D29819D62ACC083C5D597DEEAAAD5E19FD6E5A0D3E49E
D9EEA9A0B57092A563D0E09FCFE09CDAEEA9DBF1A9C3DD94CEE8A1CEE9A2CAE49DBED58F
D8EFA9CEE39ED7EBA6D3E7A2576B26D0E49FD5E9A4C2D792D0E5A0D4EBA5D1E8A2A2B671
535E1CCBD795DFF6B0C4E29AC2E098E2FCB3909F5AA0AB66949F5AE0EDA8CDE29DCCE5A1
C7DD9DD2E1A8E7E9B7040600D4DEA9C8D9A2DDECB5CAD79FD7E4ACD4DFA5E9F4B88A9658
8894545B6A29A1B1707E924DC6DB96D4EBA3C9E39AD0E5A0D0D99AE3E7AAA0AA6B889754
CBE09BD8F2A9CDE79ECBE59BD3EBA1C8DE96CDDE98D9E8A5D3E29FD5E4A3D2E1A0D1E1A0
D0E09FD1E4A2C8DD9AD2E9A5D0EAA3D6F1AAC2E299C6E89C
C6E693D8F8A3C3E38EC4E58ED0EE98CEEB97D4F1A1C5E196CDE7A6CFE6B0F5FFE1F8FFEC
FAFFF5FCFFFFF1F1F9FBFFF6C9E6A4C3EA8DC5EC93CBEF98CDEE9DC9EA9BC8E69CC9E79F
C7E59DCBE9A1CCEAA4C8E89FC8E89DCCECA0CBEB9FC7E69ACBE29CB4C4856C773DDFF2BA
B8DEA3C9EFBEC8E0C093A597AEC3C4DAFCFDDBFFFFDBFFFFE7FFFFF0FFFFF8FFFFFBFFFD
FAFBFFFDFCFFFFFEFFFBFCFFF8FCFDFCFFFFFBFDFAE3DFDC1E100F331F20B9A5A4FFF4F2
F7EEE9FFFEF8F8F5EEFFFFF8FFFEFAC4BFBBFFFEFBFDF9F8FFFEFDFFFDFEFEF9FDFFFDFF
FFFDFFFFFBFCF6F2F1FFFFFAFFFFF8F9FBEEFEFFF3FCFFF3FBFFF4FAFFF9DCE1E501050E
D8DEDEF9FFFBF5FFF4F7FFF7F7FFFDF0FFF5F1FFECE0FBD0C5E4A8C5E8A4CAEEAEBADCA0
CAE5B0CDE4B0CDE5ABCDE6A5CDE79ECEE99CCCEB9BCAED9DC9F2A4BAE7A298CB92649C6F
3E79597BB9A45A988D7AB7A85588698BB08794A57B3A3D0E9A955E8C8849E1E8A4D5E59E
C7DB94D7EAA8B3BD804F5519C3C488DEE3A1DAE69ECBE196D3F1A7C9EAA3C3E29CCCEAA4
C8E19DDCF3AFBED390D7EAA8A8BD7A97AC69A4BB77D6F1ACC7E79ECAECA2C1E59BC6E89C
D6F0A7839A52B4CF88C3DE99CBE6A3D9F2B0C9DC9CDCECABB4C57F8A9B55ABBC76D7E7A6
D1E1A3D2DDA5E4EBB80E160096A56EDFF4B9C7DD9FD7F0AFB9D291CEE9A6D0EBA6D2EDA6
CFE9A0B4CB838A9E5793A46057662396A2609CA765B3B77AE7E0A9DDD69F999D6294A060
D3E8A3C7E198D8EEA6D1E09BE4EBA8BDBC7C746A2F8B80488F864D9D986096975D595A21
46400E5B5525726F3CBDBD87D4DCA1DAE6A8C4D795E0F7B1
C7E293CCE999C1DE8CD1F19ED2F29DBDDD8AC9E89AD7F3A9CAE3A2CFE3AEF8FFE1F7FFEA
FAFFF5FCFFFFF3F3FBF9FFF4C9E6A4C4EB90C8EC94C9EC98C8E89CC5E39BC9E6A3D0EDAB
CFE9A8CCE9A7C9E8A4C7E8A1C7E99DC5EA9AC6ED9AC8EE9BD4F3A7C0D68DB6C37DB8CC87
BCE49EC2EAAEDAEAC69EA796798787BBDCE1BFFFFFCFFFFFEAFFFFF6FFFFFEFFFDF3F2EE
FFFDFEFFFDFFFFFFFFFCFEFDF8FCFBFEFFFDFBFAF8E3DEDB160807140404A99594FFFAF8
FFFCF6FFFDF6F1EEE5FFFFF6CDCCC7EAE9E4FFFEFDFDF9F8FFFBFFFFFDFFFFFCFFFFFCFF
FFFCFFFFFDFFFDFAFFFFFEFFFFFFFFFDFDFDFEFFFDFAFDF6F1F4E9FCFFFBFEFEFF00000E
EAEAF2FEFFFFFCFEF9FCFFFDFCFFFFF1F6F9F4FFF2EFFFDECFE6AEC0DD9DD0ECB2DDF5C3
CCDCAFD1DDAFD4E1ACD6E4A7D6E7A0D3E899D0E795CAE793B8DD8DCCFAB1B6ECAEB1EFBC
4A906C6FBBA118695A347E6D3B755C84AC8AB6C7A3989B705A52214B4509D7D998D0DB96
DBECA8D7EAA8D5E1A3969E62767B3B9CA15EC8D289D8E89DB9D38ACFEDA7CDE8A3CDE8A3
DBF4B0C6DF9BD4EDA9D2EBA7DFF8B46E894459742FB8D68ED0EEA6CEEEA5C6E69DCDEDA2
C6E597DFFBAE415C159CB772CFE8A7C4DA9AD3E7A8C5DA99C3D792B0C47D8FA05A9BAA67
D6E1A5D5E0A8C8D2A01D2900A6B87EBCD294C8E1A0CEE9A6D9F8B4D3F5ABC9EBA1C2E498
C3E397C7E398BFD68EE1F2AC8B975567702F5E62257D7D41AEA770DFDAA2888C51929E5E
D9EDA8C9DE99D5E6A0B4BF7B9C9C5C6E652A3C2D0052410D4E410C594F1A8885509F9C69
ABA073A1946A8C81547C7646E7E5B2DFE2A9D4DCA0CED899
D5ECA8DAF4ADCEE89FCBE79DCDE99ECCE89ED0EBA4C2DD9AC8E0A6CFE3B2F4FFE0F6FFEA
FAFFF7FCFFFFF7F7FFFBFFF6CCE5ABC8EB99CAEB9CCAE89EC5E39DC5DF9ECDE7AAD8F1B7
E1F9BFD4EDB3CBE7AACBEAA7C9EBA1C2E79AC4E999CCEF9FCEEAA0D9EFA7DDEAA4687C35
C8F0A9C2E9AABBCCA2B9C3AB72827870938F45837E84C2BFE9FFFFF2FDFFFEFFFFFFFFFD
FFFEFFFFFEFFFFFFFFFDFFFEF8FCFBFEFFFDFBFAF8E5E0DD1A0C0B1F0F0FA99594FFF2F0
FFF2ECFFF7F0FFFFF6F4F4EA898883FFFFFAF9F8F6FFFFFDFFFBFFFFFDFFFFFDFFFFFBFF
FFFDFFFFFDFFFFFEFFF8F6F7FFFFFDFFFFFAFBFCF4FEFFF3FFFFF1FFFFF4E9E7EC07040D
E6E1E5FFFEFBEDEAE1FFFFFAFFFDFFFFFEFFFEFFFAFBFFECEFFCD1E8FACAE0F0CBCDDEBE
E2F0D7E3F1D8E7F4D6E6F4D0E3F2C7DCECBBD5E6B0CEE3A8C7E3A6C4E6A9C8F2B3C8FABF
9FD8A1BAF9C49FE3B0B4F3C4ADDDB57A9E780D2600AEBE8FDBE2AF8E915865692ED0D99A
CDDC9BC9DE9BD3EAA6D7F1AACBE199C7DC91A3B3689BA75DA1AA676D7637E6F2B2D2E2A1
C3DA94CAE8A0C8EAA0BDE197C0E49ADCFFB6B6D68D90AA61A0B66ED3E29DDAE5A1D9E9A2
CBE294D1EC9DBED88F7E9851D8EEADCAE09FD1E6A5D3E8A5E2F6AFBBCF87CDDE98AEBF7B
6C7A3D95A26CDBE7B7000900D4E6ACD3E9ABDCF5B4C9E4A1BCD996BDDD94BDDF95CDEFA3
D2F2A6D9F5AAC5DC94E6FAB3DBEAA7CCD795B3B97B979D5F7D8549293300364204C2CE8E
D7E3A1CFDB99C3CE8C495211969C5CA7AB6ECECF95E1E0A8DDDCA6CFCE98DAD8A5D9D7A6
D1D0A0E2E1B3D5D4A45D5D29D4D39D9D9C64ADAB72A7A268
D4E7AFC5DAA1C3D89DD2EAACD3ECABCAE3A2CEE6A8D1E9AFCEE5B1D6E8BEF4FFE4F8FFF0
FCFFFAFCFFFFFAF9FFFCFFF8CFE6B2CAE8A2CDE8A5CFE9AACFE7ADCFE6B0D7EBBAE0F4C3
F7FFDADDF4C0CCE5ACCDE9ACCDECA8C5E79DC3E599CAEA9ECCE7A0CBE29CC7D691ADC37B
83A95EB3D895CADAABCED7B8D3E4D193B7A9256356528F87E2FFFFF4FFFFF9FDFFFFFEFF
FFFDFFFFFEFFFFFFFFFEFFFFF8FCFBFEFFFDFDFCFAEBE6E30A0000221212B9A5A4FFFAF8
FFFCF6FFFDF6FFFFF6B7B7AF9F9E99FFFFFBFAF9F7FFFEFFFEF9FDFFFDFFFFFDFFFFFCFF
FFFCFFFFFCFFFFFFFDF8F7F3FFFFF8FFFFF4F7F9EBFFFFEFFFFFEAF8F5E4FFFEFB080204
EBE4DEFFFDF1FFFCECFDF6ECFFFCFFFFFCFFFFFEFDFFFFF3F8FDDFF7FEDDFCFFEFFBFFF6
F8FFFAF7FFFAF7FFF8F8FFF4F5FFEFEFF9E1E8F2D7E3EECCF6FFDDCDE3B4C1DEA6BEE0A3
C0E9A7C2F1A9BFF2A7BAECA7BDE4AFC9EABD84A173829C6CC8DAAA959F6D4F511FCFD49C
E2EDB1D1E8A4C6EAA0B2DB8DD4FBACC7E899BED489D8E49CDBDB9D9A985DDDE1A4CFD99A
E0F5B0BFDD95BEE298D2FBAFBFE89CBCE194BEDC92ADC47C93A05BAFB673D9D898DADD9A
D7E99DCAE594CAE298BAD189B8CF8BD4EBA7CEE3A0D4E9A4CDE199DBEFA7DBECA6D6E7A3
C4D4967D8C557C88580A1800C0D19AD0E4A7C6DC9CD7F0AEC7E29FDAF8B0D1F1A8CBEBA0
BEDD91CFEBA0C7E198BED48CCDDE9AE1EDABDDE7A8CDD999A1B7768BA462A4B775C9D595
D5DE9DDEE3A38F95557B8443CDD999CEDE9FE7F7B9D0DFA4D7E4ACD8E1ACE1E3B2D9DBAA
E5E8B9F4FBC8E5ECB8585D279FA46C595D226464284C4A0F
E0EFC6E9F8CDF6FFD9E7F9C9D7E9B7E1F5C2E2F6C5CFE2B4DCEEC6E3F2D1F7FFEBF9FFF4
FCFFFBFCFFFFFCFBFFFCFFFAD0E2B8CAE3AACDE4AED6ECBBE1F4C7E5F7CFE8F8D3EBFBD6
F8FFE1E1F3C9CCDFB1CCE3ADCFEBAEC9E8A4C4E49BC6E69DC6E19ED0E7A3DAEEA9C8DF97
BDE2956B8C45D1E0A9D6E1B7E7FADCD2F5DD69A790478474C6EAE6F2FFFFFCFFFFF3F1F6
FFFDFFFDFBFEFFFFFFFEFFFFF9FDFCFEFFFDFFFFFDF2EDEA413332382828B6A2A1FFFAF8
FFFCF6FFFBF4FFFFF6D2D2CAF9F8F3FFFFFBFFFFFDFBF9FAF9F7FAFFFDFFFFFEFFFFFEFF
FFFEFFF9F8F6FFFFFAFCFCF2FFFFF1EDEFDAEDEFD9F5F5DBEFEECFC3BFA69B92890C0300
716859A69E89B8AE95FFFEECFFFBFBFDF1F5FDF1F3FFFDF6FFFFEDFEFBEAF5F1EEFEFEFF
F5FFFEF3FFFFF7FFFFF8FFFFFBFFFFFCFFFFFEFFFBFEFFF5F8FBE8E9F0D1C4CFA4E5F7BD
CEE39ED6F1A2C7E58DCEEE9BD4EEB1CAE5B2C3E5B3002100C1DCB199AA804C4E26A5A778
D2DBA4BFD896CAF9ABB8EF9BBDF4A0BDEC9BCDEBA1DBE8A3E4E2A5635D23D8D89CCAD394
D2E39FD4EEA7D5F5ACBFE197D1F3A7D2F2A7CFE9A0D8E9A2C7D18C777A37797434D2D38F
DAEB9DD2EB98D6ECA1CCE299A5BA75BED38EB6CB86CFE59DD2E69ED1E69BDCF0A8D4E8A3
CADC9ECFE0AAD4E1B30009005160298E9D62ADBF81D1E6A5DBF4B2AAC57ED3F1A9C9E79D
C5E498C8E499DDF7AECCE39BD0E49FD2E39FCBDA99DEF3B0C9EDA5D2F8AFC9E29EC9D897
DFE1A2ACAA6D454509939C5DE0F0B1C4DF9CC9E7A7BFDFA0D5EEB5CBDCA8D1D9AADDE0B3
D1D7A7F3FAC7FFFFD3B6C187ACB77B94A264C6D594DDEEAA
EFF8DDE7F0D3FAFFE5F8FFE1F1FFDBF8FFE3EBFBD6C7D7B3E9F8D9F1FEE4F9FFF3FBFFF6
FCFFFDFEFFFFFEFDFFFCFFFBD6E3C5D0E2B8D6E6BFE4F4D0F3FFE2F8FFE9FAFFEBF7FFEA
F9FFEAE2F1D0D0E0B9CEE2B1CFE8AFCBE8A8C8E5A2C8E6A0D0EAA9CBE4A2DBF2ACC9E39A
C1E396D7F5AB435113D7E4AFC2D7ACBEE4BF80BB9B39755CA7CFC6EEFFFFFBFFFFFFFDFF
FFFDFFFCFAFDFFFFFFFEFFFFF9FDFCFEFFFDFFFFFDF7F2EF1608071E0E0EAB9796FFF7F5
FFFCF6FFFAF3EBE8DFB0B0A8FFFFFAF2F1EFFFFEFFFEFCFDFFFEFFFFFEFFFCFAFFFEFCFF
FFFFFDF8F7F2FFFFF6FEFFEFFFFFECDADABEDFE0C1BCBD9B6B6943454020534C3A080000
827B615D54355C522F7B7054FFF6EDFFFBF8FFFBF8FAEDE5FFF8E7FFFEF1FFFBFFFFFBFF
FAFFFFF5FFFFF6FFFFFAFFFFFCFFFFFFFEFFFFFDFFFFFDFFFFFCF6FFFFEFFFFFE1FFFFD8
FDFFC7CDD78ED0DD8DDAE899D9E9ABBED29DC5E2B237582DE8FFE0CEE1C3505537949671
D3DCADD4EEAFBBEB9FA8E691B2F09BCBFFB0BEE29AD4E9A8D0D69A9495590F1500EBF5B6
93A2614E621D203500677E38D0E7A1C2D890D6EAA3D9E9A2D9E39EDDE29FD8DB98A2A862
D2E393CBE290CDE295E4FAAFDCF2AAD0E69E0E2400DAF0A7D1E69BC7DC91CBDF97D1E5A0
D7E9ABD3E6AFDCECBF213102CBD8A2DBE9AE576729CFE2A2C2D897E6FFB9C6E19AC3E197
CCEB9FC2E195CCE89EC9E39AD6EBA6DFF3AED1E1A0C0D995B7E197C4F0A5CDEBA5D9E8A7
D1D394E1DFA2B0AE73282E00C6D999D3F0AECDF1B1BCE0A2CBEAB1DCF3BFF7FFD6FEFFD8
FFFFD6E7F1BCD5E2AAD7E6ABC6D89AD5ECA8DAF4ADCAE59E
B9BBAD8B8D7FBFC3B2FEFFEFFCFFEDF5FFE7E4EED6F2FEE6F2FEE8FAFFF2FBFFF6FCFFFA
FCFFFDFBFCFEFFFEFFFDFFFCE8F1DCE4F1D5E9F3DAF4FEE6FCFFF1FCFFF4FCFFF4FCFFF4
F9FFEEF0FAE1E2F0CFD8E9BFD2E6B3CEE6ACCDE7A6CDE8A5D2ECABD4EEADABC681D9F5AB
CEEFA0C0DB8EA0AF6A869456D5ECB4BEE4B39BD4AB3B765899C3B5E6FFFFEEF5FFFFFCFF
FFFDFFFDFBFEFFFFFFFEFFFFF9FDFCFEFFFDFFFFFDF9F4F1291B1A2F1F1FB29E9DFFF4F2
FFF5EFFFFDF6F7F4EBE7E7DFFEFDF9ECEBE9FFFEFFFFFEFFFFFFFFFFFEFFF9F9FBFAFAFA
FFFFFBFBFCF4FDFEEEFEFFEAFFFFE4D4D4B2DBDCB478794F7A7B4FB3B38D827E65191300
B4AE8CE3DFB2BCB686878054887C64DACDBDFFFBEBFFF5E3FEF6DFFFFFEDFFFCFBFFFDFF
FFFFFAFCFFF8FEFFFBFFFFFDFFFEFFFFFCFFFFFBFFFFFAFEFFF4F2FFFCF4FFF6E4F4EBCE
FFFFDAD2CE9EE6E3ACDCDDA3CCD39DE0EEBBD2E9BD5F795640543B97A693929685767A61
8F9B73BBD69FCEFBB6B8F1A4C1FBAEBCF2A7B2DB99D1F1B2E4FDBCBED39296A86A9FAF70
93A1638A9455A4AD6E919A59B9BF7FCFD895E5F0ACD2DF9AD9E9A2CFE099C9DD95B1C67B
C8DE8CA1B765D1E495BED388BFD38CDDF1AAAEC27A4B601582994BC4DB8DD7EDA2C4D994
D5E9ACD6EBB3C5D6A9000D006F7C46D1DFA4CEDEA08DA060657A39193000809B54D2EEA4
C3E296D2F1A5C7E399DCF6ADC5DF98BFD690E3F8B5D0EBA6C7F1A5C7F1A5C8E69EDBECA8
DDE3A3D6D698CCCC90676B2E6B793BC9DFA1D5F3B7C7E9ADC6E4AEE3FECBF5FFDCECFECE
EFFDC8CDDCA3C8DAA0DAF0B0C6DF9DCAE5A0CCEAA2C4E499
6D6A65A6A39EFFFFF8FFFFF6EBEDE2FEFFF4FCFFF4F5FBEDF9FFF3FCFFF8FBFFF9FCFFFB
FDFFFCF9FAFCFFFEFFFFFFFFFAFFF2F9FFEEFDFFF2FEFFF6FEFFFAFCFEF9FDFEF9FEFFFA
FEFFF8FCFFF1F8FFE7E4F2CED3E4B7CEE3ABCEE6A8CFE9A8C7E1A2CEEBA9D8F7B1BBDB90
D5F1A4CBE395CBD98E9AA761CAE0A0CEF4B9CAFFCF3E785286B39FEBFFFFF5FDFFFFFCFF
FFFDFFFFFDFFFFFFFFFEFFFFF8FCFBFDFFFCFFFFFDF9F4F11F11100B0000988483FFFAF8
FFFCF6FBF2EBCECBC2F9F9F1FFFEFAFFFFFDFFFEFFF8F8FAFCFBFFFCFBFFFCFCFEFFFFFF
FDFEF9FFFFF4FCFEE9FFFFE4FFFFE1DBD9B0E1E0B24C4E1DB8BB8CD7DCB3828266040300
DAD9ADDCDBA5E2E2A4D8D59EB6B18B847D60544D30625D3D928E69A8A586C6C0B4F9F4EE
FFFDF4FFFEF3FFFEF3FFFFF6FFFEF8FFFDF8FFFCF8FFFCF6FFF8F0E8DAD1726457675A47
9D91798D82669B90729D98725E6132C2CB9CF6FFDEF9FFECD9E4D45C665B596154707966
6C7B5A627C4DC7EDB2BCE9A6BCEEA9AADB99D8FFC7B6DFA3BAE1A2CDF0AECEECACC4DC9E
D5E7A9E0EBAFD0D69ADFE3A8C0C185959A5AB3BC7BCFDE99D9EFA7C9E59BD7F7ACC5E496
D5EC9CCBDE8D76883CBCCE84CBDF97D4E8A0CFE39BD2E79A9DB4648FA6568FA55AAABF7A
D1E7A9D5E9B4C7DAAC000E00616E38DBE6ACD5E3A6CFDFA0DAEDADDCF1ACBBD58EAFCB81
8BA75C85A458627E34C2DE94AAC47D78924BC5DE9ACBE6A1C7E99FC0E298D6F1AAC2D691
D6E19FE5EBABDEE2A5B4BA7C505A1DB7C58AC3D69ED6EDB5C9E4AFD3EFBCF1FFDCF2FFDA
F7FFD3D4E8ABCBE1A3CDE6A5D0EEA8C4E49BCCEEA2CBEDA1
AEA4A5FCF3F4FAF4F4FFFEFBFFFEFBF5F4EFFFFFFAFEFFFAFEFFFBFBFDF8F9FBF8FDFFFC
FFFFFFFCFCFCFDFBFEFFFFFFFFFFFAFEFFF8FFFFFAFFFFFDFFFFFFFFFFFFFFFEFFFFFFFF
FFFFFDFDFFF5F7FFE9ECFAD9D6E7BBC6DAA5CEE6A8E4FDBCDEF8B9DAF7B5C3E79FB5D78B
DCF7A8D6EB9CCAD788909E539FB66EC8EDAACCFFC7A2D9AF84B69DE6FFFFF8FFFFF8F5FF
FFFCFFFFFEFFFFFFFFFEFFFFFCFFFFFCFEFBFBFAF8FBF6F31B0D0C3A2A2A907C7BFFF3F1
FFFCF6EDE4DD908D84FFFFF8FFFEFBFFFFFDFFFEFFFFFFFFFFFEFFFEFFFFFEFFFFFEFFFF
FEFFFAFEFFF2FFFFECE5E6C7EEEFC7E3E2B48D8B5880834ED7DFACCFDAAF666D4C030900
D4DBA8DFE5A5E2EAA1CED48EE0E3AEAFB182949665A0A4716C7137535A26747857C8C7B3
FFF9EFFFFBF4FFF5ECFFF9EBFFFAEAFFFEECFFFCE8897E68B0A58F897E6A8C816FA99D8D
423628312519AA9D94847D6B6A6E49656C43C6C6AAFFFCEBFFFFF6C4C7C0909A91253624
71856A58704CA2B98DCBE6B3C9E7B3C6EBB5B2DEA9C2F3BBBFEFB1AAD697CBF3B4CAECAF
D4EEB1CDE1A6CFDDA2DAE3AAD9E1A69BA56894A264A6BB78CBE9A3CDEFA5C2EB9FC9EEA1
D2EA9ECDDF9377893F8FA059CADE97D0E49CC9DD95D5EA9DD2E999A8BF6F6F853A526820
CCE2A4D4E8B3CADDB000100096A36DD2DDA3D8E6A9DDEDAECADD9DCFE49FD0E7A1CFE9A0
D4F0A5C8E499CBE79DC8E49AA7C27B516C25A1BC77D1EAA6D1E8A2CAE098DAF0A8D2E8A0
CEE29BCADB95E5F0AED1DA9B505419A9AC75D2D7A1DAE2AFD2E2B1E2FAC8EEFFDCE9FFD3
F4FFD1D5EEADD2EBAAC0DB98C1DF99D8F8AFCAECA0C3E89B
FFFAFFFAEEF2FFFBFF92898CA59F9FF8F4F3FFFFFDFBFBF9FFFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFBFBFBFCFAFBFFFEFFFFFFFBFFFFFBFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFDFF
FDFDFFFEFFFAF9FFEEE9F6D8D4E5B9CBDFAAD7EFB3EBFFC4F4FFCDA6C581CFF7AED3F9AC
C5DD91DBE99CD8E3959CAA5B98B064C5E9A3C7F7B9AFE5B477AC90E6FFFFF7FFFFFFFCFF
FFFDFFFFFEFFFFFFFFFEFFFFFCFFFFFCFEFBFCFBF9FDF8F51305040B00008C7877FFFAF8
FFFCF6ABA29BA8A59CF6F6EEFFFEFBFFFFFDFFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFCFFFD
FEFFFAFEFFF3FFFFEADFE0BEDADBB1B5B38268652E87884FDBE8B2CADAABD4E0BC000800
A0AB73CFDC96DAE797E1EE9FCDD896E7F1B5E1EBAECAD792D6E499E2F2ABBBC893686C4B
D7C9C0F5E0DFFFF8F1FFFBEDFFF6DE9E957688825E6C6842A5A17BC7C59FD6D3B4FFFFE9
FDF7E9E1DAD2FFFCFAF9F5ECFFFFE8A2A685A49C859D9181CBC3B8DDDDD3DCEADBB0C5B2
5E765C25391D39442468745096A67F8AA57844703D44773F3D6E36659559B0DCA1B6DEA2
BDE0A6CFEEB3D5EEB5CFE7ADDCF4B8B6CE90CDE7A8C4E19F89A96695BA74D1F9B2BEE29A
D4ECA2D0E49CBBCC86BED28B91A560C2D68FE6FAB2D3E89BD5EC9CD1E898D2E99BC4DA92
A3B77A3F531E4F6034000A00DDEAB5DDEBB0C1CF92D6E6A7D6E9A9D4E8A3CBE09BCFE69E
C5DF95CCE89DCFEBA1C9E59BD9F4ADC9E49DD7F2ADAAC17B99A563D1DC98D2E39DBAD189
D5EFA6D4EBA3CCE09BD9E4A297985E59541DDAD4A2E3E1B0CFD9A7C7DBA8C4E2AEC6E7AE
CAE4A7C2DB99D6EFADD9F4AFCAE8A0C5E59AC1E397C4E69A
FBE8ECFFF2F5FFFAFD4E4244B9AEB2FFFCFFFFFEFFFFFDFEFEFCFFFEFEFFFFFFFFFFFFFF
FFFFFFFBFBFBFDFBFCFFFFFDFFFFFBFFFEFBFFFEFFFFFDFFFFFCFFFFFCFFFFFCFFFFFDFF
FFFEFFFEFFFBF9FFEEF6FFE5F8FFDDF7FFD4E8FFC2D8F3B0BAD592EEFFC8BEEA9DB8E193
D9EDA5D4DE95E3EBA084924390A85ABADE94B7E4A3B1E6B2558C6CD5FFF3F5FFFFF7F4FF
FFFCFFFFFEFFFFFFFFFEFFFFFCFFFFFDFFFCFEFDFBFFFAF71D0F0E160606A08C8BFFFAF8
FDF0EADED5CECECBC2FEFEF6FFFFFAFFFFFDFFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFBFFFD
F8FDF6FDFFF2FDFFE8DEDFBDD7D6AA9795625A551BAEAF75CDDCA3DFF3C2C7D7B2001100
CEDDA4CFE099C8DA86D1E38FEDFDB6C0D18DC9DA93D5EB99CCE58AC0DA83D5ECA48C9568
B5A69FFFF6FFFAE5E25B493B675C4097946BDCDCAAE0E5ABC9D196E8EFB9D8E0AFE3E9C3
FFFFEAFFFFF0FEFDF8FFFFF8FFFFEDFFFFE5FFFEEA6859465D523EC9CBB5D6E8CEC2DCBF
566E5424341A010300090700767B5BC7DCB3B3DEA9BCEDB6BFE9B7163E0C69915FB1DCA7
CDF9C4C3F2BBABD89FC2EFB4ADDB9DC8F4B5C5EDAEB3DA99BBDF9FC9ECAC779756D3F0AE
C6DD99D4E9A4D6E9A7D0E5A4BED3905267228EA45CC8DE93C9DE8FD7EC9DD3E89BD1E59E
D3E5A9D5E7B3CBDAAF0A1A005F6D38C0CF94DEEEB0D8E8A9C4D797DCF0ABDEF3AECBE29A
D6EEA4D3EDA3D5EFA6C8E299C0DB94C1DC95D4EFAAD2E7A2888E4E0B1000D5E49FDBF2AA
CFEEA2BEDE92D3EDA4CAD996E0E1A55C551EAEA26ED5CE9AEFF1BFDDEBB6C4DFA8C8E5AB
DFF7B9CEE4A3C6DC9BD0E9A5CBE59ECCE89ED9F7ADCDECA0
FFF9F8FFF4F5B3A1A1807071FFF4F7FFFBFFFCF3F6FFFDFFFFFAFEFCFAFDFDFBFEFEFEFF
FEFEFEFEFEFCFFFFFDFFFFFBFFFEFBFFFEFBFFFEFFFFFDFFFFFCFFFFFCFFFFFCFFFFFDFF
FFFEFFFEFFFBFBFFF2F7FFE6F8FFDDF5FFD4E8FFC1CAE5A0C8E69EBEE298BDEE9FC7F1A5
D1E29CDEE3A0DAE2999CAA5DACC476CDEFA3BDE7A5C0F2BD457E5BC8F7E7F4FFFFFDFAFF
FEFBFFFFFDFFFFFFFFFEFFFFFCFFFFFEFFFDFFFFFDFFFDFA0A00005141419C8887FFFAF8
FFFCF6E0D7D0FFFFF6FFFFF7FFFFFAFFFFFDFFFEFFFEFFFFFCFFFFFBFFFFFBFFFFFBFFFF
F4F9F2FEFFF3FEFFE9E0E1BFDEDDB1989560625C22D6D69AD8E7ACC8DCA7D0E2BA000A00
E0F2B8DBEFA7D2E593D8EE9BB6CA83DEF3AED4EA9FCEE891D9F797BDDD7CD2EF9DDDEEB8
6D61558F797C69564F73685295916BE3E7B4BDC788DCEBA6D8E9A2CDDE9AD2E1A6D1DFAE
D9E3C1F6FEE7FCFFF6F4F7ECFEFFF2FFFFEDF4EDD3D8CFB0A2A07A38411640572B2A461E
2C442475836ACBCAB8ECE7D4FFFFE8F8FFE1D4FBC4C0F0B6B7DEAFC8EFC30011006C9A6B
AFE1B0C2F8C4AFE8B1A0DAA0457F44659B5F649458C0ECAFD1F7BCBCDEA2C6E2A8779154
8FA565D0E6A6C7DB9ED5E9ACE3F7B8D7ECABA0B5707D9348BBD081C1D687D3E89BDEF2AB
D0E2A6CFE0ACC9D6AB000A0057662F73854994A466D8EBABDDF0B0C5D994BFD48FDAF0A8
DEF6ACBED68CC0D78FD0EAA1D3EDA6D2EDA6C8E39ED1E4A2BDC282494B0ADFECA7BFD68E
C6E69AC7E99CCDECA0CEE49CD8E1A0E3E3A7453E0777723BE2E2ACBFC891D1E4ACDAF2B6
BFD595CAE19DCBE29ED4EBA5C8DE96CAE097D9EDA5A8BC74
FFEEE8FFF1EBA28D88FFFAF6FFFAFAFFFBFBFFF6FAFFFCFFFFFDFFFFFEFFFCFAFDFBF9FC
FFFDFEFFFFFDFFFFFDFFFEFAFFFFF8FFFFFAFFFEFDFFFDFFFFFCFFFFFBFFFFFCFFFFFDFF
F7F5FAFEFFFAFBFFF1E2F1D0CFE2B4CFE7ADD5F0ADD3F1A9D0EEA4C6ED9EB5E899BEEA9D
D4E5A1E8EAA9DDE29FC2CF87C5DD91D6F6ABBFE6A5C0F1BA3C7852B0E3D0F4FFFFFFFCFF
FFFCFFFFFDFFFFFFFFFEFFFFFCFFFFFEFFFDFFFFFDFFFEFB1709080D0000BCA8A7FFEDEB
FFFCF6B3AAA3EEEBE2FFFFF8FFFFFAFFFFFDFFFEFFFEFFFFFCFFFFFBFFFFFBFFFFF9FFFF
F7FEF7FCFFF4FDFFE8DBDCBAE1DEB39B9863625C22D9D99BC6D496E3F6BE88996D000A00
1E30008B9F58CBE091C9DE91E1F4B4D4E8A9BED58DDBF7A3D3F392C7E988C8EA96C7DD9F
57563A5D5141ACA68C878761E8EFBCDDEBADE7FBB3CCE496D4EFA2BDD78ED5EEADD6EAB5
CEDEB7F9FFEAFBFFF1FDFFF3FFFFF4FFFFEEFFFFE3D2DAA9D1E1A2DAF1ADDAF4B3EFFFD3
EBFDD7D3DDC4EEECDDFFFFEFFFFFE8EDFFD3CFF1B4C0EAABC6EDC0BCE4BFBEE8C2001300
BEF1C6ADE5B6B4EEBC7BB5824C8550B4EBB41849125A854F3F662FC4E7AFC3E0AAD1ECB5
D2EAB041591FD3E8AFCEE3AAC0D59ACAE0A2D9EEABDEF4AB8BA053A2B768D4E69AD1E29C
CADA9CD7E5B0E5F0C5000900D5E6AFDBEFB2849658485D1C647938CCE19CE9FEB9C2D890
C6DC93CEE69CDFF6AED1EBA2C2DC95D0EAA3CCE5A1C8DD9AD9E4A2E1EAA98F9E59D2E9A1
D6F2A7C7E79BC5E498D1EDA2C8DC94D4E39EF1FAB9949A5C53591DA2AA6FCFD89FD6E6A8
DCF2B1DFF8B4D3EAA6D0E5A0CCDD97DBE6A1C9CE8B60611D
FFF8EDDFC7BB9F897EFFF3ECFFF6F2FFFAF9F2E6E8FFF8FBFFFDFFFFFDFFFFFDFFFEFCFD
FFFEFCFFFFFDFFFFFBFEFDF8FFFFF6FFFFF6FFFEFBFFFEFFFFFCFFFFFCFFFFFCFFFFFDFF
F8F8FAFEFFFAFBFFF1DFEECDC8DBADC4DDA3C9E6A3CCEAA0C2E193D4FBAAB5EC99CAF9AB
CAD998D3D397D9DE9E9EA964CBE198CCECA3BBE09DB5E4AD44825995CBB4EEFFFFFDFAFF
FFFDFFFFFEFFFFFFFFFEFFFFFCFFFFFEFFFDFFFFFDFFFEFB3E302F0B0000806C6BFFFAF8
E1D4CE9A918AFFFFF6FDFDF5FFFFFAFFFFFBFFFFFDFEFFFFFCFFFFFBFFFFF9FFFFF9FFFF
F8FEFAFCFFF4FAFEE7DADBB9E0DDB29E9864665D24D9D898E3EFAFB8CA8EE6F6C9000A00
697841738342596B2155692136480EBED199DDF3B2C6E192C4E386DAFD9FC0E190D4EDAB
CDD5A4DEDFB5FFFFD6FCFFCFCEE19FC2DA90B4D383CAEC98CFF0A1CBEBA2CBE8A8BFD7A3
CBDDB5ECF9DDF8FFEEF9FDEFFFFAF4FFFFEFFCFFDDDBF4B3C9EB95BCE184BEDE89D5ECA6
D4E1B3D0D6BAF3F6E5FEFFEFE0EECDCBE1B0D1F0ACC9F0ADBEECBEACDBB9C0EFCB90C29D
1749233D704722552C56875A8DBC8EAAD8A9C8F4C378A27086AE7A96BC89537844577843
57723D869D67809763B0C791CEE3ABDFF4B9CDE2A1BBD189D4E99E899E518D9F55B4C57F
D3E1A4CFDCA7D3DEB300090062733CC8DC9FE4F8B9C8DD9C8FA4638BA05B8EA35E8AA058
98AE658DA35A869D55849B53A0B771C2DC95DCF5B1CEE5A1D3E4A0C2D38F657932D5EBA3
D3EDA3BEDA8DCFF0A1C2E394DBFCADBFDE92CEE59DA5B974768041393F0193945AD9DDA2
CFDE9DC4D994CBDF9AD2E39DD2DF99E9F3AED7DA95757632
B99E8D8C7263D6BFB1FFFAEFFFFAF4C3B4B18C7E7EB5ABACFBF2F5FFFCFFFFFEFFFFFEFF
FEFDFBFFFEFCFFFFFBFFFFF8FFFFF4FFFFF4FFFFFAFFFEFDFFFDFFFFFDFFFFFCFFFFFDFF
FFFFFFFCFFF8F8FFECE8F8D4DCF0BFD3EDB0C9E7A1C0E094C5E494C2E998BCF3A0B7E79B
EDF9BBD1CF96606125CBD694D5EBA3CCEAA2CAEDABBCEBB46AA97E90C6AEF2FFFFFFFDFF
FFFDFFFFFEFFFFFFFFFEFFFFFCFFFFFEFFFDFFFFFDFFFEFB5A4C4B0F0000675352FFFAF8
A1948EEBE2DBFFFFF6FFFFF8FFFFFAFFFFFBFFFFFDFEFFFFFCFFFFFBFFFFF9FFFFF9FFFF
F9FFFBF9FFF3F8FBE6E1E2C2DEDBB2958F5D665D24E3DFA0E2EDA9CADA9C9FAC7E000900
EAF7C1CFDD9FC5D48FD7E7A6CCDDA99FB17FBCD196CEE8A1C3E18BCFF19AC5E59ACBE9A1
D5E9A1D1E196D3E899CAE390CCEA94D1F59DCDF39CC7EE9BBBE194CCEFABCEEBB3DAF1C3
F6FFE5F9FFEDFAFFF2EEEEE6FFF6F4D9D8C6E8FFCBBEE798BAED84DAFF9BB9DC76D6EC9A
E1EAB5EDF0D1E8F1DCDBEAD3D2E8C1D4F0B6D4F0A3B7DD92B0E8B77BB8963F7855C5F8D7
B3E0BFC3EBC9D1F2D3DBF9D7E4FFDCD9F5CFDEFDD4BFE3B7C8F2C2AEDCABC5F5C1C3EFBA
638351526A38CCE4B2A8C08E809761CBE0A7DCF1B0D2E8A0CFE499D2E79AD3E59BB9C883
939E62B5BF8BD5DEB3081300D1E4ACD8EEB0BFD595D1E7A6D3E8A7D7ECA7D2E7A2D4EAA2
CBE198CBE198D6ECA4D3EAA2C0D7918EA55FC2D995D5EEAACFEAA3D5EFA89CB36B7A9048
C5DB92D1E99DD2F1A3C4EA97BCE994B4E18ECBF6A6BDDD92D8ECA5DBE0A0D2C9905A5118
5B5D1E616A29B5C07EE6F3AED3E09AD2E29BD9E9A0C7D78E
6248397F6556FAE3D5FFFAEDBFABA2FFF7EFC3B4AF6F615EE7DDDCF9F1EFFFFCFDFFFDFD
FDF9F8FBFAF8FFFFFDFFFFFBFFFFF8FFFFF6FFFFF8FFFEFBFFFDFFFFFDFFFFFDFFFFFEFF
FEFFFDFCFFF3F4FFDFE1F5C4CCE4A6C2E09AC6E69BCEEEA3CDE99FC6EB9EBAF19DC0F1A2
C6D698C2C28C9DA067DAE6A6CFE79BC0E393C9F1ABB9EAB27ABD9484BBA8ECFDFFF9F7FF
FFFDFFFFFEFFFFFFFFFCFFFFFBFFFFFCFFFDFFFFFBFFFEFA3025231705055B4746FFF9F8
B5A6A3ECE3DCFAF7F0FFFFF7FFFFFAFFFFFBFFFFFDFEFFFFFBFFFFF9FFFFF9FFFFF9FFFF
FCFFFDFAFCF1FBFDE8E8E7C8D6D3AA807D4A55531ADDDFA0D2DF9ADDEDAF8B986A061300
D2DFAAD4E2A5DBEAA5D5E6A2C9DBA18B9E66CFE4A9D4EDA9C7E696C7E993C5E898CCECA0
D2ED9ECEE595D0E995C0DC85DDFBA1BFE087C5E590CAEB9CCFECA9C9E5ABCAE1B3E3F7D2
EFFFE4F8FFF1F9FFF4D1D7C9D3D1C2E1E8C7CCEAAEC8F49FB6EB81BAEA7AD7F792CEE18F
F0FABEFAFFD9DDEECECDE5C5CEEDC1BDDEA5C0DF99CEF7B597D4AA2B7254397E5FC8FFE8
BBE5CDB7D7C2EEFFF6EBFFECF2FFE4F7FFE3F2FFDDD5F7C5C5EFC1C6F4C3AFE1A6BFF1B2
BAE6AB9AC18A81A370C9E9B78EAA777F9861C8DDA2D1E7A6D1E79FD5E9A1D1E399D5E69F
8A9958939E649FA7740008009DAC73D1E3A7D5E7A9D8EAACC9DD9ED3E8A7D2E9A5CCE39D
D1EBA2CCE69DCFE69ED2EAA0CDE59B8EA65CC9DF96CEE69CC5DF96D3EEA794AE6595AC64
D6EAA2CADE96D9F1A5CAEB9CBCE795C8F8A4BEE999D0F2A6CFE09AD8DD9BE4E0A3A39D61
9191554B5010848949CDD693D5E09CD4E49DD0E49CD3EBA1
EED5CEF3DAD3D1BBB05D473A8C7669FFFAEDFFFBED65534796857BFFFBF4FFFCF6FFFCFA
FDF7F7FFFEFFFDF8FEFFFDFFFFFFFDFFFFFAFFFFFAFFFFFBFFFEFFFFFDFFFFFDFFFFFEFF
FEFFF6E7F2D2D2E6ABCDE89BCCED96C8EC94C4E999C9EAA3CEE6AAD1EEACBEF29FBCEE99
8DA363848D56D3DCA7D6E9A7BCDD84C6F293CAFBAAAFE9AE5DA08191C6BEF2FFFFFFFCFF
FFFCFFFFFEFFFCFEFDF8FFFCF8FFFDF7FFFAFBFFFBFFFFFA4439370D00007C6766FFF9F8
E8D6D4FFFCF8FFFFFAF6F7F1FFFFFAFFFFFBFEFFFDFCFFFFFBFFFFF9FFFFFBFFFFFCFFFF
FEFDFBFFFFF6FEF9E6D2CFB0D5D6AC363A07BBC388D8E4A4C6DB9AD6EBB0CFE1B1000A00
7C8C5BDAECB0CBE095D5EB9994A95ACFE59AD0EAA3BED992CDEDA1C9EC98B9E085CFF29E
F4FFCDF2FFCED6EBAAC5D991DAEB9DDCEA9BA8B4689DA663DAE1ABDFE6BCEDF4D5EBF5DC
F5FFECF7FFF1F4FFF1C8DDBED5EBBCC1D99DC6E59FCBEE9ECDEF99CFF099C9E28FCDE398
DCEFAFE5FAC1DAF5C2C7E4B6CCF0C2BAE0B1C6EEBC66956B4A846C6EB5A332886FB5FFEB
D3FDEFD4EFE8EAFFFFEEFFFFF7FFE8FCFFDCE0FABBCCF0B0C3EDBBC2EDB8B3DC90C8F7A6
B6F4ABB3F4B249804633622CABD1A0829F6FA9C18F677E46CDE3A5CEE5A1D4EAA1CEE398
CFE099DFECA78E97560C12006A6F35DEE6ABDCE5ACCAD89DD1E3A9CBE1A3D8F2B3C5E2A0
D2F1ADB9D990C6E599E8FFB7BED98888A04CD9EF9ACBE18ECBDC95DBF0ABC3E1996A8840
4A6018C7D691ECF9B4CCDD97CAE89EC4E69AD3F1A7CADE99E9EFAFD9DE9EC7D290DFE9AA
E2E6ABB3B47A7F8046707437DAE0A2D8E3A1D7E8A4CFE59D
FFF9F4FFFAF3AD9990D1BBB0664E42FFECDE8B7466947E70F9E6D8FFF4E8FFF8F1FFFCF8
FFFCFDFFFDFFFFFBFFFFFDFFFEFCFFFEFDFBFEFDF8FFFEFAFFFEFFFFFEFFFFFDFFFFFEFF
FDFFF3E5F1CBCFE6A0CAE890CAEE8EC6ED90C4EB9CCAEAA7CDE2AAD0EAADAEDE8ACAF7A2
536929D6E0ABCEDBA6D3E8A5E8FFAEA6D471BDF19EB2ECB235755B90C2BFF2FFFFFCFAFF
FFF9FFFFFDFEFEFFFFF9FFFDF5FFFBF2FFF8F5FFF6FDFEF85B524D1B0907695151E6D1D0
ECDADAFFFCFAF8F5F0FFFFFAFFFFFAFFFFFAFEFFFDFBFFFFFBFFFFFBFFFFFCFFFFFFFFFF
FFFEFBEFE8DEFFFFECE9E6C75A5C34515A25D7E5A8CEE1A1D1EAA8CDE7AAD5E9B8000B00
94A676D2E6ABC9DE93CFE59094AC54C3DA88D9F3ACD5F0ADD3F2AED1F3A7C7EE95C7EA98
ECFFCEF5FFDACADEA3E1F2AED2DE948E964B6A6D285A5A1ED9D6A9EBE8C7FFFFECFEFFF1
F9FFF1F1FFEDF2FFEDC4DFB6BEDC9EC9E99ED5F3A9C8E499C8E094CAE296C3D990D4EAA2
D2E9A5CEE8A7C3DFA5C1E2ADBCE0B0D0F7CBB5DFB7598B68347358AAF5DE328B77B7FFF4
E1FFFEEEFFFFE4FFFFD1F4F6E0F1DFFBFFDFCDE3A3C3E29ECFF2BCC3E9ACC6EC95C1EE91
C7FFB29DDF98B1EDAD93C8904B7948D1F8C9BFE0B1C2E0AE4D662DCDE5A7D9EEABC9DD98
E1F2AECEDD9AD0DC9C000A00959B5F4F5219D8E0A5DCE7ADD9EBAFD3E8ADBBD596D4F3B0
C1E29DCEEFA8D2F2A7B1D082D9F4A391A9558DA44CD8EB99D8E59FD0E49FCCECA3C6E89E
9DB46EA2B16ECBD191D8E3A1D1EBA4BEDC94D5ECA6D8E7A4CDCF90DBE0A0E4F8B3C8DD9A
CDD79AEAEEB3D1D298626327E4E8ABDCE5A4D6E7A3D2E7A2
FFFBF4EBDAD2705E54FFF1E6C0AA9D856E60856E60D4BDAFFFFAEDFFEBE2FFFBF4FFFBF8
F8EFF0FFFDFFFFFEFFFDFCFFFEFDFFFEFEFFFFFFFDFFFFFDFFFEFFFFFDFFFFFCFFFEFFFF
FBFFF5E2F0CCCEE4A3C9E692C9EC90C5EC93C5EBA0CAEDABC1D8A0D9F3B6C9F4A26F9645
BDCD8EDAE1ABCFDEA7D2EBA7BFE68BC7F495BEED9FC0F2BD18523CD7FFFFF1FFFFFCFEFF
FAF7FEFFFEFFFCFFFFF9FFFDF6FFFAF5FFF9FAFFF9FFFFFA8E8580271513574241C3AEAD
D3C1C1FFFCFAF5F1EEFFFFFBFFFFFAFFFFFAFEFFFDFBFFFFFBFFFFFBFFFFFCFFFFFFFFFF
FFFEFBF9F2E8FFFFECC4C1A235370F909964D3E3A5D5EAA7D1EBA4C5DF9ECFE3AE000C00
384A18D8ECB1CADE97DAEFA0B6CC7AC6DC93D4EAACC9E0AABBD49DC5E1A6D0F0A7C7E6A0
D0E9B2C6DAA7D8ECAFD4E5A1DDEBA099A35ACBD28F999C63DEDFB5EEEFD0FFFFEDFEFFF1
FBFFF1F5FFECF5FFECD1E8BEC9E5A8CFEFA4D1EFA5C1DD92CEE69ADEF4A9D6EAA2DDF3AB
CDE29FD1EAA9C7E0A7CAE8B4BDDEAFC2E7BB3C653B78AB82B1F6C7ADFBD3398672CBFFFF
EEFFFFF2FFFF4B7B7F44777890AFA9EBFFE6C3D4A0D9E9AAC4DA9CD1F1A8C8F493C2EE8C
B6DB8DE0FFC0B1DD9EC3F5BA195017063D06B5E7B4C3EBB7AAC8948B9F6AAFBC86D9E3AE
DAE7B1CBDCA6DBF2BC273C0492A063B9C386A2AE70839354D0E3A3C5DB9ACAE5A2D0EDAA
CFEDA7CBE9A3DBF9B1B6D288D2ECA28CA4588FA658CDE297D8E9A3CCE39DC0E49ACEF4A9
B2CD867F934E949F5D81904D90AE669ABC7291AC658EA25D909656AAB372D8EFA9CAE49D
CFDE9DE6EFB0C9CF9152581A5F6527C3CE8CCFE09CCFE39C
FFFAF2FFFCF48B7A72FFF4EAFFFAEFFFECE0FFF8EDA1867B654D435A433B64534CFFFBF8
FFFCFDFFFEFFFFFEFFF6F7FCFFFEFFFFFEFFFFFFFDFFFFFDFFFEFFFFFEFFFFFDFFFEFFFF
FBFFF6E4F2CFCFE5A5C9E696C9EB94C5EB96C5EAA4C9ECACCFE8AFCCE6A7C1E89787A859
E9F1B5CBCE99EAF9C0BFDA97BEE68EC3EF96CAF2ABB3DDAD447764C7F3F2EEFFFFF2FAFF
FEFFFFFFFFFFFCFFFFF5FEF9F5FFFAF8FFFBFCFFFAFFFFF8AFA4A01D0B0955403FBCA8A7
AD9D9DFFF9F7FFFEFBFEFFFAFFFFFAFFFFFAFEFFFDFCFFFFFBFFFFFBFFFFFEFFFFFFFFFF
FFFEFAFFFAF0F7F0DDB3B091606338D9E3AED6E6A8CBE09BCEE89FC3DE99D9F0B8001300
000B00D9ECB4D7EBA6CADF94C4D98ED5E8A6D9EBB9CEE0B6CBE0B7D0E6B8CEE7AEC6E0A3
DAF1B9C4D9A0D4E9A8D1E29C84944BD8E59DE0EAAB939A66E0E4BFEBEED3FCFFEEF9FDEE
FCFFF1FAFFECF9FFE8CADDB0CFE9AABEDC92D0ECA2D1EBA1CCE299D5EA9FCADE96BCD089
000D00213700425B214E6B35325221001000001000C2F1C3B6F7BDB0FAC91F6654DBFFFF
F2FFFFA2B5B3194C4718514B7DA19FCEE5D5CDDEB1DDEDAED5EAA5D4F1A1C3EB8BC6EE8E
DDF8A9C3DA94C0DE9EC9F1B3D9FFD14D7F4A457744BBEAB6BFE5B2C9E7B591A979D0E3B5
D0E2B8C4D6AECCE2BC152A006E7F48D5E8A8C5D896D9EEAB4257120F2600C5DF98C4DE97
CDE7A0C8E29BCCE69FD9F3ACCAE19B94AB65C2D995CCE19CCADE99C6E099C5EBA0C5EEA2
D9F7AFD6EBA6EDF9B7C8D995D0F0A7C2E69CC5E39B9EB36E424B0A343F00C4DE97D1ECA5
D4E8A3D5E4A1D7E3A3A1AC6A4A5513E6F3AEDBECA6CDE19A
FEF7EFFFFDF4D1C4BCA8978FF3DFD4FFF9EDD6BAAF7B5F54CBAEA6C9B0AB54413BFFFBF8
F8F0EEF3F1F2FEFFFFFCFFFFFCFCFFFDFCFFFEFEFCFEFFFAFEFEFCFEFFFFFEFFFFFCFFFF
F9FFF4E6F6D2D0E8AAC9E89ACAEC98C5EA9AC4E9A6C8EAADCFEBB0D0EDAAB8D98AA8C072
D4D498D9D8A0D8E7AEC5E4A0C5EF9DCBF4A5BFDDA1D7F6CD2F5848B5DDDDEAFFFFF0FFFF
FBFFFFFEFFFFF9FFFDF2FBF6F7FFFBF9FFFBFEFFFAF7F4ED918682110000513D3CC1AFAD
B2A4A3FFFBF9FFFEFBFBFAF6FFFFFAFFFFFAFEFFFDFCFFFFFBFFFFFBFFFFFEFFFFFFFEFF
FFFBF8FFFDF4FAF3E04C492AFFFFDAC8D39BD1E4A4CEE59DD2EDA0CDE99FC2DA9E1B2F00
5E703ECDE0A8DBEEACA0B16BA8B975CFDEA5CEDDB4D0DDBFF4FFE6F8FFE8F3FFDBF7FFD8
D5EAB1D4E8A9C7DC97A7BB737D8F45DEEFA9C2D2945C6836D2D9B7E4E9D3FEFFF3FEFFF4
FEFFF1FAFFE8FEFFE4C7D4A6D8EEAEC1DB92D0E79F97AD64465A126A7B34A7B871A9BA74
DDF1ACCFE3A4C2DA9ECDE8B1809E6C001900628358B2D9AAB3E6AB90CB9B519586ABE6E2
072317000A003D715B0F443461807B798E7F99B48184A25CC1E293C7E995C6E38FD0EC98
D0E998CDE599DAEFACC9DEA3C1D8A4C3DFAF83A777143E0E3769367CB17DA8DAA996C194
47664497AB90D5DECB000600C7DBA8C9E3A2C4DD9BD0EAA3C4DB93CAE29893A96073893E
A5B971DBEFA7BED38ED5EAA7D9EFAFB7CD8FA3B87DCDE3A5DEF1AFC5DF98CDF6AABAE498
C8E69EC7DC97CEDD9ACEE29DBCDE94C9EFA4C3E199C8DD98E3EEAC8A9654BED891C5E39B
D3EAA4CEE29BD4E5A185944F45520DD2DF9AD0E19BDBECA5
FFFFF8F0ECE3FFFDF6AFA29AFBE9DF8F776D82655DF6D8D0FFE7E1E3CAC55E4944FFFBF8
FFFDFBFBFAF8FCFFFFF2F7FAFDFDFFFEFDFFFFFFFBFEFFF6FEFFF6FCFFFAFCFFFFFBFFFB
F8FFF1E3F5CFCEE8A9CAE99DCCED9CC8EA9DC4E7A5C6E8ABC6E4A4CFEDA7D5F1A492A257
B0AA6EE3DEA6BED094D4F7B3BBE599C5EAA4E6FAC7D8EBCD6E8E83436A6999BABFD9F2F7
F1FCFFFBFFFFF9FFFFF5FEF9FBFFFBFCFFFAF5F5EDDED7CF62554F0E000042302ECDBBB9
E3D5D4FFFCFBFDF9F6FFFFFBFFFFFAFFFFFBFEFFFDFCFFFFFCFFFFFCFFFFFFFFFFFFFEFF
FFFDFAFDF5EAC1BBA58C8968ECF2C4CFDCA4D9EEABC8E298CEE99CD5F1A7657D412E420D
D3E5B3CFE2AAC6D9979BAC6699A968D2E1AADEEAC4E4EED3FBFFEDFAFFEBD8E6C2E6F6C7
BCD093D5EAA5B0C67D81974CD9EFA4CDE39BDBEFB48A9C6CD1DCBEE6EFDAFCFFF6FEFFF4
FCFFECF8FBE0FFFFE1E4ECBBC9DC9C425911657B33D6EAA3DFF0A9C6D790CEDE97DBEAA5
C5D692DFF2B2D0E5AACAE1A9213C094360304D6A3C95B68773986427562C00150700241C
3B5E4894B695B8ECC58EC1A089A692C8DFC3C5E7AB87B06280A95ADAFCB0C5D994D7E6A1
C7DC8FD9F0A2D3E49ECDDD9FD1E2ACD4E8B7C2DFAFB9DFAE89B987295F2D4C8251639268
A6C9A9AFC7B1788375101C065D7748D5F4B8CEECACD7F2AFDBF5AEC7DD94DBF0A5687A2E
9BAB60D8EAA0D2E39DCEE29DD1E5A6CFE4A9637A42A1B67DD5E8A8C2DC95CDF6AABDE69A
CCEAA2DBF0ABD3DF9DDBEFAAD1F1A8BEE298D2F0A8D8EDA8BAC5836C7735C9E39CD1EFA7
C3DD94CFE59DE0F4AD99AA644C5914D5E59ED0E19AC8D992
F3F6EFFFFFF8FFFFF6FFFAF1FFF6EFAB948EC7AAA4FFF4EFFFF7F17F666158433EFAECE9
FFFDFAFDFCF8F6FBF7FBFFFFFEFFFFFEFFFFFEFFF6FCFFEFFBFFECF9FFEDF6FFF1F5FFF0
F1FFE6DBF1C3CBE5A4C9E89ACCEE9AC8EB9BC4E7A3C6E9A9D1F2ADB8D68ED9F1A5CFD992
584C10E4DBA2D6E8AAC2E7A4C6F1ACCAECB0D7E1BCFCFFEFBAD4CB385C5C11393BAACCCE
E2F4F6F5FFFFF9FFFFF8FEFAFCFFFBFFFFFAF3EEE8D5CCC56E5F5A0F0000362420E9DAD7
FFF9F7FFFDFBFDF9F8FFFFFDFFFFFBFFFFFBFEFFFDFCFFFFFCFFFFFCFFFFFFFFFFFFFEFF
FCF4F1FFFEF3AAA48E959271E3E9B9CEDCA1C8DF99D3EDA3C7E295C3DD9660753C1C3000
C3D5A3D9ECB4C3D694BACB85A7B776E2EFB7FCFFDFFCFFE8F6FEE6C9D2B59BA67E92A06D
BED191D8ECA499B062B3CA7CD3EB9FCAE19BC0D89EB7CD9FE3F1D7EFFAE9FBFFF6F9FDEF
F8FAE5F1F2D3F8F9D1C5C99693A362889E56B5CB83CCE099C6D790DBEBA4E0EDA8CBDA95
D6E5A2D4E4A5A9BB7F8EA36A0920009BB6833E582892AC7F6B815B183A1F0014092B6B5D
A8D2AEB3D9A6C2F9BF74AA7077966AD3EEBBC2ECA0A0D17F59873FA1C38797A073D1D5A3
DCE7A2D1E397D1E79FCFE8A7CCE8AEB9D7A1D5F5C3C9EBB9B6DAAA9BBF8F6B8C5F33532A
466442718B7096AF9A000B0044683C7BA06AC2E3AAC4E2A4BED795D1E79FCEE096B9CA7C
A8B669CEDC8FE0F0A7D9EAA4C1D695D2E8AA71894F7E9358CADA9BD9EEA9D0F4AAC4E89E
C3DD96D6E7A3D5DE9DD6E5A2CCE7A0CDEDA4C6E099C2D38FA2A868848A4AC1D691CBE69F
D7F1A8D3EBA1C4D89073843D505D17CFDF98D9EAA3D3E89D
FCFFFAFEFFFAFBFBF3FFFAF2BCADA8B19C97FFF7F3FFEBE7D7BBB78F7672FFFAF6FFFCF6
FBF4EEFCFBF6FCFFFBF2F8F4FCFFFFFAFFFBF7FFEAF2FDDDEEFAD6E8F6D3E4F3D6E1F1D4
E8FDD6D5EDB9C5E39BC7E995CBEF98C9EC9AC4E8A2C8E8A7C7E8A1D1EFA5D0E69DDBE29E
65561BC7BC84D4E6A8BFE3A3C3EBADD4F0BFFEFFE6F4F6E8F1FFFDDCFFFC86B2B186AEAE
DBF0F3F3FFFFF8FFFFF6FCF8FDFEF9FFFFF8FBF2EBE2D5CDA0918A0D000031221DFFFBF8
FFFBF9FBF2F3FFFEFFFBFAF8FFFFFBFFFFFBFFFFFDFEFFFFFCFFFFFEFFFFFFFEFFFFFEFD
FFFAF4FFFEF1AEA8909A9A76D7DFAED0E0A2CDE7A0CBE79CCDE79DA3BC78CEE3AB001100
8EA06ED8EBB3DBEFAAC5D991B7C882D1DFA2E6F2C4D8E2BFBCC3A2B7BF9ACCD5A6DBE9AE
A9BA748FA457AFC676D3EC9BCAE596CDE8A1CDE6ADD6EDC1F0FFE7F3FFEEFBFFF6FEFFF3
FFFFEAE5E5C3BFBE90656831D5E4A3CDE19AD4E8A1D1E29CD5E59ED8E8A1D1DE99DEEBA6
DEEDAAC2D092D4E3A8DEF0B6B2C78FC9E0AAD6EEBAC5DAAFD3E4C425412B5086768AC4AC
C3E7BBCCEFB5A8E39F86C27CC5EEACC0E19CC5F19CBAE79689B0770722000C1600646940
8C9C5B78904487A25B8EAC6C72945887A8717E9C6886A16E8FA5748B9F6E9FB083C7DCB1
D1EAC3AECCA84E71510011002D532C8CB38782A374CDEBB5D3EDB0D6EBA8D6E69FD0DE91
A0AD5ED7E596D4E295D5E79DD0E69ED4EBA7A6BF7E91A767B1C07FD7E8A4C2E098C9E9A0
A1B5708F9A58B2B777DBE4A3CCE39DCBE69FD6EBA6D5E19F737335949657E1F0ADCDE49C
C7DF95D7EFA5CADE96506019D2DF99DBEBA4CADC92D5EA9F
F4FBF4FCFFFAF4F5EFF5F0EAFCF1ED917F7BDCC4C2BBA29E674E4AEBD3CFFEECE8FFFCF6
FFFAF4FDFAF3FEFFFAFCFFFAF7FCF8FBFFF6EDF8DAEBFACFD4E5B1CBDDA9C8DBAECFE5B7
CCE4B2CAE6A9CAE99BC9EB94C8EC92C8EC95C8EAA0C8E9A4C3E39AD6F2A8CAE098E3EAA7
5A4E12A3995EDDF0B0BFDEA2DEFFCDF3FFE3FFFEEBFFFDF1F1FFFBDCFFFBC7F8F47AA8A6
D1EDEEF4FFFFF1FBFCFCFFFFF2F1EDFFFEF8E3D6D0DECFC86B5A5318090240332DFFF6F2
FFFDFAFFFDFDFFFEFFF8F6F7FFFFFDFFFFFBFFFFFDFEFFFFFEFFFFFFFEFFFFFDFFFFFDFD
FFFDF8FEF4E8B1AB939B9B75C8D29EDBEEAECFEBA1CCEB9FC3DD96A0B676BCD09D000B00
D9EDBCCEE3AAD2E8A0D0E598859A4BE2F3ACD2DFA7D1DDAD98A172CED8A4D5DFA0DDEAA4
D5E79DD4E99CC7DE8ED7F09FC6E192CAE59EC0D99FCAE1B5D9ECCED8E7D2F9FFF3FCFFEF
FEFFE4D2D3AB585824DADEA3D9E5A3D4E59FD1E29CD8E9A3D1E19AD3E39CE0EDA88C9954
4E5D1A8D9C5BE1F1B3CBDDA1CFE1A7E2F5BDC5DAA2C9DFB0CCE1C01C3A20001C00C9F1CF
C3D4A7CFE8B186C4852E77307CB566CFFAA8C2E68ED4F0A6CADFB80008006E7F5DC9DFB0
CAEAA7CEF7ABB8E09AC4EBAACDEEB5C7E4AEBED29DDCEAB5939B68565D29464D1975824D
CADEADC6E3B3CAEFC30011004F77558CB49287A984000E00CBE3AFCDE3A5D6E7A3C8D68B
DBE899859443E2F1A0D6E998C5DA8DD0E89CDCF6ADCAE098515A195A6523455F183D5811
5463205C62222E2E00DCE1A1D0E49FCEE59FD4E5A1DCE5A4514D10A3A164CFDA98D9EDA6
CAE097DAF0A5CFE1974C5C13D4E19BD1DE98D2E69ED4EAA1
F7FCF8FEFFFBFFFFFBFFFFFAFFFCFAB8AAA7CDBBB9B3A09CD5C2BEF5E2DCFFF3EE6D605A
FFFDF6FFFFF6FFFFF8FDFEF6FAFFF8F9FFF3DEEDC6DEF1BAD1E5A6CEE4A3C9E1A7CDE6AD
CAE6A9C9E8A2C9EB97C9EC90C8ED8EC8EC94C8EA9EC9E8A2DFFBB1AEC87FD8EDA8DEE9A7
5E5417ACA668CADA9BC9E5ABCAE5BCF8FFECFFFEF4F5F2EBE2FAECD7FFF3B6EBE1275854
88A8A7F1FFFFF4FFFFFCFFFFFFFEFBFFF6F2B7A69FB29F985B4A420B0000655B52FFFDF8
FFFAF6F9F5F4FFFDFFFFFEFFFFFFFDFFFFFBFFFFFFFEFFFFFEFFFFFFFEFFFFFDFFFFFCFD
FFFCF8F6EDDEBAB49A93936DDCE6B1C5DA99CFEEA2C5E498D5EEAA7C9156E9FDCC000F00
8C9F71CCE1A8D6EEA4CAE18FD6EE98869B4CD1E1A0DBE9AEA5B378DEEAAAD7E598CADC8A
D1E495D3EA9CCCE594D3EC9BCAE596D2EEA4BED89BCBE3B3C9DDBAE9F7DEF3FFE9FAFFEA
C5CBA74E5124C4C78ED3D999D7E49FCEDF99D1E29CCFE09AD7E7A0D3E39C8C9B5684934E
99A865647332D7E7A8D1E1A3C7D99DC4D69AE2F4BABFD39E7B926844633A446B3F7A9B6C
C7CFA0A7B9895A966370BA7DB7F1A7C7F2A0B8D885D1E7A699A88B34432E90A67FD1F2BB
BEF0ABA6DB9397C682AED497B5D29CECFECCD8E2AED2D9A5DCDFA8D5DB9FDFE7ABAAB87A
54692E819D63BCDDA80021000015000021078CAD8E83A17B87A172D1E6AECEE1A1E3F4AD
D4E295707E2FD7E997CFE290D9EF9DD3EC9BC7E291D0E59ADFE6A3DBE1A1CFE49FD6EDA7
D7E2A09B9D5E524E11DEDEA0D5E4A1D3E7A2D6E2A0DBE0A07F763BC3BD81DBE1A1D3E49E
DEF2AABCD186DBEBA259661EE2EDA8D1DE98E2F3ACBDD38A
FDFFFEF5F5F3FFFFFDFFFEFBFFFEFBFFFAF7FFF4F2FFF4F0FFFCF6FFFAF4FFFCF6574C46
D2C7C1FFFDF4F5ECE5FFFFF6FCFFF8F8FFEED0E0B3D2E6A7CCE49ACFEA9BC9E79FCAE9A5
C9E8A4C8EA9EC8EC94C8ED8EC8ED8EC8EC94C9E99DCAE8A0C9E197DFF5ADCCE5A3CDDD9E
4746069C9B5BCEDE9DD6EDB7E5F6D6FBFFF4FFFCF9F8F9F4D2F1DFB9EAD4B6EFE032675D
426664EEFFFFF5FFFFF6FAF9FFFDFAFFF2ED9C8881C3AFA66D5B510B0000948A81FFFEF8
FFFEFBFFFBFAFFFDFFFFFBFFFFFFFDFFFFFBFFFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFDFB
FFFAF4FFFEEFA59F85B7B890CEDBA3D5ECA8C0E192CBEC9DD2E8A7C5D8A0CFE0B3CEDFB5
76895BC7DCA3CBE397DCF69FD0EA8F8CA44EC8DE95869A55A2B36FD5E59AD1E48BDEF299
CDE293D0E89CD3EC9BCDE693CFE897D6EEA2B8CE8ECFE3AECDDDB6E0EDCFFBFFEADCE7C7
575F36DBE5B0D6E19FD3DE99CFDE99D2E39DE0F1ABDEEFA9C2D38D5F702ABACB85CBDC96
D8E9A591A25E829251E9F9BACCDC9DD6E6A8DAEAAC5163271B2F00233F04CEFBBAC3E9AC
CBD4A5E0EFC808391B00391585B17CCAEDABD4F4ABCCE8AD556C506B8268BBD39FBEE3A0
BDFBB2B8FAB31C4E0F80A16AD5E5B6D5D8ABD8D7A7DDDDA9DAE2A6DDECA9CFE59CDDF7AE
BCD59195AB6B596D32000C00526F515B7B64638165B4D2AE95AF82CCE4B0BDD297CEE3A0
D5E69FD4E79854671695AB58C3DB87DBF39FC5DE8AD7EA9BDBE09DD2D898CBE09BD9F0AA
DDE8A6989A5B696327D6D497D1E09DD5E9A4D4DF9DD4D6978D8449C4BE82DBE1A1CEDD98
CADB94D4E8A0D8E8A14A5711D7E09DD6E19DC9D893E0F4AD
FFFEFFFCFAFBFFFEFFF5F4F2FAF6F5FFFEFBFFFEFBFFFEFAFFFEF8FFFEF6FFFDF6E3D8D2
AEA49BFFFBF3FFFBF4FFF6EDFEFFF8F6FFECCBDDADCDE4A0C9E591CFED97C8E998C8EA9D
C8EAA0C8EA9DC8EC94C8ED90C8ED90C8EC94C9E99ECCE7A0CFE39BC6DA93C4E1A1DCF4B6
656B2B979958DFEBABC5D6A2EBF5DDF5F6F1FEF5F8FCFFFDDCFFEBAAE2C5BCF7E3558B7E
59807BEDFFFFEBFBFAF0F4F3FFFCFAFFFAF6957C7789706938241B0B00009C938AFFFCF6
FEFAF7FFFEFFFFFDFFFAF5F9FFFFFDFFFFFDFFFFFFFEFFFFFFFEFFFFFEFFFFFDFFFFFCFB
FFFCF6FFFBEBB0A98DA3A47CE4F1B9C7DE98CBEC9DCAEB9CD9F0ACCEDFA8CDDDB0000A00
9BAE80D3EBAFBDD88BCBE88EC8E588CBE88E9AB2664A6018C4D890DFF4A5DCF196CBE287
D0E89ACBE59BD5ED9FCBE491D0E795CEE595B3C782D7E9AFD5E2B6E1EDC7FBFFE3D7E3BD
899766DDECB1BCCD86E2F4A8C8D992DAEBA5D0E19B95A66064752FAFC07AE2F3ADD1E29C
D6E7A38A9B57A2B36FDFEFAEC7D7966F7F3E839352A1B26EBACA83CAE49ABBEB9FB7E4A1
CAD8A5D5E3C059806B5D8A75405E3ABDD7A7C8E8A98BAE762748296A8769D1EAB1D6F5B2
ABDE9C5E96573A652D92B2804B5C2F5D693B232900959E67323E009CAD67CEE49BCEE69C
D1E6A1DDF0B0BECC91000B00688161BAD7BB3D5A3B74906ABED9AE4A6532D6EFB6D3ECAB
CEE59FD4EAA1C9E0926F8636D4EB99D1E995CDE591DEF1A2DEE5A1DAE3A2D0E7A1CAE19B
CEDA98A2A465999558EAEAACD2E19ED8ECA7D6E2A0D2D7976B6529A6A064D6DF9ED3E4A0
D8ECA5D5E9A1D7E7A0626D29515815D4DB98E8F3AFCDDA95
FFF9FDFFFEFFFFFEFFFFFEFFF7F7F7FCFEFBF9FBF6F6F9F2FFFFF8E8E8E0FDF9F0FDF4ED
877A727C6B63FFFAF3FFF2EAFDFEF8F7FFEFCFE1B1D1E8A2C9E791CBEC91C7E993C7EA9A
C8EA9EC6EB9DC6EC95C8EC92C8EC94C9EB97CAE8A2CDE6A4D9E6A1DDEEAABEDDA1729155
8D9C5BE4EDACC6D091DDE5B6EFF0E2FFFDFFFFFBFFECF7F1C5F3D6ACECC9BAF8DF508676
1C4740E0FEFEF4FFFFFEFFFFF9EEECE1CCC9F2D6D2BBA0990F00003E3025BDB4ABFFFFF6
F9F8F4FFFDFEFFFDFFFFFDFFFFFEFFFFFFFDFFFFFFFFFFFFFFFEFFFFFDFFFFFCFFFFFCFB
FFFCF6FFF7E7AFA88C8B8C62E0EEB3C4DE95CAED9BC5E896BFD6908B9D63D8E8BB031400
A1B584D3EBAFD6F2A5C6E48CC6E588D9F79FC1DB91B3CC88D1E8A2B8CE83DBF29AD2EA92
D3EDA3C7E29BD1EC9FCDE695D4EA97C9DC8ABDCD84DFEBABE0EAB6D4E0B2C6D1A6A8B889
DDEEB7C8DE9DD4EC9EC7E08FE6FCB1C3D78FA2B66F6F833CC3D790C1D58ED1E5A0CFE39E
C0D48FC7DB966D813C80944FA0B16D8A9B57D7E8A4CAD78FD6DF8EDAF09DB7EC9EB7ECA8
B0C7914F5E372D4A3477938497A38DD8E6C3BEDFA835622937643D5D835E6B824E6C7B42
849664000C00CFEBBBC3E4B5B2D6A6B3DAA5B4D59E274509BBCF90B9C8877A85437A8342
DAE4A7CFDDA2E1F4BD2036054A633BA7C19AB7D1AA96B186435F2F7B9764A9C68EC4E0A5
C0DD9BD9F4AFD2ECA5D8F2A87B9146D7EEA0D9EE9FCCDC91DCE5A2DBE7A5D6F1AACDE8A1
C8D9959CA262919153D8DD9DD6EAA5D3EAA4D2E39FDDE6A5575518929053D9E5A3D5EAA5
CCE39BC5DC94C9DA94A3AE6C626828D9DE9EDCE1A1DCE2A2
FAEFF5FFFCFFFFFBFCFFFFFFFCFFFFFBFFFFF9FFFDF9FFFBFBFFFAFCFFF8FFFFF6FFFEF4
B8AAA157433AFFE6DFFFFAF4FDFEF9F8FFF3D1E4B6D2ECA5CAE890CAED8FC5E992C6EB9B
C6EB9EC6EB9EC6EC99C6EC95C9EB97C9EA9BCAE7A5CFE5A5D3DC9BE1EDADC1E4AA22480D
D3E9A8CFDB99DBE4A5F6F7CDF1E8E1FFFBFFFFFDFFF1FFFCDCFFF1C5FFE2B7F6D974AB98
2D5A53E2FFFFF2FFFFFEFFFFFFF5F5B59B9AFFF7F37F625C1100006B5D52DAD2C7FFFFF6
FFFFFBFFFFFFFEF9FFFDF8FEFFFEFFFFFFFDFFFFFFFFFFFFFFFEFFFFFDFFFFFCFFFFFBFB
FFFBF5FFFDEDB6AF9382855ACAD99ED6F2A8C3E996C9EC9ADDF4AC8F9E63CADAAB000C00
506433CBE5A8C2E193CFF099DAFBA2C3E38EC1DF97D9F3B2D7F0AFD8F2ABD1EA97C2DE8A
CEECA6C6E3A0CCE89DCFE897D7ED98CCDE8AD0DC90C9D38ECED69BD4DCA9AEBA88B1C28C
B5CB8DD4EFA8D3F3A0D3F39EBDD589DCF0A891A55EBBCF88C6DA93D6EAA3DFF3AECCE09B
D8ECA7BBCF8A8DA15AA5B9729FB06ADAEBA5CCDD97E5F3A8D8E48EC5DD89C7F9B2B8E8AC
90A36C5F6B3D0E2908526C53B0B9A68A9479A2C08E4F78406C996E274D260F2900929D72
B0AE8744441ECFDBB3C4DDB3D6FCCDC5F4BE4B7B411844078DB171D1EBAAA5B87899A468
DDE6AFBDC592D8E4B6111E00475A2C768C5DB6CE9ED0EABA112D009AB88461824BC7E8AF
D6F5B9C2E0A2C2DF9DC0DB9879904CACC079D5E69FD4E49DDAE7A2C7DB96C9E9A0D2F4AA
CDE29D9DA9677C8242D6E19FD1EBA4C4E29AC6DD97DDECA9737536959A5AD8E9A5CAE49D
D1EDA3DAF4ABE0F4AF9FAB695B6020ACAD71D9D99DDDDDA1
FFFAFFFFFBFFFFF9FDFAFAFCF9FFFDECF7F3F7FFFDF5FFF9ECF8EEFBFFF8F4F6EBFFFEF4
FFFCF3D0B9B1957872C2ADA8FFFFFDF8FFF6CEE1B4CEE9A4C8E992CCEF91C8EC95C7EC9C
C6EAA2C5EBA2C6EB9DC6EB9BC9EA9BC9E99ECAE6A9D0E4A9D9DDA0CAD49792B87FC0ECB1
B4D18EDAEBA7DEE4A6FDFAD1FFFBFAFFF9FFFFFDFFF1FFFFCDFFE454A071145533275E49
89B6AFE7FFFFEBFDFDEEF0EF968687A38988FFEFEA94766E170100514338DDD7CBF8F5EC
FDFCF8FFFFFFFFFDFFFFFAFFFFFEFFFFFFFDFFFFFFFFFFFFFFFEFFFFFDFFFFFCFFFFFBFB
FFFCF6FFFAEAECE5C85A5D30DEEDB2C5E197D3F9A4C4EA95D0E69DBCCC8DDAEBB7D1E3B3
D7EBB8BAD497D8F7ABC6E892BADC86D0F1A2D0EFACC8E4AABDD99FD4EEB1C2DC93D9F5AA
C7E6A3CBE9A9CBE79DCEE796D8EC97D2E18CDAE5968F974ED6DC9EDCE4AB8D9762C5D79D
E2FBB9BCDA90CBF19AB6DA83B2CD808CA259ABC179CBE199CDE39BD1E79FC2D792D6EBA6
CCE29AD5EBA3D7EBA4BED28BD8E9A2DEEFA8C8D8918B9E4F9AB159C4E1915178437E9B6F
BBBD8BCACD96BFE0A9C7EEBFCDE2C38D9C7D5369381D380379986E9CBE9B74957645583C
070200A89B79BCB9965C643F81986E4A6E403F6E38B2E8ACAFE8A4B7ECA8C7F4B1C8E7AB
465625797B53ECE3C4080200A1AB77D0E5AA8BA369D0E9B0BAD79F2B4C1331541CA8CE95
B2D59DE3FFCBC5E2A8CCE6A9D5EBAD7C8E50D3E1A3DCEBAAE0EFACC7DE98C0E49AC6ECA1
C3DD96AABB776D7836D1E09DC8E69EC2E49AC7E29BD0E49FAAB07097A05FCEE59FC3E39A
C7E99FC5E39BCADF9CE0ECACE5E9AC7B7A4158531B98915A
FFFAFFFCF1F9FFFDFFFCFAFBFEFFFDF9FFFBF8FFFDF7FFFDF7FFFDF9FFFDFEFFFBFEF9F5
FFF9F3FFF9F35B3E38C3ACA6FFFFFBF7FFF2CADBB1CBE4A2C7E792CFF296CAEE97C8ED9D
C5EBA0C5EBA2C6EAA0C8EA9EC9E99ECAE8A2CCE6A7D0E4A9E4E9AFFEFFD2EDFFDA577849
D1E8B0FBFFD1F3FCC7FFFFE1FFFDFAFBF4FBEFEFEDCEE3D0B6EBBD4B8E5B3A7756B6E9D8
D1F6EFEEFFFFF0FCFCFFFEFF837373EED5D18D706A16000043221B5E433CFFFDF3FFFFF8
F7F9F4FCFEFDFFFAFFFFFDFFFFFDFFFFFEFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFCFA
FFF8F0FFFDECF5ECCD606233C7D799CFEBA0C5ED95C3E992D1E79EBAC88A8D9C65000E00
CCE0ABD5EFB2C2E297C9EC9ACAF09DD2F7AABBDB98CAE9ADC9E6ACD1EFB1C8E69EC7E59B
C3E09ED5EFAECDE79ECAE193D4E796D2E492D8E596566017555E1DD8E2A5BBC98EC9DB9D
D5ECA8D2EEA3C6E693CDEF9B5D792CD2ECA3C6E097D8F2A9C3DA92D5ECA4C9E09AD2E9A3
D7EDA5CCE29ACFE39CD6EAA3D4E8A1D3E79F697A338DA255D0EC98C1DF95D3F3C1D2E7BC
93935D525619CFEFACBFE7A9C9E2B85F7149000B0073864FC9E1B1C4DFB6C8E7C55A6F4E
5D5A37595029E0E1B9D2DFB4C8DFB35D7D4E001200BFEFB5BEF2B4B2E9A8B5E9ABC4EDB5
001000656D48E0D6BB312606707743CFE2A27E9756476424CFEBAEC8E6AA001B0053763E
D0F5BFAFD59CCBE9B3CCE5ACCCDEA4E3F1B493A163CEDD9CD0E3A1CAE39FC9EDA5C8ECA4
CFEAA5D8EDAA859554DDF0AEC6E49CCEF0A6D7F2ABC7DC97D4E09E93A05BC9E098CEECA2
D2F2A7C4E29ADAF1ABD5E6A2C0C98AE9EDB0E8E7AE4C4B12
FFFBFFFFFCFFFFFDFFFFFEFBFFFFF8FFFFF8FEFFFAFBFFFFF2FAFDF9FFFFF4F7FFFFFDFF
FFFBFFFFF0F0B49B978B776EFFFFF3F4FCE4D4E1B6D7EBAEC9E495CAEB94C3E78FCAF09B
C5EC9DC5EBA2C6EAA4C8E9A4CAE8A2CCE7A2CDE7A0D0E5A4D7E4AFF5FDD4FEFFE893997F
D1D6B6F6FDDBF6FFE3F8FFEDF2FEF4FBFFF8E0E6CAD4E3B8D1F0B71A46134D8266B8E3D9
CEE2E1FBFFFFFEFFFF86817EFFF3EFFFF9F3B39D923D1C13470F0ED5A3A2FFFBF4FEFFF8
F9FFFDF4FAFAFDF7FFFFFBFFFFF9FFFFFCFFFFFEFFFEFFFFFCFFFFFEFFFFFFFFFDFFFEF8
FFF8EBFFFDE6AAA07D9E9C6BDBE7A7CCE798C4EC93C5EB94D4E8A1D4DEA28E9C61000C00
A8BE80C3E09ED4F5AEC0E699C0E99BC3EE9FC5EEA2C4EAA1C5E9A1C7EBA1C9EB9EC8E79B
D5ECA6D1E5A0D9EFA7C0D68DD5EBA2CEE49BCFE59CEBFFB8F7FFC8819452CFE2A0D8E8A7
D4E5A1D1E29C9FB1678FA55AA6C47AC6E89EC0E298D1F1A8C8E39CC9E39CD4EBA5CFE49F
D6EAA5C3D792D7EBA6D1E5A0859A55D5EBA39AB169CDE49CD6F0A7C7E29BC4E1A1CDE5A9
CFDFA09DB06EC5E09DD1F0ADC8E0A4CCE1A6889A5CD7E9ABC8DC9FD8EBB3C8DDA5AFC08A
979E6AD2DCA7D3ECB3C7EAB0C2E9B024470F90A8768EA271D0E6B5C1DDACCEF6C2608A58
001500617A52CDD2B231310D717542D4E2A4C3DE9BC6E5A18CA764CFE8A761763B001700
4F753CC7EEB5CFEDB7C6DBA3D7E0A7E4EAACB3C37C92A65EA8BD7A6D864494AE6DD4F1AF
CEE7A5C8DE9DCDE3A2B3C988D1EAA6D1EBA4C9E09AD9EFA7D3E49E8D9E57B1C57DD3EBA1
C5DF95D0EAA1D3EAA2CCE29AD9EDA6D5E6A0CCDB968F9E59
FFFCFFFFFDFFFFFDFFFFFDFAFFFEF6FFFFF6FFFFFAFEFFFFFBFFFFF9FFFFFAFCFFFFFDFF
FFFBFFFFFAFBE2CAC6AD9B8FFFFFEDFEFFE8CDDAAECFE3A8CEE89ED0F09BC9ED95C4EA93
C5EC9DC5EBA0C8E8A5C9E7A7CAE7A5CDE6A2CFE69ECFE6A2D3E8B0EDFCD1FFFFE8C1BBA5
747057DADDC2E2EED6EEFFECF5FFF8F5FFF0F2FAD3CDD7A3C4D99E668B58063A23C4F1EC
F7FFFFEEE9EDFFFEFD9D9391FFFAF4FAE3DB1100002404004A080AFFD3D5FFEFE9EEF4EA
F7FFFFF4FEFFFFFCFFFCF0FCFFFBFFFFFCFFFFFEFFFCFFFFFBFFFFFCFFFFFFFFFBFFFDF5
FFF9ECC4B59E847754B1AF7ECDD999CAE596C5ED94C8EE99CFE09CCDD79B98A367334305
96AC6BC4E19ED1F2ABC3E9A0BFE99DC2ECA0C4ED9FC2EB9CC4EB9CC9EEA0CDF0A0CEED9F
B8CE85DFF3ABBBD189E6FDB5C8DF99CFE9A2CAE5A0D2EDA8EBFFC0C2DB97D9EEA9C2D691
DCEDA7CBDA958E9B55C9DA93CEEEA5C8ECA2CEF0A6C7E79EC9E49DCAE19BE9FEB9C3D792
C7D894E6F7B3ABBC789CB06BA1B671CEE59FD0E7A1C5DF98BAD38FD4EDA9D5EEAAD5EEAA
D6EFAB78914DCAE39FC6DD99D3EAA6DDF2AFC5D896CCDF9DD9E9A8D6E6A5B8C786B5C385
D4E2A5D4EAACB3DA99C2F1AD3A682786AC6FCEE0AC899263889164DBEEC0B8DCAC3F6D3C
AFDBAA5E825631421E000700606638E7F6BFCEECACC1E6A3DCF9B77E965873874C93AC73
244C109FCB90CAEBB4CDE5ABDFE7ACCAD18ED0E296D8F0A29CB36FB6CC8C99AF6FD7F0AF
C4DA9ADDF6B5BFD8974A6321D0E7A3BCD38DD6ECA4CEE49CCADE96E6FAB2596B21D5EA9F
D7EDA4C0D88EDCF4AAC8E096BFD78DE1F9AFCBE198DAF0A7
FFFDFFFFFDFFFFFDFFFFFEFBFFFEF8FFFEF8FFFFFBFEFFFFF7FCFFF9FFFFF3F5FFF9F7FF
FFFCFFFFFBF8FFF1E8BBA99BE4E3CFFCFFE8D0DFB4D1E6ADD1EDA3CBEC9BCBEF98BEE48F
C5EC9DC5EBA2C8E8A5C9E7A7CAE7A5CDE6A4CFE6A0CDE7A0CBEAA7F0FFCFFEFFDDD7D7B5
393512D3D0AFD5D9BEF8FFEBFBFFF8EAF0E2EEF2D1DAE6B6D0ECB2426D3F003927AADEDA
EEFCFDFFFEFFDFDBDAC5BBB9FFFAF4FFFAF12A180C1800007F3E42AB6E73F7E4DEFBFFF8
F1FDF9F8FFFFFFFBFFFFFAFFFFFBFFFFFDFFFFFEFFFCFFFFFBFFFFFCFFFFFFFFFDFFFEF8
FFFCF1786954796E4ED7D5A5CCD89ACCE69CC6EC97C6E997D3E3A2D8E1A899A4681D2D00
C7DD9CC7E4A1C3E49DC9EFA6C5EBA0C6EFA3C7EDA0C2E79AC2E497C6E69AC9E89ACAE699
DAF2A8D2EAA0CDE79EC6E298CFEAA3C5E39BD5F4AEC3E29CC8E6A0D9F7B1D1EBA4C1D892
E0F6AECEE29B899A53DEF4ABC1DC95C9E9A0C7E59DD8F2ABCEE59FCEE29DD3E4A0CADB97
E3F2AFC0CF8C92A15E445511EDFEBAD5E9A4D4E9A4D2E9A3D1E8A4D1E8A4CCE39FCDE4A0
C6DD9998AF6BD1E8A4DCF1AECFE4A1C0D391D2E5A3DBEBAAC9D8978F9E5D6C7838D7E5A7
D5E5A7D8F0B2BBE4A2C2F4AF497A38CCF4B6D4EBB5D4E4B394A475C5DDADA5CD99447440
CEFECC93BA8B8AA0792D3B174C572F8C9F72C4E7B1BDE6ACC3E4ABBCD99F94AD76C7E6AD
75A26766985BAED69AE7FFC7C9D998C9D990DEFAA5BDDD88C7DE98E1F6B5819655C4DA99
CEE3A2CCE2A1D4EAA9647B37CBE09DDCF1ACD0E69ED7EDA5D4E8A0CADE967F934B849850
D3E9A0D0E89EDBF3A9CCE49AD1E99FC1D98FD9F1A7CAE298
FFFDFFFFFEFFFFFEFFFFFEFBFFFEFAFFFEFAFFFFFDFEFFFFF9FEFFF9FFFFFBFEFFFFFEFF
FFFCFDFFFAF4FFFBEDB3A491AEB09AFBFFE6D1E2B6D4E9B0CFEAA3C0E192CCEF9BC3E996
C5EC9DC5EBA2C6E9A5C8E8A5CAE7A5CCE7A4CDE7A0CAE89EC1EA9CEEFFCAF9FFD4D3D6A9
4C481BE4DFB9D2D1B3FFFFEDFFFFFAFFFFF6ECEFD2D0DDB2D9F7C58ABA9064A899548F8D
F4FFFFF7F3F4595554FFFCFAFFEEE8A28E8519070044261CA46367EEB1B6FFEFE8F3FBF0
F7FFFDF8FFFFFFFCFFFFF3FFFFFCFFFFFDFFFFFEFFFEFFFFFCFFFFFEFFFFFFFEFDFFFDF8
FFFBEF5F523F9B9273ECEBBFD7E2A8D0EAA3C9EE9EC4E797D1E1A2E0E9B09BA66A0F1F00
E5FBBBD5F0ADC2E19BC9EAA3C6EAA0C9EDA3CAECA0C6E89CC7E69ACAE99DCEE99CCBE699
CDE99EC4E095CDEBA1D2F0A6B6D68DD1F3A9C8E9A2CDEEA7C2E39CC6E59FC1DF97CFEAA3
CDE79ED4EBA39DB36ACBE399D6F0A9D9F3ACC4DB95CCE19CD7EBA6CADB97C4D390E8F4B2
AFBB79616D2BC1CD8BD0DF9CC2D18ED1E29ECEE29D9AAF6AA0B572C8DF9BE1F6B3C5DA97
CDE29FB4C98690A56284975595A866A6B6758D9D5C6979386C7B3AD1E09FBFCB8BDAE8AA
CCDEA0BDD798ACD5937CAE69C0F1AFD3FDBDB8D49AD6EAB5A7BE8AD3F1BD92BD87679A62
A8DAA5BBE7B4DCF9CDB7CBA67988691028066D94687EAC7BC5EBB8C1E3B0CBE9B5AED39D
BCEFB4073F00D2FFC0C4E9A6C3DA94D9F1A3C2E68CCFF39BC9E39AD8EDAA6B7E3CD3E8A5
E1F4B2C8DD9AD7ECA9B1C6818A9F5AD4E9A4D1E79FCAE098D4E8A0C9DD95D3E79F8CA259
879F55B8D086C1D98FDDF5ABD3EBA1BFD78DDFF7ADC3DB91
FFFEFFFFFFFFFFFEFFFFFEFDFFFEFBFFFEFBFFFEFFFEFFFFFBFFFFF9FFFFFCFFFFFFFFFF
FFFDF7FFF7EBFFFBEAAA9E86A3A78CF2FFDDC9DCAECCE4AAC9E7A1BEE093CDF3A0C8EF9C
C5EC9DC5EBA0C6EAA4C8E9A4CAE7A4CCE7A2CDE7A0C9E99DBCEC96E6FFBFF0FFC5D6DBA5
5B5523ECE3B8D6D1B1FFFFEDFCFBF6E7E8E2E7EBD4E2F2CDB1D2A582B992337C718FCCCD
F4FFFFFFFDFF817B7BFFFCFAFFF7F1BAA69D2616094A2C24D39296EDB2B6FFF8F1FAFFF7
F7FFFDF6FFFEFFFCFFFFF5FFFFFDFFFFFEFFFFFFFFFEFFFFFEFFFFFFFFFFFFFDFDFFFCFA
D7CAC17D705FC9C2A6DADBB3D6E3ADCEE4A3CEF0A4CCECA1C9D99AD7E0A798A369304002
B4C889DAF3B1CFEDA7C5E49EC6E69DC8E89FCAE89ECCEAA0D3EDA3D6F0A6D4EAA1CBE399
CEEDA1CDEDA1BDDD92D2F4A8C8EAA0BDE197D6FAB2BDE199D2F6AEC7E8A1C1E198D1EFA7
BAD68CCEEAA0A0BA70C5DD93D3E8A3C4D994D3E7A2CCE09BD4E5A1D4E3A0DFEBA9D4DF9D
96A15F6E7A38D0DC9ADBEAA7DEEDAAD1E29ED2E39F5B6F2A596C2ACADF9CD0E3A1CFE2A0
DEF1AFC2D5938C9F5D7686455B6B2A3F4E0D4958179CAB6AB6C282E4F0B0D6E2A2D5E3A5
99AD6E87A4628FB87444732DC5F4B0B1DB9BD4F3B8BCD59E748F5874955E538047ACDFA6
B5EBB1B7E6B0BDE1B1D1EBC4455842000B004E7A5922552C8AB58ACCF3C4B6DAAAD5FDC9
B4EEB338763777AB69BEE9A4CBEBA0DBFBA8B1DD7ED2FDA1C3DD93D7EBA6798A46C3D792
C5D692DAEEA9CADE99D2E69F566A23D4E8A1C8DE96C9DF97D8EEA6D7EDA5DBF1A9C9E098
B1C97F88A056839B51D1E99FC7DF95DAF2A8B9D187DFF7AD
FCFFFFFEFFFDFFFFFDFFFFFBFFFEFBFFFEFDFFFEFFFEFFFFF6FBFFF7FCFFFAFEFFFFFFFB
FEFAEFFFFEEDFFFDE6B7AC90DAE1C0F8FFE1CAE0AFCBE5A8CAE9A3C7E99CCBF19EC3EA97
C5EC9BC5EC9DC6EAA0C8EAA0C9E9A0CAE8A0CCE89EC8EA9DBFEF99CBF6A4D6EBAAE1E6AE
615B27E0D8AADEDBBAF7F9E4FEFFFDFCFFFFF5FEEDB9CCAEC4E7BF8CC2A23F867EC9FFFF
F0FFFFF9F3F5B3ADADFFF9F7FFF6F085716A17060060433BFFC1C4A2676BFFF7F0FBFFF8
ECF7F1F5FEFDFFF9FFFFFAFFFFFBFFFEFEFEFFFFFFFFFFFFFFFFFFFFFEFFFFFCFFFFFCFA
B0A39BC2B6A6F3EDD3CFD1AAD3DFADC7DD9FCAE9A3CEECA6D6E6A8D5E0A6889359041300
A3B778CBE1A1D1ECA9CDE8A3CCE7A2CCE7A0CCE69FCEE89FD3E9A1CEE49BBCD088A9BF76
456418426417D4F4A9C2E498CFF1A7C8EAA0A7CB83D3F7AFC2E39CCCEDA6CCECA3CEECA4
C5E399CDE99F8AA45ACFE79DCCE19CCBDF9AD6E7A3D3E4A04D5E1A94A36098A4626B7735
96A260DBE7A5D3E29FD2E19ECAD996DBECA8768743C9DD98D1E4A2314402DDF0AECEDE9D
CDDD9CD8E7A6E2F1B0C8D796DDECABD1E09FD9E8A7D7E6A5CEDA9ACAD696D9E5A592A261
8DA2619EBB7985AA6579A45FB7E29DAFD695DDFCC0D1EDB38EAB71001700133F04B4E6A9
BCEEB3BBEBB1C0E7B27C9B720D2412637F719BC9AF99CDA98CBA9386AF83C2E8B9BBE7B4
B6F1B75A9B5B477F3ECBFAB6C9EAA3C6E999C4F599B3E085DAF4AACCDD99B1C27C96A761
CFE09AD5E6A0D3E49ED6EAA28DA15AA1B56EDCF2AAD2E8A0DBF1A9C3DA92C7DE96D3EAA2
CCE49ACFE79DC0D88E8AA2589AB268ABC379E2FAB0C4DC92
F9FFFAFBFFFAFEFFFAFFFFFAFFFFFBFFFFFDFFFFFFFEFFFFFCFFFFFBFFFFFCFFFBFFFFF6
FBF8E7FFFFE8EFE0C3A49C78F5FFD6F3FFD8CBE4ABCFECAACBEBA2CBEE9EC4EA95C1E993
C5ED97C5EC99C6EB9BC8EA9DC9E99DCAE99DCCE89DC9E99DC5EEA0C2E69ECCDBA2DBDBA9
ADA777E3DEB4EAEFCFF0FBEAEEFCFCF3FFFFE4F4E7C1D8BEC9EBC80A381C276361DCFFFF
F7FFFFFFFCFDFBF6F3FFF9F47F6C680F000035271CB1948EFFC2C7EDB4BAFFF3EFF3FAF2
F8FFFDF3FCFBFFFCFFFFF5FDFEFCFDFFFFFDFFFFFDFFFFFFFFFDFFFFFBFDFFF6FAFFF4F4
90857FFDF4E5FFFFE8E6EAC7DBE8BACFE4ABC7E4A2CBE5A4DEEDB2D8E3AB919C62000B00
C8DA9CC7DB9CCEE4A3CEE7A3D2EBA7D1E8A2CFE49FD0E69ED3E49EC4D58FA4B46D83974F
C9E59AD2F2A6527026C5E59AC6E69DD0F0A7DDFCB6BFDE98BFDE98C5E39DD3F1A9CBE69F
D1EDA3D2ECA37E984ED3EBA1D5EAA5DCF1ACCDE19CD0E49F4E621DC5D692D4E5A1D6E7A3
D7E8A4BACB87E5F6B2CFE39ECDE19CCCE09B8FA35ED1E5A0D2E5A3C2D2914D5D1CDAE9A8
D9E8A7DCE8A8C1CD8DE1EDADCDD999D6E2A2DDE9A9CDD999DDECABE2F1B0D0DF9E687837
D4E9A8DBF6B3809F5BBADD99DAFDB9CFF2B0C2E0A2C2DEA3C6E4A8002100234B0D8EBA7D
C5F1B6C4EDB3BBE0AA57764C000900001507ACDAC0C6FAD6C2EFC84B7246BEE2B4C8F2C0
B5EEB70C490EC7FFC2B0DE9EC3E6A4B9DD95C9FBA6CEFBA8CEEA9FC0D48DDEEFA991A25C
D8E9A2D1E29BD1E29BCDDF95D4E59E50641CD7EDA4BDD38ACAE199D9F0A8C2D993D9F0A8
D0E89ECCE299D8F0A6C3DB91CCE49A455D13C6DE94D3EBA1
F7FFF3F8FFF3FBFFF4FEFFF8FFFFFBFFFFFDFFFFFFFEFFFFF8FCFBF6FDF6FBFFF5FBFFEC
DDDBC2DED7BA9E916F565127D7E5B0CDE7AABEDB9BCFEDA7C6E69BC8EB9BC2E893CCF49C
C6ED94C6EC95C8EB97C8EB97C9EA99CAE99BCCE89BCAE89EC9E9A6CEE7AED4DAAEC2BF96
FFFFD8F5F7D0F5FFE7F0FFF8E9FFFFE7FFFFD3EFE3CBE7D09EBD9D03291023514FDCFEFF
F8FDFFC2B9BAFFFDFBFFFDF81E0B071C090362544BB99E97FFE0E5A76E74FFEEEAFBFFFA
F3FEF8FAFFFEFFFBFFFFFBFFFFFFFDFEFFFBFFFFFDFFFFFDFFFDFFFFF8FBFEF2F4FBEFEF
6F645EFFFFF1FFFFE7FFFFE3E9F6C8DFF4BCCCE6A9CAE2A4D1DEA6CFD8A1B6C187667439
D6E5AADBEDAFD5E9AAC6DB9AD2E7A4CFE4A1CFE39ED6E7A3DBEAA5CBDA95A6B36D80914A
CBE399D9F5AA85A157D9F5ABCAE59EC7E29BCAE5A0DCF5B1EFFFC4C6DF9BD9F3ACC7DE98
C6DD95D3EAA28BA158D3E9A0D4EBA5C8DF99CFE49FADC27DCFE49FDAEFAAD1E6A1D0E5A0
CADF9ADCF1ACD5EAA5CBE09B97AE6893AA64C5DC96D6EBA6D9ECAAC9D9989DAC6B7E8D4C
CEDA9AD4E0A0E7F1B2D0DA9BD8E2A3D8E2A3CFDB9BE1EDADD5E4A3C6D5949CAB6A8F9F5E
C9DE9BD2E8A793AC6ACBE6A3C6E19EC9E3A2D7F1B2CDEAAAAFCB8E0010005D7C40C2E6A8
C7EBAEBADEA1D2F3BA7693653D533E122D1C89B699BAEAC4BCE5BB65895BC3E3B4BBE1AE
B9F0B94B864CB1E4ACCAF5BDC7E6ADD3F3B4BCEAA1BBE79CC0DE96E7FCB7CDE19C849851
74853ED9EAA3CBDB92DDEDA4DAECA29AAF646E823ABCD289CBE29ACAE49BD9F3ACC6E099
D6EDA5CDE39ACCE49ACFE79DE0F8AEC4DC929BB3694F671D
E6F9DBE5F5DAEBF7E1FAFFF2FEFFFAFFFFFDFFFFFFFEFFFDF7FCF6FBFFF6FCFFF1FEFFEA
D6D5B6DBD7B25E552C7E7C4BD2E4A6CAE8A2C9E79FCAE89ECBEC9DCBEE9CC8EC95C4EB92
C7EB91C7EB91C8EC94C9EB95CBEB98CCEB9BCDE99ECCE5A3D2E4B4CAD4B1ECE6CCA19A7E
FFFFDFFCFFE4E2FFE6E0FFFDA4D5D987B6BC4F776F27483389A485A3BBA3D2ECEDEFFFFF
FFFEFF8F8785FFF9F6FEF3EF2917131D0A04A2948BFFEFEBFFE6EDEFB8BEFFFBF6F4FBF3
F2FDF5FBFFFFFAF0F8FFFBFFF8F8F6FCFFFBFAFAF8FFFEFDFFFCFFFFF8FCFFFBFD554949
968D86FFFFF1F9FBE3FEFFE3F9FFDCCCE1A9CEE8ABD0E6A8B2BF87646D36C9D49C6A783D
95A368D3E3A5D9E9ABA7BA7A92A563485B19657632D3E4A0D9E8A3D9E6A1D1DE99D2E19C
D9EFA6C5DD93ADC47CD4EBA3C1D691D8EDA8D2E7A4E5F8B6F9FFCAD6E9A7CDE19CDDEEAA
CBDC96C9DA94DEEFA8CADE96CDE7A0CFEAA3D2EDA6A8C37CBFDA93D0EBA4C8E39CD0EBA4
CEE9A2D1ECA5A7C17A1A3400B5CF88BFD992D0EAA3CCE39DDBEEACCFDF9ED4E3A2BAC988
939F5F8D97587A834450591A949D5E9CA667687434D6E2A2E0EFAE8999584A5A19D4E7A5
D6E9A7CCDF9D98AB69C9D998C2D291DDF0B0DEF4B3BDD69593AB6D37511288A064D7EFB3
C8E0A6C5DEA4CEEAAF779161526247445B41A8D0AB1E491CC9EDBDCAE8B6C8E3B0C7E8B3
B9EAB32B602A23521E8AAE7EC6E0B1D0EBB8C2EBAFB8E2A2CBE8A6CEE5A1D8EDAAAEC37E
6D813ACEE29ADCEEA4C9DB91CCDE92D3E89D8DA15999AF66CEE59DC9E39ACFEAA3C7E29B
D7EEA6D0E69DD0E69DD4EAA1CEE69CC9E197C9E399CEE89E
DBF5C8D9EFC8E0F1D1F1FAE5FEFFF6FFFFFBFEFFFDFCFFFBFCFFF8FBFFF3F5FEE3F8FFDD
D7D9B1E5E2B7625A2C969660D2E7A2CBEA9ECAE99DCAE99DC9EA9BC8E998C7E995C7E993
C8EB91C8EB91CAEB92CBEC95CCE999CAE69BCCE7A0D3E8AFE1EBC8DCD9C6D1C5B7918474
FFFFE6F2FFE4E6FFF6A2DACD65A4A91B575F73A49E618372E6FDE0F3FFEAF9FFFFF5F5FF
FFFDFF665C5AFFFDFAA398940D000028150FD2C5BDFFF3EEFFECF4D199A2FFFBF8FBFFFA
F8FFFBFCFFFFFEF3F9FFFAFEFDFFFAFAFFF9FFFFFBFFFEFDFCF1F5FFFAFDF9EAED675958
B4ABA4FFFFF1F9FDE4FBFFE3F9FFDCCCE1A9CBE3A7CEE2A58B986059622BD4DFA7131E00
A2AD73D7E5AACCDA9D7C8C4E8F9F60A6B6752E3E00A8B975CEDD9ACBDA95D4E39EC6D791
CEE29AD5EBA29BB169B0C47DDBEFAAD8E9A5DBEAA9D3E2A1EFFBBBECF8B8E5F1AFC9D593
D6E39EE7F6B1C0D089A2B66ECCE69FBEDC94C7E59DA4C47BD0EEA6CBEBA2C6E49CC8E69E
C0DE96B8D68E76914A839E57BFD992D8F2ABD6EDA7CCE39DC9DC9ACEDE9DD6E6A5CAD998
8F9B5BA1AB6C939C5DA1AA6BD5DE9FD5DFA07C8848ABBA79C8D8979BAE6C6E8340D8EDAA
C9DE99CCDD9996A260E3EDAEDBE5A6D6E2A2CADD9BD0E6A5D6EFAD465C1C8D9D5FC9D79A
DDECB1CDDFA3CFE7A9AEC58F616F4C8598786D91650019008AA970D5EEB5D6E9B1C8E4AA
CAF3BB95C48E12390A466539C8DDB4CBE2B6C7ECB9C9F0B7C9E8ACCBE5A4D0EBA8C3DC98
B2C782ABBF77D5E9A1D3E59BDAECA0D2E79AD0E69B81994FACC67DC5E197D2F0AACAE59E
C6DD95C2D88FC6DC93D0E69DD6EEA4D7EFA5D0EAA0C9E399
CFECB2CDE8B3D3E8BFE3F0D4F3FAEAFCFFF6FEFFFBFCFFFAFCFFF4F9FFEBE6F1CFF1F9D0
DDE0B1D0D09E554F1D929359D1E79CCBEB98CBEA9CCAE99DC8E69CC8E79BC9E89ACBEA9A
CCEC97CAEB94CEEC96D0ED9BCCE69CC8E19DD0E8AAE0F0C1DDE1CAF8EFE6FFF8F19F8E84
FFFFEAECFFE3B5E5CD62A49680C9CFBFFFFFDBFFFFE7FFFAF5FFEAFFFFEDFBF2F5FFFAFF
E1D5D7DBD1CFFFFAF7493E3A180602170400EFE2DAFFF8F4FFDCE6854D56E1D2CFEEF5ED
F8FFFBF8FDF9FFFBFFFFFBFFFCFFFBF4FEF5FEFFFBFFFCF9FFFBFDFFFAFDCEBEC15C4E4D
F0E7E0FFFFEFF7FFE3E7F6CFE0F2C2CADFA6D3E9ABD8EAAC949F67AAB37ED7E0A9000A00
5F6A30DFEDB2CFDDA06E7C3FB8C889DBEBAA87975681924EE9FAB6E0F1ADBACB87D4E8A1
CDE199DFF3ABD6EAA396A7613D4C09CBD795E0EAABD2DC9DD3DD9ECBD596ABB6745F6A28
68732F84914C7F8C46C6D790D4EFA8C6E69DC2E299AFD187CCECA3C7E99FC0E097CFEFA6
D4F4AB8EAC648CA760DAF4ADDAF1ABCCE39DCADF9AD2E7A2D8EDAAC1D492DBEBAACBDA99
E4F0B0D7E1A2D3DC9DCFD899CCD596EAF4B5CAD696A0AF6E738644A3B875CBE29EC5DE9A
DBF2ACD6E7A188914ED2D797DFE4A4D9E2A1D1E5A0DAF1ADC5DC985164249FA96CE0E6AA
DBE0A6C8D296E1F5B640531B5762385E6F4572935E001200849E5FD3E8A7D1DFA1C4DA9C
BDE1A4AFD8A0C4E8B8B3CEA34C5C371B2D075D7E53A4CA97C6E9B1C2E1A5BBD99BCAE7A5
E6FFBB879E5883974FD8EDA2DAEFA2C5DA8DCDE398DAF2A89AB46B8AA65CA5C37DC4E29A
D0E79FECFFB9DDF3AAC6DC93CEE69CCBE399C3DD93D6F0A6
C7EBA3C6E4A4CAE2B0D9E9C5EBF4DFF9FCF1FEFFFAFCFFF6F6FDEBFBFFE8D8E4BCDBE7B7
D4DBA79C9C6668632CA1A364CFE698CAEA97CBEA9CCAE89EC8E6A0CAE5A2CDE8A3D0EAA1
D1EC9FCEE99AD1E99BD2EAA0CEE4A3CEE3AADEF0BEF1FFD9FEFFEEFFFAF0FFFBF4B3A298
FFFFE8F5FFEA8CBCA21E6052B5FFFFCDFFFFD8FFFFE9FFFBECF9DFFFFFECFFFAFBCFBBC4
7F7171F5EAE8FFF8F33227230D000063514DFFF7EEFFEEEAFFE6EFA36E78E4D6D5F6FDF5
F8FFFDF0F5F1FFFBFFFFF5F7FBFFFBF8FFFAFEFFFBFAF5F2FFFAFDFFECF0A08D8F8D7E7B
FFFEF4FFFFEDFBFFE6D5E6BCC9DDAACCE1A6D4E9A8C7D798A2AD75CBD49FE2EBB4131C00
727B44C6D197E4EFB5A8B679D1E1A2CEDE9FDFEFAE7A8D4BCADE99C3D792849954D5EBA3
D1E79FCAE097CCE099B7C88273823FDDE9A7CAD495DAE4A56F78399DA768BAC5839AA563
99A46096A35E909D57D5E9A1C9E39CD3F3AAC3E39AC2E299C1E198CBEBA2BDDD94D2F2A9
D0EEA66F8A43B4CB85C9DE99C4D893D9EAA6CCDB98DDECA9CADD9BE3F8B5CCDF9D768645
8A9656909A5BAEB7787A8344DFE8A9CFD99AD0DF9ECDDD9CA8BD7ABDD692E9FFBFC6E49C
C8E49AD1E79FA0AB67C3C886D1D694D2DB9ADBF0ABBFD992D1EBA4364A059FA567D9D99D
D9D99DE9EFB1C2D291425619757E5193A0745673395F7F3E889F5995A660D3E09BD0E49F
C6E9A7D3FBBDCAEBB6B4CEA1B8C7A073855D2D4E236C9462AAD19CD4FAC1D3F7BABDDD9E
C6E3A18FA864496018D4EAA1C0D58AD7EEA0DCF2A7D0E89CB3CD84B8D68C65833DCEECA4
D1E8A0B1C77ECCE299E7FDB4C8E096C2DA90D3EDA3C9E399
C7EE9BC3E89BC6E2A7D3E5BBE7F1D8F7FEEEFEFFF6FBFFF3FBFFECFBFFE4D0DDB1C2CF9A
BDC58C6A6E33A7A56AD5DA98D0E799CAE999CCE89ECBE6A3CAE4A7CAE2A8CBE3A9CEE4A6
CEE4A3CDE4A0CFE4A1D0E4A7D2E4B0DBECC0EEFCD9F9FFEAFBFFEDFFFFEFF1E5D5BCAF9C
FFFFE1D7E7C3CAF5D7458272569BA08FCFD9DAFFFFEAFFFCFBFFECCCC5B2887676EBD6DD
FFFAFBEFE4E029201B08000053413DBAA8A4FFF7F1FFF8F6FFECF8EDB8C2FDEFEEF9FFFA
F8FFFDF4F9F5FFFBFFFFF6F8F9FFF9F8FFFAFEFFFBFFFBF9FFF3F6FFF8FD6E5A5CFDEEEB
FFFEF2F4F8E1F9FFE4D3E6B8C9DEA6D4E8A9CCE09B99A867B0B980D9E0ACCCD39F656E37
8B945DC1CC92778248D5E3A6D3E3A4CFDFA0C9DC9AAFC48197AE688DA45E8FA962CEE89F
CAE49BCBE59BD2E9A1CFE59DB7C884A3B26FE4F0B0919D5D959F60CBD797DDE9A7C9D895
C8D792D7E8A2DBECA5D1E59DC2DC95D2EDA6C7E29BB2D088C8E69ECCEAA2CDE8A1C8E29B
AFC68093A863DFF0ACE1EDABC4CF8DE2E8A8A3A8688B945391A1607F9451263900788847
8D99598E98598B9455767F40B5BF80DDE9A9D5E5A4CEE19FE3FAB6CCE7A2C3E19BC8EAA0
C5EA9DC0DF93ACBC758D94508188448A9752D4EEA5CDEDA2D2F0A6E5FBB3BEC484828043
5C5A1D848949CFE09CD3E7A8DAE3B4DBE8BABDDB9FC1E29DDAF2A890A055AEBA70E1F3A9
C4E69CC6EEA8B8DA9DD8F3BED4E4B7CADDAFD3F5C380AB76032F0077A26DC1EAB2BFE5AA
BDDD9ED2EFADA0B975B2C981D2E89DE3F9AEC0D68BC9E195DFF9B0BBD98FC8E6A0CAE8A0
70873F8A9E569FB56CBAD087D6EEA4D9F1A7CDE79DD0EAA0
C7F394C4EC96C5E4A0CFE5B4E4F1D3F8FFEDFEFFF4FAFFF1F8FFE8FBFFE3D8E6B5C5D29A
A6AE72595E1ED2D093E5EAA8D1E79CCAE99DCCE7A4CEE6AAD0E7B3D2E5B7D0E4B3CFE1AF
CEE1AAD4E6ACD4E5AED2E2B1DBEAC1EDFADCF8FFF0F8FFF1E3F6D8F9FFE6FFFFE6A89F80
FFFFDAC8D3A9D1F4D3B3E6D50F4A506DA7B3E0FFFFEDFFFDEBF3DBE7E1CBE7D5D5FFECF3
FCECECFFF6F20900000C0100BBA9A5E6D7D2FFFDF6FFECEAFFE4EFE7B4BDF6E8E7F9FFFA
F2FDF5FBFFFCFFFBFFFFFBFDF9FFFBEBF8EEFEFFFBFFFDFBFFEEF2FFF8FB4B3537FFFBF6
FFFFF1F7FDE3F9FFE3D0E4B3CBE0A7D6EBAAD2E69F8D9C59D4DDA4D9E0ACECF3BF060D00
929B64969F683C470DD3E1A6DFEFB1C3D696D2E7A6DCF3AFB7D08C98B36CC6E19ACEECA2
CFEDA3E0FFB3BAD48BCAE199DBF0AB4A5E195A6928D2E1A0CFDE9DD9E8A7D5E4A1D6E7A3
D0E49DD7EBA4E0F6ADC1D78EE0F7B1D5ECA6C2DC958BA55ECFE9A2C2DC95E3FAB4C6DB96
8A9B5799A865D0DB99D9DF9FA6A8695A581B575316585A1B8F9F5ED8EFABB8CD8ADEF1AF
D1E09FD7E3A3DAE4A5949E5F808A4BDFEBABE6F6B5C0D592C5DE9AC7E59FC6E7A0BDE398
C5F0A1BEE395E3F7AFD9E49FCFD994B3C37CC5E399C4E99CC8EA9EB6D087DBE29FEFEEAE
E5E1A2C6CB89637730768C4CD1DDADDAE7B9CEECB0DAFBB4BED68AE2F3A34A5707CEE190
CEF1A1C0EA9EC3E6A2D2EEB1C4D7A0CEE2ADDEFFC9ACD9A043733F6595638BB782D0F9C1
CBEFB2C5E5A4CEE9A64E681FD4ECA2BED489D6EEA2D3EEA1CCE69DD2F0A6C7E59DDBF9B1
C7DD958CA05852681F839950DCF4AAD6EEA4B6D086D6F0A6
C5F48EC5EE92C6E69BCFE6B0E5F3D0FBFFEEFEFFF3FBFFF0ECF5DAE6F2CCDDEBB8D1DFA2
8992536A6F2DDAD999D5DA98D1E59DCBE69FCEE6A8D6EDB9E1F3C9E7F7D2E4F4CFE0EFC6
E1F1C4EBF8CAE9F6CAE2EEC6ECF7D9FBFFF1FAFFF9E2F0E1D9F5CFE7FFD1F0F7CDA19C72
F8F5C2D4DAAAB8D2ADC1EBD75B8C9386B6C4DDFFFFEFFFFCFCFFEDA8A38FF0E2E1FFF9FF
FFFAFA4D3F3C080000473C38D7C5C1FFF9F4FFFDF6FFF9F6FFEAF5B38089F4E6E5F9FFFA
F4FFF7FEFFFBFFFAFDFFF7F9F9FFFBF1FEF4F7F9F4FFFDFBFFF9FBE4CED1725C5EFFF3EE
FFFFEFFEFFE8F8FFE1C9E0ACCBE3A7CDE4A0DCEDA69BA863D1D9A0E4E8B5D5DCA8010800
5C652EA2AB74727D43E3F1B6DBEBADB6C989E8FDBCD0E7A3D7F2ADBFDD97CEECA4C6E69B
C3E599C4E699C9E79DD3EFA5C2DC95B3CA84849755D3E6A4E4F4B3CADD9BC8DC97CEE39E
D0E79FCDE49CC7E197D0EAA0C4D994C2D691AFC47F94A964D0E5A0C5DA95E0F4AFCFE09C
A6B270B8C180D1D696D0CE918B85495B5116A99D63DDD99CD2E2A1D1EAA6D2E7A4C7DA98
DDECABD0DC9CDAE4A58E9859AAB475C0CF8EC3D694D5ECA8D2EDA8D1F0AAD1F5ADC3ECA0
C2F3A1B7E290CDE599D0E097DDEAA2C7DC9192B467B8E192D1F8A9D1EDA2D3DD98E3E2A1
E1DD9DDFE4A1C6DC939EB775B7C496CBDBAEC0DFA4BCE09AD3EEA1D7EA98B3C26FB6CC77
BEE48DB5E28FCBF1A4C7E6A0D2E8A8D0EAA9B1DA94C7FAB8CEFFCF9CD0A04A7A48B2DFA8
C3EBAFBEE1A1E5FFBF98B26B89A058DFF7ADD2EA9EBDD88BCAE49BD8F6ACB0CE86CEECA4
D1E79FD1E59DDFF5ACA4BA715971279CB46AE7FFB7C0DA90
C8EE9BC7E99CC6E3A1CFE6B0E5F5CEF9FFE6FBFFE8FAFFE5E7F3CDCCD9ABD5E2ACCCDA9D
677132828B4AE0E5A3DAE3A0CEE39ECAE3A1CFE6AEE0F3C5F2FFDEF9FFEAF9FFECF7FFE8
F9FFE8FCFFE8FCFFE8F3FCE1FAFFEBFBFFF3F5FCF4CEDBC9C8E4B4C7E5A9C9DDA0D4E0A2
7D834588925DD2ECC7A1C3B2375C6285A5B0EFFFFFE9F3EA9BA08AFFFFEEFFFCFDFFF4FB
FAEAEA2617120A00008C7F79FFFAF6FFFAF4F6F3EAFFFBF8FFE1EA66333CE2D2D2F8FBF4
FBFFF9FFFFFAFFFAF9FFF8F7EFF2E9FCFFF8FFFCF7FFF7F5FFF6F86C585AC6B2B3FFFCF6
FFFEEFF7FDE3F6FFDED0E4B3D7ECB1C5DA97D3E79F94A45DD6E0A4D6DDA7DADEAB333704
767D4989925DB3C289CBDFA2CDE3A3DCF5B3CCE39FC7DE9AC2DB97D4F2AAC5E69FC6EAA0
C7EDA0C6ED9ECCF1A4CAECA0CBE9A1D1ECA5D3ECA8CAE19DCDE29FCADF9CDFF2B0CBE09B
D3E8A3C9E09A788F49637A32677B3494A86193A760C7DB94D6EAA3D8ECA5CFDE99D3E09B
8B9451D5DA9ADEE0A1E6E4A7706C2FDFDB9EDDD99CE6E8A9D7E6A5C4D996D6EBA8D1E6A3
C7DA98DAEAA9C9D897A1AB6C8E9758E2E8AADCE5A6D1DB9CCFDE9DD0E3A1C5DC98CEE9A2
C0E296D1F3A6CEE89EC9DF96D6E89ED6EBA07A9649CDF0A0BEE395D2EEA3E5F0ABC9CC89
E6E7A5DDE8A3BADA8ECBECA5859360808C5CC6E2A7CAEBA6CDE99CC9E28FD7ED9A6A842D
8BAF58C7EF99C3E598CAE69CD0E7A1C4DE97D1F7ACB8EAA3ABE2ABC2FAC9518350A7D39E
BCDFA7D4F2B6BCD697D4EDABC7DE985D742CCCE69DD5F1A7C7E19ACEE8A1D6EFABCCE39D
D5E9A2D2E39CC9DA93D6E7A0D0E19A91A55E8B9F58D4E8A1
E1F1CCE8FAD4DBEDC3C9DFB1D3E9B8E2F9C3E5FAC2E3F6BEDAE9B0DCEAAFD6E1A7D9E4A8
748042B7C685DAEBA7C7DB96CEE5A1D3ECABE1F5C0EEFFD5F8FFE9FBFFF1FCFFF8F9FEF8
FCFFFDFEFFFBFEFFF8FBFFF3F8FFEDFCFFEFF6FFE8DBE6C4DBEAB3BED88FD1F9A3C5ED97
B2CC828FA66EC1E3C291B1A44961657E898FE1D7D8A2958DA0A390FAFFF2FFFAFFCFC2CC
80716E0D000043322AC9B6B0FFF7F3FFFCF6F2FAEFFFFFFAFFF2FABD8E98F5E0DFFFFEF8
F6EFE7FBF2E9FFFCF4FFF0E9FCF2E8FFFDF4FFF8F2FFFBF8FFFAFB58484BF1E5E5FFFCFA
FFFFF4FFFFEDF5FFDDDDEABED7E8B1C9DE9DD3E79F8A9E56D7E7A6CFDA9EDADDA85D5D2B
8082519AA470C7DFA5C7E7A6C7EAA6C8E9A2D2ECA3D4EAA2CFE69ED0EBA4CAF0A7BCE69C
BCE899BFEA9AC4ED9ECBF2A3CCF1A4C9EB9FC9E79FCBE69FE2F9B5B3C885D8EBA9B6C687
8C9C5DD0DEA089975962713065772D8EA356B7CE80C8DF91E3F9AED5EA9FB7C780A5B06B
949B57EBF0AEDADC9BD0D5939CA763DAE9A4C7DB96D0E49FCCDB9AD8E6A8D8EBABCBE1A0
D1EAA8D1EAA8CDE0A0919B5E9E9D64DCD39CE2D29EF7E6B2BBAB77ADA26C9B945D97955A
787A3BD5E09EC1DB92CFEDA3CFE79DCFE19776833BC7D78CD7EFA3C7DF93D4E49BE0EAA3
D5DC98D0E49CC2F3A2BFEEA093A1645A5F27C6D697D5EFA8CEEEA2CAED9DC6E796A4C471
92AF5DBED688DCF1A6D2E39CC3D48DDEF4ACC6E49AC7F2ABACE6A9C0FDC4497E46BBE3AE
C8E3AED2E4B0CDE0A8D6EAAFCCE0A35C7534C2E19ECEEDA9D9F2B1C3D597D4E2A5D5E1A3
DFEAA8C5CE8BE4EDAAD2DB98D4DD9ABEC484545A1ADDE2A2
F5FCECF9FFEFEBFAD9D1E7B9CBE7ADD0EDABD0EBA6D1E8A2D4E4A3D5E1A3CED89C4B5519
8E9C5FC7DA9AD9EEABD2E9A5CFE5A7DCF1B9EFFFD2F9FFE4FBFFEFFBFFF7FCFEFDFEFDFF
FFFDFFFFFEFFFFFEFFFDFFFCFDFFF5FCFFEFF5FEE3D5E0B8D9E2A9D1E79CBDEC8EC2F898
C0E798AFD097CBF0D149695EDBEDEF8F9095E2CDCCFEEAE1FFFFF1FBFFF7FFFCFF564A54
23190F190C00473727FFFBEDFFFBF1FFF7ECF8FFF6F5F7ECFFE8ECE6B9C0FFF8F8FFFCF6
FFFCF6FFFDF4FDF0E7FFFCF3FFFBF1FFFBF3FFFBF4FFF6F39C8E8E665A5CFAF0F1FFFEFB
FCF9F2FFFFF1FBFFE4CBD6AED6E4AFD1E3A5CEE29D96AC63CEE39EE3F3B2D4D99F555521
242600CAD7A2D3F1B5C0E7A4C4F0A5C1EA9CC9E598C2D88DC7DD94C2DE94C5EDA4C2F1A3
CFFBACB5E291C5F0A0BEE798AFD687C6EB9ED2F2A7C9E79DC6E099E6FBB68194529AAA69
E0ECAECFDB9DD3DDA1DDE7A8DEF0A6D3E899C6DD8DD8F0A2BED587D8EDA0E3F0A86D7730
B3B875E6E9A6D9DB9A4B520F8F9E59C2D991D6F4ACD3EEA9DFE9AC9AA266829253D0E6A5
C7E29FCFEAA7DAEFAE8F995CAAA86FE3D6A1745E2C8069376E572586723FBEB17C847943
5A4D16DEDCA1DDF2AFCDEBA3C5DC94D8E9A2979E589AA25983984D96AC61ABBB72D6E39D
DAE5A0CBE59CC2F7A5B5E697D3DFA1AAA970D5DFA0CEE39EC6E69BC6ED9ECCF3A4C6E999
80984CE9FBAFD1DE96D9E59DDFEFA8C3D78FD5EFA6B8E099BEF4B6ADE8AE3B7137C1EEB7
C4E7B1D4F1BBC3DEA7D6EFB6D7F0B6BDD7986C84464C6021CDDD9ED8E2A5E1E7A9DEE4A6
CEDB96EAFBB5D0DF9AD5E49FE5F1AFC7D290CDD393575D1D
EEF8E0F6FFE8E8FAD4CDE5B3C5E1A4C6E3A0C8E39CCCE39DD7E7A6C9D597DAE3AA353E07
BCC78FD2E1A6D4E6A8C3D79CC6D6A7D9E8BFF4FEDCFCFFECFEFFF4FDFEF9FFFEFFFFFDFF
FFFDFFFFFCFFFFFCFFFEFEFFFEFFFAFCFFF4F4FBE9D4DEBCD0DAA5D9EFA6BFEA91BEF097
C1EDA0B6DFA7A7D0B266877EE0F2F4A7AAAFF6E6E6FFFBF3FFFFF3F9FAF2FFFCFF120C0E
0602004B4722AEA586F8EDD1EADBC4F3ECD9F8FFEFFFFFF1FFF3F4C29399EBD1D27C6E6B
978E89B4ABA6FCF3EEFFF6F0FFF7EEFFF8F0FFFBF4FFF0ED968888B7ABADFFF7FBFFFBF8
FFFFF8FFFFF1FFFFEAC5CFAAD9E7B6D6E8ACCADD9B94AA62D9F3AABDD28DD1DB9E9EA36B
2C3300DDEFB5CCECABC0EBA3B7E696BFEA98D5F4A4D3EB9DE6FCB1CDE99EC3ECA0BFEB9C
C1EC9CB5DF8DD1F8A7D2F7A7C9EC9CD1F1A5CBEA9ECEEA9FD6EDA5BCD28A4B5F1898A963
C8D492F1FDBBCBD694D3E09BD2E49AC8DD90DAF1A3BAD085DDF3A8D5EA9FEAF7B18A944F
E5E7A6D9D999DBDB9D6B70309DA967D3E8A3D3EEA9B5CC88C3C98D9293594E581BDAEDAD
CAE09FCEE7A5D5EAA9A1AF717C8045AEAC733E3500665B25807942ACAA71E9EDB298995F
5F561FE1DCA2D6E5A4BBD28CDAF0A8D4E8A099A6609AA75F94A55E9BAF678F9F58B0BD77
D7E6A1CCE69FC2EEA18CB46B8F975B9F9E65D5DFA2D6EBA8D0EEA6C4E99CC2E799CDEE9F
90AB5ECADF94D3E39CCBD892D2E39DD7EDA5CFEAA3C0E39FBFECB1B9ECB4659A62548E53
67A96BBDFBBCAFDFA3BEE6AABBE2A3D8F5B5AFB77B6F6F31A0A261BEC17CD8D892E0E89F
C5E196CBF2A3C1E699CBEDA1CEEEA3C8E49AE3FAB2687E36
EAF7DBF0FFDCDFF4C9C7E2ABC4E3A0C8E89FCCE89ED3EAA4D0E09F737E424F5620BDC490
DEE6B3D3E0ABDDEEB7D0E0AFD1DDB9E3ECD1F8FDE9FFFFF3FFFFFAFEFCFDFFFDFFFFFCFF
FFFCFFFFFBFFFFFDFFFFFEFFFEFEFCFEFFFAF8FEF2DFE8CDDBE7B5D5EAA5D6FBABBDEA99
ADDF9675A66F001D0116372E455759A7ACB0FFFDFAFFF9F0FFFFF3F8F3EDA099A00E0B06
0006006E7541DBDAACE5E0B8E3D9B6D8D5B6E7F4D6FFFFECE1B9B767363A806463B4A6A3
A79D9B6E6664574F4D8B817FF0E1DAFFFBF2D9CAC57A6C69998D8DF9EFF0FFFCFFFBF5F5
FFFFF8FAFCEEFEFFECCFD9B6DCE9BBD2E1AACDDFA1809751C5E197CCE69DEAF9B8636D30
7B864CC2D699BCE19CC5F3A8BEEF9DBEEA95C9E996BFD686D7EEA0C4DE94C4EA9DC6F1A2
CAF1A0D4F9A9C4E797C1E293C9E89ABDDC8EC1DD90D6F1A4C9DF94A1B66BDCEDA6CCDD96
CEDE97CCD993B5C07B929F59CDDF95DEF3A8CEE499DEF4ABDCF2A9A3B76F44510BE1EAA7
E2E4A3C7C78999995B5D5F20838E4CCADA99C2D995A6B977707137C7C58C575B20DAE6A8
D3E6A6D2E8A7C3D897CBDE9E95A163A8AE7292965BBBBF84CCD498E1EDAFD3E6A6B3C183
5A551D847D46D2D89CD9E8A7CBDF9AD6ECA4E4F8B1D2E39CD5E6A0CBDA95B1BE7993A25D
D6E7A3CEE7A3C3E49F678441888B52918E57E0E8ADCEE1A1CAE5A0C2E49AC0E296CBEB9F
7D974DBED48BC7D891E4F3AECFE39CCBE29CCCE7A0CCE9A7CAE2AEC6E2B2BDE5B160955D
6EB27593DB9BB9FABABAF2B3BAE8A8DBFBBCC1CF91D3DA97A0A7617E8639C1CA7B7E913F
AED584B4E392BFEB9CC3EE9FBCE295CBF0A3B5D58AD3F1A7
F8FFE4F7FFDFE1F9C7CBE7AACAE9A3CCECA1CDE99ED1E8A0DBEBAC455016EAF1BECCD2A2
CBD3A4D4DDB0F5FFD2F8FFDCF4FCE5FDFFF4FFFFF8FFFFFBFFFEFFFFFDFFFFFBFFFFFAFF
FFFCFFFFFCFFFFFDFFFFFEFFFBFBFDFEFFFDFCFFFBF0F9E4F2FFD1C7DC9BCBEBA2C6F0A8
C9FFBDB5EEBB1F4D33284C42A2B6B7F7FFFFFFFFFBF4F0E7FCF2E98A7F790B0505010500
263703E4F7B5CCD69ADBDEA9D6D2A5EDEBC4F6FFDEF3F3D7774C45703C3EFADEDDFFF4F3
FDF5F3FFFDFCFFFDFE66615E62554F5A4C43544540908281FFFBFBFDF3F4F4EBEEFFFDFD
FFFFFAF7F9ECFEFFEDF3FDDBF2FFD4DEECB9E0F2B8899F5ECAEA9FCDECA0CCE09BCBD99B
58672CD7EFB1C3EBA4BBEC9DC0F19FC2EE99CEEB99C7DC8DD8EA9ECDE59BC9EDA3C5EBA0
BDDF92D6F5A7BFDB8ECDE99CD9F4A7DAF5A8EDFFB9BFD58A455B10B1C679C6D88EDDEFA3
DDEDA2D7E79CA0AE634D5A12596A23C2D68EDAF0A7BED48CBAD088A6BA73586520DBE4A3
D9DB9CF5F3B8A9A76C505014DDE3A5E1EDAFCADD9D8E9C5E534E16EDE4AD5F5D24D5DB9F
D4E2A4D8EBABC2D796E1F6B5D5E8A8C8D899D4E4A5D8EBABCFE5A4D2EFACB5D691CBE4A2
5F60278E8751F0EEB5DBE1A3D5E5A4C8DF99C0DB94CCE69DD3E4A0D7E3A1DEE9A795A463
D4E9A8D2E8A7CBE1A15A692E8786506A6732DFE4ACC7D799CDE6A4D1EFA9CBEBA2C4E499
CCE69D839A52D9EDA6D3E7A200100021380048631E516327312A00D6CEA9DBEABFDEFECD
E5FFDD0D460F357F40AEF6B6BEF2B4AED898C8F3ACCEF7A9C9E898D8F6A0C3E889CFF89C
82AC58CFF8AAC5EE9FC4EB9CC5EA9CCFF1A4C3E397CEEEA2
F5FFDCF1FFD6DBF4BBC8E7A4C9EB9FCBEB9FC7E69ACDE49CC9D99A3E47104C5222DFE2B7
EDF2C9DCE4BBFBFFDDFBFFE4FCFFF6FEFFFDFFFFFDFFFFFFFFFEFFFFFEFFFFFCFFFFFBFF
FFFDFFFFFDFFFFFEFFFEFFFFF6FAFBFAFFFEF9FFFFF9FFF3F8FFDCD3E9ABBED899BEE5A6
ABE7ABBAF9CA6D9F86264740D1E5E6F4FFFFEBF4EFFFFFF8FFFBF44D3E37040000242E16
526B31D3EFA5D1E1A0DBE3A8EBE9B8D0D1A58D9A6F7D7C5ED0A49BEBB8B7FFEBE9FFFBFA
F9F4F1FFFFFDEFEFF1D1D0CEAEA39DC2B5ADC0B2AFEADFDDFFFBFDFFFCFDFFFDFFFCF8F7
FFFFFAFBFDF0FEFFEDFCFFE6F6FFDAD7E5B4BECF9897AD6DCCEEA4C2E297D9ECAADCEAAD
77864BC4DC9EC5EDA7B9E89ABDEC9BC8EF9CD8F1A0D9E99ECDDA92D4E59FCEECA6BEDF9A
CDE8A1D3EDA4CEE59DDAF2A8C3D990C5DB92BFD58C455A0FD6EBA0D8EDA2D2E49AD3E599
CEDE934E5F118F9D52D6E69DABBA759EAF6BD5E9A4CBE09BE2F7B2869A55C5D191D3DC9D
E6E6AACBC98E807B415E5C23D9DDA2CED89BD6E6A7919B5E9D965FF0E3AE58531BDBDFA4
D4DEA1D7E7A8D0E5A4D0E5A4D0E5A4D2E8A7CEE4A3CBE6A3C3E29EC5E9A3C6EEA7D2EFAC
92975D615724AFA36FCBC990D3E1A3CDE6A2D9FAB3CCEAA2D1E29ED4DD9ECBD59696A466
CBE1A1D2E6A9D0DBA13F420D4B4815474411D2D7A1D9E7ACD4E8A9CFEAA7CCEAA4C7E59D
D6F1AAC5DF98627732A4B97690A763A0B977CFEAA7C9D89DCEC3969D8F68B3B98DD8EBBE
BDDDAE8BB98869AA7264AA6EB4EFB5C4FCBDB7F3ABBAF0A2B9E695B7DF87C0EB8FC6EF93
86A557BAD48BDBF5ACC9E399CBE59BCAE49AE2FCB2BBD78C
D5E9B8D8EFBBCCE8ABC4E39FC8EA9DC8EB9BC7E698CFE69ED0E0A17C8550595C2FD5D7B0
FFFFDFF2F8D4F9FFDEF6FFE3F9FFF8F7FDFDF8FCFDF9FDFCFDFFFEFEFFFFFFFFFFFFFFFF
FEFFFFFDFFFEFCFFFFFBFFFFF5FEFBF8FFFFF7FFFFF6FFF3E9FFD1CFE6AECEE5ADD2F5BF
ADEEB88ED3A75A8B75476861F2FFFFF7FFFFEFFCF5FEFFF8B4A39C210E07130F04768568
D5F4B8AACC82D1E7A6DBE6ACD6D8A6838458556237ACAB8DFFF3EAA46E6EFFF1EFFFFBF8
FFFEFBF7F9F6F6FAFBFFFFFDFFFAF5FEF1E9FFF6F3FFFCFAFCF2F3FCF3F6FFFDFFFFFDFC
FEFDF9F5F7ECFAFFEBDCE5C8D9E5BFB9C69A657642A4B97ECCEBA7BFDE98D7E9ABC7D29A
1A2700CEE2A7DBFEBCB2DC94CAF3A7C6E69AB7C77EA3AA666E7333A4AE71CBDFA2D0E8AC
D8EEAECEE3A0D1E4A2D2E5A3D3E6A4D3E7A2C1D590ACBD77CFE09AD1E29BDAEAA3D1E198
94A45BD2E297D2E299D8E8A1D4E3A0B0C07F90A361879A5896A967A2B271F1FDBFD3DB9F
98975E5E5C236E6931D6D19ADEDFA6E4E9AFDDE8AC939B5FE3DCA5E8DDA5575218E3E4A8
D8E1A2D3DF9FDAEAA9C4D996C9DE9BD4EBA7CEE7A3D0EBA6CCEBA5C5E9A1C8EEA5C1DE9B
DADFA5ACA26F665422837842ECF6B9C5E09BB5DB92CAEBA4DDECABE0E6AA98A064B0BE81
C6DC9ED0E2A8DADAA6292300787242898756BDC18EDEE9B1C9DB9DC3D998CAE5A2D5F3AD
C4DF9ADBF6B1C1DA96D3E9A8D9F2B0CEE7A6CBE4A3DCF2B4D0E2A8DCEBB4828E5CCEE0B0
D1F2C3CAF1C4DDFFD729582A7DC28B7FC68ABFF9BCB7EAA7B8EAA1D8FFB4D1EE9ED0E095
BFC683949657CBD090D6DD9AD6DD9AD2DD99D8E8A1D9EAA3
C4D8A5CEE5AFCBE7AAC7E6A0CAEC9FC7EA98C6E597D2E9A1D9E9AA8C95605D6035CED0A9
FFFFE0FFFFE3F8FFDFF9FFEAF8FFF8F7FFFFF8FFFDF9FFFBF9FFFAFBFFFAFBFFF8FBFFF8
FBFFF8F6FFF5F8FFFAF7FFFBF4FFFAF4FFFDF4FFFDEBFFECF1FFDFCBE6B1CFE5B6BDE1B5
AEEFC4599F7A11422F97B6B0F0FFFFF4FEFFF5FFFFF7FCF56B5852241007030200AABB97
C3E7AACCF3B0CAE4A7D6E4AF8184577A7C549DA983D9D8BCFFEDE7733D3DFFE7E5FFF8F4
EEEDE9FCFFFDFBFFFFF8FDF9FFFEF8FEF3EDFFFCFAFDF3F2FFFAFBFFFDFFFFFEFFFEFDFB
FFFFFAFCFFF4FEFFEFCBD4B7D6E2BEBFCCA03C4D19D2E7AECEEBABC8E2A1D5E4ABD6DEAB
495120DDEBB6ACC88DDDFFBECBECA7C4DE97ABB4738E8E52403B048D8D59C8D2A0D4E5B1
CCDDA6D1E0A5D4E3A8C8D89AE4F4B6A8B87A617132D9E9A8D9E9A8CCDD99D4E3A0D4E39E
92A15CDAEAA3D5E59ED2E19CDBE7A7D5E3A5B2C283728545CFE2A2D0E0A1D6E2A4D7DFA3
75763C5D5B229B965FEFEAB3CECD95DCE1A7CAD599969E62DFDDA2E0DAA05A581DDCDDA1
DFE5A7CED899DBEAA9D0E3A1D7EAA8C8DD9AD4EBA7CBE4A0CBE6A1CDE8A3C4E29CD9EFAE
D7DCA2E5DEAA614D1B60501DD9E1A5C4DF9CCDF3AAC6EAA2C6D496E6ECB0818B4FE3F2B7
CDE5A9CDDEA7E9E3B3362900ABA476BDBC8C8A8E5BD4DDA6D9E8ADD8ECADCBE4A2C7E29F
C7E59FC5E39DDBF6B3C4DF9CCBE4A3C6DF9ED2E8AAC4DE9FC7EAA6CAEAA7ACC188A6BA85
CAE4B5CDE8BFC2DAB69FC19C124B1E64A774AEE8B5BAEFB7C3F7B9B4DE9CCAE4A3DBEAA9
DBDFA296965A8A8B4FD9DDA0E7EDADDCE7A5C6D590D5E6A0
D6E8B8CCE0ABC6E0A3C8E7A1C8EA9DC3E495C5E496D0E79FD4E4A5B9C28D52582A9C9E77
D9DDBAD1D9B4CAD6B0DCEBCACDE0CCC9DECFF3FFF5EEFFEEF1FFEFF7FFF3EEFDE8F7FFF1
F7FFF1F0FFECF5FFF3E9FCE9C0D5C6F0FFF7F1FFFAEEFFEFEEFFE1C8E6B4C5DBB4D1F5D1
74B4911A5D3EC0EFDFE7FFFBF3FFFFF9FFFFEFFBF7E7EAE33B2821513F315B5E41DAEFC6
CCF1BDB6DCA3DEF6C4919E72575934858966EAF8D5FFFFE8FFF2EDAF7B7DEBCFCBFFF9F3
FFFFFAE9F0E9F4FDF8FCFFFDFFFEFAFFFCFAFFFCFAFFFDFBFFFBFCFFFBFDFFFBFAFCFBF7
FFFFF8FAFEF0FEFFEDCFD8B9D0DCB6929F73CBD9A6D2E5AECEE7ADCCE1A8D0D8A7393A0E
67683ED1D8ACD7EBB8D1EAB0D6EEB0CCDC9E515018CEC491392A00786C44E5E3BDD7DEB5
CBD7A7E0EDB8CCD9A4CFDCA6D5E2ACAFBC84D6E3ABD3E1A6D5E3A8D2E0A3D5E3A694A264
CEDE9FDDEDACD5E5A4CFDE9DDBE5A8D7E2A6D2E0A3CEDEA0DDEFB1D1E1A3CFDDA0939B60
7B7C43BCB982E9E4ADD9D69FD9DAA0E1E7AB758143DAE4A7D8DC9FE2E2A4535516CED393
E2E8A8D7E09FCDD896DDECA9D8E7A4CEDF9B92A661CEE29DD8E9A5D6E5A2C9D593E5EFB0
DADFA5D9D6A1A6926070602D979D61CBE4A2C3E7A1C7E8A3CCDA9CB8C084A7B276CEDDA2
DDF5BBB8C691F9EEC1311F00757144CED2A095996698A16AD2E0A5CADC9EDAF0AFCCE7A4
C4E19EC7E6A2D1EEABC8E5A2D7F1B0C2D89AD5E9ACCDE6A5C5EBA0BFE99DABD08B87A066
D7E0B3D5DDB8CDE3BFC9E7C5C2DFC13F644383BC9395D0A2C7F6C8B8E0AEBFE6B1C5E6AF
CFE7ABD7EBACB3C788899F5FCDE6A4CBE6A3D2EDA8C7E59F
CAD9AED2E4B4D4ECB2CFECAACFEFA4D1F1A5CEEA9DC6DD95CCDC9DDDE8B0CBD1A131360D
DAE1B8DCE7BFD2E1B8CADFB8C3DCBCB9D6B8D5F0D1CAE3C5C8DFC2D5ECCFC8DCC0DBEFD3
C8DCC0D7EBD0BCD3B998B09896AD99B6CFBAA0BBA8B3D0B4AACB9ED1F2C3C1DCB989AD91
001F05001500446D5F0009010003000001000309050100000D00000D00000C14001D3505
224412000F00597044111D000304000104000F1E000909001D00002600001200006B625B
393A320B120A010A050002000300000600000800000701010903050905060A0605090803
0002000004000207000007000511002E3B0D6A78452F400A000E00000B00121500060400
0C0800030500000D00C4D8A3C0D499F7FFC85B5521E1D0A4634D28AA9777D2CBAED4D5B5
DDE6B9D4E0AEDBE7B5778351202D008D9A65DBE8B2D4E1ABD9E6B0CFDCA4D2DFA799A76C
DCEBB0BDCD8FD2E2A4DDEBAED8E2A6C8D296D3DEA2D9E9ABCDDFA1CFDFA1010F002B3500
E5E8AFD0CF97EBE8B1DEDDA4DBDFA4CCD498909C5EC9D897DAE5A3D9E2A1595F1FE3E9A9
D0D696D2D898DAE3A2D4DF9D2A360043520F5E6D2A83924FDCE5A4DAE0A0DCDC9ED1D296
DBE0A6E0E1A8EEE1ADC2B78152581CD0E5A4BFDE9AD7F4B1D9E7A98D975A8C9A5FCFE1A7
C8DBA3F0FAC6CFC29844320A656436FBFFCFCED5A1535C25D6E1A9DEEEB0CCE0A1C7E29F
CDEAA7D5F4B0BBDA96CAE7A4C5DE9DDEF2B5CAD99EDCF1B0CFEFA4C4E99BC7E8A1445C1E
717749D1D6AED9E9C5CFE2C4C7D5BC5D745A4672514E825CA5D5AFCAFAD2AFE7BAB7E9B6
B9DCA2CBE7AACAE4A7849E61455D21CFE7A9D1E7A9D3E9A9
54603C5362393D511E2139002B49035E7C3287A35894AB638D9D5E3D480E757D4A2C3405
3743156976486B7D4D5A7242638354577B4D6A8B5E5C7B4F58744B627C55576F4B677F5D
6179575E7656647B5F61795F5B735B839C867E97826A8769597F504C73445A7B5C487058
001301386A5E65867B78898181837E827E7B2723220801001D0F025C5539606C3C627B42
5171405673476D7F57212B088C8D6D787D5D6B7C5A565A418A655C5A2D2A79625C948D85
8F90888B928A9DA6A1B0B5B19894939A94949C96969E989AA19B9DA29E9DA4A09DA3A39B
A2A497B0B5A1999F85ABB5927C875D8C9868A8B68188996299AD788F9F6E84855D272300
4C4622ACAC86647143445622384912333C052C24003E2B01462D0E3D280D665A426A694B
3B44192432002533001A28002634002B3904212F0036450E2635002534001B2A0035440B
7F8C543D4B102836001A25004E561D737B42545D24212F002030001A2A0029370097A266
92985CA7AB709293599394584C521449531494A36297AA688A9E5999AA66434F0D444F0D
AAB372969C5C525B1A717C3A8B975597A6638D9C59354000656A2A8D8B4EB5AC71A5A066
949C60A2AA6E9C975F9E99613D43073B4A095168244C631F5C6C2D4452142D3C01394B11
2A39025C6330302400190C000E120036400C57612C1924004E5921273700182C00425B19
76954F42631C6D8E4955722F526B2A596B2D768147606A2D59682333430065712F6F7D40
66794126360733371270735469765A879A7E7789716481652056320C50272B7A4D6EB281
638854687C47546632758350757F4D6367352A2800322E00
EFF5DBF8FFE2EDFCD3D2E6B1C6E0A1D0EBA6CFE9A0C2D991C4D495D9E7AAD6E1A9808A55
ADBB86D0E3ACB2CA90D0EEB2C3E7AABDE3A6CCF2B9C4E7B1C3E1AFCAE5B8C1DAB2CCE4C0
CBE0BFBED2B6D1E5CAD9EDD4CAE0C9E9FFEAEEFFEFC2DCBFBAE1B2CAF6C5C4EDCFB7E2CF
447268A0C8C0EEFFFFF6FFF9FFFFFADED3D1180A0A0A0000372E1DC6C7A5CCDEA2D3EDAC
D5F0BBCFE6B8CDDCB149512AF4F6D1FEFFE1B8CCA7EAF3D4EAC8BC4D241EFAE7E0EEEAE1
FFFFFAFCFFFBF8FEFCF7FBFAFFFEFFFFFDFFFFFDFFFFFEFFFFFEFFFFFFFDFFFFFBFFFFF6
FFFFF3F5FAE3FCFFE6CED9B1D4E0B2697641CAD9A0D0E2A8C5DAA2C5D5A4EAEDC2625E38
74704BD2D4ACDAE8B7C3D8A0DAECB2E1EAB1554D1CDDCAA0967F5D9F8B70FCF2D9FFFFE2
DDE9B9000B0091A26BD4E6ACC8D9A2CBDAA3E3F2BBCDDCA5DEEDB4CAD9A05C6B329DAC73
CDDAA2CDDBA0D2DFA7DDE8AEDBE0A8CDD099D4DDA43644074C5C1E859759D4E4A6D1DFA1
D6E0A3D8DEA0D7DB9EE3E9AB909A5BD5E4A1CADD9BBAD18BCFE9A2C7DE98C8DC97939F5D
454E0D47500FE7F0AFD3DF9DE5F6B2CBDC98CDDE9A97A3615F6424A2A063DDD398E4DEA2
CAD495DFEEADCCD296DBDFA2A8AC6F485112D8E4A4DAEAA9D1E1A2CBDE9EC2D49689985F
48521D999B6AEEE5BA3C3509E9F1BEC1D29BD6E3ADD8E3ABA3AE74CAD89BCDE0A0CDE6A2
CEEDA7C3E49DE7FFC3C6E5A1D4EAAAD7E7A9CBD39ADCE2A6E4EFADC3D08BE0ECAAC1D494
D4F2B28BA76D535C2DDCDEB7DCE6C1BBC5A3DDE0C5EAF7DBC1E9C773AF8900380E5A9C6E
84B37FACCF99D8F6C2C0DBA8CBDFAED9E6B8DEE4B856592E
FFFFF1F9FEE8E6F1CFCFE0B4C3DBA1C8E2A1D3ECA8DCF1ACCDE09ED7E5A7E7F2B6748247
839559D5EBABE0FBB8C5E6A1C4EAA1C1E9A2CBF0ADC8EAADCBE8B2D3EDBED4EAC3DDF0D0
F7FFECF8FFEFF6FFEFE5F2E0F8FFF3F7FFF4F7FFF4ECFFE7E9FFE1ACDEADBAECCF639184
274B49C3DFE0F2FFFFF9FFF8F9F0E99C88871600002B16139D9884CFDAAFD4EBA7C7E197
C9DFA1D3E4AEC8D29E5F6535E7EABDC6CFA2C5DFB0CCDBB4FFF8E6A17B72F6E5DBFFFFF6
F5F6F1FBFDFCFEFFFFFDFCFFFEFCFFFFFBFFFFFBFFFFFBFFFFFCFDFDFCFAFDFCF7FCFEF3
FBFEEBFCFFE8EDF7D4CAD5AA717D4B8F9C64DAEAACE0F2B4CCE4A8DDF0B9D3D9A92E2D00
6A693DD4DAAAD1E4ACD3EDAEC7DD9CC9D799636029DFD1A2F4E2BCCDBE9DFFFFE4F1F7D3
92A16A788C4DC2D697D8EDACE4F8B9B9CB8DEFFFC3C4D698C7D99BD0E2A466753AB2C186
C8D69BD2E0A3DAE8ADCBD599E2E5AC696A313941066D783CA0B072BACD8DDEF1B1CDDD9E
D9E5A7D2DC9D9BA465D2DD9BAEBD7ACFE39CDFF6B0D2EEA4CCEAA0CBE79DE7FDB5D7E6A1
ACB773E3ECA9CDDA95D9EAA4BFD58DE6FDB5C1D890C3D790D2DD99AAAC6B696325E0DEA1
DCEBA8CBE09BDBEEACD9E5A38E9353525415E2E4A5D3DC9BDCECABCAE09FDCF2B2E0EFB6
989F6B5B5A2ADCD8AB525123677540C9DEA5D9EBB1CAD89D6A753993A163ABBE7ECDE6A2
C8E7A1577B3180A45C2443004C6221707C3EE3E6ADE2E5ACC9DC9CCEECA6D0F5AFD2FAB3
B3DB94B1D691DDFDBC889D64545728E4DFB5DEDCB5EAECC7FCFFE3E8FCD9C2E2BDB2E1B5
4988510A501469AD7286C58CAEE7B0B7E9B4BDE9B6C2ECBA
FFFFF6FAFCEEF3FCE1EAFAD3DCF0BDC8E0A2C5DB9ACADF9AD9ECAABFCF8ED9E7A9576728
A3B674CCE69FBEDC92C6E89BC6ED9CC4EB9CC3E79FC4E2A2C8E3ACD5EBBDE2F3CFEDFADE
F8FFECFCFFF3FCFFF4F6FCEEFCFFF6FCFFF6FCFFF6E6F8E0D8FFD0BCF2C088C3A57EB0A4
CEEBEFEDFEFFF7FFFFFCFFF69E91892C130F1900006D514EE4E2CBCEE0B0D5EFA5DAF6A2
D6E7A0CEDA9AE7F0B1454B0FDEE1AAD8E2ADCEEBB3D1E2B5FFF6DEE6C5B6FFF3E6FFFFF6
F9F9F7FEFFFFFBFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFEFFFFFFFDFFFFFAFFFFF4
FEFFEDEDF4D5F2FCD7D9E5B746531DA9B77AE0F0AFBED390D2ECABCDE5A7CED7A06A6C3A
757946DCE6B1C3DB9DCEEDA9D5F3ABCBDF986567288D8650C9BC90D3C9A5666745747F55
BBCF90DCF6ADEBFFBABDD48CC4DB93D2E7A2BDD28DD5E8A6D3E6A4DAEDAB92A263C6D697
E4F2B4D6E4A6D1DFA1757F42252600828149C3C88ECED99DBFCF90DBEEAECEE1A1D4E7A5
6675347E8A48D4E09ECDDC97CDE19AD5ECA4B5D187CFEDA3BADC90D1F1A6B7CE86D4E59F
E3EEAAD3DE9AC9D893D4E8A1D5F1A7C8E89DC9E99ED4F0A6D9EDA6C4CF8BAFAF6FBFC482
CADE99C2DD96C8E69ED0E69ED9DE9C6A6627CEC58AD8D89AC6D997E2FDB8BFD897B9C88D
E6E9B4B2AE7EC0BF91252D005D7239C7DFA3D1E5A8E3F3B5D9E5A7CEDA9AC8DB99C8E29B
C5E59CC6EAA0C5E9A1CFEEA8CCE1A0D9E3A69291597E7F469DAF73BEDB9BC7ECA7B7DC96
CAEBA4D3F5ABC9EFA4CEECA4D0DC9CB7BC82909761949B6895966CAFAF89E9F1CAC2DDB2
BDF6C3ADF4BCAFF4BD44875182C28E6CA8758EC695AEE4B3
FFFEFBFFFFF6FDFFECF5FFE0E8FACAD7ECB3D1E7A6D6EBA8D0E49FD1E29ED3E3A22B3F00
E7FDB5CCE89DD0F1A0BFE590C9EF98CBEE9AC7E79BCBE8A5D5ECB6E1F2C6F3FFE0FCFFED
FEFFF3F4F6EBFFFFF8FFFFFAFEFEF6F3F3EBFFFFF8C0CCB6B8DFB0B0E8B797D8BA7CB2A5
ECFFFFF8FFFFF2FBF8F8F8EE68574F1600003F1219AE8C8BDFDFC5CFE6B0C1DE8EC3DD82
DDEF9BDBE3969CA258545710DCDF9CCFDB9BDAFAB9C6DAA5FFFDDFE0C1AFFFFDEFF9F9F1
FCFCFCFFFEFFF2EEFCFFFCFFFFFAFFFFFBFFFEFCFFFFFDFFFFFDFEFFFEFAFEFFF7FEFFF2
EDF2DBD6DDBCD2DDB5D9E5B5525F27D6E4A6CEDD9AD2E8A0C3E19BCAE5A2F3FFC48C9459
697337DAEAACD5F3ADBDE295B3D686DFFAAD48520D9B9B5DECE6B2D3D0A37B835A637543
CBE29CD1EE9EB4CF80D1EC9DDDF8A9D4ECA0D1E99DD5EBA2CDE199C9DD9597A862CBDC96
E3F2AFD8E7A4BDC9892B34005A5920D9D8A0C5CB8FD4DEA1F3FFC4CEE1A1CADF9C8DA05E
94A463BAC986DAE9A6CBDC96DEF4ACCDE79DD9F8ACBEE093DAFCB0C2E297DEF5ADC0D48D
E4F1ACCFDC97D0E19BD8EFA7C9E99EC5EB9EC7F0A2B8DE91C3E197D2E8A0D7E29E909D58
D0E79FE2FFB7C4EA9DBEDA90E4EBA85A521376672CE8E2A4D9EDA8C2E09ACBE5A4E5F4B9
DEDCA9989262DADCAD313E096E874DC1DDA0D7EDAFCBDB9DCFDB9DD2DE9EE6F9B7C9E39C
CDEDA4BBE093C9EDA3CDEBA3D4E7A5D8E1A2D0CB93A19E69929B66C5D49DD0DDA5E3F1B3
DCEBA8BFD38BCCE496C3E08ED2F3A2D1F4A4C6E69AACC67F364608434A14D8D6A6DAE0B4
CFEABFA9D0A4CBF1C8CDF3CAC1E7C0254B24557D5888B08B
FFFBFFFFFDF9F4FCE7E3F4D0D1ECB9C9E5A8CDE6A2D4E8A3CDDC99E3EFAD6575344E631E
C1DD93C5E697C9EC9ACEF19DC4E594C9EB9EC7EBA3D3F3B4E3F7C4EEFAD4FCFFEAFEFFEF
FCFFF2FFFFF8FCFCF4F5F5EDFCFFF8FAFDF2FFFEF5DBE2D0CBF4CC5892694D8C71A2D4C8
F1FFFFF1F4F9FFFFFA8881771200002A0D07CDA7A6FFF2EAEFF4D4CBE2AAD6F2A5D4EE95
D6E5927C83355F6319BCBD79E0DEA3DCDFA8DBECB8EDF6CBF5DFC7A6897BDED0C7FFFDFA
FAF5F9FFFCFFFFF8FFFEF6FFFFFCFFFFFDFFFFFEFFFFFEFDFFFEFBFFFEF7FFFEF2FEFFED
FFFFEAE7EDCBE9F1C87A845294A267D8E7A6CDDC99D5E6A0DCF3ADC8DB99CED89B4F5519
7D8347CDD99BC9E09ACBE99FD3F4A5C8E4974D5C1791995DE8EAB9D7D9B1D4DBB9D3E2B7
D5EEACC3DF92DEFAADC5E194C2DC92C7E197CFE69ECDE49CCFE59DCFE39E95A662D2E2A1
C1D08FE3F2B1D5E1A35B6327A29F6ACBC591EAEDB4D6E0A3CEDA9CCFE2A08AA45DB3CA84
D8E9A3C9D893C9DD96D4E8A1D2E69FC8DF99CDE8A1D1EFA7BFDD95CDE8A1CDE49ECDE19C
D6E5A2D9E8A5D8E9A5AABF7ACEE9A2C5E59CC3E59BD5F5ACC9E49DD2E7A2D8E9A5909F5C
D0E5A0BFDA93C2E69CD6F6ABCCDC95E8E9A75E5416E8E2A4D0DF9ACCE69FCBE29ED5E5A6
D6D9A264622FDCE0AD222F0097AF73C8E2A3CBE4A3D2E8A7DFF4B1D3E8A5CAE19BCEE9A2
C4E29AD4F4ABCBEBA2C0DB94D4E9A6D1E09FDAE2A6D5DDA2B1BA85939C67BABF89D6DBA1
D1DA9BDAE7A2D0E298D3EE9FCAF1A0B0DB89CCF3A4C6E69BD1EBA4DAE8AA76773E9E9E6C
9CA47BDFEDC9D6E6C2C6D5B4CFE0C0D1E4C65C70547B8F73
FFF7FFFEF2F2E0EED7D5F6CBB6E2A3C8F4A9CDE99ED0E097D4DB98D2D89A5563258AA361
C8E9A2D7FDB2B0D585D3F3A7C7E29FCFEFB0C5F3B5CDF8C0F7FFE1F3FADBFEFFEDFCFFF1
FCFFF4F5FBEDFEFFF4F8FFF3F0FFF3F1FFEEF2EFDED8DCCB49755C114D33538972E6FFFB
F7FFFAFCFCF2FFF8EE0D00002E1C10604E40D8C7B7FEF7DDF4FCD3D4E9B1D0E9A5CFE59A
D8E69B545B155F6024DEDAAADCD0AAE3D4B7FFF7E2FFFBEDFFF2ED684645D3B9BAFFF9FB
FFF9FFFFF9FFEDDEF1FFFAFFFFFDFBEAE3DBFFFDF6FFFBF2FFF9F0FCF4E9FFFFEFFFFFEC
FDFCE0FFFFE1FDFFD9909867DEE9B1CAD89AD5E5A4DAE6A4D7DD9DE3E3A77C773F4B440E
827D46E2E1A8CAD296D4E4A3D0E7A1CCE5A1D2E8AA8C9D69E0EAC5CCD0B7FCFDEDFCFFEC
C9E0AAD3F0ADBEDB99D3F0AEC4DE9DD2ECABD7EFB1C6DC9ECCE0A3D3E5AB909F66CBDAA3
C9D6A0DDEAB4D2DCA7565A27554A1CECE2B1E2E5AED2DCA0E6EFB0D2E39F3E5E1386A65A
C8D891DBE8A2D4EAA2D7ECA7D5E1A3CED99DD0E2A6CCE0A3D5EAA9CCDF9DD0E3A1D1E4A2
CEDE9D92A2615C6A2C8A9658242E00D5DFA2DEE8ACD7E1A5D4E2A5E0F0B2C7D79995A366
454D11D8E4A6DCF7B2C2E49ACBE99FC9DF96A1AB66535613959A57E2ECA7C7D691D2E39F
DFEBAD909A5E575A232830006C7C3EBFD594DFFAB7C7E6A0C5E69FC6EAA2C4E59ECDEBA5
C2DB97E1F8B4CDE29FC2D995D4EFAACAE9A3C7EDA4CBECA5CEE1A1D8E4A6929C60929D61
DFEDB2C8D79CD1E5A8CDE6A5CAE7A7C6E5A2CDEAA7C2DD9AD0E9A5C8DD9AD3E4A0E6F2B4
979B69A6A77DC9CAA2DBDBB7E1E0C2FAF8DFFFFFECFFFFED
FFECF6FFF7F6ECECD4C5D8ABD5F5B4C4E298E0ECA4EAE9A6EBDFA5B3A671595621DAE1AB
C8D79CC7DC9BD3E4A0D7E1A2DFDDADD7D9B1E0F7CBE9FED7F8F4DBFFFCEDFFEFE5FFF8F0
FFFBF3FFFFF6FFFFF6F9FFF4D1EDD6EDFFEDFFFFEFF6EFE57A948B74958CEBFFF5EBF3E8
FFFEF3FFF8EF80625A2907002E0D048D7166FFF1E1FFF0D7F0E6C2CAC395DAD7A2BFBA80
75692F91804AE1CAA0FFE5C5FDD8C5FFE6DBFFF1EDFFE8E7FFECEBD3A09FFFF0F1FFECEE
FFE7EBFFF2FBFFF3FFFFE9F2FFEEEEFFF7F3FFF4F0FFEDEAFFF6F3FFF6F1FFE3DBFFEFE3
FFFAE6FFFBE3FFFBDB8E8059ECE1B4DBD3A2F1ECB5D4CD96E5D8A3E4D7A2988C586E6733
6A6732EBEBB5DADFA7DCE7ABD6E6A7CDDFA1D2E4AA91A170CDD9B5D9E2C7FEFFF3F7FFE9
D2E8B7C5E1A4D3EFB2BDD99CCCE5ABC9E2A8C4DCA2E1F6BEE4F7C0C6D9A28E9F69CCDAA7
E1EDBBD3DFADCFDBA9A0A4726A5D31C9BC8FC9CC97CDD59ACBD193D2E19CD5FAAC5D8232
D7E79EE3EEA9C9E098BFD692A2AA6FECF1BB96A36D9AAC7294A465889857A8BB79A6B979
8C9F5F9BAE6EBFCB8DE0E8ADDADDA4AAA9717E7D47D3D39DCAD299D6E4A9D7E9ADCAD9A2
6B6940E6E8C0B6CA99D4F2BCC8ECAFC5E3A7D2E1AA575B28949261E4E4B2D8E0ADD0DEA9
C6D6A5E7F3C5DDDFB7141100534D19A6A469D2D699D2DC9DDAEAA9DAEDABD2E1A0D9E2A3
E4E4A8D5D096DBD59BEAE8ADC8CE90CCDC9BD5F0ABCDE29FD7D99AE5DFA5D7D099C7C28B
756F3DC3BF8FD0CE9DD2D0A0D9D8A8BFBF8D9D9D67BDBE85C1C58ADDE2A2B2B775B2B073
BFAA7B6B4F27A48863A98C6CB8987FFFE3D0F9D3C8FFDAD1
FFEBEFFFE8E4FFEAD2DDC7A0E4D7A2E9DB9EF7DFA3D7B6807F562870461EF7D3AFE3C59F
FAE3B9EFDAABEED8A6F9D8ADFFD0BAFFC9BDFFF6E8FFF6ECFFF0F1FFDDE3FFEDF8FFEFFB
FFF2FDDBC0C7FFF6F9FFFFFBF7FFF8CED9CBBBAEA60F00000D0000EFDAE3EBCCD2FFD8DE
FFF0F3C68B8F2B00002D0000723437FFD0D2F4BAB87D443BE5AD9CB981687B4224834826
8A4B28A46345DD9680D68D7EFCADA6FDACA8F39E9BF7A29DFBA69F933F35E69488FFB5AA
FFC4BCD28782DD9392FEB6BAE9A1ADE9A2B2F5AEBEF5ACBDBE7684C8808C843C479E575D
8844456B2A248F514679402DC58F778855387B4A296E441E6B4A1D7862314F45140B0B00
000900C9DAA4CEDFA8C4D39AD9E4A8E6EBB1CED19AADAF7DF7FED2EEFAD2CFE3C0BCD2AB
CAE3AC577132C9E3A4D4EEAFD2EAAECEE6AAD5EAAFC2D79EC9DCA4BACD95071800354610
5E6C37DBE9B466743F0108000D0200201500767944778145E1E5A8DCE9A4BADC8FD1F4A4
D5E59CCED994D5EFA6C5DE9A6E783C010800020F0085975DD6E6A7D7E8A4B6CA85C9DE9B
E2F7B45A6F2C000C006D773A72783CD5D69CE1E2A981844BDDE5AACBD99CD4E8A9DCECBD
666352292921324235526D5A5D7A64556D57000500545243160E015D5749343829091404
0005000004000505001503005027077B4A1F784D20603C0C5C3C0B5D3F0D624010764D1F
794A1E804D227E491F814E236E43167A5A29654E1A694F1CA8804F7E4F2385562C62320A
AC7C567444206F3E1D7544237A49286638147C4F28774C22744B1F694312714D19895D2E
8C4D2A833C207931188A422C863A2A6E2117742520813130
89544283533CA8825E79582B654A1570561D5B3E0661410E4B2A006F4D286E4D2E68492C
573A1A664A257458305635148359496740399B7E78472E2A7754588D656E663747603445
3914253B2330332C33282C2D131E18373C360A000043282D7A5662643A4871414D67323C
581F2565282D2D0000561B1F7840437C4447975F60753A36985A4F8C4939772F1968200A
884032A55F55BA716B863C39934749974B4B75272371241A9549397C341E954D357A341B
914A3494503D9E5B4B7C3931712E35A866729A58648B49538B475277343DDC9A9EAC6A6C
70302E955951B97F71A26B577E4C316D3F1E693D1A79532C624A1C5A4A19655E30282900
0E17002F3C10000A00394714222C001B2400373F04474F163B4510354612526635607844
405A1D203A006C8544223B003851105C7436687E406E84466F834872864B0F2100465720
65763F61723B596831818A555C56262C240040450D7C864ADBDFA2D6E19DD3F3A7C0E192
909D55AAB570C9E39ADFF8B4848F532B33003C4911D9EBAFCCDC9BCDE19AE4F9B4DDF4AE
BED58FB5CC8693A664536221353E00141A003135001F25001D27002F3F00344A0A182800
2A291738373219291C1631201B3B262039242A3525292A1C312B1F332F23262C1E131F11
202E212F392E2D2E284A3A2B5C351473441872471A6B47177250207755257E5A2A906538
7D4C21754016774017875228966A3D8F6B3B6F511F806432825E2C714918522700C6996F
BB8B63B787619E6C49774522CE9C797E4E288D60378C6136BD9768B79565B69663A77F4E
AA704B9F5D3DB06D50BF7C61C8816BD28B79E59B8EFFC3B8
BCBB85B9B67FA09A6090884AD6CE8F928E4E5052136B733AA1AB79A0A97EC6CCA8D1D5B4
A5A485969672D8D9B1DCE8C28CAF917BA891578771A5D4C2ABD5C96D8C86000307000009
6B6B75636C73233B3D000807324241000202CCC3C6AB989EFCE2EBFFF6FDFFF6FAFFF0F0
ECCECC391D191700005C4841FFF4EDF6E5DEFFF8F1FFF8EFFFF7E8BC918085533CFFF2E3
FFE6E7FFF0FBFFF4FFFFEBF3FFE9F1FFF6F8FFF0E9FFFBEAFFFCE1FFF4D3E9D7B1DFCDA7
EAD8B4FFEDCDFFF8DFFFEFD9FFF6E6FFFDEDFFFAEBDFCFC0FFF5E5FFFCEAFFF4E0FFFEE4
FFFFE1FFFFDDFAF5CDE5E2B5D5D5A3EDF0B9D7DCA2C9D195E3EBB0D2D7A1D1CEA158532D
574E2F160F00070700D2D9B0C6D8A8DCF5BCCDEAAACDEAA8C6DF9DA3B5778D985EB8C389
CDE2A1C7E09EE4FAB9B9CF8ECFE5A4D6ECACC4DA9AC9DF9FC1D799DFF5B77F9356899D62
D1E5AACCE0A5D7E9AFCFDAA2D5D3A07D7A477F874EE1EBAED8D99DD9E29FCAE99DCAE99D
909D5776813CD3EFA5C3DE99C3CF91C3CB92748149CEDDA2D6EAA5CCE098C5DC94CFE9A0
D1EDA3C7E198CDE49ED9EDA8D4E09EEDF6B7E0E6A89EA7689BA767CADD9BC2D897D6EAAD
D8DEB051582FCAE2B2D6F8C5B7DCA6C0DEA8CFDFAED9DFB1504F23C8C99DDCE8BAC6D8A8
D8EEBFD6E7BACFD7AEDEE1B4DDDEA5E2E2A4E1E6A6E2EBAAE2EDABD8E3A1D2D898D7D99A
DDD99C8D84499F955AD9D095E8E6A9D0D595D5E09ED8E7A4CCD896E9F4B2E4EAACD2D69B
DEDDA4DDDAA3D9D49D58511DE0D9A5AAA56EC8C78FDEE2A7C7D091D0DF9ECBDC98E1EBAC
EAE1AA9381518D7B4BDAC89AEBD8ADFFFAD0FFFDD6A08A63
C6E999DCF7A8D2DE94D7DD97DDE09D505918789052A5C88EB1D9A7CDF6CAC5E4C2BED7BA
98A88D9DAC8FACBD9BA3C0A164997F1856411C554470A99A7DB9AD55868000161A76808A
E5EFF9D2E6ED94BEBC19433F627C7B788385FCFFFFFFFDFFFFFBFFFFEFF2FFF7F7FFFCF6
82786F21190E030100787A6DFCFFF6FCFFF8FEFFF5FFFEF2FFF8E8B7A08E6B4D35FFECDD
FFF7FDFFF8FFFFF2FDFFFBFFFFFDFFFEFEF6F1F6E2FCFFE6E6F3C8F0FECDD9E6B1D8E2AE
D1D9AAEEF5CCF5F9D6F2F7D7F5FFDCE1EFCBF2FEDACFDBB5E5F0C8E6F1C7EEF9CEDBE7B9
E1EFBCD4E5AEEAFEC1D6ECABD6EFABC1DD93C6E599D8F4A9C5DA99DBE6AED9DCAD5D5934
5D5338130B00060100DADFC1D9E9C4C1DBABC3E2A7DBF9B9C9E4A1CCDF9DA6B2726E7839
D8EBA9BCD38DD3E8A5DEF5B1D0E7A3D2E9A5DAF0AFD5EBAACBE1A0CEE4A4768A4B91A566
D3E7A8DFF5B5D8ECAFCEDDA2D9DCA5ACAF78404A0EB1BB7ED8D99DE8EFACC1DB92D3EFA4
B8C37E7B8641C3DE97C3E19BF7FFC7D0D89DB0BE83CEDEA0D2E69FCEE49BC6E096CFEBA0
CBEA9EC6E49AD2ECA3CCE29AD0DF9ACAD694D3DE9CAAB674BFD08CCEE39ECDE6A2D5EAA7
D8E1A2465011C4E29AC7F0A4C6EFA1C5E79BDDF1AAD8E29D636524DEE5A2DCEDA7E4FBB3
D0EBA4B0CA83E4F4B3D0DF9ED5EAA5C8E29BC1DC95C1DF97C3E199C5E39BD0EAA3DBF0AB
D6E7A3B1BD7B8C9755ACB876D5E6A2D1E8A2D1ECA5C9E9A0D2F6ACB6D88ED5F3ADCEE7A3
BFD491E8F8B9D5E1A3727C3FD1DB9E859153C4D495D7EDACD0EEA8C7EBA3C5EDA4CBECA5
CCDEA0C2CB92909960BDC68F9CA56E9AA36CFEFFCFA8AF79
BDF594B7E487CCE28FE9F1A89CA15F8B965AC9EAB3C2F4C1B8F3C782BE9895C3A7375A44
57705D687D6A6C846EAABCACE9F2EDFEFFFFFFFDFFF9FCFFF2FFFFE5F4FBFFFAFFFFF7FF
FFFAFFEFFCFFABD9D66FA49C91B4B0E9FFFFEEFFFFDEEEEDFEFFFFEEE9E6FFFEF8FFFBF2
03010006070052584AD3DED0F2FFF7F5FFFAF6FFF9F7FFF4FFFFF1EEE7D4A5967F857261
9A827EF2DADAFFF0ECFFFCF4FFFFEFFFFFE8FCFFE1F2FFD1CFE3A6CFE4A1D0E3A1D8E6A8
CFDAA2CFD5A5D0D2ABD3D5AEC3CF9FD9E7B2C7D49ED2DFA93E4911E0EBB1D3DEA2DAE6A6
DAE9A6E3F3ACEAFCB2B4C97ACAE390D5F19CD7F39CC8E18DE0EDA8D4DCA1D4DCABC3C9A3
646A50121A05020900F9FFEEF6FEE7FBFFE6F8FFDAE9FAC6DDEFB5DAEEAFC9DF9ECAE19D
586D289AB068CBDF9AC4D994D0E5A0D1E6A1C1D693CBE09DD7EEAAC8DE9DD2E8A7879D5C
C5DB9AB9D290D7EDADD6E8AAE0EAAEC3CB90AEBC7F6E7A3C393900C6CB89C4DB93D4EEA4
D3DE99D5E09B7F9D55CBEAA4C2D092D5DFA3C0CB8F728243AEC47BD2EA9ED0EC9FCAE99B
C6E999CAEC9FD5F4A8C0DA90D7EBA3DBECA6CFDE99DAE9A4A2B66FD5ECA4CBE69FCAE298
DCE89E7F8D40C0E08BB1DC83CFFAA1C2E68FD2E896DDE899585C10D6DE91C7DD8BBFDB87
DAFAA5C4E18DCCE192DBEDA1D3EAA2CCE69FD1EBA4D6F0A9D1EBA4CFE6A0D0E5A0D1E29E
CEDA98ECF7B5818C4A9DA967D2E19EDFF3AEC4D994CAE49DC6E69DCAEAA1C8E39CD5EAA5
D1E09DB4BD7E999D60D7D89CD0D497696F31C5CF90C4D493DAF3B1BBD895CBEFA9C0DF9C
DDEFB5D3DDA8D6E0ABC6D199D6E1A9EBF6BECFDAA0D0DBA1
B5EF89C5F293D6E997D1D48F57551CDFE7B6BEDDB1B7EAC1C2FFDD458467001100E9FFFD
F1FFFFF1FFF9F4FFFDF5FFFAFFFEFFFFF8FFFFF6FFFFFAFFE4EBF3F9FFFFFFF7FFFEE5FB
FFF2FFF6FEFF9FCCC9457A72CFEFECEEFFFFE5FEFBF2FFFFF3F9F7FFFFFBF7F4EDAEAA9F
0A0600040000B8B8AEF6FCF2F9FFFBF6FFFAEBF8F1F7FFF9FCFFF4FBFCEAF2EDD7867B65
54413278625462513F8F886EE4E5C5C8D3A9D5E7B3CFE7A9D0EBA6C6E298D3EDA4C8DD9A
D9E8B1EBF4C7FCFFDDF4FAD4DDECB5CBDFA0D6E8AAD7EAAAD0E09F4C5D19D0E19BD6E7A0
CCDE92CFE293CEE491D3EB95D3F096D0EE94BBDA7DD9F39CD0DE93D8E1A2D8E5B0DDECC5
000A00000600000900FBFFFBFEFFF6FBFCEAFEFFE4FDFFDDD7E4B6C7DCA4C8E4A7D0EDAB
C8DF99475B1471853EC2D68FD9EFA7CBE09BD0E5A0D8EDA8D0E7A1C6DD99DAF1AD809753
8AA35FDAF3B1CAE3A1CDE2A1CDDB9EE2F0B2CDE0A0A3AF6F4E4C0F8D8D4FE7FBB4C8E096
DDE7A2D1DE9987A75ECCEEA4CFDF9EE4EEB1C6D195526221475D14CBE697D5F1A4B8D98A
CBF0A0C1E696BFDF93D6F2A7C9E197CFE39BD8E9A3C9DA94CDE19AC7DE96D0EEA4CFE99F
DFEBA1818F42DBFBA6C8F098BFEA91CDF19AD0E392D7E2949B9F53565E1198AE5CC9E692
C6E892D6F6A1C7E08FCCE395C9E79DC4E49BCBEBA2CFEDA5C9E49DCAE49DD1E8A2CEE39E
D1E5A0CBDC985C6D29CBDF9AD1E5A0D4E9A4C3DA94D9F4ADCBEDA3CDEFA5C7E59DCBE29C
9FAE6B8F9857DDE2A2DADC9BE9EBAC848A4AC8D293DEEEADCCE2A1C9E6A4C9ECA8CFEFAE
C4DBA3C9DBA7DAECB8D7EAB3CEE1A9D0E4A9CDE1A4D1E7A7
CAF697B9D77FE1E49D6358208A794ED9D3B1D8EBCD9FC6A978AD936FA28F678B81F1FFFF
F9FFFFFEFFFFF7F8FDFBFFFFF5FFFFF5FFFFFBFFFFF8FFFFEBFFFFF0FFFFFFFBFFFFF8FF
FFF4FFF9FFFF89B0AB1B463DF1FFFFF3FBFDF9FFFFF1F7F7FEFFFDF9F8F3FFFCF642352D
0D00003E2B25FFFAF6FCECECFFFCFDF5EFEFFFFEFFFFFFFBFBFCF4EFF0E2FEFDE9D7D1B9
DFD1B4958866A49E7A61623ACCD8AAD5E9B4CAE6A9C4E4A1C2E89FC7EDA4C7E7A4CAE8AC
C1D7A8F2FFDEF9FFEBE4F1D3C3DAA6CDEAA8CAE4A3CCE7A4D0E9A5CCE69F8EA55D8AA258
D1E99DCEE99AC4E18FD6F6A1CDEF98C6EA92CCF098CAEB94D7EA9BD1E09BD6E5ACC8D9AF
011100000500000302FCFFFFF6F6F6FFFFFAFFFFF1FBFFE6D1DDB9D2E5B8CEE9B6CEEAB0
D7EEAAD0E49C95A961CEE29ACAE097C9DF97DAF0A8C9DF97C6DD95DDF4AEC3DA94CCE39D
B5CF888EA7638BA460CFE6A2CCE1A0C9DE9DD0E5A4DDE9A9565215A6A467C9DA94CEE49C
D5DE9B9BA863A5C77DBFE399D4E7A5E1EBACD3DFA1D5E5A4BAD087AFCA7BBEDD8DCDF09E
C5EC99C6ED9ACEF1A1C6E597CEE89ED8EEA5D6E7A0ABBF77B0C67ED4EEA5CCEAA0C9E39A
DCE8A68E9D5AD4F2AAC1E79CC0E89FCCEDA6D4E4A3D9DFA1BBBB7F4A4E116E813FC9E49F
C6E89EC9E9A0D7F1AAC2DD96C2EB9FC8F7A7C0EB9CCEF7A9C9EFA2C6E89CC4E499CBEBA0
BFDF9476964B8CAC61C1E196D0F0A5CDEDA2C2E297CDEFA5CBF3AABBE39AC6EAA28AA860
869B56D9E8A3E0EBA7D0DA95D6DF9C87944FC0D18DC9DE9DD0EAA9D0F0AFB7DB9BCEF2B5
C1E2ADF0FFDCE5FFCFF0FFD8EEFFD6C7E9ACC7EAAAC3E8A5
C8E893D1E699ACAA6D594B1EDDCDACD5CFB5D8EAD275988236634ED9FFF4DFFEF6F0FFFF
FAFDFFFFFDFFFBF8FFFCFFFFF2FFFFF0FFFFF4FFFFF1FFFFE9FFFFEDFFFFFFFEFFFFFAFF
FFFBFFF9FFFF779C95426C6290A4A2F3FBFDFCFFFFFEFFFFFCFFFDFCFFF8FFFEF80A0000
0F0000543B37FFE7E6FFF8FAFFF4F8FFFBFFFFFDFFFFFFFDF6F7EFFEFFF4EEF3DFD2D2B8
D7CDAAF2E6BE77724A040500101900243604627B42607F43648747BBDDA0C9E7B1F0FFDD
F5FFE8E9F6E2F5FCF4F9FFF4F5FFDFDBF4BBCAE3AAD1E9AFC6DEA2BED496E6FABBCEE3A2
6A7F3CC0D791CDE79EBAD68CD0ECA1C2E195C3E397D4F3A5C9E493D8F0A4D2E6A9EEFDD2
323C24141912121116EDECF4FFFEFFF5F5F5FEFFF8F4FBE9F9FFEAD0E0BCDFF4CBE1F8C4
C7DC9BD4EAA1C0D48C99AF669CB269BDD38ADAF0A8D9EFA7D1E8A0D8EFA7CBE29CD2E9A3
C8DF99CDE7A096AD69CDE6A2D9F2AECAE39FD0E9A5CFDE9D565014A59F63D9E8A3D7EBA4
959E5B6B7833C7E99FCFF3A9CDE09ED5E1A1D0DC9CD5E6A2AEC479B4CF80C3E292CCEF9D
C4EB98C4EB98C8ED9DC8E99ACDE99ED1E99FCADE9694A860849A52CAE49BD0EEA4CEE8A1
CFDB9B8F9B5DD0EDAAB5DA94CEF3AEC8E7A4C3D194EAEDB4F1F0B8BDC0876D7D3F94AF6C
C1E29DBCDD98D9F4B1D0EEA8B5E194B7E897CFFAABB1D78AC1E699CBEBA0C9E99ECDEDA2
A5C77B95B76BB6DB8EC9EEA1C4E69AC5E79BC2E297CCECA3B1D58FD9FAB5A5C480A7C07C
E1F5B0C7D691DAE5A0DAE49FD3DD9898A35FBECD8AD9ECACD9EFB1CFE8AEDDFAC0DEFCC6
DFFCCCE4FFD3F0FFDDEEFFDAE1FFCBC4E8ABC4E8A8CBF2AF
CBE199D0DF9E6D703B99966DEEEDCFD7DFC8A5BEA869917969967FE2FFFAE9FFFBEDFFFA
ECF7F3FCFFFFFEFEFFFAFDFFF8FFFFF7FFFDF7FFFDF4FFFDEEFFFFF2FFFFFFFEFFFFFBFF
FFFDFFE1EDEDB8E0D7558378ADCCC6DAEEECF1FFFFEEFAF8E8F7F0F7FFF9C5C8BF040000
180B031E0B05C4AFACAE9C9CF0E1E4F2ECEEFFFFFFEAEFEBF9FFF8F3FFEFC5D3BC70765A
7467478976552A1B002F2607605F405B613F57633D2C3D13000B0061734B9BAA899FAB93
CFD5C9FFFFFFFFFCFF8F8D907880689EAA8466724A6C774DD6DFB4E0E9BCB7BF90DDE5B4
A7AF7C9BA370929C67DFECB6CAD7A2E2F0BBD5E6B0C4DD9CDBFFB0ACD181ECFFC6FCFFDD
33301D080000281B24C8BEC9F9F8FEF8FFFFECF9EFF1FFEFF6FFEBF9FFE6FAFFE2F8FFD8
D6E9A9C9E197D5EBA2AFC77D61792FC5DD93CEE59DC0D78FD2E9A1D0E79FCEE39ED0E5A0
D4E9A4B1C88292A764C9E29ECBE9A3BDDD94D0EBA4CDDC995B55199F965BDAE5A1C8D993
A3AA678D9A55D2F6ACC6ECA1C5DA95D4E09EE6F2B0AFBE79A6BB70BFD789CAE999C8EB99
C5EC9BC2EC9AC3EA9BCAEC9FCBE79CD0E89ECBDF988B9F58778D45CCE39BD1EDA3CFE69E
E2EDA966732ECCE89EC6EB9EC9EDA3CAE8A0D9E5A5D7D89CCBC98ED8D99D8C9D598FAA63
C1E399C5E79BD3EFA5C1DF95D6FBAEC0E699C7E79CDEFAB0D2E8A0D4E8A1D5E9A2AEC47C
94AE65B4D086D8F6ACCEECA2C4E096CFE9A0D1E79FD2E7A2E5F9BAB7C98DBBCB8DD7E3A5
DBE6A4DDE4A1D7DC99DFE29DCED18E989A59DCE0A3D5DAA0C9D29DF0FAC8FCFFD8F7FFD8
F8FFDFF7FFE1EEFFD4E9FFD0F5FFD8D3ECB3BEDA9DBEDB9B
B4B77E878A556F7046DEE2BFCBD4B9ACBEA666826B8EB298E5FFF2E7FFF3E5FFE9F1FFF3
F8FFF8FBFFFAFFFFFFFFFFFFFEFFFDFBFFFBF8FFFBF5FFFBF4FFFDF8FFFDFFFEFFFFFEFF
EBEFF0F2FFFFDAFFFA7FB1A5608E84D9FEF7EDFFFFF2FFFFF7FFFDFBFFFA8C8D85060000
6A5D55A190898E7C788D7D7D281E1F2E2A2B212121030804656D6220291817200B73765B
8C7F5D4A3A18675839C6BD9EDDD9BCD9DABBCBD0B0D3DDBAE8F7D08F9E779BA684677055
484C3B43443C454344656460848973586142757C5B757C5A222804737752858760DFE1B9
D0D3A8C4CA9EA8AE82868D61CFD8ADCDD6ABDAE5BABACD9685AA5C5D8232DDF7B8DFECC1
706F5A0B0200080002C8BCC6B8B3B7E8EAE5F9FFF4F8FFEDCFDEBFE8F6D2E9F3CEE9F7C6
D4E9A8C6E096E2FAB0C1D98FCDE59B7B9349698038DDF4ACCBE29AD0E79FD1E6A1CBE09B
D6EBA64E631E889B59C9E29EC8EAA0C3E79DD2F0A8D9EAA6655C21A49A5FDFE8A5D1DE99
9DA461CAD994C6ECA1C8F1A5D2E7A2D0DC9ADAE6A45C6B26ACC176CCE496D0ED9DC2E595
C5EC9BC4EE9CC1E899C8ED9FCAE69BD5EDA3D2E8A092A65FA4B871D6EDA5CAE69CCDE49C
DFE8A54F5A16C8E29BD0F2A8C3E49DC9E49FEAF2B6D2D198F7F0B96A69304F5E1DA7C07C
D9F9B0C9EB9FBDD98FD6F2A8BDDF93D0F2A6C2DE94CBE199D2E19CD3E09BB2BF7A6B7A35
ABC179C7E198D2F0A6C7E59BCAE69CD7EEA6D2E69FD1E09DD2DDA3D2DDA5A2AB72DFE9AC
E6EFAEE0E7A4D9DE9BE3E9A3DDE29F989D5BA1A568E5E8B1EAECBBDBDEB3FFFFDCEFF3CE
EBF3CCD9E5BDF1FED3E2F2C3DEEFBBCADDA5D9EFB1D1EAA9
8D764D63512BBBB593DEE3C5D7E7CD5D755B627C61B3CDB0F0FFEAF1FFE6EBFFDBECFDDB
FBFFECF7FAE9FCF7F1FFFDFBFFFEFBFFFFFBF7FFFBF5FFFBF8FFFDFCFFFDFFFFFFFCFFFF
F7FFFFEAFFFFE2FFFFD9FFFF478578ACE6DADBFFFFECFFFFFEFFFFEAE0DE90817E301F18
87746EF2DFD9FFF4F0F8EAE7B7ADACABA5A58584827C7B7799948EA9A1969D9181DDD3B8
BCB48D777346AEAB82CECEA8D7D8B6E3E9C5CED9AFD1DEB2F2FFCFEFFFCBF9FFD4B9CA94
B9C998C0CDA2B9C39EF4FFDDF1FFDCDAEAC5F9FFE1FBFFDF818C62717C51515A2DD0D9AA
4F5829626B3C424B1C424E1E67744679865868784B52652E576E2617310094AC70C9DFB1
5D70540411000D0F0ADED8D8CCC1BFB0A299E4D7C6FFFADDD7DBB6CCDCADE1F9C5BDDB9D
C8E39CD8F4A9BBD58CD7F1A8D7F1A8ADC77E6F8640B1C882CFE49FD2E7A2D9ECAACDE09E
D7EAA85366248C9C5BD2EBA7C7EDA2C7F0A2C1E196CFE09A5E551A9C9056DCE1A1DFEAA8
898E4ED1E09DB4DA8FC3EDA1D3EAA2DFECA7DAE7A2AAB772C0D288D6ECA1CFEB9EC0E094
C5EC9DC7F0A1C2E89BC6EB9ECCE89ED6EDA5C1D5908CA05BD6EAA5D7ECA7C4DE97D6EBA8
CFD5997C8448CBE4A3BFDD9DCAE8AAC6DEA2D9DDAADDD9AAD4C99C615D2D707B43C7DCA1
D1EFAFC0E09DC7E1A0D6F4AEC8EDA0C8ED9FD6F2A7D5E9A1DEEBA5CCD792727F39B5C67F
D1E99FCFEEA2C4E699C3E89ACEEEA2CCE89DCCE299D0E19DDFECB4C6D09CD5E0A8FCFFCD
FCFFCAE9F8B3D7E7A0CEDE95D3E39C919D5BD0DC9ED8E1AAD3D9ABF5F7CFF9F9D7D6D7B5
D9E0B7C4CFA4EDF9CBC7D5A2CDDEA7DBEFB2C0D696CEE4A3
997255BCA184FFFFE3E2F1D4EEFFEF4A6D4F88A787C2DEB8CDE4B8CEE1B3DAF1BDD8ECBB
CFE0B6E7F0D1FFFFEDFFF8EFFFFBFAFFFEFBF7FFFBF5FFFDFEFFFDFFFEFFFFFEFFFCFFFF
F1FFFFEEFFFFDAFEFA95C8C123655B05423AE4FFFFF5FFFFFFF6FAAF999B301818513C37
FFEFE8FFFCF3FFFDF4FFFFF8FFFFFBF6F8F5FEFFFDFFFFFAFFFDF6FFFBF1C8B1A3917C67
605B3BB1B38EFEFFE1FFFFE5FFFFE8EFF5D9F8FFE0FBFFDFD4E4B3DCEFB7CFE3A4CCE1A0
D4E9A8C7DB9CD4E8ABCEE1A9D9EDBAC0D6A5C3D7A6DAECB8D0E1ADCDDCA5D9E8B1E0EFB6
8492575A692E75844B68794291A26B7C8F58C5D8A1B4C98EB7CC87D1E8A2ADC68CD1E8BA
5B7051000700000200EEEAE1F8EADFFFFCEAB3A487999069D6DAA8E0EFB4A7C482DAFBB4
D5F3A9BCD88DD3EFA5C2DE94CCE69DCBE59CEBFFBC879E58D5EAA5CADF9AD8EBA9CFE2A0
D4E4A3BECE8D92A261D6EDA9BAE395C3EE9FBBDD91D0E19B7F753A9E8F56D4D697D9E4A2
DBE0A0DDECA9CEF4A9C2ECA0C2D991D2E19C96A35ED9E6A0D1E19AD7ECA1CEE89EC3E397
C5EA9CC6EFA0C4EA9DC5E79BCEEAA0D0E79F9BAF6A869753DFF3AECBE09BC8DF9BDCEFAD
EBF1B3B2B87CD0E6A5C2E19ECCE9A9D4E9AED4D6A4A7A07264572BC5BF8FDBE4ADD9EFB1
C2E19EBDDE99E0FBB8BCD792C4E99CBFE194C8E298C9DA93C4CF8A4E5813C3CE89C7D891
D5EFA5CAEA9EBCE394C9F0A1CDEFA2C4E397D2EAA0D5E8A6B4C18B5B6533D8E5AFE4F3B8
DFF4B3DBF2AAD9F1A7D0EAA0D3EAA2A5BA75ADBF81CAD7A1E0E7BBF5F7D2FAF9DA9B9A7B
A3A87FA2AA798D976398A56F86945997AA6ADDF0AED6EBA6
CBA18BFFF0D7FEFFE8EDFFECBFF1CE5C936CA7D4A9C7EBBBD4EFB8B6D093C4E3A0D4F4B3
BCD99FE0F6C7FCFFE4FFFFEDFFFAF8FFFBFDF8FFFDF8FFFFFFFBFFFFF9FFFFFAFFFFFDFF
FBFFFFDDEAF0F1FFFF6284863F7673DCFFFFE6F9FFFCFAFFF0DBE42E14173E2626B4A39C
FFFDF3FFFFF3E7EFE0EDFEEEF0FFF8F2FFFBF5FFFBEEF3ECFBF4EA907C71391B10977D70
E0DACEFEFFF6FEFFFAFAFCF7FEFFFDFAFFF9FBFFF6F5FEE9C5D3B0CBDCAFC8DBA3E8FEBE
C7DE9ABCD68FE0FAB3C4DD99CCE7A4D4EFACCEE7A5CCE69FD0E7A1C6DC93DEF2AAC6DB90
586A1EC8DD90D2E79CD0E49CCBE199D4EBA5C6DD97D5F0A9C1E399E3FFBFC2DBA4DBECC2
6C72582D2C1A6F675AFFFAEBFFFEE8FFFCDCE4E3B7D4D9A1525C1DA1B16ACDE297D0E89C
C5E196CFEDA3CCEAA0DBF9AFD1ECA5B8D38CC4DE97D5ECA6D4E9A6C6DB98D1E4A2D1E1A0
D2E0A2EBF9BB93A163D0E7A3C2EB9DC8F5A4CDF2A5DDEEA8C6BC7FB1A267DFE1A2DBE4A3
A4A969899855BAE395C1ED9ED0EAA1E2F1AC899650DBE8A2D7E7A0CFE39BCDE79ECBEBA0
C4E99CC5EB9EC7EBA1C3E59BCCE7A0CDE49E839654A2B271D5E5A4C9DC9AD1E6A3CDDE9A
D1D693C4CB85D2E89FD3F1A7CBE69FD8EDAAC9CA90605922A29560E5DEA7CFD99ACEE39E
D2F0A6C1E195D6F1A4CBE79ACAEA9ECFEFA3DEF4ABBFCC864A510DE3E8A5D2DC97D5E59E
C7E197C6E69ABFE697CAF1A2C6E89BC8E79BDAF2A8C0D08FB9C38FE4EDBED6E4AFD1E5A8
EDFFC4B6D18AC1E196C9E99DC5E39978934EC9DFA1DFF0BACDD4AABBBC9AC2BEA1FFFCDD
FFFFD8E0E4B1C8CF99DCE6AA515B1E566522D9E8A3CCDD96
DEC0B5E7D7C8F5FFECDBFFE57BB58F579669B7EDBBC6F1B9C1E1A2DBF6B3C9E49FC5DE9A
D1E6ABDEECB9CFD1AAF4E9D3FFF8F6FFF9FFFEFFFFFCFFFFFFFAFFFFF9FFFFFCFDFFFFFD
FFFFFFFBFFFFEFF8FFCCE5EC48807FBDF0F3F2FFFFFDF5FFA69198270F0F1E0B07CEC1BB
F3EFE4FEFFF4F7FFF6F2FFF8F1FFFBE7FDF1F5FFFBF9FEF7867D74A6948ABC9E93FFF7ED
FFFBF8F5FBFBFBFFFFF8FBFFEDF0F5FCFFFFFCFFFBF7FDF1D3DDC5DDE8C8CAD9AED1E3B1
D1E4ADD7EAB2C2D79ED2EAAEC2DC9BD2EDAAC7DE9ACEE49CCDE39AA3BA6C7B9443D5F19D
C7E38ED6EF9BC4DA88E0F3A4C8DD90D8EEA3D0E89EC1DF95CAEEA4C0E19C96AD775A663E
42452A2E2916615A4AB5B09CAAAB8C9AA178C9D6A0D5E5A66F833B8B9D51D2E393D2E798
D0EAA0CAE89ED6F2A8BAD48BD3EAA4D4EBA5D5EAA5A6BB76D4E9A6CFE4A1CEE19FD5E5A4
D5E5A4C5D49395A163CEE3A0CAF0A3BFEB9CC9EB9FC3D790D9D596A59B5EDFE1A2D7E09F
8B91517F8E4BC8EA9EC7EDA0CAE199CDDE989CA964CDDA94D6E5A0C7DB94CEE89FD2F2A7
C2E89BBFE89AC8ECA2C5E39BCDE19CD3E29F849453CADD9BCCE19ECFE4A1DCECABB7C47F
5F6920C8D488D2E99BD1E99FD4EBA3C8D7949C9E5F575316DFD99DDDDD9DDDEAA4CEE69A
CCE89BCBEA9CC5E091D4EFA2C7E295D8F0A6A3B46D687530BCC282CBD191E8F3B1CFE09A
C7E198CDEDA1C7EC9EC7EC9EC0E094CEEA9FD3EAA290A3618B9862DDE7B5D0DFA8CDE1A6
BAD090DDF6B4CDE8A3D5F0ABD6ECAC8DA166A6B481A3AC81C9CDACFCFCE0FAFAE2F0F1D2
E6E9BADBE0A6DCE4A9CDD599DFE8A9DCE7A346510CA9B670
EEE7EEE2E6E7F1FFFDE4FFF66197754E8C5DAFE8B1BCEEAFCAEEAED5EBAB69753773743B
A59B6AB5A2789D8362E0C1ADFFF6F4FFF3FEFFFBFFF2ECF8FFF9FFFFFBFFF7FBEDFBFFF1
F7F9EBFFFFF8F8FDFFE6FFFF3E8380A4E6E2E5FDFFFFFEFF887F7A2319103D342DE7E3DA
FEFEF6FEFFFAFAFFF9FBFFFDF9FFFDEFF5F1FEFFFBFFFFFA564B45FFFBF3FFEDE4FFFBF3
FFFFFBFBFFFFFCFFFFFCFFFFFEFFFDFEFFFAFEFFF8FEFFF4EDEFE1EDF0DDECF1DBECF1DB
ECF1DBEAF2DBEAF2DDE9F3D8DFF1C7CBDFACD9E6B1B1BA83B1BD7F8A9E57D4F5A6C2E893
CEF49DB9D984DAEFA0D7E59ACED994EDFAB5C0D590A6C079435F15728C45A9BC84D6E3B7
666D4ED7DBC4D1D6C0DAE4CBDFEECDF5FFDFAECA90A2BF7DA7C379D8F0A4D3EA9ACCE393
C3DD93D8F2ABD6EBA6D4E5A1D0DF9CE4F0AED0DF9C677834CEE29DD6EBA6CFE49FD0E5A0
CADB97D7E6A3939D5ED3E4A0C3E59BD0F6ABC0E097CBE09BEFF5B5989A5BD0D595DBE1A1
929B5A525E1CC7DE98DCF6AFCFE49FD7E8A4A3B26FDDECA7D4E8A3C6DB96DFF9B2C0E298
C2EEA1C6F2A5C6EAA0CDE29DEBEDAEDCDC9E879250CFE49FCDEBA3C4DE97DEE7A6737A37
8D9F55CDE597C9DF96E3F4B0BFCB8DD0D89CABAF744C4D11D6DD9ADCE8A0CBE093CFEA9B
D7F1A7CAE69CCDE49ECBE09BBCCD867F8F46BDCA85D1DD9DD8E6A9D5E3A8CCDEA0CDE2A1
D0EAA3CCEAA0CAE99DC9E89CC9E89CCAE69CC9E39CCBE09FCAD99E9AA76F91A067809258
87995FD8E7B0CAD4A0D7DDAD95966C74714EA39E81EBE5CFFFFFEDF7F8E8FEFFF4D7E0C5
D4DEAACDD999E1EBACDDE7A8CDD695E5EEADCED5926E7532
EDFFFFEBFFFFE9FFFFCDF4E144704F8FBD8FB9E6AFC4EAADC3E0A05D7030242900656029
504213655025765C37795B41DCBBB6FADFE6FFFAFFF6EEFDFFFAFFFDF4F7FBFFF1F1FEE4
FEFFEDFEFFF3FCFFFFE1FEFF42918B9EEBE3EEFFFFF9F5F64039310600004D493EFCF9F2
FFFFFAFFFFFBFAFAFAFEFFFFFFFFFFFFFFFDFFFDFCFFFDFA5A4F4BFFF1EAFFFBF3FFF9F1
FFFFFDFCFFFFFCFFFFFCFFFBFEFFFAFEFFF8FFFFF6FFFFF4FDFDF1FDFDF3FDFDF3FDFDF5
FCFDF7FCFDF8FCFCFAF9FFF3F8FFE8D0DFB6CBD0A8A4A579C3CA94D0E3A3D0F2A6BCE795
C2EE97CEF19DD6EB9ECFDB93DDE4A0C7D290758A47B3CC88839D53A2B772D1E3A9D1DEB0
676E4DD2DAC2DFEBD3DDEDD2E7FCDBF1FFDFC3E4ABCBEBA8C6E49CD2EDA0CEE595D1E89A
E6FDB5B4CB8590A45F909F5C919C5A96A15F8D9856586724D3E7A2CCE39DCFE6A0DDF4AE
D2E6A1CEDD9AA3AE6CCDDE9AD0F0A7BFE399DEF9B2C3D893838F4DA9AF6FDFE4A4D8DE9E
B8C1807C8846E3F4B0C2D691CADE99D1E5A0CDDE9AA9BA76E0F4AFC3DA94C3DD96D4F6AC
BCEB9DBDEC9ECFF3A9CCE09BDFD99DD9D095969C5CD3E8A3C5E79DCDE8A1D8DD9D7A7C3B
D8EEA3D6F5A7CDE39BD6E5A4E9F1B6E2E5AC90935A586122D8E59FD9EEA1CAE294C7E293
C2DC92C3DD96D7F0AED8EDAA78884176833BC1D08DD4E4A5D3E5A9CCE1A6D0E8AAD1ECA9
CAE8A0C9E89CC9E898CAE999CCEB9FCEECA2D1ECA7D2EBA9DDEDAFC2D095E1F0B7C1D099
606C3AADB689DFDFB99994768C8068A1927FE5D5C6F3E7D9FFFEF1FFFFF2FCFFF3C1D0B1
D7ECB3CAE19BD4EBA5D5EAA5CADE99DEEFABD9E8A5A4B370
CFFFFFD6FFFF98C9B64F775D597657D4E9C0CBD9A87D8850949E629CA566A3AB6FDCE4A8
D1D69EE0E5AFDCDEADD2C8A48B6F61604443C1BBBFF8F9FEFFFAFFFFFDFDFEFFF2FCFFEF
FCFFF1ECF2E8F8F8FFEAFFFF20736B8EE0D4F2FFFFF2E6E8180D070700006C655BFFFEF8
FFFEF9FBFCF7FDFDFDFCFCFCFFFFFFFFFFFDFEF8F8FFFCFA564B47FFFAF3FFFBF3FFF4EE
FFFFFDFEFFFFFEFFFFFEFFFDFFFFFBFFFFF8FFFFF8FFFFF6FFFFF6FFFFF6FFFFF8FFFFFA
FFFFFBFFFFFDFFFFFDFEFFF8F9FFEDE5F0CEC2C3A3B5B38DDADDAEDDECB1C7E6A0C7F0A1
BBE792D1F4A2D2E79AD0DC94E7EEAAB1BC7A718844CBE69FDCF6ADDDF4AED7E9AF000900
DBE2C1E2EAD2FBFFEDEBF9DFF5FFE8E9FFD6CAE7AFD3F1B1CBE6A1C0D88EC9DE91D6EBA0
C5DC9494AE67A1B671C8D995D8E4A2D7E2A0C1CD8BAEBF7BD1E6A1CFE6A0CFE6A0C7DE98
C5D994D5E6A2BEC987899855C0DE96C7E99FC5DF98DBEFAA4D58168A9050E7ECACD8DE9E
D6E19FACBB78DDF1ACCBE09BCCE19CD2E7A2DBEFAA6F833EA1B671E6FDB7C7E19AC8E89F
BCEB9DBEED9FC4E89ED8ECA7D8D296AEA56A949A5AD7ECA7C3E59BD0EBA4D5DA9A979958
CDE599C4E395C6DC94C3D291E2EAAFD6DBA193985E5C6526D0E099CCE395C9E495D5F2A2
D4F0A5CEE9A2BCD593879E5AC1D58DC7D98FDAEEA7CEE3A0CAE09FC8E3A0D3F1ABC9E99E
C9EC9CC6EC97C5EB94C5EB94C7EA98C7E99DC8E9A2CDE8A5D5E8A8D0DEA1C5D49BEDFBC8
F6FFD7FEFFE3FFFFEAFCF5E3FFFCF1F4E3D9FFEEE4FFF7E9FFFFECFCFFE4ECF5D6E0F6C8
CBF0ADBCE69ABEE89CC2ECA0BFE89CC6ECA1CEF2A8C8EAA0
C4FFFFBEFFF069A4881C43249DAC8BDBDBB5CFC79958511D5C5C20D0D998CDDE9AC3DA96
D4EDACDAF2B4C5DAA1EAF0C2CAB29A583D32908F8AF9FFFFFFFFFFFFFFFDF9F7EBFFFFF3
F8FEF0F9FFFBF0F4FDE5FFFF469D9599EBDFE4F2F2E1CED0291C16261C128C837CFFFEF8
FBF8F3FEFDFBFFFEFFFAFAFAFFFFFFFFFEFFFFFCFCFFF8F6635854FFFAF3FFFBF4FFFAF4
FFFEFDFEFFFFFEFFFFFEFFFDFFFFFBFFFFFAFFFFFAFFFFF8FFFFF8FFFFF8FFFFFAFFFFFB
FFFFFDFFFFFDFFFFFFFEFFFBF2FBEAFCFFECBFBDA4D1CEAFF9FAD2C4D19CC9E8A5CBF4A8
BFEA9ABEE393D0E799D8E59DDBE5A09AA762B7D18ACEECA4BFDB91CBE29EBCCD96152200
D8DFBEEBF0D9EAF2DBF9FFECF7FFE6D8EFC3C4DFA8C9E6A6D1EAA6D0E69ED8E89FD0E298
A0BA7193AE67BED38ECEE29DD5E19FDEEAA8D0DF9CD4E5A1CDE29DBFD992CEE8A1DBF5AE
DDF2ADD2E39FC2CD8B576623B1CC85D5F3ABB3CA84DBECA8596221989D5DE0E5A5D2D898
DDE8A6CADB97A0B570E4FBB5CBE29CD3EAA4D1E6A1869B567C914CD2E7A2CEE59FC4E49B
C1F0A2BFEEA0BEE298D9EDA8E2DEA16D64298A9050D7ECA7C7E99FC7E59DDFE4A4BABC7B
C9E195DBFCADDDF4ACD7E7A6D6E0A4D6DEA3A4A96F475112E1F2ABCFE698C1DC8DC5E494
C7E69AD6F4ACD0EBA88FA866C6DD95D0E89ECDE49EC8E39ECFEAA5CDEDA4D0F2A5BCE28F
C4EC94C3EE92C4EF93C4EF95C4EB98C3EA9BC2E89FC7E6A2C9D99AE0EBAFE0EDB8F2FDD2
F7FFDFF7FBE4FFFFF3FFFDF8FFF8F5EAD8D4F5E4DCFFFEECF9F3D9FBFFDAEDF9CBB9D197
C0E8A1BDEC9EBCEB9DC0EC9FC2EEA1BFE99DC0E99DCAF3A7
60C59B2F855E609C78DBFDDAD3D7B49D8F68705B2E9A8955C1C080E4F1ABC7E59BC6EC9F
C6EEA5B8E099BBDE9CEBFAC3FFFDDAAA927AA6A998EDFAF0F9FFFFFCFCFAFFFEF8FAF6ED
FDFFF9F2FCFBF5FFFFD2F7FF1D746C98E5DBF9FFFF392325271811463C32AFA69FFFFEF8
F9F4F0FFFDFCFFFEFFFBF9FCFFFEFFFFFBFCFFFDFDFEF4F29F918EB2A39CF7E6DFFFFBF6
FFFDFDFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFBFFFFFAFFFFFAFFFFFBFFFFFBFFFFFD
FFFFFDFFFFFFFFFFFFFEFFFDFCFFFAFFFFF4D1CBBBC8C2ACFFFFE1DBE7B9DAF8BCC1E9A2
C7F1A5BEE395CFE59AD8E59DCED9945F6E29D5F1A7C3E39AD1EFA7D7F0AFD5E8B1000900
D8DFC0EAEFD8FEFFEDFBFFECF8FFE6DDF2C7D0E7B1C9E1A3D3E8A5D1E59EACB97374843D
C7E198C3E199E1F8B2D3E8A3CAD996D4E3A0CFDE9BDAEEA9CDE49ED3EDA6DAF5AEC2DD96
C1D892D0E49FDAE6A4556421C3DD96CFE9A2D5E9A4BCC886545A1AC3C888DEE3A3D8DE9E
D6E2A0D9EDA86D843ED8F2ABC4DE97CEE8A1D2E9A3D0E5A0AFC47F879C57BFD690D9F9B0
C6F2A5BBEA9CCBEFA5CDE19CE6E2A550470C9BA161D2E7A2C7EBA1C5E39BE7ECACB6BB79
C2DD90CBEC9DC7E198CADD9BD4DFA3DAE4A871793E5B6727CADB94CEE698D4F1A1D3F4A3
C0E094C3E199C0DB9886A15ED1EAA6D7F2ABD1ECA7D3F2ACCBEBA2C2E799C7EE9BC3EE94
BCE98ABFED8BC4F290C6F396C6F09AC5EEA0C5EDA6CCEAAACFDEA3D1DAA3D2DBACD4DCB7
F8FDE7FFFFF4FFFEFDFFFBFFFFF9FFF0DDDF9A8981887D679894716B723F8F9D5FCFE49F
C7E59DD0F2A8CDEDA4C8E89FCEEEA5CDEBA3C6E49CCAE8A0
469D70065224ABDEB3C0D9B17E7F575E4F249F8F5CF3EAAFD3DD98C7E295B5DF8DC8F7A6
C7F6A8BBE79CCCEFABE8F7BCFBE9BB594220D7DDC3EDFFEDF2FFF8F9FDFCFFFDFAFFF5F3
FFFFFDE8F2F4E2FDFFDCFFFF398A84B5F6EEFCFFFF6A52500D00005D5048D4C9C3FFFDF8
FFF7F5FFFAFAFFFEFFFEFCFFFFFEFFFFFEFFFFFDFDFFF7F5ECDEDB4C3D38CFBCB6FFFAF5
FFFCFDFFFEFFFFFEFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFBFFFFFDFFFFFDFFFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFBFFF6F1B8AEA2E6E2C9FEFFDFDFFAC5C2E9A8
C2ECA2CDF2A5CBE198D0E097D6E39D3B4C05C2DE94CCEEA2C5E49EC3DD9ED1E3AF0E1B00
AFB697F1F5DCFFFFECFCFFEAF9FFE4E9FCCFD4E8B3C7DD9FCCDF9FD0DF9C8F9A5655641F
C9E49DC1E198CDE8A1D3EAA4D8E9A5D7E8A4CFE09CD5E9A4CFE6A0CAE59EC9E79FC2DD96
D2E9A3D8ECA7C9D5934B5A17D3E8A3CBE29CDEEFABCCD7955257178B8D4ED4D999EAF3B2
CDDC99E1F6B17D9750C6E49CD0EBA4C6E19ACFE9A2DDF4AEC4D89396AB66CCE39DCCECA3
C2EEA1BAE99BCBEDA3D4E8A3D5D1946D672BC1CA89CCE39DC6EAA0C9E9A0D9DF9FA3A866
D3EEA1C5E898CFEBA1D0E5A2E5F3B6D7E1A54D571BCBDA99D1E59DD0EB9CC7E696C6E796
C6E69AD7F7AEE5FFBFC3DD9CD3EDAEC2DC9DBCD999C9E8A5BDDE97C4E99CC3EB95C5F094
BFED8BC2F08DC4F290C3F093C0EA98BDE59CC1E5A5C8E4AAD7E3B1E4EABEFFFFDFFEFFE8
FEFFF3FFFFFAF4F0F1FFFBFFFFF1F6322222FFF2E5F6ECD1DFDEB2D4DCA191A15ABFD58A
CBE79DD3F1A9CDEBA3C3E199CBE69FD1ECA5CDE8A1CAE59E
7AAA80C9F4C9B6D1A699A97C404412E6E6B0DDE2A2CBDB94CAE999CFFBA6BDF29AB5E994
BAE596C7E99FDDF3B2DDE3A7B4A36B574618F5FCDAF4FFF1F0FFF6F8FFFFFFFDFDFFF9FB
FFF6FEF8FFFFD8FFFF98D9DD084C4BCEFBF8FFFFFD0F00000E000080716AF4E7E1FFFCF8
FFFBF9FFFBFBFFFEFFFFFDFFFFFCFFFFFEFFFFFDFDFFF8F7FFFBFA63544FA08D87FFF4EF
FFFCFDFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFDFEFFFFFEFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFEFFFBFAFFFAF5FBFFFBFFD8CBC5D0C9B7FEFFE4DBF5C5C8EEB1
BCE59FD0F4AACBE199D0E099DEEBA561752DBDDC90D2F4A8C3E29CDAF6B9C4D8A5000800
434A2B1012002D2F17ECF2D6F9FFE1E6F6C9CCDDA7D2E4A8D8E6A8E5F1B1B2BB7AB6C280
D3F1A9CEF0A6BDDB93C3DD96D1E5A0CEE29DD1E5A0CEE39ED1EBA488A35C66843C839E57
9AB16B869A55929E5C96A260CFE39ED6EAA5CAD694EAF3B291935467692A9DA262CFD897
CFDE9BDBF0AB99B46DC9E9A0D3F1A9C6E49CC9E49DC6DD97B5C984D6EAA5D8EDA8BDDB93
C1EDA0BEED9FC0E298DBEFAABAB679A6A064DAE3A2CCE39DC7EBA1CBEBA2B7BD7DB2B976
D2EEA1C9EC9CD3EFA5CADF9CBBC98C98A367616C30DDECABD2E69ED5F0A1C6E595C7EA98
CAEC9FBEDE95A1C07C6F8B4E889F697A915DA1B882C2DBA2B7D597D4F5AEC3E898BFE78F
C7F094C8F193C6EF93C2EA94BFE399C0E3A3C9E7B1D4EBBFDCE4BFCBCEAFF7FBE2FEFFED
EAF0E2F7FAF1FFFFFBB4ACA9F5EAE6A09488EDE1CBF1EBC7E8E8B6D5DE9FD0E09794AC5E
C8E89DC5E99FC4E89EC1E59BC4E69CC7EBA1C8ECA2C5E99F
DBE7C1DEEAC2454C2058602FDDE6ADD2E1A0D5EDA3CAED9BC3F199B1E68CBEF39BCAFAA6
BDE294CCE39DDDE9ABA5A5695F5114F4E9B3CED6ADEAFEE3F2FFFAEDFCF7FFFFFFFFFAFF
FFF6FFEFF5FFA3E7EA419293ACDFE3F0FFFFFBF6F2140100291811A79891FFF7F4FFFCFA
FFFCFBFFFDFFFFFDFFFFFDFFFFFAFEFFFDFFFFFDFFFFF5F4FFFBFAC6B7B27D6B67FFF2ED
FFFCFBFFFDFFFFFDFFFFFEFFFFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFAFFFFF9FFFFFAFBE2D8CCFCFFE5DFF6CAC5E8AE
C2E9A6C9EDA5D0E69ED3E39CD5E29C9CB068CEEDA1BEE094CCEDA8BFDB9ED6EAB7000D00
7C816175785D95987DD3D8BAFCFFE1EAF7C9CADBA4DEEDB2D0DEA0CDD798A0A668D2DE9E
BCDA92D5F9AFCAE8A0CDE7A0D6EBA6D0E49FCFE49FB4CB85758F48AEC982CFEDA5C7E29B
C8DF99D5E9A4DAE6A4D1DD9BD2E39FDCEBA8CCD795DBE1A1DCDE9FB9BB7C565B1B8E9756
D6E7A3C8DF9992B068CBEBA2C2E299CCECA3CDE8A1C9E39CC9DD98D7EBA6BDD28DD6F4AC
C8F2A6C0EC9FC6E89ECCE09BAAA669CCC68ADBE4A3CEE59FCAF0A5C6E69D98A160D9E09D
C6E295CBF0A0C7E399CAE19DA2B073949F63D7E2A6CDDC9BC8DE95D5F0A1C5E695C6E997
D1F3A6D2F4AAD4F3AFC8E4A9D3E6B9C8D8B1F2FFDBE7FACDA8C08CC5E1A4C1E09AD1F2A3
C8EA96C9EB95C8E998C7E79CCBE8A8D6F1BCE8FFD5F8FFE8FCFFEAFFFFF1F5F8E7FEFFF3
F9FFF19CA092BFC1B3E8E7D5E6DFCCD7D0B4D3CDA9D4D1A4D7DAA3D9E3A498A963CAE298
CAE89EC3E39AC9E9A0CFF1A7CBEBA2C7E99FCAECA2C8ECA2
D4BD9B92835C8B83558D925AC5D898D2F0A6C4EE9CBDEE95C1F69CBFF198BFEB96C3E696
CDE49CCFDB99D4D89D8B864C79702FEEE8AED9E0B7F0FFE6EFFFF7F2FFFFF2F8F8FFFBFF
FFF6FFF8FFFF2177740F6E6ADFFDFFFDFAFFC2BBB5352B1F130500A79891FFF4F1FFFCFA
FFFCFDF7F1F3FFFDFFFFFEFFFFFEFFFFFDFFFEF8FAFFF7F8FFFCFAF6E9E39B8C87CFC0BB
FDF2F0F2E8E9FFFCFDF4EEEEFDF9FAFFFEFFFEFEFFFBFCFEFEFFFFFCFFFFFEFFFFFFFEFF
FFFEFFFFFEFFFFFDFFFFFDFFFFFCFFFFF8FFFFF0FCFFFAFDC8BEB4F5F9E0DDF4C8CAEDB5
C4EBAAC7E8A3D3E8A3D3E29DD9E6A08D9E57D2EEA3C0E296C6E7A2CFEDAFCDE4B0000900
222806DEE1C4DFDFC3A6AA89FEFFDDE7F5C2CFE1A7D7E7A9DBE9ABCFDB9B91995DD8E7A6
CCECA3C3E99EC5E59CD8F3ACD3E8A3CDE19CD3E8A38EA55FC0DA93C9E49DC3E199D4EFA8
D4E9A4CEDF9BE2EDABD3DE9CCCDB98D5E19FECF5B4D1D696E4E6A7BDBF804A4F0F939E5C
D1E5A0CAE49D89A75FD5F7ADC6E69DC7E79EC0DB94D7F1AAD5E9A4D5E6A2D0E49FCDEBA3
BAE498BCE89BD6F8AECEDF9BA29E61E4DEA2D6DF9ECBE29CCFF5AAC7E79E9DA665D8E19E
D1EDA0C7EC9CD1EDA3D5ECA8839154CBD69ADFEAAED3E2A1CDE39ADAF5A6CBEC9BC8EB99
C9EB9EC3E59BCCEBA7CEE7AED3E1C0C4CCB4FCFFECFBFFE8C3D1ADDDEEC1CADFA7D2EBAA
BCD68FCBE59CDCF3AFC2D89AD1E3B1D9E9C2EDFADEFCFFF3FFFFFAFAF6F3EBECE4BEC2B4
D9E1CCD7E0C5F4FBDAE9EDC8E8E6BDABA87BB4B281DADAA4D6DBA1D3DFA19BAE6EC7DC99
D3E8A3D0E5A0CEE39ECBE29CCDE29DCFE6A0D0E7A1CFE9A2
623E1A82663ECFC391DDE3A7E3FAB4CCF1A3BBEB95C0F299B6E78EC4EE98D1F2A1D4EAA1
DCE8A6DBE1A3C5C68D828148979655DEDDA4D4D8B3FBFFEFF3FFFAF2FFFFF8FFFFFFFEFF
FFF7FFF4FFFF278B8360C3BEF5FFFFFFEAFAA79E972620123D3027D2C3BEFFFBF8FFFCFA
FFFCFDFAF4F8FFFDFFFFFDFFFEFCFFF8F6FBFFFBFFFFFDFDFDF3F1FFFCF8FFF9F3554842
B6A8A7FFFCFAFFFCFBFFF9FAFFFDFDFFFDFEFAFAFCFEFFFFFCFFFFFCFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFDFFFFFDFFFAF6FFFFFBFFFFF8FFFFF9FDCFC5BBFFFFEAE3FACEC2E5AD
C5E9A9D1F2ADCBE09BD2DF9A707B36BACA83D0ECA1C7E99FBFE29ECEECAED5ECB6000A00
3A401CCFD3B2E3E4C4DFE3BEFEFFDAE0EEB9D6E8ACCADD9DC9D998C2D1908E9A5CD2E2A1
C9E8A2BEE499CBEBA2C8E39CBDD28DD5E9A4879C57809751C3DD96D6F1AAD1ECA5D1EBA4
C9DE99C5D491D9E4A2D5DE9DDFEBA9B2BE7C6C75349EA363535516999B5CA7AD6DD7E2A0
DAEEA9DDF7B09EBE75C1E399BADA91DBF9B1D9F4ADC4DB95C9DA96D0E19DCBDF9AD0EBA4
C4EEA2BDE99CCFEFA6D0E19D9D995CA09A5ED6DF9ECCE69FC3E99EC3E59B939E5CD5DE9B
C7E396CDF0A0B8D48AD2E7A44E5C1FD9E4A8D4DFA3D5E4A3C9DD95CBE697C0DF8FC7EA98
CDEFA2CBEBA2CFEEAAC7DEAAFCFFECFFFFF4E5E7D9FFFFF1FEFFECF3FCDDFBFFDDDBEBBA
DFF0B9DDECB3D1E0A9E2EEBEFCFFDFF0F6DAFEFFF1FFFFF8D5D0D4DBD6DAF7F8F3E4EBDB
F8FFE7DFEBC5E7F3C3D8E2ADCBD096BABE81CACE91DEE4A6DBE5A8D5E3A691A568607437
D8E2A3D7E09FD5DE9DD8E1A0DBE4A3DAE5A3D3DE9CCDD896
886B3FAE9869E2DBA4D6E0A1CAE49BBEE393C1EB97CEF5A2CDEE9DCEE99ACFE099D1DC98
E0E6A8D6DBA18991584D551ABBC485D4DBA5D6D7B7FFFFF3F5FFFBF5FFFFF8FFFFF9FDFF
F1E9F6EDFFFF1B807863BEB9FDFBFFFFF2FF948B842A291743362EE6D7D2FFFBF8FFF8F7
FFFCFDFFFCFFFFFEFFFFFEFFFAF9FFFFFEFFFDFBFEFFFEFDFFF9F7FEF5F0FFFCF6756862
80716EE9DAD7FFF9F7FFFCFAFFFDFDF6F4F5FEFEFFFEFFFFFCFFFFFCFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFFFAFFFFF6F6C3B9ADFFFFE8E9FFD4C8EBB1
C7ECA9CBECA5D1E5A0D7E29E2A3300E0EDA8CDE79ECBEAA4C9E9A6CAE8AACEE5AF000B00
606640CFD3AECFD1ACD3D8AFFDFFD5F3FFC9CFE4A3D6EBA6C9DE9997AB66B6C685D3E8A5
CAE9A3C7EBA1D7F5ADD3EDA6D6EBA6CDE19C889C57BBD08BC9E09AD1EBA4C4DE97CBE29C
DDF1ACE3EFADE4EDACDAE0A0D4DF9D96A15F464F0E4E5313A0A263D4D999E3ECABC6D290
CFE49FBED992A8C87FD7F9AFCCECA3C8E69ED2ECA5CBE09BB8C985D2E19ECDDE9ACDE8A1
CBF5A9BEEA9DC7E79ED5E6A2A09C5F5C561ADCE7A5D4EEA7C1E79CC7E99F929D5BDAE3A0
CCE89BCEF1A1D0ECA2CDE29F4B591CD9E3A7DAE4A8CDDC9BD9EDA5D2ED9EC8E797CFF09F
C9E99DC3E39AD0EDAACBDFACF9FCE9FFFEFAFFFCF7FFFEF7FFFFF4FFFFEFEDF3D9F4FBD9
D7DFB6C2CB9EDFE6BCDDE1BCFFFFE6FFFFEDF9F7EBFFFEFBBDB8BCCDCBCCF8FBF2F3FCE7
F5FFE0CEE0AED1E3A7CDDE9ADFECA4BDC97FC1CB84C6D18CD7E6A5D7E9AB9FB47B2F4107
9392599C965AAAA468C1BB7FD9D397E7E1A5E8E2A6E2DEA1
E9DCA8E3DCA5DEE2A5CEDD9ACCE69CCDEE9FCBEC9DC8E797D2EA9ECBDD93CFDA96D8DEA0
E8EDB3D2D79F808753737E46CEDDA2E0ECBCE2E2CAFFFFF6F8FEFEF4FEFFF7FFFFF5FFFF
F4FFFFC6F0EF2E8B836CB8B8F7EEFFFFF2FF897F760D0C002C2219E9DAD5FFF9F7FCF2F1
FFFDFDFFFDFFFDFCFFFDFEFFFEFFFFFEFFFFFFFFFFF5F4F2FFFEFBFFFAF4FDF4EFEEE3DD
AFA099998783FFFCF6FFFDF8FDF8F5FBFAF8FFFFFFFBFCFEFCFFFFFCFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFDFFFFFDFFFFFEFFFFFDFFFFF6F8FFF4EFBDB4A3F6F9DAE0F8C8C8EAAE
C8EDAABCDB95E1F2AED8E19E434A07E3EEACCCE39DCBE9A3C8E8A5C2E0A2C6DDA5011100
676E44E8EDC5DDDFB7CAD0A0E0EBB3B9C98BD0E5A060772F9DB46C98AF67DEF1AFC9E09C
C2E49AC8ECA2BEDC94C8E29BCCE19C71854092A661C2D691D1E8A2D6F0A9CDE49EC8DD98
CDDE9ACAD593D2D898E1E7A76D7836737F3D8E9756E9EFAFD7DC9CDDE2A2CED796DCEBA8
D2E7A294AF6884A45BBFDF96CCEAA2C0DB94D4EBA5D0E49F9FAE6BD8E7A4D5E6A2C7E19A
C9F2A6C0EA9EC5E59CD9EAA6A4A063474105E1ECAAD2ECA5C7F0A4C7EBA194A05EDEE7A4
C7E396C3E495D4EEA5CADD9B4E591DD3DDA1DEE6ABD7E3A3CFE099CDE597C9E696CEEF9E
C5E599CCEAA2F2FFCAF8FFDAF9FAEAFFF6F7FFFDFDFFFDFDD7D3D0FFFFF8F2F4E69DA18A
B7BC9EBABE9D929371A3A485F4F2DBFFFFF1FFFEF6C6BEBBEFECE7F0F1E9FCFFF1F9FFE8
F6FFDCCDE5ABD1E8A4D7EDA2C4D78898A959D9E79ADAEAA1D4E8A3CFE5A4DEF8BBC4D89B
C2C88CACAA6D868447666427565417535114545416565618
D8E6A8D5E4A3CEDF9BD4E8A1D1E79ECDE599CDE599CFE79BD7EDA4D1E59EDDECABD4E0A2
BEC7907D84505457288A9462CEE0ACF3FFDAF5F6E6FFFAF7FFFEFFFEFEFFF8F9FDF4FFFF
E0FFFF41837971BCB8CCFDFFFFF6FFFFF1FF9F958C040100332920FCEFE9FFFCFAFFFAF8
FFFEFFFFFEFFF8F9FDFAFDFFFCFFFFF3F7FAFCFFFFFEFFFFF8F7F3FFFFF8FFFDF7FFFAF1
FFF6EE94817AFCEDE6FFFCF6FFFCF9FFFEFBFFFFFFFCFEFDFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFFFEFFFFFDFFFFFEFFFDFDFDFBFAF6FFF9F4FFFDF1C8C2ACEAF0CCCCE4B0BBDDA0
C5EAA5C2E19BE1F2AEC3CC89656A2AD9E2A1CEE19FCCE7A4CBEBA8C9E7A7C9E1A7000C00
2F360AD8DEB2DFE2B5BEC591D5E3A69DB16C3C540AC3DF92D0ECA1D0ECA2D7EEAACDE8A3
CEF0A6D7FBB1C2E098DCF3ADC6DA95849551D3E4A0D9EAA6C1D691D1E8A2D8EDA8D4E8A3
E0EFACD9E2A1999E5E565B1B596422D7E3A1CDD695D8DE9ED7DC9CDEE4A4E4EFADD6E5A2
4F641F7C9750C4E29AE0FFB7CEECA4C9E39CE1F6B1CEDF9B7B8A47D3E29FDCEDA9C4DE97
C7F0A4C4EEA2C7E79ED5E6A2A8A467554F13DAE5A3C4DE97CBF4A8C1E59B939F5DD8E39F
CBE699CAEB9CC1D890DFEFAE4C561AD5DDA2CED399DEE8A9CFE099D4EB9DCCE798CCEB9B
C8E79BD0EEA6F1FFC9F9FFDAFFFFF1F3EAEBFFFDFFFFFAFCEAE6E7D2D1CF21221A919385
D0D2BDDDE0C5DEDEC288886EB0AE99FAF4E4D5CCC3948E82FFFFEFF8FEE4FBFFE4F6FFDB
EFFFD0CFE9AACBE4A0CFE79DD8EFA1859A4BEBFDB1E7F9AFD1E79EBED891C6E49EDAF8B2
BFDA95C6E099CFE9A2D4EEA7D6EDA7D2E9A3CDE49ECAE19B
BFE099C8E89FC3DF95DAF1A9D1E59DCBDF97CFE59CD5EDA3CBE79DC0DB94D3EEABD5EBAD
D4E1AB929566A29F74F4F7CCD4E7BAF5FFE6FFFFF6FBF5F9FFFBFFFFFBFFFEF9FFF1FFFF
6BB4A0257A67C2F8F8EDFFFFFFFBFFFFEFFBA0968D201909483E35FFFCF8FFFCFAFFFDFB
FFFDFEFDFDFFF9FCFFFBFFFFF9FEFFFBFFFFF1F6F9FCFFFFFAFBF6FFFFFAFFFFF8FEF5EC
FFFBF1CBB9AF97867EECDFD7FFFEF8FFFFFAF6F6F4FCFFFFFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFFFFFDFFFDFDFFFEFBFEFFFAFCFEF3FFFBEFFFFEEDC1BC9FDEE5BCC7E0A9C2E5A3
C1E6A0D6F4ACD7E6A1ACB370595B1CDBE1A3D0E0A1D0E9A7D0EFACCCEAAACAE2A8000F00
1E2600D4DAACDDE1AFB4BD867C8B4A94AA61CCE79AD0EF9FC5E496B9D88CC3DE97CAE8A2
BADE94C4E69CBED992D3EAA49BAF6ACEDF9BE5F4B1D1E29EE8FCB7BBD08BCEE39EDEEFAB
9FAB695B6121757738CED091D2DD9BD4E3A0D2DD9BD5DE9DDBE1A1D9DF9F0F1A00768743
CFE49FD0EBA4D0EEA6C1DF97C4DF98D9F0AAC9DD988F9E5B6C7836CAD996DDEEAAC7E19A
C9F2A6C8F2A6C8E89FCEDF9BBAB679696327D6E19FBED992CCF6AAC1E79C94A05ED6E19D
D2EDA0CCEB9DCFE59DE0EFAE7B8348AFB47A9FA46A8C9556CCDC95DFF6A8CFEA9BC9E696
D0ECA1CDE8A1CEE7A5C9D9A8FFFFEEFFFEFBF9F3F5FFFBFFB4B2B5D6D6D6F2F3EEFFFFF8
FFFFF1FFFFECF2F4DCFFFFEAE7E5D08C8774B2AC9EE8E5D2F6FAD7DEEABCD2E2B1D1E6AE
D2EBB1C6E3A3C5E29FCAE59ED3EAA260762DBCD186BFD58AD0EB9EDCFBADC5E697C4E99B
CAEFA2C8EEA3C6EAA0C0E49ABDE197C0E49ACCEEA4D3F7AD
BFF0A1CEFAADBFE195D6F0A7D4E59ED9EAA3D4ECA2C4E298CDF6AAB6E297BFEAA3BEE1A1
D8E9B396976BCABA98FFF7D4ECFED8F0FFEAFEFFFBFFF9FFFFF9FFFFF9FFFFF6FFD9F2EC
25886983EBD0E6FFFFEDEEFFFAF7FFFCF7FD716660140800574A42FFFCF8FFF5F3FFFDFD
FCFAFBFBFCFEFBFFFFF9FFFFF3FBFEF9FFFFECF1F4FCFFFFFEFFFDE9EAE4F7F7EFFFFEF4
FFF0E6FBE7DC55443ABAADA4FFFEF6FFFCF7F9F9F7FCFFFFFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFFFFFDFFFDFDFFFFFAFCFFF6FEFFF3FFFCECFFFBE3ADAA89D5DEB1CCE5ABCCEFAB
C5E9A1D3F1A9DFECA7AFB4724E4E10DFE3A6CEDC9ED6ECACC6E5A1C5E4A1CCE4A8011200
38400FCDD3A3DCE3AFD9E3A7CDDE9AD8F0A4C4E191CDEF9BCEF19FC3E696D9F9AECDEFA5
C9EDA3CDEFA5D0EBA4CFE6A08B9C58E4F3B0D0DC9AC4D390C9DA96D5E9A4E3F7B29AA966
616C2A9CA161D5D597DADC9DD8E3A1D4E3A0E1ECAAD1DA999CA2627B8443D3DE9CD6E7A3
D4E9A4CCE7A0C9E79FD1EFA7D7F1AADBF0ABBCCD89A0AF6C899553CEDA98D8E7A4CAE49D
C9F2A6C4EEA2C9E9A0D1E29ED7D396676125D7E3A1C9E49DC7F1A5CAF0A595A15FD9E4A0
C8E396C0DF91D4EAA2CBDA99B6BE839C9F66989B62515A1B96A35DCDE295CBE395C3DE8F
D6F0A6D2ECA5CAE3A1CCDCABFFFFECF2F2EAFCFBF7FFFFFFF7F7F9FEFFFFFEFFFDF9FCF5
F7FBECFAFFE9FFFFEAF1F4D9F9F9E1F5F3DEEDEAD7F8F8DCECF4C1DBE9ABCBDD9FC8E1A0
C8E5A5CBE9A9CFEDADD5F2B0D7F0AE869D59D2E9A1CCE498C6E391CBED97BFE38BC9EF98
C1E698C4E89EC9EBA1CAECA2C8EAA0C6E89EC5E59CC4E69C
C6EAA4C7EBA392B16B8DA8618B9F58B4C57FD2E8A0CDEBA1C3EFA2B8E89ECBF6B1C1E0A5
DDE6B795906ADFCEB0FFFDE1FBFFE8E7F8E5F9FFFFF8FFFFEAFCFFF0FFFFECF9FFB2D9D6
2B8770BCFFFCEAFBFFFFF8FFFFFBFFFFFDFF615A520700005F564DFFFDF6FDF3F1FFFEFB
FFFEFFFEFEFFFBFFFFF4FCFFF4FEFFF7FFFFF8FFFFECF5F4FCFFFDFEFFFBFFFFF8FFF9EF
FFFAF0FFFAEF625147A0968DFFFEF8FFFEF9FEFFFDF8FCFBFCFFFFFCFFFFFEFFFFFEFFFF
FFFEFFFFFFFDFFFEFDFFFFFBF4FAF0FCFFF4FFFFEFFEFCE5A8A989D7E0B5CCE3ADC6E4A8
D0EDADC1D99BF1FCC0C4C78E595923DEE3ABCBD69ED9EDB0C9E6A4CFECACD6EBB2000A00
171E00747A4C9BA171D8E3ABCDE09ED2ECA2CCEC99C6E995C3E694D0F2A5BFDF96C4E39D
C4E49BC8E69CCFE9A2C8DD9899A865CFDB99D1DD9BDEEDAAD8ECA7CADF9AD0E5A093A460
74803EC7D08FF5F7B8D2D898D5E9A4CAE19BCFE49FB0C47F4A5B17B6C783C9DD98D0E5A0
C9E09ACDE7A0C8E39CCEE8A1CBDF9ACAD996A0AB69939E5CB4C07ED6E7A1D2E39FC9E39C
C8ECA2C1E79CCBE9A1DAEBA7E5E7A8525214D7E3A1D5ECA6C3E59BD4F2AA919D5BD9E4A0
CBE79CD1F1A5C4DB93D8E8A7D8E2A5DDE2A8DAE0A4959B5D76813DD1E19AD9EEA3C7DD92
D1E8A0C9E09CC7DD9CD8EAB6FCFFE6F9FDECFEFFF6FCFFF8FEFFFFEFF0F2FEFFFFFBFDFA
FEFFFAFCFFF2FAFFEBFBFFE9FEFFE8E6ECD0DCE2C6D4DCB3D7E3A3D5E79DD3E7A2D5EBAA
CFE9AACEE8ABC9E1A3CCE0A1CBD99C8C965AC6CE93DBE4A5DBE8A3D6E69BCEE491D2EB98
CEEDA1CBEBA2C9E9A0CAEAA1CCECA3CDEDA4CBEBA2C7E99F
D9D3A1DFE4AE8AA0607D9A57D6EDA7AEC27BC8D993D5ECA4BFE59AC8F0A9CAE6A9EFF9C7
B8AE8A57482BFFFFE4FFFFEAFEFDEBFCFFFAECFFFFCCFCFF97ECEF68C7CB64AEB747838B
BCEFF2E9FFFFFCFFFFFFF7FEFFF0F6FFFAFA6A6D64020A00474538FFFAEFFFF7F0FFFDFA
FCF6F6F7F5F8F9FCFFF9FFFFEAF8FBF4FFFFF4FFFFF7FFFFF7FFFDF8FAF5FCF9F4FFFCF8
FFF9F4FFEBE56B5A53C6BDB6FEFBF6FCFEF9F0F5F1FCFFFFFEFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFF7FDFBFBFFFDFEFFF6F3F8E4B6BCA0CDD7B4CBDAB1D6E7BA
EAFACDFBFFDCFEFFDDA3AA80969B72C8CFA3DAE3B4D3E1ACD0E6A8D1E6ABD1E1B0000800
131900010500707650CEDAAACFE5A7CCE89EC9EA99C8EB97C8EB9BC9E99ECAE7A4CCE7A4
C6E19AD4ECA2D5E9A2D2E19CB8C580DCE7A3DDEAA5CBDA95C9DE99DDF7B0BFD992809A53
819653D8E8A7D5E1A1CCDF9DC9EBA1C1EB9FCDF6AA9AC075CFF5AAC6EAA0BBDD93D1EFA7
C0DB94D2ECA5CEE29DD4E3A0838C4B4E5011E0DEA1E5E7A8D3E49EC8E096D2E9A1D4EEA5
BEDA90D1EDA3C9E098D2E69FCEDA9855601ECBD795D6E7A3D4E7A5CADA99B3BD7ED4E3A0
CDEDA2BBE093C8E89FD4EEA7CDE09ED3DF9FDFE8A9E2E8AA6C723280894865702EE0EFAC
D2E2A1CADF9ED4E8A9CDE2A9E5F6CAE6F6D2F9FFECFBFFF3F7FCF6FEFFFFFEFDFFFCFBFF
FEFDFFFEFFFFF4F9F2F4FFECF8FFEAF4FFE3CAE1B5CCE3ABCCE098D2E498D7EAAACADCA2
D6E7B088955D7981455F5F21625920403000765F36472F0B8A744DA08E5EA99D619F9E5B
D2E39DC6E19ACDEBA3DCFAB2C4E49BC7E79EC4E69CC4E89E
FFEEC5928A5BCFE3A6DDFCB9829D58D4EAA2D3E49DC5DB93CCF0A6C7EBA5CADCA2F0EFC3
A08D6D8F7B62FFFFE8F7F9E4FFF9EFFCFFFDE7FFFF7FC3C42997960C828437939E63A2B1
E9FFFFF7FFFFF7F8FCFFFDFBFFFAFAFFFAFA7678730003004F4D41FFFFF3FFFDF4FDF4EF
FFFCFDFFFDFFFCFDFFF9FFFFF5FFFFF4FFFFEDFDFDEDFBFBF9FFFFFEFFFBFFFEFAFFFBF8
FFF8F6F6DEDA675551E9E0DBFFFFFAFCFFFBF8FCFBFAFEFDFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFCFFFFF9FDFFFBFFFFFCFFF8F6FDEBC1CAAFE0EAC8D5DFBAD1DCB4
E6F0CBF7FFDCFBFFE0A5AF8AA0A881CCD7ACDCE5B6D5E3AECEE2A5D9EDB2C0CD9F0A1200
121700060B00686F4DD5E2B6CFE4A9CAE8A0C8EB9BC6EC97C8EB9BC9E99ECCE6A5CDE6A5
D3EDA6D3EBA1C8D9929CAC65949F5BCCD793DBE8A3D8E9A3DBF2ACC7E19A839E5749641D
94AB67CBE09DDFEFAEC7DC99CBEDA3C0E99D82AB5FC9F2A6B2DB8FCBF4A8D1F5ABBEE096
D4F4ABDCF6AFD1E6A1D1E09D96A15F6D7232D8DA9BD3DA97DFF5ADC8E499C0DA90E0FAB0
D0E79FD0E79FD6ECA4D1E79FD9EDA8C3D4907E8D4ACFDB99D9E5A5D6E0A1BEC889D4E4A3
CDEDA4CDF3A8CCEEA4DAF5AECEE59FC8D995DDE9A9CDD6978D9355595F2161692D4E5A1C
E4F2B4D2E5A5C4D899D7EDAFCBDFAAC7D8ACECFAD7F5FFE6FEFFF6FFFFFDFFFDFFFBF5FF
FFFCFFF9F6FDFEFFFBFBFFF4F1FFE4D3EAC0BCD7A4D5EFB0CFE497EBFBB0C4D496DDECB5
8B9863555C26989A5BD5D090E7D69E6C5426DDBC9DB492796E4E35684B296E58265D5316
5C652460742FD7EBA6C3D893C3DA94D4EEA7CEE8A1D1ECA5
96835886804ECFE5A5C5E6A15C7A32CAE199E0F1AAD8EEA6C9EBA1C8E7A3D5E4ABEFEEC2
624F2F9F8B72E2DEC5EAECD7FFFFF8E2ECEBBDEAE7286E6C1F797A85DEE40E525F558593
E9FFFFEFFFFFEFFFFCF7FFFDF9FFFBFEFFFDA29C9E070000150C03DAD2C7FFFDF4F6EDE8
FFFCFBFFFDFFEDEBF0F9FCFFF8FFFFF4FFFFF2FFFFF6FFFFFCFFFDFEFDF9FEF6F3FFF1EE
FFE9E7B39B9742302CF2E9E4FCFBF6FCFFFBFCFFFFFCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFCFFFDFDFFF5FEFFEFD4DBBCFCFFDFE5F0C6D3DEB3
EDF8CDFBFFDBFCFFDCADBA8EB1BD8DD2E0ADD8E5AFCEE0A6CCE2A4CFE4A9D0E0B1040E00
424729060A006D7452CEDBAFCFE4A9CAE8A0C8EB99C6EC97C8EB99C9E99DCCE7A2CCE7A4
C8E49ACEE89ED3E79F8B9C559AA762D8E39FD6E39ED1E29CC6DD97CDE7A0AFCA8369843D
99B06CC6D997D6E5A4DEEAAAD3E4A0CEE39E97AC67C8E29BDEF8B1C1DF97C7E59DC5E59C
C3E39AC7E79EC9E79FC9E49DA4BE777A914B91A661778E4686A057D7F3A8C0DA90BFD98F
CFE69ED2E9A1CAE098CBE199E1F5B0C5D6928FA05CCFDE9BCAD998E7F3B3D4E0A0768947
BFDD95CEF0A4C0DE94B8D48AD4EBA5D8ECA7CCDB9ADDE9A9C9D394D6E0A1A7B375657335
CDDD9EDEEEAFDFF2B2C9DB9DE4F5BED9E7B6F3FED6F1F5DAFBF9ECFDF8F4FFFCFFFFFBFF
F9EDF7FFFBFFF4F1ECFFFFF1EAF0D4F7FFDBD6E6B5D4E6AAD6E499CBD78DD3DEA246531D
586530E3ECB5C7CC8CEDECABF9F0B59F8F5EEBD7B6FDE8CDEAD9BDE2D5B2D6D09CDFDDA0
9393556F71329FA162BBC080E4EAAAE0E9A8D9E2A1D8E3A1
A99D6BA09F67C8DE9D50712AC2E096D6F0A6CADE96D3E9A1C6E69DC8E5A2D9E6B0F3F0C5
453212A38F76DBD7BEEBEEDBFFFFFAF2FFFF93C7C341868375B8BED5FFFF9CC8D5648491
C2DBE2E4FCFCEBFFFFE7FFFAE8FFFEF2FFFFDDD1DB1400070A00009F978CFFFDF4FFFCF8
FFFBFBFFFCFDFDF8FCFEFFFFF6FEFFF7FFFFF7FFFFF9FFFFFDFFFCFEFBF6FFFDF8FFF9F5
FFF8F4AB938F73615DFFFDF8FEFDF8FBFFFAF9FDFCFCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFCFFFFFEFFFFFFFFFBFDFFF2FEFFECCCD3B2FDFFDCEAF6C8D8E4B4
E8F4C4F1FFCEF8FFD5A7B884BACB94D2E4A8D3E5A7CCE1A0CFE8A7CCE4A8D8EABA000700
5156380004006E7554D0E0B3CFE4A9CAE8A0C8EB99C6EC95C8EB97C9EA9BCAE8A0CCE7A0
C9E79DCCE89DCEE69C6A7E368B9853D5E29DD2E19CD5E6A0CFE6A0D0EAA3C9E49D90AA63
92A764F1FFC0D5E1A1CDD697E0E9A8D7E09FDFEAA8909F5CCEDF9BD6EBA6CFE9A2D1EFA7
C9E9A0C6E89ECEF0A6CDEFA5CDEFA5CBEDA3CDEFA5C9E99ECDE99F526E23526C22CBE59B
D2E9A1C7DE96D1E8A0D1E79FC6DB965367225B6F2AD8ECA7D6E6A5C7D796D3E3A2899D58
D7F1AAC6E298DEF8AFC8E299CDE49EDCF1ACC0D391DFEFAEDDEDACE0F0AFCEDE9F4C5C1D
0B1B00CDDD9ECBDB9CD8E8AACEDCA1C7D19DD5DCB2E4E5C6F3EEDBFFFCF6FFFBFBFFF5FA
FFFAFFFFFAFDF7ECE8FFFFEFFFFFE6DCDEB9EAF2C3C5CE95D2D993E4EBA5A0AA6E4A541F
919E68DEE9AFD8E19EDADF9CCFCD90EEE8B6EFE4C4FFF8DDFFFDE0D4D6B1CFD9A4E3EDAE
DADA9E645E224C480B5F5B1E080600D4D295E0E0A2DADC9D
CDC890D3D99B758F48B6D88CCFEFA3D3EFA2C9E195D2EAA0D1EFA7CBE4A2CFD9A4F4F1C6
5E4D2FB8A68EFDF7DFFEFFF0F9FFFFE5FFFF69A49E86C7C3E2FFFFE9FFFFEDFDFF25333E
5A6F70ABCAC4E3FFFFDCFFFFD1FFFAE0FFFEFAECFB5E3D4E110200484035C3B9B0FFF5EF
FFF4F3FFF5F6FDF7FBFAFAFCFCFFFFF5FEFDF9FFFFFCFFFDFEFDF9FFFDFAFFFBF8FFF8F4
FDE4E0B29A96D6C4C0FFFDF8FFFEF9FCFFFBFAFEFDFCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFCFCFCFFFEFAFBFBEFFCFFE9AAB08CE1EABFDAE6B4D2DFAA
D1E0A9D5E4ADDBECB592A66BBCD091D0E5A2D2E9A1CFE9A0CFEAA5D7F1B4C1D5A4000800
282E12000400666D4EE5F4C9CFE4ABCAE8A0C8EB99C6EC95C8EC95C9EA99CAE99DCAE89E
CAEA9ECDECA0D2ECA271873E909F5AD9E8A3D5E49FD5E9A2D6EDA7CBE59EBBD58E9CB36D
708341B7C685DFE9AAD4DA9CDCE1A1CACF8FDBE1A17A85435F6E2BD4E8A3D3EAA4BED992
CEECA4C5E79DCAECA2BFE399BCE096C7EBA1B9DD93C7E99DC8E49AC1DB91D2ECA28CA65C
415B129BB56CCEE89FCFE69EDDF4AEBED38E6A7F3ACBE09BDFF4B1C4D996D3E8A5D2E7A2
8196516E843CA7BD75D7EDA5CEE59DD2E9A1D3EAA4BFD690C7DE9ABCD18EE1F6B3849956
1D2D00C7D798CDDD9EE1EFB1E6F0B4CBD29CA0A376928F6E776F5A95877C5C4A48321E20
685358B19D9FB4A29EFFFCEFFFFFE6FFFBD9E2DFB6FCFAC7E6E6A6CBCE8B52571DB6BF8A
D2DDA5D1DFA2DDE8A3CCD691D6DC9EE6E8B7F0F1D1FFFFEAEFF8DDDAEAC5E5FEC7C9DF9F
D1D598F1EDB0F6F2B5B8B4779D995C555316ABA96CA2A264
C3C88895A15FC7E399D3F5A8C3E696C6E597C2DD90DFF7ADCEE8A1D1E6A5D3DCA7F1EEC3
6A5D3DB2A48AFFFFE8FEFFF1EAFAF9E6FFFF3C77739CD3D0F0FFFFF9FBFFFFFDFFFCFFFF
7184806384795B8C7973B19C9EE5D3CCFBF5FFFAFFC7AABE251515160E038D837AFFFCF6
FFFBFAFFFBFBFFFCFFFFFEFFFEFFFFF6FAF9F9FDFCFEFFFDFFFFFAFFFDF8EADBD6AB9693
8E7571AE9692FFFAF6FFFBF6F5F4EFFCFFFBFCFFFFFCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFDFBFEFFFEFBFFFEF2FAFCE6939776CFD6AAD2DCAAD0DDA7
D1E0A7CBDDA3D0E4A7889E5EC1D894CBE59CCDE89BCEEA9DC2E299CDE9ACCAE0AF000E00
2D331700040073795DEAF6CECFE4ACCAE8A2C8EB99C6EC95C8EC95C8EB97CAE99BC9E99D
C3E598CBEB9FD3EFA490A85E9FB06ADAEBA5D4E59FCDE19AC6DD97D4EEA7CBE59EBED58F
6B7E3C3C4B0AD1DA9BEDF3B5E0E9A8E5F0AEDFEBA9C6D592899A56A9BD78BBD28CD4EEA7
C3DE97BEDC94CEECA4D3F3AACBEBA2D5F5ACC1DF97CEECA2D3EDA4CEE89ED6F0A6D5EFA5
D3EDA498B269354F0691AB62BFD992E2FCB5C7DE9892AC65CDE6A2DBF4B0CFE8A4CEE59F
E1F2ACD6E5A072833D8A9E57CCE39BC5DF96D9F4ADD3EEA7D6F1ACD1ECA7C1DA96B6CD89
4E612162723362703298A466475114636B32848657B0AE88C3B9A0FFFDEDFFF2EEFFEBED
DAC4C7AA91948C7774645047D4C3B1FFFEE3FFFBD8EBE4B8DAD89D6264239DA26ADCE5B0
C2CD93E0EFAED6E39DE2EFA7ECF6B9B7BF8EE8EDCFFBFFEDEEFCE3F2FFE6D9FAC5BCDA9A
EAF6B6C5CA8AC9CE8EDEE3A3E8EDAD9FA464858B4B9EA464
CDD894D3E49DC7E398D2F5A5CEF1A1D0F1A0D1EDA0BDD78DC9E09AD7E7A8DEE5B1E7E4B9
665C39B4A98DF9F5DAFBFFF3E5FFFEE2FFFF1C504EC2EAEAF9FFFFF5E9F7F7ECF4FFFDFE
F5FFFD89A99A1E4F3C2B68566FB1A3A1CFCDECEFFFFAEBFE3E34330700004F453CF2E7E1
FFF4F3FFF4F4FFF8F9FDF9F8FFFFFFF9FBF8FEFFFDFFFFFBFFFDF9FFF8F4C6B4B0604B48
967D79EBD3CFFFFAF6FFFAF5FFFEF9FCFFFBF9FDFCFBFFFEFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFFFDFFFFFDFFFFFEF8FFFFED949778D9E0B7DDE7B5D9E6B0
DEEDB4D2E4AAD3E9AB88A15FC9E49DC9E89CC6E595C8E998BFE197C4E2A4D8EEBD000D00
353B2100030082886EE2EECACFE3B0CCE6A5C9EA9BC8EC95C8EC95C8EC95CAE999C9EA9B
C8ED9FC8EA9DBCDB8F92AC628B9F58C3D790D2E69FD0E69ED1E8A2D4EEA7CCE69FD2E9A3
9DAD6C4C5818AAB072D7E1A2C0D590CFE9A2C9E39CD7F1AACAE49D7F995292AC65B1C882
DEF5AFCBE09BCBE09BDAEEA9C8DC97D5E6A2CBDA97D6E7A1D2E8A0C3DB91C6DE94C3DB91
CAE49BDCF6AD94AE658BA55C859F585B762FB7D18A8CA760C8E39ECAE5A0C4DF9AD3EAA4
CEDB96E9F4AF86964F81954DDFF6AEDAF6ACBEDC94C3E39AC4E69CB9D990D5F3ADD3ECA8
859A577282411524005D692B4D571A7C844BD4D7A8FDFDD7FFFFE4FFFEECFFFBF4FFF9F8
FFF7F9FFF4F6EFD7D7A7928D927F71CEBDA9FFFCE3FFFEDBDDDAA54F5316A7AE78D3DDA8
E3F1B6D4E5A1D2E299C1CE86C8D295BAC293F7FBE2F7FFEFF8FFF3F2FFECCBEBB9DFFFC0
BCD794F1FFC2D0E7A1C6DD97E7FEB8C0D791C8DD98DDF2AD
D0E49CDFF5AAC2E193C3E696CFF5A2B9DC8ACDEE9FD5EFA5D6EAA5DAE6A8DADDA8DCD9AC
706A46DBD6B6FFFCDFF8FFF1D4FBF87CACB093BABFEAFFFFFFFEFFFFF4FBFFFAFDFFFFFA
EFFBF1EDFFFBE3FFFFD3FFF97DB0AB2D54596F8090EAEDFC979795343027272018CDC2BE
FDF2F0FFFBFBFFFCFDFFFDFDFDFCFAFBFBF9FFFFFBFFFEF9FFF9F3FFFCF8E1CECA7F6765
D2B9B5FFF8F4FFEEEAFFF8F3FFFFFAF8FDF7F2F6F5FCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFFF8FFFFFAFFFFFBF7FFFFF19F9F85E8EEC8EAF3C6E0EEB9
DAEBB5CDE1A6CFE5A786A05FCDEBA5CBEB9FC6E796C9EC9AC9EDA3D1F1B0BBD3A1000D00
050A000609007C7F6AEAF3D4D0E2B2CDE5A7CAE89EC8EB97C9EB95C9EB95CAE999C9EA9B
C5EA9CCDF2A4CDECA0C7E197AEC47CD4E8A1DAEEA7CBE199CDE49EC8E29BD0EAA3CFE6A0
ABBB7A939F5F818749D4E0A0D4EEA7C6E89EC6E69DD5F3ABCCEAA2D3EEA7D2ECA5879E58
899D5881924E9AA966D3DF9DD3DE9CE1ECAAD6DF9ED5E09CCDE19ADEF6ACD3EBA1CFE79D
CDE79ED3EDA4BAD48BD3EDA4DAF5AEBCD790C8E39CDAF5AEC9E7A1C7E59FD3F1ABCDE49E
DBE8A3CCD691E7F4AEADBE7793AA62C5E197C1E198D1F3A9C9EDA3CCEEA4CAE9A3C4DF9A
D6EBA8CFDF9EE4F3B2D2DEA0DCE7ABCCD79FFFFFD6FEFFDAFFFFE4F8F1DEFFF9F0FFFAF7
FFF8FAFFF9FBFFF9FBFFEDECB4A19A645246FFF7E7FFF9DD6F6D3D898E56D5DEA9E1EBB6
CADA9CD0E19BD1E196E6F4A9D2DA9FD5D7AFECEED9F5F7ECFBFFF6F7FFEFDFF9CCBEDDA2
D1F2ADB5D98FC9EBA1D5F9AFAFD187D6F8AECBEDA3C3E59B
CDE89BCCE89BCAE99BC9EA99C6EC99C6EC99C8EB9BCCE89DCADB97E2EAAECECE9AAFAE80
8B8C62F5F5D1FFFFE1EFFFE9CAFDF8356A70A5BDC7F9FFFFEDEBF0FFFDFDFBF3F0FFFFF6
F9FFF8F2FFFBEAFFFCE5FFFEE0F9FDEBFFFF7C9EA8C4E1E7606B670101000F0A047F7774
FFFCFAFFFCFBFFFCFDF7F1F1FFFFFDFBFBF9FFFFFBFAF9F4FFFEF8FFFCF8FFFAF6604846
B59C98FFF8F4FFFAF6FFF7F2FFFFFAF3F8F2FAFEFDFCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFEF6FFFFFBFFFFFDFDFAF8ECADAC97FFFFE3F8FFD7F8FFD5
E6F6C5CADFA7D2EAB0C6E0A1C9E8A4C8EA9EC8EB9BC5EA9ACBF0A3C6E6A5C9E1AF021000
0004000102008C8D7BE3E9CFCCD9AEDAEFB6D3EEA7C7E899D1F19ECCEC99C9E898CBEC9D
BEE395D2F9AAC5E599CAE69B9DB36BC4D891CFE39CD8EEA6CDE49EC3DD96D9F4ADCEE8A1
D5E8A6C6D5946E77384A5616D4EEA7C4E49BBFDD95C7E59DD7F2ABC0DA93DAEFAACDE19C
DFF0AC7F8E4B4E5D1A56622097A260D9E4A2D9E2A1D3E09BD0E49DD3EBA1C8E096CFE79D
C4DE95D0EAA1CBE59CD2ECA3CDE8A1CBE69FCDE8A1CFEAA3C7E59FC1DF99CEECA6CDE49E
E1EEA9CCD792CEDB95DDEEA7B0C87ED4F3A7C8EA9EC3E89BC2E79AC9EB9FD0F0A7CDE8A1
C5DC98CEE19FD9E8A7D1DFA1CADC9ED2E4AAD2E0ADCCD7ADFFFFE6FFFFEDFFFFF4F7EFEC
FFFBFDFFFAFFFFF9FFFFF9FCDECECE8C7D785F4E47554A385A5B33D3DBA8D8E2B0CEDDA6
CDDD9FCBDC95DEEC9FD8E299DBDEA5A7A37EDBD3C6FFFDFBFFFFFAFEFFF3E8F4D0CBE2AC
C3E6A2C5EFA3BDE69AC8F2A6C1EA9ED1FAAEC2EB9FBDE69A
C9EA9BC9EA9BCCE999CAE999C6EC99C5EC99C6EB9BCCE89DE0ECAAC5C98EEBEBB58C8E5D
9BA374DBE2B8E9EEC6EDFFE88CC5BF558E97E7F4FFFBF7FFFFFDFFF2F3EDFFFFF6FEFFF6
F5FDF2EEF9F1F7FFFFF8FFFFFCFEFFE3F1FC6491963B6C69DFF4ED3D423B0001003F3B38
CFCAC7F4EBECFFFDFDFFFEFDFFFFFDF6F8F5FFFFFBFFFFFAFFFEFAFBF0ECFFFAF8998481
6B524EFBE3DFFFF2EEFFF6F1FFFFFAFCFFFBFCFFFFF9FDFCFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFFFCFFFCF4FFFFFAFEDEDBD2A2A48FFAFFDFFEFFDFFBFFDA
E8F8C9D5E9B4D2E9B1B6D295C4E3A0C5E79DC0E597C3E89ABAE093DBFBB8D1E9B5000800
383B280A080079776AEFF1DCDFE9C6A4B581CDE6A498B469CCE89BC6E393D4F0A3C3E296
C4E99BC1E899CCECA0CBE79C90A65EDCF0A9C6DA93CEE49CD2E9A3C6E19ACFEAA3C9E39C
D6EBA8D5E4A3A5AF7097A162304400ADC47EE2F7B2E2F7B2B7CB86DEF2ADCADB97D4E5A1
CBDA97D7E6A3DEEFABDBECA8BFD08C9BAC6890A15D8CA0598DA35B8DA55B859D53CCE49A
DEF8AFD0EAA1C9E39AC5DF96CCE69FCEE9A2CAE49DC3DE97DDF8B3D3EEA9D2EDA8D2E9A3
C1D08BE5F2ACE9F9B2CBDF97D2ECA23B5A0EBFDF94C6E89CC5E79BCAECA0CFEDA5C9E49D
CBE29EDBEEACE1F1B0D3E3A2DEF2B3CEE3A8CFE1ADD4E4B7F7FFE0F7FCE5FFFFF3FFFFF8
F9F4F1FEF5F8FFF4FAFFFBFFFFFBFFE3D7D9C4B6B6B6AEA3B8BB9CE6EFC4DEEBBFC8D9A5
DBEEAEDEEFA8BECC7DB6BE759D9C646E6544F3E4DDECDDE0BBB1B2CECABF9FA283CFE0AC
C9E8A5C9EFA4C6ECA1C8EEA3BDE398C1E79CC3E99ECBF1A6
C6EB9BC8EB9BCDE89BCCE89BC8EB9BC5EC9BC5EC9DCCE89DDCE7A5E6E6AAE5E6AD585D27
C2D09BDFEFBECAD3A6E3FCDE6EADA5001119E5F1FFFFFBFFFEFFFFFBFFFAFBFFF6F1F9EC
FBFFF9FEFFFDFFFEFFFAF2FDFFF2FFFCFEFFD0FFFF458177A6C4BCA7B2AC323834181A17
595856FFFEFFFFFBFCF6F4F5FEFFFDF7FCF8FEFFFBFFFFFBFFFEFBFAF0EEFFFBFAB7A3A2
694F4EFFF8F4FFFAF6FFFDF8FFFEF9FCFFFBFCFFFFF3F7F6FEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFFFCFFFCF4FFFFFDFFDEDBD2B0B29DF9FFDFF9FFDCF9FFDA
F8FFDAF7FFD6E6FDC5B3CF94CEECACCEEFA8C5EA9DCBF0A2C1E899CCEDA8CEE5B1000700
7071610F0B0279756CFFFFF1959A7CD5E0B5D3E7AC69803CDEF8AFCBE59BBFD990D3EFA5
C6EB9DBEE395D2F1A5CDE79DABC179D2E69FD8EEA6CFE69ED1EBA4CCE7A0C6E19AC7E29B
D6EDA9DAEAA9D3DF9FD9E2A39EA464515616232900D4DA9AE0E6A6CDD695CFDA98E5F1AF
DCEBA8E3F7B2C4D994C8E29BCCEAA2C1E198D2F4AACEF0A4C8E49AD6F0A6D6F0A69AB46A
809A51CAE49BCCE69DCBE59CCEE8A1C6E099D7EEA8D1EBA4C5DE9ABAD38FC8E19DCCE39D
E4F8B0C8DA90C0D58AC8E094D3EDA3D7F3A887A65AD6F6AAD0F0A5CAE89ECDE8A1D2ECA5
CBE29CBFD48FC2D691CFE2A0CDE3A2BCD496C8E0A6CCE0AFD7E7C0D3DEC0EEF6E1FBFFF1
FFFFFAFFFFFDFDF9FAFBF5F9FFFCFFFFFCFFFEF5FAFBF6F2FFFFECF4FEDBF2FFDACCDCAB
DBEDAFCFE1979BA858ABB368DFDCA7D3C8AAE4D1CDFFF8FFFFF9FFEFE4DEFDF9DCD1D9A8
DEF4B4CAE59EC6E19AC9E49DD7F2ABD0EBA4CDE8A1C9E49D
C5EC9DC8EB9BCFE79BCFE79BC8EB9BC5EC9BC5EC9DCCE89DD6DD9ACCCA8F9392596A7239
D4E9AEDFF7BDC9D7A2D6F1CE76B7AF6FAEB7F1FFFFFFFDFFF4FAF8EEF8EDF3FFF1F9FFF8
FEFFFBFDF9FAFEF2FCFDEBFBFFF5FFFFFDFFCAF9F10A473863847DB0C0BD4D5957000202
252628FFFFFFFFFFFFFEFFFFFCFFFFFBFFFDFBFFFDF6FBF5FFFEFAFFFEFBFFFBFBAB9999
5C4442FFEEEAFFF8F4FFF9F4F7F6F1FAFFF9FCFFFFFCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFEFBFFFFFCFFFFFEFDD6D6CAA3A790F1F8D6E6F1C7E2F2C1
EAFCCAF0FFD1DBF2BA99B578C7E6A3C9EAA3C0E296C6EB9BCAEF9FB4D58ECCE3AD000700
4F4D3E060000887E7CDCD5CBC5C4AFF1F9D4CCDAA7CEE2A349601C8DA45EE4F9B6C8E29B
C5E79BCBEDA0CEEDA1C6E096D7EDA58DA15AD4EAA2CCE39BCCE69FCFEDA5C4E29ACAE8A0
D5ECA8CEE19FD6E5A4E2EBACDBDB9DAEAC6F757336575719A4A466E1E3A4D1D797D9E4A2
D3DF9DDAEEA9C8DF99CBE9A1D6F8AEC7EDA2BCE69AB2D88BCDEBA1C2DC92C8E298D5EFA5
7F99508DA75EDCF6ADD4EBA3D3EAA4C8DD98D0E5A0DEF3AEA3B875788D4A7F9451CCE19C
C0D88EDBF3A7D1EC9FD7F2A5BFDB90D4F0A586A257C1DD92CCE89EC9E39AC6E099CFE6A0
DAEFAAD8EDA8D6EBA6DDF2ADCEE8A1CDE6A2E0F8BAD0E5ADCBDCAFD4E4BFF9FFEAFBFFF1
F2F8ECFAFDF6FFFFFDFFFEFFFFFDFFFFFDFFFEF8FCFFFEFBFFFFF1F5FEE3F9FFE4D7E7BA
CBDD9F9BAD6391A04FCBD388DCD9A4A09579FAE6E5FFF0FBFFF2FAFFFDF6DDDCBEE5EDBC
829254718641879B56A1B570CEE29DCBDF9AD1E5A0CCE09B
C3EC9EC8EA9DD0E69DD0E69DC9E99DC5EC9DC3EC9DCAE99DE4E9A75753165D5D21B9C587
CAE4A3C1DF9FD5E9AED8F7CE003F3776B9C1E2FFFFF7FFFFF9FFFFFBFFFAF5FFF4FAFFF9
FCFCFCFFF8FFFFF8FFFFF6FFFFF0FFEDEAF1E9FFFFDEFFFF65867F6D8381768987000404
050A0D9EA2A3FAFEFFF5FBF9F9FFFFF9FFFFF9FFFFF5FBF7FFFFFDFFFEFDFFFCFDBBABAB
674F4DE9D1CDFFEFEBFFFDF8FFFFFAFCFFFBFBFFFEFBFFFEFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFBF8FFFFFEFFF7F6F1AEB19E74795BD6E1B9D2DFB1D5E6B0
C8DBA4D7EFB5C8E0A484A161C4E39FCAEA9FC5E697CBEE9CD2F8A5CDEDA4E3F7C2000900
2420140A0000877B7BACA19DDAD7C6F4F7DAFEFFDCE5F4BDC3D599687C3DC8DA9ED1E7A6
C5E59AD0F0A4CAE69BC4DC92DFF3AC5F732C9BB169C8DF97C8E39CD0EEA6C7E79ECCECA3
D2EBA7C9DE9BCDDD9CD5DFA0DEE0A1D7D799D6D698CACA8C9A9A5C4C4E0FA1A6669FA867
D6E19FCFE09CD4E9A4C6E19AC5E59CCCF0A6C6EFA3DAFFB3C8E69CD0ECA1CCE69CC5DF95
DDF4ACA9C07840570FACC27AD1E6A1D7EBA6BED28DD2E6A197A7667F8F4E667635D3E8A3
C5E196D6F7A8BEDD8FC1E092D1EDA0C1DC8FB9D18794AC628BA15897AD648FA55D8FA55D
B7CC87D7EEA8D0E7A1BED58D8EA65C7D954B879E58859B5B9DB079BACB9EE3F1CDDFE9CE
FBFFF0FCFFF4FEFFFAFDFEF9FFFFFDFFFEFFF7F3F4FFFEFBFBFDF0F9FEEAFBFFEADCEBC2
C9DB9F788A40A8B766E2EDA1D5D59FCCC5A8F1E3E2FFFAFFFFFBFFFAF7EEEDF2D2D9E5B3
DCEAADD4E3A0E0EFACD3E29FCAD9969DAC6997A66395A461
C2ED9EC8EA9ED1E59ED3E49DC9E99DC5EC9DC3EC9DCAE99DDFE4A2443E009D9D5FD8E7A6
C9E8A4BFE29ECDE3A3E1FFD723645C6BB0B7DFFFFFEBFFFFF0F9F6FEFFFAFCFFFAFBFFFA
FFFFFFFFF9FFFFEFFFFFF4FFFFFAFFFFFFFFE8FCF1EBFFFBB5D4CF425F5D7186870F1F1F
00070981898BF9FFFFF9FFFFF8FFFFF7FFFFF5FFFCF9FFFFFCFFFFF9F8F6FFFBFDF4E6E6
A8908EE5CDC9FFFAF6FFFDF8FFFFFAFAFFF9F6FAF9FCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFEFFFFFAFAFAFFFFFBF8FAEDA2A79079815CD3DFB1D2E0ABD0E4A9
CBDFA2D8EEB0CEE7A68AA562CEECA4CEEEA2CCEE9ACEF09CBEE18DC0E097C0D29E000600
1F1B0F08000055444AB2A4A4FFFEF3FFFFEAFFFFDFDFEBB9CFDEA7B8C78EAAB982D4E8AB
CAE8A0C8E79BD0EAA0D2E89FD4E59F91A25C7E924BD8EFA7CAE59ECDEDA4CAECA2C7E79E
D3EEA9D7F0ACD1E4A2D4E4A3D4DF9DD3DC9BE0E9A8D3D999CED4948D9353565C1C666C2C
E6EFAECAD694DFEEABD7EBA6C9E09ACCE7A0BAD890C3E197C1DD93DEFAAFC8E298C9E399
CFE69EC3DA9294AA62849A52CBDF9AD8E9A5D8E9A5D1E09D849352D6E2A2CDD999C9DD98
CCECA0B4DB8AD3F6A6D0F1A2C1DD90E1F9ADC3D990D3E79F8D9E578FA0598B9C5693A760
9EB36E8CA35D87A15AA6C07689A251A1B866D3EA9CCFE59DAEC2838D9E68BFCFA2F5FFDD
F8FFE6F7FEECFEFFF4F0F1E9FAF9F4FFFFFBFCF8F7FFFEFBFFFFF8FFFFF3F2FAE2D7E3BD
D7E9AF7F9147C6D886DBE79BEBF0B8DBD7BAEFE7E5FFFCFFFFFEFFFCFFF6E4F2CEC9DCA5
CEDE9FCADB97D2E39FD3E4A0D6E7A3C9DA96CDDE9AD2E39F
C2ECA0C8EAA0D3E4A0D4E39ECAE89EC5EB9EC3EC9ECAE89EBABC7B8C8648E1E1A3D1E09F
C9EDA5CDF5AEC5E09DDBFCCF02413898E1E7CEFFFFE0FFFFFBFFFFFCF7F4FFFFFBF3F3F1
F2F1F6FFFBFFFFF7FFFFEDFDFFFEFFFBFFFDFEFFF6F8FFF8EDFFFF4565642F494A142829
0004054E5859838D8EDEE8E7EEFAF8F3FFFFF3FFFDF8FFFFFBFFFFF8F8F8FFFDFFFFFBFD
B6A1A0BFA7A3FFF6F2F9F0EBFCFBF6F9FEF8FCFFFFFCFFFFFEFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFFFFFEFFFFFCFFFDFDFFFAFAFDF2FEFFEFAEB596AFB88DDBE8B3DBEAB1CBDFA0
D0E5A4D1E7A6CCE5A188A35CC8E79BC4E393C7E792C2E48DD2F5A1CEECA2C9DAA6121700
4B443A0A0000725E67FFF2F8FFFCF6FBF9E4FFFFE1DFE8BBCEDAA8D6E3AD9EAB766F8147
CFEAA3C5E196D5EDA3D9EFA6D0E19BD1E29CA2B66FC8DF97C9E79FC7E79ECFF1A7C1E399
D6F4AEEFFFC5DAEFACD6EDA9CEE8A1DEF9B2C9E39CCDE29DD1E29ED5E4A1CED997737C3B
3137004349099BA161E0E6A6DBE4A3D8E1A0DFEAA8D8E7A2D1E8A0C2DE93DAF4AAD0EAA0
CBE29AD0E79F80964E8EA45CCDE19CCEDF9BE9F8B5DBE7A595A161BDC788BAC485C3D792
CFF4A4BFEB96CAF1A0C2E595D6F2A5BED68AD6EAA2D1E19AD9E6A0D5E29CD0DF9ADAEBA5
C9DF978FA9608CA85ECDE89BD7EF99CAE189CEE491CEE396D1E5A0A3B277909E6B909B71
B9C3A1DAE0C6FDFFEDDFE1D3EBEBE1FFFFF8FFFDF9FEF9F6FFFEFBFFFFF6F8FDE9D0DAB7
DFEEB5899E53D6E997D1E294C7D099BFC2A3ECEBE7F6F6FEF1F9FBF5FFF6E4FFD6ECFFCF
E4FDBBDAF1ABC9E09ACEE59FD0EAA3D9F3ACCFEAA3C8E39C
C2ED9EC6EB9ED0E69ED1E5A0CCE7A0C8EAA0C8EAA0CDE79E989D5B9E9D5DD1D694E0F1AD
BBDC95C5EAA4D7F2AFCCEDBE7AAFA546878B88CAC6DDFFFFEDF9F9FFFDFFF3F2F0FFFFFF
FFFEFFFFFCFFFFF2FFFCEFF9F8FFFFEAF7F0FFFFFAFCFBF7ECFFFFEBFFFFF0FFFF545E60
03060B010508000305697979DDF1F0F0FFFFF0FFFFF1FFFFFAFFFFFFFFFFFFFEFDFFF8F6
B9A4A1AE9692FFFAF6FFFAF5FEFFFAFBFFFDFBFDFCFAFBFDFCFFFFFFFFFFFFFCFFFFFCFF
FFFFFFFCFFFFFBFFFFFBFFFFFBFFFBEAEDE2FFFFF1ADAB92CCD7ADCFE2ABD9EDB0C8DB9B
D4E4A3CDE19CCBE59C8AA85ECEEA9FCBE79AD5F2A2D0ED9BC6E798CEECA6D4E6B6000600
2A261D070000938489FFF8F8FFFDF6FFFDEAFBFEE1F5FDD8CFDBADDEECB7CCDBA28C9F5F
D2E9A1C9E399CFE59CCFE39CCFE09CDBECA8CDE19C92A963CBE59EC3E19BD5F3ADC2DF9D
DEF6B8F7FFD3DDEEB8D4E7AFCAE4A5C6E3A1CFEAA5CCE69FE0F8AEC7DD94D3E49DD6E69F
DCE9A48F9A585861225B6123484D0D686D2DCCCE8DDEE5A2DDECA7CBE199CAE098D3E9A1
D3EAA2CCE39B8BA15992A860D5E9A2D0E19BCAD994D5E4A1CEDD9A2F3F00000C00D3EAA4
BADC8FD5FCABC3E696C8E99AD5F1A4C5E093D8EEA5D3E79FCADE96DEF2AAD1E59EC4DA92
D5ECA4D1EBA2C4E096D2EDA0C7E08CD4EC94D8F09CC7DE8ED8EEA5C8DD9ACBDDA1D6E4AF
D0DDB1F1FBD8FAFFE4A5A8939B9C8EE4E1D8F7F4EFFFFEFBFBF6F3FFFFF8FFFFF1D2D5B6
D6E2B0889B59D8EAA0D6E5A0E3E7B4E4E1C2ECE8DFFDFDFDF9FFFFF5FFF8F4FFEAECFFD5
D5EAAFD9EFAECCE0A1D0E6A8C3D89DD5EAAFCBE3A9CDE4AC
C0EC97D4FBA8CBEB9FBEDA90D2EBA7D9F0ACC2D794D5E6A296A05BC2CC87CDD893CBDF98
C9E49FD1F0ADC2DEA1E2FFD39DBEB38BB9B970AFA7CEFFFFF0FFFFFCFFFFF9FDFFFCFCFC
FFFFFDFFFDFBFFFBFBFFFEFBF2FFFFF1FFFFFFFDFFFFFDFFF0FFFDE8F9F3FFFEFFCFC3C7
2F1E26060004323B404F676B55787C82A8ABEBFFFFF4FFFFF7FBFEFDF7F7FFFEF6FEF1E9
C2ADA89C837FFFEEECFFFCF8F8FFFAF5FFFDFCF8F9FFFDFFF9FFFFF6FAFDFFF8FFFFF9FF
FEFFFFF7FFFFF8FFFFF7FFFFF6FFFFFCFEFDFFF7FAB4A095D8E6C3BDD9A8D3ECB2CCDF9F
D7DC9ADFE6A2CCE69C81A356D1EDA3CFE6A0D1E6A3D1E8A4C7E59FCEECB0F4FFE3000900
0C110A060604605D58EFEDE1FFFEF1FFFFEFFEFFEFE3ECD1CFDEB7CEE0ACD2E9A3D2EA9C
6A7F34DCF0A8D1E59ECADE99CEDE9DD2E5A5DCEFAD637634CCE19ECEE3A2D3E5A9D3E1AC
F4FFD4FAFFDFF0F4D9888D6F8D956EA1AB79D2E0A5CCDD97E4FBABCBE490D7F39EC8E593
CFE99FD0EAA3C6DB9AD4E7A7CEDD9C98A4625E6821959C58808648767E42E3EFAFD2E39F
CADE99D7EDA5C2DA9096AC61CADF94D3E89DDCF0A8D6ECA3CCE69DC9E79FC6E7A0C7E79E
CFE79DD1E59DD0E69DCFE79DCCE89DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DCAE99D
CCE89DCDE79DCFE79DCDE79DCCE89BCCE999CCE999CCE999CCE89BCCE89DCDE7A0CDE6A4
D7ECB1CBDDABCFDEB7EEF7DAF9FEEAD9DBD0C3C2BDCFCECAFDFAF5FCF8EFFFFDF1D8D2BA
C4CAA4ABB988D7E8B1DBE4AFEEE5BCC9B89AEDDCCAFFF8EFFEFEF6FAFCF7FFFEFBF5F3E4
F6FDD4E4EEBADDE5B6DEE7BCE4ECC7EAF1D0EEF4DAEBF0D9
BFEA91BAE28CD6F9A9D4F2A8C3DA96CEE1A1EDFCBBD3DF9D85904BD3E098DCECA3D4E8A0
CEE5A1CFE9A8C3DFA4DBF7CEF0FFFBB5D9D773AFA7D8FFFFDCF8FCE9F3FCFBFFFFFEFFFF
FFFEFBFFFEF8FFFCF6FFFFF8F0FFFDF0FFFFFFFDFFFFFBFFF8FFFFF8FFFBFFFBF9FFF7F9
17000610010801060CE6FEFF1E434950797FC9EAF1EAFEFFF4FCFFFFFEFCFFFEF6FFF6ED
FFF9F4644A49FFF7F6FFF9F5F2FFF5F5FFFBFFFCFFF6EBF1F9FFFFF7FCFFFFF8FFFFF8FF
F8FCFFF2FFFEF7FFFFF4FFFCF4FFFFFDFFFCFFF6F6BEA39ADFEFCBC2E5AFD3F1B3D1E4A2
DEDF9DE3E69FCBE89880A754CDECA0CEE59DD1E6A3D2E8A7D2EFADC5E0A9E7FDD9000700
09130B000200626459F7F9EBFFFFF0FFFFF1FEFFF4EDF6E3DAE9C8D1E5B2CDE79DCBE793
CCE194475710CDDE98D2E2A1D4E7A7D8EBABBED1919EB171000F00E0F0B2CEDBA3CED7A8
EDF1CEFFFFEAA19F92B2B0A1EEEFD0CAD0A4D7E0A7E3F2ADB9D07EB9D57ED2F39ACFF19B
C4E498C5E49ECFE9AAD3EBADD5EAA9D5E6A2C5D58CDEE8A1DCDBA25A5921D5DAA0D7E3A3
D4E8A3E2FAB0D3EBA18CA458DBF2A4CAE193C0D68BD6EEA4C9E79DC0E296D2FBAFC4E89E
D1E59ED4E49DD3E49DCFE79DCCE89DC9E99DC6EB9DC5EC9DC3EC9DC3EC9DC5EC9DC8EA9D
C9E99DCCE89DCDE79DCDE79DCAE89EC9E99DC9E99DC9EA9BC9EA99C9EA99CAE99DCAE89E
CBE6A3D0E5ACCEDFB2E1ECCAFCFFEDFEFFF4E1E0DBB6B5B1FFFFFAFFFFF6FEF0E5E5D8C7
D5D8BBD2DEB8C9D8ADD7DEB4DACAA8AE9479FAE1CDFFFCECF6F2E7FFFFFAFBECF3FFFBFA
FFFFEAFDFFE0F8FBDECDCFB7FFFFEDF9FAECFFFFF8FFFFFA
D9FFA8BADD89C1E195CBE69FD4E9A6CEDE9FCAD9985A6624626F29D3E39ADAECA0D1E79C
CAE49DC8E5A3C9E7A9DBF8CCF0FFFAC7E9E85E9790D8FFFFEAFFFFF4FFFFF9FFFFF6F7F9
FFFEFBFFFEF8FFFDF6FFFFF8F0FFFDF0FFFFFFFDFFFFFBFFFCFFFFF4FAF6FDF9F6FFFCFB
D1C1C2130709010004ADB8BCA3BCC13F6065B3D6DAE0FFFFF1FFFFF3FCFBF2EFEAFFFCF6
FFFAF6BFA7A599817FFFFBF8DDE7DCF8FFFAFFF6F7FFFBFFFBFFFFF9FDFFFFF8FFFFF8FF
F9FAFEF4FFFEF8FFFDF4FFF7F4FFF4FAFFEDFFF3E3B7A38ADEEFC2C2E6A8CCEBA7CDE39A
DDE399DFE79AC7E99285B056C9ED96CBE896CDE897D1EBA1CEE9A4C2D9A3F7FFE6071402
363D36090B0863645CE8E9DBFFFFF3FFFFF3FEFFF6FBFFF3EEFBDFDCEFC1CEE8A1CBE695
CCE196A8B97271823CD4E4A3D7EAAABFD292E4F9B8C0D592445715819152CFDCA4D4DDAE
DFE3C0A7A991D8D6C9F8F9E7F0F6D28A9460768447C2D68FE3FAAAD7F39FC9E692C1E092
D2F0A8C5DF9ED4EEB1CBE3A7C5D99AD4E8A3DAECA2D7E29DD6D59C726F384A4F15DCE8A8
C7DB96CCE49AC4DE948BA659C6DE92D5EDA1D3EBA1C6E096CCE89ECFEFA4C4EA9FC7E99F
CDE79ED0E69DCFE79DCCE89DC9E99DC8EA9DC6EB9DC5EC9DC3EC9DC3EC9DC5EC9DC6EB9D
C8EA9DC8EA9DC9E99DC9E99DC9E99EC9E99DC9E99DC9EA9BC9EA99C9EA99C9E99DCAE89E
BBD693EDFFC9F8FFDAF7FFDFF7FFE7FEFFF3FFFFF8FBFAF58E8F87FEFAF1FFF9F0FBEFE1
CBCDB5FBFFE6F7FFE1FFFFE1FFFDE1E1C7B0E5CEBCD4C4B4908D7EE0E0D6E2D7D5F9EEEC
DEDBD2FFFFF6EFF1E6E5E6DEFAFBF5FFFFFBEAEAE8FBFBF9
C2E490C7E696DCF8ADD2E9A3D7EAAAD7E7A8DBE9AB3C480663702AD4E49BCCDE92CCE297
CDE79EC5E29FCEECACDEFBCDF1FFFADFFDFD275E5897CEC9E2FFFFF4FFFFF3FAFFFEFFFF
FFFEFDFFFDFAFFFDF8FFFFF8F1FFFDF1FFFFFFFDFFFFFAFFFFFDFFFEFFFFF9F9F7FFFFFA
FFFDFA201614070000767479EEF9FD748D91799FA0DEFFFFE4FFFFF1FFFFFEFFFFFFF8F7
FFF8F5FFF9F54D3835A59892FCFFF6FCFFF8FFFBFBFFFAFCFBFFFFF9FDFFFFF9FFFFF9FF
FBFCFEF8FFFDF9FFFBF8FFF4F4FFECF9FFE4FBECCFAA9D7AD5E9B4BFE2A2C2E19BCAE098
D8E299D7E495C5E9918FBA5EC7EE95C8EB91C9EA93CFEC9AD8EFABCDDFABF9FFE8010900
393B3809090777776FF7F7EBFFFFF4FBFDF2FDFFF9FBFFF6F9FFEDE5F7CDD2EBAAD0EB9E
CCE196D6E89EC4D58F677B36B3C684DEF1AFC7DC99DBF0ABCEE29DB1C180647237A6B07E
949A74FCFFE4EDEBDCEEF0DBD5E0B5D1E3A7B1C683798F46BFD789D2EA9CDCF6ACD0EAA3
D9F2B1C6DEA4D7ECB4D2E7AFD1E5A8D3E8A5D0E49CD2DF99E4E2A968632C2F3300C9D394
DBEFAAD0EAA1C5E1969AB669CFEA9DC7E295E3FBB1C4DE94C4E096DBF9AFBADC92C8EA9E
CAE89ECCE89DCAE99DCAE99DC9E99DC8EA9DC6EB9DC6EB9DC5EC9DC5EC9DC5EC9DC5EC9D
C5EC9DC6EB9DC6EB9DC6EB9DC8EA9EC9E99DC9E99DC9EA9BC9EA99C9EA99C9EA9BCAE89E
CCE7A4DCF4B8E5F7C5EBFAD3F8FFE6FEFFEFFFFFF4FFFFF8FFFFF8E5E2D9CABDB5EEE1D8
9FA08EF5FDE5FBFFE8FBFEE1FFF5DFBBA08FAA9383F5E5D5C3C2B0B6B9A8ACA499B0A7A0
AAA6A5D2D2D4E1E2E4C5C6C8FEFFFFFEFFFFFEFFFFFCFFFF
D7F2A3C9E497CAE199C5D896D6E6A8C9D79AD3DFA1535F1F99A863E4F6ACC6DB8ED0E89C
D3EFA5C4E29CCBEAA7DCF8C8F0FFF6EDFFFF52858093C8C2C8EAECF1FFFFF7FFFFFAFEFF
FFFEFDFFFDFAFFFEF8FFFFFAF2FFFBF4FFFFFFFDFFFFFAFFFFFCFFFBF9FCFEFFFDFCFFF8
EFECE34037300D0000958787F3F3F5C9DBDB406867C7FAF5E0FFFFE6FFFFF7FFFFFFFBFF
FFFBFBFFEDEBB7A4A073645DF2F2E6F2F2E6FFFBF8FFFAFBFEFEFEFCFDFFFFFAFFFFFAFF
FCFEFDF9FFFBFCFFF6F3FCE7EEFFDDFBFFDFF3E9C6A19972CEE2ADC5E4A8C6E3A3D4EAA9
D6E19FD0E099C5E8969BC56FC8EE97C9ED95C5E98FCBEB98CDE29FD3E1AEFBFFE7000300
28272505010283807BFFFDF4FFFFF6FBFBF3FBFBF9FCFFFBF9FFF3E4F5D1D0E8AECDE7A0
CFE59CD1E69BD4E8A17185408DA15CC7DC97D6EBA6CEE49CD4E8A1D3E4A093A164818B57
C6CCA6FFFFE8F5F3E4D4D8BFCEE0ACDAF5B0BAD48B6781379DB56BB6CD85D1E6A5C7DB9E
C6D7A1CBDBAACEE0B0C7D9A5D4E8ADDCF2B1CAE298D3E39CDEDCA3756E38272800EEF8B9
BACE89C8E49AD7F6AA7F9F53D4F3A7BCD88DC9E399D2EAA0C6E097CDE79ECEECA4CBEBA0
C8EA9EC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99DC8EA9DC8EA9DC6EB9DC5EC9D
C5EC9DC3EC9DC3EC9DC3EC9DC8EA9EC9E99DC9E99DC9EA9BC9EA99C9EA99C9EA9BCAE99D
D3EEA9C9E1A3CADCA8E4F3CAFCFFE6FEFFECF3F6E5F6F8EBEEF0E5FFFFF89D908A7E716B
AFAFA3FCFFF3F2FBE8FFFFEEFFFAEDBEA096C3AC9EFFFDEAFFFFEAF2F8DEF8F6DDF5EFDF
F8F7F5F5F6FBF2F3F8C6C7CCE0E4E7EBEFF0FCFFFFEEF4F4
C9DE93DCF0A8D2E39FDBEBACD5E3A8414C12414C10AEBC7EC5D491E4F5AEC4DA8FD3EB9F
D2EEA4C7E79ECAE9A5DCF8C7F5FFF8EEFFFF8AB7B27AADA8567C7DCBE4E8F5FFFFF2F5FA
FFFEFFFFFDFBFFFDFAFFFFFAF5FFFBF5FFFFFFFDFFFFFBFFFFFBFFF0EEF3FCFFFDFCFFF8
FFFFF42B21171801008C7774FFFDFBF3FFFD7CA39E2E615CBAECE9DDFFFFF0FFFFFBFFFF
FFFCFDFFFBF9FFEEEAA5968FB1AB9FFFF8EDFFF6F2FFFAFAFFFEFFFDFDFFFFFBFFFFFDFF
FAFCF9FBFFF8F8FCEDE2EAD2DBEBC4F9FFDAEEE9C399956FCBDBAED1E9B7D4EBB7E6F8C4
DBE5B0D1E0A5C8E7A3A8CE83C8ED9FC9EC9AC4E891CDEA9ACEDE9FE4ECBDFFFFEA010100
252120040000817C79FBF6F0FFFFF8FDFCF7FBFBFBFCFFFFF7FFF4E0F0D3CCE2B1C7E09F
D0E69DCFE499C9DD95B3C98194A964C8DE96D8EEA6CFE59CCADE96CEE29BD3E1A3E3EDB9
E1E7C1F9FCE1EFECDDF9FFE5D9F1B5BFDF94CEEDA1D2EEA493AA646E824384955EA3B180
7B865B9EAB809EAB8095A576A5BA81DCF5B3CFE9A0D8E9A3DED99F685F28D9D89FD1DB9C
DFF4AFD7F2ABCBEBA0C1E396749448E3FFB4C8E298CAE298E0F7AFC4DB93D2ECA5CEECA2
C6EB9DC5EC9DC6EB9DC8EA9DC9E99DCAE99DCCE89DCCE89DCCE89DCAE99DC9E99DC8EA9D
C5EC9DC3EC9DC2ED9DC3EC9DC8EA9EC9E99EC9E99DC9EA9BC9EA9BC9EA99C9EA9BC9E99D
C7E59FD3EDAEDAEFB7DFF0C3E6F2CEE4EDD0EAEFD9FBFFEEFEFFF4F8F8EEFDEFECFFFBF8
FBFBF3F9FFF5F9FFF5F9F6EDF0D8D4B89994FFECE0FEF1DEFBFFE0FBFFE1F2F6D1DCDCC2
F2F1EDFFFEFFF9F8FDEAEBEDC4C6C3DBE0D9F2F8ECFBFFF4
D6E39DD9E6A1C5D191D8E3A7D8E3AB525C2747521AE1EFB4CFDF9ED4E8A3C6DE94D0EAA0
C6E298CBEAA4CDECA9DEF8C8F2FFF1F2FFFFE3FFFF99CAC6456F6ED0EFF2F2FFFFF4F9FD
FFFEFFFFFDFBFFFEFAFEFFFAF7FFFBF7FFFFFFFEFFFFFCFFF8F5FEFFFEFFF4F6F3FFFFF8
FDF7E90B000015000099827AFFFBF6F3FCF9DEFEF90027243E706FD1FFFFE7FFFFECFFFF
FBFFFFFFFEFBF7EAE4B9ABA2A6988DF3E2D8FFF9F4FFF0EEFFFEFDFDFDFFFFFDFFFEFEFF
FAFFF9FCFFF6F5F8E5DADEC3CDD8B0FEFFDCF3F0CD9D9A79CFD9B6E0F0CCE3F1CEF7FFE0
EAF2CDDAE7BCD0E8B6B3D297C9E8A5C9EAA3C4E69ACFEBA1D3DEA2E3E6B9F1F1D9040000
191315060000877F7DFFFEFAFFFFFAFFFEFCFDFCFFFCFFFFF8FFF8E5F3DCD4E6BCCAE2A6
CCE19CD5EBA0DAF0A7BED58DCFE69E93AA62CBE399CFE59ACFE499DEF2ABCDDB9DCDD7A2
EAF1C8FFFFE8EFECDDF7FDE1E9FFC6C0E595C6E69AD1ECA5BCD292CFE0AAE1EDBFC7CFA8
F8FFDDFEFFE3F2FDD5E2F2C5B7CC94EDFFC5D2F0A8CCE0999A955B9A8F59E4E3AAD7E1A2
D0E5A0C3E199BADC90D9FBAF4B6B20C2E096CCE49AC8DE95E0F6ADCEE49BCCE29ACEEAA0
C6EB9DC5EC9DC6EB9DC9E99DCCE89DCFE79DD0E69DD0E69DD0E69DD0E69DCDE79DCAE99D
C8EA9DC5EC9DC2ED9DC3EC9DC8EA9ECAE89EC9E99DC9EA9BC9EA9BC9EA9BC9EA9BC9E99D
CCEAA2CBE5A4C5DAA1C8DAAAD4E3BAD8E3C1D9E2C5E2EAD3F3FCE9FEFFF3FFFCF6FFFCFA
FDFCF8FCFFFDFCFFFDDAD5D2E8CFD2A18280FCE4DAFFFEE8F4FCD7CEDEAFC6D09EDBDFBC
EAEAE2FCFAFFFFFFFDEFEFE7F1F2E0B2B69BCCD4ADDCE8BA
DBE4A1CDD695EFF7BBCCD39D767E4B959F6DD5E1AFD5E4ADD0E2A6D0E5A4D3EAA4D4EEA7
BDD893CEEBA8CDEBABDDF4C6F8FFF5F5FFFFE7FFFF608E8B124340B2DADAE8FDFFF9FFFF
FFFDFFFFFDFBFFFFFAFEFFFAF9FFFBF9FFFFFFFEFFFFFEFFFEFEFFF8F9FEFFFFFDF4F0E7
FFFDF12716061100008F7D71FFFAF3FBFFFDECFFFFDFFFFF1B444683B0B3C3EEF4E7FFFF
EFFEFFFEFFFDFFFEF8F1E3DA5C4A3EBCA69BFFF5EFFFFAF8FFFDFFFAFBFFF9FEFFF9FFFF
F9FFFBFCFFF3F9FBE5DADDBECDD4AAFFFFDAFFFFDBA6A785DADFBFF2F8DCF3F9DFFCFFEA
F6FCE0E2EDCBD7E9BFBCD2A1CAE3A9C9E6A3C5E59CD2EBA7969F66B2B389D4D2BD0B0600
2D24270A01067D7573FFFEFAFFFDFAFFFDFEFFFEFFFCFFFFFBFFFFEFFAE9DFF1CBD6EAB5
D3EAA6C5DD93CEE59DE2F9B1B5CC8471893F8DA559D0E89CD4EA9FBBCF87DBEBAADDE7B2
E6EDC4FFFFE7FFFFF3FEFFEADCF9B7C6ED9CD5F5AAC1DB9ADCF1B9CEDBAFEBF3CEEBF0D0
FFFFE6F3F8D8E9F1CCFBFFDCB1C68EE3FDBCD2F0A8CFE59DA6A4699E955CD9D99DE4EEAF
C7DC97CDEBA3D5F5ACBDDF93A7C77C4D691FA9C078DFF3ABBFD38BD8ECA4D7EDA4CBE59B
C8EA9DC6EB9DC8EA9DCAE99DCFE79DD1E59DD4E49DD4E49DD6E39DD4E49DD1E59DCFE79D
CAE99DC8EA9DC5EC9DC6EB9DC9E99ECAE89EC9E99DC9E99DC9EA9BC9EA9BC9EA9BC9E99D
C9E79FC7E4A1CFE7ABE2F6C1E8F9CCD3E2BBCDD8B6E0EBCDE4F0D8FCFFEFFFFDF4FFF5F1
FFFFFDFEFFFFF1F5F6EFE9EB91767B816162CFB9ACFFFEE4F1FED2C6DBA3DCEBB0D5DDAE
ECEADDFFFDFDFEF9F3FFFEEFFFFFE8E5E9C4BEC695D7E0A9
929455ABAF72787B44525624919769DAE3B8E2EDC2ECFAC9EAFBC5D5E9AECAE0A0CDE6A5
CFE9AACAE4A7CDE9AFDDF2C9FBFFF5F8FFFFE4FFFF7AA7A4265A56C9F7F5E9FFFFF9FFFF
FFFDFFFFFCFDFFFFFBFCFFFAFBFFFBFBFFFFFEFFFFFCFFFFEFF8FFFBFFFFFFFDFDFFFBF6
FFFAEF412A1C130200564A3AFDFBEFFBFFFBF7FFFFE2F5F9EAFFFF335A5F6A9B9FDFFFFF
EBFFFFF1FDFBFFFFFAFFFBF1675144BA9F94FFF9F1FFF8F5FFF9FBFCFFFFF5FFFFE7FAF8
EBF8EFFBFFF1FDFFE6DFE1BCD1D7A7EEF6C3F0F9CAA4AC83838764EFEFD3FFFFE8FAFEE5
F8FEE2F9FFE2ECF8D0B5C594CBDFA4D9F2AEC8E499D4EBA36B733ABFBD965D5845070000
3C33380900057C7774FEF9F5F7F3F0FFFEFFFFFDFFF4F7FFF5FBFBF9FFF6F8FFE6E1F5C2
CFE5A4CAE49BD4EEA5CCE69FD1EBA2C3DD9396B164A2BA6CCCE395E0F4ACC8D897D9E3AE
F2F6D1F7F7DFA09C90E9EFD5DDF9BCC9EEA1CCE9A6CDE5ABDAEBBECCD6B1FFFFE6FCFFE4
FFFFE7FCFFE1DAE2BDDDEABCCFE2AACDE6A5C2E098D0E69EB6B678797339E1E2A6CFD99A
DFF4B1C5E099C1DF97CCEAA2C4DF98DFF6AEC7DB943044006B7F37C4D890D5EBA2CDE79D
CAEA9EC8E89CC9E59AC5DD93B8C9829BA862747E3956601B979E5A96A05BB0BD77E3F4AD
CBE198D2EEA3CBEB9FC2E296CBE99FC7E59BC5E599C8E89CCBEC9DCBEC9DC9EC9CC8EA9D
C9E99EC9E7A1D0EAABE6FEC4F7FFD7E5F5C8CEDDB4CEDCB8D0DFC0FBFFECFFFFF1F6EDE6
FDFCF8FEFFFFFEFFFFEFE9EDB59A9FDFC0BEF3DDCFFFFFE3D9E9B8CBE5A6DEF3AECBD8A0
F0F0D8FFFEF4FFFFF1FFFDE9FFFEE3FFFFE15C5E36A2A57A
59571C5251188E8E5AA0A175CFD4ACF9FFDCF9FFDEEFFED5F1FFD3E2F6C1D6EBB3D0E7AF
CBE2ACC9E0ACD3E9B8E5F5D1FAFBF3F8FDFFEEFFFF7EA8A6124B45D2FFFFEBFFFFECF5FC
FFFCFFFFFCFDFFFFFBFCFFFAFEFFFBFEFFFDFEFFFFFBFFFFF5FFFFF9FFFFFFF6F7FFF7F4
FFF0E82D13060B00004A4532FFFFF4F4F9F2FCFFFFF9FFFFF0FFFF52737A558889C9FFFF
E2FFFFEEFFFFF7FFF9FFFDF35F473BC1A398FFF6EDFFFBF8FFFDFFF2F9FFE4FCFEEBFFFF
F2FFFBF0FCE8FEFFE4D6DCB0E7EEB8D2DDA1C7DBA08B9D699CA178E2DFBCE9E8C9E6E9CA
EDF7D4EEFAD2DFE8BBC2CC97D7EAAACBE399C1DC8BCDE398A5AD74E3E1BBA8A292060000
5F565B0500058A8484FFFFFAFFFEFBFFFEFFF7F5FFFEFEFFFCFFFFF7FFF4F9FFEADEEFC2
C8DE9EC8E29BCCE69FC5E099CDE7A0C9E399A9C47799B465DEF5A7BBCF87E1F1B2D4DEAA
CED2AFBCBBA6BEBAAF828570DBF0B8BFDC99CDE5ABCCDEAECCD8B4D5DEC1FAFEE7FFFFEC
FFFFE8FFFFE4CFD7AED1DFAEC3D79CD3ECAAD7F2ADC9DE99E9EEAE5250137C8043D5E1A1
BBD08DD9F2AED9F3ACD6F0A9CDE29DD3E7A2E1F2AC8C9D577E924AB6CC817D9549B4D083
BEDA8F95B166859D539BAF67A9B97298A35E89934E8E9551949B578D9450A6B06B929F59
CBDC95C9DF96C4DE94D6F2A7CDE99FCBE99FCBEA9ECBEB9FCAEB9CC9EA9BC8EB9BC9EB9E
CEEEA3C9E8A2CAE7A4DEF8B9F0FFCDE2F4C0D0E2B2D2E3B7DAECC6DAE5C5EBE9D4FFFEF1
FFFFF8F4F6F1FEFFFFD7CECFFFF6FAD7B8B5F8E3D2F8F4D1E9FCC5CBE8A5C6E096D0E0A2
EAEAD0FFFEF4FFFEF1FFFFEDFFFEE5FAF6D980805C80805A
E7E2AAD5CF9BE9E7B7E9EAC2DDE1C0EBF2D3F8FFE3F9FFE4F8FFE3F2FFDAE6F9CCD6E9BB
CDE0B3D2E4BAE2F2CBF2FCE1FFFFF8E6E7E9F1FFFF94BCBB3A7772D0FFFFDFFEFFF8FFFF
FFFCFFFFFCFFFEFFFBFCFFFAFFFFFBFFFFFDFCFFFFF8FFFFF5FFFFF5FDFFFFF3F5FFF7F6
FFF7F1361E121509007A7967FEFFF4F9FBF6F3EEF2FAF7FFF8FFFFD0E9EE649693447C79
84B2B2DDFFFFF2FFFFFAFAEE53382DC9A99EFFFBF1FFFDF8FBF9FEF7FFFFE7FFFFDDFFFF
EEFFFBDCEBD4E4EECBCBD3A2D8E2A3C4D890CDEFA585A461A0A972DAD7AADCDAB1E6ECC0
D0E0AFD9ECB5C8D198A8B273D3E59BD6EF9CD8F59BD1E8988B945BD6D6B2E7E4D30E0906
716A71030004807C7BFFFFFAFCFBF7F2F2F2FDFDFFFEFEFFF7FBFEF3F9EFFBFFEAEAFACD
D0E6A8D2EDA8CDE8A3CCEAA4D1ECA5D3EFA5C6E0969BB669D1E79CCBDF97CFDFA0E6F0BC
A7AB8AABAA96EAE5DFFFFFF19CA97DD2E5AEDEEEC1C0CCA8E3E9CFD8DDC7FEFFF0F4F7E2
FCFFE5FCFFDED3DCAFCBD9A494A66AD1E7A6CCE5A1D2E7A2CDD695A9AE6C414A095D6C29
E2F5B3BED390D2E7A4CBDE9CD8E7A6D1DD9BC9D691D7E6A1EAFEB6D2EA9EDDF9ACBEDD8F
D0EAA0CBE399C8DE95CCE098D4E49DD9E6A0DCE7A2E0EAA5CCD691F5FFBAC4CF8A909D57
384801E0F1AAC9DD95CDE39ACBE59CCBE99FCDECA0CCEB9FC8E99AC7E899C8EB9BCAEC9F
CDEDA2C9E9A0CAE8A2DEF8B7F0FFCAE5FAC1D3E6AFD1E5B2D0E6B7C1D1AAE0DFC3FFFAE4
F1F2E26C6F64B0B1ABF9F2ECFFF7F4D8BAB2E9D4BFD9D7B0D0E5ACC8E9A2CEED9FD5E9AA
ECEED9FFFDF9F9F2EAFFFFF3FDFAE7FFFFE6E0E0BEACAC86
8D8652CDC797CBC69CDAD7B4D0D3B6E6EBD4F8FFE9F8FFECF7FFEAF7FFE6F0FFDDDFEFCB
D9E9C5E4F2D1F4FEE3FEFFEFFFF7F4FFFEFFF4FFFF8AB1B04D8E88D4FFFFE6FFFFF3FDFF
FFFCFFFFFCFFFCFFFBFCFFFAFFFEFBFFFEFDFBFFFFF8FFFFF4FFFFFAFEFFFFF9FBFFF9F6
FFF1EA2410050800006E6C5DF2F2E8FFFFFBFFFCFFFAF3FBFAFDFFF1FFFF9EC9C22A5F59
6BA1A3CEFAFBEDFFFFFEFFF66C5045B8968CFFF5EBFFFBF5FFFEFFDBECF3E0FFFFCDFEF8
D4F4E7CCE0C7C8D7B0ECF9C4DBEBAAC8E49ACBFBAF79A75F808D55E2E1B1DEE1B2CBD7A7
CAE3ACCEE7ADD0DB9FA1AC6AC7DC91CAE692C6E78ECBE69599A46CD7D8B6FFFFF10C0805
676268030106787775FFFFFAFFFFFBF5F5F5FEFEFFF5F5FFFCFFFFFCFFF8F7FFE5E2EFC3
CDE5A9CCE9A6C2DF9CCEEBA8C9E7A1C5E39BCBE79C9DB86BC9E195D8ECA5C2D294D9E3B1
9EA182FFFFEDFFFDFAFEFAEFBFC3A2E3EAC1EAEFCFE7EBD2EAEDDCE3E5D8FFFFF3FDFFED
E5ECCDF4FCD3DAE6B4E7F6BB92A565C9DE9BC6DB98D2E5A3DBE6A4B9C4809BA7653C4B08
9AAD6B98AB69D4E3A2D9E5A5D8E1A2CFD597EBF4B3C8D590CADE96C2DD90D6F7A6CBEC9B
C1DC8FD4ECA2DCF2A9D4EAA1CEE29AD3E49DD4E59ED1E19AD6E69FBFCF88E9F6B0AABA73
86964F8C9D56CCDD96DBEFA7CCE69DCDE99FCBEA9EC7E69AC5E599C8E99ACAED9DCAED9D
C7E79BC8E89DCEECA4E2FFBAF4FFCCE7FFBFD1E7A9CCE1A8D4EDB6D9EDBCD5D7B2F6F2D5
AEB098CBD0BCEDEFE1FFFEF3FFF0E8EFCFC2C5B196E5E4B8C2DA9CBFE399D4F5A4C8E19F
ECF5D8FFFFF4FDFEF0FFFFEFFFFFEDF6F9DED9DCBD939774
625A299D9668F2EDC7F3F0D1F4F6E0F9FEEAF3FEEDF4FFEFF7FFF1F7FFEDF6FFEBEAF8DE
ECF6DEF7FFEAFEFFF1FFFFF4FFFCFBFFFDFFE3EEF27DA1A122686096DBD6E6FFFFF2FCFF
FFFCFFFFFCFFFCFFFBFBFFFAFFFEFBFFFEFDFBFFFFF8FFFFF9FEFFFFFFFFFFFDFBFFFBF8
FFF5EC2A1C110800004C433AFBF3F0FFFCFDFFFBFFFFFCFFFBFEFFEDFDFCE1FFF891BEB7
3A747675ABADD9FEF7F9FFF8BBA097B8968CFFFCF1FFFFFAFCFFFFEBFFFFCFFFFF4F8A84
2E5445677F6564744D2132002B4307527938AFEEA7BBF6B289A06CD8DEB2D9E2B7D8E9BC
C6E9B3BCDDA4DBEAB3A8B377CFE6A0CAE99DC0E391DBF9AF899762A5A889F4F5E7000000
69686D09080D757671FBFEF5F5F8F1FEFFFDE6E7ECF8F8FFFCFDFFF3F6EBF8FEE2F9FFDA
CDE5ABC6E5A2BFDE9BD4F3B0CDEAA7C3E19BD3EFA5BAD48A97AF65B1C580B9C88D97A071
EFF2D5FFFFF1F9F1EFFFFDFAFFFFECA6A086E1DCC9FFFFF3FFFCF5FBFBF3F8FAEFFEFFEF
D9E3C0D2DFB1C8D79EC0D39392A35F95A662CDDD9CE0F0AFC2D18EDBECA6D9EAA6D6E7A3
6E7E3D49581799A165999D62E2E1A8E4E4A8D6D899ECF5B2CDE199CFEB9EB7DD8ACDF3A0
DDF9ACCAE298C2DA90CFE99FD5EFA5CAE49AC8E298D2ECA2D3EDA3D3EBA1C4DA91E2F6AE
CEE29A8E9F5895A65FC8DC94D0EAA1D1EDA3CCEAA0C7E69AC6E69ACBEB9FCBEE9EC7EA9A
C4E699C7E99DCBEBA0DBF9B1EBFFC1E0F9B5CFE5A4C9E2A1B7D396D4E9B1DBDEB183815B
DFE3C2FEFFE6F1F5DCFFFDEAFFF9E8CEAF9B9D8A6AE0E2B3D2ECABB9E296C5EB98C6E49C
CFE2B4CFDDBACAD5B3CBD6B6F4FDE0FCFFEAFCFFEAFCFFEA
9A92645E572BFFFFDFF9F5DAFDFFEAF8FEF0F9FFF6F7FFF8EEFFEFF7FFF4F8FFF3F6FFF0
F9FFF1FEFFF6FFFFF8FFFAF6FFF9F9F6EDF0F9FFFFE7FFFF6EB5AD88D1CAE4FFFFF7FFFF
FFFBFFFFFBFFFBFFFBFBFFFAFFFEFBFFFEFBF9FFFFF8FFFFFFFDFFFFFDFFFDF9F6FFFDF6
FFFFF44B443A150B02483936FFFAFDFFFAFFF5EAF2FFFDFFFBFFFFEFFBF7F2FFFDC6E9E2
76B2B389C6C9E2FFFFEFFCF2B0958C8B695FFFFDF1FEFFFAFBFFFFE8FFFF73B0B187CAC3
CFF9EBC6E0C5CCE1B6D9EDBCBAD6A66D9C685FAA6FA6EDB5A8C49CFBFFE4F4FFDFEFFFE1
E7FFE4E9FFE1E7FACD849163B2CB92CCEFAFCAF1AEBADC9F8F9F7089906FFFFFF4000100
75767B00010482847FFEFFF8FEFFF8FEFFFDFEFFFF37383DF8FAF9FEFFF6F6FADFDDE8BD
CDE4ACC5E3A3C5E3A5D3F1B1D0EDABC9E7A1D7F3A9D7F1A7C0D88E495D187A894E8E976A
EEF1D6FAF8EBFFFCFFFFF7F8F8EADFFBEBDE7F726AFFFCFAFFFCFCFFFFFBFEFFF6FAFFEB
BFCBA5E3F4C0D6E8AADAEEA9C8D993546320D8E7A6C8D796E4F8B3CEE49CC4D994DBEFAA
CBDA99D2DC9D606429514F160A0500E1DCA2E2E2A6C9D08DD5E9A1CBEA9ABEE894CBF5A1
CDEC9ECBE59BC8E499C9E89CC8E89CC5E79AC6E89BCAEC9FBADC8FD0F0A4C3E296BBD58B
DEF4ABCDE199DEEFA892A65EC9E39ACFEBA1CFEDA3CBE99FC9E99DCCECA0CAED9DC4E797
C6E89BC8EA9DC5E59ACAEA9FD6F2A8D1ECA5CAE49DCFE8A4D3F0ADC3DB9DE7EEBAA8AA7B
BDC299FFFFDFF5F8D9FFFFE4FFFAE3C4A68CCDBB97D1D3A2D3F0AEC1EB9FC2E998CEF0A3
C4E19FC9E2A9D1E8B2D2E8B7F7FFDDF8FFE3E2F1D0F6FFE6
CAC1966C653BFFFDDDFFFFE8FFFFF1EDF3E7E8F2E9E1EEE5DFEFE4EBF9ECF7FFF7FBFFF8
FEFFF8FEFFF9FFFDFCFFFCFDFFFAFDFFF6FAFBFFFFD6F8F965AEA571BCB5C1E9EBE8F5FD
FFFBFFFFFBFFFBFFFDF9FFFBFFFDFBFFFDFBF9FFFFF9FFFFFFFCFFFFFBFFFCFDF8F5FDF2
FBFFF636382D0A00003B2527FFECF5FFF7FFFFFBFFFEFFFFF8FFFFEEF9F3F9FFF8DEF7F1
7EB9BD67ABAED4FFFFF4FFFBD5BAB197756BFFFEF1EEF3EDF9FFFFCBE7F23B7F809DE6DD
E0FFFFD9F7DBCDE4B8D4EBBDCEF0CF85BA9C358A6164B18D95B8A2EFFDEEF5FFF6EDFFF4
3F6D50A5D2B3DFF6DAAFBFA2D5F1CBBFE4B9C5EFC189AD7FB8CAA0889172F4F7EC020605
6C6F740001047C817BF6FCF2F9FFF5E8EDE78E8F93FEFFFF9999997A7C6FFFFFE6ECF7CC
D2E9B1CEECAECDEBAFC1DFA1C2E19EC6E3A0C3DE97CFE9A0D1E8A0D2E5A3E4F3BAD7E0B5
EEF0D8FFFFF4FFF9FEFFFAFFFFF9F8FAE2E0FFF2F486777CFFFCFFFBF9FAFEFFF6FBFFEC
4E5F35384B13DEF3B0C9DD95D3E49DD2E19C919B5ED8E6A8C7DD95D2ECA3CFE6A0D3E7A2
DBEAA9DBE3A7E8E7AFBEB78170652F2E2500B0AB71EBF2AFCADE96C8E998CCF8A3BBE792
B9DA8BD6F2A7DCFCB0C9EEA0BEE596C4EF9FC6F1A1BBE897C7F2A2B9E293CEF3A5CAEA9E
D7F1A7C7DD94CFE39B667A32AAC47BBFDB91CEECA2CEECA2C8E89CC9EB9EC9EC9CC5E898
C7EA9ACAED9DC6E69AC4E498CCE89DC8E49AC8E299D1ECA5C3E39ACFE8A4E1E9AE797B49
9EA474FDFFD8FFFFDEFFFBD9FFFADFE4C7A9F2E3BCDCE0ADCDECA9C5EFA3C6F09EC3EA97
CFF5A2CDF2A2C3E599BCDD96C4E2A2CFEBB0C6DFA8DAF2BE
D6D4A4B2AF82CECCA5FFFFE1FFFFE8E3EBD3D7E3CDCAD9C2D0E2CADEF0D8F0FFEAF7FFEF
F9FFF1F8FFEFFEFFF4FFFFF8FFFEFBFEFAFBF2FAFDEDFFFFD1FFFF75B3B03F7D7AA9D5D6
F8FFFFFFFDFFFEFFFFFFFFFDFFFBFBFFFDFAF9FFFBF8FFFBF7F3F4FFFCFFFEFFFBFBFFF8
F5FDF026261C0B000052393CFFF6FFFFF1FAFFFCFFFCFFFFF1FCF8F8FFFBFCFFF8F2FFFF
DBFFFF3B767A547D79A1B1A7A59188664A3FFFFAEEF9FFFBE4F1F757787F347474CFFFFF
D6FFF9EDFFF4F4FFE6C4DAB4C3E0C4BBECD64DA08C3083717DA99AE6FEF0F1FFF6E4FFF1
52836EB5E2CBC8DFC5919E826C7D5B0C260384AC8ABDE5C3435B390C1B00778272000200
666A6B080C0F3F4342848985808780909692202926E8EFE8CCD4C5AFB89BCFD8ABDFF0BC
EEFFD8EBFFDAE7FFD4C3E6ACC6E9A9D4F4B1BFDD97CDE99FCAE199D9ECAACBDA9FD0DCAE
ECF1D3FDFEEEFFFFFAFFFDFBFFF7F2FFFBF4FFFBF8F1E6E4C9C1BFCBCBC3F0F8E3909F7E
C0D6A5B1CB8EA4BE77DBF3A9CDE199E1F0AB96A061A2AC6DB4C380CFE39ED4E9A4C9DE9B
D8EBABCAD89ADDE5A9DDDCA3C3BC859E955C6862269A9C5BAEBE77D3EFA2BBE28FC8F29E
D3F2A4C9E399C3DF94C8E89CCDEFA2C9EEA1C6EC9FC6EFA1C0E99BCCF2A5C6EB9EC1E396
C7E69AD4F0A5CEE89ED2EAA089A359ACC67CCBE59BCFEBA1C9E59BCAE59ECDE8A3CDE8A5
C6E3A0CEEBA9CCE9A7CAE7A4CCEAA2C6E49AC4E397CDEDA1D3F2A6D2ECA3C3CF8FBDC589
596229D6DFAAD4DAAAE1DEB3E1CDA8B19B76918659D9DEA8CDEAA7C1EA9CCBF5A1C0EB92
BDE58CCAF198C7EA96D3F6A6C3E398CDEBA5CDEAA8C8E2A1
D5E0A696A169B6BF88EBF4BFEBF2BFE2ECB8D4E2ADCCDEAAD0E9B2D1EEB6D8F6C0DDFBC7
DCF8C7DCF4C4E3F9CBEEFFDDF8FFF6F3FEFAF8FFFFF1F8FFFCFEFFBCDDE626908238A495
D5FEFFFCFEFFFFFAFFFFF8FFFFF9FBFFFDF6F1FEEDF2FFF6F6FFFBFBFFFFFCFFFBFBFCF4
FFF9EF3B2E2527160F594642FFFAFBFFFBFFFDFBFEF6FCFCF9FFFFEBF6EEF9FFF8EEFFF9
E8FFFFAFD0D9213536636864796F663B2D22E9E7DAF8FFFAF0FFFF1235374E8081DBFFFF
DDFFFFEDFFFFF5FFF6DEECD5E0EFCECCF0D64E969532828355907CE2FFEBF0FFE8EDFFEC
527F6BB6E2CBC7DDB7A5AD7E2B2700010600BBDFC3BCECD2B0D4B83751367B8E7A1C2719
61615F06040738353E5C5C66848B910F1D1D000700D7EED2CFE4B9D1E6ABA9BA74C0D997
C7F3C2DFFFEADEFFE0C5F4C0B9E2A8C8EFAEC6E7A2D5F0A9C9E098E2F6B1CADA9CCCDAA5
F3FED4F3FCDDF1F9E1FCFFEFFEFFECFCFEE9FCFBE7FFFFECCFCFB794997B737F59829665
C6E3A9CCECABA8CC84CDEDA4C2DC93CCDD97D5DE9B7B803E79793DEBECB2C0CE90D4EAA9
C2E19DC9EAA5CBE6A3D4E7A5D8DEA0E1DFA4A49B60615B1F717634D3E39CDEF8AEC6E297
C9DF94CEE096D4E59EDFF0A9C9DD96D5E9A4CADF9ACCE39DD6EDA7C9E39CCCEAA2C8E89D
CEEEA2C0E295D3F8A8BDDE8FB3CE7F889F51D0E69BCFE39CD3E6A6D0DFA6D5E3B0D4E1B5
DAE9C0C5D5AECCE2B4CDE8B3C3E3A4C3E79DD0FAA8C4EC96CDE99CC8E096DCF0A8D7E8A1
A6B77199A865BBC589D2D59EE7E1B1A29A6B928E5EDBE3AAD1E8A2C4E797C8F098C4EC94
CFF19DBFDE8ECEEB9BCDE99CD0EAA0C9E39ADEF8B1BFD992
CCDC9E8C9A5C99A567D8E4A4D7E1A2D5E19FD2E39FCDE49EC6E49EC6E7A0C7ECA6CAEFAA
C8EBA9CAE8AAD3EFB4E0F6C8F7FFF1EFFCF5F5FFFFFBFFFFFFF9FFE0F6FF51BFB21D9685
D8FFFFF5FFFFFCEFFFFFF2FDFFFBFBFFFEF5F2FEEAF5FFF4F4FFFCF8FFFFF2F4F1FFFEF8
FFFCF475645A19080021120BFCF2F0FDF9F8F8F9FBF2F8F8F2FBF8F9FFFDF6FFF7F8FFFD
F2FFFFF3FFFFE7ECEF8C8B87211D141E1A11AEB4AAF4FFFDE1FFFE1A4443477779DCFFFF
E6FFFFEEFFFFF7FFFAFBFFEFFBFFE3BCDAC05597A32F7D8973B29DD8FFDED1EEC2CAE6C0
194631B2E0C6CCE8B8C1CB8F5E531DDDDAADD3F6D870A58B1542230C2F11CFE7CF13200F
15171203000275727DF3F2FFF8FFFF9BADAD000D0085A283C0DCA9C8E3A0BAD18396B46C
426D40AFE0C0A9D7B0C7F2C4B2DDA7749C5DB2D591B3D28CCCE7A0BDD694D9EFB1D8EBB4
C6D7ABD7E7C2EAF9DAF8FFE7E5EFCDE2E9C7DAE2BDFEFFDFD7E4B8D2E2B3D6EAB5C2DBA1
D4F1B1BFDE9B7C995694AF6ACEE39EE4F5B1E1EEA9D4DB98ADAC739B9A616F793DD4E9A8
CDECA8CAEBA4CEEDA7C4DD99CCDB9AE2E8AAD6D6989A985B707231828B48A2B16CD5E6A0
D9E9A2E1EEA6D4E19BD2DD98DAE5A1CCD795E3EFAFDBEAA9C9D897DDF0AECEE59FCAE69C
C2E296C3E89AC8EF9EC4EA97BCD987AFC676788D42D8E9A3C7D598E3EDB9FBFFD9F8FFDD
F2FBDEFBFFE8F7FFE4E3FACCC4E3A7D0F6ADAFDB86C3EE95D2EEA1CCE498C7DF93D6EEA0
CAE19394A65C9AA762E9EFB3CECD979A9865979763DDE5AAD1E5A0C3E294C9F199C8F097
CBEC9BC7E396D3EEA1CCE79ACEE69CD0E89ECFE59DD2E8A0
D9E5A797A3658F995CD8E4A4D1DD9DCEDD9ACFE49FCBE59CC7E79EC3E79FC4E8A2C4E7A3
C4E2A2C5E2A2D1E9ADE0F0C3FFFFEFEEF3EDF2FFFDF2FFFFF6FFFFEAFFFF98E4E02A7C76
D6FFFFF0FFFFFEFEFFFAF7FEFBFFFDF6FFF5FEFEF2FCFCF2F2FBF8F9FFFFFDFDFBFFFEF8
F3E6DE8F81781C0D06352822FFFCFBFFFEFDFEFFFFFCFFFFF7FDFDFCFFFFECF1EBF6FBF5
F6FAF9EDEFECFFFFFBD5D2CB3C3932040601808F8CEBFFFFDFFFFF7CB1B5467D80D0FFFF
E5FFFFECFFF7F5FEEBECF2D8E9F9D2D9FDE34E909C003F4A205B45E4FFE8E3FED3CEEDC4
00220ABBEECFCEF3BDD3E6A4ACAA6DC3C8923B613C205332215127325B33C8E5C9233424
0002000506086F7075FBFFFFF4FFFF9CB0AF031D147F9C86CCEAC4D0EDB7E6FFBBC3DB9D
1F3912C6E0C3D4EFCECAE9BFC1E3B024480B739A57CAEFAACCF1ACC0E3A1C4E3A8CCE8B5
CAE0B9CEE1C1E4F6DCFAFFE9FBF9D2C6C396FEFFD3EEFFCAC0DCA1BADD9DCDF0B0CCEAAA
C7DB9CDBE9ABB5BD81545C20E2ECAFC6D496BDD291DEF3B0E6F4B6818B4C2A3600C8D796
CBDB9AD7EBA6CCE09BD3E8A3DCF0ABC7DB96DFF0ACD9E8A59FAA68505918555B1BB4BD7A
D2DF99C9D990D3E39CCBD892DAE7A2E6F2B0BFCB8BCDDC9BD8E7A6D9ECAAC1D892D0EAA1
D4F3A7BFDF93BDE090D4F7A5D4F19FCBE49363792EDBEFAACAD89DDCE8B6F3FBD2FEFFE3
FCFFE6F3FEDEF0FFD9D6EEBCD3F1B3B9DD93D6FFAAC4EC94CAE99BD2EDA0C7E295CCE798
DBF4A3BED3869FAC66A4AD6EE6E7AEAEAD77999963D3DBA0CFE39ECDE99CCCF29BC1E991
C4EA97CAEB9CD3F2A6C8E499CAE49AD5EBA2C6DA93D8ECA5
DBE3A79DA667909A5BE0ECAAD5E4A1CEE49CCFE9A0C7E79CCCEEA2C8ECA2C8ECA4CAEBA6
CBE5A4CDE3A5D6E8ACE2EEC0FFFFECFFFFF8F7FFFDF1FFFFE9FDFEE3FFFFB4E4E63F7679
7DB2B6C8EDF3F8FFFFFDFDFFEFFFFAF2FFF8FFFFF6FDF6F0F9FAFCFCFFFFF9F8F6FFFDFA
FFFCF3B8AAA1170A02190E08FFF8F6F1EFF0F8F9FDFCFFFFF7F8FCFFFFFFFDFCFAFFFFFA
FCF5EDA49B92978E85ADA69E67645F111A174A5F62B3D8DED8FFFFCCFFFF215E61AFE6E3
DAFFF7F1FFF6FCFFEACBD2B0C8DFB5E0FFEF6FB2BA21676F265C44C5ECC0BDD7A8BAD6AD
7BB092B7F1CBA9D799C4E29ADEE5A2000900002400B7EABFB5E7B2B8E4B1C3E2C3000E00
000804000303696F6FEEF7F6EBFBF8BCD0CE203A37527066C2E0C8C4E0B8A7C388E7FFCB
2441230018068CAC947B9D7C60805700100042632A6D8F52C8E8A9CDEBADCCE8ADD2EDB8
C0D7A9D7ECC3D0E4C1495531615E35E9E7B7CDD5A2DCEFB7F0FFD0EDFFCFC1E4A2C6E5A2
D2E5A3D6E2A0E1E7A7CCD18F97A05D96A35ED7EDA4C4DB93D0E5A0D7E8A4D1DD9BA6B16F
C1CA8995A05EDBE7A5DAEBA7CBE29CC7E19AD1EBA4C3DA94D2E39FCCD7959FA464868D4A
5060198BA055596A237989424B5A15485712434F0D5D6C2B92A261CADE99DDF3ABC3DA92
CBE59BD5F1A4DEFDAFB7D686C9E696C4DF90CCE49A849956B1C0878C9866A8B389939B76
87916EF3FFDBD6E7BBD4EBB5C3E09EC8EA9EB9DF8AC7ED96C5E496CCE89DD5F1A4CBE898
C6E190DFF6A8C9D9927F8847C6CA8FA5A56F9A9D66D4DCA1D3E4A0CFE99FCCEF9BC1E991
C3EA97C7EC9CD1F3A6C2E296CCE69CD4EAA1D6E7A1BFD08A
D5D69A979C5C959E5DD9E6A1CFE39CCAE49ACCECA0C6EB9DC5EC9DC4EA9DC8EAA0CCEAA4
CFE5A4D0E0A2D5E0A4DCE4B3CFD5B9F5F9EAEFF5EBF6FFFAF4FFFFF1FFFFF0FFFFBDE2EA
397E7B76B2B0F5FFFFFFFDFFEDFDFCF0FFF9FFFFFAFFFCF9FFFEFFFBFAFFFFFEFDFFFDFA
FFF9F3A69991080000120904FFFBFBFFFEFFFEFFFFFEFFFFFFFEFFF1ECF0FFFCFFFFFAF7
8D7D70625141584839483E345756525863652542484B7782D4FFFFCEFFFF3B7C8094CFC9
DCFFF6E6FFE7FAFFE2E2EDC3CAE7B9BFEECE0038380C4C4E0F3B20D0EFC3D0E4B3D7F2C5
4B815D81C095BFF6B2BAE395DDEEA70614005F814FB0DEADB9ECAA95C287BDDFBE000800
6574710009086F7970F7FFF6F4FFF8B6CDC33D57565D7A7895B1A5CAE7CBC9E5B2DEFFD3
41786500130CC8FFF5C0F1DEB6DEC4264523637A50889A684958219FAA6ECFDB9DD4E2A4
DDEDAFBCCE9299AE73B7CA93CCD5AAA3A983D3DBB2BECB9FF8FFD8F0FFCFC4DEA1D7F2AF
D1E8A2C8DE93CEE394E2F5A3BECD7856640DE4F29AD3E28DD7E99DDDEEA8D0DD98D7E29E
949D5A424B08515E19889953D6EDA5D1EBA2C9E49DCAE49DCDE29DCBDA97D3DC9BECF5B2
D6E89ED5EC9EC3D88DD9EDA5CBDC96D4E59F51601D4354104A5B178C9D59C9DD96E6FCB4
BED68CBDD589D5F0A3D3F0A0E6FFB3C8E497C7E198E3F9B8C6D7A0A4B2817E895FD4DFB7
B6C09B939F77D1E1B2C7DAA2DBF4B2CCEB9FCAEC98D1F39DC9E89AC5E498D2F1A3D0EF9F
C0DD8BCFE897DDEFA5C9D4906E72357E7F469EA16AE2EAAFD6E7A3C6DE94C6E894CBF39D
C4EE9CC0E99ACAF1A2C1E396CFEBA1CFE59DE4F5AF98A762
E1DFA2A1A161B6BD7AD3E39CCCE49AC6E69AC8ED9FC6EFA0C0E99AC1E899C8E89DD0EAA3
D2E5A3D2DEA0D6DBA1D7DEABD5DFBDFCFFEFFFFFF4FFFFFAF8FFFFF2FBFFFDFCFFE9FFFF
63B0A8439088DEF0FAFFFDFFF5FFFFEFFFFCFEFFFDFFFEFFFFFDFFFFFDFFFFFDFFFFF8F6
F6EBE5897F760D04002A231DFFFEFDFFFFFFF9F8FDF8F7FCFFFDFFFFFAFFFFF3F6AD9A96
745E50FFEAD8FFFBECFFFAF1FFFFFBEDF8FA8AA7AF36626D58949EB4F9FFBAFCFB336F65
729F8ACCEBCCF8FFE3C8DBADC2E7B3A7DAB11F5C545D948E749776D1E7B6D2E0ADBCD4A4
7BAF8878BB88B1EDA5C9F8A8CBE09B404F141E3C0A7DA46F416F264B7835C4E6C5000E02
707E7E26302F414E3CC6D6BBF4FFEDA0B7A3000F0C435B5DC7E0DCECFFF1C6E4B2B7E1B3
4A8879317775CDFFFFAAE4D6BEEED809301166855CE2FACA879A63607032B5C181D1DC98
E3F0ABD1DE987F8C46BBCB8ADDEFBB83956590A071E9F7C6CDDBA8CFDDA8DCF0B5C8E1A0
CEECA6CAEA9ED7F8A9BAD785CCE28FCFDE8B5E6613DEE595D2DC93D2DF99E1EEA8D8E8A1
D0E099D7E8A1E6FAB3AABE7770863EC5DB93D4E9A4E5FAB5CDE19CCDDE9AD3E4A0C7DB94
C6DC91DFF7A9C4DC90D2E89FDAEEA7CBDC96D6E7A3D3E4A0BBCC886778343E4F0BCBDC96
E0F4ACE2F7ACC0D68BD0E89AB8D487CBEA9ED5F0ABB7CF91DEF1BACEDEAFEEFBD0ECF7CF
D4DFB7CCD7AC465421A5B77BD6EDA9B7D187CEEB99C4E491C4E298D1F1A6C7E899C3E493
D3F3A0CDE897CADF92E7F4AE868C4C88894F94975ED8DDA3D8E7A4CBE198C4E393C8EE99
C6F09EBCE797C6ED9EC4E699D0ECA2CCE39BCBDC9687944F
E2DA9CA29E5FD8DD9BD3E39CCFE99FC7EC9CC2EC9AC2EF9CC2EC9AC4E99BCAE89ED4E9A4
D7E6A5D7E0A1D9DDA2DBDFACD0DAB7F6FEE6FFFFEFFFFDF2FCFEF9FBF9FEFFF8FFF7FFFF
B0FDF5388B81D4F1F7FBFFFFF5FFFFF5FFFFF7FDFDFDFEFFFDFCFFFDF8FFF9F3F5FFFCFB
FFFCF6AFA59C130A010400007C7B777C7C7C78777C7D7B80BFB6BBFFFBFFECD9DB685350
947D6FFFFBEAFFF4E6FFFCF4FFFBF8F2FCFDEEFFFFD9FFFF64999D72B0AFB3F2EA66A091
6A9C83365E3C728E66799666578346265B277BB29D94C3AFD9F2C858652FBDC48EE0F2C0
5E8D617DBB88B0ECA6C0F0A4D6EFAEC9D7A2586E40BCDAA4BFE59AC3EBA5C8E3C4000700
727D7FF3FEFAA1AE945968412A3C121326065B6F64DFF3F2F1FFFFD5EED8C1DFA9ADD3A0
0C3F2E245F5B80BCB2B1ECDAABE7CB144E2882BA89A8DBA3C0ECAFBDE4A1ACCA84586E26
7A8540B3B9739D9C59E7ECA9C2DC93C4E49BCCE5A1596C2C919F61D0E0A2BDD194A6C383
BDE29FBDE6A2BFE9A7CFF4B1E6FFC1C3D297CBCE9798965DAAA968CED48ECBD890E2FAAE
ACCD7ED3F6A6CFEEA2C5DF95AFBE79A6AF6C5C611FC3CA87D9E5A3D0E5A0D2F0A8CFF1A5
D1EDA2C4DF92D3EDA3C3DB91D0E69ED4E8A3CCDF9DD4E4A3D1E1A0B5C48175844194A35E
C3D38CD6E69DCFDF96DCF1A6CAE69BDAF8B0C4DE9DC8E0A6E9FBC9E3F2C7FBFFDFE7F3CB
D3DEB4C6D2A2E6F3BDB0C082ABBF7AD3E9A0E2FAAEC9E497C3E19BD2F1ABC5E79BBFE091
D5F7A3D5F2A0C5DC8ECBDB92DAE19EA4A86B7B7C43B4BA7ED4E0A0D8ECA5CBE699C5E695
C8EFA0BDE698C5EA9DCAEA9FCAE69CCFE69E8B9C5696A560
C1B579868042DEE19ECBDB94D0EC9FC9F09FBDEA95BEEB96C4EE9CC6E999CCE69DD5E6A0
D9E3A4D9DFA1DCDDA3DFDFADDEE2BDF3F6DBFFFFECFFFFF1F8F9F1FFFCFFFFF5FFFAF6FF
D3FFFF368379D0F8FAF1FFFFE5F7FBF7FFFFFBFFFFFEFFFFFCFBFFFFFDFFFBF5F7FFFDFA
FEF5EEA1988F0E07000400000100000707050B0B0B0300003E3435E8D8D9DCC7C6725A56
D9C5BAFFF4E8FFF8F0FFFCF6FAF5F2FAFEFDECFCFBEAFFFF6F9A9344786C5D9685B4EBD4
BFF4D64A7957739B766D97674A7B393C70308EC09DC4E9C8CCDDA7999F61BDBE84D1DEA9
759C6F80B684BFF6B2B7E49FC6DDA5E1EDBF8B9A71AFC390CBE99FCEEDA9C9DDC125342F
747D82E4EEE6DFEAC8919F6C64733C4A5A2DD7E6D1F4FFFAF2FFFAE8FFE4BCDBA0B3DB9D
0012003F745A4A816280B8937FB88F124C1C7FB883BAF0B6B7E9ACCAF6B7B7DE9FACCC8D
97B17482985AA8BA80D5E9ACCFECAAC6E7A2CEEBA9819B5C859D61D6EFB5C9E6AC67894D
8FB57A5D854999C185CDF0B6C2DEA4CDE2AADFECB7B1B67E6F6E2EC7C884DCECA3C0DC8F
CDF7A5C0EB99C1E698D4F0A5D3E09BDCDE9D797838E1E1A1DEE9A7CBE59ECCF2A7BEE799
C3E397CBE79CC5DF95D8F2A9CAE19BD4E9A6D5E8A6D0E3A1D1E1A2D9E8A7ABB777717D3B
E7F2AED4DF9AD7E29DCDDD96CBE59CCCEAA4CCE6A9D3EAB4F1FFD7F7FFE0F9FFE1E3EFC9
CAD5AAE5F1BFC5D29AD6E4A7A2B2717A8E49C3D790D5ECA8D2ECADBEDC9CCBEAA4D4F6A9
C0E190C2DF8DD8EFA1DAEAA1E0E9A69DA26264652B9FA368CCD697D9EAA4D0E89CCDEC9E
C9EB9FC4E69AC9E99ECFEDA3C6E097D4EBA350641DADBE78
B4A469544A0DDEE19ED3E39CC9E89AC5EF9DBFEC97BEEB96BEE594CFF0A1CFE59DCAD994
C1CA8B777B3E64652B4C4A17877D5AD2CDB0E1EACFF8FFEFECF4E5FFFBF9FFF3FFFFF0FF
E6FFFF437E7A81B8B5D5FFFFE5FFFFF5FFFFF6F6FFFFFDFFFEFEFFFFFEFFFFFCFDFEF9F5
FFFAF3B3ABA0100A000400004D4A414847427D7C787E79762D221E0F00001804007D6962
BFB2ACFFFDF8F4EAE8FFFCFAF6EEEBFFFFFAFBFFFAF5FFF8E3FEEBD0F6DD649276457859
A5DBB9B3EBC8B3E9C7B4E9BBBBEFA7BCEBA3C3EDBDC8E5B7D7E3A1BEC077AAA969E3EAB4
59794A8EBA89D2FFC0DEFFC7DCEDC1F5FCDAD3DAB8707C4ED6EAA5CBDFA0E2F0D7020B08
6E7377E4EAE0DDE5BCD6E1A5D1DE99808B51E7F3CFE7F5DCF5FFEFE7FFD9B8D895CAF5A6
BEF2A8B6EEA783B6716E9C5B79A162CAEEB1C1E2ABC1DFABCBEBBABEE2B2B5DFB1BCEDC0
BEF5CBACEBC0A6E9BEBEF7CEA4C29C6B7F5A5670498FB288BCE7BABAEABABEECBBC2ECBA
C8EDB9C6E4AE5A763C8EA86BC8E2A1BDDB95D8FAB0C5DF95E0E7A3B4B9764A5B14A8C77B
BEE798B5E291CAF0A3CAE69CD4E19CDDDF9EBCBB7B878948D5E19FCCE69FC6ECA1C1EB9F
C8E89DCEEAA0C6E298D2ECA5CDE4A0D7EDACCFE4A3D2E5A5D0E0A2DBE9ABD3DFA14F591A
949D5CDAE3A0E4EBA8D7E49FD0E7A3CCE9A7CEE7AEC1D7A8F7FFE3F6FFE2F9FFE4E4F0CC
D9E4BAD4E0AED7E4ACCBD99CD5E3A5C9D99A96A66891A369E3FAC4C4E0A6C7E5A5C5E49E
C4E397DFFCACC3DA8CD8E89FD3DD98A6AB6B6C6D336E7237B7C081DAE9A4CDE39AC8E396
CFEBA1C8E39CC5DF98D6F0A9C6DD97B4CB8590A560CEE39E
A38E55615519DBDB9BD6E69FCBEA9EC5EF9DC4F19ECBF6A4D0F3A3D3EDA3C8D993E3EEAC
3E4406575B1ED3D79CEFEDBA55482561583BC1C8A9F9FFECFEFFF3F7F0EAFFF6FFFFF7FF
F4FFFF658D8D3E77719ACCC9EAFFFFF5FFFFFBFFFFFAFDFFFBFFFFE5EAEDFFFFFDFFFFF8
FFFEF4A8A093070000282214CFCBBFFFFFF4FAF7EEFFFDF3FFFDF35545380F0000160600
75706DEEECEDFFFEFFFAF4F4FFFDFAFFFFF6F4F2E5F6FBE5F8FFEABBD5B2BBDFB9002D06
00330DADE6C3B6F3D2C0FBCFBEF2A8BDE99CC7EDB2CAE6ACE1EDA1DDE0919594515F642C
F2FFD9EEFFDFEDFFD6E0FDC5F8FFE0FFFFE6D5D8B999A074D0DA9BE0EBB1FCFFED000200
878B8CF2F6E8C9D0A4CFDA98A2AD6188934ED5DEAFE9F5D1F5FFE4DCF8C8C5E9A3C6F29D
C2F39AC2F39ABAE691CBF2A3BDDE97D2F0B0B7D49CDAF8C6BBDCB1678D665D8B67467E5B
488969337C5E4897782B6C4C000D00596A4A627D5A1F451E497951001A00518459507D52
8DB286D0EDBFCEE6B6A2B98590AC71D0F3B1B1D993D9FDB5C8D995DCE9A4D3E9A1739147
85AA5DD0F5A8C1E196CCE69DDBEAA5DAE3A0D8DF9C4E571490A15DD5EFA8BCDE94D6FAB0
C7E59DD0EBA4D3EEA9CDE6A2CEE4A3C0D696C7DB9CD7EBAED9E8ADD7E5A8D2DDA199A165
515719D7DC9CCFD494D1DB9CCFE4A3CBE5A8D6EEBACADFB6F7FFE8F3FFE5F9FFEAE6F1CF
CFDAB0CAD6A6D6E3ABD3E1A6DBE8B0D6E3ADB1BD8BAAB789D8E9BDE1F7C8CEE7B0D8F5B5
C9E49DBCD68CD4E99EDEEBA3D5DC98C4C68799995DE7E8AC8C9554D0DD98D7EBA3CEE49B
CDE39BD3E7A2D7ECA7D8EDA8C9DE997E954FE0F7B1C6E099
6F5822837439E9E9A9CFDF98BDDC90CAF3A4C7F0A1B6DD8EC2E195CDE199C5D08CE0E6A6
585E20A2A86CE0EAAEC8CF99C7C39D5D5737929173C5C3AC8C8477FFFCF6FFF7F8FFFDFF
EAF3F8EDFFFF487674588281C6D3DCFBFFFF9DACB3000509000507313D3DA5ABA7E9EAE2
FDFAEBA19A88100800140C00BCB5A3FEF8E8FFFFEFFFFFEDFFFBE662563E4F3F251C1100
0100003E4146F7F6FBFCF7FBFFFDFBFFFDF6FEF8E8FFFFE8FFFFE1C8D7AEDBF6C942673B
002E045D957086C5A6ACE9BFBFF1AAB8E394C8EBABC8E2A1CDDF8BDDE791BDC07B868B51
C0CD9FE6F9CBDAF1BBDAECBAFCFFE4FFFFE8CACEABAAB082979B60DDE1AEF7F9E30E0F09
777974ECF0DFDFE7B8E0EBA7AAB566BFCA7CD0DA9EE2F0BFE3F9CBD1EFBBCCF5AFBEE99A
C5E896C2E191D5F6A7C2E69CC1E9A3B6E0A1C2EFB82656242054261A4E274B815F44795B
457C5F457B616DA18A5883655C774CD3EAB6BAD6A3C0E2B06A94644C7A4C75A27969936D
1136141F4120425F4087A58386A4804F6F4898B891C2E3B4CDEBAFD0EDAAC0DB96DDF6B2
A9C07C7C914E83985594A964C7DB96CBE09BE1F6B1C7DC978DA35BC7DE96D1E8A0C2D993
CAE39FD2EBA7DAF3B1D5EEADF2FFC8DDF3B5D5E9AED4E8ADD2E1A8CAD79FDEE9AFBFC78C
40450B85894EEEEFB5E8F0B4D1E3A7CCE3ABE6FCCEDFF0CEF6FFECF1FEEAF9FFEDEAF7D9
EDF9D3D9E6B8DAE7B2D4E1ABD8E2B0E8F1C4EAF2CDEBF5D3E9F4D4172703CBDEB1C9DDA8
C5DE9DD6EDA7DEEFA8CBD892E8EFAC9B9D5EA5A569EFF0B4BBC1818C99549EAF68D8ECA4
C4D390EBF7B7D5E4A3C5D594DBEFAA879E58BAD48DD5F0A9
634C188C7D44DFDDA0DDECA7CAE89EBDE495C0E798D0F0A4D4ECA2D8E7A2E1E7A7A3A76A
9BA165C2CC9094A466253400CDD6ABF6F3D24D3D246A55440F0000887E75FAFFFAF5FFFF
F8FFFFF4FFFF00090B00060C03000EDAD8E64C686B00100DCEECEA172B29000801E1E7DB
FFFFEFABA3904C412B0A0000A39882FFFAE3FFFFE8F6F2D7342F11686240867C58A49D81
24251F000106D9D8DEFFFEFFF3EDEFFFF8F2FFFFF1F9F7DEEDF1CCE4EFC4C8DCABCFEFBD
B7E1B30E41180E4724B2EBBEC6F5B1BEE69DC6E9A9D0EEA8D1EB92D3E88DD8E59DDFE9AD
96A06ED2DEAED9E6B0D2DEACF7FEDDF9FFE1D9E2B5D9E0AC5E5F268F8E5EFBFBE10D0F02
707368F2FAE3CDD6A78692509DAA5BD4E192D1E09DD9EDB2C7E3B0C5ECB7C2F2B6B7E8A7
BCE3A2DFFFC0B5D99BCAF0B5C6EEB98AB484174217001200B2E0BBE3FFEEDAFFE5C5ECCF
BBDFC3CAEDCFBCDDC0C3E1BDCCE4B4D1E8B2DEF6C4D1EBBCAEC99ECEEAC4CCEBC9CAEDCD
C6EBCCC2E9CC466D50082D0E0C2D0E567355597254CEEAC2C2E8ADC5ECA9D3F1B1C8E1A0
CBDD9FCBD99CD2E0A296A665D3EAA6CAE49DC8E39CDEF9B27F964E859B53DEEFA9DAEBA7
D6EBAAD7EDADC3D99BC5DB9DF5FFCFF7FFD1EAFDC5D0E3ABD1E2ACEBF8C2C1CC94DEE6AD
5E632B3A3D04CCCB93CACF97D6E5AED0E4B1F7FFE3F3FFE7F7FFF2F4FFF2F9FFF3F2FEE6
FBFFE3E1EEC2D8E4B2CFDBA9CBD3AAE5ECCAFEFFEAFEFFEDFEFFEFFCFFECB1BC9A94A477
CFE2AAD5E8A8D6E5A2D2DD99DBE09E9496559D9D61D1D296D2D898D7E29EA0B069CADA93
E2EDABCAD394CFD99ADCEBAAD7E8A4879C57CEE8A1D6F1AA
715A28AFA069EDEBB0D8E4A2C9E49DC0E296C3E599CEEAA0CDDE98D6DF9EDBDCA093945A
D6DEA3D9E7ACD6EEB05571376B8555D4DAB682614EB3877E7D5F57362D24EEFFFAE9FFFF
CDDBDB2F363C00040B02000D11000F03000B335D5B3F7B7187B2AB5B7971000700727D6D
CFCEBAA0988132240A241600B4A68BDAD1B4DAD4B45855328B8960CDCC9EF1EFBEEFEDC6
C7C5B80100020100048F8C93FFFEFFFFFEFFFAFAF2FFFFEFFFFFE4CBD6ACD1E3B1CFE7B3
C3E5B2AED5A681B0843B6B3BADD99CCBF3B4C2E8ABBBE09BC9F097C8EB8FC7E197D6E8AA
98A06DBBBF8DD7DCA4E9F0BCF5FDD8E8F4CCD1E3A7CBDA99B5B67C868454FFFFE3000400
868F7CE9F8DBB1C1949BAB6DACBC73D3E599CEE39EC6E0A3B1D6A2CDFBCCC4FDD0C8FFDB
CCFFDDA3DBB499CDA94F7C5F4E745B3555405D7663E5F8E5EEFDEAF8FFF1D5E1C99FAC8E
6878546D7E54839668CADDAF5D744A879B76CEDCBB757B5F767A6364695357654E8FA78D
C6E9CBB8E4C1BCECC6A8D5ACB6DBAF627D522332094C5F314E713799C383AED093D2EEB3
DAEEB3E4F3BAC7D69BD9EBAD687D3C92AB67BFDA93C5E099CCE39B8B9F5784944D8A9956
CBDD9FD6EAADA2B67B96AB70A2B77EE4F9C1D2E7AFC2D59ED6E7B3E4F2BDDDE7B3D4DBA7
F5F9C651541FD8D6A3EAEDB8D5E2ADCFE0B3F8FFE6F9FFEFF8FFF7F9FFFBF9FFF8F9FFF1
F9FFE6EBFAD1EBF8CAEEFBCFE6F0CDEFF8DDFCFFF4FBFEF5FBFBF3FDFDF1FDFFEB959F7A
B3C190ACBB80D4E0A0D9E29FDFE4A2A7A767A9A76CEBEBAFE3E8A8D7E29E87975051611A
D7E0A1D8DEA2D9E2A3D3DF9FD8E7A6435614D5ECA6B5CF88
6049178F7F4BD2D097C2CE8ED3ECA8CDEDA4C7E59DC9E098E5F1AFDFE3A664632A616229
E1E9B0BFD195BEDC9E5D7F43547240DAE0BCBB9080955E57EFD2CA050700000C00D7FDEE
F8FFFF17141B3D3741493B4A0F000B0B071563949044867A2C5E550A2E24324C3FD0DDCB
E0DFCA9F957A1304000F0000958667EBDEBCA5A07A5A572CBBBD8CDDE0A9D7DBA0EBEDBC
FFFFECBCB2B0040002010005A9A9B3FBFFFFFBFFFFF9FFF6FBFFECE2F1CAEAFACBCCE1A9
CCE7B0C5E3ADB1D3A0A4CB96244C179FCA94CCF4BFB9E6A3BEF097C3F296C3E89BC6DEA0
D5DEA9B0B07CA5A66CBFC289CCD8AAD0E2B0D3EFA4D8EFA1DEE2A5BCBA8AA0A47F000600
3040231F3212263C0ECDE2AAD8EDAAD2E8A0CEE7A3CCEEB1C4F0BDD3FFE294D5B776B79F
306B552358461242347BA39A87A6A0CEE2E0DBE7E77A7E7D7B7C7738352C0F0E00030300
010500010700000800020C0006110000070001040017170026240F252712000500021400
07240864896779A17C88AF83C0DFB3D6EDBF657246D3E5B5CEEFB8042C000018008BAD71
B9D69CC6DFA5D8EDB2CADEA1CCDEA0D5E8A896A665CFE39CD7EBA4C1D58DC1D58DDEF2AD
D9EBADF9FFD3DBECB5C4D7A091A46DD4E8B3D6EAB5D8ECB7E5F5C4FBFFD6E6F0BEDDE4B1
D0D4A2636533555322D7D9A7D9E3B1D1E0B7FBFFEAF8FFF2F9FFFBF9FFFFF2FCF4F6FFF1
F7FFE8F9FFE3F9FFDBFBFFDFFCFFE8FCFFF1FCFFFBFAFBFDFEF8FAFFFEFAFEFCEDFFFFE6
E1EABFBBC8929EA86B939959D9DB9CC0C0827E7C41C8C88CE0E5A5CBD491DCECA5D6E69F
747A3CB5BB7FDDE3A5C8D293CFDE9D819452CDE49EE3FDB6
866E3E6959259F9D649FAB6BD4EDA9C7E59DC7E19ADCF0ABCBD495B1B175332E00696830
DFE8AFD8EDB2BEE0A39CBF852B45169B9A7BC7998A8B5B5182796A283926001403B3CFC3
F9F7FAA4949F0800070700070C000D00050DD7FFFF09473C0F4239000E02112D1E93A28F
DBDDC590876A0F00001B0600A28F6EE1D3AE9891675F5D2DE9ECB5DAE3A4E1EBA6EBEEB5
FFFFE3F4E3DB332928010005555965CBD5DFF4FFFFE9FCF8E9FCE8F5FFE6F6FFDAD5E8B1
D7EBAECEE4A6E0F6B8CFEAB30A3001699469A0CE9FB9EDAFC0FCA4BCF79BC4F4A8C1E1A0
E6F1B9D5D69DC6C585C8CD8DD1DFAAD5EFB0CCF096C3E187CFD897EFEEBE888F65213009
263C18001000062100B9D4A1CDE5A9BED897CCEBA8D7FFC3B9EDBF9DDABB5DA496397A74
001B154E6B676C8484CFE4E7F2FFFF79838C646B750000090302080100000805000E0D00
12110019190026270027240022190019100047431E898A689198773C4729233117000800
0007003141271222073243236273515D6E4AA4B992D5ECC0C8E2B24D6B376D925C1B440A
BBE9ABCAF4B5BCDEA1CFE9ACD9E4A8D9DFA3919155F2F4B3DCE7A3DCF0A8D1EDA0C6E49A
C8DC9FE7F8C1E3F4BED7E9B596A874C3D5A3CCE0ADC7DBA8E3F3C4F4FFD1FCFFD8DBE3B2
CDD0A18183524D4B1ADFE1B0EAF3C4E2EEC8FCFFECF6FEF1FBFFFFFBFFFFDCE5E0E5F0E2
E0EDD3EBF9D6DDECC5E9F7D3F8FFE9F4FCEFFCFFFFFBFAFFFDF3FCFFFBFFFDF9F0E3E5CD
F6FCD6D7DFACC9D196818646757537B1AF72817C42DAD89DC4C989F2FBB8CCDC95D4E49D
BDC3859BA165DFE5A9D9E3A696A564C4D795C5DA95C7DE98
E1D8A1D9D79ED8DDA34F5A20839559D3E7A8D9E9AB95A163666C2E5355169D9F60DFE5A7
C5D597D2ECADC0E7A6BCE2A9000B00040200FFF3E7BB968D4F4C39EBFAE7536A58000600
FFFDFFFFF2FCC5BBC648424C040008000205698A81B5DFD322433C0B2B20000B002F4433
ECEFDCC3B8A444321A110000A49574ECE0BAA59A6D544E1CE4E5ABD3DE9CC2D48AF7FFC3
FFF9D5FFFDEDFFFBF9B1AEB500000E323B4AECFAFFF0FFFFF5FFFBF7FFF1F8FFE8D1E2B8
EBFBCADEF0B4BBD08BCCE6A7D6FBD077A380396742699F6D97D68FA4E496C0F9B4C0EDAC
BFD99AE2F1AECAD68E95A15997A768BED58FCFED95D3EB93DCE5A2D7DAA5D5DDAC000A00
798E63DDF6CCBCD7AAD5EFBFD5EEB5C9E5AACAE8ACB4D7A16C96705B8B759BD2CDD3FFFF
EEFFFFEEFAF8EFFBF999A3A24A53520003021319176A6F699DA097E3E5D7B2B49F909074
8C8D6BD2D2ACCECFA5EFECBFBDB382B1A776969463898F5FE1EDBFD2E3B7C9D9B2A3B18E
687152434A2B272C0E272C0C0E1500010D00091900899B73D0E0BBD9EEC3C2E0ACA6CD94
2D5C254A7942A7D098CEEDB2DCEEB2CCD498C7C88E6D6E32B0B978D9E9A2C5E093D4F0A5
D3ECAACCE1A6CFE1AFD2E3B7ADBF97CBE4BDD8F6D0C1E1BCDAF8D4EDFFE4F4FFE2FEFFE4
DFDFBBBFBA92655E30BAB689FFFFDCF9FCDFFFFFF3F7FCF8F9FFFFF9FFFFCBD3C6D5E2C8
CAD9B0DDF1C0CBE3B3DDF3CCF8FFEFF8FDF6FFFDFFFFFAFFFFFDFFFAF7F0FFFFF1DADFC1
D2DDB2D9E8B1CEDE9FD7E3A39A9E614F4D12ABA26BE4DBA4D5D398DEE4A4CDDE98D4E8A1
D4E09E899354717B3C6B7A3999AA66C2D691D1E79FD2E8A0
D0E7A1C1D796DBEDB3C9D6A1565E2FD3D6A9DFE1B09EA16A5E6426C9D48FD5E79BCEE69A
C6E49AC4E8A0BBE29F5B7D4A000700020400F8EADFFFFBEFA89F8E060300010200060900
000002FCFFFFF9FFFFF8FDFF0B0C0E0001007F8375D0D2C524201D000501000A00729084
FEFFFBEDDFDC1200001000009F9C7DDBD6B0A493685C4A1AE2DDA3D7E2A0D0EAA1DFF8B6
FBFFD4FFFFE8FFFDF8FFFDFF66637400001062626CE2E6E9FCFFFFEDF3F1F9FFFFF8FFFA
EFFFE4D5EBBACFEBA0C0E298C1E6BAC2EACF154327477A5980BD93ADF0BDA8E9B1B5F3B2
C3F9AEC4F19EC1E58ECCE893586B1C929E54D2D890E6E9A4EDEFAED1D598DCE4AB000A00
738450E4F8C5D3EAB6C6DFA8CCE3ADCCE3ADC3D7A6D3E5BD3A4A30253326F7FFFFF1FBFC
F9FFFAFBFFF4717A690005000006007B8465C1CBA6D9E1B8D7E0B3DCE6B48A935E9EA770
8A935A4F591DDAE4A8D7DFA3565F20DCE7A5D1DD9D505E20536124CDDCA1D3E2ABD1DEA9
D4DCA9DAE0B0DADDB0D8DBAE2E3104515427313709010500010300DBE1C7D2E4B4BED9A4
C9E9C25E825E001000284E1BC7EAAAD0EDAACEE3A898A76E727E40DCE7A5DBE59ED5E59A
CBEA9EC8E8A5DCF2C3C1D2B25C715E000B005D9081417B6DA5DDD0E0FFFFF0FFFFF5FAF4
FFFDF1FFFCE454421C6C5A32FFFDE1FFF9ECFFFDFFFCFEFFE1EBF4F7FFFDE1ECCCCAD9A2
CBE198C3E493C4F2AAD7FFCAF2FFEFF8F9F4FFF5FFFFF6FFF8FCEDF7FFE8F6FFDECBDDAD
DEF6BAC8E5A2C3E59BD1ECA5DAE6A8928F58A99465F5DDAFEDDDACD1D098DCF2B1CBEAA4
D0E79FD8ECA4D1E59DCCE299D3E9A0D4EAA1CEE69CCFE79D
D1F5ADC7E6A3E0F5BDF3FCD144411EF4EECCF5EDC89591628E9257E1EEA8D7EE9ECDED9A
CEF1A1C7EDA2CBF2AF92AF7F41503D373934E9E6DDFEF6E9978A7A342717685E5257524C
8C9091E8F2F4E9F6FCF7FFFF9FA3A2616159C1B8A9FEF0E3BCA8A75D5958224139AFD2CB
FCFFFFEDDEE53725250A000097977BDEDAB5AB946B695121ECE6ACDCE7A5CAEAA1D4F4B1
EBFBCAF7FEDDF7F8F0FFFEFFB2AEBC64616C030102040300BBBCB7FEFFFFF4F9FFEDF7F8
F3FFF2BFD8AECBEBA2D2F7A7C1E8A7C0EBB6C3F1C397CAA12D654273B18CADF0C49ADDA8
A8E9A7B0EAA0C5F6A7C5EA9CBFD68EB9C48254551CD1D098C0C487E9F2B3D6E0A446531B
81925CEFFFCEC4DBA5D0E8B4CEE6B2B5CB9AA0B288283615020700131309FDF7F7FFFDFD
E7E9DC0004000006000209009BA37AD4DDAECCD79FDAE5A9DBE7A777843FB2BF79D6E39D
DAE7A2CFDC97A8B472859451CBDC96CDE199E9FDB6C1D58ECEDF9B808F4C899555818D4F
838D516E763B898E569DA26C9A9D68E0E2B0B0B07E79774E3635191215000007006E7F55
C3DDB8B6D5B35379523A64349FCB90C8F0B1BBDDA0D3EDB0C0D092A4AE6FE9ECA7CEDA90
CCEF9FBAE29CC1DCB3C4D9C6455E5800110D81B5A985C2B346827682B3ADC8E3EAF4FBFF
FFFBFFFFFBEFEFDBB85F4924D8BDAAFFF8F4F5EBF4EEEDFBF9FFFFF9FFF8C7CFA6E0EFAC
D2EA94CFF296BBEA9ABFECB1EBFFEAF8FFF8FFFAFFFFFBFBFCFFEAF7FFDDF4FFD5D0E8AC
CCEBA7C0E598CAEFA2C6E49AD4E0A0A7A26A745E2F876F41DBCD9CEFF2B9B2CF8CCFF5AA
C3E397C8E799D4F0A3CCEB9DC1DD90C9E89AD7F3A6CBEA9C
C7E4A4CFE7ADF2FFD1FFFFDFA29B7FFFFEE4FFFDE09D946D9E9D67E0E9A8C9DE93C5E091
CCEB9FC0E19ACCEFAFBEDAAACFDCCAF2F5EEFFFFF4FFFEF1FFFCEFB8AA9DF0E6DCFFFAF4
FDFEFFF5FDFFF7FFFFF8FFFFFCFFFFEDEAE3FFFEF1FFFCF3FFF9F9767A7B2C514ACCF1EA
F1F6FAEEE1EA59494A0A0000949077E1D9B5A38A62634B1DE5DEA7D3DF9FBFDE98C6E9A7
D1E3B3EBF5D3F8FCEEFEFFFBF6F6F6F2F3ED323524000400000500575E4E323C34F7FFFB
F5FFF4C5DDB9C0DEA0BFE28ED6FD93B2DD72B6E289CAFCB3B8EDB74B845B054020538E70
0015005289627CAB7FD2F9CAC4E1B1B9CFA0DDEDC09DA9799DA870DAE8ADCBDAA3011300
647A49B2CC9CD7F3C2C7E5B36682516D8758CDE2BB09180027301D9C9F96FFFEFFFAF9F7
0307000006004F5839E9F3CEC1CCA1CBD8A3D4E1A9DBE9AB4C5B1881904BCEDE97DBEBA4
DEEDA8D1E09DCCDB9AD3E29FD0E19BDCF0A9DAEEA7C1D58ED5E6A2D7E8A4CFDE9D566222
D2DEA0E1EBAFDCE6AACDD59CEEF3BBDADFA9D1D49F9A9C6A6264330E12000004000B1900
CBE5B6C6E9B1C9F1BD78A27460895FB8E0AEB9DD9DD4F3ADC4DA9AA4B2748B9652DEF0A6
C4E99BD9FFC382A38414322893B0AE304F47E7FFF1C2ECC4D1FBD5000F001F3938F4FFFF
FEFEFFF4EDE7E5D8B6937F5A6E4E41D1B5B4F9EEF2FFFEFFFFFEFDFBF9EAE3E8BFD2DEA0
D3E599C6DF8ECBE9A1D2F4B8C4EDC1D5FADBF1FFF1F8FFF0FDFFE1D6DDB3D3E4B0CEE6A8
C5E59CC5E697DBF6A9D2E299E1E4A1D9D0957467328C834CA6A76DC4D493DBFBB0C1EA9B
D6FDACC0EA98B5DC8BC3ED9BD5FCABC3ED9BB9E08FC6F09E
C9E1A7DCEEBAFDFFDCF9F8DAC5B8A5E7D6C4FFEFD95548269D9969E2E8ACD2E29BCBE397
D4F0A6C1E09CCDEBADD8EFC1F1FDE9FDFFF7FDFBEFFFFDF0FFF4E7A39588FFFDF3FFFEFA
FBFBFDFBFFFFF9FFFFF2FAFDF7F9F8FFFFFAFFFEF3FDF4EBFFFFFD6C7A7A1B463FB9E2DE
F2FBFFFFF7FF5D4E51110300A59D86F9ECCCA78B66664B1EE4DFA7D4E3A2C3E49DCEF1AF
C7DEAAEAF8D4FBFFEDECF5E4DEE5D5FCFFED959F7A7782570B1700051000000700000600
081A046F846398B380C8E69EC5E582CAEE84D1F59BCCF5A9B2DEA3ADDCAECAFCD6B5EBC7
87BD993D744D02320C719E77D2F8D3C6E5C5CBE5CAC1D9B7D1E5B4ABC088455C281E3606
324D20819E724261375271479FBE9294AF862F4521819478ABB6A5F0F7EFB9BABC33342F
081000535E3CF7FFDCD0DDB2D5E1B1D6E5AED6E4A78F9F5E99A865D6E7A1EEFEB7BCCD86
CCDB98DCEDA9C6D594DDEEAADAEEA9C8DC95C1D58EE2F6AFD2E39FCEDF9BD9E8A7CAD998
DBEAA9C6D294E4F0B286925496A06496A06498A065B0B87CDFE3A6BBBF8D6F745E000700
243C0A96B87BB4DBA2C6F0C000110094BD95BAE2A4CCF0A8C2E09AD0E7A3B1C580ADC480
8AAF6A729D654F775C21473AB0D1C8EBFFF45C754BCCE5AEDCF4C0F1FFE3A2BDAE97ADAB
F5FFFFFCFFFAD3CEB0EFE4C623150A2F2422B4ACA9FFFEF8FFFDF3FFFCE5DEDCB5838A54
859355C4D996CDEAA8AFD395B5E0ABDAFFD7E4FFE4F2FFE8FFFFE1D8DBB0C7DAA3CFEFAC
CBF1A4C7EA98D4E99AD5DD92DDD594B7AD6F837D3FCCCE8F8C99548AA057D0EC9FB8DB89
BCE694C8F5A2CDF8A6BFEC99B8E391BFEC99C4EF9DBDEA97
D1E3AFE0EDBFFCFFDFFFFFE8928275AD998EFFEDDC2A19009A9369E1E4ADDDE9A7CEE49B
D3EDA6C7E29FD1EBAEDEF4C6EFF8E3FFFFF6FFFFF3FFFEF1FFFDEF817368FFFBF2FFFDFA
F8F6F9FEFFFFF0F3FAFCFFFFF4F4F6FCF8F5FEF5EEFFFEF8F8FFFF758F8E14474290BEBB
F4FFFFFFFCFF3F33370B0000A79A87FFF4D6A78663684D22E3E0A9D3E6A6C1E29DCAEFAC
C7E2ABDBF1C2F7FFE4E5F6D4C5D5B1D1E2B6CEDFA8C8DA9CBCCE94C7D9A775856177876C
2D3F25000E00000C007B9363677949C9D9AAD2E5B7CAE4B4D8F9C4CAF0B7B4E0A1B4E6A1
B1E69EB4EBA7C0F4B66FA16E44724E26503C1F443D8DAFA1B0CCA6CCE6B6CDE8BB425E35
506E4AC4E3C1D3F2D0ACCBA973916D415C3BA4BB9E7A8E75F8FFF6F8FFFA292D30020701
7A8567D0DFB4DDEABECDDDACC4D39CDAECB099A96A869A55C9DA94C9DD95D3E49DD7EBA3
D1E29ED4E8A3D5E5A4CEE29DCADE99CFE39CDFF3AEC8DC97CDE19CCDE19CCCDD99D8E9A5
D3E4A0AEBD7C92A16096A564CCDB9ACEDD9CDCEBAA9EA967949B58E2E7ADDEE4BEA3B18D
000C00022000B1D89FC9F4BF729C76204A249AC494CCF4B6CCF1A4B1D185D1ECA7D4F2B6
C0E5B2648E66002F0D1E4B2EC2E7C6C0DAB3C0CC9A939860D5DDA4CDDBAADBF7D183A489
E3FEEBF5FFF4FFFFEDFCFFEC385043092016878579AB9E8EB9AD93A295757265427D7850
616A3B36511A83AF70CDFEBCCBEEB4C0E1AABDE4AFC1DEAEDBE2B8D9E1B2C3E2A6BCEAA1
BDEE9CC7EF99D1E493DDDF94F0E39F9F9150999855DEE8A3CFE499C3DA8C93A859D1EA99
CBF0A0B4DF8FC4ED9ECCF7A7BBE495C3EE9ED1FAABB9E494
CBDBAAD1DCB1FEFFDFFFFFECC9B8AE735F58C2AC9F58482F9D956ED7DAA5D7E3A1C8DE96
D0E7A1D2EDAAE2FCBFEFFFD4FAFFEAFFFFF4FFFDF1FFFAEDFFFDF19D9087FDF2ECFFFDFB
FFFEFFFFFEFFF7F8FDFEFFFFFFFFFFFEFAF9FFFDFAFFFFFBF0FFFF87ABA920595382B3B0
F2FFFFFFFDFF554A4E0B00009A8977FFF3D9A88464765931F0EFB9DBEFB0BDE09EC1E6A3
CFEDAFC4E0A5DFF7C5DFF7C7D2E8B7C5DCA4E2F8B7D3EAA4CDE4A0D2E8AAF7FFDCC1D6AF
9BAE8E2B401F000B00162705000500686C5DD7E0CDCEDCC3BBCEAECBE4BAC5E6B1CCF2B5
CFF9B7BAE9A5B3E4A3B7E8B077A87B3F6E4E4C7C66305A42395B367C996DC7E5BF183614
628064BCDAC0CDEBD14D69502741267D957BD8EED795A693F7FFF7F9FFFD000104030802
CEDCB9D6E8B6CDDEA8CEE1A9E1F3B7A5BA795A6E299BB169D2E69EDDF3AAC1D58DCEE49C
D2E6A1CFE49FD4E7A5D4E7A5D0E49FCEE29BC5D994D4E8A3DFF3AEECFFBBB7CB86DDF1AC
798A466E823BBFD38EC8DC95C2D68FDAEEA7CADE97CDDC97AAB16EB6BB7BC5CF93D1DFAA
1A2D00000D00D0F2C0BCE4B2BAE5B81E482093BE93B9E4AFC1EBA3DFFFB9B2D791B6D9A1
C3E7C15D8563001A00245327B6DCABC2DAA6E1E8B25D5C24D0D198E0EBB3DFFCC6EBFFDF
EBFFE8D2EBCEFEFFF1ECF8EC214C43154336A1B49E656849595A305B5A2E42421C6F7553
536241000D00365624A4C58CD2EAAECBE5A6CCF0B0C7E9ADB7CA9CD5EDBBC6F4B4B4EEA2
ABE791C6F79ED6EB9CE3E59AE0D593BDB270A09F5CBEC881D7E99DD9EC9D919E4F95A658
C6E295D4F6A9C6E89BC3E598DCFEB1D1F3A6BCDE91CCEEA1
CCDEAAD2DFB1FEFFE1FFFCE6FFFCF165524B5745397A6E56C0BC96DAE1ABD7E8A4D0E89E
D7F1A8DEFCB6ECFFC7F5FFD6FEFFEAF1EFE2FBF8E9FFFEF1CEC4BAACA299FFFCF8F5EDEB
FFFAFCFFFCFFFCF9FFF5F4FAFFFFFFFFFEFFFFFEFDF3F9F7EDFFFF96C2C13D7874A6D8D7
F1FFFFFFFDFFA89FA2180904957F71FFF8E0B2896D8A6A44FFFFD0ECFFC6CAEDADCAEFAA
D1F5ABC5E79DC5E4A1C8E6A8C9E5A8C1DE9EC7E29FC5E09BCEE7A3D7F0AFBCD39BE2F8C9
CADFB6CFE4BDDAEFC8B6C5A42C311D0505000203000406034E5452828B88CDD9D5EAFCF0
E3FCE7EDFFECC7ECC1BBE6B1C2F0B2BEF1AEC4F9B1C2F3B2BBDFAFABC9A3405D3E638064
00100015301D001101768D7BB4C9B6F4FFF4EBFCEAACB8AAC3CDC43A3E3D08090E424740
C2D1A8E8FDC2C1D598D4EAAACEE3A23148029AB068BCD48ACEE49BC2DA90D7EDA5C9E098
DDF2ADCEE59F2F440122370070843F98AC6783975296AA6571853E8A9E576A7E3790A65E
DCF0A9CCE299C7DD95D7EDA4D4EAA1D7EDA4DCF2A9CEDF98D9DF9F9CA15EEAF6A4C8D88D
061700051D007F9D77C8EDC1BCE7B286B27F3C663EB2DDB0BDEBADBDECA4BBE9A1D5FEC2
D0F4D08EB394143F1158834BD7F9BCD4ECAECAD39CD6D9A4A2AA718D9C61A1BF7FCDF1B3
BDE0AAD1EAC2CCD4BFD5E5DB113F3D124E42C8FFDBA8D7A1B8D69AD3EFB499C091476F4C
8BAB93C5D4BF9F987C251C009DA66DD7EEA8BEDE95CDF2ADCFF6C1B3E3AFA8E6A5BDFFB8
AEF29DC2F8A2CCEB9DD5DF96E3DF9FE1D99AB0AF6FD3D594D8E29DD4DE97DCE298979F54
93A55BCCE49AD5EDA3BDD58BC7DF95CFE79DCCE49AD8F0A6
CDE2A7DDEFBBF6FED7FFFFE8FFF6E7B6AA9E5A4E409F9780DBDDB5DAE4AFCEE3A0CCE69C
CBE99FCBEBA2CEEDA9CFE4ACD4D9BBFFFFEFFFFFF1F2ECDE9E958CA89F98FFFAF8FFFDFB
FFFCFFFFFAFEFFFDFFFFFEFFFAF9FEFEFFFFF3F4F6F7FFFFE7FFFF92C3C0498480C2F2F2
ECFFFFEAEAF2D0CACC0B0000846A5DFFE6D3A3755B7D5C39F8FAC8E3FCC2C4E3A8C2E7A2
BCE28FCDF39CCAEC9FC4E59EC5E3A3D0EEB0C2DEA1E6FFC5F1FFCCD5EFB2C5DDA3CAE1A9
CFE6B2CCDFB1C4D6ACF9FFE6FDFFF1E6E3DE5B5A58211F226F6E7400000700000703080B
75807AF5FFF6DDF6D9C6E5BBC2E7B1BCE4A5C3F1A9BBE5A3CAEBBCCBE6C54F694E000C00
000800000E0363746CDEEEE4F2FFF5F8FFF8FBFFF8A9AFA56C6E690000007E7B82F5F8EF
DDEDC0BBD191D6ECABD0E7A3D4EBA5829951D7EFA5D3EBA1D0E89ED0E89ECBE29AD9F0A8
7F96505168228AA15DD4EBA7C7DC97D8ECA7D5E9A4D1E5A0DBEFA8C6DA93DBF1A9CBE199
D0E69DC8DE95D5EDA3CEE69CD0E89CD1E99DC2DA8ED7EBA3D7E09D939953DEEB93D4E392
647541000A00C8E1C1C0E0B9C1E8B3C4EFB784AF81C3F1C3BCECBAB5E7ACBFF3ABB5E3A2
BCE1B5CAEAC300100032531ABBD79AD1E9ABD6E8AED1E3A9D5E9AE425C1D85A562C1E1A0
CEEBB1D3E6B8CFD9B6CDE3CE104942004637ACF1C4B5F1B1CFFAB3BAE7A476B07E104C2A
80AF9DCCE6D9DBD8C5392F0C7B7B45C5D28DDAEFA4C2E39EB7EAB249875445894CA9EFA9
B0F0A2B9F09FC7EC9FD1E79FD9E2A19D9E62919057D3D49AE9EFB1CBD692D4DF9ADAE79F
CDDE972C40005A6E26E3F7AFD4E8A0C3D78FE3F7AFC9DD95
C9E7A1D3EDAEF2FFD3F5FCDAFFFFECFFFDEDFFFFEDEEEED4D3DBB2D1E2ABCFE8A4CBE99F
C8EA9DC8EA9EC7E8A1CAE2A8DDE1C0FFFFEBFFFFEF6B6557595248FFFDF7FFF7F5FFFCFD
FFFCFFFFFDFFFFFAFEF7F6FBFCFFFFF9FFFFF1F9FCEFFFFFC5E9E93C6D6A457C79D5FFFF
F2FFFFFEFEFFDDD9DA261710593B30D6AD9B9060496D4B28FFFFD4E2FBC4CDEAB4C3E3A0
C7EB91CAEF8FCBEF98C7E99DC3E1A1C5E2AAD0EABBD9F3C4F2FFDAD5EDB9D4ECB2C2D79C
CBE0A5D7EAB3C8DAA8FBFFE4FFFFFAFFFEFFE6E2E3ABA7A48D8A815B594C040500010300
00030089917A6E776298A68FA8BAA4D7EAD6F2FFF3E9FFE9C4DCBCC6DEBECBDEC8000E00
67746B000400767F7EE7EDEBFCFFFDFAFCF7F2F1EC95948F34302D040000DFD8DFEDEDE3
D8E8B7BFD894D2ECA5D8F2A9C5DF968CA65CC5DF95CAE49ACAE49AC6E096CFE9A0D1EBA2
90AA638EA861BFD894D3EAA6D2E7A2D4E8A3CBDF9ADFF3AEC6DC94D0E69ED8EEA6D3E9A1
CEE69CCBE399D3EBA1D3EBA1D7F2A5BCD78AD8F3A6CDE297E0EAA39BA159D3DD94D1DD95
E5F5B65B6D3B132809688163CDEEC1B8DFA8B3DFA434602B85B38EB4E4BAB3EAA6C5F9AE
C7F0AEC4E3AA6A8051001000C0D1A4D7EEBAC1E4A4CDF6B0C5F0A9B9E29E86A86C97B079
C7D7A6E4F1BCD0D9A2C4E4B500432D106550ACE3B9BCE5A9C2F0A7B1E49F6FA979002C0D
327160548F7DB7E5C889A57C545722534D0FEEEFABC8DE9D20562268AC7D165520265D23
6EA15FC8F7B1B8E19BD0F3AFD2EAACCBDAA177804BB2B985D0DBA3DAEEB1D4F3B0BFDE98
C6E099B5CB839AB068BFD58D99AF6793A961849A52AFC57D
C1E698C3E49DDAF1B9DDECC3F7FDE3FCFDEBFFFFEFE8ECD3D3DFB7D0E4AFCAE7A5C6E89E
C7E99FCBEDA3CEEEABD4E9B1CFD0AEFFFDE6E6DFCD5C56487F7870FFFEFAFEF8F8F2E9EC
FFFBFEFFFDFFFFFDFFFEFFFFF9FFFFDEECEFF2FFFFEDFFFF9DC1C17CA9A6C4F2F0E6FFFF
ECF9FFFFFEFFB3B2B00A000038180BD6A8987F4D36704D2DDEE4B6C7E2ADC8E3B0C4E0A3
C7E88FC7EB8BC7E992C8E89DD0ECB2DEF8CBF2FFE8F4FFECF4FFE6C9DEB3CEE3ABDAEEAF
D6EBAAD3E5A7CBDAA3FCFFE1FDFEF6FFFEFFFFFFFAFDFBEEF8F7E2F3F2D6F8F7D8FFFFE3
323216030300010200060700080A07030708000105010A056B7B61DCEFD1BCCBB4000500
696F6B0001025E5D62E7E5E8FFFEFFFFFDFDFFFDFB7F7774060000060000FFFBFFE5E5D9
D6E7B3C9E39ACFE9A0CBE59CCBE59B92AC62D4EEA4D4EEA4D4EEA4D5EFA5CBE59CC9E39A
8BA55EC6E099D6EFABCFE6A2CADF9ACEE29DD2E6A1C9DD98D6ECA4DDF3ABBBD189BFD58D
D7EEA661792F40570FCEE69CD2EAA0D9F3A9C4DC92DDF2A7D4E0963F4602F2FABE1D2700
D7E3A3D7E6AD000900001200CFE9C2C4E4B3AFD59A5E89511A472088B68FC4FABCB7EBA1
C0EAA2BFDD9D5C6D39000800DAE7BCCFE7B7C6F2B5ACE39FB4EDA8B5E8A5CDF0B6899D68
606A35D4DCA1CDD8936C8B4F185A3E1E665096C19664874DB7E59CC2FAB37BB9866FB591
A5EFD89CE4CE5B987977A277929F6A6060244D530D1D3300023807C6FFDBBFEFC5C0E7B8
5D804A92B679B3DB9CB9E3A3BFE2A8D2EFB9637545D4E4B5CFE3B0B2D39AACDF9DCDFFB9
CEF2AACFEBA1C2DE94D9F5ABC5E197C9E59BC2DE94D9F5AB
C1ED96BEE596C9E7A9CDE3B4F4FFE1FCFFEFFEFFEFEDF5DDD3E3BED2E8B7CBE9ADC4E4A1
C1E19EC4E4A1C8E6AACEE0AEDBD8B5FFFFE6A69E8BAAA498FFFEF8FFFEFDFFFEFFFFFDFF
FFF9FBF0ECEDFFFEFFFCFFFFF2FDFFF1FFFFEBFFFF7493983C5E5FA3C5C4DCFFFFE8FFFF
F9FFFFFFFEFFEDECE81C1208401E12C49585BA8670654224DAE1B5BFD9A9CAE0B2DDF2BA
D2ED9ECFEB96CAE699CAE4A3D0E8B8DBF0D1E7FAE7EFFFF0F5FFF1D8E9C5C8DBA4C5D896
D0E19DFBFFCAF5FFCCF1F9D2FFFFEFF2F4E7FCFFECFBFEE3FCFFDDE1E3BCEDEFC8D3D4B2
DDDCC0726F5C8F8B804B4642211D1E130E12030004030400000600000D00757F66737A6A
050601110C10322830877C84BDB0B7AB9FA1B5A7A75045435B504EBCB2B1FFFCFDE9E7D8
D2E0ABD5EDA3D0E89EC4DC92D2EAA0839B51CAE199D2E9A1D1E8A0CBE29AC6DD97B3CA84
839A54D6EDA7D6EDA9C3DA96D7ECA7C8DE96E3F8B3CCE19C596E29D6EBA6D3E8A39CB16C
788D48B8CE86DAEFAA536921C5DB93C9E098D9EFA7C9DD96CDD991C6CF8E8B9161CFD5A7
828B544A551B4B59240E1F00000A00CCE5BED4F1C1B5DAA69DC5912F5B283F6F3BB9E8B1
B9E3A3DFFFBED1E3A7B0BA85616F3CD2ECBCB1E1ADB9F5BFB9F8BFBCF3B987AB6EDCF0B1
7B84434C520CEAF6AAB5C78BC6DDC3D9F5DF001B00557D3FB3DE97ADE59E9CE8AA3B8F5E
61B090B6F8DDB9E4C9557550B4D5A0B9D996B0CF837699550018000017000E2C0ACDDFB9
D8E7BC778B58B9DAA1CFF8BEC3EEB888AE7B2F4A1F90AB80BBDFAFC8FBC377C281A9F2AB
B9ECA1C7EDA0C7EDA0C6EC9FC4EA9DCAF0A3C8EEA1C6EC9F
C4F397BFEB96C5E8A4CAE2B2F6FFE6FBFFF1FCFFF3F6FFECF4FFE6F5FFE1EEFFD6DDFAC2
D1EDB3CDE8B1CEE6B4D1DEB3D4CEAC4C3E24A8A08DFFFAEEFDFAF5F5F3F4FCFAFDFFFAFE
FFFEFFFFFEFFFDFDFDF4FAFAF2FFFFE1FDFFA1C3CC53767C95B1B2EEFFFFEEFFFFF4FFFF
FEFFFFEEECEDFFFFF8160E013A190ACA99886F3824714E32D8E1B6E8FFD3F6FFDFDEEBBF
CFE1A3D1E6A3D8ECADE2F6C1F0FFDDF7FFF1F7FFFDF7FFFDF4FFF1D1E0BFCEDFA8E2F3AF
CDDD96EAF6B6EDF7C5FFFFE3F8FBE8FFFFF1FFFFEAFAFFDEDFE6BC8C946599A172878E64
D7DBBAC2C5AAE2E1CFB2B0A3A9A59AB0ACA1A7A1954B4A3568724D5B673F343D20000300
0906000600000800020A00040D00022313161303033E302D948987F3E9E7FFFBF9F0F2DD
CDDCA5D6EEA4D0E89ECCE49AD1E8A0576E269DB46CC7DE96D6EDA5C3DA92D7EEA8B8CF89
8CA35DCCE39DD1E8A4CFE6A0C8DF97D9EFA7BFD48F5F742FA0B5708CA15C859A55CEE39E
DBF0ABC4D795CEE19F455816BCCF8DD2E5A3DEF1AFD1E1A0E4F0B0D3DCA5DDE2B9D6DAB5
D6DCAE8B945DC6D093BFCA920008000514009DB38DC6E3B5BFE3A6A1CA8E60895F3E6840
B8E4AFC2E9AAC6DF9DCADD9B7A8C50233E098BB98BB4EBC377B085427741597E3BD0E89C
EBFAA9CFDA8B98A85F68763B7B7F5EB1B899CEE6B4C1E4A4C4E7A3CDFAB5B0EEAD91D89E
71B68A80BC98B7E3C23F653E78A56ED3FFBDC0E699B9E19B3E6B40B9E0C323381956613F
333A11C3CFA1C3DBA7B3D6A0C5EBB86A90615E7D54B0D0A7CBF4C89CD5A2539E637BC683
BAECA3C5EB9ECCF2A5BCE295C6EC9FC2E89BC6EC9FB8DE91
BEF091C0EC95C6E9A5CBE3B3F8FFEBFCFFF4FEFFF8F9FFF5F5FFEDF8FFECEFFFDEDBF0C7
CFE1B7CFDFB8D1DFBCD4D7B8998E7059492FE8DDCBFFFFF3F4F3EFFFFFFFFFFEFFFFFDFF
FFFEFFF5F4F2FEFFFDF8FFFFEEFFFFE7FFFF8DBAC01C454BE8FEFCEAF6F4F8FFFFF0F4F5
FFFDFFFFFEFBFEFFF6211B0B4F2E1DA67564AE77635D3A1EDFE7BEE6FFD5F4FFDDF4F9D9
CCD4AFCED9AFD8E3B9E6F2CEF1FDE5F8FFF7F7FFFFF3FEFAF7FFF2D0DEBACDDD9FE5F5AE
D1DE99D4DDA4D9DDBAF2F4DFFFFFF4FFFFF4F4F8E1D4DBB9D9E5B78F9D6894A56F96A773
C9D9AAE2EFC4D8E2BDB6BE99929970898F63ACB07E9FA6729DAA757C895BB1B896020400
383429140A0937282D7E6D734A3A3D3D2D2E978986998E88C3BCB6FFFEF8F8F5EEF4F8E1
CDDEA7D1E79FD0E69ED8EEA6CEE39E3F540F7E934ECFE49FCFE49FCADF9AD8EDA8C9DE99
869B56D2E7A2CDE29DD4EBA5D3EAA2DCF3ABCFE69E859C54D0E5A0CBE09BE0F3B1CADD9B
D4E7A5D4E4A5D0E0A159692AA7B779D5E5A7CAD89BDAE7AFC7D0A1D9E2B7DAE1B7D7DCB4
C7C8A684875CE7EDAFD7DD9D4147170007002D3A1ECEE2BDC2E0A0CEF2B4B6D8B5254C31
56845FC7F6C0B9DF96CDEE9DB2CE835F7D3F24462162896E567F6198C29489AD63B9DB7D
CDE887CAE189C0D59482935D3B48136F7945E6EFB8D9E7ACC8DD9CC4DF9CCAE7A5C8ECAE
A1CE973B713F8AC8972965329DCE97BEE5A6CBE99FC9E8A44B7448CDF4D588A27F000D00
0D1800535F31A5B584D4EAB9B9D3A669845B3E5A34B6D6AFA0C69D54835797D19FACE3A9
C6EDAAC6E49CD1EFA7C3E199D5F3ABC8E69ED2F0A8CBE9A1
BDEC8CC4F099CBEBA8CEE4B6FBFFEDFDFFF7FCFCFAFDFFFCFCFFF8FBFFF3F9FFEDF7FFE8
FAFFE9FCFFEAFFFFEFFDF8E46F6043FFF3D7F7ECD8EAE4D8FFFFFDF8F7FCFBFAFFFFFEFF
FFFEFFFFFFFDF9FEFAF5FFFFE2FFFD7EA6A85C8E95D9FFFFF4FFFFFAFAF8FFFEFFFBF7F8
FEF4F5F5F0ECFEFFF3060100422110C897869B64508D6B50C7CFA8D3E9C2FBFFE3FFFFEA
FFFFF1FFFFF1FFFFEDFEFFEFFCFFF4FBFFFBFBFFFFF6FFFCFBFFEFD7E4B9C6D594D0DE93
D9E4A0D1D8A5C8C7B2BFBCB3E6E1DBD4D2C6A9AD949CA77FDEEFB9CFE5A5C8E19DC9E4A1
CCE6A7C6E0A3BDD59BD1E4ACDDEDAFE2F1AEC9D68ED3E09AD9E9ABB5C38E9EA67D25280D
686556070000605252AB9B9EE1D1D2FFF3F3FFF9F3B8B1A7EAE6DDEEEEE4FFFFF6DAE2CA
D3E4ADCDE39BCEE39ED9EEA9CBE09B5B702B839853D8EDA8C4D994D7ECA7C9DE99D0E5A0
768B46DEF3AECDE29DCCE29AD3EAA2BFD990A1B870C7DE96D1E6A1CEE39ECCDF9DD4E7A5
CEDE9FD6E4A7D9E7AA455016DBE6ACDFEAB2DCE5AEEBF5C3FAFFE1E6F0CEE4ECC5DFE4BC
91916F4C4A23D7D69EDFDFA3E1E1AB9B9E711C2301000800748B55C4E0ADBEDBBCC9ECD4
82B393427847B2E69ECAF7A4CAEF9FC0DE9E7C926CB6CAAFC3DABDCDE9B9C3E89AD9FFA0
CAF08DD1F39CD5EFB0C3D8A0C9DD98D3E39C899354525E20829253D6E5A4F1F8B4DAE3A0
CFE4A3C8EEB1B5EFB5B6F1BBBEEBB4DEFFC3C9DF96D3ECA8BDE7B988B691B1DAB0C3E4B5
7A92625F6F3E636C3D666D41AFB78E4E5C38000F004159371A35125B7B54CAEAC3CDE9B9
D1E5A8CCDB98D5E4A1CDDC99DAE9A6CBDA97D5E4A1D5E4A1
C1EE8FC7F19BCAE8A8CFE1B7FCFFF1FFFFFDFDFBFFFFFDFFF8F8F8FBFEF7F9FFF1FBFFF2
FFFFF3FFFFF3E3DED8C0B4A8BAA98FFFF5D7FFFDEAFFFEF2FFFFFDFEFFFFF2F3F8FFFEFF
FCFAFBF9F9F7FBFFFDF4FFFFD3F1F14E7A7D87C0C7DFFFFFF3FDFCFFFDFAFFF7F6FFFBFB
FFFBFBFDF6F0FEFFF11D180442210E7D4A37824B3759371CD9E1BCF1FFE1FFFFE8FFF9ED
FFFCFFFFFBFFFEFAF9FCFBF6FCFDF8FDFFFCFCFFFFFBFFFAFCFFEACBD7A7D1DE98E8F4A8
DFE8A785875FA39F96F2ECF0FFFDFBFCF8ECEEF1D2D1DDADD6EBA8CDEA98C4E68FCEF59C
CAF09BCDF2A2CDEFA3C9E9A0C0DC92D0E89CC8DF8DD9EE9FE0F5B0B7C98FCFDBAD111600
6766540A03006358568E80805244449F918ECFC6BDAFAB9FFFFFF4FEFFF4F8FFF1EDFADE
D2E3ACCEE29DCFE2A0D2E5A3CDE09EA0B3719AAD6BBFD290D2E5A3DCEFADD3E6A4D5E8A6
8B9F5AC8DC97D7EBA4D4EAA2C7DE96D7F1A7D7F1A8819B52D0E7A1C9DE99DAEDABD1E4A4
D7E7A9CEDC9FDBE6AC67703988915AD3DCA7FFFFD3FDFFD8E7F0D5FBFFEDFEFFE6F0F4CF
E7E8BECFCC9F565225393303DCD9A2E9EAB0858C56000800000B005D6F57CEE7C9BCE0BC
BCF3CC4A895A7FC080B3ECA5B4E29AC7E3A6E5EEC155572FD3D9ADCDDCA5C6E89BC1EF97
AADB82C5F2A1CAEAABCAE4A3D5EB96D5EE93D0EFA1CCEAA2EBFFBD4954105A560D948C41
E1DD94D6DD9AC2DBA4C9EBB8CEF1BBB6D498CDDA94D1E6A1BCECB849885972B37DC5FFC4
7EAA6F9EB77E8F9663635C32544A270C07000005000A15000007007E8566D2CCB2E6DCB9
E3DCA8E4DEA2EAE4A8E3DDA1E6E0A4DED89CE3DDA1E3DDA1
C7E897CBE99FC9DEA5CAD9B0FEFFECFFFFF4FAFAF2FFFFFAFFFFF6FFFFF3FFFFEDFFFFEC
FFFFECE9E2D09E9286564734C3B391EEE0B9D8D3B5FFFFEDFFFEF8F7F1F1FFFEFFFFFEFF
FDFDFDFEFFFFF8FFFFECFFFFC9F3F10C444586C5CCDCFFFFF8FFFFFBF2EBFFFCFAFFF7F7
FFF9FBFFFCFAF7F5E8372F1C3E1B0892644D8957407B593DCED2AFE0EFCEFFFFEDFFFFF6
FFFDFFFFFCFFFFFDFFFFFDFFFFFEFFFFFEFFFFFEFFFEFFFAFCFFEAD9E5B7DBE7A7D0DD97
D0DA9E7C8159B1ADA2FFFEFBFEFFF2E6ECD0EBF6CCD5E4ABC0D68ED0EC98C5E68BC4E98C
C0E78EC6EC97BFE494D0F2A5CAE99DC7E295DDF5A7C4DB8DCAE097DFF2B2C9D7A2666E47
60624C0A06007A736DFFF9F8FFFCFBF2EAE7B3AFA6E4E4D8FFFFF4F5FBEDF9FFF6E1EFD5
CCE0ABCEE4A3D1E7A6C9DF9ED0E5A2D5E8A6A5B87697A864D6E7A3C4D591DBECA8C4D591
9DAE6A879854CCDD99D3E7A0CCE49AD6F0A6CBE79C607A30D1E29BDFF0A9CADE97D5E9A4
D4E9A6D0E3A3D0DEA38F9A6294A16C8C96649C9F72CBCBA7D7D9C3FCFDEBFAFCE4FCFDDD
E8E9C1E1E2B8BEBC969390656D6C33A3A564BABF7F8D946130351E2F3B27000B0091B087
B6EABA78B9834284477EBA7CC8F8BCC5E6ADC7D5A49CA370979E68D5E5A6BFE194CFFCA9
C3F2A1B8E499CAEAABCFEAA5CDE68BCFED8DD0F69FB1D686CFEBA0D6E89C9CA14FA7A653
9B9A488B8F439FAD6F8499606C884DA0B676DAE49DD7E6A3BFE7B2B4EEBB93D3972F6A2A
8EBC7CC2DEA3E1E8B5D5D0A69C96723734131211000E14000009000D1B00575435615733
4B440E585216605A1E5A54185852165B571A5E5A1D5A5619
D5DFABDAE4B0EBF3C4EFF6CAF9FFD8FAFFD9E4ECC3E7EFC6F0F7CDEFF5C9E2E5B8F2F1C3
EEE9BFF7EEC55A4C27635429DED49FDEDDA5DBE7B5FDFFE0FFFDECFFFAF4FFF9F9FEF8FA
FEFEFFF4F9FCF8FFFFEAFFFFB6F4F1428E8C7CC2CAD9FFFFF5FFFAFFFFF3F4F1EAFFFEFD
FFFDFFFFF4F8FFFBF82F190C44210D9D755BA27B5A674A28FBF2D3EAEED3FBFFF3F5FFF4
FCFFF8FDFFF9FFFEFFFFFDFFFFFBFFFFFBFFFFFCFFFFFFFDF9FEEAEDF7D4E4F2C1C7D69F
D7E4AFA2AB80E8EBCCFEFFE6F5FFDDCEE9B4C2DAA0D7EBACCADD9BD5E9A1C6DB90D8EEA3
CAE298D3EDA3D1ECA5CAE59ECCE69FD0E5A2CFE2A0D2E39DD0E298D9EAA3E0EEB3505C2E
6267490104007D7D73FFFDFAFFFEFBF8F7F3FDFEF8FFFFF8FAFDF6FCFFFAFBFFFBE2F1DC
CEE8B9CEEEAFC8E6A8C2DF9DD1EAA6D1E6A1D6E7A08D9D54E0EDA5D8E49CC9D48FE3EEA9
B6C17F535E1CD4E0A2D5E5A4D1E79ECCE999C9E8984A6312D3DB8EE3EA9DC5D686D7F09F
C5E496CCEAA0CFE3A4CBDCA5D0E6B5D2E3B7FFFFE3F8ECD4A0917CFFFDEAFFFCE9FDFBE4
FFFFE8E4EBCAD1DCB4D6DFB0D0DA9EECF3B0A7AC6A3A3D04919268B6B797474A2D32421D
C9F5BAAEE7A37EB6774E844A53815086AD7EC9EABBC7E5B1BCDA9C5877318DB262C7ED98
C9EC9CC5E59AD6EFAECCE39FDCF5A2CDEA90BEE089D2F69EC1E58DCAEE94C7E98BD0EF91
CEEB8FCCE891CCE796D0E89CABBF779CA9639CA25C717737A7BA83C8E4B1C7EDB2BEE5A6
CAEAABD0E8ACD5DFABD9E2B3D0E6B85F714B4D5031B2BD9D517A4E659A66A5CD99CEEBB3
CFE2A2D6E39ED8E7A2DFEEA9C5D690DDF1AAD1E5A0C6DA95
D4DBB1DBE4B9F7FFD3F7FFD4EFFFCAE9FCC4D7EBB0D7EBAEC8DA9CD3E3A5D7E2A6E6EEB3
DEDEA8D8D5A0615A26655E28ADA8708D9059637342CCD6B1FFF9E6FFF3EEFFFAF8FFFCFD
FFFEFFFCFFFFE8F1F6EAFFFFB8FAF62F7F7C70B9C0DBFFFFECFDF3FBFCEEFFFFFAFFFFFF
FFFDFFFFF8FEFFF2F12F140B3815017F5A3DB69471745735FFF0D1FFFFE6F2FEEAF5FFF1
F9FFEFFBFFF1FFFFFAFFFEFFFFFAFFFFFAFFFFFAFFFEFDFBFEFFF1F3FEDCEEFFD2CFE1AF
D2E3AF97A574DCE3B9E7F4C6CFEEB2CAEFAACCEBA8D3ECAACEE19FD6E5A2D8E7A4D4E39E
DDF1AAACC37B8DA76086A05989A05CA7BC79CEDE9FD9E9A8DAECA2C1D389C9D79C8F9B6D
777E5F0003008C8D85F7F7F5FFFFFDF9F9F7FEFFFAFEFFFBF9FBF6FAFFF9FBFFFDE8F6E5
D2EFC3C3E6ACC8E7ACC8E6A6D6F1AECFE6A0CDE1999FB165C9D78CE0ECA2D8E49CD7E19C
D1DC9A626C2DC2CC8FD7E6A5D0E79FC2E191C9EC9A6F8A39E2E69ADCDF92CFE18FD0ED9B
C7EC9CC7EBA1CDE5A7D1E5B0DDF8CBE1F5D0FFFFECF4E3D3AE9988FFF9E8FFFDEDFFFEEF
FEFFF1F0FAE2EDFBD8DAEABDDEE9B1CED69AE7EBAE9FA066949363B5B38C6B6A4E000900
517037C2ECACCEF7BDB6DEA98AB07F274D1E789E6DBADFABBFE3A66D8D4C799852B6D288
E2F9B1CCE19CCCDF9DD8EDA8C5DD93CEEB9BCEED9DC5E894C1E790D1FCA2CBF89DB3E083
C4EF95BDE48BC9E996CAE596D0E298D0DB96DAE19EBFC5875D662FD6E5AED0E8AACCE6A5
CAE3A2BED293E2EFB7C3D4A0C7E7B56984573B3C1CB3BD9A95C79264A66972AA6DB9E6A5
C6E7A0C1DD92C7E398C3E296C9E99DC0E295C8EA9ED7FCAF
C9E1AFCEE9B4F2FFD8F0FFD6DAFCC0D0F4B6C5E9A9C1E6A3CDF0AECFEFAEC8E5A5CDE5A7
CBDDA3DEEBB3CAD49FE4EBB8D9D7AEF2F2CEB1B8994749335F51487F6A69FFF9FBFFF6F9
FDF7F9FFFFFFF9FFFFEAFFFFBCF3EE39807C96D9DFD3FFFFF4FFFFFFFFFAFFFFFDF4F4F4
F6F1F5FFFCFDFFFAF651352A3F1A079C775CECC9A9583B19DFCFADF8F5D4E6EFD2E4F3D6
E2F1D4EAF6DEF7FAEFFEFEFCFFFCFFFFFCFFFFFCFFFCFDF5FAFFEBE4F4CDEBFFCCD2E7AE
CCDFA791A26CD7E0B3D4E4B3C5E5A6CBF0ABCAE9A5C5DE9AD3E7A2D7E8A2BACB84869750
7F954AC1DC8FD9F5AACBEA9ED3EFA5C5DF969BB06B80944FC9DA93E0F1ADCEDBA65B633C
6D715A0608004D4C4AFFFEFFFFFEFFFAFAFCFFFFFDFEFFFBFBFDF8FBFFFAFBFFFDF6FFF2
EDFFDFC9E7B1CDECB3C4E2A6CDEAAAC8E39ECBE29AC4DA9151661BC8DA90D1E198E0F0A9
D8E4A2C3CF8FB3BF81D1E1A2D3EDA6C2E296CDF2A4A4C073D6DC94DADD96D8EA9ECBEA9E
C6ECA1C2E5A1CEE5AFD8EBBEEAFFE0EEFFE6FFFFF3EAD9D17E6C60FFF6E9FFFEF3FEFBF2
FEFFF6B2BBAA8F9981B6C19FA1A87CD6DDAADEE1ACDBDBA9CFD0A4A4A681999C7F070D00
000900A9BE93CEE4B5CDE4B0D0E9B2859E671A3300657D4BD4EABCDAEDC0B4C5989AAA79
C9D89FCAD89AD0DF9AD2E39DCBE1A0CFE9A8D3F0ADC9E8A2BEE096BADF92C7EDA0D2F8AB
CFF4A7C7E99DD6F4AEC6E19ED7EDADD4E6AADAE7AFD5E0A8DBE6AC92A2643C530F77924B
D9F0A8D2E6A1CDD79ADCEAAFC5E2AA607645211D00989A73CBF6BEB2EDADB2E0A0C9F0AD
D6FBAECFF2A2C4E797C3E898D1F8A7C2EC9ABBE593C1EC9A
C5E6ADC3E6ACEAFFD3EAFFD4C7F1B1C1EEABBFECA7B8E5A0B9E6A1BDE6A4BFE3A3C5E4A8
C2DEA4C9E0A8DCF0BBE5F2C6F6F9DEF7F4E3FCFAEDB3ACA4A39594473436B3A0A2DACACB
FFF9F9FFFEFBF7FDF9EEFFFECAF4F0477F7C6EAEB0DCFFFFE9FBFDFEFFFFFEFFFFFEFEFE
FDF9F6FFFCF8FFF4EB462A1E3F1A08916B54F9D4B97457377E6E4ACAC6A0DFE7BECDDCB5
D6E4C0E7F4D6FBFFF2FFFFFAFFFEFFFFFDFFFFFFFBFEFFF4F1FEE0D1E4B7DBF2BACCE4A6
C7DD9F8FA069D5E1AFCDDEAACDEBADC8EBA7CAE7A4C7DE9AD1E5A0DBECA58A9C52506518
CEE698CCE999D2F1A1C3E493BBDA8CD9F5A8C9E1977A9048D7E8A49FAD70838C5D4E5534
666958010000737174FFFDFFFFFBFFFCFAFDFFFEFFFFFFFBFFFFFBFEFFFAFCFFFBF9FFF4
F4FFE4D9F3C3E1FCC9C6E1AACAE6A9C8E5A3C8E39ED5EFA6486219A4BC72CBE199D8ECA5
C5D594E2F0B28B965AC4D495D3ECA8CAEAA1CAF0A3C4E29898A25DE3E8A5CFE59DC5E49E
C5EAA5C3E5A9DDF0C3E5F5D1F1FFEDF4FFF2FFFEFAEEDFDCA89992FFFCF3EEE7E1C2C1BC
D6D8D3B9BEB7A2A89AC2C7B1AEAF90DEDEB8E6E5B9ECEBBFFDFED6A9AD8A9BA283313A1D
0B1400323D1DDCE8C0C2D2A3D4E7B0DDF2B99CB37B000C007C916ACDE1BEB7CBA87D8F69
9AAE7DB1C58AD5EAA5D1E8A0D2ECADCCE8ADC0DEA0CDEBABCFEEABCEEFAABFE09BC3E49D
BEDF98C2E39ED2F1AEC7E4A2CCE9A9CCE6A9C4DCA2D2E6ABC9D99BDAEAA986A057A4C075
ADC5796B7D33A6AF6CD6E2A4CAE4A74E602C524920B2AD85C3E4ABC1F2B1D6FABAC6E6A5
B9DC98C1E6A0BCE19CCAF2ABBFE9A1CDF8B0CDF8B0B9E79E
C8ECACBBE2A1D9FFBFD8FFBFBAE7A2BEEDA7C1F0AABBEAA4C1EEABC4EEACC8EEB1D2F3BA
D4F1BBD0EBB8E6FECEDCECC8FEFFF4FFFDFFFFF8FCFFF6FDFFFAFFFFF4F9B5A2A46C5857
BAA8A4FFF6EDFEFFF6F5FFFBD4EDE984ACAB1A525379AAAFC0D3DAFBFFFFF6FAFBFFFFFB
EFEDE1EFE6D7FFF5E6503323220000502A17FFE9D4E0C2A662502CE9E2B8DCE3B0CAD6A4
D0DDB2E7F2D0FEFFEFFFFFF6FEFAF7FCF8F7FDFDF5FEFFF1F9FFE4CEE2B1D3EBAFCBE4A3
C9DF9F8EA066D7E1ADD4E2ADD3EFB2C3E29FD5F0ADD7ECA9CFE09CDEEEA782944A899E51
BCD788D0F09DCAEC98C9EB97D6F5A5C4E191B8D082D4EAA1C1D192818B56D9E1B8070B00
070700010000767178FEF8FFFFFAFFFFFCFFFFFFFDFFFFFBFEFFF7F6F9F0F6F9EEFBFFF1
F8FFE6EDFFD5F5FFDDCFE7B5D0E9B0CCE8ABC3E09EC9E7A1C0DE98829D56D1EBA4C8DD9A
D7EAA8C6D4968E995DEAF8BBCBE1A0CFEEA8BFE79EC7E79E56611FE6EFB0C5DA99C6E4A4
C7E9ADCDE9B8F5FFE0F8FFE9F4FFF4F6FFF9FFFDFFFFF3F8FFFBF88980795F5A57BFBDBE
FFFFFFFCFCFCFFFFFDFFFFF6FFFEEC898268FFFFE1FFFFDEF3F3CFDFE5C1AAB5936B785A
5A644C030D00546440DBEEC1D0E7B3BBD69FCDEBB75B7B4C1F3F1A719372B3D5B4CBEDC8
C1E5B782A86F7FA663759A5490B371CBEBAACCECABC9E8A5B9D894DAF9B3CDECA6CFEFA6
C9E9A0CEF0A6CBECA5CDF1A9CAEEA8CEF3AEBFE49FCCECA9D9EEABC7DB96D6F2A7CCEB9B
CCE796A9BB6F737D36B0BB7991A7671E2B00716239D8CBA1CCE5ACB8DFA0C6E0A1CBE3A9
D4F1C1BCE0B4C2E5BBB5DAAE789F72446E40436D3D0B3706
CEEDAABEDE9BCFEFACCAEDA9BDE29DC5EDA7C5EEA8C4EBA8C6EDACC1E5A7BCDBA0BFDAA5
C7DFAFDBEEC1F8FFDDF9FFE8F3F8F2F4EEF8FFF8FFFFF8FFFEF3F9FFFDFBFFF0EBFFFAF1
5946388D8070FFFFF1F9FFF4F7FFFDEEFFFF9ACBCF4B7C81A4BBC1F9FFFFF9FFFBFEFFF4
DEDCC7E2D8BFFFFCE48266512903004C2418FFE7DA6C4D395F4A2DE5DCB3D0D09CEDF6C1
D1DCB1E8F2D0FEFFECFFFFF4FFFCF9FFFEFBFFFFF6FEFFEDFBFFE3CDDFADCFE5A7CEE4A3
D3E7A891A067DCE4B1F3FDCBF0FFCCC6E0A3D1E5A8D7E7A8D5E1A1D3DE9A96A35DCDDF95
E3FBADBDDA88BEDE8BD1F39FD1F19EDCF7A6DFF7A9C8DC94CAD89BC6D09EE9EFCBCCD0B9
010100060203665F67FFF8FFFFFCFFFFFDFFFFFDFAFEFEF4FCFEF0EBEEDDE1E5D4EBF0D9
FEFFE6FCFFE3FBFFDFCBDCAFC9E0ACC8E1A8C8E4A7CAE9A6D2F1AD718F49BBD490D3E8A5
DBEBACD5E1A39BA569C3CE92C9DE9DD2F0AAC0E69DC7E6A0566222D3DB9FCADE9FD0ECB1
C7E4AED0E7BBFEFFE8FEFFEFF7FFF8F4FDF8FFFBFFFFF9FFFFF9F7FCF3EEFFFEFBFFFEFF
F6F1F7FEF9FFFFFCFFFFF8F8FFFBF44E3E2FFFFAE2FFFFE3F7F7D5EEF4CED0DCB693A17D
D7E1C6020C000008005F714BEAFFD6B7D2A5DFFED4BBE0B5B5DBB4638D674C79527BA87D
B5E5B5B9EAB3B7E9AE8DBD81315D228BB47ABAE1A8CDF3B8C4E8ABCAECB0B6D89BBEE0A3
CBEEAEC5ECABB3DB9CBBE8A7B9EAA8B5E9A7C0F7B4C2F0AFBEDB99E2F9B5CAEA9FAFD081
CCE999E9FFB2CFDA9597A260DEF2B587915C927F57C5B38DE6F7C3CEEBB182945A596734
415A33000D000014001C3E1B5C805C5F835DC3E9C2BBE1B8
D6E6A5CDDD9CD5E5A4CEE19FCDE29FD3E9A8CCE2A1D0E6A6D3E9ABDFF2BAE9F7C4ECF8CA
EBF3CAF9FFD9F9FDDAFEFFE9FCFFFBF7F4FBFFF6FFFFE9F1FFFEFAF4F4E8FFFBEBFFFAE6
E5D1B97F6F56E9E4CEF9F7E8FFFEFBF7FFFFC5F0F64475798DA6AAEFFBF7F7FFF2FCFFEA
D4D3B4DDD3B0F8E3C66445301D000059322DF9D3D0533229EBD5C0FFF9D6E1DDADE7E9B7
E8EDC5F6F9DEFFFFEFFFFFF6FFFCFBFFFDFBFFFFF6FDFFEAFAFFDFCEDCABCEE0A4D0E3A3
D8E6A9879059D6D8A9FFFFD8FBFFD6DCEDB7D4E1ABD1DAA3DBE0A89CA2669AA362DAE7A2
C9DD95E0F8ACD5F1A4BFDC8CC4DF90CBE395CADF94D1E29CDFEAAEDBE5B3DDE3BF595D46
18180E0D090A655E65FFFCFFFFFCFFFFFEFBFFFDF4FEFFEDFEFFEBE8ECD1D5DCBDDFE4C4
F9FADBFFFFE3FDFFDED8E0B7D8E8B9C8DCA7D1EAB0CDE9ACB3D08E93AE6B9CB271D6E9A9
C4D295DAE4A894995F545C20D4E3A2D3EAA4C8EAA0CCEAA297A1629FA569D5E7A9D1E9AF
CBE2AECFDEB5FFFFE8FFFDECFAFFF5F7FCF8FFF7FEFFF9FFFFF5F2FFFDF6FFFDFAF9F1EF
FFFCFFFFFBFFFFF0F5FFF9FBFFF8F5654F44EDDBC7FFFDE2FFFFDFCED3AACFDCAE8C9C6F
CBD3ACC1C7A52F351900060086957ED9EDD4A2BFA3CCEECDC4EDC383B18272A26E588A55
568B57659B6A79AE82659C727EB58E73AA8354886230603A54815A5F89637DA67E98C199
81AB8384B38987BC8E83BE8E86C99663AB79ACF9C5AAEBB5CFF6BDB9D799CAEFA9CAF0A7
CEF0A4D4EEA5B9C887C0CB8F3C511880895A8E77579A83649EA97F8FA5748B9465939A6E
44562C0A2300041D00678257BFDCB0B5D2A4CEEEBDC4E4B3
DAE0A0D9E09DDCE5A4D5DE9DDAE5A3DBE7A7CDD999D5E1A3CFDAA0EAF3BCFFFFD5FFFFD8
FDFDD7FFFFDFFBF6D6FFFFE8F3FBEEFDFEF9F9E3E5FFE9E5FAFBE9FEFFEAFFFFE2EEE1BF
ECDAB6A797758C8366D1C8B7E6D4D4FAF9FF6E949D1041459FBCB7DAECDCD5E2C8BEC5A3
9B9970B5A97FB39C7A2203002100001B0000613D41674949F4DED1E7D9BFFDF6CCEEEBC0
ECEBCCEFEDD8F0E8DDEBE0DEEFE0E5F0E4E6E2D9D4CBCAB8FBFFDFD5E1B1D3E2A9D2E0A3
D4DDA4747644C0BD92FFFFDCFFFFDAF5FED1F3F6C9DCDEADDBD9A858582295995ED9E2A3
D6E5A2C9DD96CAE199D5EDA3D6ECA3D5E9A1DAE7A1D9E5A3CDD89CDBE5B3D7DDB7CFD3BA
323226030000686266FFFBFFFFFBF8FFFFF6FFFFEDFFFFE8FFFFE3EBF1CBD4DCB3E0E5BD
E2DDBDFFFFE3FFFFE1FBFDD8FEFFDCD4E4B3D3E6AFC1D99DDAF2B4C0D99897AB6CCCDC9D
E3EDB1D8DDA3CBCC935D6126DDE6A5CEDF99CEEAA0CFE9A0D5DB9B666A2DD8E6A8C6DA9F
D4E5B1D2DAB1FFFFE4FFFBE9FFFFF3FFFFF8FFF9FAFFF9FAFFFBF4FFF8ECFFFDF4FFFDF6
FFFCF8FFFAFAFFF9FAFFF8F8FFF6F35E433AFFE6D5FFFBDFFFFFDCD8DBACD1DEA89BA571
A2A175FFFEDCAAA48A4744310101000003007A8976C3DABECEEAC2B0D5A2CFF6BFBDE8B2
B6E2B1A8D5AC87B392628D7186AF9192B99C779C7D001200001100000A0023371C3A4E33
60775B718E6F8EB1906D997560946D0D481C82C3987BB686BDE5B3C7EAB2BCE6A7C7F1AF
BFE7A1C4E3A0E3F5BBC9DAA4D1E9B7D5E0B6816B53AF9680CFD9B7ABBD977D815C33350E
818C628D9D70546538BFD1A1D8ECBBDCF3BFBDD49ED7EEB6
939554A3A663A2A7659CA15FB0B774CED494C4CA8AA1A7699FA46ABDC28ACBCD9CC4C395
CECAA4E8E2BEE7E1BFCBCAABE3F0D4DBE3CBE3D2C0E7D5BFE1E7C3E0EDC1DEE2B0D8D5A2
BEB282B6A57A60513072614FC9B0B3DCD6E25379840C3F407EA08FB0C8A8AEBE979EA677
92905F6E6232725C376C50381B000023000496757EB799A1C6B1AEF5E5D6F3E9CEEBE4C7
EBE3CEE4DACEE9DBD8F0DFE5F4E0EBF5E4ECE7DBDBCFC9BDCCCCB0D0D7AD8F99659CA56E
939563747144ACA27ED1C9A5EAE7C4D0D2ABD7D3ADBBB68EAEA77D564F21969360C9CC95
949E619FAE6DA3B3729CAF6D7E8D4C99A565C7CD8F999F6196A063929C67989F758D9274
2F30200101004E4A47EDE9E6C2BFB6EDECDAEDEDD3E3E7C2A1A87C9FA774B5BF8AA8AF7C
A09874AEA383A89F7EB9B791ADB0858D9765919E6986985E97A96D92A46669773A97A165
A1A76B8C8D53A09F6659591D969755A6B069A1B76CD8EDA2D6DB98424403D8E4A2D0E0A1
D5E0A8DADCADFFF8D7FFFDE4FDFBE4FFFDECFFFBF3CDB9B2BBAB9CFFFDECFFFEECFFFDED
FFF3E6FFFCEFFFF9F1FFF8EFFFF4EA735648FFF4DFFFFCDDFFFACFE7E7B1D4DEA19C9F66
927F55FFF9DDFFE6D1D0B9AB0F000017080107000063634BD7DDBBD9E6BBC9D9AAD0E3B5
D0E5BCC4D9B8C8DBC5DBE8D4DFE2C7D6D3B4DCD5B8160B002F1E04341F048A7258BEA68C
E9D4B9E3D2B6E7DCBED2CFACCDD5AEA1B08574895E27421599BA8FBCE3B6C0F0BCBDEFB4
B6E2A5C7EAB0C0D7A3D4EABBC8E5B9D4E3C2867062897366868E774454391A1C046D694C
D1D2AA888B5C7A8050D9E0ADD4DCA9DDE7B2CDD8A0D4E2A7
CED591D9E09CD3DD98C3CD88C4CF8BCFDA96C3CE8AA8B371BDC78ACFD79CD1D8A2C5C997
C9CC9FDEDFB5E2E3BBD0D7AED4EABCD4E3B8E1D7B3E3D7AFD9E3AFD3E7AAD3E2A1D3DC9B
D9D49AFEF0BF75633F917B66FFF6F8FFFCFF83ABB53F777484AD8FD4EFC2D1E5B2C5CE99
E5E2AD897D4DFDE7C2A5897325060158393EFFE6F2FFF6FFFFF0F4FFFAF4FFFEEFFFFEED
FFFDF1FFF9F3FFF9FDFFF8FFFFF6FFFFF8FFFFFAFDFAF3E9F7F7DBDEE5BBD9E1AECED59F
D4D4A2625E31BDAF8CFFFFDFFFFFE1FDFAD7FAF4D2DFD7B2D1C8A16E653A8E8A5BE2E2AE
D3DBA2E6F1B5D2E0A3CCDA9DE5EFB3D2D79DCFD097DFE3A8D2DC9DD7E2A8DBE4B5C5CBA9
2A2D1808080065625DF5F2EBFFFFF3E2E4CEE5E9C6CDD4A8DCE5B0C4CF93D1DD9DCCD499
B7B2886A603C918964A4A1788485598D9461EEF7C2D9E4ACD1DFA4D3DEA2555F236A7236
D9DDA2DCDDA3D5D49BC3C184B9B673DDDE98B7C97DA5B76BAEB16C565713C4CF8B778643
939D61A9A7745F4C246E5B3B7572538685697A6D5A8C7B69675740908268B8AC92C2B79B
BFB399D0C2A8BEAC94BAA48D937664856953DEC4A98B7752B4AA7979793D78823D595B1C
957E55AF8B71D8B8A1D6B7A38B7160B09B884C3D263D331807020037371372774F4F552F
080F004047285D624B57573F2218003423076A553A7D634A93755D75523C7A5441BE9885
A07B68AB8B767359407B6A4E8F866583805DE6EAC596A48012300C557F577FB08187BC86
7FAE7794BB86809A6B6F885E516F4959694E200E020F00000B14031A2C16ADAE9CE0DAC2
A7A27CBCB98CB3B181CCCB9BBEC08ECDD19EADB27CAEB37B
CAE098D5EBA3D8EEA5D1E79ED1E79ED7EDA4D6ECA3CCE29ACFE49FD4E9A6D0E4A5C4D89B
C4D79FD1E2ACD5E6B2CEE3ABC7E5A7CDE5A7DEDFA6DFDDA4D1E09FCBE29ACAE598CFE59A
D8DF9BDFD8A1634B258D715CFFEEEDFFFEFF6E9AA3518E8683B085C6E8ACCCE1A6E0E9B0
E9E6B185764BFFFCDCA58A7723060251363BFFF7FFFFF8FFFFF9FFFFF8FCFFFCFAFFF9F5
FFFAF7FFF9F9FFF8FFFFF7FFFFF0FFFFF7FFFFFBFFFFFEF4FFFFE5D0D9AEE6F0BCD9E0AA
E5E5B35A5629AA9C79FFFCDCFDF8D8F9F6D3F7F3D0EAE2BDDDD5AE615A2E737141D9DBA9
D8DFA9CED99FCCDA9FDDE8AECBD39AE4E7B0DFDEA8E6E7AECED997DAE8AACDD9A7727A55
2F331C0002006D6D65FFFFF6FFFFEFD5D8BDE0E5BDD7DFACC3CE92E5F4AFE0F0A7D9E6A1
979763A19E71EDEABDF0EFBFA6A8767276439BA26CD0D89FD4DDA4EAF4B85F672C646C30
E6ECB0E5E9ACD5D99CE8E8AAABA362DDDA95D6E499C4D489CED18A7F823DDAE79FA7B671
DDE8A6DFDEA5614F21B1A075A3A178CACCA4C2BC9AE1D4B4BEB191978A6ACEC4A0D1C9A2
CEC99FDBD4AAD4C8A0CFC19C735F3EDFCBAAC8B48FA8996EBCB57F909251B3BD74999E5C
D2C29EAA9077C3AC8D7F6D47796A3F8D8255C0B98DB3B087110E000403000A0A00080B00
0104001C20000305000D0E000104001D1D0529240E322A17241706342415402C21766257
725E55837268695D4F958F7FA3A492919984919D85A1B59A2544254F79552051240C410D
24551E1C440F031F003A552A1A3A1336492D3D2C223B28223D483890A18FD1D2C4B6AF9C
4F4625A59E749D966C8C875D8B885BA1A0727D7C4C828453
C6E49CCBE99FCDEBA1CBEA9EC8E79BC8E79BCAE99DCBEA9EC8E69CCAE89ECAE8A0C9E7A1
C9E6A4CBE8A8CAE6A9C8E7A4C4E8A0CBE99FDAE5A1DCE39FD3E39ACBE697C6EC97CBEE9A
CEE096E5E3A88D714A6C4936FFF8F4F5FAFED7FFFF0016052B5D28C8EDA8C4DC9EC7D099
302900AD9B77FFFBE3C7AB9D29100B3C2726FFF1F4FCEFF6FFFBFFFFF8FFFFFCFFFEF3F7
FFFCFDFFF9FDFFF9FFFFF8FFFFF0FFFFF7FFFFFCFDFFFFF3FEFFE4D4E2B1CEDDA4D9E4A8
DBE0A88C8A59A1986FE8DEBAE1E1BBE4E6BFF1F2CAF9F7CEF0EDC05352228D8F5DDAE1AB
D4DFA5D8E7ACD4E4A6DEECAF8C955C9CA16992915BDBDCA3D6E2A0D8E8A7C7D5A2606A45
2227100002006A6B63FCFEF3FFFFEFEDF2D4D7DEB5E6F0BBD8E7A6CEDF9876893A55671D
D8E2A5E4EBB5C1C990D2DAA1E1E6AEE3E8B0A1A66CE4E9AFD1D99EE2EAAE8B9558959F60
D8E2A3D0DA9BD2DE9ED5DB9B9F9758D1CE8BE1F1A8DFF1A7E0E7A1848A44D3E59BD8ECA4
DAE7A2D5D69A62521EEBDDACCDD29CE6F0BCE7EABBF5F2C7FFFFDCA19773DDD9ACD3D3A1
CED19AD6D9A0D9DAA1D9D8A2C9C393D2CA9CDED6A8F4EEBCDDDCA3D3D896EAF6AAD5E09C
E5E2B9C2B998C4C093DEDDA7D3D596DAE19E787E40CCD39DCDD4A84248262C3015000400
040700121600373A0D232900141E000007000006000004000B0D000402000C0700413A2A
070000070100030100070A000005002F3B25D2E1CAC6DABFBDDABBC6ECC5B0E0B092C58D
71A167B0D79ECAE7B194AE7EC1E2B7CDE0C0988879A8968CF9FFF1E8FAE4FDFEEC5D573D
AAA77CE2E0ADD5D3A0D0D09CDCDFA8EAEFB7D0D59BE4E9AF
C9EDA5C6EAA0C5E99FC5EA9DC4E99BC1E698C1E696C3E898C2E797C1E696C4E99BC8EDA0
C9EEA1C7EBA1C5E9A1C5EBA0C4ED9EC9EC9CD1E79CD5E59CD5E79DCFEA9DC1F19BC1F19B
D0EFA3D3D79AAD8F69B08B78F3E2DAF5FFFFD5FFFF3B816995CB91B9DE98E1F9BDBDC596
716847B8A48CFFF9EAB0958C2B170E392A23FFFDF6FFFFFAFFFEFFF9F4F8FFFDFFFFFAFF
FFFDFFFFFCFFFFFBFFFFFAFFFFF8FFFFFCFFFFFFFBF5FDE8F0FFD7D9EEB6C8DF9BD8EEA6
D1DD9B9FA569A29F6CD9D7A7D8E0AFD6E2B0E9F3C1FBFFD0F1F8C24C541BC5CF93DEECAF
D4E7A7CDE3A2C9DF9E859A59566427CDD79BC2C58C494F13DDECABCFE2A2DAEAB9D2DEBA
000500000300767972F3F6EDF1F4E3F5FBDFD5DDB6C2CF9ADAEAAB81954D8FA455DEF5A7
C6DD95D0E7A3D2E7A4E4F4B3C7D695D1DB9C8E9758939C5DDEE7A8D4DE9F909C5C9DAC69
CDDE9AD0E5A0DAF1ABCEDD9AA6A265E1DFA2DBECA6BED58DCEDB9593A05AD0E89ECAE49B
C6DA93D7E09F675E25DFD99FDAE8AACAE0A0CBDA9FE7EEBAFFFFDA948F67E1E3B1DAE4A8
D7E6A1D9EAA3D6E7A0D5E49FDEE8AB50551DDDE2ACD0D59DDAE2A6D7E29ECEE094D2E69F
CCDFA8BDCF9DC9DFA1D9F0A8BCD786CAE692E2FDAE48621BDFF4BBCADDAF57663F9BA783
424D252D3609000900919C64192A005F723AD6E7B1D2E0ADD8E4B6D1DAAFD5DBB5EEF2CF
CED2B1C5C8A95F62432D33117A815F0007000008005F6F4AD0E6BFCCEBBFBFE7B2CBF9BB
ACD694BADF9CD6F0B1C5DEA4C4E5B0DBEDC3E2D2B9FFFCE8F9FFE6F3FFE4A0A086615F38
DAE0A0DBE698CFDA8CD8E596D7E596D6E797CBDC8CD7EA99
C5E6A1C2E39CC3E49DC6E89ECAECA0CBEE9ECDF09ECFF2A0CBEE9AC8EB97C6E997C5EB98
C5EA9AC4EB9AC6ED9EC9F09FC5EF9DC4EB9AC7E69ACEE69CD5E69FCFEBA0BBF29EB5F19B
C0E99BE1EBAE6745207E5541FCF0E2E7FFF2CAFFFC317C5E589053BDE59FD6EDB7C9CFA9
493D27BBA59AFFF7F3C4ABA62D1B11251C0DFFFFF0FFFFF3FEFFFAF2F2F2FFFDFFFFFDFF
FFFEFFFAF8F9FBF8FFFDFAFFFBF8FFFDFEFFF6FEF3E1F1D6CFE7B7C5E3A3CAEA9ECCE999
C7DC9173803B9A9E63D4DCA3D0E2A8C9DEA3D1E5AADBEDB1D5E3A5516120D7EAA8CCE39D
C2DD96D2F0A8CBE9A18AA45DD6E9A7D3E2A1C2C88CA3AB6FD1E1A0C2D699D0E2B2DBE9C6
000500020800727771F7FCF5FEFFF4EAF2DACFD9B4D3E1AEB5C78997AD65C7DE90CCE798
CFF2A2BDE294D4F4A8CCE89DD0E69ED8E9A3C6D38E919C5AD0DB99D5E19F8998558A9E59
CAE49DCBE9A1C6E69DD1E8A28F8E55E3E2A9D5EAA9C0DB96D7EAA89FB36ED2F0A8CBEBA2
D5EFA6D8E7A2888649E3E5A6D9F0AABEDE95D4EFAAD4E6AAE0E3B687885ED8E1AAD0E19D
CDE899CCEC97C8E893CAEA97BCD38B647737AEBD82C8D69BDCECAECCE09BD4EA9FD3EDA3
CBEAA6CDEDAAC9EBA1D9FCACCBEE9ACBED99B9D888C7E3984059178EA267B0BE89DBE5B3
D8DEAEE0E3B4D8DAA8D4DBA5D0E3A3BED795C7DD9DCADEA1D2E3ACDBECB8D5E1B3DDE8BD
FEFFDDEFF7D0F4FAD4F0F6D0D2D8B2989F761920003E491F293A0DCAE5B0C3E7A9B2DB95
DCFFB7E1FFB5C2D991CEE5A1C4E4A3D2E4B0ECD9B8FFF8DBC9D4AC96A77DE4E4C0D0CF9F
DAE79FD0E691D4EA95D8F09AC9E38CC9E58ECDE992C9E78F
D0EAA9D1ECA9D0EBA6CDE8A1CBE59CCAE598CAE596C9E493D0ED99CFEC98CCE995C6E691
C6E691C8EA94CAEC98CAED9BC4ED9EC3EC9EC4EA9FC9E79FD3E3A2CDE8A1B5F3A0AFF39E
BEEEA2CEDC9F64401EC19781EDE8D5A3C2B0286D5A4D9A78BBF6B6CDF4B1C1D7A8ADB294
62544BB39B9BFFF6F8EDD5D33B2B1E130C00E0E2CAF3FBE3FBFFF3FCFFFBFEFFFFFEFFFF
FCFFFFF9FFFBFCFFFFFCFFFFFCFFFFF9FFFFF5FFF4E0FAD5C1E2A9C7EDA4CBF39DC4EB92
CEEC966E8535AFBC76DBEAA7CDE8A3CCEBA5C8E6A0C8E39CCEE59D89A359D4F0A5C5E496
C7EA9AC0E595C2E7999DBD71DAF4ABD6EAA3D6E19F808C4CD1E6A5D7ECB1D2E3B6B7C5A4
0914030003005F6563F6FCF8F9FFF5E1EAD5D0DCB8B8C899596B319FB471DCF4AABCDD8E
BBE893C4F69DCAF6A1B6DC89D9F5A8CBE196C2D38C94A15CCEDB96DCEBA696AA6391AB62
CDEDA2C9EEA1B9E495CFEEA86D7039D9DCA7D0E8ACCEEEADDAF3B2839C5AB5DA94BFE79E
CBEBA2C9DE998B904ECED794C8E89DBEE799D6FBAEC3DE9BBAC39492996DD8E7AEC8E299
C4E891C3EF90BFEC8DCAF59BBFE494CEEDA792AC6DD5EDB1D3E9ABC3DC9AD4F0A6C4E395
C4E692CBED99C4E596B0CF83D8F6ACB2CC85E1F8B0D8ECA4D1E198E7F1A8DAE09AD3D292
F2EBB5E2D5A8A69672958E64A1B075D3EEABCAE3A2D4ECB0CFE4ACD0E4B1C8D8AB7A8960
7C88622F3916030A00BCC2A0CDD1B0DCDDBD7A7B5B010600717B49D2E6A9CAE8A0CBEE9E
C3E58FBDD984CDE08FDEF3A4DCFBAFBCCC8DC4AF82CCB58CAEB685D9EAB6DAD9ABDFDFAB
C8DC95C6E597CDEC9ECAEB9CC6E999C8ED9DCDF2A4C9F0A1
C4DD9BCDE6A2D1EAA6CDE7A0CCE39BCFE79BD3EB9DD4ED9CC9E493CDE995CDEA96CAE793
CAE793CBEB96CAEA97C5E695C9EB9EC7EDA0C6EFA3C8ECA2CFE6A0C9E7A1BAF0A5B6F3A6
BFEDA2D2E0A27A572FB28D72D3D8C45D877341876B9DE6BBB4E4A6C7E4A4D2E2B5939679
6E6158E2CECDFFF9F8DFCAC734261B0C0400E0DEC7FFFFECFEFFF3FEFFFBF8F9FDFBFCFF
FBFFFFF8FEFAFBFFFFFBFFFFF9FEFFF8FFFBF4FFF0E2FDD4C3E5A8D5FAACBEE48DC2E68C
D4F09C94AA5FCBD99BD6E5AAC8E0A2D3F0B0CAE7A4C4E29CD4F2A8C4E397C9EA9BC6E999
BFE494D0F5A5C6EB9DC0E094BEDA8FD9F1A7D5E9A1768A45ACC282CADEA9D3E3BFD7E3CB
000500000400656968FEFFFDF8FEF2EBF4D9D3E0B48C9F67AABF86CEE7A6CCEAA2C8EB9B
B8E48DCDFBA1BEEA93C1EB97C7ED9ACCEB9DD6EEA4B5C982DDECA7CDDC978E9F5991A75F
C1DF95CAF0A3C3F09FC1E3995D6029DEDEAAC5E1A4BDE29FCFECAA8AA463C9EAA5CBEFA7
B9DD93E5FCB67E7E3E9D9F5ED1EDA3C9F2A3B7E092D3F2AC8F9964929A67D6E8ACC8E69E
C3ED9BC3F199B6E78EC3F09BC8F1A2C1E399A4BF7CB0C988C7E09FD3ECABCBE6A3CEEAA0
D5EE9BC7E08CD3EFA2CDEBA3CDE7A8DDF1B4CDDB9ED4DD9CE2EAA1C8CF82D8DF91A4AA60
909052A09A689F916CA69E779FA86FB3C58799AA74D7E7B6CCDCAD5E6E41738354374416
1B2800646F4529300E293011DFE4C6DCDFC25E61422025005C6530D8E8A7CCE69DC6E595
D3EF9BD6EE98D5E491D2E091C1DC8DE2EFAAE4D09DAB9667CFDCA4D3E8ADD0D7A1D9E1A8
D3ECABCFEFACC5E5A2BFDF9CCFF0ABCAE9A5C4E19ECBE8A5
CAE89ECAE89ECAE89ECAE89ECAE99DCAE99DCAE99BCAE99BCAE99BCAE99BCAE99BCAE99B
CAE99BC9EA9BC9EA9BCAE99BD3EDA4CCEAA0C2EB9DBFEA9AC4EA97C7E99DC5E7ABC3E6AC
C3E79DD6E39B84652EDFC19DDBF0E144786B79BA98BAF2C1C7E0A6E1E9AED7DAAB9F9F7B
5A543CFFF7E8FFFCF3DCCEC541302637261CCFC1B6FFFCF3FFFBF6FFFDFDFFFDFFFFFEFF
FFFFFFFDFFFEFEFFFFFEFFFFF8FDFFF9FFFAF7FFECE1F7C9CAE3A2D0EB9ED7F09CBED583
D9EAA4ABB67ED1D8AFF1F7D5EDF7D2E7F4C8D8EAB6C9E1A581A05CC7E99DBCE193C8ED9F
C5E79ACEEEA2C7E59BA0BC72D4F0A3C9E696D3F09ECEEA9DB8D092D1E4B7DBE6D5F3FBF0
35392800020075726DFEFBF6FFFFEFE2E8C2DAEAA98AA057CDE6ACCEEDB1C4EAA1C4E99B
CCE997D1EE9ACBEE9AC5EF9BB4E190DAFFB6BDE1978FAA63D9E8A5D7E09F9AA0609EA965
C8DE96C8EA9DC5F29FC6E69A5C5A1FE5E0A8BCDB97C3EDA3D0EFA996AD69CEE19FCAE19B
C3E79DD5ECA69D8E55A5945CE4F3B0C3E599C0E49AD0ECA2929B588F9454E5F5B6D0EAA9
B9DD9DC8F2B0C6F1ACBCE69ECFF1A7C8E299CEE29A67783294A463D5E9AAD6EBB0A6BA7D
8A944FBECA82CCE39FD2EFAFC9E2ABD3E4B0E2E4B3D1CE998180408A914BB2C97BCAE99B
CAEAA1CEE6A8D2DBACD7DAADADAD79323200211E0027260A1212005C603BC5CE99E4F0B0
D4E3A0CBD99CE2EFC3707B596D775CA3AD92A0AC88303C0EC6D199CFDFA0CDE7A0D5EFA6
BCD289D8E89DE0E89FDBE59CC5DB909BA8638B7A42A49762C9DF9FBCDF9DDCF1B6CCDFA7
D0EDB5C8E6B0C6E3ADBED7A0D1E4ADD7E4AED6DDA7959863
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCCE89DCEE49CCBE59CC0EB9BBFEC99C5EB94C8E89CCBE3AFCBE3B1
DEF9B4A9B56B8E7938ECDBB0DBF7EB1C51476FAB87BFEEBADFECB4CDCA93EDEBBB86845D
504F31FFFFECF9F2E2B4A79E170600170400BCA7A2FFF5F1FFF9F9FFFCFFFFFDFFFFFDFF
FFFEFFFFFDFEFFFEFFFEFFFFF9FDFFFBFFFAF8FFEBE4F5C9D3E7A8D0E59AC5D887E6F6AB
ACB77BD4DBAFD0D3B8FEFFEDFCFBE6F6FBDDEAF6CED6EAB58AA868C9EDA5C0E598CAEFA1
C2E297CDE99FC8E29B8EA85FCAE699C4E491C8EA94C7E899BBD397CDDBB7FBFFF8F4F6F3
2D301F030200605B55FFFFF6F3F3DBEEF6C7D8EA9E87A04DD3EFB2B2D498BBE39CD4F6A9
C5DA8BD4E798C5E292C9F09FC6F5A4BCEB9BC3E9A0829D58E0ECACD1D5988A8A4C9A9F5D
D5E49FCEEA9DC1EC9ACCEB9D534D0FE8E2A6CFEFA6C0EC9FCAECA2D3EAA4C9D492E5F4B1
CAECA2D1E8A298834C7E652FC6CF8ECDEBA3C8EAA0CAE49B989E56B1B26EBCC888D1E6AB
CDEEB7C0E5AFD0F6BDC2E4A7C9E4A1CFE59DDCE9A18A964E7E8A48D6E6A8B6C992B5C48D
A8AA6B9A9F5D98AC6D8FAB70CFE7B3D1E1B2B3B284A8A071948F55F4FDBAC3DF92578031
527E335A813E586F3979815282804F716A408E866F8A8371645F4C7B7A5BB4BC83DBE6A1
D7E598DAE9A4D0DEABA6B58E313E202E3D1C55663A000C00E0EEB3C2D293EAFFBDBDD790
E4FAB2DDEAA5C9CE8BD8DF99A1B76E56631D5D4E159C9159DDF6B4CAF2ACC5DFA2CCE1A9
C8DEADDBEEC0F4FFD6D8E6B5D9DFAFA7A6769E9868625A29
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCAE99DCDE49CCAE89EC2F1A0C5F29FD0EC98D1E79ECBE6B1CBE6B3
BED392818B44B8B06FC8C799D9F8E9093B3078B08DB6E2B1CCD6A2E7E1B1B1AC8244411E
716F56C4BFAC71695C0A0000150400170400B6A39DFFFAF6FFFBFAFFFBFCFDFBFFFDFCFF
FFFEFFFFFDFEFFFEFFFEFFFFF9FDFFFBFFFAF8FFECE5F4CBD7E9ADCCE099D2E49AB5C47F
727C47EDF4CBF6F8E2FDFBECFFFFF1FFFFEDFAFFE2E0F1C495AE74CEEDA9C4E69ACCEEA1
C7E69AD2EEA3CEE89F819B52C7E396CBEA9AC6E995CCEB9FB7C891E9F0CEFFFFF8FFFFFD
0102000B0C00625F56EEEEE2F0F4D9DAE4B23B5001CBE491DAF4B5D0EEB2C3E79FBFDE90
E1F1A6DCEA9DD5ED9FC9EA9BBDE697BEE799C2E39C9FB672D7E0A1EBEBAFA3A1649F9F5F
D9E4A0D5EDA1C2E797C8E497655F21DAD699CEECA4C4EEA2BEE096CEE59F626D2BCDD997
C9EBA1D3EAA4AD9A625F4812A2AB6AD3EEA7CBEBA2CAE1999697539F9B5BD1D79BD8E7B0
677F4B567440BBD9A3DBF8BED2E8A8DCEDA9D2DF99CBD6919EAA68ADBD7FAEC189D8E7AE
D3DA97D3DD98ACC28198B4798CA56EA9B9889FA172E1DEAB817F465A6320405C1153792C
527C347A9E5ECCE0ADD0D9ACDADBAFE1DFB9EDE8D4E4E1D2E6E5D1DCDFC0B1BA839BA863
809045808F4AA6B57ED5E2B686926C000A0053642EA1B075DFEAAEE0EEB07D9450AFC982
BAD08893A45E88924D7D8843C5DD93D3E39CDACB92D4C790D1E7A6BADD99CFE4A9DCE6B1
FFFFD1F9FBCADDDCAC7272405E5A2A474411B3AD79EBE5B1
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCAE99DCDE99FCBEDA1C3F4A2C5F29FD5E698D6E19CCCE5AECBE6B3
DAEAAC596221D1DA99D0E0AFC3E5D400110475A985C2E8B9D7DDB1A2997056502C858063
FEF9E5716B5D070000110400301F182D1A13B9A6A0FFFBF6FFFCFAFFFBFBFEFDFFFEFFFF
FFFFFFFFFDFEFFFEFFFEFFFFFBFCFEFCFFFBFAFFEEE5F3CFD6E7B1CADA9BE3F2AF8F9D5F
78804FFBFFDFFFFFEFFDFAF1FFFEF8FFFFF4FEFFEAE2F1CA99B07ACCE9A7C5E59CCAE99D
CEEA9FD7F1A7D3EBA1859D53CCE69CD5F4A6C6E997D2EEA49CA672FFFFE1F4F1EAFCF8F5
171506010200606257E5E9DACCD5B686945FDDF4A4C0D986D3EEABB6D295E5FFBCCDE89B
D3DF95DAE49BC3D88DD4F0A5CAECA0D3F5A9C8E39C92A563CDD395E6E4A79C965A949353
D6E09BD4E8A0C4E596D6EEA2625E1FCCCA8DCAE8A0C6F0A4CAECA2D0E7A13C4504D4E09E
C2E49AD7F1AAD7C88F66511A939C5BCFE9A2C5E59CD3E9A1A1A05F9C9255E8E7AF88915C
081A00000C00001500516830D4E8ABD4E3A2D6E19DD5E09CD8E4A2D5E5A7C9DCA4C1D397
D6DF9CDFEAA5BFD894BCDA9AD9F5BBD1E3AFD7DBA90D0B00232400D8E3A1E2FCB3B9DD93
CCF1ACC7E6AAD0E4B3DAE5BACFD6ACE2E6C3F6FAE3F9FCEBFFFFEDFEFFE4E1EBB6CEDD9A
DFEFA8A9B8739FAE75DDEBBAC4D1A3D9E7B4D5E5A7CDDC99D2DE9EDEEDAC435A14D6F1AA
D0EAA1C7DB94DEEBA5C6D68FD1EDA2C9DA948E7F46A3965FC8DD9CC0DF9CF4FFC8FFFFD1
6D6A35635C285E5723736C36D1CC95DCD7A0F0EDB6E0DFA7
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC8E89DC4EA9DBBEF9CC1EB99D8DE94DBDB9BCCE3ABCAE5B0
D0DBA3495317CCE6A5CBF0BC4A715C1A4534D6FFDFEEFFE3FFFFDF6E6141AAA085FFFFEA
F8F2E4332C220B02008679732F2019291811A7968FFFFBF6FFFAF5FFFCF9FEFFFFFCFFFF
FFFFFDFFFEFCFFFFFFFEFFFFFBFCFEFCFFFBFAFFF0E7F2D2D8E5B7C9D89FD6E4A9B7C48E
BDC49BFFFFE8EFF0E2FFFFFAFFF8FBFFFCFAFFFFF1DFE8C99DAF7FCDE5A7CAE59ECCE79A
CDE599D3E99EC7DD9493A960CCE69CD4F3A7C2E497CDE6A2ABAF7DFFFFE4FFFDF4FFFDFA
7F7B6F151606565A4CF4FDE8D8E6C274874FCEE796E2FEA9D0E9A5C6E09FC1DB94CFE59C
D4DB95E7EEA8C4D48BD3E9A0DAF6ACC7E399DBF2AC859451E4E6A7EAE6A99892569E9A5B
E1E8A4D2E39CC0DC8FDAF0A75D5C1CDDDD9FD4EFA8B5DE92CBEDA3D7EEA85A6020DCE7A5
C2E49AD3EDA6EBE1A66D5C24959B5BCEE59FC3E199DAEEA9A09A5CA3945DE3DCA8757746
949D70B2C2955A6C3C7E905CD4E3AABECC8EDEE8A9E0EBA9CBDA9998AA6C475C21384C0D
26330047570E67813A6483405B773C566B330B140091945FB5B87FD4DEA1C0D995CDECA8
CAEAABB8D59DE2F4C4E8F5CAECF8D0E9F7D3F9FFECF9FFEFDEEBD1D7E3BFCFDDA8D0E0A1
CFE09CEDFDBCCFDCA466733ED3E0AAD4E2A5D6E69FD6E39BE0EBA992A160A2B973C6E49C
D4F0A6D1E8A0CBDC96CEE29BC8E69CDAEEA7B3A76DA59861D2E2A3D7F0AF8E975E504F17
79743A989256A5A164CBC68CE8E6ABDDDCA3D4D79ED6DBA1
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC8EA9DC6EAA0C1EC9DBAEE9CC5EC9BE1E19BE7DFA1D5E4ADD0E4B1
1A2200808F58C3EDAEC1F3BE527E63B8DFCCDCFFDFEDFFDFA9A588A99B81F1E6D2F6EFDF
898278080100706762FFFCF82617121F0E0794837CFFFCF4FFFCF6FFFEFAFBFFFEFAFEFF
FFFFFDFFFEFCFFFFFFFFFFFFFBFCFEFCFFFBFBFFF2E7F1D6D6E1B9D3DFAFD4E0AEBBC497
F5FBD9FFFFECF8F8EEFFFEFFFFF7FFFFF8FFFFFFF6DAE0C69EAE81CFE4A9D2E9A3CFE79B
CFE698CEE396B2C77CADC37ACCE69DD0EEA4C3E599CDE3A2989568EDDDC3FFFCF3FFFCF6
302C20080B00070E007A886E889A70C1D99BC3DE8DC9E590C7DE96C3DA96E4FAB2CBDC95
959C58989F5BEDFAB4C3D790D2E9A1C7DE96CDE19CBDC987999B5CD5D396B0AC6DA9A868
DAE19DD8E9A2CCE79ACCE299838343EAECADCEE8A1B7DB91CBEDA3BFD6905D6323D2DB9A
CBEBA2C7E29BDED89C65561D989D5DD2E6A1C9E49DD7EBA6E0DAA08C7C48DAD09F979565
4B4E23949D72A3B0824C5A2999A772EEFCC1D4E2A5CBD99B697C3C4F63249AB274C7E09F
CEE29AA7BC717A954E52712D5A77375D7237B7C48CCFD6A0DCE4ABE0EBAFC7DD9DCCE6A7
CBE7ADD2EAB6F9FFDCFBFFDDF7FFDFDDF4CAF2FFE6F4FFE9D9EAC8D6E8C0D6E8B4D2E4A8
CFDFA1CEDEA094A16B94A16BD3E0A8D2E1A0D5E398D4E094A5B06C536221D8F2ABC2E098
CEEEA3D2EEA4C7DB94DAF0A8CEF0A4B9CE89DACD96D8C992DCEAACC3D798787B44D8D69D
DADC9BE3E8A5D1D694E3E9A9DBE1A3D7DFA3D6DFA6DFEAB0
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC8EA9DC6EFA3C1ED9EBDEE9DCAEC9FE5E4A1E9DFA2D6DBA5CAD4A2
61693A94AA79ACDFA7BDF9C6154626BCE2C9F0FFECF4FFE1B5AD98B8A898FFFDF1FFF7EE
060000060000F0E6E5FFF5F32B1C171E0F08887A71FFFCF4FFFEF8FFFFFAFAFFFBF5FBF9
FEFFFDFEFEFCFFFFFFFFFFFFFBFCFEFEFFFBFDFFF3E8F0D9D3DAB9DEE6C1C3CBA4BCC49F
FEFFE9FAFDECFFFFFAFFFAFEFFF9FFFFF5FFFFFEFAD4D7C29FAC81CFE3A8D5EAA5D0E59A
D8EA9ECCDE929DAF65CADE96CFE69ECDE8A1C8EAA0D0E6A690895FE6D2B9FFF9EDFFFCF4
161206070A00010D00627353A9BF90BED897CEEB99CAE691DCF2A7E0F4ADC4D58FD7E49F
555C1957601DC8D792CDE19CD0E7A1D9F0AAC4D893DBE7A5595F1F9D9F608F8F4F969B59
C9D48FD7EBA3D7F3A8CEE69C999E5CDEE3A3C4DB95CFF1A7D7F9AFC3DD96606525CAD090
CCECA3C4E29AD7D5985D5318989D5DD4E3A0D2E9A3D1E1A0DED9A1584B17A09867C4C091
232400555C30B1BC91919E70283605CEDFA9D0E1AA99AD70546C2E789253E0FDBDCCE9A6
D5ECA4D5EDA3C1DD93E1FFB9D0EAA9C9E1A3D3E2A7D9E7ACCDD8A0D6E3ABCEE2A7C7DCA4
CDE1ACDCEEBEEFFCD0F5FFD9DDF7C7D0F0BEE7FFD6E1FCCFC6E0B3C5DBACC9DDA8D2E5AE
CDDEA8EAF8C3CDD9A78F9965E0EBB3CFDB9BAEBA7099A5599EA9658F9E5BCCE69FCFEFA6
C5E79DC5E59CD1E8A2CBE59ECAEEA4D4EBA5DED19ACCBB85CEDA9CC2D29383824AD8D79E
D6E7A0D1EC9FC9E399D9F0AAD3E8A7CFE1A5D5E6AFCBDCA6
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC6EB9EC1EDA0BCEB9DBDE899C9E89CDCE19EDFD69BCDC692BBB88B
727B50EDFFDDB7ECBE74B3863D734FC8EFD0D3E3C6FFFFEA7A6E5EDFCEC4FFF6F08F8583
060000767070FFFCFDFFFCFA2D201A1D0E077E7067FFF9EFFFFCF4FFFFFAFCFFFDFBFFFF
FEFFFDFEFEFCFFFFFFFFFFFFFCFCFCFEFFFBFEFFF5EAEEDDCFD3BCDEE5C6929779FFFFE8
F8FBE6FFFFF4F8F9F4FFFDFFFFF9FFFFF4FFFFFEFBCED1BC9DA87ECEE0A6D6EAA5CFE197
DAEA9FC8D88D8B9B54D9EDA6CAE19BC5E099C9EAA3D1E5A8887F56F7DFC5FFF0DFFFF8EC
9B978B000300323F25DDF2CBCCE5AED6F3B0C6E393C9E591C9E092D4E59EB6C280737D3E
D5DFA0D4E09E738342DDF1ACC6DD97C7DE98E6FAB5C8D995D1DC9AA6AF6C686F2C99A460
DAEBA4C8E096C1E094D1EBA1909958DEE7A6CBE29CCDEDA4BFE399CDE7A05052138D8F50
C8E69ECCEAA2E1E3A4625C209B9D5ED3DE9CD6EBA6C8DB99DDDCA3867F4B575421B4B282
ABAC8071774B1B2400ACB78C6A7A4D293B0B667D473851188DA96ED8F6B8BDDD9CC9E8A4
C9E49DCFE99FCFEAA3BAD590D2EBA9DAF0B0C9DD9ED3E5A9DBEAB1C6D59EDDEBB6DAEBB7
C1D1A2DCE9BDFCFFDCF8FFDACEEDB4C3E9ACC5E9ACBDDFA3CAE7ADD6F1BACCE3AFD2E4B4
D1E1B4E5F2C7FCFFDCA6AF80939D68D9E5A79BA862919E56D5E09CD2E39FD0EBA4BEE096
C9EDA3C7E79ED8F2ABC3DD96C2E69CD2E9A58F8049B1A06ADAE4A7C0CE90AFAA73D9D99D
D0ECA1C1EB99C8EEA1C5E69FC4E1A1C8E1A8F7FFDAF8FFDC
CBEB9FC9E99DC8E89CC9E99DCAEA9EC9E99DC8E89CC8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC6EB9EC0EFA1B3E294D5FAADD2ECA2CAD994EBEBAD6C58265A4B20
FCFFDDEDFFE8B3E7C378B68F154E25BAE2BDEFF8DD08000096887DFFF2EDFFFBF9110809
040000807A7EFFFCFDFCF2F133262010010084766DFFFBF1FFFBF3FFFFF8FBFFFCFBFFFF
FEFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFBFFFFF8FFFFF4FFFFF0FEFFEC5E604BEEF1DC
FFFFF3F9FBF0FAFBF6FFFDFFFFF9FFFFFAFFFFFEF8DFE3CC859065E0EFB6CFE09CD4E69C
D9E79C8D9B5055621CD5E6A0D0E5A0CDE8A3CEEFA8D0E4A78A8158C0A88CE5D3BBD5CAB8
0D0A00000400021100C8DFB3C4E0A5CFEDA5D2EEA1C0DB8AD9EE9FC9D99097A26097A164
D5E3A5D1E4A2869B5AC6DD99DEF5B1C1D894CAE19BDDF2ADCADB959BAA65CCDD97CCE098
CFE79DCCEB9FC7E99CD0EFA38F9E5BDDE9A7CFE49FCAE8A0C3E79DD5EFA8A19F62A5A567
D6F1AAC1E198D5DE9D6E6C2F8C8C4ED0D696E0F4AFD2E5A3D1D99E9FA26B5457229A9C6A
DEE1B2D1D7A99DA47A96A177D2E1B8000C00000D00C1DDAACFEEB5C5E7AACDF0B0C0E09D
CCEAA4D3EDA6C0D791CCE39DD3E8A5CEE3A0DFF5B5C8DEA0D9ECB4C9DAA6D2DEAECFD8AB
FEFFDAFEFFDCD0D9AEDDEFBBC6EBA8BDE99EC3EDA1BCE297C9EAA3CCE9A9C2D9A5E8F9CF
F9FFE4F7FFE2FCFFE4E5F0C8929C6A5C672D8C9858DBEAA5DEEBA6CCE099CBE99FBFE497
D1F5ABC7E79EC8DF9BCFE8A4C9EDA5CEE4A3A0905CA6925FDCE4A8BBC98BA5A068DDDEA2
CBEBA0C0EF9FC6F0A6C2E7A4C8E7ACCAE2B2F7FFE3F9FFE4
CAEA9EC9E99DC8E89CC9E99DCAEA9EC9E99DC8E89CC8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC6EB9EC2F1A3D1FDB0BBD98FCCE39BD4EEA7C9D2936D5322654921
FFFFE38EAC9015452B0C45255A9265BADFB4FBFEE359493AA1928BFFFAF8B6ACAD060000
0B060AFAF5F9F8F2F4FFFCFA3326201F110894867BFFFCF3FFFBF1FFFFF8FCFFFDFBFFFF
FEFFFDFFFFFDFFFFFFFFFFFDFFFFFDFFFFFBFFFFFAFFFFF6FFFFF4F6F7E9C3C4B6FFFFF3
FFFFF6FDFEF6FFFFFBF6F5F3FFF5FDFFFAFBF4F5E7D3DABB99A678D2E1A6D0E19BD2E299
DDEAA2909C54505B17D2E19ED3E6A4C7E09CC0DF99CBDFA0918A5EA79473EFE2C2E5DEC4
636250030B00000800CAE2B0D4F1AFC1DF95C1DD92F2FFBCC3D987C1D186A7B174D8E3A9
DCEEB0CCE2A27B9151DBF1B0CAE39FCCE5A1E3FAB4BAD189DCF2AABFD58DDBF3A9D8F2A8
CEEDA1C7E99CBDE294C5E59ACADE9991A05DD3E7A2CEE8A1D2F6ACC1DB94E7E3A6C3BF82
C1DC95D6F6ADCDD9974648097F7D40EDEFB0CDDE9AC0D592DEECAFCDD69D99A168595E28
C0C492E7EABB7B82582A350DD3E2BBF1FFDFF2FFE1D0EDBFBBDCA7C6E7AEC4E6A9D0F0AF
C9E6A4C3DC9AD0E3A1E8F9B5485915475A183B51108BA365475C241E2E00363F128C9168
FFFFDCF7F9D1D6DDB1C9DCA4C8EEA5BEEE9AC7F39CC0EA94CDF0A0CEECA6C5DBAAE7F7D3
FBFFEDF9FFEDFCFFECEFF9D7BECA9CA0AD77B4C285D3E3A2CEDF99CCE299CEEEA3C4E99C
D0F2A8D5F3ABD6EBA8CCE19EC3E29EDBEEAEC9B884CAB683CBD5988C9C5D8D8B52E0E4A7
CBE99FC0EA9EC5EAA4C2E4A7CDE8B5CFE4BBF9FFEAFBFFED
C7E79BC8E89CC9E99DC9E99DC9E99DC9E99DC9E99DC8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC6EB9EB6E096D1F9B0C7E198DBF5ACBFE39B7689475D3F0BD5B28C
FAFADE5F78658AB4A6B5E6D0CFFFD3C5E5B6EEE8D06A564BA59691FFFCFB8A8184736E72
010004FFFEFFFFFAFAFFFDFA30231B23150A938278FFFDF1FDF4EBFFFFF8FEFFFDF6FAF9
FEFFFFFEFFFFFFFFFDFFFFFDFFFFFDFFFEFBFFFFFAFFFFF8F9F4EEB9B6AFF6F3ECFFFFF8
F4F5EDF8F9F1FEFFFAFEFFF9FFFFF8FFFFF3FEFFE9CFDAB2C3D49ED0E3A3D9EAA4D9E9A0
DFEAA5CCD793919C5ADFEEADCEE19FD2EBA7CFEFA6D1E7A6B6B484B8AC84DED7ADCFCCA9
191B06000500000900D0E7B1C4DF9AD7F3A8B5CF86BED68A95AB59415204DFEAAECFDCA6
D0E4A9ECFFC67B9355C7E09FBED493CEE5A1DAF1ABCCE39BCEE89FCBE59BCAE69BCCEB9F
C1E396C5EA9CC4EA9DD1F3A7D3EAA48A9E59CCDD99CCE39DB3D78DD1ECA5F8F2B6938D51
D0EAA3C5E79DD3E7A25E6424625E21DCDC9ECDDC99E0F5B2CEE3A2DDEFB1D1DCA04A5219
8B8E59DEE0AF6D70450A1000E3EECCE6F7D7F2FFE8C0DAB3BFDCAEE0FCC9BDDAA0CBE7AA
C5DFA0DDF1B2D3E1A3D6E19F56611FE4F3B0DAF0AFC8E0A2C9E0A8D5E5B691966D63613B
F7F3CDFFFFDAE5EDBECADEA3C4EA9FBEEC94C5F192C3EC8ECAEC95CCE7A0CADDAFE3F1D7
F8FFF3FAFFF6FCFFF1EEF7DAD7E4B9D0E1ABD1E3A9CADD9DD3E9A1CDE79DCAECA0C9EEA1
BDDD94BFDA93D0E09FD5E5A6D0EAA9D9E7AA9783505A4613515D1D5B6E2C9A9E61E4E8AB
CEE29BCDE7A0D5EEADD2E7AFD6E5BAD2DDBDFCFFEFFEFFF3
C4E498C8E89CCAEA9EC9E99DC8E89CCAEA9ECAEA9EC8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC8EA9ECCF2A9B9DD95CAE49BCCEAA0BBE79C93AE69684D16E6C099
FFFEEA8B9B91577B779BCAB8B8E2B4C5DDADC5B9A1473126D8CAC7A8A2A23531323B393C
FFFEFFF8F8FAFFFEFDFFFAF4392C231C0E0178685BFFFBF0FDF3EAFFFEF8FFFFFDF9FBFA
FEFFFFFEFFFFFFFFFDFFFFFDFFFEFBFFFEFBFFFEFAFFFEFAF9F4F1A6A19EFFFEFBFFFFFA
FEFEF6F4F6EBFEFFF6F1F5E6F2F5E0F9FDE2F4FFD7AFBF8ED0E4A7CDE29FCDE199D3E39C
D1DC98D4DD9C97A162D7E3A3C7D796D1E8A2CCEAA0CCE39FA8AC79A8A475DEDEACE3E6BB
00040000060036471DD5EDB3C0DA93E3FDB3DFF6B0DBF1A891A7549AAB5DCFDAA0D0DCAA
C7DCA3F5FFD1B7CC91DCF0B1D4E9A8D0E5A2C7DC97D9EFA7CBE59BDBF7ACC6E599CFEFA3
C5E79ACAEFA1C5EA9DCCEEA2C6E0998DA25D879653D3E8A3C7EBA1D2EDA6D6D094A2995E
D5EFA8C4E89EC0D791000B004F4B0EDAD699D9E5A3CADF9CCAE3A1CEE4A4D4E4A5ACB479
92925CD3D1A089875E111200D1D7BBF9FFECF5FFEDC4D8BCD9EFC9ADC395CEE2ADCBDEA6
D4E9B0D3E5ABCDD59AD5D99C696E2E545F1D7187466A8445D3EAB4DBEBBCD5D7B0645E3C
9D9570FFFFD4C5CD9AD1E5A8C3E79DC0EA94C4ED8DC6EB8BC8E990CDE7A0D6E7BDE9F5E1
F6FCF8FCFFFFFCFFF6E8F2D7CFDFB2D0E3ABD5EBADCCE39FCDE79DCDEC9EC4E99BCCF1A4
C9E79FD9F0ACE3EFB1CEDA9CCFE3A4D3DDA1947E4C6E5A277B8A4996AF6BC6CF90D9DF9F
CEDD98D8E9A5E7F7B9E4F0BEE1E9C2D5DBC1FDFFF1FFFFF6
C0E094C7E79BCBEB9FC8E89CC7E79BCAEA9ECBEB9FC8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99ECDEBA5C4E29CD8F4AABFE497BAEDA2D5F4B09B884D926C45
C0A89CF1EFF4001D22537E74C0DFB3D0DCAAA09077B09A8FFAF1EC010000141414D7D9D8
FBFCFEFEFFFFFFFFFBFFFEF853463D1B0D005D4D40FFF9ECFFFBF2FFFEF8FFFEFDFFFFFF
FEFFFFFEFFFFFFFFFFFFFFFDFFFEFBFFFFFAFFFEFBFFFDFBCCC3C4B3ADADFEFAF9FFFFFB
FFFFF8FBFDF0F7FBECD8DDC6CED8B5D6E3B5DCEDB791A568CFE6A2D6EDA5CADE96D5E6A0
D4DF9D9FA76B555D21C9D597DAEAA9D1E8A0BFDE92CDE79E98A3698F945EDFE7ACE5EDBA
131C0100080066774AC9DFA1DAF2A8C4DC90C8DD9A90A560A7BD6AC8DB8CD2DFA9EDFACC
F2FFD0CDE2A9D6E8AECFDEA3C8D699CFDE9DD2E19ED0E19BC3D990D4EEA4C1E094CEEEA2
C8E89DD0F0A5C5E59AC2E297D4EFA8B8CF897C8B48C7DB96D6FAB0C8E39CDED59AADA469
CEE8A1B6DC91CFEAA3EFFBB95D571BF6EDB2D0D998D4E9A6CFEAA7CAE5A2D8E8A7E2EBAC
5F5D246F6736B8AF88423C1CFFFDE8F0F3E2EEF7E67A8672444E33919B768D94683A4412
63744063703B45450F130E004745086F7535AABF7C7794547089524F5F32363612CBC0A0
6F623F817D50EAF3BCC9DD9ECBEAA7C8ED9FC9EE91CCEE8FCCE891D5EAA7ECFAD7FAFFF7
FCFFFFFCFFFFFBFFF8E7F4D6CBDFACC6DF9ECFEAA5D0ECA2C4E397D2F3A4C3EA9BC4E99C
D1ECA5D0E3A1BBC185757A404A5A1C5D6228654D1DAA9462D6E6A5C6E49ED8E9A5E1EEA9
D3E39CD6E5A0E2F0B2E7F1BDEFF7D0E7EBD2FFFFF3FBFCF4
BCDC90C7E79BCCECA0C8E89CC6E69ACBEB9FCCECA0C8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCAE89EC5DC98D4EDA9D4F4A9CAF4A8B2E69CC6EAA4CEC486906F44
A98380FEECFA000B1700221AD4EBBFECEEBD57452DE9D3C8BCB5AF1E1F1A595B58FCFFFF
F7FBFCFDFFFEFFFFFBF7F3EA5B51451C0C004E3C2EFFFBEEFFFCF3FFFDF6FFFCFCFFFEFF
FFFEFFFEFFFFFFFFFFFFFFFBFFFEFBFFFEFAFFFDFBFFFCFDA9A0A3DDD4D7FCF6F8FCF8F5
FBFBF3FFFFF4FDFFEED5DEBFD3E1B0D3E7AABCD2918CA65FD1EBA1DBF6A9CEE49BD7E8A2
D6E0A1959D6250581DCFD99DDEEDACD7EDA5CBE79AD2EEA3889A5CA2B075C7D695C7D49C
333E205D6A4E91A170C9DE9DC4D98EE0F6ABCCDF9FA3B674CFE593E1F3A7DBE9B4E0EDC1
F9FFD8C0D19BD4E1ABA0A970DCE4A9E6EFB0D6DF9ED3E09BD8ECA4D4ECA2CDE79DC9E59A
BFDD93CBE99FCEEAA0D3EFA5D0EEA6DDF7B099A563D3E4A0B7DD92D3EEA7E8DEA39B9156
D6F0A9D2F8ADCEECA4B7C6836C6328CEC489E6EFAEC6DB96C7E59FCBE6A1DAEBA7D3D999
4F490F403201E6D7B078684EFFFAEAFFFFF3C6C6BC17190C858772FFFFE4F5F1CBA6A579
283406222B003633002F2600A49E62DEE0A1D0E5A2C7E4A4CFE7B366754A514E2BFCEFCF
584A25999264CFD89FD8ECADCAE6A9C9EAA5C8E893D0ED93CBE290D5E7A9FAFFE6FCFFFD
FCFEFFFBFEFFF4FEF3E7F6D5D0E7AFCAE59ECCEB9DC7E897CDEE9FC8EB9BBFE697CBF0A3
C7E29B74834274753C7A7941949E629D9E65826738B19B69D5E8A8C0E19ACCE39DC7DB94
D7EEA0CBE196CDE09ED8E9B2F4FFD6F5FEE1FEFFF3F4F7EC
B9D98DC6E69ACDEDA1C8E89CC6E69ACBEB9FCCECA0C8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCCE89EDEF1B1CADF9EB6DB8EC1F0A2BAEEA4C4E8A2E2E19EC6A97D
703E3F745368C9E3F27EA7A15160354F4919A18D7598847B302C2370726DBBC0BCE4EAE6
FBFFFFF5FAF6FFFFFAFFFFF4473D311808004D3B2DFFFBEDFFFBF2FFFCF6FFF9FAFEF9FD
FFFEFFFEFFFFFFFFFFFFFFFBFFFEFBFFFEFAFFFDFBFFFCFDDACFD3FFFCFFFFFDFFFEFAF7
F4F4ECFFFFF3FEFFEDD3DDBAD5E9AECDE79E78944987A356C9E696C6E393CDE59BCBDC98
CDD79A9AA269646931D2DCA0CAD998CCE29ACCE999C8E497849A599EB072C6DA93D1E3A7
5B6948E6F3D7CDDDACD8EBA9DEF0A4C9DE91DBEBAD7B8E4EC9DF8DC7DC8FD3E4B0E9F5CD
F3FFD0D7E4AFE5ECB88D925CDFE0A7D4D599B7BC7CBBC481D1E19AC0D58AE0F8ACD4EEA4
C8E299CCE69DCFE6A0D4EEA7C6E49CBCD68F9CA866D4E5A1C1E79CD0EBA4DED499CDC187
BAD18BB8DE93C6E69DE0F1AD584E13695D23DCE2A2D6EBA6CBE9A3C7E29DCEDD98DDDF9E
AA9F67867142D5BD99917B639B897D938680080000FFF9F1FFFFEFCFC5AC7768475B522B
535A314A5125564E1F675A26C0B67BE8E8AAC7DA98D4F1B1D2EDB8CDDCB1716C4CFDEECF
61512DAFA778D2DA9FC4D899C8E1AAC9E5AAC9E497D2EB97C9DE91D3E2A9FEFFEDFEFFFF
FDFCFFFAFCFFF4FFF1E2F4CECDE7A8CCEB9BCDF199C2E68ECBEE9ABCE191BEE798D4F9AC
D2ECA54B5717838049E7E2ABD9DEA6E5E4AEA5895AA99562CFE4A3CEF2AADCF7B0C5DF95
CEF09CC3E692C3E398CAE7A7E1F9C9E5F6D4F9FFF1F2FDED
B8D88CC6E69ACDEDA1C8E89CC5E599CBEB9FCDEDA1C8E89CC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DCCE89ED9E7A9C5DA99D8FEB1BBEE9FB4E69DD1F5AFD9DF99EED3A6
7A42456C445E89A3B417413D8D956C594F1EFAE4CD0E0000130F06545952EEF3EFFBFFFD
F1FAF7FBFFFDE8E9E1FFFFF4302718160600554434FFFBEDFFF9F1FFFCF6FFFCFDFFFBFF
FFFEFFFEFFFFFFFFFFFFFFFBFFFEFBFFFEFAFFFCFBFFFCFDE1D6DAFCF3F8FFF9FCFFFCF9
FFFFF8FFFFF1FEFFEDCCD8B0D5E9AAC8E59543601089A956CDED9ABFDC8CE1F9AFD3E7A2
E1EBAF8A9259535822DEE6ADD9E8A7CCE299CCE798CFEC9CD1EAA8829857DAF0A7C9DD9E
637150E4F1D5D5E3B0CCDD99CFE195D1E397536325D3E3A4CEE492D4E99CD2E2B1E4F3CA
FCFFDAD7E1ADD7DBA958582457561E5E5E2297975999A05C55601B55671DBBD186D0E89C
D4EBA3D3EAA2CDE19CCCE39DCFEDA5CEE9A2DEEAA8869753CDF3A8C3E199EFE3A9E1D59B
8FA660CFF8ACC3E39AD5E6A2665C215E5218D8DE9ED3E8A3C9E7A1D6F1AAD4E19CE0E0A0
A192596650217E613FDBC1AA130000655351F2E7E5FFFCF8F5E9DB60513A907B5EECDEBB
CDD2AAE9EEC5DFD4A7E3D3A0F2E5AED6D698D2E5A3C6E3A3C5E0ABDCEBC0696444FFFEDF
6856328F8758E6EEB2D2E6A7CBE1B0CEE7B0CDE79DD9F09ECDE297D6E3ADFEFFEFFFFEFF
F9F8FFFCFEFFF9FFF6E0F2CAC4DF9CC9EB95D3F79DC6ED90C4EA95CDF4A1C7F0A1BADF92
CFE9A258622396915AE3DCA6D7DAA3E4E1ACA48859B39F6CD2E7A6B9DF94CCEAA2D0EFA1
C3EB93C3EF96CDF4A5C7EAA6CAE6B3C7DDB7F5FFEDF8FFF4
pop
P
% End of image
1 0 0 r
.03 w
.12451 .72964 Mdot
.09097 .62762 Mdot
.10835 .52386 Mdot
.20656 .33952 Mdot
.2203 .14706 Mdot
.21909 .05257 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.34127 0.349206 0.65873 0.666667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
C7F4A1B9E492C4ED9ECAEFA2C6E49C8DA6628598589BAB6CDFEAAEC6D195E2EEB05C682A
C6D594DFEFAED3E4A0CEDF9B3F4B0B95A161D3DF9DD9EAA6CDE19ACFE69ED5EFA5C5E498
BFDE92CAEA9ECBEDA1CAECA0CDEFA5CBEDA3CBECA5D7F5AD90A45F91A05B97A25E939E5A
969D5AA5AC69909553575C1A4B500E5F6623727B3886934EA6B570BED28BB2C67F93A961
95A8664B5113B19B69CCB684D7DCA2D4E2A5CDD097C5BB86A7905EAB97627F8044B1C27C
CDE19ACBE59BCBEA9CCDF0A0C7E59BC9E59BD4EAA2C6D7919FAC6774813C334000E1F2AC
D1E8A2C3DE97CBE9A1BDDD94D4F2AAD4EFA8D0E7A1CBDF9ACEDF99D2E39D90A75FC7E59B
CCEEA1C9F2A3C2EB9CC8F1A2BEE093D6F2A7D0E19DD9E2A1E1DFA4DAD1988E7E4A5B521B
BEC788D6E5A4687132A6AA6DD4D496E2E2A4E6E8A9CFD897D0E19BCEE89FC4E499BDE396
C8EFA0C9F2A3C5EC9DC8E79BBECD8ADFE8A7B0BB79A9B875CFE59DCFE9A0CCEAA0CAECA0
C6EB9DC5EC9DC3ED9BC3ED9BC5EC9BC5EC9BC6EB9BC9EA99CFE799CFE897CCE89BC8EB9B
C5EC9DC5EC9DC9E99ECDE79E95A662869252B1BE86E2F4C0C2DDB08EB48B2C5E3814491D
86B67C80A869DDFFC3ADCE952E531F06340375AD8080B8919ECCAF89A991F8FFF130341B
323311CCD6A4E6FFC1C0E49EC4EBA8C0E3A18DA662C5D992D5E69FCDE599D7F7ABC1E699
D0EEA8869B5A363902A1A068D6D59CE8F3B1C8E499C3E89AC5EA9DD0E7A15A5416E4E0A1
CFE59DC9EB9FCAE49BD4E59F888A49D2D996CDE7A0C1E399CAEAA1CCEAA2CEE9A4C9E09C
7F8E4BD6E39ECEDD98D7E8A1DCF0A9C9D998BEC78E777E4A
B9E492C5F09ECBF2A3BFE195CAE8A0D7EEAAD2E5A5BBC98B949F6397A2664C581ADFEBAD
D9E8A7C3D392D4E8A3849551879353D7E3A3DBEAA7C9DA96CFE39CDBF1A9C4DE94D2EEA3
DAF9ADCCEB9FBEDE93C5E59ACEEEA5C5E59CC2E19BD7F2ABD0E5A0D3E29DDDEAA5D9E4A0
CCD592D7E09DE5ECA9DAE19EDDE4A1E0E9A6DDE8A4D5E49FD9EAA4DFF3ACD5EBA3C1D892
CCE39FDCE5A667532075612EE5EAB0DAE8ABD5D89FB4AA755D46145F4B16B1B779C7DB94
D4EAA1DEF9ACB9DA8BC9EC9CD0F0A4CEEAA0D6EDA5D5E9A2CEDB96BAC7825D6C27C2D38D
C6DD97E6FFBAD6F4ACCAE8A0C7E29BCBE59EC7DC97DAEEA9D7E6A1D7E8A2BDD48CD0EEA4
C2E799BEE596C8F1A2C5EA9CD3F3A7C5DC94D0DF9CD9DF9FDDDDA1625C228980499C975F
C7D192CEDE9D737D3E858B4D9E9E6098985AADAF70E3ECABD0E19BD1E8A0CBEBA0C9EEA1
CBF2A3BFE899BDE495CDECA085945155601E84904ED3E4A0D5EBA3C4DE95C7E59BC9EB9F
C6EB9DC5EC9DC5EC9BC5EC9BC5EC9BC5EC9BC6EB9BC9EA9BCFE799CFE799CAE999C6EB9B
C3ED9BC5EC9DC8EA9DCDE79ED9EAA6D8E4A6646F37BFD09CCBE5B67DA27614441A8EC292
BFECB1BFE8A6B2D19577965D9FC48EB8E6B5CBFFD7AEE8C0A1D2B474967E707F6A121700
222804D1DFAEB9D696C2E7A2C4EDABCBF0AD829B59E5F9B4CCDD96D1E79CB4D488BFE497
C8E7A1D2E7A650551B363500E4E5ABC6D18FD2ECA2D2F4A7C5EA9DD3EAA45A5617D8D495
DFF6AEC5E79BCAE69CD1E29C5658179FA663CCE69FC9EBA1CEEEA5C8E6A0CCE7A2D1E8A4
C8D79499A661DAE9A4D4E59EC4D891D0E3A1E8F3B9BEC792
CEF8A6C0EA98C3E89AD0F0A5CBE69FCBE09DCDDD9ECEDC9EBBC68A667135A3AF71C0CC8E
CBDA99D9E9A8BBCF8A445813A1B06FC7D695DCEBA8D0E19DDCF0A9CCE29AC1D78ED3EBA1
C4DE94D4EEA4D7F3A9D2EEA4CCEAA2C4E29AC4E29CD3EEA7D5EAA5CBDF98D1E29CD8E7A2
D4E19CD4E19CDCE7A3DCE7A3D5E29DD6E39ED0DF9AC8DC95C6DC94CBE29ACEE89FCEE9A2
C5E09BCFDD9FAB9A666D5926DBE0A6E3EEB2DEE1A89A935D6F59276B5C25DCE6A7D1E8A0
CAE49AD4F3A5BEE191CAED9DC8EA9DC2E195C9E399CCE299D2E19CD5E49F74833E8B9F58
D4EBA5C2DD96B8D68ECBE69FC6DF9BC7DC99E9F9B8D2E19ED4E39ECDDE97D8F0A6CFEEA2
C2E799BEE596D1F6A9C4E499CFE69ED8E9A5EDF8B6D3D8989D9E625A5A1EA7A76BE7EDAF
E6F6B5CEE3A06F7E3D424B0C57591A5F5F21868849D4DA9AD3E29DCEE49CC6E49AC9EB9F
CBF2A3C1E899BFE496D2F1A596AA655C6B28A3B470DBEFAAC8DF97CEEAA0CFEDA3C6E89C
C6EB9DC6EB9DC6EB9BC6EB9BC6EB9BC6EB9BC8EB9BC9EA9BCFE79BCFE799C9EA99C5EC99
C2EE99C2ED9BC6EB9DCCE89ECFE39ED9E5A796A169BCCA95C6DDA997B7854E7A4991C08A
BAE7A6DAFFBCBDDD9C82A165BBE1A8B3E2AEA9E3B3B4F1C860967692B89F70836F2E3820
081200DAEBBED5F4B8C1EAA8BBE5A5C4E8A898B170C9DA96DFEFA8D2E89DD0F1A2CDF2A4
C7E99FD7F0AE98A26647480F9A9B61D4DD9CCEE49BCDECA0C2E79ACEE59F6C6829DDD99A
C9E197C3E598CFEBA0D3E49D646724838A47CEE9A2C7EBA1CFEEA8C5E39DC6E3A0D3E9A8
E3F2B1949F5BBAC984D1E59DCDE39BCBE09DCFE1A7E0EEB9
BCE191C2E595C8E89CCCE89EC6DB96DCECABE2EEB0D5DFA2DEE8ACD3DDA1D6E0A3CFDB9D
E4F3B2AFBF7E495D187B8F4AC9D998D1E1A0C5D692C0D18D6C80399AAE679DB1699BB168
CCE299CBE198C4DB93CAE199D9F3ACD9F3ACCDE6A2CAE49DD8EFA7CDE39BCDE19AD6EAA3
DBECA6D5E6A0CFDE99CAD994D7E8A2D4E8A1D5E9A2D5EBA3D2E9A1CEE89FD0ECA2D4F2AA
D3F4ADC7DA9AE2D5A0AC9B674A4F15B0BB7F91945B7E7741B8A773CDC28ADAE9A6CCE89E
C3E296BEDF90D0F6A3C4EA97CAEF9FC5E79AD0ECA1CFE79DCADE97DBECA69DAE689DB16A
95AC6687A15A6A853E5B752E9EB370768645C5D191E2EDABD4E39ECADE96D1EBA1C5E498
C9EB9ECDEFA2CBE99FC8E299CBDC98D0DB99CFD494696E2E4E5215C3C98BD6E0A1D2E2A1
C2D995CAE39FB3C3829DA768BDC282B4B476959758575C1CD8E5A0D5E9A2C9E39AC2E297
C9EEA0CAEFA1C6EB9DCCECA0CDE29DCEE29DD6EBA6C7DE98C8E299D7F3A9CCEAA0CAEA9F
C8EA9DC6EB9DC6EB9BC6EB9BC8EB9BC8EB9BC8EB9BCAE99BCDE89BCDE89BC8EB99C3ED99
C1EE99C1EE99C5EC9BCAE99DDBEFAAC9D597D1DAA1818B56576A33BDDAA2C6EDB4C4F0B1
BAE39DC4E9A3CCEBA8BEDE9FD6FCC1C2F3BCB8F3C3B2F0C7538A6AABD7BE94AD98718069
41502FA8BF93B4DA9FC4F1B0B9E5A6C8EFB0839B5DD0E09FC6D68FDDF2A7B8D789C4E99B
C3E79DC8E39ED2DEA0ADB176636428BDC383D3E79FC4E095C6E89CCCE69F9490519F9E5E
D2EAA0C5EA9CC8E499D3E79FB9BE7B969D59D5F1A7BFE399CBEAA4C6E3A0C3E09ED0E6A6
C0CC8E9FA96A6C7B38D4E8A1D8F2A9C8E19DD2E7ACF1FFCD
D7F2A5CBE699CFE79DD9EDA6D9E8A5D2DC9DD5DB9FD8DCA1C2C58CEFF2B9D2D89CEBF3B7
B9C384758141657431ADBE7ADEEEADDFF2B0D7EBA690A45F798A4492A35DBECF887E924A
91A55DBED28AD5E9A2CBDF98C9DD98CFE39ECFE4A1CFE49FCEE59DD2EAA0D2EAA0D1E79E
D0E69DCEE49BD2E69ED9EDA5D4EAA1CFE79DD0E89ED1EBA1CEEA9FC4E397C1E094C1E397
B7DD94DBF1B0DCD09CD5C5925459216B763C666930544F18BBAB77FDF4BBC7DB96C9E99E
CCEEA1BFE494CCF29FC0E794C9F09FC2E797D0EFA3D5EFA5CBE198DBEFA7C9DD96CEE49C
D1E8A2C4DE97B6CF8B5E7531415110485414DDE3A7CED798D9E9A2DDF3A8CEE89EC2E195
C9E99ED1EFA5C1DB94D7E8A4E3ECABDEE0A1DDDDA1646529595F21C1D08FDDF2AFCFEAA5
D1F0AAD5F3ADCDE29FCCD898E3E9A9E3E5A6DBDB9D555A1AB7C07DD5E6A0DBF2AAC7E59B
C5E79ACEF0A3CAEC9FC3E397CAE49DE4FBB5C9E39CC9E39CDBF7ADC6E49AC0E095CFEFA4
C8EA9DC8EA9DC8EB9BC8EB9BC9EA9BC9EA9BC9EA9BCAE99BCDE79DCCE89DC6EB9BC2EE99
BFF097BFF097C3ED99C9E99DDFF4AFEFFBBDE0E8AFAAB37A69783FD4ECAEBEE1A1C8F0AA
CCF2A7C4E89ECAE8A2B7D693B4DC9EB3E4ACA2E2AE72B58A5A9575B9E9CFC5E2CEDBEED8
ABBEA095B08586AF77BCECAEC7F7B9C1E9AB88A062D9E8A7D3E09AE2F4AABFDE8ED2F7A7
C1E699DEFCB6D3E1A3CED4989FA064686E2EDDEDA6CCE69CCFF1A5CBE59EC4C081565515
E1F9AFCAEF9FC3DF92D1E69BEAF0AAA1AB66D6F2A8BEE298C9EAA3C8E7A3C6E3A1D9EFB1
DDE8AEB8C2866A783ACDE29FC9E49DC1DF99E3FFC0E3FFC2
DEF0A6CBDD93D3E39CD6E19DD4DA9A9B9F62AFAE75E6E4ABECE9B2DDDAA3DEDDA46C7035
73793B8E9758E3EEACD0DF9CC8DB99C8DB99A0B46F96AA65E2F3ADC3D48EE1F2ABC5D68F
DAEBA491A15A68773299A863D7E6A3D8E9A5CDDD9CD9EDA8CAE199CDE79DCAE49ACBE59B
D4ECA2CFE79DCAE298D1E99FCCE49AC7E197C6E297C9E89CCCEB9FCCECA0CDEDA1CCF1A4
C8F0A7CCE7A4E7E0AACFBF8C9EA36B737E44C0C38AAEA9729C8F5AE9E4AACBE09BC2E799
C9EE9ECCF3A0B8E08ACAF49EC5EF9BBAE190C0E295CDECA0CAE298CEE49BD0E69ED1E8A0
D4EEA7CEE8A1C6DF9BE5FAB7D1E09F7C854663672C616729BFCF88DBF1A6D0ECA1C8E79B
C6E49AD0ECA2CDE29DD7E3A1DBDD9EA3A1646A682DACAD71CBD596E2F5B3CFEDA7BBDF97
C2E69EC2E39CC9E29EDCEBAADBE1A1D2D495F0F0B29193546A712EB2C17CDDF3ABCDE99F
C0E094C8EA9DCCECA0C7E79BC3DE97CCE7A0C0DB94D2F0A8CEECA2BFDF94D4F4A9C7E79C
C8EA9DC8EA9DC9EA9BC9EA9BC9EA9BCAE99BCAE99BCCE89DCCE89ECAE99DC5EC9BC1EF97
BEF195BEF195C2EE97C8EB9BF8FFC8FEFFCAD8E0A5C9D196B2C082ADC281C6E59FC7EBA1
C9EEA0CDEFA2C8E69EABCA868BB37472A56A70B07C79BE92A9E9C787BCA28DAE9BD6EED8
839A7D92B18789B8828ABE80BBEDB0BAE2A6A6BE829FAE6DB0BD78C2D48AD5F4A4C2E797
C9EFA2CCECA3D0E0A1DBE1A5D5D69A636828BBC882CDE59BCEF0A4BFD992E5E1A29A9958
8AA256C7EC9CD3EFA2D0E59AD5DB9599A35ECEEAA0C6EAA2CAEBA6C9E8A5CCE9A9EDFFC7
FEFFD3DDE6AFB2C085A7BD7CCFEDA7C7E6A0C0E19CCEEEAB
CEDA92E5EFA8CED5916769286767294B460C59521B5D541D2F25006F68325D582065632A
DEDEA2DEE2A5D9DF9FD5E09ED1E4A2D1E6A3394E09C2D691C9DA94DBECA6C5D58EEEFEB7
D9E9A2DBE8A29DAA655B68237D8947D3DF9DE9F5B5C5D692CEE89FCBE79CC5E196CDE99E
D6F0A6C5DF95C0DA90D6F2A7CDE99ECCEB9FCBEA9EC7E79BC5E599C6E89BC8EA9DC5EB9E
C3EEA6C1DE9CFFFFCDFFFFCDCACF97D2DDA3D7DCA2C5C28B9F945ED6D499D4EEA7BFE697
C4EB9AC4EE9ABAE48ECDF7A1C9F5A0C5EF9DC4E999CFF0A1D0EAA0C9E197D0E79FCAE199
C8E29BC9E39CD2E9A5D4E9A6CAD698F2F8BCCCCB92565A1D899952AFC77BCEEA9FCEEDA1
C7E59BCBE59CDCEDA997A05F5A581D696329565016D7D79BDEEAA8D4EEA7BBDF95CAF4A8
C6EEA5C3E79FCDE8A3D7E7A6D3DC9BD2D495ECECAED7D99A444B0896A35ECFE39CCDE79E
C4E397C8E89CCCEB9FCCEB9FD0EEA6CAE8A0D1EFA7CFEFA6BCDC91CBEBA0DDFDB2C1E397
C9E99DC9E99DCAE99BCAE99BCAE99BCCE89BCCE89BCCE89DCCE89EC9E99EC3ED9BBFF097
BCF195BCF195C1EF97C6EC99D1E8A0D5E1A1DAE0A4D9DFA3E5EFB0859952CEEA9FCBEC9D
CFF2A0C0E190C3DF94CCEBA5C5EEACB4E8AAA8EBB5ABF3C551927000311723463292AE98
839D80D1F4CAB4E6B17AB275AEE1A6D0F9BDC9E1A5CFDE9D9BA662CDDD94D2F1A1C3E898
CCF2A5B4D48BD8E8A9E5EDB1DADB9F93985697A45EC9DF96C7E79CC5DF98E6E2A3F1F0AF
50681CC0E595DBF8A8CEE396CED48EA2AC67C3DF95C8ECA4C6E7A2C8E7A4CCEAAAF5FFD3
F1FBC9DCE4B3D5E2AA90A666C7E59FD5F7ADB3D78FD4F8B0
DEE3A0D4D996A6A8674B4B0D99995D9B995EA9A76C9C9A5F9E9C61828244A2A264B8BA7B
D9DE9EE1E5A8D7DD9FD9E3A4D4E5A1D0E69E667D35CBE29AD8EFA7C8DF97E0F6AEBCD089
D0E19BD3E49ED6E5A0D3E29FBBCA8790A15D81955096AB688DA8638DAB6589A75F8BA75D
7E9A4F668235839F52CDE99CC5E196CDECA0D2F1A5CBEB9FC6E89BC8EB9BC8ED9DC5EBA0
C7EBADCEE6B2FFFDD0FFFFD4D9E0ACDBE6AEDADFA7BAB980A8A369CFD494D3EDA3C5EC9B
CBF29FB7E18BCFF9A3BBE790BCE795C7F19FC5EA9CCAEC9FC9E79DC0DC92D1EBA2CBE59C
D5F1A7BFDB91D7F1A8CFE49FD3E3A2D6E0A1D9DFA3BFC58767722E8B9A55D0E49DD6ECA4
D1E79FC9DD96DAE7A23D4303777739BABA7CEAEAACCFD897D5E9A4CAE8A0C5EEA2BFEB9E
C3EDA1C5EBA0CFEDA5C7DC99DAE6A6E6ECAED5D69AE0E0A45F60249DA665CCDB98D2E8A0
D0EAA0CEEDA1C8E99AC4E699CFEFA4BCDC91CFEFA6CCECA1C7E79CD0F0A5C2E297CBEBA0
C9E99DC9E99DC9EA9BC8EB9BC8EB9BC8EB9BC8EB9BC9E99DCAE89EC9E99EC5EC9BC2EE99
BFF097BEF097C2EE97C6EB9BCEEAA0D2E6A1D6E2A2DEE9A7CCDB965C7028748F42CBEA9C
D0EFA1BFDD93D0EBA6D3F1B1B9E1A5C1F3BE9CDAAB40835A75B291C8FDE1BDE0CA334F36
395330C5E2B6C5ECB5BCE9AE4E7F47538047A8C990D5EEB4C0D69692A965B3D38ABFE197
C1E29BD9F4AFD1E1A0CDD697ECEEAF909251A1A865D5E49FC5E39BE2FCB5D1D694D5D895
8FA75DC1E094CFE79BCADC92EAF1ADBCC782BED88FC4E59EC1E09CC6E5A2C9E8A5F3FFD0
FBFFD6D1DDABD9E8B1A7BB7E8FA866C9E49FD0EBA6CBE6A1
B7B77975753777783CD7DBA0D9E1A5D0DA9BDAE6A4CDDD96D0E296DAED9ECDE091D5E59A
D0DD97DEEAAAD2DCA0D6E0A399A863ADC277C5DD91CEEA9DC8E89CC3E599C6E69BCDEBA3
CBE6A1CEE7A3D2E9A5D1E8A2CFE6A0CCE7A0CBE9A1CCEBA5C9E9AAC1E0A4CAE9A6D6F4AC
C6E297CCE999CFEA9993AE5FD5F0A3C9E497CBE79CCDECA0D2F3A4D0F3A1C1E792C3E49D
DDF2C9F9FFECFFFFE8FBFADBE2E7BFE2EAB9D5DDA4969C5EABB26FDEEBA3D1E99BCAEC98
BDE38EC4EC96C1EB95C4F099BFE997C3EA9BC4E89ED5F9B1BEDF9AC7E8A1C7E6A0D2F2A9
CAE99DCAE99BCCE999CCE89BCFE79DD0E5A0D0E5A2D4E2A47C7D43545217646529E0E4A7
E1E7A7DCE5A289924F9DA762D7E29DD6E39DD3E49ED0E69ECCE89EC8EA9EC5EBA0C3EC9E
C3EC9DC5EC9DC8EA9ECCE7A0D0E5A4D6E1A5DBDEA5DEDDA75A5722A8A56ECACE93D4DF9D
D8EEA6C8E799C5EC99C7F19DC4E99BD1F1A5C5E59AC2E296CBEA9ECCEB9FCFEEA2CBEB9F
C2E296C9EB9EC6ED9EC3EC9DC5F2A1BFEE9DBAE998C2ED9DCFEFA3C6E599C9E99DCFF2A2
C4EB9ABDE795C4EB9AC5EC9DC9EB9EC9E79DD2ECA3C9E098CEE69CB7CF85698339D1EBA2
C8E19FE1F9BDD9F4BDCEEEBCD6FDD1D5FFDE8DC09F104527C7F9DEBDE9CEBBDEC077916E
293B11D2E3AFC4D297D9F1B5B6E3AC8CC28E7BAD7A81AF7EA9D3A1BDE2AE608148ABC78C
CFE5A7C9DC9AD8E4A2DBE29FEDEDADBCBA7D5C561C747539C8DD98DFFAB3C3D490D2E19C
D5E9A2687C35B2C17CDEEBA6D4DF9BD2DF9A5468234E6821BED994CBEAA4CFF0A9D9F8B4
E1FBBEE7FCC3E4F7BFC7D99FD8E7AE909B619199609CA169
716F343F3F03AEB277E9F1B5DCE8AADFEFAEC9DF97D8F3A6C5E28EC2E08ACEEA95DEF7A6
CFE39BCDDD9CBBC68C9AA569B0C079BDD285CDE597CFEE9EC8ED9DC1EA9BC5EB9ECBEFA5
C9E8A2CBE9A3CEE7A3CCE7A0CBE69FC8E89DC5EA9CC4EA9FCCEFAFC4E3A7C6E5A2CFEDA5
C5E194D2ED9CD3EC9B94AD5CCDE599CFE79DD1EBA2CBE79DC3E398C0E295C3E696D3F0AE
E2F1D2FCFFF3FEFFEDF6FADFD7DDB7D3D9ABCDD59C9AA56399A65ED1E397CFE897D0ED99
C5E793C8EE99BFE995C0EA96CEF5A4BDE294B7DB91C2E69EC4E5A0CAEBA6C6E7A0BEE094
C9EA9BC9EA99CAEA97CAE999CCE89DCCE7A0CCE7A4D1E3A5B4B37BAAA36D635C258F8D52
D6D69AD9DE9C79823FB1BE78D4E49BD0E69BCDE79DCAE99DC9E99EC8EA9EC6EAA0C5EB9E
C5EC9BC5EC9BC6EB9DC9E9A0CDE6A2D1E3A5D8E0A7DDDDA7524C1899945DF2F0B7DAE0A2
D5E6A0C8E799B9E08DC1ED98C1E899C9EEA0CAEC9FCBEB9FCBEB9FC9E89CC7E69ABEDD91
D3F2A6CDEFA2C6EB9DC0E99AC0EB9BBFEE9DC0F19FC4F1A0BADF91C4E498CEEEA2CBEDA0
C3E598C5EA9CCAEFA1C5EA9CC5EA9CC8EA9DCCEB9FCAE69BD2ECA2C4DA91849850C7DB96
D4E8ABE6FDC5ECFFD5EDFFE1E7FFE8DFFFEB96C7A91B4D30C2F3D6C6F3D4B6DEBB6C8D62
5F7745D1E4ACE0EBAFD2E4A6C2E9B0B7EAB2B7F0BB1C56238BC18FBCE8B7B3D3A191A872
CFDEA5DCEAACCCDD97D7E7A0C4CD8AD8DA9B8E834D615C24E8F8B7BBD58EDEF5AFD5EAA5
D3E4A071803D97A361C9D593D9E5A3D8E7A4C0D18D495E19B4CE87D0EEA6B1D188D0EFAB
C1DDA3F4FFDAF7FFDACADAADE3ECC1CCCEA6A4A07A5B5630
8D8D4FBFC084DAE0A2DCE6A7C9D897BFD38ED9F1A7C6E192CDEA98E0FDA9D6F29EBAD284
B9CD859BAC688593568A985AC8D891CCE194D1E99BCDEC9CC5EB98C1E897C2E998C6EB9D
CCECA1CBE9A1CDE7A0CCE89ECCE89DC9EA9BC7EA98C3E898CDEFA5C6E7A0C5E59ACBEA9C
C8E593D4F09CCEE7968BA254D0E69DD3EAA4CCE2A1C7E09FCDE7A6CCE9A7CBE8A5D1EAB1
DEEFCFF6FFECFBFFEAF8FFE0DBE3BAD6DEADDEE8ACBDC88693A058CDDF93CEE595D1EC9B
C8E797CCEF9FC3EA9BC3EA99D3F6A4C8EB99CBEDA0CCEEA2C9E9A0C7E79ECDEDA2CAEA9E
C9EA9BC9EA99CAE999CAE99BCAE89ECAE8A2CAE7A5D0E4A7D7DAA1E9E6AFC9C78E919256
54581B585F1C76813DCFDF98D3E59BD0E69BCDE79DCAE99DC9E99EC8EA9EC6EAA0C6EB9E
C6EB9DC6EB9BC8EA9DC9E99ECCE7A0D0E5A2D4E2A4DAE0A461602757551CDDDDA1CFD494
CEDD98D5EFA5CDF0A0C9F09FC5EE9FC2EB9DC8EEA1C6EB9EC2E297C8E69CCDEBA1CAE69C
CCE69DC5E197C7E59BCCEAA0C9E99ECBEDA1CAEFA2C1E699CCF1A3C7EE9FC4EB9CC5EC9D
C9F0A1CDF4A5CAEFA1C2E799C7E79BCBEA9ECBE59BD2E89FDAEBA4D3E09AA3AE69ADB977
C4DA9AD9F5BAE1FFC9D6FBC8CBF6C9CDFDD591C59F0C441FAEE6C1B9F0C99BCEA5083607
163E0ABCE2A9D0EFB3B8D696CBE9A9C2E9A6C0F4B2A1DC9C90CA8D538349C0DBA68B9C66
7E8C51B8C889E4FFB8CFEFA4C6E099D7E6A5B0A972767139899555C1D892D5EAA5D2E6A1
D6E7A3D2E19E9FAE6BD3E29FE0EFACC5D692BACE89D9EEA98EA55F9BB56EDBF6AFC3DFA2
C7DEB4F5FFEAF7FFEADEEBD1E9F1DAF3F5E0F3F0DFDED7C7
959A5AD2D797F0F9B8BCC886E7F8B4D0E69EC7E197D0ED9DC6E693BBDB88C8E59394AF60
6379306C803BC7D796EDFDBCD5E4A1D5E69FD2EA9ECCEB9BC5EB98C2E996C1E895C2E797
CCECA0CDE99FCDE79ECEE89ECEEA9DCCED9CC9EC98C6EC97C6E997C9EC9AC9EB97CDED98
CAE892D1ED99C7DE8E869C51C3D991D9EEADD1E5A8CDE2A9D4EBB3D0E7AFCAE3ACC6DEAE
E9FDDAF3FFE6F4FFE0F2FED6D9E5B7D3DDA8D7E3A5B6C37E99A960D2E498CEE597CEE99C
C6E297CCECA1C7EBA1CCEEA2C5E697C8E797CCEB9BD4F3A5C1E094C6E599C8E79BC9EA9B
C9EA9BC9EA9BCAE99BCAE99DCAE8A2C9E8A4CAE7A7CFE5A7DBE3AAD3D49BEFF3B8BEC486
4C55165D6824BBC883D6E7A0D0E69BCFE79BCCE89DCAE99DC9E99EC8EA9EC8EAA0C8EA9E
C8EA9DC9EA9BC8EA9DC8EA9DCAE89ECDE79ED1E59ED6E2A0929858525415DDDFA0ECF1AF
DEEBA6C8DE95CFEBA0C3E598C7F0A2BCE798CAF0A3C6EB9EBEE094C9E79DCEEAA0D0E79F
CEE49CC9DF97D1E79FD6ECA4CFE59DD1E79FD4EBA3C9E39AD2F2A7C5E79ABDDF92C2E799
C8ED9FC0E597BFE194CBEB9FCAE99DCFEBA0CBE198D3E79FD9E9A2D4E19BB6C07B8D9957
D8EAACCEE6AAC7E3A9CAEBB4C6ECB9C4EFC18EBF92194E22A9E0B68DC699639D6D366F3C
396E38BCEFB6C4F6BBC6EFADD4EEA5BDD98CBCE89DCBFFB8BCF1AD5B874ACFEAB3AEC18A
6C7E42D6ECABB1D58BC2EB9FC1E399D3EAA6E5E6ACA6A56C919B5CEEFFBBD0E19DD1E29E
CDDE9ACDDE9A92A35FB1C27ECADB97D4E8A3EEFFBDCADE99A2B77299B06ACCE39DD2EAAE
CBDFBAEFFFE7F2FFEAF9FFF1F8FFEFEFF3E5FDFAF1FFFFF8
D0D794DFE8A5D6E19DDEEDA8C8DC9580984E86A255ABCA7CABCA7AA7C67694B36391AD60
D6F0A6DBF2AACDE29DC6D997D3E3A4D3E3A2CFE69ECBEA9CC8EE9BC7EF99C6EE98C6EC99
C9E99DCBE79CCCE69DCDE79DCDE99CCCEC99CAEE97C7EE95C3E78FCCEE97CCED94CDEE95
C9E791CDE995CBE2949EB46B7E914FBFD195CDDEA7CDDDACD2E3B6D1E2B6E7F9CFF5FFE1
DBF1CAD5EBC4CEE3B8D7E9B9D1E2ACD2E1A6CFDE9DA4B36E9DAD64D5E79DD1E59DD1E8A0
C7E19ACBE9A3C8E7A4CAE9A5CEE89ECFE799C3DE8FDAF5A6C6E295DBF7AACDE99CC6E597
CAE99BCAE99BC9E99DC9E99EC9E8A4C8E8A5C9E7A7CCE6A7D3E1A6CFD99DD9E3A6D5E1A1
CBD797CAD994DCEDA7CCE299CFE79BCDE89BCCE89DCAE99DC9E99EC8EA9EC8EAA0C8EA9E
CAE99DCAE99DC9EA9BC8EB9BC8EB9BC9EA9BCDE89BD1E69BD5E199868D49898E4B999E5C
D0D996D1E09DD5E9A4C8E39CC4EA9FB9E397CEF4A9CBEFA5C9E9A0D0EBA4C6DD97CCE09B
DAEBA7D8E7A4DAE6A4D7E2A0D0DB99D2DD9BDBE4A3DCE9A4C7DB94D4EBA3D4EBA3CDE79E
CDE99FC7E399C9E59BDAF6ACCEEAA0CEE89FCCE39BD1E79FD3E7A0D1E29CC1D28C869552
DCE8AACED99DCCDBA2DDF0B8CBE4ADC1DFABD1F6C3C1EBB94F7F4D5E94626DA77480BC88
2A663236754063A26B8ABC7DC7E291E3FAA2C4E692C3EC9EACD790C8F0B169884DCCEAAE
BAD89A95B572CDF5ACC5EFA3D4F8AEBCD792CBD99BDEE6AA576122616D2BC5D18FD4E3A0
DEEDAADFF0ACD1E29E4C601BE2F6B1C4D893CFE39ECDE19CD6EAA5ACC07B90A45FCBDDA1
CFE2B5E6FAD7E0F1D1F9FFEAF9FFEBFCFFEFF6FAEBF3F7E9
DFEAA6D4DF9BD0DD97C8D992A1B76E4A6216D1EDA0C5E496CCED9EBCDD8ECCEB9FC7E69A
BCD88EC5DF96DDF4ACCEE3A0CEDDA4CDDCA5C9DF9FC8E39CC7EA9AC7EE9BC7EE9BC8ED9D
C5E599CAE59ECDE7A0CCE69FCBE59BC8E797C7EB94C9ED93C9EC92CFF097C8E992CBE993
C8E392CCE496D8EEA5C6DA9596A667DEEDB4DBE9B4D0DDAFD4E1B6CFDBB5E2F0CDEBFDD7
DCF6C9CDE9B8BFDAA5CAE1A9D1E5A8D9ECACD2E39F9DAD6696A65FD2E29BD4E59FD7EAA8
CDE3A3CFE9AAC6E2A7C7E1A4CFE4A3D6EAA5D2E8A0D7EDA4BBD387CAE294CCE798D1EE9E
CCE89BCAE99BC9E99EC9E9A0C8E9A2C8E9A4C8E8A5CAE7A5D0E4A5DEEEB0D3E3A4D6E9A7
E3F6B4D1E79FCCE39BCBE399CDE89BCCE89BCAE99DCAE99DC9E99EC9E99EC8EAA0C9E9A0
CCE89ECCE89DC9EA9BC8EB9BC6EC99C8EB97CAEA97CFE897D9EC9DC8D48A5F6622525715
A6AC6CD7DFA3D8E3A7DCEFAFCCEBA5BFE59ACBEDA3C2E299D0EBA4DDF4AECBDF9AE2F3AF
CCD896D8E3A1DAE0A0D9DE9EE0E5A5DFE1A2DADC9DE1E6A6D1D895E6EFACDBE6A2C8D590
D7E6A1DEF2ABD0E69EC6DD95D0EAA1C9E39ACDE99FCBE79DCFEBA1CCE89EC9E59B9DB26D
CDD999DBE3A7D5DFA3D1DFA2CFDEA5D2E7AED7F0B7BBD9A3BFE4AEC3EEB9C1EFBE1A4E1D
093E10BAF3C6AAE5B9588B52BEDE89C8E082E5FDA9B9D187DCF9B7D1F3B686AE72CBF7BA
BAE8A767924DBFE49EB8D992C3DE97DDF7B0D6EDA9C3D6947A8543737939DEE7A6D3DE9C
D5E4A1CCDD99CCE09BD6EBA6465B16CBE09BD9EDA8CCE09BCDDE9ADBEAA78F9B59D2E0A3
D5E7B5D6E9BCC9D9B2F0FFDBF7FFE2FBFFE8FBFFECFBFFEC
D2DF99D8E8A1D3E59BC7DC8F698133D3EE9FBDD98CD4F3A5C1E196D7F7ACD0F0A7CEECA4
CFEDA3D1EDA2C7E398D7EEAADDEABCDAE7BCD2E6B1CCE6A7C6E89CC4E999C5EA9AC8EA9D
CAE8A2D0EBA8D4ECAED1EAA9CBE4A0C5E498C7E897CAEE97CCEC97CFEC98C5E292CDE89B
CDE79ECBE29CD9EEADD6E8AA88975CD3E2A9CCD9A4CFDBABEEF9CEF6FFDBFCFFE4F8FFE3
F1FFDCE6FFCED2F1B5CDEAAACCE5A3D3E8A3C9DA938F9F5893A35CCFDE99D2E1A0D8E8AA
CFE2AAD6EAB5D0E6B5D3E7B4CCDAA7D2DFA9E0F0B2B8C8879FB36C94A95EC0D789D3EB9D
CCE89BCAE99BC9E99EC9E99EC8EAA0C8EAA0C6EB9EC9E9A0D2EDAACDE3A3BED493CBE4A0
C0D995C4DE95D7F3A9CAE69BCCE89BCAE99BCAE99DC9E99DC9E99EC9E99EC9E9A0CAE8A0
CDE7A0CDE79ECAE99DC8EB9BC5EC99C5ED97C8EC95CAEA95BBD282F4FFB9CAD18DBABF7F
7E8247B2B57ECCD19BD8E3A9D4EAA9CAE8A2CEE7A3BDD490D6EBA8D9ECAAB4C382D5E1A1
DDE6A7EDF3B5DADEA1D4D599EBECB0E4E4A8D1D195E0DEA1E1D99BE7DFA1D0CA8CC4C383
D8DA99D8DF9CCDDA95D7EBA4D3EAA2C1DD93D0F0A5C3E89BC7EDA0C2EB9DC6F1A2B5DA8D
425611A6B272D6E2A2D8E4A4CDD999CAD698D7E5A8D9E8ADD0E3AC738A564F693A021E00
13330E82A58555795D85AC7FC3ED9BD0F294DBE99CDBE1A1C6D199D6F1BCB8EBB26BAB6E
BBFCBA88BD79173600D0E09FE0EBA9C8D792CCEEA4D2F2A9E8F4B23E4303636929CFD897
CFDB99D5E6A2D2E7A2D1E8A2D6EDA793A863CEE29DC8D995D9E8A5DFEBA98C9755556123
CDDFA5C4D7A0CDDFABF8FFD8F8FFDADEEFC3D9EAC0E2F3C9
D9E9A2C5D68FD8EDA0516818CFE897C4E18FDDF9ACBDDC90D0EFA9CCEBA7BFDE9BCBEAA6
C2E098D5F4A8CAE999C4DD9BF9FFDFF4FDE0E7F8CED8F1B8CCEDA8C6EB9EC6EB9ECAECA2
D0EDABD9F1B7DEF3BBD9EEB6CDE5A7C6E49EC8E89CCEEFA0CCE89BCCE69CC4DE97D4EAA9
D6EBB0CADDA5D1E2ABCFE0A998A76EF1FFC7EBF8C0E3F0BAF1FACBE4EDC2EEF6D1E3F2C7
E1FEC6D6FABAC7EAA8C4E39FC6E099D8EEA6D7EBA3A4B46B99A660D2DE9CD1DCA0D4E1AB
CDDDACDAEBBEDEEFC5E5F4CDF2FAD5DFE7C0ECF5C6A4B179ABB97B90A15BCEE29AD4EA9F
CDE79DCCE89DCAE89EC9E99EC9E99EC8EB9BC8EB99C8EB9BCDECA6E1FEBCD3F0ADDDFBB5
C2E09AC1DF95D0EEA4C9E99DCAE99BC9EA9BC9E99DC9E99DC9E99EC9E99EC9E9A0CAE8A0
CFE6A0CFE69ECAE99DC8EB9BC5EC99C3ED97C5ED95C9EB95D9F1A3D1E399D4DD9AE9EDB0
494913A8A876E8E7B7CDD4A0CCDA9DD3E6A4DCECABCBDB9AE2F1B0CBD7977C8848919B5C
959E5F949A5C595F21383C0053571A4F53163F43065D5D2163591E665A1E5E5417615B1D
5C5B1B4042015D6623B4C37ED6ECA4BFD990D3F3A8C0E598C2EB9DBCE798C3EFA0C9EFA2
D4EBA5ABBA77727F3A95A25DDDE6A3DFE8A5D3DC9BD7E1A26F7A40DEECB783946796AB84
839B7BA5BFA67C99835A7E580030002C5600B5C17FDFE2ABDAE0B2C6DDAFB1EAB580CA8D
57A261BDF5B4CFE7A973773AE9E7AAD2DB98C9EB9FC3E89BD3DF9DE0E2A37378384D5615
DEEAA8D6E7A3C8DD98D3EAA4CAE19BD1E6A16B7F3ABCCD89CEDD9AD1DC9AE1EAA996A061
D7E6ABCCDFA7D4E7B0F8FFD4F2FFD0D3E7B4D2E6B5CDE3B2
DEEFA9D2E39CA8BD70A0B767C8E190D1EE9CC6E295CCEAA2CCEBA8C5E3A5C9E7A9CBE9A9
C7E6A2C9E99ECCEE9AC8E19FF9FFE8FBFFF2F6FFE6E0F8C8C5E5A6C3E7A1CBEFA7C8E8A5
C5DEA4E5FCC8F0FFD6DFF2C4D1E8B2CAE4A7C5E49ECAEAA1CBE4A2D0E6A8C9DEA6D5E7B5
D6E7BBCCDDB1D4E4B7D0E0AFA9B881CEDDA2BFCD8FA0AE71F1FCC2D2DCA7D0D8A9D3E4B0
C7E5A7C8EDA8C9EDA7CAEAA1C3DD94D3E9A0D1E39990A0596E7B36939D60A9B27BD4DEAC
D8E3B9E9F5D1FBFFE6F8FFE7FFFFEFF5F7E2FFFFE4AAB187D0DAA58F9D5FE3F4B0C4D891
CEE59DCBE59CCAE59ECAE89EC9E99DC6E995C8EC94CDF09CDEFFB6E9FFC6E3FFBFCDEEA7
C2E19BC8E89DCDEDA2C8EA9DC9EA9BC9EA9BC9E99DC9E99DC9E99EC9E99EC9E9A0CAE8A0
CFE69ED0E79FCBEA9EC9EC9CC6F09EC7F19DC7EE9BC5E896D2ECA2CADB95E1EAABEEF1B8
7E7E4C9E9D6FD3D2A6DCDEAFD1D69CD5DE9FE1EAAB959E5F919A5B8A93542D3600525C1D
5761227B85469FA96A899354A2AC6D96A0618A94559CA2649E9E609E9A5DA19F62909052
9D9F60969C5C9FA86794A05E5F702CDCF1ACCBE59EBFDA93D8F8AFBEE096C6EAA0CBEBA2
CEE49CCEDD98B5C27C95A25A96A059B3BD76929D589DA864ABB97BE2F3BC96AC7BC8E1B9
88A684BBDCC18EB19D335F3C4D88467EB0678A9F6799A2779EA885CCE6C1ADE6B99BE4AD
5FA66ABEF4B6D0E4A978773EE0DA9CCDD28FDAF9ADC1E195CDDA95E3E8A8BFC5854E5917
9FAB69C6D793E0F4AFC4D994D3E8A3C5DA95798D4890A15DD9E8A5D1DD9BD2DD9BD5E1A3
A8B57FD2E2B1CDDDACF8FFD8F8FFDAC6DAA9D5EBBAC9E1AF
CFE09CA4B870A8BF71CAE191CDE693CAE594D0ECA1C9E7A1D0ECB1C7E4ACC8E5ADC9E6AC
C4E2A2C8E89DCDEF9BCBE5A4FBFFF1FCFFFBF8FFEFE5FAD1C9E6ACC4E8A2CAEEA8C6E6A5
CAE2AEE8FED0F6FFE1ECFED8E5F8CBD9F2BBCDEBABCCE9A9D2E7AFE3F3C4E2F1C8E9F9D5
E7F6D7E0EFD0E9F9D4E4F3C8F2FFCDE0F2B4DBECA8BCCB86707F3EABB67AD4DFA7CCDEA4
CFEEABC7EDA4C3E59BCDEBA1CDE79DD1E79CD3E39AACB974535D1E9AA269BFC693EEF5CB
EFF6D4F1FADDFAFFEAFAFEEFF2F1ECFFFFFAF9F8E6A4A887858D5E859056CAD89ADEEEAD
C8DD9CD6ECABD7F0AECBE6A1C9E79DD2F3A2D0F29BC2E68FCEF2A8D5F8B4D3F7B1C7EBA3
C3E49DC8EA9ECCEEA2CAEC9FC8EB9BC8EB9BC9E99DC9E99DC9E99EC9E99EC9E9A0CAE8A0
CFE69ECFE69ECCE89EC7E99CC4EA9DC3EC9EC4EA9DC7E79ED8EFABCFDFA0CED79EF1F3C1
BAB98B9B9970E4E5BDF3F4C8C9CA9158591D48490D7074378E9456ABB475C0CA8BDCE8A8
E0ECACEBFAB9EFFEBDCFDF9EDAEAA9D0E09FD2E2A1D9E9A8D3E29FDDE9A7DCE8A6D8E4A2
D6E2A0DBE7A5CCD896BAC68456622053621F233200A0B16DBDCE8ADDF1ACD5E9A4C9DE99
CBE59CD4F0A6CBE59BCCE498CEE499DEF3A8C6DB90D1E59ED1E6A5C7DFA3CFE7B5415E32
2645233254395F826EA1CEAFB4EFB7BFF5B9C9EABD000B009FB39741604191C59FA8E6B7
A8E3AD79A66DC9DDA2CED297636325E8EFACC5DC94CFE9A0E2EEACC8CE8ED3DC9BDDE8A6
4A56145F6E2B9FB06CDCF0ABD7EBA6D8ECA7C0D48F92A35FB6C582D7E6A3E0ECAADCEAAC
9BA870D8E6B1D3E1ACF2FFCDF5FFD3CCE0ABD9F0B8CBE4AB
5A6D2B90A45DB7CE80C7DE8ED1EA97CEE998CCE69DD8F2B1CDE6AFCAE4B4D2ECBDD3EEBB
C9E7ABC8E89FCCEE9ACBE5A4F9FFF4FCFFFFF8FFF3E5FAD3CAE7ADC7E8A3CCEDA8C6E4A4
C9E1AFE5FAD1F7FFE7F5FFE6F2FFDEE1F9C9CEEAAFCAE3A9D4E5B8F4FFDCFBFFEAF9FFEF
F7FFF1F4FFEDF8FFECEFFFDACFE1ADCDE2A1D8ECA4C9DE91D8EAA0C1D08B2E3C00D6EAAB
C6E59FC8ECA2BEDE93CAE69BDDF5A9DEF3A8C9D69095A05E686E32BDC28CCACDA0F0F4CF
F8FBDEFBFEE9FEFFF1FFFFF8FFFAFFFFFDFFFFFFF6E5E8CDD0D7ADDDE7B2D2E0A5D6E6A8
CDDFA5CFE2AACFE4ABCAE2A6C9E4A1C9E79DC8E895C3E591C9EAA3C7EAA6C6EAA4C6EAA2
C6EAA2C6EB9EC7EC9FC8ED9FC8EB9BC8EB9BC8EA9DC8EA9DC9E99EC9E99EC9E9A0CAE8A0
D3EAA2D2E9A1CEEAA0C9E9A0C4E8A0C3E8A2C9E9A6CEEBABCBDEA6E7F4BFE6ECBED2D5AA
9D9E76888A63D9DEB6585B2E62632A5757198F9152EAEFAFDDE3A3C6D18FE8F4B2CEDF9B
CBDC98D1E5A0D0E5A0C6DD97CFE6A0CAE19BD5ECA6C9E49DC7E99FBFE59AB7D98FD1F1A8
CAE59ED4EBA5CADB97D5E19FD1DA99E1E7A7595B1C5B5B1D5F5F21D1CF92E6E4A7D6E19F
C4EDA1C1F6A4B0E491C8F8A4C7F4A1C4EE9CBFE697CCF0A6CBECA7CAE9ADCCE8B55F7C50
000D00536F56C8E5CFBCE0C6B1E1B7B0E6B5C5F5CDBEEAC74E7759B5DCBF5C8364C9EFCA
D4F8CA85A36FC1D99FDAEEAF465617596928DAEAA9D2E2A1D0DC9ADEEAA8DFEBA9BDC987
EAF6B4505C1A394805D2E19ECEDF9BCADB97E5F6B294A5618B9C58D0E19DD0E49FCEDF9B
7E8D4CCDDB9DCCDA9CD3E3A4D9EEADC6DC9BD1EAA6C8E19D
869959D6EAA5EBFFB6D5EC9CDAF19FD2EB9AC3DA94CDE5A9C6DCADD1E8BEE6FCD5E7FFD4
D3EFB5C7E6A2C9EB97C9E3A4F7FDF3FBFCFFF7FFF1E2F7CEC7E5A7C6E89ECDEFA5C9E8A5
C9E1ADE4F6D0F6FFE8F8FFEAF6FFE5E1F8CACBE7ADC9E2ABD3DFB7F9FFE5FCFFF1FBFFF6
F8FFF9F8FFF8F7FFF1E3F4D2E9FDCADAF0AFC5DD91D5EC9ADDF2A5C2D68EBCCF8D94AA69
BEDC96E2FFBAD8F6ACC5DF95CBDF97CBDB94A5B06C626B2C92955CE3E5B4C8C9A1E8E9C9
FCFBE6FFFFF1FEFFF5FFFFFDFBF5FFF6EEF9FFFFF8EAEAD2E8EDC4D3DCA7CDD8A0E9F6BE
F1FFCCCFDFB0CBDCB0E5F8CAE4FBC5C8E2A3C9E49DE5FFB9D3F4AFC8EBA7C4E8A2C9EDA5
CAEEA6C5EA9DC4E99CC8ED9FC8EB9BC8EB9BC8EA9DC8EA9DC9E99EC9E99EC9E9A0CAE89E
D3EBA1D1E99FCCE7A0C9E8A4C6E6A5C6E5A9CCE9B1D6ECBBD6E6B9E1E9C0D6DAB7FCFDDB
E7EBC86D734F9FA780A0A77BBABF85E4E9A9D4DA9ADAE3A2D8E4A2C8D794DAEEA9CDE29D
CDE49ED2E9A3CFE9A2D4EEA7D2ECA5CDE7A0D8EFA9BEDC94C8F2A6C9FAABC4F0A3C8F1A5
BFE197CBE69FD1E5A0DFEBA9D3DC9BE6E8A9B4B275ABA5697970353F36005A50158D8D4F
637A34BEE298D6FBAED0F5A7B0D587C0E597D0F6ABBCE299C7EEABBAE2A4C1EAB25A8454
16431AA7D5B1B8E5C6BCEBCB85B58D80B58B57916883BD9781B795BCE8C7AFCCADB6CAA7
C8D9AFA0B4819CB87DC6E6A5D2F2B16C86479DAF75CEDCA1D7E7A8C5D994DBECA8DCEBA8
D7E3A1737F3D616C2AD0DB99DBE7A5C3CF8DE3F2AFBDCE8A8DA15CD5ECA6CEE59FCCE29A
8B9B52D8E59DDBE8A0D0E097D5EA9FCCE297D0E89CCEE99C
D0E2A4C1D492C7DC91CFE495C8DE8CCEE597D8EDAACDE2AACCDEB4DDF1CEF4FFE8F2FFE3
D5F0BBC5E2A0C8E998CFE9AAFCFFF8FEFFFFF8FFEEE1F7C9C6E5A1C5E898CDF0A0CAEAA1
CDE4AEE3F5CDF3FFE5F8FFEAF6FFE5E0F6C8CBE7ADCFE6AED4DEB9FCFFE7FEFFF3FAFFF8
F8FEFCF8FFFDF4FFF3CFE2C4BCD2A1D4EDACC8E396C3DF8BD4EC9EC7DF95DEF3B0485E1D
86A45EB9D78FC7E198CCE39BDCEDA7D4E19C9DA665505419959561EDECBEC6C3A0F1F0D4
FFFFEFFFFFF4F9F8F3F9F7FAFFFCFFFFF8FFFFFFF6E2E2C8DBE1B5D0D9A4DFEAB2FCFFD4
FCFFDCD4E0BCD0DDBFF7FFE7F8FFE3D1E4B7CFE3AEF1FFCEDDFBBBCEEEABC7E8A3CBECA5
CDEEA7C6E89CC5E79BCAEC9FC8EB9BC8EB9BC8EA9DC8EA9DC8EA9EC8EA9EC8EAA0C9E99E
CEE99CCAE49AC9E49DCBE8A6CBE8AECBE7B4D3EABEDFEFCAFCFFE6DFE3C8D1D4B9F3F6D9
F5FADCF9FFE0F9FFE1BCCC9DD4E2A5EBFAB5CDDE98C9DD96E5FBB3D2E9A1C0DA91D1EDA3
D5F1A7D1EDA3C9E59BCBE59CC4DE95CDE49CD7EDA5CCE7A0BFE89CB3E196BBE59BC0E49C
D3F2ACCEE7A3D2E5A3CFDB9BE0E9AAD9DDA0E2E2A6E0DEA3E9E4AAE5E0A6D7D298665B23
634E17684F1978632CD8CC92F0ECAFDCE2A2D2E5A5CFEEABB8E19F598D4D417E42A4EAAE
76C38D95E8B4328857408E5E164F225C8F643A794C4D8E637FB88FE6FFEAF5FFE4F6FED7
A5AB7F93A06BC8E7AB517B39BAE6A7B4DA9F3A50219AAC7AC5DE9DD3EDA6C5DC96E1F5B0
C2CE8C8C9755525B1AE7EDADDFE8A7D0DB99D3DF9DDEEFAB91A862D1ECA5CCECA3CDE99E
9CAF5ED3E28FDFEE9BD3E593D5E897CDE293C8DF8FCFE799
D5E7A9DCEFADDBEFA7D4E99CD4E99AD5EA9FD1E4A4CBDDA9E1F1CCEDFDE0F5FFECF2FFE4
D1E9B9C1DE9CCCEB9BD8F1B0FCFFF6FEFFFFF9FFECE6FAC7C8E69CC5E991CCF099C8E89C
CDE5ABDAEDC0E6F3D5F0FFE2F2FFDEDDF3C4C9E5AACFE7ADDAE2BBFEFFE8FFFFF4FAFFF9
F9FEFFF8FFFFF2FFF5CBDFC4DCF4C4B7D492D9F5AAD7F4A2C6E393D4F0A6C5DE9DAFC887
9BB671C3DE97DAF1ABDAEEA7BFCE89A4AF6DA5A96C999A618C8A59E6E3BABCB797F5F0DA
FFFDEEFFFEF8FDF9F8FFFDFFFDF7FFFFFDFFF3F1E4D8D9BA9FA577CBD29CD8E1AAECF6C4
F7FFDAE7EFD7EAF3E2F9FFF4F9FFF1E7F5DBDCECC8E0F6C7D8F4B9CCECA9C5E6A1C8E9A2
C9EAA3C6E89CC7E99DCBEDA0C8EB9BC8EB9BC8EA9DC8EA9DC8EA9EC8EA9EC8EAA0C9E99E
D0EC9FCCE79ACDE8A3D6F3B3DDF8C3E0F7CBE6F7D5EEFBE1F6FBE7FFFFF1F9F8E6F2F4DF
F4FAE0F6FFE3D9EBC5DCF2C1C2DB9AC5DF96CEEAA0CCEAA0C8E89DC5E59AC5E59AD3F3A8
C8E89DC4E298C8E49ACCE69DCCE39BDFF3ACCEDF99D3E9A1BEDC94E7FFC1CDEBA5415A16
182F00566927C2D190E1EDADCCD697DBE4A5D5DE9FCFD899C7D091DCE6A7EDF7B8D4D498
B39A64BB9A679375416A55203C31005A5920838D518CA16688A56B143B02001400C3F8C2
79B27F3E7949155324336E40B7EBBBB0E6B5A6E4B3094716D9FFE0EAFFE3DAE9BEFFFFDA
EFF1C068723DBEDE9FA2CE8F5385488DB9849DBD94779265D4F4B3C2E299C9E49DCBE09B
E8F7B47D8645484D0DD8DD9DD3D898E2E8A8CCD896D8ECA788A25BBDDD94C5EBA0C7E99C
90A354B1BE6ED1DE8FD1DF92D3E39ADBECA6D3E6A4D7ECA9
606F34B5C586D0E19BC5D78BD7EA9BD8EDA2D3E5A7ECFECCF1FFDFF5FFEBF5FFEFEFFFE5
D1E9B9C4E1A1CBEA9AD3ECABF7FEEEFCFEF9F9FFE8E7FCC4CBEA9AC7EA8CCCEF93C6E693
CBE4A3CEE2B1D4E2BFE5F4D3F3FFDCE1F7C6CDE7AACFE4A9DAE1B8FFFFE5FFFFF3FEFFFB
FAFFFFF8FFFFF3FFF8D5E9CEB7D1A2DBF9B9BEDC92D0EF9FC7E69AC1DF99D2ECAFCBE4AA
C2DB998CA35D5E722D70813D9AA664C3CC8BD8D99DB8B77F9B9969E4DFB9ACA588F2EBD8
FBF5E9FFFCF8FFFEFFFFFDFFF8F3F9FFFEFBEBEAD6CED2AF535A279CA46BDCE5AEFEFFD8
FEFFE6FCFFF1FBFFFBFBFFFFFBFFFBF9FFF8F0FCE8DCEDCBCDE8B1C9E8A5C7E6A2C8E7A1
C9E8A2C9E99EC9E99ECAEA9EC8EB9BC8EB9BC8EA9DC8EA9DC8EA9EC8EA9EC8EAA0C9E99E
D2EF9FCBE79ACEECA6E0FCBFEEFFD8F2FFE1F6FFEAFCFFF3FDFDF3F7F4EBFFFDF2FFFFF1
F1F9E2EDFCDDD1E7C1BCD8A7CFF3ADC6ED9EC6ED9EC2EB9CBAE394C8F1A2CEF7A8B4DB8C
C8EA9DC3E397D5EFA5D2EAA0D1E59DD8E8A18E9B5596A15D838E4C7781429AA364D5DE9F
E5EBADB5BB7D959E5F97A162A1AD6DD9E9A8D5EAA7D6EFABD1EFA9C4E59EB3D78FCFEDA7
CCDC9BCED899D3DD9ECEDA9CA3B174A5B37895A26A939D699AA0705A5B3155512C4D4222
604F35220C003A1F0CD0C9ADC1E2B3C2F9C08FC68FB3E5B0B5E0ABC7E5B3D2E3AFE5EEB9
D4DDA48D9C611F3B00D1F9BDAFDEA890C1926A987386B186B8E0A1D1F5ABCDEDA4C7DE98
C8D7948A93524F5112ECECAEDCDC9EE9EEAED9E4A2D4E8A3A8C37CC0E49AC3EDA1CDF1A7
8C9F5DA0AA6DD3DDA1D9E4ACDDEAB5FBFFDAF3FFD7E8F7D0
73834594A463CADB95E4F6ACD4E69CCCDD99E5F3BEF9FFE1F8FFECF7FFF3F7FFF6F3FFEB
D9EEC7CCE3ABCAE69CC9DF9FE8F0D8F0F4E5F4FFDCE5FAC1CEEA9FCAEB94CDEE97C7E492
D0E9A5CBE0A7CBDCB0E3F3CCF8FFDFEFFFD4D6EDB7D3E5B1D5DCB3FBFBDFFFFFEFFFFFF8
FAFEFDF8FEFCF8FFF8E1F1D7E1F6CBEBFFC9D3EDA6C7E197D5EFA8CDE6A5C8DDA5CEE3AB
E4F8BBDBF0AFD5E8A6D7E7A6CBDA97D7E1A2DFE2A9AFAD7AADA87EE5DCBBA59A84FAF1E2
FFFEF6FFFEFBFFFEFFF9F7F8FFFDFBFFF9EDBDBDA3B9BB9358552298955EDBE2ACF8FFD3
FFFFE6FFFFEFF8FEF4E2ECE3E0EBDDEAF6E2E6F0D5D2E1B8CCE1A8CDE6A4CFE8A4CDE79E
CDE79DCFE99FCEE89ECAE69CCAE8A2C9E8A4C9E8A5C8E9A4C8E9A4C6EAA0C6EB9EC8EA9E
CAE8A0C5E09DCBE5A8E3F9C8F6FFE2F8FFECFBFFF3FFFFFAFFFEFDFFFEFDFFFEF9FFFFF4
FBFFEDDFF0CEC8E2B5CDECB3BBE198C9F0A1C0E99ACEF7A8CAF3A4B8E192CAF1A2CAEFA1
CEEEA2C4E397D8F0A6CCE299CFE099D2E29B69742F737C39BEC484DFE3A6DEE2A5DDE2A2
CED494DEE4A4B7C07F8E9A587C8B4896AA65BED591D0EBA6CDECA8C9EAA5CFF4AEC3E7A1
D4F2ACC3DE97D4EFAADBF4B0BED795D2E6A7CBDA9FDDE6B1D6D8A7C8C195A3946DA38B69
98765A7B533A70422B856C4D95A976A8D19781A871CAEDB7CCE8B5D2E9B5CEDFA8CCDBA0
CDDC9BB4C7858DA66486A667C0E7B0BDEBBA689B7268976983AA69BADF92CEF7A9C2E69C
CBE29CC7D290767638BBB77AE0E1A5D1DA99D1E29ECBE09BCEE8A1C8E89DBADF92CDEFA5
8F9F609BA46BD5DFAAD4E0B0D5E0B8FBFFE4F1FEE4D5E1C9
909F5C95A45FD1E09BD5E4A1CCDA9CDEECB7E8F4D0F2FBE6F9FFF9F9FFFFF9FFFFF1FDF3
EDFBE2E1F2C8CFE2AAD5E7ADD6E1B7D4DEBBF6FFD8E4F6C2DCF1B6C8DE9DCAE49DD5EFA6
CBE29CD5ECA8C4D89DEEFFCCF8FFDCF3FFDCF9FFE4CAD5B3D9DDBAFFFFE4F9F8E4FFFFF4
FFFFFAF7F8F2FFFFF4C3C8B1939B76D6E0AEC5D094C3CF8F788446D5E0A6CBD5A3DFE9B7
E4F1BBF9FFCFD6EAABC8DE9DCDE4A0DCEFAFC4CD96BFC192F2E9C8FFFDE8D7C5BBFFFAF6
FFFAF9FFFFFDF8FEFCFEFFFBFFF7EBFFFEE87E805BA5A2776F572B9E8658D9D9A7FEFFD8
FFFFE1FFFFE6F2FBDED7E7C3C4D7AAD6EAB5CEDEA0D6E5A4D1DD9FD9E5A5DAE7A1CAD88B
DAE998DEEC9DC5D58ED7E7A8D4E7B0C3D9AAD4EEBFC8E4B3CDEFB3BAE29BBDE896CAF3A5
D0ECB2C7DAADD7E9C1E4F2D1F1FBE3FEFFF6FFFFFDFFFDFFFFFCFFFFFDFFFEFEFEFCFFF6
F6FFE7DDF2C7CCE5ACCFEEABC4E49BD3F3A7BFDF93CDEDA1CCEB9FD2F1A5BBD78CD3EFA4
CFE99FCDE59BDCF2A98A9E568B9C55C5D58ECADA93D5E49FD3E4A0D1E5A0D1E5A0D1E59E
D3E49DD3E59BD3E59BD3E59BC9DB9195A65F808F4C8D9C5B919F6294A267B2C085D3E3A5
D3E7A2DBF1A9C3D991DBF1A9CADF9AD3E8A3DFF4B1CCDF9DCEDE9FD7E7A9D9E4A8E6F1B7
899158A3AA74E7ECB65B622C000900121D00D4DEACDBE7B7D0DDAFD4E4B3D2E7AED1E7A7
CEE49CD3EA9CC5DA8D98B06688A5629CC082CCF7C18AB17A6A803FD3EFA4B4EA96B8EF9C
CDF3A8C9DC9AB1AC728A8148DAE0A4D2E5A3C9E49FCFEAA38A9E5792A35CCFE59CD0E69D
83944EB8C786D0DFA4D4E5B1CFDEB5F8FFE6F2FFE9E2EFDD
96A65F223200DFEEA9D3E2A1DCE9B1D7E3B5D5E0C2FBFFF4FAFFFEFBFFFFF8FFFFF6FFFC
F9FFF3EEFCDBD3E3B4CDDBA6CFDBABDFEBBDF7FFD8F7FFD8C2D2A1D3E6AFD5E9ACC5DC98
D5ECA4D6EDA5D2E7A2C8DC9FCCDCABEFFED7FBFFE8D8E1C4D0D6B0DBDFBAD6D9BCFCFEE9
EFF0E2FFFFF3595A48C7CAAFE2E7BFCFD6A3E5EDB2D2DB9CD8E0A4555D24DFE6B2D4DCA9
D2DCA7CFDEA5D5EBABBFD896E2FBB9B4CA8AEFF9C4CECFA7A2967CFFF9EBF0D8D4FFF9FA
FEF4F5FFFFFDF7FFFBEFF5EBFFFAE8EEE3C760623BA09B71835F3BC19F7AE4E3B5F8FFD6
FAFAD8E4E3C4CDD7B4D9EABED5EDB3D2E9A5BDD081E2F0A39DA864525D1B525E16535F13
5B6618CFDB91D5E09EE3EEB6E3F0C5F9FFE3F5FFE4E4FDD5CEECB6C6EBA8D1FBA9BCE297
CCE4B4D1E2C0F2FFE1FBFFEDFEFFF3FFFFFAFFFDFFFFFCFFFEF8FFFDFAFFFBFCFEFBFFF6
F8FFE8DEF4C5C9E3A4C8E69ED0ECA2CEEA9FD9F5AAC9E399C7E197C2DC92E0F8AED3EBA1
D3E9A0C4DA913D5109DAEEA6D6E7A0D3E49DE1F2ABD6EAA3CDE7A0CCE7A0CCE89ECCE89D
CDE89BCDE899CFE799CFE897E0F7A9C8DD92C2D18CE6F2B0CBD598586027565B25D6DEA3
C7D693DBECA5CFE099CDE199D5E9A2C3D991CCE29AD0E79FD7EEA8CBE59EC4DE97C8E39C
8CA762BBD691B9D7919FB672303A0052551CE5E5B3E1E0B2D0D1A7D2D8AAC6D59ECCE2A1
D4EEA4CEE998D7F39EC0DB8ACEEAA0214000B6D99F95B2789BAA67C7DF93B8EF9BA9E792
CCF6AACFE2A08F8851B6AD76D7E1A4D0E6A5C7E59FCFEAA38F9C5797A15CD3E39AD3E59B
A4B46DC3D28FD9E9ABD7E8B2CADBAEF7FFE3F7FFECF2FFE8
B0BF7A7B8A45BDCE88DBEBAACAD99ED6E4B3EBF7D3EFF8E3FAFFF9FBFFFFF9FFFFF9FFFB
F9FFF3F4FFE3E0EFC4D8E6B5D9E2B7D2DBB0FAFFD9C9D4A9B3C39291A46D7E9255D3E8A5
CAE298BCD48AE0F7AFD0E6A5D3E6AEF1FFD5BCCAA68D9975555E31606839A2A882F5FADA
A8AC938A8E75FFFFE6CDD3AFCED6A5E7F0B7D5E09ED0DB97DFEAA8D9E3A46A7438D1DCA2
D9E6AECFE1A5CEE2A3D0E6A5D4EAA9E6FABDCDD5A4D2CFACC7BBA5FFFAF1E6CECCFFF9FA
FFFCFBFFFFFAF2FCF3FBFFF4FFFFECE9E2C69EA480CFCDA779573BAC8A6ED8D8B4FCFFE3
FFFFE8D2D0B9E0E9CAB2C29BCDE4AED1E7A6D3E398778538A3B770C8DC97E3F7B0D2E39D
C9D893D6E4A6B2BF89C7D3A3E9F3CEF6FFDEF7FFE2F8FFDFCCE3AFC7E1A2BCDA90DAF5B2
CDE3B4D4E5C3F6FFE5FBFFEDF9FDEEFEFFF7FBF7F8FDF8FFFDFAFFFEFDFFFBFDFCFBFFF4
F8FFE8E3F9CACCE6A7C9E79FCDE99FCAE49AB8D288E3FBB1C7DF95849C52E0F8AEB2CA80
8CA25982984FE8FEB5C1D78ED0E49CDBEFA7B6CA82D4EAA2CCE7A0C9E9A0C9E99EC9E99D
CAE99BCAE999CCE999CCE999CBE697CCE498D0E69DDAEEA7D8EBA9CEDE9FCDDB9ED7E5A7
92A35DA1B56D8EA25A8DA159ACC07998AE66CBE199E0F7AFCEE59FD1E8A2CAE19BCCE69F
96AF6BDFF8B4CCE5A1CCE5A1C7E09C8DA060373C066864357D7149564D22AAAA78D7E5A7
C1DD92C5EB98C6F09AC2EE99C1E79CC9E9A88DA871435820D0DF9CCEE69AC9F8A7B5EA98
CCEEA4DDEDAC959058ABA66ED6E2A4D0E6A5C9E49FD3E8A3909B5797A15CD2E49AD1E59D
8F9C579EA869CBD69AD7E4AEC6D6A5F4FFD8F5FFDFD8EAC2
D3E29FDAEBA54E5F19E0F1ADDAEAACC6D49FF5FFD9F9FFE6F6FFEEFBFFF8F8FFFAF7FFF6
F9FFF1F2FFE3F3FFDBF4FFD6F5FBD5FFFFDF242A04EFF7CECDDAAECCDDA9C7D99FCCE1A0
485F175E762CBFD78DD5ECA6D1E5A8E3F5C1D5E4B9E2F2C5D2E1AAC8D59DD4E0AECAD5AA
D3DDB8FCFFE1FCFFDDD2DEAED5E2AAD2E1A0CFDF98E5F5AAD2E299C3D28DE9F8B7546425
95A566C4D797D0E5A4D6ECABC9DD9EBCCB94FFFFDAF3EED0F5E5D5FFFAF3D7C2C1FFF5F5
FFFDF8EBEDE2C0CBBBE5EED9FFFDE7DDD9BEC2CDABE1E2C270523AAD8E79D6D6BAF7FFE6
EEEDD9FFFFEFF7FFE7E7F7D3C4DBA7869C5C5E6E25C5D58ADAF4AAC6E19AC2DB99CAE0A2
E1F4BCCADAA9E7F4C978825D979E7DDEE5C4FEFFE1FAFFDBD7E3B1DCEBB0D3E3A2C5D79B
F8FFDDF0FFDDF9FFE8FBFFECFDFFF0FFFFF6FFFFFDFDFBFFFFFDFFFFFEFFFAFCF9F8FFF1
F7FFE5E3F9CAD0EAABCFEAA3D6F0A7C5DD93DBF3A9849C52587026BAD288C3DB91BBD389
C6DC93D2E89FCAE097C8DE95D5EBA2D0E69DDCF2A9C2D991C9E9A0C6EAA2C8EAA0C8EA9E
C8EA9DC8EB9BC9EA9BC9EA99D3F2A2CDEC9CD2EEA1CCE69CC3DD96D4EDA9DEF5B1C7DE9A
C8DE96DBF1A8BDD38AD8EEA58AA0584E641CDBF1A9BDD38BD1E6A1D2E7A2C9DE99DEF3AE
8DA25FBFD491E3F8B5C8E19DC1E198A1BF79545F25CECC9BE0D1A66D5E33918958D0D69A
D0EAA1CBF5A3BBED96C8FCA9BDE99EC5E9A9C4DCA8CCDDA9D3E2A1D2E89DC5EC9DC1EA9C
C1DB94DCE8A8AEAD7476773DD3E3A4CEE7A3CCE39FD6E7A3939A5799A05CD0E49CD0E69D
98A55F8F9857CED89BE5F0B6D6E2B0F9FFDAF6FFDAC9DCAF
DAEAA9CEE29D3C500BCADE99D6E9A9C8DAA0D9E9BAE9F8D1ECF9DFF9FFF1E7F2E2EAF5E5
F6FFEEF6FFE9F9FFE6FCFFE3FFFFE3A1A282DDE0C1E6ECCAE0E8C1CBD7A9DAEBB5D3E7A8
D8EFA9ACC47A94AC62849B538096559FB47BB9CB99BED09CCBE09FDEF3AECFE3A4E5F8C0
C8DAA6F8FFD6D8EBB4DEF2B7D2E7A4CFE59CD6ED9DC9E08ECDE494D7EEA0C6DC93A5BB73
899D58798D48D5EAA7CCE1A0D1E3A7DDE7B5FFFFDEE5DFC7C6B5ABFFF9F6D6C0C2AF9F9F
BEB7ADEAEDDCDCE8D0DCE6CBAFAF95B6B99ED7E6C5D7DEBF4D3221987B6DD4D5C3F9FFF1
FFFFF4FFFFF3E6EED9C7D6B5DEF4C392A86A83944DDEF3A6C9E89CC9EDA5D1EFB1D3EEB9
D7ECC3B8C7A6ECF9DF949C848F9378D3D6B7FBFFDAFDFFD5D9DDABABB07AD7DCA2E7F0BB
F9FFDDF5FFE2F9FFE6FAFFE9F2FAE3FFFFF4FFFFFAFFFFFFFDFCFFFEFFFFF9FEF8F5FFEF
F5FFE3E2F8C7CEE8ABCBE6A1D2E9A1C7DD94E2F8AF62782F637930E2F8AFC4DC92D3EBA1
D2EAA0E1F9AFC7DF95E2FAB0BED68CCAE298CBE399DDF9AFC8EAA0C5EBA2C6EAA0C6EB9E
C6EB9DC6EB9BC8EB9BC8EB9BB4D785CBEE9CC1E494C0E094D6F6AAC6E69BB8DA8ED8F8AD
CBE59BD0E89EE6FEB4C1D78ED0E69ED7EDA5849851DAEEA7D3E7A2CDE19CD0E19DD6E7A3
8D9C5B9CAB6AD1E09FCBE09BCBF0A3BCDE94C9DE9DEBF0B8F4EAB9D4C697857B48BFC086
CADE99D1F6A8B0E18FABE090BCEBA3C5ECADCEE9B49FB17DCEE19FD2E89FC8E69CD4F0A6
D6E5A2CCD594999D60919B5CCFE6A2CEE7A3CEE19FDAE5A396985799A05CCEE69CCDE89B
CFDD92A3AA64D8DE9EE1EBAFD6E0ACFCFFDAF9FFDFD6E6C1
D1E4A2CDE09E70843FE6FAB5BFD290D9EBADD0E1ABC6D6A7E7F5D1EFFCDED0DCC4DAE6D0
F3FFE9F8FFECF9FFEAF1FADDC6C6AC615F46FFFFE8F2F5DAFFFFE4DDE8C0D6E3B5D6E9B1
C4D998D2E9A1D4ECA2D7EEA6D0E7A3E1F7B9F7FFD4DBF0B5CAE49DC8E298CDE7A0BDD694
D8F1B0CDE5A7D0E9A8C5DE9AC6E096CDE899C9E591B9D581E6FFAEC5E08FCBE697E3FBAF
E3F9B0CEE49C879C57859858DBE8B0D8E0B1FFFFE3F3EBD8DAC9C2FFF0EFF9E5E6FFFBF8
FFFBEDC3C7B0ABB694EAF6D2FFFFE4EDF7D5EBFFDDE9F4D69D8678FFE4DBFFFFF3F7FFF5
F5F5EDFFFFF4FAFFEDCAD9B8687E4DC9DF9FE0F1AACADF92C5E599CDF1ABB9D89FB9D4A9
D9EDD2F7FFF3F9FFF6FCFFF3F5F9E2868A69AFB189B9BB8CD9D9A7B7B7837D7B48AEB182
CCD9AED4E4BFF1FFDCE8F3D3DAE2CAEAEFDBF8FAEFFFFFFAFAFAFAFEFFFDFBFFF8F9FFF1
F8FFE4E4FAC9CEE8ABC9E49FCCE39BD0E69DC6DC9394AA61D2E89FC4DA91D3EBA1CCE49A
BCD48AC1DB91DAF4AABBD58BDBF5ABCDE99ED6F0A6B1CF85C8EAA0C6EAA2C6EAA0C6EAA0
C6EB9EC6EB9DC6EB9DC6EB9BD0F3A3DAFFAFCCF1A1BCE191CBF0A0D3FAA9C4EB9ABADF8F
D5F4A8BAD48AB3CD83D8F0A6CFE69ED8EEA6B1C57E8FA35CABBC78CEDD9AE9F8B5C7D391
A8B273CAD495CED899D7E8A4CFEFA4C8EA9ECCE69FC2D293CDD097DFDCA7948F589D9C63
98A4645B752E3F681CE3FFC9C4F3AD85AF706F905BB4CD96D7EEAACEE49BD3E7A0DAE9A4
DCE2A29CA161515B1CD2E2A1CCE7A2CEE7A3D3DF9DDEE3A39897579A9F5DCCE69CCCE89B
DCEA9D9FA75ED2D996D5DDA2D2DAA7FAFFD9FCFFE4E5F0D0
D0E5A2C6DB98889D58D8EDA8C7DC97CFE4A3D4E6AADEEFB8E5F5C6F2FFD8CDDBB8D1DEC2
E5EFD6E9F3DBFBFFEDF4F9E3B1AE9BB5B09DEEEBDAFFFFEDFFFFECE8EFD0CAD6AECEE0AE
DCF0B5D4EBA7C4DE97CAE49BD3ECA8E9FFC3F2FFD0C4DC9ED0ECA2D3F2A2C4E397C7E59B
C3E199C7E59DD9F7AFC0DE94CBEA9CDEFDADBFDF8CCFEF9CD1F19EC4E491CCEB9BBDDA8A
C0DB8ECEE69CD6ECA48B9B5CE1EAB5DADDB2F6F1D4F3E7D7CAB8B4FFF9FAFFFAFAFFFDF4
FFFCE9FFFFE4F9FFDBF9FFDCFAFFDCF8FFDFF0FFE3E4F5D3A69384FAE1DAFDFFF5EFFBEF
F6F6EEFFFFF3FBFFECA0B28C99B27BBAD391D4E69CD2E79AD8F4AABEDE9DD0ECBCE7FFDF
CEDFCFF8FFFDF9FFFDEEF4EAF6FBE4C8CCA9FFFFD8ECEEBCE1E1ADE7E7B5817E5196996E
CFDCB1D9E9C2F5FFDDE8F3D1D5DEBFE4ECD4F5F9E8FEFFF4FBFEF7FCFFF8FBFFF4F6FFEB
EEFFDADCF2C1CDE7AACEE7A3DCF2AAD0E49CDEF2AA869A52C9DF96DCF2A9D1E99FCBE399
DBF5ABC3DD93D4EEA4C6E297D0ECA1C7E69AC9E59ADAF8AEC9E9A0C8EAA0C8EAA0C8EAA0
C9E9A0C9E99EC9E99EC8EA9DCAEA9EB7DA8AC4E999CFF4A4B9E08DB5DF8BCCF6A0D5FCA9
C6E798CFEBA0D5F1A6DEF8AECAE199C6DC94D3E7A0CFE09AA1B06DBDC987C8D391D0D998
B4BA7CD9DFA1DDE1A4DAE5A3C1D78EDCF8ADC6E69BDBF9B1D0E9A5C6D697E2E6ABDBDAA1
D4D59B7C8649445D1CB6D997ACD69634622488B37BBBE1A4CCE9A6C6DA93CFDA96D6DB99
B1AF726D6F3051601DD4EBA5CAE8A0CEE8A1D5DE9DE1E1A39A96579A9F5DCCE69DCAE99D
D1E19699A35AD7E09DDBE3A8E0E8B9FFFFE1FEFFE8FCFFEA
CDE29FD4EBA7D3E8A34D621DB3C883CCE19ED4E7A7C8DA9CE5F6BFF9FFD8D8E7BCCFDDB9
D0DBBDD1DBC2FBFFEDFEFFEFB2AFA0CBC5B9FFFFF3FFFEF1E4E7D6FEFFECFBFFE4E8F9CD
CDE1ACC1D99BCEE7A3D4EFAAC6DF9DC6DEA0D3EBB1D0EAABD0F0A5BCDF8FCAEB9CD2F4A7
D0F0A4CAEC9FC1E195CBEDA0C7E899CAED9DC3E495D5F8A6B8D988CFF2A0CFF0A1C7E897
C9E898D9F4A7C8DE96BBC98B515824D3D1AAFFFFE6D5C7BAF7E5E1FFFAFAFFF1EEFFFFF1
FFFFE8F0F8D1CCDDA9C8DBA4C3D5A1D5EDBBC5EAB7C4DAB3A39280F6E0D5FCFFF4F7FFF6
FFFFF4EFEEDCD4DFBFB4C79AC7E0A6D6EFABD5E79BCCDE92DEF5AFF4FFD4EFFFDDF2FFEE
F8FFFDF0FAFBFBFFFFFBFFFAFEFFECFEFFDFC5CD9ADEE5AFDEE3ADCED29FACAD81686D44
FBFFDDF6FFDBF9FFDFE2F1C8CEDAB6DAE3C4DEE6CEE1E9D4FAFFF1FBFFF3F3FFEBE2F1D4
D7E9C1CCE3AFC7E1A2D0E9A5D5E9A2C6DA92B7CB83B1C57DD4EAA1D0E69DD0E89ECBE399
CAE49ACEEA9FCEEA9FC7E69ACEEDA1BDDC90D0EFA3CAE99DCAE89ECAE8A0CAE8A0CCE7A0
CCE7A0CCE7A0CCE7A0CCE7A0C1DD93D7F5ABCDEDA1C1E494D0F6A3CAF29CB9E48BC4EC96
CBEE9ECEEDA1CCEB9FBCD88DD6F0A7CFE69ED4EAA2D4E59FD7E6A39AA5636B7433E7EDAD
9FA366929357D5D69ADBE0A0D7E49ED0E89CBBDD90C3EC9EC3E99ECCE7A2DEE8A9BAB980
706B346C6C36D6E5AC82A0648CB476B4E1A6CEFBC0BBE5A6CBEAA6D7EBA4D9DE9CEFEBAC
979356797B3CB4C883C5E39BC9E9A0D0E7A1D7DD9DE2E0A39A965799A05DCCE69DCAE89E
D1E29B9CA763D9E3A4D4DDA6D9E0B4F4FAD6FEFFE6FFFFEC
C5DC96CDE7A0D9F0AACAE19B809751D8EFA9CCE19ECBE09DE9FBBDEFFFC7CFE0ACE7F6CB
CDD9B5CBD6B8FBFFEDFEFFF1C1BFB2E6DFD5FCF8EFFFFFF6FEFFF4FCFFF1EFFCE0EAFAD5
CEE2B1C7DFA5C8E2A1D0EDAAD2ECABCAE4A5C8E1A7CCE8ABCCEDA6C1E699CBEDA1CBF0A2
C1E396C6EB9DD0F2A5C2E799C8EA9EC6EB9EC8EA9EC6EB9EC8EA9EC6EB9EC8EA9DC8EB9B
CAEB9AC6E595D2E89FDEEDACAAAF79DEDBB2FFFFE4D7CABAF6E5DEFFFCF6F0E7DEFFFFED
FFFFE3E5F2C4D1E5AAD5EBAACFE5A5D0ECAFC0E8ACC9E3B4A2937CFDEADBFCFFEFF4FFEE
FFFFECD7D7BDD3DFB7D0E4AFD5EFAEBFD990D5EA9DCFE197E9F9BBFAFFD7FBFFE6F7FFEF
FBFFFFFBFFFFF8FEFCF8FFF5FBFFEAF8FFDADEEDB6D6E4A9D8E5ADCFDCA7DEEABC8A976B
F9FFDAF7FFD9EFFFD0E2F2C5DBE8BDD1DDB7CED9B7E7F1D6FBFFEDEAF6DEF9FFECE4F3D2
D4E7BAC1D8A0CCE6A5D8F2ABC8DE9690A45C4D6119CEE49BDBF1A8D1E79EBDD58BD8F0A6
CAE49ACAE69BCFEBA0C7E69AC5E498D0F0A4D2F2A6C6E599D1EBA2D5ECA4CEE59FCBE09B
DDF2AFC5DA99D4E9A8D1E6A5DBF0ADC4DB95C2DE94C7E69AD1F2A1CDF09CC0E68FC6EC95
C8EB9BC9E99DC9E99DCAE99DCDE79ECFE69ED0E69ED3E49EDDECA98893516A7332C9CF8F
9E9F63A3A367D2D296E0E2A3D2DD98CFE79BC8EF9EBEEB9ABFEA9AC6E69BE0EAAB9C9A61
615A26E0DEADC9DAA4628146B9E2A6C6F3B8BBE4AAC3E7A9C8E7A3C7DB96E1E1A3E7DEA3
352F00999E5CDCF3ABBEDE93C9E79DE3F9B1CED592E9E8A8959557969F5ED1E8A2CFEAA3
D0E5A491A163D1DEA6D2DCAAD7DEB4FFFFDFF8F7D9A29E83
D9F3AAC0DA91D5EFA8D1EBA47F9650BFD690D0E5A0DEF3AEEBFEBCF7FFCAC8DAA0C5D6A2
CCD9AEDBE6C4FAFFE9F5FAE4B2B19FEFEDE0FFFFF4FFFFF4F6FCEEF9FFF3F8FFECF7FFE4
F5FFDCE3FCC3CCE8ABC3E09EC1DE9CC7E4A4DBF4BAEDFFCCF0FFCFD1F5AFC9EDA5CCF1A4
C2E799C2E797C9EEA0C3E89AC6EAA0C6EAA2C6EAA4C6EAA4C6EAA2C6EAA0C6EB9EC6EB9D
D2F8A5CFF09FC7DF95C7D69563662FD2CDA3F2E7CBE2D3C0C1B3A8FFFAEEEAE7D6DEE2C7
D3DFB7D3E6AFD1E7A6CAE49BCAE49BC4E39DC4EDABC5E0AB645639BDAB97F2FBE0D9E9CC
B5B89BBEC09BD4E2B1CBE0A5C1DC97D5F1A6D3EA9CDBECA6E9F3BEFEFFDCFFFFEAFEFFF3
FEFFFBFCFFFDFBFFFAF9FFF1DAEAC6D2E4B4C8DBA3C7DB9ED0E4A9CEE3ABF4FFD6D9EABD
C2D4A2DDEFBBD2E3AFD1E2AED3E1B0CCD9ABDDE9C1DAE8C4F2FFDFF8FFE8F8FFE6D9EBC3
C8DEADD8F0B6D0EBA8B5CF86A2B86FA8BE7582984FC7DF95C9DF96D8F0A6D3EBA1CCE69C
CCE89DD8F4A9C2E195DAF9ADCCEB9FC1E195C7E79BCEEA9FCDE59BD2E69FCCE09BCFDF9E
D7E5A7D3E1A4D7E5AAD4E2A7BCCA8DE5F8B8D5EAA7D2ECA3B5D184D9FBA7CCF099C8EB97
C8EB9BC8EA9DC8EA9DC9E99DCCE89ECDE79ED0E69ED1E59ECAD99697A361495211F1F7B7
D2D397A2A266E9E7ACDDDFA0D9E6A0D0EB9EC0EA98C2EF9CC7F19FC7E398D0D595665F28
726A39DFE3B15F7A43C4EBB2B7E4A9C1EAAECCE9AFD3EBAFCFEAA7A0B46F4A480B61581D
929151DCE5A2C6E298CFF1A5D0ECA2C3D790E3EAA7999B5A9AA060D1DD9BCDE29DCBE4A0
849A5AB9CD92CFE0AAD4E2B1D9E0B6FFFFDFFFFFE47B755B
CBE79CDCF8ADCAE69CBBD68FC6DF9BCCE5A198AF69BDD48EC5DB93DAEFAADEF1AFCDDFA3
D8E6B5E1EDC5EBF5D3FEFFE8B3B79EEEF2DBFFFFEFFCFFF1F5FEEBF7FFEEF6FFEBF0FFE0
F3FFDBE0FCC2CFEBAEC7E6A3C5E2A0C8E5A3D6F3B3E5FFC4EBFFCECBEBACBFDF9CC8EAA0
C6E89BC4E797C9EC9CCAEC9FC8EAA0C8E9A4C8E8A5C8E8A7C8E8A5C8E9A2C8EAA0C6EB9D
BBE291C9EF9CCDE79DDAE9A650531ADAD3A5E0D3B1DBCDB3B8AD99FFFCE8E2E6CDCAD6B2
C0D2A2CDE2A7D2ECA5C9E497CFEA9DBFDF94CBF4AECBE7AD40331196856BF9FFE1C5D5B0
CED0A9E5E8BBD3E2A9DBF1B1C4E29CD4F0A6C7DE96D1E1A2ECF1C8FFFFE2FFFFE9F6F7E5
F6FAEBF8FFEFF7FFEBF8FFE6E9FCCFD3EAB4CEE8ABCAE4A5D7F1B4CFEBB1EDFFD1F5FFD8
D8EBB4C0D19ACFE1A7CDDFA5D3E5ABD5E6AFC8D8A7F5FFD9F6FFDDF5FFDEF0FFD9DFF2C5
CFE6B0D1E9ABC6E099DAF4AA112900879F55C8E096E9FFB9C3DB91BBD58BCFE99FD3EDA3
C3DF94CCE89DCBE79CC6E599CEEDA1C6E599C5E498DAF6ABC5DB922A3B00D3E49E2B3A00
525D215A632A5259234D56213A430EC6D199D8E8AAC6DB98E7FFB5CDE99CBDDD8ACBED99
C6EB9BC6EB9DC8EA9DC9E99DCAE89ECCE89ECFE69ED1E59ED7E6A3D1DD9BE4EDAC4B5111
494A0EC6C78BF5F5B9CDD393D2E69FCBEA9EB7E18FC4EE9AD0EF9FD5E59EE5DFA3605420
97956498A975568149B2EAADB6EAACCFF5B8C5CE97DFE2A9172C005063219E9E60DBD79A
F5FAB8D1E09BB7D68AD3F3A7CCE49ADCECA599A25F969F5CCFDB99F0FFBDCAD998D8EBA9
4F6827C1D99BCBE0A7D8E8B7D7E0B5F3F4D2FFFFE6D9D1BA
CAE797C2DE91D5F1A7D1ECA7D0E9A7D7F0AEADC3828299539FB56DDAF0A7BCD089CBDE9C
D5E4ABBDCB9AE1ECC4A9B390CAD2ADE0EAC7F2FDDDF9FFE8F8FFECE5F8DAD3E9C5D0E9BF
CBE6B3C7E5A9C9E8A5CEEDA7CFEDA7CAE8A2C7E4A1C9E6A6CDEAB0C4E3A8C5E3A3C9EAA3
C9E99DC6E997CAEB9ACAEC9FC9E9A0C8E8A5C9E7A7C8E8A7C9E8A5C8E9A2C9E99EC6EB9D
C0EB99C8F2A0CBE79CD2E39D5B5F24C0BA88E7DBB3E4D7B7E2DBBFFFFFE4D6E0BDD1E2B6
D0E7AFCFEAA7CCE89DCBE896D1EC9BC3E294C8F2AAD2EBB1544621A59274FEFFDFC2D2A5
A0A374E4E7B2C1CF92D4EBA7C4E19EC5E29FD5EBABD0DEA9F2F6D5FEFEE6F2F4DCDEE2C9
DBE1C5E0EBC9E7F8CEF1FFD6E3FCC5C8E4A9CBE7AACCE8ABEDFFCEE9FFCBEBFFCFF4FFD6
62763BCADC9EE2F5B5DCEFAFCBDE9EC4D899DDF1B6C2D59EC8DAA8EBFFCED1E4B6CBDFAC
CFE7ADA4BD7B748E45CDE89BD5EFA5D8F2A8C2DC92C5E196CEE89ED2ECA2D8F2A8C2DC92
D5F1A6C9E59AD3EFA484A0559CB86D96B56979954A819B5199AF64B2C67E8697519CAB6A
97A165C3CA94D3DAA7D9DFAF7E8454AEB683BCC991D7E9ABD5EAA5B6D086D3EFA2CBEC9B
C6EB9BC5EC9DC6EB9DC8EA9DC9E99ECCE89ECFE69ED0E69EDCEDA9D2E19ECDD896A1AA69
878B4EB8B97DCDCE92DAE0A2D3E7A2D2F0A6BEE896CAF19ECDEA9ACEDA92E4DA9F594C18
686A39A7BF8B60965CAAEAADBFF7B8BFDEA2A8A36C978C56829150869957D2D699ECEEAF
D0DD98C6DE94DCFCB0C6E69ACFE099D4DF9A77823EB9C883C5DA95C7DC97D0DA9BD8E2A3
95AC68D2EDAACDE3A5CFE0AAD3DEB3ABAF8C716D54F8F2DC
CBEB98BBDA8AD7F5ABD0EDAABED899C9E3A4CCE4A6A8BE7D677D359BB166D7ECA1D9EDA5
D3E3A2DFEEB5AAB686525E30D2E0ADD7E8B4DBEDBDE3F6C9E7FCD3D4EDC3C1DCAFC0DCA9
C6E4A8C3E3A0C4E69CC7E99CC9E99DC8E89CC9E79DCCE9A6C9E5ABDEFBC3E4FFC1D3F3AA
C8E799C7E995C9E996C7E897CAE8A0C9E8A4CAE7A7C9E7A7CAE7A4C9E9A0CAE99BC6EB9B
C5F2A1BFEC9BC7E79BCCDD979398589B945EEBE0B2D4CBA2EDE9C4FFFFDDCEDEB1D1E8B4
D2EFAFC9E9A0C4E594C9E996CAE594CAE99DC2EAA3C8E0A6756541BBA484FFFFDCCAD8A7
5A5C2AB6B980D4E3A2CFE6A2C1DE9EC9E7ABD8EFB9E2F1C8F6FBE5FDFFEFEBF1D7D0DCB8
C9D9ACCDE2AAD4ECB0DFF9B8D0EDABC2DF9FCAE6A9C6E2A7E6FFC7E6FFC6DEF7BEDEF6BC
A9BD7E92A56397AB66889C55ABC179DAEFAAC7DC9BD5EBADD2E7AEB3CA92D3EAB4CEE6AC
7E9756B0CA83D9F4A7C3DE8FCAE699C5E196C5E196CDECA0D5F1A6C3DF94CBE79CCDE99E
C9E59AC7E398B0CA8095AF65BDD78DCFEBA0C3DD93C5DF95CFE79BC4DC90D8EEA6D4E4A3
CAD59BE2EAB7ECF2C4D9DFB3DEE4B8E5EEBF838F5DD2E4AACAE09FD7F1AAB7D388D7F8A9
C6EB9DC5EC9DC6EB9DC8EA9DC9E99ECAE89ECDE79ECFE69ED5E9A4DAEBA7D0DC9AC8D391
CCD5964F5517D7DB9EE3E9ABCEDA9ACFE6A0BEE596C6F09CCEED9DCEDE95DCD69A5E521E
4A4C1BE0F8C66FA96FB4F6B8A3D99B9AB6796E612C97844CCCD697CFE4A1DFE9AADEE9A7
C8DF97CDEDA1CAEC9FBFDB8EDDE9A18D944EC6D38DDBF1A9D6F6ADD6EFAB9A9E63515314
D3E79FC2DE93D6EDA775874B303C0CD2D8B2E6E6CCF3F1DC
D2F49DCEF09CC7E59BC4E19ED0EAADCAE3A9C9E1A5D4EDACADC37B8DA456B7CC7DD6EB9E
D3E49ED5E5A66C794342511AC6DB9AD8EFABD6EEB0C8E1A7C7E2ABCBE8B2CAE9B0C8EAAD
CDEDAACAECA2C7EA9AC5E894C6E894C8EA96CCEB9BCFEDA5CEEAB0EFFFD3F2FFCDD1EFA5
C6E391C9EA93CDEB95CCEC99CCE89ECAE8A2CCE6A5CAE7A5CCE7A2CAE99DCCE997C6EC97
BDEE9CB6E595CCEEA1D4E8A0D9DE9C989258EFE5B0D0C899C9C89AFBFFD5D5E7B3C8E4A9
C2E39EC6E89CC9EC98CBEB96C8E394D3EFA5C7ECA7C4D9A095835FCBB293FAFFD4D3E1AE
9C9F6A95995ECEDD9CD1EAA8CCEAAED5F2BCBDD2A9F8FFEAF4FFEFFBFFF4EAF7DBD3E4B8
CBE3A7CBE69FC9E89ACDEE9FCEEEA5CEEDA9D4F0B3C8E1A8CFE6AEC7DEA6D4E9B0CCE0A3
C8DB99EDFFBAB0C47C72873C6B823498B064D5ECA4C8DF9BD7EFB1D8F0B4CBE3A7A4BC7E
98B16FC9E39AD3EE9FCCE997D1F0A2CCECA0CCEB9FC9E89CCAE99DC6E599CDE99ED1EDA2
CDE99ED4F0A5819B51C2DC92CAE49ACDE79DD4EEA4D4EFA2C5E292DEFAADD9F3AABDD291
DFEEB5E1EBB9CAD1A5EBF2C9F1F8CFD1DAAFA4B183E5F8C1BCD294D8F3B0D4F2AABEDE93
C6EB9DC5EC9DC6EB9DC6EB9DC9E99ECAE89ECCE89ECDE79EC8DD98CFE39EDBEAA7EEFAB8
BDC788626B2C93995BB5B97CE4E5ABDDE7A8C6E89CB8E592C6F09CD1EC9DDEE0A189824C
5F6132C9DCAEB9EBB694CF95C2F4B55771347D6E35D7C289DBE4A5CFE4A3C2D190D1E5A0
CAECA0D6FDAEC7EC9CCEE99CD7DD97B4B772CEDF98B9D78DBEE499D5F3AD908F56A6A265
D5E59AD2ED9CCAE09794A7657A8952D8E1B4D2D8B6FFFFE6
CAED93B9DB85C5E59ADBF8B6C5DEA4CFE8B1DBF3B9C1DA99CFE59DA7BE702C4200A2B866
DBEDA3C4D390B7C588A8BB7BC7DF91D3F09ECEEDA1C1E09AC2E19EC7E7A6C9ECAACFF4AE
C5EA9DC7ED9AC8EE97C9ED93CAED93C9EC92C9EA91C7E698CAE3A9E4FDC6DFF8B7C8E499
CAE691CFED93CEEA93D0EE98CDE89BCCE7A0CDE6A4CCE7A4CDE79ECCE999CDE994C8EC95
C8FCA9BAED9ECAECA0CADE96DFE4A19E985ADDD49BD7D29BAFB27DF4FFCBD8F0B6C8E6A6
BDE199C6EB9DCEF19DCBEB96D0E89CCDE7A0CFF2B0D4E6B2BFAB88F0D7B8FEFFD6D8E5B0
DEDEA89B9C6293A163C8E0A2CCE9B1DFFCCECDE2C1F5FFF1F2FFF8F5FFF8E4F9D8CFEAB5
CDEBA3CCEE98C7EC8FC7EB91C4E596C7E59FCBE5A8CEE5AFCEE2ADC7D8A2F6FFCCE9F9BA
CFE39EC9DD95D4E99CCADF90C2D987B0C97889A1558CA65D849D5B87A05F9FB779AAC381
CCE69FD5F0A3CBE695CFEC9ABFE091C5E79AC9E99DC7E79BC2E296CEEEA2CBEA9ECCEB9F
CBE79CBEDA8F94AE64CEE89ED2EAA0C7DF95CBE399CFEA9DCCEB9BC5E695C6E49ACFE8A6
C6DA9FD7E5B2FCFFDCFEFFDFFEFFDFFCFFDDE0F0C3B5C996D2EAB0C6E3A1CAE9A3D1F3A9
C6EB9EC5EC9DC6EB9DC6EB9DC9E99ECAE89ECCE89ECDE79ED2E7A2D9EDA8CBDA97BCC886
D3DF9F929C5DE0E9AA9C9B62DBCB98E1DCA4D9F7ADB4E893B7EF96BDEA95CADB97B2B37A
7F7C4FAEB78CD2F6C67AA973BBE4A83A5012B7AD70D7C98CDDE7A8CFE4A3DBEEACDFF9B2
B0D98BB1DE8DC5EC9BD6EEA252530FE0E19DCCE098D5F7ABC1EDA0BFDE98A8A36BDCD297
CEDA8ECDE492CAE19396AA637D8D4ECCD9A1D5DFADFEFFDA
8DA04EDCF1A2D2E9A1C2DD9AC9E5A8CFEBB0BEDA9DD5EFAEC8DF97DDF3A8C5DA8BD1E495
D1E399DDF1AA809353D9F0AAD3F0A0C8EA94C2E394CCECA1D3F2ACC6E5A1BEDF9ACCEEA4
C7E99CC8EB99C8EC95C7EB91C7EB91C9ED93C9ED93C8EB99C6E4A4D4F0B5CAE7A4C3E296
D1F19CD3F199C7E58FC9E692CDE89BCDE79ECDE6A2CFE6A0CFE79DCFE799CFE895CAEA95
B6E594B7E899CBF4A6D1EDA2D8E59F9A9F5D9C9A5DA19F66B2B57EF0FBC1D4EAACCDECA9
C8EAA0CAEC9FCBEA9ACAE596D9EAA4C1D492D5EFB0E6F7C0DFD3A9FFFFD6FFFFD4D2E1AA
D9E1A8DAE2A7909F64D6EBB2C6DEAEF2FFE1F7FFECEEFBE7F3FFF2F3FFEBDDF4CAC8E1A7
C8E79BCDED98CAED93CBED96CFEEA0C6E19CC2DA9ED8EDB4D8EBB4CBDCA5FBFFCFEDFFC0
D0E69ED1E99DC8E092CFEA99D8F3A2CBE896C8E497CCE89DD2EDA6C8E39ED3EEABC2DD98
D5F1A7C6E295C1DE8CCCEC99CAEB9CC9EA9BC6E69ACCECA0C6E599D5F3A9C6E298C8E49A
C5DF9697B168D3EDA3BAD48AD9F4A7D3EEA1C7DF93D1EE9ECCF099C6EC95C6E999D6F4AA
C6DF9DC9DEA5F9FFD8F9FFDCFBFFDDFBFFDDD1E0B5ACBE8CD0E5ACE0F8BAC8E39ECBE99F
C9E99EC8EA9DC6EB9DC6EB9DC5EB9EC8EA9ECCE89ECFE69EC9E09AD2E9A3CDE19CDFEEAB
C5CB8D7E8446D7E3A3D6DC9E645B2498965BCEECA2BCEC98BFF79EC0F09CCBE59EDDE7AB
D6D8A79EA579C1D8AA4E6C3A041F0093A06A958A54EDE2AAD7E3A3CFE8A4CEE8A1C4E499
C2F1A0C6F7A5CAF1A0C9E195585E18DBDC9ADBECA5C3E197C8EEA5C9E6A3A3A46A080600
DDEDA4C8E092D9EFA48AA057758944DFEFB0CBDA9FD2E1A8
62581A5A5616DDE3A3D7EAA8CAE7A4C0E49EC5EAA4C9EAA3C7E29BD2E8A0D7E8A195A65F
6C803968823BAAC882CDEFA5C3E59BC3E398C6E69DCBE9A3CEE9A4CCE5A1CCE5A1CFE9A2
CDE99FCDE99ECDEE9FB7DA88CEF4A1C1EB95C6F09AB6E18FCCF5A9CAF2A9B9DF94CAF0A3
C8ED9DC9EC9CC0E192CCEB9DCDE99EBDD78ED4EBA5CAE098D2E69FD7EBA3CBDD93CBE397
C6EB9ECAF6A7BFEEA0C5F1A4BCDE94D6EBA891975B928F58B0AF77EBF0B6CFE2A2D1ECA7
CAE8A0C6E298CBDF97D5E29DDAE3A4C9D1959BA96B697438ECF4B9FDFFCBF4FFC7D1E7A7
D8EAACC8DAA0B4C7908D9F6FC9D8AFFBFFE4FEFFEAE7EDD1E7F3CBE6F7C3EDFEC7BED092
DCF1AED1E79FC1D89081985095AC66CDE3A2D5EBABCFE5A5C6DC9ECFE5A5EFFFC5DFF8B4
CCECA1C9EB9EC8EB9BC8EB9BC9EC9CCAED9DC8EA9DC7E99CC8EA9EC8EA9EC8EA9EC8EA9E
C8EA9DC8EA9DC8EB9BC9EA99C9E898C6E393D5F0A3D1EBA1C8DF97CFE6A0CFE4A1D1E6A3
92A963A1B872C9E39ACDE89BCDEA9AD3F09EC2E28DCBED96CCF396C6EF91C9F095CAEE97
C7E899D4F2AAE9FFC4F0FFCFF7FFDAF8FFDCCADAADB9C796BECD96E6F6B8E3F4B0C9DD95
CFE79DC8E499C5E79AC8F1A2C0EF9FBEE799D0EAA1CEE29BD7F1AAC4DF98C3DE97D9EAA6
C3BE8499945AC6D695D7EEA896A761899D56C6E599D3F8AAB2D988C7EC9ED2EDA6CDE2A1
CCDA9F3E4B166A7646D4DDB072784C4C4920847450BCB486D1E1A0C8E89CC4E99BBCE797
CAFCA7B8E894C3EC9DCBE79C88954FC2C986D6DC9CCFDB9BDCEFAFD5E9AAA0B072596C2C
C5DF98D0ECA2D9F3ACAAC47D6C8541CCE39FD2E8A7CFE5A4
CDBC848B81466A6A2CD1DD9BD2ECA5C4E49BCDF1A7CBEDA3D4EFA8C5DC96CBDF9AC6DA95
D4EBA5CAE59ECDEFA5BEE298CAEBA4CAE9A5CBEAA6CDEBA5CEE7A3CBE4A0D0E7A1D6EDA7
C5DC94D6F0A7C2DE93D5F5A9BBDD90BDE493D3FDABC9F2A3BAE395BEE497C8EDA0C4E99C
C0E296CFEFA4D2EEA4D6F0A7D0E79FE3F9B1DCEDA7CADB95D4E39E8E9B56B1BC78D7E8A2
C2DE94C1E79AB7E698BDEC9ECCF4ABD6F1ACD7DFA4C9C68F746F38A1A26897A768C4DF9A
C8E89F9FBA7381924C7F8A4891995D9CA468DCE6A9CEDD9CDAEEA9D8EFA9F5FFC8CDE8A3
BCD594D7EFB3CEE0AC889569A2AA85F2F7D7EDEDD3A4A887A5AF7AC7D798D8E6A8D5E5A6
8A9A5B7588488EA161D0E3A3D0E5A4ABC07FD3E9A8C6DC9BC7E09ED8F1AFB1CA88D4F2AC
C6E89CC5EA9CC4E99BC3E89AC3E89AC4EB9CC8ED9FCBF0A2C6EB9DC6EB9DC6EB9DC6EB9D
C6EB9DC6EB9DC6EB9DC8EB9BD7F4A4CFEA9BCBE397CBE399D3E9A1D5EAA5CEE19FB4C785
9AAF6CA5BC76C8DF97CAE69BCCE89BD1F19EC5E791CEF29AC6ED92BDE68AC0E78CC1E88F
C0E391C8E89CD3F0ADD4EEB1CAE1ABD7E9B9CFDFB0CDDBAAC6D39BB1BF81C8D590DDEDA4
CADB94C9DF96C7E69ACAF1A2ACDD8CC7F2A3C2D890E3F4AEC0DA93D0EEA6CCECA3D6EAA5
DAD198968D54E1F6B3B9DB91C9E59AB0C87C9DB76DCAE49AD8F4A9C9E59AC8E49ACFE8A4
D5E9AA7B8A4F4C5622828556DCD9B09E9672574A2A757249D5E9AACEF3A6C1EC9DB2E191
B8E997C2F1A0CCF5A6C7E59BD8ECA58F9A56E6EBABD8DD9DD9E3A4CCDC9BDBF4B2CBE8A5
99B46FDEF9B4C5DE9AC7E09CD5EEAA738C48BED591D0E7A3
D9D79ABBBB7D5F6424939C5BDBEAA7CCE09BD3EAA4BFD992CBE69FC9E79FD1EFA7CBE69F
D0EBA4C9E49DCFEAA3C8E69ECAE9A3C9E8A2C9E8A2CAE8A2C7E59FC5E099CAE49DD0EAA3
CCE69DCEE89FC8E299E6FFB7C5E196C9E89CC9E89CBCDB8FCFEBA1CFEAA3D1EBA4DBF2AC
D5ECA6CDE29DCCE09BCADB97D0DF9CBAC684D6DF9EE7F0AFAEB474676D2D909555D9E2A1
D8E9A3CCE89ED8FCB2D0F6ABB2D38CD1E6A3D0D39ADAD59EA29D66DEE2A7CADD9DD2F1AB
CEF2A8C7E99FC7E198CDE19CDAEAABB8C889D5E8A8D1E8A4C5DF98D2EDA6ECFFC0B8D68E
D0EBA8D8F0B2D1E4ACA2AE7E8B9269B7B898A09C7F63654059662EC3D694C4D4938A9D5B
576A28BED390D9EEABCCE19ED5EAA7C6DB988AA15DCFE6A2E6FDB9B7CE8ADEF5B1C9E49D
C8E89DCAEC9FCCEEA1CBEDA0C7E99CC4E99BC8EA9DCAEC9FC8EA9DC8EA9DC6EB9DC6EB9D
C6EB9DC6EB9DC6EB9DC8EA9DBCD88BDAF5A8CBE399CDE59BD9EFA7DFF5ADBFD38E6F833E
BED38EC0D78FD3EAA2D0ECA2CDE99ECDECA0C4E596CCED9ED0F3A3C8EB9BCAED9DCEEEA2
C9E99ECCEAA4CEEBA9C7E1A4C5DCA6CEE2AFDAECBAD1E2ACBED0967D8D4E90A15BAFBF78
DAE7A1E8F8B1BCD48ACDEDA1CFFAABC5EB9ED0E49DCBDA95CEE8A1D7F7AEB6D88EBED38E
DBD59B979258C6E19CCDF1A7D6ECA4D3E39C879851CBDF97D7EDA4D2EAA0D3EAA2CCE39D
CDE3A2A6BA7B84935C555F2B919467424319201C0040461AC4DCA0BEE19DC8F2AAC8F6AD
BBEB9FB6E597BFE89CC8E89DD7EDA5919E59D0D793E6EDA9C7D48ED2E69ECFE99FC3DF95
A6BD77CDE29FC5DA97D3E8A5D8EBA982955397AA68D8EBA9
D1E09DDAE6A4ABB473595F1F7D8242CFD595E6F1AFCEE29DCEE9A2D4F6ACCAEEA4B6DA90
BFDF96CAE8A0D2E9A3C9E09ACBE69FC5E59CC6E69DCBEBA2CDEDA4C9E9A0C6E49CC6E49C
D4F0A6C1DB92D1E8A0C8DF97D2E8A0D5E9A2D1E59EE5F6B0C9D895E6F5B2C8D492C5D18F
D3DE9CDFEAA898A1606167275F6424A1A364D9DB9C58581A7B793CA2A06369672AA4A466
D0D996CEDF99B4CF88CBE9A1CEE7A3D3E2A1F3F2BAC0B68199925CE4E8ADCEE3A2C3E49D
B8E195BFE89CD0EEA4D6F0A9D4EDABD6EFADCDE8A5C5E39DCEEEA5CFEFA4CBEBA0CEEEA3
CBE9A3BDD695CCDEA4E1EEB9D6DCB0FCFCD6F1EECDDBDCB4CAD89DA7BC7799AE69A3B873
C4D994CFE49FD3E8A3CEE39EC8DD98CADF9AD8EFA98AA15B89A05AD6EDA7CAE19BCAE49D
C7E399C8E79BCBEA9ECDEDA1CDEDA1CAEA9EC7E79BC4E699C8EA9DC8EA9DC8EA9DC6EB9D
C6EB9DC6EB9DC6EB9DC8EA9DD3EFA5C6E09790A75FBBD38997AD65778D449BAF67D3E79F
D8EEA5D5EDA3D8EFA7D2EDA6CDE8A1C9E7A1C6E59FCDECA8C5E2A2C2DF9FCBE5A6CFE9AA
C9E3A4CBE5A6CDE7AAC8E0A6F5FFD4EDFFCAC5DAA2C2D79EDFF3B4C5DA97A8BE7682934C
9CA661858F4A9DAE677D994EC1E79AC9EEA1CCDD97E4F1ACBFD690D0F0A7DBFDB3CCE39D
AAA56BB3B377BBD993C8ECA2CBDC96D5DF9A96A15CD9E9A2C9DA93D2E69ED2E8A0CEE59D
DBF2AEC5DB9AE0F4B7AAB9829CA6725058274046182C38088FA87186AA6CB0DA9AB3E29E
C3F2ACBBEAA2C6F0A8C3E59BC3DD96BFD089929E56B8C47ACCDD8FDCF1A2D2ED9CC8E394
B4CA82A0B06FD7E7A6E2F2B1C4D493D4E3A29FAE6D98A766
D2F0A8D0EAA3D1DD9B9DA2624C480BADA96CBFBF81DDE8A6C0DA93C8ECA2C1EB9FC2ECA0
CEF2A8D4F2AACEE29DCFE39ED0EAA1C8E89DCBEBA0D6F8ACDEFFB4DAFCB0CDEFA3C6E69B
BAD890DCF6AFCBE09BD6E7A3E8F4B2CCD594CBD090DFE1A2C7C88C95955997975BC7C78B
DFDFA3E2E0A55351169A955B5F5A20827C42E3DDA3534D139E955CEDE4ABA9A067787236
C9C989D1DA97E5F9B4CDE29DE1F4B2CED798E5DEA8B6AA76B1A772DCE0A5C2D796CFF3AB
CFF9ADC0EA9EC0E296C8E69EB5D490D6F5B1C7E8A3C3E49DD1F5ABC5EA9DB3D88BD7F9AD
CDEBA3C8E39ED2E6A7D9E8AFD5DDAAFFFFD8FFFFDBDCDFB0E3F3B4C5DC94CCE39BBFD68E
DEF5ADC7DE96D2E9A1C9E098D3EAA2DFF6AEBDD38BA2B87099AF67ACC27AD4EAA2D1E8A0
CBE59BC8E298C6E297C9E59ACDE99ECDECA0CCEB9FC8E89CC9E99DC8EA9DC8EA9DC8EA9D
C8EA9DC8EA9DC6EB9DC8EA9ECFEAA3D3ECA88FA660CDE49CD6ECA3E6FCB1D1E699C3D88B
D2E89DCFE79BCBE29ACCE7A2CBE5A4C8E5A5D3F1B3DEFAC0CDE3B4D0E3B6DAEBBFD9ECBE
CDE1B0CCE0ADD3E7B2D0E7B1EBFFCAF5FFD3DAF2B6D4EDACCBE6A3D0EBA4CDE99FCEE29B
949B579C9F5C707B364F651C789A4E66863BBCCB86D7E29EE5FCB6B5D38BC8EAA0DCF3AD
A7A56AABAB6FD1EFA9C3E59BDAE7A2DBDD9CB3BA77A9B26FD9E6A0D1E29BC5D991D5ECA4
C7DE96C6DF9BD5EBAAC0D497D0E2A8A3B27B74814C63744044602D254A146A935B84B176
CCFABAB8E6A5C4EFAAC7ECA6D3F1A9CBE39993A55995A658DDF3A1C9E18DD4F099D3EF9B
C8D992A1B06DB2C17ED4E3A0D7E6A3D7E3A1DDE9A77D8947
C0E69BCBEBA2CFE09CDEE4A4A9A568584F14656124E6ECACD7ECA7D2F2A9BBE498C4EEA2
C8EEA3C4E29ABFD48FDDF1AAD1EBA1CAE99DCCECA0D8FAADDFFFB7DAFFB3CEF3A6C6E89C
CAE8A0DEF8B1364A054E59174C5013656328B7B177D9D0979F965D999057E5DCA5968D54
726932D6CD94685D27DED39BEADFA98B80487B703AA59A62675A25D4C790EFE2ADA2975F
989457E8EDABC8D794D4E5A1CEDD9CD7DD9FDCD29DC4B783A89C68E6E7ADCCE1A0CBECA5
C3EDA1C1EB9FCBEBA0D0EEA6D9F8B4CDEEA9BFE099BFE399C4E89EC8EDA0C1E698C1E396
CAEA9FC7E29BCEE4A3CADC9ED1DEA6FFFFD3FCFFD0DAE3AECBE09BCAE69BCEEA9FCDE99E
CCE89DCBE59BD2ECA2DBF3A9C4DC92C6DE94D9EFA6EDFFBAC3D990849A5195AB62CAE097
DCF2A9D6EEA4D0E89ECBE59BCCE69CCDE99ECEEA9FCBEA9ECAE99DC9E99DC9E99DC8EA9D
C8EA9DC8EA9DC8EA9DC8EA9EC7E29FC4DD9B9AB16DCAE199D2E89FC7DE90C4D98AE0F5A6
CFE696CFE79BC7DE96CCE7A4CDE7AAC9E5ABDFFCC6EEFFD7F6FFE4F7FFE6FAFFE9F0FBDB
D5E3BFCBDCB2CFE0B3CEE2AFF5FFD4F2FFCEC1DB9ACAE8A2C7E59DD1F1A6C8E89DCFE69E
D9E09CDEE19EE5F0ABD3E9A0C1E397C0DE949CA964B3BE7AABC07BCAE59EC3E39ACDE29D
DAD59B706E33CCE7A2D1F0AAD6E19FEDEFAECDD290464F0CCDDA94DFF0A9CFE59CCEE69C
D6F0A6D8F2A9D9F2AECCE2A1D1E5A6CADC9EC2D198DAEDB6CDEBB7C5EAB6C6EEB95E8951
7AA76C96C484BAE7A4C2EBA5CAEBA4C6E298C9E195B7CE7EB2C977D0EA93CAE68FC4DD89
D9EAA3BDCC89879351C7D693DBE7A5CFDB99D9E5A3BAC684
C4EDA1D3F5ABCDE29DC9D492E1E1A35E5A1D686629C2C787D6E5A2DBF5AEBBDB92BCE096
CBEDA3D8F8AFC6E099D3EAA2CEEA9FC8E799C8E99ACDF0A0CEF5A6C9F2A3C7EDA0C6EB9E
C6E69DCCE69F445312585E2038330070652FD7C692F6E2AFB2A26E978A55F1E4B0AC9F6A
50430F6E612C594C18B6A974DFD29EEBDEA9685B27F4E7B29C8F5BE3D6A1DDD09CA89D67
575316DBE09E54632091A560CAD998D8DEA0FFF9C4C9B9867A6D39E0DEA5DDEDAECEECA6
BEE298C7EBA1D0EAA1C7DE98C2DD98BEDB98D3F2ACD6F6ADCAECA2C5EA9DD2F7A9C6EB9D
D0F2A5BFDF94CAE59EC6DF9BD1E5A6D3E5A9CFDCA4CFE1A3D1EBA2D7F6A8C8E799C5E496
BFDE90DAF6A9CEEA9DC1DC8FD8F3A6CAE598CAE296BFD78BD2E89DD8EEA38FA4594E6318
C5D991CAE097D2E89FD3E9A0D0E69DCDE59BCCE69CCDE99ECCE89DCAE99DCAE99DC9E99D
C9E99DC8EA9DC8EA9DC9E9A0D0EAA9DAF3B2C4DA9994AB65C7DD92D5EC9EDDF3A1C8DE8C
D3EA98D6EEA0CAE199D2ECABCFE8AEC6E1ACE2FECDF3FFE3FBFFF1FFFFF4FEFFF4F6FAE9
DDE5CED3DEC0D2E2BBCDE0B2F3FFD2F4FFCDD9F7B1D3F3A8C8EA9EBADC90BEE396CEEAA0
D6E39DDEE8A3B7C780D0EAA0C1E699CFEFA4D9E6A1D7E09D475B16CCE69FE0FBB4CEDF9B
EADFA75E551CC6DB98CAE5A0CAD694E8EEAED9E29F55601C94A45DCFE39BD7EFA3C7E295
C9E497B3CD83D3EAA2DAEFAACEE19FD7E7A6DEECAFD1E5AAD5F4BBADD29CBDE6AEBEEAAF
BDEBAD76A7665F8D4CBDE7A5BDE59FCDEEA7D0EEA4CEEA9D7B9647C2DE8ADCF5A2DFF8A7
CCDD96C5D6929FAE6BC9DA96D9E8A5E3F2AFBAC986D4E3A0
CAECA2C0E097D9F0AAD9EAA6CDD695DEE3A3B7B97A4F54144D5816BECD8AE5FAB5D8F2AB
BFDD95CEEEA5C1E198CCEAA0CFEBA0CCE89BC8E799C6E999C1E698BCE596C3E99CCBF0A3
C8E89FCFE6A0DBE7A7B9BD80645B2480703CCAB381EFD9A7A18F5D6E612DB0A36FE1D4A0
A59864635622897C486C602CEEE2AEDCD09C5D511DDDD39EA49864928853C9BF8ABCB57E
818143ABB471D5E9A434490495A564A4AA6C8A804BBDAB79A39360E3DCA5CED89BD2E9A5
CEE9A2CBE69FD1E59ED7E8A4D7ECA9D1E8A4CFE8A4BFDA93CAE89EC6E69BCDEFA2C6E89B
C6E89BC4E699D7F7ACC4E49BD4EFAAC8E3A0C8E1A0D4EFAACFEEA2C4E596C6E798CFF0A1
D0EFA1C4E395C7E396D1EDA0CAE598D3EEA1D1E99DD3EB9FD5EBA0CFE59AC7DD92B4C97E
899D55A2B66EC1D58DD2E69ED2E89FCEE49BCFE79DD1EBA1CDE79DCCE89DCCE89DCAE99D
CAE99DC9E99DC9E99DC9E9A0CFE9A8C3DB9DD5EBAA8DA45EDAF0A5BDD484D8EE9CD5EB98
CCE391D1E99BC6DD95D0EAA9CDE6ADC3DEABE3FED1F5FFE8FCFFF2FBFAF6FFFFFBFFFFF8
F8FCEEF6FFEAF9FFE6F5FFDACDE2AAD3EDACC9E79DB9DC8CD0F2A5C5EA9CCFF5A8C3E398
D4E8A1CFDF98D6EEA4D1F1A5C2EB9DC3E89BD1E09BD6E19DDAEBA7677E38647B35D2DD9B
EFDBA67D6C36D7E3A3D5ECA8DAE9A6CCD896D8E7A2CADB95667C339CB46ABFDA8DD5F0A3
9DB86B9BB367CAE097D0E19BD5E49FD5E19FDCE5A6CEDEA0BAD89CD1F7BACBF3B5B6E0A1
BEECACCAF8B87BA9698CBA79C3EDABC6EEA8BBDF99CEEEA58FAB61688238B7CF83C4DA8F
D7EBA4D6EAA5C4D8939AAE69CADE99C9DD98E2F6B1D0E49F
7D944E9BB56EC6E099CEE59FDAF1ABC1D590D9E5A39BA463727838B0B676D1DA99CDD997
D0E5A0CCEAA2C4EA9FC9EEA1CCE89DCBE397C5E194C8E99AD0F2A5CBF2A3C4E99CC2E498
D1EFA7CFE6A0D7E3A3D6DA9DE8DFA8DDCD9998814F634D1BA39662847A45584E19DBD19C
F0E9B358511BD9D29C7D7640CBC48ED1CC9579743DAAA770D8D39C5A57204F4C153A3B01
7A8342C6D791D7F1AAD2EDA6C4D996A0AA6B877D48614F1D675523A59A64BCC286D8E7A6
CADE99D9EAA6DAE3A0D3D999D9E3A4D4E3A2D0E09FDEF2ADC4DA92D1EBA2CCE89DC7E79B
CAEA9ED0F2A5C4E99BBDE295CFF4A7C9EDA3C1E59DC8ECA2C9EC9CC6E997C4E795C5E896
C9EA99CAEB9ACCEB9BCEED9DCCE999CCE999CDE899CDE899CFE799CFE799CFE799D0E69B
DBEFA7C7DB938CA2598CA259CBE198D6ECA3C2DA90D5EFA5CDE79DD1EDA2CEEA9FCAE99D
CFEEA2CCEB9FC9E89CCEECA4CEE8A7B8D092DDF3B28FA6606E8439CAE191DAF09ECDE390
D4EB99CFE799D1E8A0D2ECABCFE8AFCCE7B4DBF6C9F5FFE8FEFFF6FFFEFDFFFEFFFFFFFD
FEFFFBFBFFF3FBFFECF8FFE1D1E5B0C4DE9DCDEBA1CEF19FD8FBABC1E696C2E89BC7E99D
CCE69DCCE69CCAEA9EC5EE9FBBEC9BBBE496D0E49DE2EDA9E0F1ADC5D994DDF1AC8D8F50
C6AA78755927E9EAAECCDC9BD0E3A1CDE29DD6EDA5CFE9A0D1EDA2B9D88CA0BC6F9EBB6B
D3EE9FC6DC919CAE6493A05A909956ACB171E0E0A2D8E1A2CEEBA8C1E9A3C1EAA6CCF6B4
BDE7A5BCE9A8B6E4A4A7D8971C4A0ACCF9B8B7E09ECCEFADC9E6A4839C5AC9DE9DD3E8A5
CAE19BD7F1A8C5DF9688A259D2ECA3D0EAA1C7E198D0EAA1
6B7A37536722C6E099BEDC94C1E198E2FFB8C6DB96CBDA97B4B979676729777739D8DD9D
E4F3B0C7E29BB6DF93BDE698C3DF94DBF1A6D5F0A3CAE699CAEA9EC1E396BEE094D1F1A6
C9E49DC9DE99DBE7A7DEE2A5E2DDA5E6D9A4B3A26E6A5925A0996289874E5D5A23B8B67D
CBCA9265642BD3D29A8D8C537E7D45A3A46A4A4B12DBDFA4DCDFA69B9F64A0A36A969E62
AEBD7ACCE39BC2E299C5E59CD0E9A5CCD898B9B27C8C7A4854400E73663165662C8D9758
AAB976CCD795E6E6A6EBEAAADBE0A0DDE3A3D8E1A0CDD997E1F0ABD4E8A1D0E89ED0ECA1
C6E599BADC8FD1F6A8D1F8A9C1EA9CC0E99BBBE599C3EC9EC7EC9CC9EC9ACAED9BCBEE9C
CAEB9AC8E998CAE999CCEB9BCCE999CCE999CCE999CDE899CDE899CDE899CDE899CFE79B
C3D990D9EFA6CDE59BBCD48AB7CF859DB56B98B066C1D98FC4DE94C9E399CCE89DCAE69B
C7E398C7E69ACCE89DCBE69FC9E2A1DDF6B5CBE1A0A1B87291A75CACC375D2E896D3E997
D0E795CAE294C8DF97C5DF9EC5DEA4C9E4AFDFFBCAF5FFE4FEFFF3FFFFFAFFFFFDFEFEFE
FDFFFEFBFFF9FBFFF1F8FFE6CDE1AECBE4A3CBEA9EC1E291BEE18FB9DE8EC7EC9FD3F5A9
CFEFA4C9E99DC3EA9BC2F1A0C1F6A4C2EE9FCCE29AD2DD99C9DA96C4D893CDDC99919153
987847916F3FDED99FDDECABCCE39FD3EEA7C6E49CD1F1A6B8D88CC6E69ADAFBACCAE797
D4EFA0C1D88AD5E59CD0DA95ACB16F8B8A4ACDC78BEBF0B0C9E49DB9E198CFF7B0B3DC96
BCE5A1D0FABAC6F4B4B0E0A2467638A0D094BFEBAEBBE1A4C6E3A9AEC68CBAC990CADC9E
C5DE9AD1EFA5D2EEA48BA95FC7E59BD4F2A8CAE89EC5E399
DCE5A4B2C17EBDD48ED2F2A9C0E69BBDE398C5E39BD4E8A3DBE1A1A2A063545013666628
98A361DCF3ADD0F6ABCBF1A4CCE69CD9EDA5C7DD94BED68CD3EFA5D8F4AACAE69CCBE79D
D4EBA5C7DB96B0BF7CDCE5A47E7F43615C22D1C88F605A2098995DD3D99BA7AD71656B2D
3C4206575D1FEAF0B4DAE3A4868E529FA869C1C98DD8E2A3CAD497E5EFB0CAD497D7E6A5
D4E8A3D4EEA5C6E89ECAEEA4D8F3AEE3F2B1E2DBA5BAA876B8A472DBCE99A7A66D949D5E
717C3A5056166C68298B85479998589A9C5B9BA05E848B48D4DD9AC4D18CD0E19BD8EEA6
D9F5ABCDEBA1CBEDA1B6DB8EB4DA8FD0F9ADC5EFA3C1EC9DC3E89AC9EC9CCCEF9FCCEF9F
C9EA9BC8E99AC8E99AC9EA9BCAE99BCAE99BCAE99BCCE89BCCE89BCCE89BCCE89BCDE89B
D6F0A6D2ECA2C7E197C9E399D1EBA1BDD78DA4BE74A0BA70D8F2A899B36996B066C9E399
D6F0A6C3DF94C7E197D7F1A8D1EAA8C3DC9AD3EAA6D0E79FCCE299A0B769859A4BDDF2A3
BFD686DDF5A9EAFFB9D2EDAAC5DFA2CEEAB0D7F4BED6EBC0F7FDE3FCFDEFFFFFF7FFFFFD
FDFFFEFBFFFCFAFFF3F8FFEAD2E5B7CFE7A9CAE69BCAEA97D0F09DD8F9A8CFEFA4C1E397
C8EA9EBFE496B8E393B9EA98BBF29FC1F0A0D1E8A0D8E5A0CEDF9BF0FFBFD3E29FD3D395
B59564876535D7D197C6D292D5EEAABFDF96BEE096C7E99DD9FBAECDEFA2BBDC8DC5E496
C4DF92E5FBB0D3E39C6A742F868646817D40685F26333500AEC87FC7EDA0CAF0A7CCF1AB
D0F5B2BFE7A8B1DDA0C2F2B6BAECB17DAF74B2E2A8BDE6ACC7E4AEDDF1BC788550D8E5AD
CDE6A2CAEA9FC6E49A7292478CAC61C6E69BCAEA9FC8E89D
DAE3A2E1F0AD425913C4E49BBBE196D8FEB3CAEAA1D8EFA9D8E3A1E3E8A899995B727435
5C67258CA05B96B66DC7E79ECAE098D8E9A3DEF2ABD5E9A2C6DC94C9E098D0E79FCCE29A
CADF9AB0C47F63722F9AA6646C75342E3400868849464B0BAEB879DAE6A6D6E2A2B2BE7E
98A464A9B575D5E1A1CEDA9AE4F3B2CCDB9ACAD998CCDB9AE2F1B0D1E1A0CCDB9AE0F1AD
D0E49DCBE59CCBEDA3C9EBA1C1DC97D0DF9EE2DBA5D0BE8CA08C5AE8DBA6D8D99FE1EBAC
D7E3A19FA8679C9B5B9F9B5C9998586A6C2B4D52103B4200A2AB68A3AE6A9FAE6981954E
8EA45CC2DC93D0EBA4D8F8AFCDEFA5BBDF95B4DA8FCFF5A8C3E598C6E999C7EA9AC6E999
C8E99ACAEB9CCAEB9CC8E99AC9EA9BC9EA9BCAE99BC9EA9BC9EA9BC9EA9BCAE99BCAE99B
CFEEA2C5E498C6E599D0EFA3D6F2A7D2EEA3CAE69BC2DC92B0CA8090AA6092AC62A7C177
B6D086D1EBA1DAF4AABDD78EC6E099CCE5A1E7FEB8C4DB93D1E79ED2E89D8DA255A5BA6D
DFF5AAC3DB8FB7CE86C3DE99D0EAA9CBE8A8C9E7A9D2EBB4E8F2CDF5F9E0FEFFF3FEFFFA
FCFFFFF8FEFCF7FFF6F9FFEDCADBAFD2E7ACCFE9A0CCE796BFDC8AC4E191C7E59BD0EEA4
CDEDA1CDF2A4CCF5A6C6F7A5BCF3A0BDEC9CCDE49CD7E49FCFE39EBCD08BE1F5B0D1D394
C5A9776F511F969459A4B473CBE4A0CFEFA6DFFFB4B3D589C7E99CC9EB9EC7E899D2F1A3
D6F1A4BED48BCADA939099569C9E5FB1AF74B7B079949559A9C37CD5F9AFA9CD87C3E6A2
CAECAFC3E9ACC4EDB3BAEAB0C3F6BDA0D69C6E9F67C9F4BCD0EEB8C4D6A27C8451E0EBB3
D5ECA8CCEAA0BBD98F7292475C7C31C1E196C9E99ECDEFA3
D1E09DCBDC9896AB6695B069C3E39ACCEEA4C3E39ABCD68FCFE39ED3E29FD2DD9BDAE5A3
8E9A588695526377324A5E1998A764909C5AB9C885DBEAA7CEDD9AD7E8A4D2E39F9AAB67
8FA05A51621CA9BA74E4F5AFC9DA94DAEBA5DFF0AAD2E39DDDEEAAD8ECA7CFE39ECDE19C
D1E5A0E0F4AFD6E7A3D1E29EC5D692E2F3AFD0E19D9AAB678899558A9E5980914DC3D490
D2E19CC8DC95CEE9A2CBE9A1C9E09CDAE4A5DBD49EC3B17FAB9967ECE1ABD6DA9FCBDA99
D5E9A4C1D28ED7DE9BE2E4A3E2E7A4D6DD99D6E09BAFB9749BA662828D4997A36198A764
586925869A558FA461D0E5A2CEE5A1CCE5A1DCF5B1C5E099CAE89ECAEA9EC7E79BC4E498
C7E79BCDEDA1CBEB9FC5E599C9E99DC8EA9DC9E99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9D
C8EA9DC3E598CDEDA1D0F0A4C5E498C5E498D0EFA3D3EFA4E3FFB4C4E095D0EAA0D5EFA5
A3BB71869E54ABC379D2EAA0D0EAA1DFF9B0C4DB93C3DB91D4EAA2D9EFA6CEE29A96AA62
AFC57CCDE59BE1F8B0D5F0A9CAE59ECAE8A2C9E8A2C6E09FD7E8B2EAF5CBFCFFEAFBFFF4
FBFFFDF5FEFBF7FFF8F9FFF1CFDFB8CDE0A9CFE6A0D3EB9DD5EE9DD0E998CDE79DCEE89F
C2DC92C4E397C6EB9DC4EF9FBDF2A0C1ED9ECDE39BCEDD98D6EBA6D3EAA4CCE39DDAE5A3
EFDBA66A5520DAE3A4CAE19D8BA25C758F485F7B31E0FEB4C3E296C4E498DCFCB0C8E79B
C6E297D3EAA2DCF0A9D5E4A1DAE2A6979B60504F17747C41D1EAA988A8675B793B274509
48652F38592490B883BCEBB5B8EDB5B2E9AF95C88D8CB87DB8D79CCDDFA55B632ACFD79B
D0E5A0D5F1A6C9E59AABC77C6E8A3FD1F0A4C9E89CCBEB9F
D9EEA9D1E6A1C9DE9949601AC9E39CC6E099D8F3ACD3EEA7C6E19AD6F0A9CFE6A0D9EDA8
CFDE9BDCE7A5989E5E4E54145E6728444E0F828C4DD3DD9EE2ECADDAE5A39AA664293500
61702B869751D2E69FC9DF96CEE69CD1EBA1A6C277D6F2A7BCD38BD3E8A3DCF1ACD1E6A1
C9DE99D5EAA5D3E7A2C9DD98CDE19CD4E8A3CCE09B50641F98AC67DCF0AB9BAF6A94A360
E2EDA9D3E09BD1E6A1CFE6A0D9ECAAD8E1A29C925D5A4816A2905EDBD49DE7EFB3D1E6A3
D8F2ABCAE19BD4E39EDAE5A0D5E29ACDDA92D9E6A0DCE9A3CFDC97D2DF9ADFEBA9D7E3A1
95A1613E4A0A344000CBD797D4E0A2CCD898E1EFB1CADD9BCEE89FCEEDA1CCEB9FC6E69A
C8E89CCEEEA2CBEB9FC3E397C8EA9DC8EA9DC8EA9DC6EB9DC6EB9DC6EB9DC6EB9DC5EC9D
CFF6A7C2E99AC1E698C5EA9CC7E99CCCECA0CAEA9EC0DF93CBE79CC8E499CDE79DCCE69C
CEE69CCBE39995AB62435910CEE69ABAD588C8E096E3FBB1D7EDA5C6DC94D2E6A1CFE39E
3D520D8BA25ACCE39BCEEAA0C5E196CCEB9FD1F2A3CCE89ECEE3A0DDEEB7EFFDD9F9FFEF
F9FFFAF7FFFDF8FFFCF9FFF3D6E6C2CEE0ACD2E7A4C2D98BD1E697CAE191D6ECA3D1E79F
DAEEA6D3E9A0C3E296BAE192B9EA99C5F0A1D4EAA2D4E39ED1E8A2C1DC95D3F1A9C8D995
D5CA928C8149CFE2A0D3F1ABD9EEA9D9EDA8D8EEA63950089BB56BD5F1A6BDDC90C8E79B
D4F2A8C4DF98CDE49ED1E4A2C8D699DFE8AFE0E8AFD4DFA7678047000F004D6833D3EEBB
354F1F102D002A501FC2F1BDB3E8B0B6F0B580B678548242D5F5B4D4E7A794985BE3E8A6
CFE09AD6EEA4CFE79DD0E89E8BA55BC6E096C7E398CDE99E
C7E59DB9D48DE0F5B0D4E5A138470461722EC8DD98D1ECA5C1E399D3F7ADC4E89EC8E69E
DAEEA9D8DE9ECECA8DEBE5A9CED295A2AA6E949C60949D5E8B91539197599AA3628F9A58
C8D590D2E39DCFE39BCFE99FC9E89CCEF1A1D7FEADBFE496DDF9AFCCE39BBFD68ED2E9A1
DAF1A9C8DF97CDE39BB5CB83A9BD76B2C67F95A9627E924BD5E6A0B5C680D2E39DB6C37E
939856979C5A9EAD6AA1B570CAD998DFE5A7A599656F5D2BD3C390D3CE96D9E7A9BBD691
CDEFA5CEEEA5CAE199CADE96CDE398D1E89AD5EA9FD5E69FD8E9A3D2E19CD3DE9CD3DC9D
CED69AC0C68A8D9156696D32494A11A9AA70D8D9A0DAE2A6BFD48FC7E59BCFEDA3CBE99F
C8E69CCCEAA0CBEBA0C6E69BC8EA9EC6EB9EC6EB9EC5EB9EC5EB9EC5EB9EC5EB9EC3EC9E
BDE697C6EFA0CEF5A6CAF1A2C4E99BC1E698C6E89BCDEDA1D0EFA3C9E59ACCE69CD6EEA4
D4EAA1CBE198CFE39BD7EDA2B3CB7DADC879D9F1A5CBE399C2D890DAEFAAD0E3A1D8EBA9
E3F8B5AAC17B99B068C2DE93DEFAADC9E996BDDF89CEEE9BCDE599D3E8A7DCEDC0E9F8DB
F4FFF4F8FFFFF9FFFFF8FFF5CEDBBDD4E4B3DAEDAD92A75C98AB5C97AA5BCCDE94D0E099
CCD792D6E39DD6ECA3CDEDA1C3EE9FC4ED9FD2E69FD2E39DC8E29BD4F6ACC3E79DD4EBA5
D9D79C707034CFEDA7B8DC94BECF8BEEF9B7C2CF8AD1E29C5F752C859F55DBF7ACC8E79B
C8E69CD0EEA6CDE8A3C8E19FD7EBAEC9DBA1D4E3AAD3E6AF0E26005571417D94683D5428
CBE2B8D6F2C982A77B487645BEF5BEBBF5B8B6EDAC6F9E58CFF0A9D7E8A2747732CFD28B
D6E39DCDE199CDE199D1E59DA7BD74A3B970C9E197D3EBA1
C4E69CD1EFA7CBE29CCEE29DD6E5A296A562697D38CBE59ECBEDA3BDE396C6EB9ECAEA9F
CAE098D9E4A0ECEBABDEDD9DDEE7A6D5E4A3CFDB9BD8E4A4E3EEACD6E19FCDD997DDECA7
D5E6A0D5E9A2D2EAA0C8E499C9EA9BC6EB9BBBE593C7EC9EBFDB90DDF4ACD2E8A0C6DC94
D1E79FD2E8A0CEE49C677D35CEE49CD3E9A1C6DC94D2E8A0CFE59DDCF2AACEE49CD0E19B
D8E3A1DDE6A5C9D89798A8679FAB6BB2B67B8D86507C703C9E945FA4A36BD2E0A2A6BF7D
8AA8626D8843667B3880944F8EA25B90A45C8599528D9E58D4E5A1DCEBA8D4E0A0D8E2A3
D6E0A3E4ECB0D2D79DB9BE849A9B62797A412B2C00939B60AABD7DBFD894D1EAA6CFE8A4
C8E19DCAE5A0CEE9A4CBE9A1C9E9A0C8EAA0C6EAA0C5EB9EC5EB9EC3EC9EC2ED9EC2ED9E
C5EB9EC8EFA0C4E99CC2E799CAEFA2CDEFA3C8EA9ECBEBA0C9E79DD0ECA2CBE79DCAE49B
D1EBA2CFE9A0C9E39ACCE49AD3E9A0B4CA7F859B52ADC47CD3EDA6C9E29ED4EAA9C9DE9D
D8EBABBBCE8C97AB668CA25AAAC278CFEC9CD6F6A3C9E996CEEB9BCAE39FCCE0ABDBEDC5
EFFFE5F7FFF3F8FFF3F4FFE9D7E7C0CBDDA9CCDF9F91A55DCFE499D1E399C5D6906E7D38
313A006F7835B5C07CD2E8A0CAEEA4C6E89ECEE29DD3E29FD4EDA9BFDE98C9EFA6C7E59F
DEE4A662682AC8E7A3CAF0A7D9EEA9C4D18CDDECA7D9EAA4D2E8A08BA25A859C54D1EBA4
C7E09CC8E19FD5EEADC9DFA1DCEFB7CADDA5D4E5AF7F915DA6BE8ADEF6C2C3D9A8D0E6B7
B9D0A2C7E3B3C7E9B76D9862154509AADD9BC1F3ACB8E39BC1E198D1E59E9FA662D9E09C
D5E69FC6DC93D5EBA2D6ECA3CBDF978FA55CCEE49BD5EBA0
CFF1A5C2E297D4F0A6C9E39AD4EBA3D4EAA290A75FACC37BCBE59CC9E59AD2ECA2CAE49A
D0E89CD6ECA1CDDF93D3E89DC3DD93CDE99FD8F4AAC6E298D1EBA2D1EBA2D6F0A7C6E096
CEEA9FCEEA9FCCEB9FCDECA0CCECA0CAEC9FC7E99CC5E599D8F0A6CBDF97D1E59DD1E59D
C8DC94C7DD94DAF0A7657D33CDE79DCDE79DCCE89DCCE89DCCE89DCCE89DCAE99DCAE89E
D1ECA9CAE3A2D0E6A6D7E9ABD0DA9EBABD8494915A6A67304D4C14666930879155717F42
515F223A4509262E0043480E4E561B545E22424C0F566224B1BF81DDEDAECCDC9DD4E7A7
C9DC9CD5E8A8D5E8A8D6E9A9D5E3A6B1BF824D581C54622751602982935CCBDCA5D6E7B0
D4E6ACCCDEA4DAECB0CCE0A1D1EAA8D1ECA9C4E39DC3E79DBCE599C7F1A5C1ED9EBEE99A
C7E99DC8E69CC7E59DC8E69CCAE8A0CCEAA2CCEAA2CBE9A1CBE9A1C0E097DCFCB3C5E59C
C6E89ECAECA2C7E8A1C7E29DDAE9A8CED899A6B97798B16FC3E29EC2E19DCEEBA9C6DF9E
CFDFA1D4E0A2D1D99D9EA86B8A9958D7ECA9CAE59EC4E49BC4E29CCAE7A4CEE8ABCDE6AD
D4ECB8E2FAC8E8FECDE4FBC7C9DEA6DAEFB4D1E5A6A6BB78D1E6A3DAEDABC2D595BFCF90
98A265999F639B9A61A1A76BAAC381C2DD9AD5E5A6D6E4A6D9E9AAC8E19FC8ECA6C8E7A3
E1EDAF828C4FC1DB9AD1F2ABD0F0A5DAF9ADC4E095D8F2A9C1D890CFE49F96A967778748
97A66BA1AE7698A56F87945F879361B7C393C9D5A786945FCFE4A3C9E09AD5ECA8D3ECAB
C7E1A2CDE9ACC8E6A6A8CB877EA25CA2C87DCBF0A3CFEFA4ACC782D0E5A4B1C183D7E9AB
D1EAA6C5E399CCE89ECFE99FCAE2988EA459C9DF94CAE193
C4E699B9D98DD2F0A6C2DE94CFE9A0C6E097CEE59D8CA35B92A85F93A960C5DB90DAF0A5
CBE397C9E495CDE899D2EF9FD4F5A6C3E598C5E599CDEDA1D1F1A5C0E094C4E498D0F0A4
C6E69AC6E69AC5E599C4E498C5E599C7E79BCBEB9FCFEEA2C4DA91D8E9A2D5E69FCCE098
C9DD95C1D78E7C944ACDE79DCCE89DCCE89DCAE99DC9E99DC9E99DC9E99DC8EA9DC6EB9E
C5EAA4C0E39FC8E2A1D2E5A5DBE5A8DFE5A9CECF95ADAE74E0E4A9D6DEA2D8E2A6CFD99D
D9E3A7E1E9AED2D79FDFE2ABDCE1A9E2E7AFDAE2A7E2ECB0B4C2847C8C4DA1B673DBF2AE
DBF4B0CEE7A3BFD894C7DE9ACFE4A1DAEDABCDE0A0CADA9B9EAC718C975F424B14242D00
848D54A1AA71ADB67DDCE6AAD0DB9FD3E3A4D7ECABD5EEACCDEBA5C8E7A1C5E9A1C9EAA3
D3ECAAD3E9A8D0E6A5CAE39FC7E29DC4E29CC5E39DC5E59CD0F0A7B4D68AC8EA9EC5E79B
C2E497C5E79AD9FBAECAE69CCADA99D7E3A5DEEEAFADC3828CA764A9C683D6F1AED2E8A7
DEF1B1C9D799E4F0B2D7E3A59AAA6BC6D999D9EFAED2EDAADAF7B4CCEBA7C5E29FC9E6A3
D1EEABD0EDAACAE5A2C3DE9BD3ECAAC4DD9BC1D796CBE1A0D0E5A4D1E6A5D0E5A4C6D999
D1E1A2D7E1A4D2D198B3B77C91A76693AE6BB1C484CAD89AD2E0A2C7DC9BD0F1ACCDECA8
BBC789666E32DFF2B2BDDB93B9DB8EC1E696C1E494CCEB9FCFE9A0DDF4AECBDE9CBCCA8D
95A0668A955D959F6AB1BB87A4B07E95A17196A27277864FCDE39BE4FCB0CCE69DC6DF9B
C1DB9ACAE7A5D8F5B397B672D2F2A977974CBCDA90D1ECA5B4CD8BD0E8AAC5DAA141591F
C6E5A1C3E59BC9E9A0C4E298D6F0A6688034D3EA9CD9F0A2
8CAC60E3FFB7C8E79BC9E59AD4EEA4D2EAA0D1E79FD6ECA4C3D78F7E924A8AA057B3C97E
C3DB8FD8F3A6D6F1A4C0DC8FCDECA0CCECA0CAE99DCAE99DC8E79BCAE99DC6E599C5E498
CAEA9ECBEB9FCBEB9FC8E89CC5E599C5E599C8EA9DCEEDA1D3E9A0CCE098DCF0A8D0E49C
BCD088CBE198CAE298C4DE94CCE89DCCE89DCAE99DC9E99DC9E99DC8EA9DC8EA9DC6EB9E
C4EEA2C4EDA1CAEAA1CCE29AD0DD98D5DC99BEC07F909553D6DC9CD4DF9DD7E3A1CDDC99
D2E1A0D5E4A3CAD696D4E0A0D7E1A4D2DC9FD6E2A2C6D594D9EAA6D2E6A1A1B76FBBD28A
BED88FC6E097D4ECA2D6EEA4CCE299C9DD95E3F4AED1DE98D5DC96DFE59F989B56525512
70712F5352126C6A2DDAD699E8E6ABD4D39AD7D89FCED198E0E8AFD1DAA1DBE6AED6E3AB
CDDCA3D0E2A8D3E7ACD2EAACCDEAA8CBEAA6CAEBA4CAEFA2C8ED9FC8EE9BCBED99C7E792
DBF7A2C8E28BCFE590CEE692CFEA9DDEF8AFB7CD85D2E39DB3C27D92A15CCADB95CDE19A
CBE29ACDE99FC9E79DC2E096A0BA7195A962A5B46FD4E59FBAD48BCCEAA0D5F3A9C8E69C
C0DC92C8E49AD4EEA5D7F1A8D7EEA6C9E098C0D78FB4CB83CCE29ACAE098D8EEA6CFE59D
CEE59DD9EDA6E4EDAADBE6A2BDDB91A6C87C99AF678E9D58D8E7A2CFE59DBAD88EDFF9B0
EFF6B36C6C2CD5E09CCDE59BCDEE9DCDF3A0D3F6A4C6E798CDE99CC9E399CFE59DC8DB99
D7E7A8D3E3A5D2E1A6DEEDB4D2E4AABFD0999CAF77586C31D1EAA6CAE5A0C0DD9BBFDBA0
DAF7BFDBF9C3ACCA9492B176BBDB9C9BBB7A9FBE7BC8E7A4A1BE7EB0CC91D4EDB64E672E
CEEEABD2F3ACCDEDA4BFDD93D5EFA5A3BB6F8EA557CCE194
88A85C7E9D51C9E59AC2DC92D8F0A6CFE59CC2D890CEE29BCCE098D6EAA2D6EAA294AA61
6B81389EB66CD1E99FDCF6ACC4E095CFEBA0CCE89DC8E499C6E297D5F4A8D3F2A6CBEA9E
C9E89CCAEA9ECCECA0CCECA0CBEB9FC9E99DC5E79AC6E599DFF7ADC1D58DCADE96DCF2A9
B5CB82C4DC92D4EEA4CBE79CCCE89DCAE99DC9E99DC9E99DC8EA9DC8EA9DC8EA9DC5EC9D
BCE998C3EE9CCDF0A0CEE69AD5E29AE0E7A1C6C984939651B3BA76CCD792DDEDA6D7EBA3
D0E69ECAE098C9DF97DAEEA7DCEBA8DCEBA8CEDF9BDAEBA5C8DC95CDE39ACCE49A5D752B
9FBA6DC9E497D7EFA3C5DC8EEEFFB6D3E599BFCF84DEEC9FD6E193D1DA8BD8E093D9E093
DBDF959B9C5671702D6561215D591C575218B7B27A939059DAD9A3777741969662747644
7175427B824C8790598F985F8E985C8A945587935187944FD3E39AD8EB9CDDF3A0C4DA85
D7F095CFE98ECAE588D6F49AC9EC98BDDE8FDDF5ABDCECA3CED893A9B06A5D6823D2E49A
BBD78CCFF2A2BFE697CCF3A2DDFCB0BDD388A7B26DBBC77FE7FFB5C7E698BFDE92D2F1A3
D9F5AAC8E497C2DC92CEE99CC6DE94DDF5A9CAE298627A2EB3C980CDE398CFE59CCCE79A
C6E69AC6E295CCDD96D2E79CD2F7A9CBF2A1B5CF859DAF6592A25BD0E59ADBF7ACC4DA8F
D3D492645F1DD8DD9AD8EAA0C4E393C1E792C9EC9AC4E594CBEA9ACDE89BD7EFA5D7EDA5
CADF9ADBF0ABD2E7A4C7DC9BC9DF9ED9EFAFBDD6956C8544A6C07FCBE7AAD0EDB5DCFAC8
88A5794D6C42A8C79BC4E5B69ABA884E6F386F915588A76BBAD99D5B783EC5E0A97E9A60
8CA969C0DB98DDF6B2D7EEA8C7DB94D4E59E9EAB63BBC77D
D7F6AAC2E195415D12DCF6ACD6EEA4BCD289E0F4ACDAEBA4E1F2ACCBDC96CFE09ADBEFA8
CCE29A889E56586E26799048D2E9A1C7E198C9E39AD2ECA3D0EAA1C0DC92BEDA90C6E49A
C6E49AC5E399C3E398C7E79CCAECA0CBEDA1C8EA9EC7E59BCDE49CBED48CDDF3ABD9F0A8
4D641CC8DF97B3CD84DCF8AECCE89ECAE89EC9E99EC9E99EC8EA9EC8EA9EC8EA9EC5EC9D
BCEC96C2F098C8EB97C7E08FD4E295EBF1A7DADB95AAAB65C9CF89D6E29AD1E399CBE397
CCE89BC9E89ACCEB9FD2EEA3C9E098C7DD95DEF4ACCAE097CFE79DDEF6AABBD689CBE699
B9D1834B641396AD5DC3DA8AC6DC8ACFE291D7E898DAED9CDBF39FC7E18ADEF6A2DBF19F
D0E191C6D487DFEBA1D7E19ADBE29E9DA2604449095054174A501471773B575C225A5D24
4F4C155A531D675A266F59276E52206C4B186D48146C49136B4C136D5A18DAD38BDEE798
C2DA84D0F598D0FF9FB4E687BBE790C7EA98DFFAADCCDE92D5DF98CED68D5E6A228EA054
DDF9ACC2E895B8E290C5EC99CFEEA0D0E799C5D28A8C9A4FBED68ACBE898D2EEA1CBE898
CDE89BD4EFA0CDE89BBCD788C2DA8EDAF2A4CEE69A536B1D8CA257DBF2A4C8DE93CAE797
C5EC9BC7EE9BCEE99CCAE797C2ED9BC6F29DCEED9FD2E79AD4E49B9AAC60D2EDA0C7DC8F
E8E5A25C5310E1E09DD8E49ACEEB99CAED99C5E894CEF09CC9E996CEEB9BC8E394CBE397
CAE298D3EBA1CFE9A0D4EEA5D0ECA2CDE8A1D3F1A9C5E29F001400B1CE98D4F1C13A5930
42603E9FBE9F6382631A3C194A6A436D8E61B4D6A375965FDAFBC2AFCE959DBA82D6EFB6
99AB71D2E0A3D3DDA0D4DD9EE3E8A8DCDE9DE0DF9C504D0A
BFDE92E8FFB9A2BC725E782E8CA259C4DA91D7E8A1D2E39CC4D58FE2F3ADDDEEA8C5D692
DCF0ABE1F6B3C7DC99DAEFAA6C823A869C54B4CA82BFD68EDBF2AAD3EDA4DAF4ABCCE89E
D1EDA3CCEAA0C8E69CC6E69BC8E89DC9EB9FC9EB9FCAE89ECDE79EDAF0A8CFE69EA2B971
496018CBE59CD7F3A9C2DE94CAE89ECAE89EC9E99EC9E99EC9E99EC8EA9EC8EA9EC5EC9D
C1EF97C4F397CAEE97CAE18FD2DE92DCE096BFBF79898943D4D792E1EBA4D3E59BC9E497
C9E89AC3E696C4E999C1E396D8F4A9C1DB92BDD78EDDF7AEC5DF95C0DA90E9FFB9C5DF95
D9F1A5C6DE90BFD6865F7626889B4AE3F6A5CBDC8CD5EB99C9E694C2E392C4E393BAD787
D1EC9DD1E99DD8EDA2D2E39CD4E49DCFDF98E3F0AAD7E49FE1EEA9C5D18FD0DC9AD2DD9B
E0E5A5E4E4A6E9E1A3EADA9FECD39BEFD099F6D19DFAD5A0A8875191783F726727565914
ABBD71D3F2A2BEE592C9F5A0C6EC99D7F8A7ACC77AD3EA9CE1F3A9D3E398C9DB9171883A
BED98CC3E292D5F6A7C5E695CAE699D1E99BD2E79CB8CD80748C40ABC878D2EDA0C6E192
BDD88BCFEA9BDBF6A9D4EFA0D5EDA1C7DF91D0E89CA3BB6D859B50DBF2A4CDE398D1EE9E
BDE795C5F19CD5F1A4CFEE9EC1EE9BBFEF99CDEC9ED4EB9DD0E298C0D28686A154C4D68A
A7A461A69D5A9594516C762DD0E89ACCEB9BC9E898D6F3A3CDE899CFEA9BCDE899D8F3A6
D2EDA0D1EC9FC6E096CFEBA0CCE89DBBDA8EC4E397C7E6A0839F6400100019350CB4CFAE
CCE8CFAAC7B192AF995A785E2B4A2AA9C9A2BCDCADD6F7C281A06789A86DACC98F9AB379
40551ACEE2A5E5F5B7CCDA9CD4DE9FD5DE9DE1E4A1BBBE7B
C8E49ABBD78DCBE59CE1FBB2A7BD7494AA61AEBF78CFE099D8E7A2DBEAA5D3E4A0C4D493
CFE2A0D2E5A5C2D796D7ECA9D2E6A1CCE099B5C982556B23657B33869D55CFE69ECDE79E
C1DB92C7E399CCEAA0CDEDA2CAEA9FC7E79CC7E79CCAE89EC3DD94E2F9B195AC647A9149
D7F1A8C1DB92C8E49AD2EEA4CAE89ECAE89ECAE89EC9E99EC9E99EC9E99EC9E99EC6EB9D
BCE891C0EB92CEEE9BD9EC9DE3E9A1E6E39EC0BB79898444B3B373D5DC99D3E29DD4EBA3
D0EFA3C6E89BCFF4A6CDF2A5C8E89DD1EFA7DDFBB3C8E69EC7E59DD3EEA7C1DC95CCE7A0
D5EFA6C1D98FD2E89DCBE196CCDE92ADBF735A6D1E83994EC7E59FD4F4B1D5F5B2C3E29E
D7F4B1C6E19CC3DE99CCE69FCBE29AC9E197D3EBA1C6DE92CEE69AC6DE90D7EFA1D9F4A5
CBE896CAE795C9E495CAE294CDE297D1E29BD8E5A0DCE7A5EEF8B9BDC589D0D89DBBC388
5A62295E662DDAE1ABD1DCA0D2E39DC1D78CD4EEA4D5F4A6C8E89CC6E798D2EEA3C4DF92
5E722A86984ECADA93CADC92DCF2A9CCE89BB9D98DCCED9EBCD88D8BA6598DA55BCAE296
E3FBB1C4DC90BBD389D8F0A4DDF5ABC1D98DD5EDA3DBF3A7A9BF76ADC378C7DD94D2EEA1
C9F2A3C6F09EC8E298C1DD90B8E594BFEF9BCFEEA2D4EA9FD7E8A1C7DC91C7E398BFD489
F6F5B46058179C9D5B929C5781954D81994F91A95F8EA45B90A65D899F56AAC077C7DF95
CDE59BD5EFA5C6E096C7E398D4F0A5D5F4A8D6F5A7C6E49CC0D9A05C7345CBE4BDF2FFEC
E6FEE8B7D0BD5971615D7963BFDCC07D9B77CCE9BDC4E0ADA8C38C92AE735F793C809E60
6D9654AEDB96C5F0ABB5DE98C4E9A3DCFFB8A3C179DCFAB0
D3EEA7D3EEA7CCE69FBDD78ED9EFA7859B5296A76099AA63D6E5A0C7D691D5E5A4DCECAB
D8EBABD5E7A9C8DC9DCEE1A1D2E39FCDDE98D7E8A2899D5692A65F73894197AD65889F57
96AD65AAC47BC4E096CFEDA3CDEBA1C7E59BC8E69CCEEAA08EA85FA6BD75B7CE86A0B76F
CEE89FD5EFA6CCE69DCCE89ECCE89ECAE89ECAE89ECAE89ECAE89EC9E99ECAE89EC8EA9D
CBF29FC7EA96CBE395D2DF97DCDD9BE0DA9CC5BB80958C51C5C086DFE3A8D1DD9FCEE3A0
CDE8A3C2E19BCCEDA6C3E49DC9EAA3C7E6A0C5E4A0CBEAA6C8E5A3C6E3A1D2ECABCDE7A6
CFE8A7CFE8A6D2E9A5D5EAA5D0E5A0CFE39C90A45C8DA25D83985D92A971BCD49ACDE5AB
DBF3B7CDE2A7D3E9ABD3E9A9D0E6A5D2E9A5D5ECA6CFE6A0D2E9A1CFE99FCEE89EC6E096
CDE599CCE79ACDE99ECCECA0CBF0A3C9EFA6C3EBA4C2E7A2C0E3A1DAF6B9D1E6ADCDDAA5
7E80513E3A0DC5B991E7E0B2D8DEA2DEEFA9CEE89FBADA8FCBF1A4B7E092CCEEA2D3EDA4
BFCE89858E4BC4CB88D0DB97CCE099D0ECA2CAF0A3C1E79AD1EDA3ADC47C96AD65AAC179
CAE199D5ECA4D1E8A0CEE59DCFE69EC7DE96D9F0A8D0E79FD0E69E70863EB1C77FC7E198
C0E598C9EB9FD6ECA4D4EBA3C5EEA0C4EFA0CBE99FCEE49CD2E69FCFE59DD3F1A7D7EEA6
DBDD9C686425EDF4B1CFDB99D9E8A5CEDD9AD6E5A49BAC6884955151621E798D4898AC65
C7DD95D8EFA7D0E79FD3EAA2D1EBA2C6E097CAE69BCDE6A2CFE4ABD4E7B9F7FFE3E3F6D8
F4FFF3EFFFF3778C7B94A996C8DFC38EA68295AC80CEE6B2C9E1A7C9DEA3D7EDAF85A363
B7E9A467A05999D18ABBF0A8C4F8AEACDF94CAF8ADBAE69B
CEEBA8CCE7A4CDE6A2CAE39FD0E5A0C3D991D7E8A2B2C37D5D6E286F803ACBDB9AD9E9A8
CFE2A2D3E7A8B8CC8FDEF0B2D2E2A1CCDD99CFE09CD9EAA6DAEBA7CEE29DCCE09BD1E6A1
D2E7A2CDE49EC7DE98B1CB848CA65F78934C98B36CC9E39CC8DF99D1E8A2D5ECA6C6DD97
D5ECA6D3EDA6C1DB94CCE69FCDE7A0CAE59ED3EEA7C4DF98D0EBA4C5E39BD2EDA6CAE89E
C8E89CD7F3A6D7E8A1CED592E2DDA39287518275416054227B75439A9A668C955EA1B379
88A064849E5F8CA9698AA86891AF6F85A564BDDD9ED1F1B2C5E3A7CEEBB1CAE6ACCBE6AF
C9E2ABC5DEA5D0E8AED1E9ADCFE7A9C5DE9DCFE8A6CCE0A1D4DDA8DEE2B0767A48565D2A
7E8552DAE2AFCFD7A4DFE9B4DEEBB5CCD9A3CBDAA3E3F2BBD4E3ACD0E2A8A5B77D78814A
544E1CAAA06F9F9D6A8B945DAFC28AC8E6AAC2E8ABC0EAABBFE9AABCE2A7D3EEB7D5E6B2
C9CFA1E6E1B777694264592CDDE2AAC8D899E0F9B7BFDE9AC1E6A0C6EBA5D1F0ACC6DF9D
DDEBADCED69AA0A4699DA569AABA7BCBE6A3CEF3ADC0E59FC5E09DD7ECABCDE2A198AD6C
809554CADF9EE9FEBDC9DE9DD2E7A6C7DC9BD5EBAAC7DD9CD2E8A7DCF2B1AEC483A3BC7A
C9E4A1CEE7A5DAE6A8D8E8A9CBECA7C4E9A3CBE4A2CADD9DCDDD9EDCF2B1BDDC98D7F2AF
CDD39767682ED5E1A3D0E0A1D6E0A4D7DFA4D7DFA6D7E1A5D7E2A6D7E3A5D2E0A2D0DEA0
BFCF90A4B77791A4629CB16EBCD18CD3E8A3D5EAA5D0E3A3D8E7AEC5D19FFBFFDDF9FFE4
CFDBC3D9E6D289968268785ECFE0C0CEE0B88EA070ACBD86CEE0A4D9E9ABD6E4A6CBE4A3
BFECA9C7FEBA8FC682669E57A5DA94AEE29ABDEFA6C5F4AC
C9E6A6C9E6A6D0EAA9D3ECAACAE19DE5FAB5C3D790E3F7B0E1F2ACBCD0894D5E1A859856
DCF1B0D1E5A6E5F9BCCFE3A6D0E09FDCEBA8D7E8A4C6D793C5D692D5E6A2DBEFAAD4E8A3
D2E6A1D2E7A2D4E9A4D5EAA5D3EAA4D0E7A1CCE39DC9E09AD2E9A3DCF3ADC6DD97CDE49E
C1D892E2F9B3C4DB95D9F3ACD1E8A2CBE59ECAE49DD3EDA6D0EAA3CCE69FC8E29BCDE7A0
C9E39ABFD58DDFEBA9A3A76CBDB680DBCF9FD5C89CA99D73D8D4A7CED0A1E4EDBEC8D6A3
CCDEAAC8DDA5C8DDA5CCE5ABC2DEA3A3C185213F0357743ACBE8B2BFDAA7C7E1B1D1EBBC
D0EABBDCF6C6C2DDAACCE7B2BFDAA5CFECB4D4F1B7CEE3AAD7DEA8DCDCA6D8D8A4E2E5B0
CBCF9D5B63302A3402616D3D8B986ADAE7BBD2E1B6BBCAA10009004D5D368A9A75D1DDB9
DCDBBCD2D1B2E5EBC7C8D8B1CCE7BA0011005C8952BDEEB6C3F3B9B6E2A7C3E4ABB5CC94
E0EAB6DFDFADDFD7A8464310000A00DCF0B3B8D092E5FFC0C7E4A4CBE5A6C4DC9EDFF3B6
C2D095DCE7ADD4DDA4C3CE9499AB6FCBE3A5BBDB9ACEECACD6ECAECEE2A5DDEFB3B6CA8D
60743795A96CB2C689DCF0B3DCF0B3CEE2A5C6DC9EE1F7B9C8DEA0BBD193D3E9AB97AD6F
D5EBADC6D89CDDE2AAC9D299CAE7A7C8E8A7DAF0B2D5E4A9CFDEA3CFE5A7C4E4A3C9E6A6
DDE6AD7A7F47C9D89DDAECB0DCE3ADDFE2ADDEE3ADDCE3ADDBE2ACDBE4ABDDE8AEDDEBAE
B9C88DE5F5B7CDDFA17C8F4F728545BCCF8FE3F3B4CAD89ADDE7ABDEE7B0F9FFD3F9FFDA
D4DDBED1DCBED3DEC0CFDABADBE7C1C1CEA28D9A6539470CC9D498CFDB9DD3DDA0D3E3A5
C8E8A9A9D192D2FABB97BF80244C0DC8F0B1C7EEAFB4DB9A
638046567237678346587233324B095B722E5D722D5D732B5A6E266E843C253900152A00
5A6F2E6076365066285B71316C7F3D5E6F2B697A368899558899556C7D396C7D39879854
8798548FA35E90A45F879B56899D588FA35E859954718540869B5694A964839853829752
6479347E934E6A7F3A869D5792A76290A7617C934D859C5679904A8FA6608EA55F9AAF6A
99AE698F9F5E9FA76B1E1F003C36069F966B807750463E1998966F9DA2798E996F607043
6474455666353F4F1E001000001300000F001C3700000E00000D00233A0C001600274018
233C144661382D4A1E39562893B3845779474F744054733A495C1C697833707F3C687839
7A8C5063783F566D39677E506B845A344C285C7555718A6D58705839503C4B62501F3F2A
001000002C10001400134C29266038508D613E7A4737723C53894F5181457EA5665F7D3D
6B803F5C68287177377A8445466021123000203800415319727D457178427E854F556028
6D7C43384C11637B3F5B75383F571B001700000D00495B212234003A4C1259682F1D2F00
2B3D0302140047591F47591F000D00283C01253A00000D000F24002E4308182D00071C00
071900000A002E2E001A1F001A32000F2B00213500212E00263300293D021A3800193500
2D3600282F002C3E043B4D13262D002B2D002B2F00272E00232A00212A00212C00223000
2F3E052E3D022E3D022A3A002232001E2E00253300313C001F28002127003037015F6537
2F360D070F00353D1625300518240035420C2B3600252F0050581C262E002C3100363E05
626B343D48102633003B48121523003748142132006E804C
55723CD9F6BED0EDB3C9E5A8C7E1A0E4FDBBDFF6B0C2D991DCF2A9C9E197D8EEA6C0D791
CCE39F96AF6D2B4403647D3CCADD9BCCE09BD3E4A0D5E6A2D1E29ECDDE9AD3E4A0DDEEAA
D3E4A0DDECA9DBEAA7D0DF9CD0DF9CDAE9A6DCEBA8D3E29FCBDF9ACCE19CDAEEA9CCE19C
D0E49FD6EAA5D3E7A2DCF0ABCADE99D9EDA8D4E8A3D1E5A0C7DB96D8ECA7CDE19CC2D691
CEDF9BD4E3A2D9E1A59B9E67CFCD9DEFECC1AEAC85757750D6DEB7CDD9B1A0B187000C00
000E00C8D8ABCEDAACC3D1A0C2D79EE7FFC6C5DCA491A874728859BBD0A5C6DCB5000B00
000C0035512B516F49C1E4BAC0E5B9BCE3B6CEF8C8CAF3BBBADD99D3F5ABC1E29BC3E6A2
BADE9ECAF0B3BAE1AAC8F0BEB2D9ADBFE5C0BBE0BFD1F5D9486954244532000B00000D00
1746324A8069B2EACF83BB9E3F7B570038104E895BB3ECB9285D2578A86CB5DD9EC8EBA9
D9F4B1CCE19CCEDD98D0E5A0C6E6A3B3D69680955A1E2900060600D7D4A1C2C08DF6FBC5
CFDEA5C1D99DC2E0A2DAF8BABFD99CCCE1A689965E8F9A62D7E4ACD1E0A7E0EFB6BECD94
DDECB3CDDFA599AB71D6E8AEDBEFB4C9DDA2DAEFB4CEE3A8C7DCA1D6EBB0CBE0A5D0E5AA
BDD19697A46CCCCF9AD9DEA8D8F0B4D1EDB0D2E4AAD9E6AEC9D49CD6E8AECFEBAECBE3A7
DCE1AB4C4F1AD6E3ABD0DFA6DAE1ABDDE2ACDDE4AEDDE6AFDBE6ACD7E5AAD4E3A8D0E2A6
D6E8ACC2D498BED094D0E2A4DDECB1D5E5A7CDDCA1D4E0A25B6423E2E8A8D4D99FD6DDA7
D5DDACDBE4B5E0EAB8CBD8A3D2DDA3DAE5A9C8D494CCD697E4ECB1F6FBC3878B58D7D9A8
E1E4AFBEC18CD9DDAAD7DEABDEE8B6D2E0AF67774ACBDCAF
A4C1917F9D6B4E6C36C9E6ACBFDB9EBCD695CBE4A0DEF8AFC4DC92D7F1A7CCE39BC4DE97
D4EDA9CDE8A5A9C382849E5D8DA25FA2B774C1D492D7EAA8D9ECAAD2E2A1CADA99C9D897
D7E6A5D3DF9FD0DC9CD5E1A1DBE5A6D8E2A3D2DB9CCCD697E0EFAECFE2A0D6E6A5CCDF9D
D6E6A5DDEDACCFDF9EC4D493D0E09FD0E09FD9E9A8D4E4A3DDEDACD5E5A4DCEBAAD9E8A5
D1E29EB1C27E909C5EB7C185E1E8B4D0D8A7D9E4B9ABBA8FADC2978DA47A647E5161784A
879A6DDDEDC0E0E9BCDCE6B491A369788C4F8FA3689FB27BB3C796D7E9BFD5EAC3D4EAC6
4E68455F7D5927492450795194BF94A2D1A5C1F2C3B0E5AFC0F8B7B8F1ACABE4A0BBF6B4
B4EFAFB8F4B6B1ECB2BEF9C1A5DDAC6EA37540734A12421C507C5950795961886B5C785F
D6DFCEDCDFCECED7C4D9EBD1C5DEC07698737AA1754E7A4986B57F5F8C53C6EFB3C0E4A6
C3E1A1CFE8A7CDE2A1D5EBAABBDE9AD7F7B6CBDFA26972396D6C366B65317C7642DBDBA5
D9E4AADAEEB1D8F2B3A3C080D6EEB0E5F9BCE3EEB4949D646D7B40CDDBA0DBE9AED1E0A5
D1E0A5CFDEA3A3B579586A2EC7DB9EDCF0B3BBD193D4EAACD3E9ABBCD294DCF4B6C4DC9E
D6EEB09BAD719DA56CCBD49BCCE6A7D6F4B4C7D99DDCE7ADE6EFB6D0DEA3CBE1A3DBEDB1
CECD97867F4BE6E9B2D2DCA0D7E1A5D3DFA1CEDC9ECEDE9FD0E3A3D2E7A6D0E6A5CCE5A3
CDE6A5D4EDACD3E9A9C8DE9DC7DB9CD3E6A6D9EBADD8E7A6D3DE9A959E5B636C2DD7E1A5
DBE6ACD7E4ACC8D69BD6E6A7E1F0AFD0DF9CD9E8A5F1FDBFEFF8BFE4EBB8BBC195545A2E
78824DD3E2A9E3F6BED8EFB7C9E4AFBBDBA9547848B0D7A8
C4E3B7CDEDBEB9D9A78DAC73D7F5B9CDEAA8C9E49FC7E198D5EFA5CAE49ABBD58CDFFBB1
D5F0A9B2D08ACFECA9CDEAA7AFC68292A7648499568DA25F92A56393A664B6C584E2F1B0
DAE6A6D6E0A1DAE4A5E1EAABD9E2A3CDD395D7DB9EEAF3B4CDD999D1E1A0D2E2A1DEEEAD
B9C887DBEAA9CFDE9DE0EFAEE2F1B0C9D897D4E0A0D0DF9ECBD797909C5C8B975793A25F
94A55F94A86191A560D5E5A7D4E3AAC5D7A3E0F6C5607C4C2B4B1C000F006D8E5FC0DDAD
E0F6C7A0B081616A3BBAC28FA2B073CFDFA0DDEDAFC4D59ED3E3B2E8F9CDE8FAD2F4FFE4
F1FFE8B2D1AFB6DCB779A67F80B0861B50228CC69675B17E76B68279BC8795DAA47ABF88
7EC18B64A77164A56D3B7A431E592353895582B47F8FBE8AD5FDCBBDE3B0B6D8A6C7DEB0
92946F938D6B9996739FA17C979D778D9A6FB2C397C7DDAF95AF804C6A380012006C8C5A
ADD09AB5D8A2DEFFCBC3E4ABD7F7B6BED996C9DE9DD7E3A5CED49895965C59581F242500
B6BE82D0DC9ECFDFA0E7FABACDE2A1C5D898CBDB9CD8E6A8D3E1A3738143C7D597DFEDAF
E5F5B6CCDC9DD3E6A6D9ECAC526726D2E7A6D4EAA9C3D998DAF0AFD2E8A7D2EBA9CFEAA7
D1EEABB9D290A4B072D5E3A5C5E4A0C9EAA5C1D494E5EFB2DAE2A6BBC588F0FFC3D4E0A2
DFD69F6A5A26EBE4ADDEE2A5E1EDABD7EBA6CFE49FCBE29CC9E39CCBE69FCAE8A0CAEAA1
C4E29CC4E29CCCEAA4D7F2ADD4EDA9C9E09CC8DD9AD1E5A0CEDB96E5F0ACDDE9A7CEDA9A
697739ADBD7EDBEBAACCE099CADE96BBCF87E6F7B3CFDD9FE9F3BEFEFFDAE4EAC6D6DEB7
BAC8939DB174647C408CA96FC0E5AFC3EEB9BAEABA669A6A
8BAC8192B386BBDBAA718F5B91AE74648141BBD993D8F4AAC8E499C4E093D2EEA3C6E49A
C2E098D3F2ACCBEAA4BFDE98C2DB97CAE19DB4CB878DA25F859856A0B371B2C180AAB978
939F5F949E5F9AA3649AA062898D508185489FA064C5C98CD2DE9ED6E5A4D2E1A0CAD998
85915195A1618995559BA7678B975795A161BCC687DBE7A7D5DFA0A9B374959F6097A361
B0C57ACAE296CBE29AD6EDA9CDE5A7C6E2A8AACB9441683300250056824DCBF6C1BEE3AF
93AE7B6C7E4C8A9462B6BF88C6D292D9E8A3CFDE9DD0DFA4D9E7B2E7F7C8F7FFDFECFFDB
E1FDD7D2F2CDC0E8C3BAE8C1AFE4B84B86563A7A484C8E60216041135339407F64317051
2E6B491C593067A0738AC08C689962BCE8ABCCF3B2C1E09CC2DC95D4EAA1B1C3799DAF65
8FA75D8BA3599CAD6788935187884EC0BA869A8F629D946B98936D9697752C3A17496340
49714E8CBE998ECAA4B3E7B9CCE8ADD1E29ED2E6A1D9EDA8D4E8A3D9EAA6929D5BA7AD6D
7575378C8A4DCFCF91CFD494E7F2B0C7DB96D1ECA5D3EDA6CFE09C919D5B93A25FCCDB98
C3D490C5D692D7EBA6CADE998A9F5A9AAF6ACAE19BDEF5AFCFE6A0C6DD97C6E099CEECA4
BFE399D2F2A9AFC37ECCE19CCAEEA4C3E79DCDE29DE3EEAC8F9555A9AF6F6A7634E0E5A5
EBDAA2644B15E4D39BDDDC9CC7D78EC7E295CFEB9ED0EFA1CBEE9EC7EC9CC8ED9FC9F0A1
C5EA9CCBF0A2C6E89CBBDB90C1DF97D5F0A9D7F1AACBE29AD3E49DD9E8A3BACB87D8E9A5
C9DC9A829752829850DDF3AADAF0A5D6ECA3C1D590ECFEC0CBD9A8E1EDC7F7FFE3D5DFBD
DFEDB8D0E2A6C7DCA1668349A8CD97C5F1BEAADEAE82BA8D
6A7D5D657B572B461D98B589BCDEAB81A26B93B276C5DFA0D4E7A7D5E1A1D4DF9DD4E09E
D6E5A0CEE49CC6E298D2EEA4D0E5A2D1E4A4D0E3A1CFE2A0D1E29ED3E4A0D5E4A1D5E4A1
DAE6A6CDD798BEC68AB1B779A0A4679395569595579CA063A0A9708C955C9DA367969C60
8E975E9CA56C9CA46892985CBAC084D4DDA4D9E3AEDDE8B0CBD096DBDFA4D6DBA3D4E1A9
C6E2A5D1F1B0CDE6A5C7DD9FD3EAB28299650018000E2400849662C1D29CD7E8B298A975
7B8D5BD4E2AFDBE2ACDDE0A7DEDFA5DCE0A3DFE5A9D8E0A5D8E1AAD1DBA7C9D5A5DDEABF
D4E0BAF8FFE4F4FFE5C8E2BDCBEEC4C1EBBDB9E9B5B4E5B6B8E3C7A8CFBAB6E0C8C6EED3
BBDEC0C3E1BFD0ECC3C3DDAED8ECB9D4E3AAC9D195E9EEACD2DA91C1C87B999C4F959E4F
CDE693D1EE9ACFE293DAE299EBE3A4DFCC94EFD4A7F5D7B1AC8F71A69176C7C0A6DFE5CB
B2C9AD85A98D6A9979547E58B6C896DBE4ABD8E3A7D9E7AACEDC9FE3EFB1C5CD91E3E4A8
C4BF85766D32675E23656122ACB16FE1EEA8CEE49BCDE39ADBE6A2D0D794E1EAA795A05C
DEEAA8D1E09DDEEDAAD1E09DD2E19ED5E4A175844391A05DD8E9A5D1E29EDDF1ACCBE29C
C7E59DD4F0A68E9A5896A560C4E49BCAEAA1DEEDAAD0D595838345D5D798DFE8A7989A5B
88713B6D4F1B69561E6A642888924D9DAF65BDD287CFE698D0E89ACCE496CBE59BCEE89F
CEE7A3CCE5A3CEE7A6D2EBA9D3EAA6CCE39DCBE198D1E399DEE9A4D4DB98DBE4A3D7E2A0
CBD795D8E5A0E7F4AF55621C8F9A55D8E19EDAE0A2DBE0AAD4D7ACF7F8D6FDFBE2EFEED2
E8E6BDEFEEC0F5F8CBE6F2C4A9BA8EBCD7ACC7E7C08BB18A
FFFDEDFFFFEBDDEAD05C77588DB590C7F2C77E9E75889A70D7D3ADE9D7AFF0D5AAF9DFAE
E3D499DCDC96D7E898D5EA9DDBE4A5D4D99FD8E1A2D8E3A1D4E19CD3E09ACFDE99D6E7A1
CFDE9DE9F7B9CED99DD1D99DE3E9ABD8DA99DBDC9ADBDCA2D5DBAFE2E3BBDFD5A2ECE2AF
D1D2A6DEE1B4DEDBA8D9D49DE7E5B2CED4A6D5E3BFE1EDC7D3D1A1D7CF9EDDDCB0A0AE8A
537B591A4622C8E2B5A2AF817A855D02060030290D644D2DE7BC91FECC9BFED4A49B7F50
ADA678D2D4A2D4D496EEE8ACE4D3A7EDDAB2EEE2B2DCD7A0E2E0A5E5E5A9E0DBA4DFD5A4
E9D7B1FFFAD9FFFCE1E4D5B8DCD6B2D5D8ADD9E7B2D0DDA8E2E0B7DEDAB4D8DAB2E4E5BB
EEDEBADBC5A0E7D4ACEDD7AEF1D8AFE0C195FFE2B8E9C799EBDCA5595015E5DB9EE5DFA3
E3E9ABC5CF90E9EBACE2DCA0E7D69EECD09EF4D2A5FBD3AFFCD0B3FFDCC3FFF5DFFFE9D2
E4D4BAE3DDBD6C6C4A0408003D411CD9DBB6D9D7B1F0EBC5DBD2ABE1D5ADE8DBAFE8DBAE
DCD29FE9E2ACE6E1A75C5B1B525311E3E6A1D6D994E4E5A1DAD696E7E2A2DFDE9E969859
575D1FCFD79BDAE2A6E1E6ACDADBA2E8E7AFDAD7A298975F9A9B62D9DCA3D9E1A5D0DA9D
D3E2A1D5DE9DA19B619A9659CCDC9BDBEBAADDDDA1E9E0A7AEA36BDED89EDAE0A4D6D79D
E6CE9E7D6132FFF7C3E0D9A3F3EEB7908B515E5A1A5D5A15E9E69FDBD891E2DE9FDED9A2
D7D2A8EBE7C2D4D1AEE0E1B9CED29FE2EBACD7E296DEE598E0D89AE5D8A1EDE2AADCD69C
DAD699E7E3A6E1DB9FE3DA9FDFD09974602DDCC496EAD1A9FFE8C7FFF2D4FDE5CBFFFAE3
FFF6E3FFF1DEFFF9E4FFFAE4FFF4DC897D63F4EFD1D1D0B1
BC8485885B58FFF6ECECE9DA4250391D311896A68C888C736D5D44A7876EB38A6CC39973
BC9C6BB39F64A5A05CA5A463A89E6B9E9164B0A673B8B37BAAA86DA7A7699FA36690955B
9EA16C8B8D5B979666A7A37398915DA49B64A3995C5E5721A2A27E868664A3976D756A3D
82835B8B8D663733068E8A5B8C8B5F787E584B5B3E7C896B56542D423B110C0A00374524
1F422A2C533823330E3B3D15211E003B32156551397752358B502682400E8E5424815928
6453275D55246259186E5E239E8662472E1076673E514918535118535116625B24695928
644821654222613E2265462AA68F6D91855B8C8C5A4B49166B582D8D764C988D5F463509
7C5632BA8D6C7D553266401C825734C08F6EAB70528957366851257C723F584A19605422
5855225D5B286E6932594C158D78416A4E1C6B461A7046206D4021B88A70BC927AA07B61
8361459477558169435647204D4727120F00080100352C0D594C2C7B6D4A4C3C18614F27
BBA87E968456A494638F7F4B64551E3B2C00918249A6955DAC965DAD975E9E8B53B2A66C
534A13A099629E9761A89C6AA59564D4BF90AA94655A4415695727B3A3729387538E8751
A39E64A499618369369B86519A955BA19F64AC9B67967C4B7D6332A995629F95607A6E3A
9D7C51603D13937D4EC5B3837A613894794E785C2A6A4F18553800A48650B59668B1906D
B89881AF907ECFB4A3AD957DB09E7AB0A470857D3C716825AE9B63C3AF7CA1915DA69B63
A0975E8C83489B90587C6D369D85556A4D219E7C56A27E5A8D6A4A9F7D61AB8D719C7C65
C19787DFB3A6B98F81C7A290CEAF9A6C5239604D2F766645
8C1D2ED87280B4616BEBAAAE7448476C4F494A362B271507634E3D775C4964442B694427
805A36643F156E491C7F5C326E4A2A6441236B4A276B4D2761451D6952296E5831523E1B
6952335F472B7559416E50345F3E1F74522D7B562C5B43173C3813656B4760653D3D3F17
65673F474C23454C234E562F535F3B4B5936505F3E0008000812000007002328004F572E
5A6B4743512D5D582E62532863512B675531554120B59E757757246A4A115E430C9A8550
B0A271635320765C236C511CBCA67FD5C6A548431B686A3B979E6A787F4B444614676032
A8966E7B633F553B1A5C45256A5C39918D6750572D9BA0772013000E0000DAD6B35F5635
A4866CE5BFA8F2D4B8FFF1D5FFF4D7FFF1D6F9CAB06D46296F613A9895685C5529665F31
807E4D67653287824B6D622A5D4C14664F199D81516B4A1F734F2BFDD9B9EBC9ADFFE2C5
F3D9B8D5BD97C3B0855E4D229F916C342A0607030011120074764EA8A97F66613982734C
674927977051673A1B7D4E3074492967411D785A3440200075481F74451B754A1F6F4A1D
6A4A1B6041127657285D3B0E744D226E441A7F5229794C23754B21724B206F4C226E4D20
6244127C5C296D42156A41135E400E573907825C2F85582E7D502671481CA17F526E491D
7140186B37106F441A8F653F8759387A492B835130EBB996713C1A713C1C6D371FB67E6D
A16B61AE797366342DA07064EDC3AB8059387351249377454A3603685B2659521B6E6C31
7070345E5E22716F345751175D4D1A634E1F6E562A9980576D552F6E58339C8A66574322
56381C694A2E684A2E9A8163937F5E62522E4C431A888155
FF9EABD8727DCF747DAC5F65CB8F916A413DA18A82241A0E252614696E5775795E6F6E4F
6255356A5333896849957455AC9277A18E70978668AC9D7CB8AB89A39A799B91769B937C
A8A08D908474AA9A8AA2917D8F7B629C8867AC956CBDAE8380825AA1B089869A75A0B18D
5C653A90996E6D7D59283D1C213919182D0C00090023330C172D07D6EBC4CFDBADDDE9B9
C9DCAFCEDDB4E8E6BFC6B996F6E3C5DFCAADE2D1B3E0D6B3DEDBB057592AB6BE8DD0DAA8
D9DFB1E0DDB0E6D8A9E6D5A9E1D8B1D1CFA8CDD4ABB9C69B7D8E6286996BC0CDA1D0D6AA
E9E4BAD8CCA4ECDEB7A89F78302E08DFE7C2D2E2BEA9B7944D4C2E696446D3D9B5DCDDBB
89755AE3C9AEFFFDDDFFF2D0FFEDC9EDD7B2EFCEAB9A835AA4A373D8E2ADD2D7A1D8D8A4
D3D1A0D0CD9AE8E3ACE5DCA3D8CE93CFC085D4C08BE2CC9BEDD4ABF2DAB4FAE2BEE6D0AB
D3C098EDDCB0D9CB9AE8E1ADD2D6A3E0EEB9CEE0AC59703A0F2700506733C7D7A8C2C89C
A29A75DBCBA9B49B7DB69B80A0846CB59B82988368876C4F78502DC39772B9946AAA8B5F
AC9162BDA674B09665A68A58937342AC8A5AD4AE81BB9568AD885C8A693CDFC094D2B687
B29865E0C791D4B684937543B99D6BB29664D8B889FDDBADB997698A683AD9BA8CCAA97C
D0A97EE6BF94FFDAAEE3C098CEA587E0B69DFACEB5FFEFD8E2B39FFFD0BEE7B7A9BB8B81
C3928DFFF2ECFFECE3FFEBDDFFE9D6CFAB91987758D4BB93AA9E6EBCB780DDDEA5DDE3A7
D7DFA3D9E2A3D0D698D7D89EE7E2AA766C37DED2A0EFE3B3A4996B90885A8F8B5EECE5B9
E1CFA7DFCCA2E4D3A8F6E9BDF2EABBE3E0ADE3E3ADE5E8B1
8A5C4D8459498A5C4FA88074FFF1E6F5E5D6DFE6D4819F875F957574B690B9FFD6B2F0C7
91BF9856714E8C9374B1B899C2DBB4D2F5CB96BB90779E728CB58D7BA7836B96786F9B80
76A08C264D3A577A6683A58C66856369855C6A8454576F3B728653738A5C75987796B895
5E6F4394A378C3DEBDA2C4A9D7F9DEA9C7A5D8E9BCE3F6C8C7E7C0CDEDC4C6DBA3CEE5AD
B3DAABA6CEA9CBE5CAD2DDCCEAE2D7FFF7EED0C6BCA8AA9D68816E658D755384677DAE8E
69936F8BAD8AB1CAACD5E6C6D8E4BC7E8B5F2D421945613987A782BCDCB7B7D1AA8CA178
C8D3A8DEE4B6D7D9AA8083583E4921A3B794D8F2D5435C3F67734F879065DBEFBECFDCAE
B8B187F3E6BCD3CF9FFFFFCCE2E1A9E5E0A8B5A66FAAA466BFD08AD9F1A7EBFDB3D1DA97
EAE9B3F0EAB8E6E1AA6D682E666022938D4F8E854A6C632CA298659E93659A8F62F9EEC1
F7ECBED7CD9AECE3ACD5DFA0C1F4A9B7FAABA7E399BBF3ACC3F4B276A46489B97D8ABA80
91C48C73A57295C595B9E2B8C4E2C0D0E3C7DCE6CDC2C2A86F6742B1A57BE3DFB0DEE1AC
CBD39AD4E0A2CED899D4DD9C4E5313E6E6A8E7E2A8D6D197E6E4AB7B7A429D9D67DBE0A6
CAD092DCE5A4CCD896909B59B5B97CDFE0A4CFD597DCE2A4D8DEA2ADB176A7A66DD8D79E
D8DBA2D7DAA1EAEBB2D5D3A0DFDBB5D9D4B4E2DBC1E4DCC7FFF4E4FFFCF1FFF6EBD6C8BD
A7998CF9EDDDFFFCE8FFFFE8D8D2BAE8E4C9E5E1C6D4D4B2CED0A1D3D8A0E4EDB4DCEAAD
D6E6A8D8E8A9CFDD9FD7E1A4D6DCA0919259DFDEA6E0E0AADCDFAADAE1ABBEC8938C955E
A9A870E4DFA7E0DEA5DDDCA3DDE1A4D3D99BD4DF9DD0DC9A
91936B5E5C363C2F0F3322089B8671E2D7C3F5FFE7DDFFE467A38139855E4CA17881CFA7
7BB7956E95783F4C384E5E44769F7571A9782A6231235E30407A5114502C0A47282E6A51
589180447A6A75AA98B8EAD1D2FFDDD1FFD1C6F1BBC3E9AEC3DFA4C8E6B2BAE7C0C3EDC9
C6E0B1CAE1B5C4E7C9AFDABF8BB39992B491CFE3B0BAD19BC5ECBFB8E0AEC3DD9ECBE5A6
D4FCCA507C5884A793DCF1E8EBEEE7F1EEE98E8F87A8B9B166988F074B3E65B09B92D9BB
90C6A4103C19789E85C2E3C6C7E2B55F7B48001300527A57517C5E608D7082AA887B9E76
788F61A7B985D3E4AE65774500100091AE8FC9EFD80D30181A3009263A098CA973C8DFA9
BBBD8BE0DDA8DBE1A5C9D593D9E6A1D5DF9851530A979E51C9E590C4E78DCEE690D7E598
D4D39AD8D2A0EFEAB3727035939353DFE29FEAECAB6D7134595C235E612C6163319A9A66
B0AF79D4D299EBE9ACD3E29DC4FBA8A2EB92C1FFAEB9F8A9B2ECA0ADE9A19FDE98448946
2D793944945742915877BF8D6EAB8183B28EB4D8BCC0D9BBA1AB866F764ABECC9BDBF0B8
DBF5B8BCD997D7F5AFD0EAA3839951D0E19BCEDD98F2FEBCC0CF8E72804290A264D2E6A7
D8EDAACDE7A0C7E99FB9D990859856D7E7A6D3ECA8C9E7A1C8E3A09AB06F707E40EEFEBF
C5DF9EC5E2A0DAEEAFD2E1AAD3E3B6EDFBD8EBF8DEDDE6D5EDF2EBFCFFFBFEFFFBFBFEF3
FEFFF1D9DEC79AA384F6FFE0ECF7D9D9E3CAF7FFEDDBE5CAECF5C8F0FBC3C3D297CEE2A5
D4EAACC7DD9DDFF4B3C8DB9BD9E5A7858F52EEF6BAEDF7BBE9F7BAD4E6A8C2D89ADEF3B2
7D8643888D4A9BA25EE2ECA7D9E6A0CCDC95D3E59BDDF2A7
CFEEB2C4DCA2E3E6B7E9DDB7E4CCB0B29881A08F7BE5E4CFECFFEB9AC1A693C1A500270F
7A9582798476574C461A14046D865FCBF3C1B8DFB088B386A6D0AADCFFE7DFFFF490BBAA
7BA39AD0F5EDDBFCF1D4F3E1E9FFE8D0ECC3B8D3A0CDE6ACD4EEADBEE0A3B4E2B3CCF9CE
B9DDADD3F7CB0E3A193260449DC8AA8DB28978915A6780467BA26BC6EFB3D6F5AFABC480
7E925D1C320C000A00839B8EE3EFE3EEF6E7F5FFF3E2FFF33E8273A5FAE78CE1C4C2FFE3
BBE9BBBFDEB2CFECCDBFDDB9C1E2AD0012000016002A5C3980B69C82B8A094C6A9B9E7C2
C8ECBCC2E1A8A4C2863B5A21001000153E1E001401406D59D3EFC9D0E8B6D7F8C13F5A23
9A9E6BE7E8AFCDD999E1F5AECCE395CDE391586513D7E993CCEF91DDFFA4BBD679E5F4A3
EDEDB1DFD9A5918F56909253E6EDA9D4DF9ACBD892D9E8A5C5D596F0FFC29FAD72818C52
626A2E636929B0B36EDAE49BC3D98EC6E597D0F5A7AEDA8BBBF0A2CDFFBBBAFAB0ADF3AB
B5FCBAABF3B4377C4370B57F67A97977B6895A976E69966F8E9E796C734A5D6A3EC3D7A4
C3DCA2D0EFACC4E39DCBE79D829A50CDE199DFEFA8C8D590F0FCBCCEDC9E8C9C5E9BAE6E
CCE09BC5DF96C2E89DC2E69C6D7E3A8B9755CDE6A2CEEDA7DCFBB5BAD38FAEB87BEAF8BA
BFE09BC4E8A2D1E6A5CFDEA5E7F6CBF8FFE6F8FFF1F9FFFAF1FAF9F9FEFFF6FAFBFCFFFA
FCFFEFE8F1D2D7E1BCE6F0CBC8D1B2FCFFEDE9EFE3FCFFEFFCFFDCFBFFD1CBDFA4D2EAAC
D3EDAEC3DD9CD8F1AFC4D998CFDF9EC2D190E8F7B6FAFFCBF8FFCCDAF5B2D6F5B1BBD991
E0F2A8909E5194A257B3C378D6E89CE0F5A8D4EB9DBDD486
B5EA9CC6F2A7CEE7A6D2D7A1E7DAB0E2CEADB8A489D8CEB5E1E5CCF8FFEFE9FFE8F0FFEF
CBD3C4E8E4DB2B1814645848D2E3B7C7E8AFB0D19AC4E9B6C8EDC1CBF1CCE9FFF3E5FFF4
59796CD3F1E5EEFFFAD4EDD7CADFBECEE4B5DEF1B9CCE2A1CEE8A1C2E29FD2FBC1BBE7B4
B0DBAD1E4B20497856C2F1CFC1EBC5BFE5B6CEEBB1BEDC9C00140000130040621586A65D
C7E0A79CB68F577D68DCFFF2F2FFF6F7FFF3EBFAE3EBFFF4124F40307A6B4E977A2E6B41
94BD85CBEEB4BBE5B57CA877BEE7AB588447538457AAE2BFB3EFD643816A134E324D845D
B6E5B1C4EDB1C4EBAAC2EAAEBCE7B9548565001304457869BCDBBCCFE8C0D0F1C4F2FFDD
515429D7D6A6D6E3ABCCE2A1D6F1AAC2DC92D8EA9ECAE08EC8EF96B7DE85E0FAA3CAD68A
D8D79EDCD9A46F7036D2D898D6E39DD3E59BCEE49BD0EAA1D3ECA8C8E19FCAE0A0D3E5A7
D1E09F919E58566017E3E79DE7E29EDFDC97DBE29CD7EBA3C6E89EB8E499BAECA3BAEFA9
B4E8A6BBEFB1B9ECB1C3F8C0B0E7B0B8F1BE78B4801846172B37116E704B4F572E859566
D8EFB7CBE5A6CBE6A3D1EBA4DEF2AB45550ED8E39ED4DD9AD2DB9AD5DE9FD0DA9D5A6427
D4DF9DDAEEA7CFF1A7BEDE95A0A9685E6424C6DB98CAE5A0BDD893D9EEABDEE2A78E965A
C7E4A1D2F3AED1E1A2FFFFD1FCFFDDF7FFE3F7FEECFCFFFAF4F8FBFEFFFFFEFFFFFBFEF3
FEFFEBFFFFE1CAD1A7D7DEB4606644F4F6E0FFFFF6FFFFF1D3DEB3CBDDA3D4E9AECCE4A6
C9E3A4CCE6A5C8E19FD5EAA9DDEDACBECD8CE1F0AFD1E5A0C8DF99DAF8B0B8DC92CDEDA2
CAE193D5E899DAED9E3C510298AD60C7DE90D2E99BD4EC9E
B4F599B8F29BC2ED9ECBE9A3D5E5A7DAE1ADD9DAAED5D7B0B7BD9B9CA5868E987D808871
ACAF9CCDCABBFEF2E6FFFFE7D5EAB2BEE29CC3E6A2C9F0B1BDE4ABCAF2C0E3FFE2D0F7D8
2548309CBEA6D6F4DAD4F2CEC3DDAEC0D99FDEF5B1CBE399C7E197CBE79DCDECA8C0E6AB
4E7F500B3F1804340C3863387BA17091B6807FA366CBEBA8CBE79ACCE997C6EB9BBDE99E
B8EBB087C296084A2FA2DBCAE6FFF6F7FFF3EEEFDDE5E9DA58716D496C65C1E9D1C7F0C6
9BC585001A00226F29B0FDB9B9F0AC8AB878164A1A639D77AEEED3A8E9D1B1F0D14B855C
386D359FD08FCEFBB8BDEBADB4E6B5649C79B0EDDD80B4A87B978990A592A6BFA9E1F5DC
85836CC9C4A7D2DAB3DAEDBFCEE9B48FA86FC5D79DCDE1A4C9E9A6C9EAA5D4E4A5DBE0A6
C2C18B2D2C00707638DFEAA6D3E59BCFE799D0EC9FC9E99DCAECA2CDEEA9C6E3A1C4DD9B
D6EBA6D5E69F98A65B52540B694F129A7A41B09A60D4CA8CE9EBAAD6E2A0CDE09ECDE3A2
CAE0A0D0E8AAC9E1A5D2ECAFC4E0A5CDECB1C3E7AAD0E8B4B9B993423918060400202700
8D9B68D3E5ABC1D395E3F3B2D9E4A2DCE3A07B7B3BE4E3A3D7D598E5E3A8D6D4999F9F63
E6E4A7CBD28FD2E8A0CCE0999A9657A19B5DD7E09FD2E39FD3E3A2D7E0A1E4DEA4747237
879A5ACFE5A4DEE4A8FFFECBFFFDD6FFFFE6FFFFEFFFFBF5FFFDFDFFFCFFFFF9F6FFFFEF
FFFCDFFFFFDAE5E3B3DBD8ABFDF9D4D1CAB0CAC0B4C8C3B0D4DDB0CEE0A4D5E9ACD3EBAD
CBE3A5CCE5A4D3E9A8D0E3A3D0DF9E8A9656C1CD8BE0F1ABCDE39BC6E298CCEEA1C3E696
C9E193D5EA9DC7DC8FDDF2A5B2C77C7B9146DCF2A7C5DB90
BCF195BEF195C1ED98C4EB9ACAEAA1D4EFACE1F6BBEAFDC6E4F4C5D2DFB4D4DCB7D5DCBB
F7FADFFDFDE3FFFFEAFFFFE1D1E7A6C5E697CAEC9FCDF3AAC1E8A5C0E8ACC5EDB9B6DDB1
BEE4BF98BC98D0F0C9C1E1B2D5F2BAD2EDAAC4DF92CBE493B0C87A344C0063792EACCC8B
44794B003812B0E1B4CFF7C3CCEFB5B6D89BB8E0A2C5E9A3CCE490DEF69EBEE594BEF2AA
BDF9C37CC3993B897171B8A6CFFFEBD9F6E2DAE6D2D2D8CAC2D3CD3E554D7A967F5B7B52
83AD6B90CD802E863A80D68BC4F9B3BDE7A779AB76427B523D7D5B65A68672B28D3F7D4E
558B51C2F3B2CBF8B5BCEAACBBEFBE326C46B4F2DBA0D4C7B5D1C5AFBFB4D8EFDFF8FFF3
D5CEBEBDB29E939878BDCEA4BCD6A694AF7CD4E4B3D9EBB7CBE8AEC8E4AAD4DCA9D9D7A6
53531D5A6024C1CB8CDEEDA8BDD388D0ED9DD2F3A4C5E79AB9DD93C4E8A2CBEBA8C8E5A2
CAE49DD1E79ED0E598D2D88ECCBA7CC0A66DB8A268716126736B2DECEBABD2D795E1EAA7
D8E4A2DEEDAADDECA9CBDA97DBEAA7D0DF9CB5C481959F63A9A87C5A583232370E000C00
697D489DB67DD3EDB0BCD294CEE1A1C6D292919A59CFD494DBDD9EE1E3A4DBE0A09BA05E
E3E5A4D1DA97E9FFB7D6EAA39A9A5A696828E0EBA9D0E49FCCDF9DD8E4A4DDDDA1ACB073
A6BB7ACEE7A5E0EAADFFFFCEFFFFDDFFFFE3EBEAD6DEDFD1EFEFE7FFFFF6FFFFF1FFFFE8
F0F5CDD8DFACD4D9A3DBE0AAE0E1B5CFCFADEBE6D0D4D4B8C5CF9DA0B274ABBF80DCF2B2
F1FFC7E1F7B7D3E8A7D3E3A4D2DC9D697231ECF7B5D8E5A0D0E49CD3EEA1CDEE9FCBEC9D
D7F2A5D0E69BC8DE95C9DD95D5E9A1B8CC8496AA62D5EBA2
D5E795D4EA97CFEB97C5E896BEE896C1ED9ECDF9AEDAFFBCD1F1B2C6DFA6D0E0AFDDEABC
F6FED5ECF4CDE6F0CBDCECBBCDE49CC8E591C9E996C8EB99C6EB9EC8EDA7C8EFB0C8EFB8
C7EDBC95B989C4E6B4CCEAB4CCEAAAC9E59B9AB66294AD59A2B76A96A85CBACB7DC8E5A2
4981540F4D26E0FFE1ABD299CAEAA9C1E19EDBFFC4CAEFA9C6DD85CCE389B9E296BEF2B4
B5EEC3B2F3D5317A6662AD99599A84A8E0C7A9D5BCBDE3CCB0D6C787AC9B15371C23481D
689157437834458E499BE19BC0E9A5CAEAABC6EFB799CB9A78B18683C09686C49584BD88
7AAE70BEECABB0DA98B9E5A8CEFFCB538C61ACE9CADAFFF7F0FFF6EEFDEAECFEE8E4EED5
E7DBC5E6D6BCA8AA83C5D5A69AB57E86A268C6D7A0D3E4ADCEEAAFD7EFB5D9D9A7C7C18F
72753C9CA667DDECA9D4E8A0C4DC8ED1EE9EC6E798CDEFA2CAEEA6C7EBA5CAEAA7CDECA9
CCE7A2C7E198CFE79BDBF2A4D7EBA3CDDC97CFD8956E702F4E4D0DDEDD9DD5D895DBE6A1
CEE398CDE599C7E293D7EFA1D1E1969CA45966631C5B5C1A4D57223F56228CA875496F36
1C480D245416CDFDBFC6F4B4C9F1B2D2F5B390AD6BD6EFABCFE6A0CCE39BD9F1A781994D
CCE299D2ECA2B9DB8EC0E295A3B97160762ECDEBA1CBEDA1C3E59BCEECA4C5DC98D2EBA7
A8CE85BFE79ECFEEA8EBFFC8F5FFDFF5FFE6E0F3D5CBDFC3D8ECD1EFFFE7F2FFE6EFFFDC
DEFBC3C6E4A6C9E6A4D4EEAFD5EDB3D3E9B8F3FFDDE9FCCFB1C3898497578CA160CEE4A3
F5FFCAE9FEBDD6E6A7CFDB9DE0E9AA505616CFD595CAD390D3E39CD7EFA3C1E092C4E596
D2ECA2CDE59BD4EBA3CDE39BDBEFA8C2D68F485C15899D56
DCDE93DBE396D4E99ACAEB9ABEEB98B6EC98B7EE9BBCF1A1C3EEA6C2E5A1C6E0A3C9DEA5
D2E5AED1E5B0CFE6B0CAE4A7D3EEA1D1ED98CEEF98C6E892C6EB9BC6EC9FBCE69EC9F2B0
B4DBA2BEE5AE8BB178CDF1B4BADD99C8EA9EC1E18EC4E08CD7E79CDCE8A0DDEAA2C7E4A4
7CB487002E07AADEADC6F2B5C2E6A0C8E9A2B6DF9BC7EDA4D5ED99D6EF9CCEF9B4B1E4AB
B4E7BC81B793001F0097D4B3B1EDCB9ED4B093C19C9EC6A35578577E9E79CCE8BFC7E5B3
D0F4B7C5EFADB3EBA4B8EAA3C7E1A0C5DB9DBCDBA0D3FCC4C7FAC2ACE3ACB7EEB5B5E8AD
C9F7B7C6F0B0C0E7A8C8F0B4BEEDB780B6854E8B61D0FFDEEDFFE6F9FFE6E1F2CECAD2AD
D4C6A3F2E0B8D1D3A1C9DB9FD8F5B3BEDB98D5EAA9D1E6A5C7E29FC4D89999965F5B541E
DAE2A6C9D998CDE19AC9E195D1EC9DD2EF9DBEDF8ECDEDA1C9EAA3C1E19EC2E0A0CCEAAA
D1EEABCDE8A1C7E197C5E196BCDE92D2F2A9D3EDA6BBCC889AA5619DA461E0E7A3D3DF97
D5E29ADCEEA27F9243616F204D580AA4A85BA5A157B5B670D0E4A5D7F6BAC5EBB0ADDB9D
ACE2A471AB6E649E6392CA8DB8EAADA4D0938CB372C0E09DC8E89FC9E99DCAEB9A85A454
D1F0A2D0EFA3C8EA9DC4E699ADCB815D7B31C0E296C5EA9DC5E99FC9EDA3B9DA93D2F3AC
8FB76EBCE49BC1E79ED6F6B7D9F4C9EFFFE7E6FFDDCAE4BFC4E0B8CBEBBCCCECBAC8EBB1
C4E8A8CAF1AEC1E6A1BDE29FCDF0B0C7E6AACAE9B0DEFAC0D6ECACCFE39EC8DD9AB4CB87
8FA5647E93528A985A96A063E4EAAC969A5DDADF9FE8EFACD5E29CD4EA9FC5E292D1F0A2
C4E397C6E298CFE9A2D8EFA9D3E8A3DFF4AFCFE39ED5E9A4
D9DC97D5DF98D0E69BC9EE9EC2F3A1BCF6A1B8F49EB7F19DBEEFA0CAF4AAC9EDA5C3E29E
BDDC98C7E7A4C6EBA6C4E8A2C5E498C3E08ECCEE9AC6E995C8EF9CC6F1A1B5E398C6F5AD
DBFFC9D4FFC4517F41A2CE8FB7E29DB9E399B2D988BBDA8AD7E49CC8D18EDEEEAFBCDBA2
C5FACE104D2377B07DB8EBB0C4EFAAD1F7AEB3D990C7EBA1BFDD93CAEBA4B4E4A8BCEFB7
BEEEB4D0F9BD5B7F41CBE9ADC8E4AAB5CC9495A8716E7B4381894DE6ECACD3DE9CCADB97
D3EDA6B0CF83DAF9A9D1E99DE2EBAAE3EBAFD2E4A6C7E5A5B7E29DB7E9A4CEFFBBCCF9B6
D4FBBAB8DB9BCFEEB3CAEBB2B6DFA796C790366F3AD7FFD6DCF7C4E7F8C2DCEFB7DAE3AA
CABB84A29257DBDE99DAEFA0CEF09AC0E28CC8E18ECDE494D0ED9DD9EEA3A7A2625A5214
DDE9A9CDE49ED4ECA2CDE899C9E493D1EE9CCDEA9AC3E296C9E7A1D8F5B3DFFBBED5F1B4
C7E4A2C6E49ECFEBA1D5F1A7CEE8A1D4EEA7BED992C5E39BC4E298506A21D0E19AD7E19A
E5E4A1D2CB876C611F645B166E6A23D8DA91DAE599E8F8ADCAE19BD6F5B2BFE3A3C0ECAD
D4FFCCA5DCA3376D39669865CDF9C68AB17CA7C88FB2CF8FD4EFA8D6F1A4B7D37F9AB662
D9F1A5B4CA81DEF2AAC9DD95CFE99F92AE63D8EFA7D0E79FD1E8A2CDE7A0C4E49BC3E39A
87A05CD1EAA6C5E39DCCE8ADE0F1CFF8FFEDF0FFE1D0E5BCC5DDABC8E4AAC6E4A6C1E1A0
C0E09FCDEDACCFEFB0CDEDAECAE8AAC3E1A1BBD898CDE8A5D1EBA4CEE59DCEE8A1CFE9A2
C9E29EB8CF8B8797584D571A8A90528C8D51D7D99AD1D895D4E19BDBF0A5C0DB8CC7E899
D4F4A9C9E9A0CCEAA2CAE59EBBD58CBCD38BE5FBB3C8DE96
D5E5A4CFE49FC9E49DC3E89BC1ED9EC0F1A0C1F0A0C2EE9FBBE194CCEEA2CFEDA3D1EFA5
C6E69BCEF3A6C7F0A4C8EEA1D5F1A7C4DE94D3EFA2C8E998C3E898CAF3A4C2EEA1D7FFBD
D7FFC4C6F4B678A56A7CA86BADD797BEE7A196BE758AA85ED2DC97DFE5A7C6DAA5C1E5B5
C7F8CB437E501856259CD79DC2F5B2C6F0A6D0F2A5D0F2A6BAE19EC6F2B77DAF7CC2F4BF
B9E3A4D7F6B0BDCD82D2DA8DAEB56FAFBA76B0BF7EE5F2ACE1EA9BC8D17ED2E190E8FDB0
BED891D5EAA5DDE59ADCDC94958C51A29D63DCE5A4D4EAA2BFE194CBF4A5C7F2A3E5FFC4
F0FFCDD2EEB1D6EFB6C3E0A8C8EBB395C1865F9355B3E3A5D4EDB3CCDEA0CFE4A3D6DF9E
C7B97C726322DCE094CBE18ECBEE94CEF298CDE994D2EB98CBE898D3E59BA49C5D5B5315
CEDD9AC1DC95D0ECA1D6F1A2C6E190C9E493D2ED9ECBE59CCEE7A5ECFFC6F5FFD3E1FAC0
C9E3A4C4E19FC9E7A1C9E79FCEE8A1CCE69FD0EEA6C3E199C7E59B4B651C91A25CD7DE9B
E1DC9CACA163A29759DCD495F3F4B2D8E39EBED489C3DF94DBF5ABB5D38BCFF2AEB8E2A2
B3E5AAC1F6C0699D6D17461ABBE4B8BEE2B2728E5BD9F3B6CEE59FD1E99BC9E18DAEC672
BBD083E3F3ACE6EDA9D9E39ED1E79EC4DE948E9F59D0DD98D6E2A0CFE39ED3F1A9C3E199
9FAE6DDDECABD0E7A3CDE4ACF4FEE5FEFFF1EAF3D6CDDCB1CDE0A8D4EDABD4EFAACFEDA7
D1EEACC4E2A4EBFFCEF2FFD3C7E3A6D2ECABD7F2ADCAE69CC5E196C3DF94CAE99DCDEBA1
C8E39CCDE4A0D8EBABDCE8AAE2E8AA6364287B7D3E5B621FBAC781D5EA9FBED98AD6F7A8
C9EEA1BCE295CEF0A6C7E79CDDFBB1CCE89DCBE59CD0EAA0
C7EEABC5ECA9C4E9A4C2E6A0C3E29CC6E19CCCE19CD1E29CDCE7A3D8E29DCED994DCECA5
CCE297CAE699BEDF90CAE99DDCEFADC2D092DEEFABD5EBA3C2DE93CAEA9FBEE29ACDF2AD
C9F0B1C7EEB5C1E8B18BB07A8BAE74CDEFB3CCEFAFD1E7A65F6120CDD097D6F3C7BAE4BE
AFDEB0B8F0BF3E80503F824DB2EDADB5E39ACBEA9AC9E99DC5F5BBA9E1B2548B61B2E1B3
C0E3ABCADF9CEBECA0979143D3D68FC8D794D6F5B1B9DF94C7EE93C7EF8FC9F59EAFDB90
C4EAAFD9EBB9776A35654C166C55216152199C9B58D1DD91D5F19CC6E891B8DC85D5F6A7
D8F3AECADFA4C1D69EC4DBA5D8F5BDC0E8AAB4E6A1C2EFAAC7E0A6D2E3ACC7DBA0E7EFB4
D2C38CA99A5FE8EEA8D6ED9FC0E391CEF3A3C9E59AD2ECA3C6E49ECEDEA0A197645F5522
D7EAA8C6E69BC2E193CEEB9BD1EC9BC9E291CEE597D5EBA3C4D998DFF3B6EDFFC9E2FAC0
D4EEB1D0EDADCDEAA7C3E29CBEE096C9E99EE2FCB3D9EDA6D3DF9D969F5E5E6323D6DB9B
D4D89BA7B071B2BE7EC8DB99D0EBA6C6E59FD2F7B1CFF3A9C6E297D6F2A7DCFDB6ACD593
C4F4BAC9FBC876AA7C1D4B2484AD85CAEDC3425E2DD7EFB5C2D792C8DF8FE3F9A4C8DE89
62772AC7D28DDBDA99E6E7A5C3D990DCF6AC919E59E8EFACDAE19ED1E09BD1EFA7CEE9A2
C2CB8AC9CF8FD1E6A3D2E6B1ECF1DDF5F5E9E7EBD0D3DEB3D1E1A3D0E69ECAE49ACAE59E
CCE9A9C1DDA3F0FFD6F2FFD6C1DAA0D2EBAAD4EEA5C9E495DCFBABC9EA99C3E696C6E89B
C3E39AC5E09BCDE2A1CFDD9FDBE1A58C9053E2E7A7D4DB98CDDA9495AA5F9DB869C2E595
C0E798C4EF9FC2E89BB5DA8CCCEEA1C7E899BBDA8ED9F5A8
BBE5A3C1EAA6CAEDA9CDEAA8CFE4A3D1E09FD8E1A0DFE4A4DEE09FBCBF7C9AA15DAAB771
93A85D85A15477984993AF648B975982884CC5CE8FDEEAA8D5E69FDEF4ABC9E39CC8E5A2
C7E7A6C3E5A9CDF0B8B7DDA45F854C93B97EAFD59ACEEBABBAC47D79823FCFEDB9BFE6B7
C6EDB8C4EFBAB1E7B64F895765985FAFD997CFEDA3B7D89184B57E1F5728285C2EC2EEBD
C7E6ADB7C7869A9B4FB6B467E7F1A8D3E8A3CCF1ABC1EDA0BBE78EC8F598C2F29EBCE7A0
D4F7BF8090618173428E7242F6DAAABEA974807B3BBAC277D9EF9CC5E38DD9F6A2C4E093
C7DE9AD3E7AAD5E6AFDDF0B8C1D69DD5EFB0C7E4A1CBE6A38CA06593A46D54662C8E965B
4E3D096E5A25969658D7E6A1C5E197D2F0A8C6DB98D4E9A8CFE7A9D6E3ABA5986B5E5421
C6DA95DAFAAECDE99EC2DC92D4ECA2D4EAA2CDE0A0CFE1A5D7E8B1EBFDC9F5FFD4E5FCC4
CEE8ABC3E09EC6E59FCAECA2CEF4A9CEF2A8BCD68DD6E7A0D5DF9AE0E3A0525212DEE0A1
D9DFA195A16391A566D2EFADC7E8A3C2E89FC0E89FC5EDA4CBECA5C4E29AC5E197D0EFA9
C1E9ABB2E1AD6C9E78002A07ADD5B2BEDEB59FBA87AFC489D7EEA8CAE191D2EA92D0E890
CDE29598A55FE1E1A1D7DC99D1E79FD5ECA4B9C6814D5613DAE3A0CFDE99C7E29BD4EEA7
D5DE9DA2AB6ACBDE9CD4E6B2EBE9DAFFFEF8FFFFECFBFFDCE9F8C1D4E9A8CAE19DCCE7A4
C9E3A6DAF3BCF3FFD9F1FFD5CDE4AED4ECB0BFD894D2EEA3C4E393C4E793CDF09ECDF0A0
C8E89CD0ECA2D8EDA8D4E3A2D5DE9F95995CA1A666D0D996D7E6A1D3E9A0C2DE91496C1C
8CB364C8EFA0C3E99CD2F7A9C4E699CBEC9DD1F0A4C5E496
C6DF9DC8E19DCEE3A0D1E1A0D3DF9FD8E3A1DDE3A3D9DF9FAEB7768D9854D4E59FDBF2AA
BCDA90CDF2A5BDE698C9E99EB4BE7F9A9A5C979958B9BE7BD5DC96DCE8A0D6E69DCADE96
CAE49DC4E39FCCF1AEC8F2B2B6E4A69BCD90AAE0A4B8E7A1D0EE96A6BD624F6817C1DB92
D6EBAAD6EBB0C9E4B1CAE7B7638553799C664F713588AE718DB97E8FBC81BFE8ACBDE1A3
CAE4A397AC67C8D992D3E89DCAE49BC3E199CAEBA4CCECA3CFE99FDCF4A8C3D9917B8E4C
5A6A2C7984488D9355E6E0A6F2DCAAE7D09E6A61289FA464D2E39DDAF1A9C6DD95D1E8A2
CADF9CD5EAA9D4E9A8CEDE9FD1DB9EC7C88C908A504D480E8A925793A16489975A969A5F
A89260654919786D35E2E3A7DBE7A7D6E5A4D6DCA0D5DDA1DCECAED3DDA1A4986460571E
AFBF76CCE999D9F0A8CFE5A4CFE2AACCDCABCDDCB1E2EEC8F7FFE1E5F5CED3E6B9CBE2AE
C9E6A6C9E9A0C9EB9EC8ED9FC0E69DCFF3ABC0DE94D0E89AD5E696E8F3A5434900A4A762
E1E3A4989E6297A165DBEBADC8DF99C8E499CDEF9BC7EE9FC1EAAEC0E2A6DDEFA5DEEC9F
CFE8A4C4E9B58BBF9B12472BC3EBC9C7E6BCD9EEB68DA25FC6E096CDEA98D2F096C5E38B
D7EFA3A2B66FD4E3A0D9EAA4CEE59FCFE6A0D4E8A3495D18CCE09BDBF0ABCCE69FC4DB95
DBEFAA687C37D4E9A4DCEAB7E8E2D2FFFBF9FFFFF3F9FDE6F9FFE3E8FBCECDE4B0CFE8B1
CAE1ABCAE1ADF7FFD8F3FFD4DCF2C1DFF7C3BFDAA5CCEAACC8E79BC8E895CBEB98C9EA99
C9E89AD2EEA1D6ECA3CEDF98DCE7A3989F5CC1C885D9E29FD7E8A2CAE199C6E49ACAEA9F
8BAB6096B46AD3F1A9C3E197C9E79DD0EFA3CEECA2CEEEA2
8798547F904C93A25F909C5A8C9755D0D998EDF6B5AEB77698A462B0C17DCCE39DCFEAA3
C7E99FC4EDA1C1EDA0C7E99FDAE7A2D8DA99C1C481A1A761A2A860C7D188E1EDA3D6E69D
D2E89FCDE8A3C5E8A6C5EDAEB0DDA2C4F7BF76AC78C7F9BABAE08BDBF89CB7CF79ABBE6F
7F8C47C7D296DAE7B1CBDDA9BED6A2C6E4B09BC188C1E9ADBEE6A7B8DF9CD0F5B0CDEEA9
D0E9A592A963CDE7A0D3F1A9CDEFA5C7E99FCDEBA3C9E39CDAEEA9CBD795A2AB6A3C4504
747D3CB2BE7CD0DF9CECF5B6E7DEA7EBDEAA99925B7E7D44D1DB9EC6D697CADF9CD0E7A3
D4EBA7C7DC99C4D591BFCA889E9E60756F33766A3091874CD9DA9ED8E2A5DEE8ABE8E7AE
DBBF8F75532575612E878049A0A167D6DA9FEEE9B1CECD94C8D295E3E9ADCDBD8980763B
A9B76CC1DC8BCFE69ECCE0A3D3E3B2D6E5BCDEE9C9ECF9DBF6FFE5E4F4D0D2E4BACAE2AE
CBE8A6C9EB9FC8EB97C5EC99BDE39AD1F7AECBEBA0CCE89BCBE091CDDB8C646C2171742F
E0E2A38F93589FA46ACBD799C9DD96DCF4A6CEEC96BFE292C2EAB5C0E1ACDEE99DC5CA78
D7E7A0C4E2AC8DBC9C2E6047BDE2C1C3DEB39CB075AFC37EDEFAAFCCED9CBCDD84D0EE96
CDE89BD1E8A2D3EAA4D0E7A1D0E7A1C1D892D8EFA94E651FDBF2ACC1D892D1E8A2CEE59F
CDE49E667D37CFE6A0C6D59EF6F4DDFFFBF2FFFFF1FBFFEBF0FFDEEFFFDBE3FACCCCE4B2
D5E9B6CDDFADF4FFD3F9FFDAF8FFDDF7FFDFD4EBC1D3EBB9CAE59ED5F2A2CFEE9EC8E797
CEED9DCEEA9DCEE69ADBEDA3D1DE98A2AC67CFD895D4E19CCCE09BCDE7A0CEEEA5C9E9A0
C7E29B516B24B2C983CBE59ED6F0A7C9E59BBDDB91CEECA2
ACC07B9BAF6ACFE39EE1F2AE7F8B493944025C67258994528E9A58DAEBA7C9E09AC7E29B
D3F5ABC0E69BC8F2A6C5EA9DCDE39ADFEFA6D2E299A5B3688D9B50A2B267A7B76E879851
6A7F3CC9E1A3C5E1A7D6F4C2EDFFE1C9EEC5AFD7B24B7045C6E5AACCE7A4C9DF9EB8CA8C
89975A919F64DBEAAFDAEEB1D3EDAED0F0AFB8DF9CCAF3ADC5EDA7C0E8A2C4E9A4C6E5A1
CEE5A1829752D1E8A2CFEAA3CCECA3CAEAA1D0EEA6CAE49DC3D792DAE6A4505B19C6CF8E
D2DD9BDFEEABDDEEAAB5C886C7D597D2DA9EA3A168605B23C7C58CDAE0A4DAEDABD0E9A5
C6DF9BDAEDABBDC3837674376B6728ABAA6ADBE4A1E2EDABD5DB9DCED297D8DEA2E4DDA6
D6B4866B45188A734160551F6260278A8950ACA36CA7A0699CA065A0A16799855275662D
B5C378C4DF90CFE69ECEE4A4D9EBB7E4F5C9EEFCD9F9FFE6F7FFE4E4F4CFD1E4B7CAE3AA
CCE9A6CBEDA0C8EB97C3EB95C2E89BC7EDA2C5E79DCDE99FD7EBA4D5E29DCAD390A5AA6A
575B1E5A6024CAD394E3F2AFCCE098CBE697C4E18DCAEA9EA5C691465F285F6619979C4A
EAFAB3C9E4AD729A780B3319C5E0C174895E8B9F64CCE39FC8E89FC3E696CCEA94D2EB97
C5DD9399B06AD5ECA6C2D993D6EDA7E0F7B1C7DE98BCD38DCEE59FC8DF99D3EAA4D5ECA6
CCE39DA1B872D6EDA7D7E9AFDDE3BFE0E4C9FBFFE4F8FFE1E2F9CBDAF5C2DDF8C3CAE3AC
D3E5B1D3E1B0EBF4C7E5ECC3F6FCD8FBFFE0DBE6C6D9EABECAE3A1D2EEA1C4E395BEDF90
CAEB9CC4E397BFD98FD2E69ECDDC979AA561C6D18DCEDD98CDE29DCCEAA2CCF0A6C7E99F
DDF7B0C4DB958CA15CD0E7A1C8DF97CFE69ED6F0A7CDE79E
DCF3ADD0E7A1CFE49FDDF1ACCDDE9A8E9D5A6A7634788442A2B16EE3F7B2CAE19BC6E19A
D2F4AAC0E49ACAF3A7C3E99CC6E597CFEA9BD8F3A4D7EFA1D2E99BD1E79CBFD38B9EB26D
1D3100B7CA92E3F7C6D1E6BDF1FFE7E7FFE3B7CFB795AF94AFCAA7C0DBB0CEE4B6D7E9B9
C7D5A2727F479AAD6DC3DA94C7E59BBFE195BCE597C1EC9DC3ECA0C7EDA4C2E6A0CBE8A5
D3E8A580944FD3EAA4C9E49DC5E39BC6E49CD1ECA5D0E7A1E7F8B4869250545F1DCFDA98
D1DD9BD3E4A0CADF9AE2F9B3D4EDABD8EDACADB77A71753A8C9055D4DA9ECEDA9ACEDE9D
D0E09FA2AE6C676D2D585D1D929755D8E39FE1F7AFC7DC97E8F1B2DFE3A8DAE0A4E2DDA5
E9C99A775225C6AF7DA398627C7B42605F26564F185D5820575D214F50165B4A16685920
CDDA92CFEA9DD0EAA3CFE5A5D7ECB4E8F9CCF5FFDEF8FFE3F8FFE3E5F7CDCFE5B4C9E2A8
CBE9A3CBEE9EC8EC95C4EA93D1F8A5C2E99ABBDD93CAE5A2D4E8ABCEDBA3EBF4BDD4DCA3
8F945A919A5BD9E6A1D8E9A2CEE499CBE697CBE898B1CF8788A16ABDCC9594984BA6AB57
73833ACCE5ABB2D4B129472DBCD0AD152400A5B880CAE5A2CCF1ABBFE497CCE894D0E694
D1E79EA6BD77C1D892D3EAA4D9F0AABFD690D0E7A1DCF3AD9CB36DDFF6B0D3EAA4CAE19B
C2D993C5DC9698AF69A8BC7DD4E5B1CDDDB0E4F8C5F4FFD6DDFAC0C7E5A9C7E3A8CCE4AA
D3E1ACCED6A5E0E3B8DAD8B2FFFFE3FFFFE6FFFFEAFEFFE1D5E9ACC9E59AC7E59BCDEDA2
CFEFA4CDEBA1CEE89FD1E79FD5E49F86934EABB873CCDD97D6EDA7C8E89FC2E89DC6EAA0
BAD48DE1F6B1A2B77297AC677C924ACFE59DCBE199D9F0A8
BDD891D2EDA6CEE8A1C6DD97D6EBA6D8ECA7CDDE9ACCDD99C8D995D2E6A1CFE6A0CDE8A1
C9E9A0C4E89EC8EEA3C4EA9DC9F09DBAE28CBAE08BC4E793C9E898CFEB9ECFE9A0C6DC9B
C7DBA0869763CBDAB1ECFAD9F9FFEDF7FFF1F9FFF6C8D6C93E5447BFD8C5B2C6ADDBECCC
D1E0B5C8D6A195A868B2CA80D0F09DC3E790CAF29CC1EB97C7EE9DCAF0A3C6E7A0D1ECA9
D8EBA991A25ED6EBA6D0EAA3C8E39CC3E199CCE7A0CDE49ECCDD994F5B1995A05EDDE8A6
D1E09DD4E8A3C8DF99CAE49DC8E19FE1FCB9F2FFCCDBF8B58DA460A0AF6E77773B635D23
635D217373359DAC69CFE69ED6F4AAC0E095C1DB92D7ECA7D1E09FDAE6A8CFDD9FDEDFA5
FAE3B16F5323C9B985D0CE95CED69ACFD79BD7D89EDADEA3D7E7A8D0DC9EC1B881A39D63
D5E69FCEEA9FCBE69FC7E09FCDE4ACE4F8C7F5FFDBF7FFDFF7FFDFE4FACBCFE8B1C7E4A4
C9E9A0C9EC9AC8EC94C5EC91C7EF96C5EB98C4E59ECDE9ACD4E8B5E2EFC3E5EEC3ECF4C5
F1FAC1DEEAA8D0E097C6DB8CCFE799C8E595CCEB9F88A3608D9B66DDE5AAD5D889D7DD87
CFE2935E7839D8F2CBB4C9AA2B35121E2700EFFFCBBDDD9CC3EEA9BCE69ED2EA9CD4E597
D4EAA1B4CB85D1E8A2D8EFA9C6DD97C1D892D2E9A3C5DC967F9650C1D892D3EAA4CCE39D
D0E7A1CEE59F8AA15B90A763D0E9A8D5EFAECEEDAACFF0ABD7FBB5CDEEA9C3E09DD1E7A7
D5E0A88084524C471F423A16AEA387CEC2ACFFFBE9FCFBDDD5E4ADC4DD99DDF8B1E6FFBC
C8E69EC8E39CDAF1ABCEE29DD6E5A2889452ADBC79CEE29DD4EEA5C4E499C0E699C8EDA0
D7F1AACDE19CD3E7A2AFC37E8DA15A8DA15AD0E49DCBE199
DEFEB5BCDC93C1DF97D5F0A9CDE49ECADF9AD5EAA5D2E7A2DEF2ADC1D691D3EAA4D2EDA6
C2E299C9EBA1C4E89EC5EB9ECCF8A3CAF8A0CCF6A0C6ED9AC0E391C9E99DD2EDA6CBE4A2
DFF3B8334410CBD8ADE2ECCAFEFFECE7EBDAFEFFF4D0DACFC7DCD74B655CD6EDDDC6D8C0
D4E4BFE8F8C7C0D495445C12CFEF9CC5E992CAF29ABCE78EC5EC99C2E799C6E69DCBE6A1
C8DC9797A864BED38ED1E8A2CDE8A1CBE69FCDE7A0CFE49FD0E19D626E2C97A361DCE8A6
D2E39FC9DE99DBF5AEC2E098D2F0AACBEAA6EDFFCCE2FFC1B7D58FCEE19FE3E4A8E0DAA0
DFD99DE2E4A5D6EAA3C6E49AC1E79ACBF1A4D1F1A6CCE89EC6DD99D6ECABCAE3A1DCEAAC
FFF2BD695824BBB980E9F3B6D8EBABDCF1B0DCEAACCFDFA0C7E4A1D4EDABDFE3A8D5D69A
D3E9A1C8E69CC9E49FC7E1A0CBE3A9E3FAC4F5FFDAF4FFDBEDFFD2DDF6BFCCE8ADC9E6A3
C9E99EC9EB97C8EC94C7EE91BEE588CCF29DD0EFABCBE6B1D2E7C0F8FFE6F7FFE0FCFFDD
D0DDA7DEEDAACDE091D6EE9AD4ED9CC0DC8FCAE8A08CA564939C67D0D195F3F7A3D8E289
CFE696CAE4A3435A2E879773010600131B00B2CB92C8F0B1C0F4B4B9E8A4DDF5ABCFDF94
C7DD958DA45EC7DE98D3EAA4CCE39DDDF4AECBE29CD5ECA6B6CD8799B06ACCE39DD2E9A3
E0F7B1CCE39DCBE29CC6E09985A157BFDD93D0F2A5C2E799CBF0A2CCEEA1C5E39BD6EBA8
D8E2A65757235E552AE1D4B1F1E2C562523991826DFEF9DBD5DFABD7ECABF7FFCCF5FFCC
C8E19FBFD894D5EAA7CCDC9BD2DE9E9CA765CAD593D4E5A1CCE39BC4E499C8EDA0CAEFA2
C3DD96D2E7A2C1D590DCF1ACD5E9A292A860D4E8A1D3E9A1
BDDF95C0E298CFEFA6CDEDA4C0DB94CBE59EDAF1ABCCE39DD8EDA8C4DB95D1EBA4D1ECA5
C6E49CC9E9A0C6E69DC9EEA1AFDA88B7E48FC7F19DCBF2A1C5EA9ACDEDA1D3EEA7C8E19D
CADEA1CEDFA87C895BB1BC94F2F9D8C0C4A9A0A48D87907DC1D8CEA8C3BA475F4FBCD0B7
EBFCDAD4E5B8CDE0A8657B3ACBEA9EC8EB99CCF29FC2EA94CEF4A1C4E797D3F2A6CFE9A0
C7D894A4B3709BAF6AC2D993CBE59ED0EAA3D1E8A2D3E7A2CFDE9B4F5B19929E5CB6C582
E8FCB7CFE6A0C5E39BD1F3A9CBF3AAB8E097CCEDA6C5E39DD0E7A3D1E4A2DCEBA8D8E4A2
D5E19FD3E29FD3E7A0D4EBA3CDECA0C5E79ABEE798C0E99BCBF1A8CCF2A9BFE79ECAE8A2
DBDCA04E4C1198A464CAE39FBEE29ABDE39AC8E7A1CEEFA8C5F1A6C0E89FCDE29FD7E6A5
D0EAA1C7E59BCCEAA4CBE8A6CBE5A8E0F9C0F2FFD4E9FFCDD9F2BBCFEBB0CAE7A7CBE9A3
CBEB9FC9EB97C8EA93C9EE91CEF396CCEF9BD1EFAFD3EDBED4E7CBF5FFEDEFFDE4E6F4D0
E1EFBADDF1AAC3DA88D1EB94CFEB97D3EFA2D1EEABADC287757D44EBEBABC9CE7AD2E186
DAF6A2CDECA6A5BB8A9BA87D9C9E6F262F0044632897C98CB3F0B4B7EFAEC8E6A0CCDD96
C9DF97B6CD878FA660CDE49EE2F9B3BDD48ED7EEA8CFE6A0E7FEB89EB56FAEC57FC8DF99
CDE49EC2D993D0E7A1D6EDA5647F3296B363C0E190CCEF9DC7EA98C3E493C9E399D7E8A2
D4DD9E85844C605829DDD0A6DACCA9A89B7B8C8163736F4AB2BB86D0E0A2E6F8BAE0F4B5
D5E9AAD5E8A8D9E7A9DBE5A6D8DEA09DA365C8CE8ED6E19FD1E59ECAE69CCBEBA0CBEBA0
D4EEA7DFF6B0D7ECA7C9E09AC2D890B4CB837389419BB26A
C4E89ED7FBB1C4E69CB9D990D4F2AAD3EEA7C1DB94D0E7A1C7DE98D0E7A1D0EAA3CFE9A2
CEE9A2C8E69EC7E59DCCEEA4D6FCAFC3EA9BBFE697C6EB9DC6E89BC8E69CCEEAA0CEE8A1
CEE4A3CEE2A3D8E9B2D7E5B2E9F5C7D9E2B7D0D8B1D3E1BEACC8AF6D8D76C9E3CA768D70
9AAB87B0C197CDDFAD97AF75C4E19FC7E8A1C8EDA0C1E899CFF4A4BEE191D3F2A4C8E298
E1F2ACBFCE8B8CA05BB8CF89C6DD97D1E8A2D0E5A0D3E7A2DDECA9C9D593586422DEEDAA
CBDF9AD3EDA6C2E299CBEFA5BEE69DCCF2A9C6E49ECCE39FDAEFACCEE59FBED992C8E69E
CBE9A1D2EEA4D2E9A1C9DF97C9E197CEEDA1CAF1A2C0EB9CC4EEA2BAE69BBDE99ED1F2AB
D6DFA0606427A3B674C9E8A2C8F2A8C6F2A7C8EEA5C2EAA1B9EEA0BEEEA2CFEAA5D3E8A3
CFE9A2C6E49CCEECA6CDEAA8C7E1A2D6EFB5E3FCC2D5EEB4C7E3A6C5E2A2C8E5A2CDEBA3
CFEEA2CBEA9AC9E994C9EB94CEF197B6D786D0ECB1F4FFE3F5FFF1F2FFF3F6FFF0D5E4C3
CFE2ABD0E69ECDE692D6F399C3E08CD3EFA4C8E5A5CBE0A5969E65BABD7ADDE791DCF196
BDDF89CBEDA3CFE8AFD3E1AED8DDA7CDDAA2A8CE931953183A8149B2F2B6C3E6A2D2E8A0
D1E8A2CBE29C9BB26C9DB46ECBE29CD9F0AACBE29CD0E7A1C3DA94A8BF7989A05AC7DE98
CDE49EE2F9B3BCD38DD5ECA4AAC0758AA2549FBA6BCBEA9ACFEE9EC9E696D0E89CD2E29B
D8DF9C98985C59521CF3E9B8DAD2A3E8E1B5C2BF949698695F66308F985F929D6396A469
CBD99CDEECAFCFD99CD8DEA2E5E6AA8C8C50ADAD6FD5DA9AE2EFAAD1E79FC7E399C9E79D
CAE49DC6E099CBE59ECDE7A0D9F3AACBE59CDBF5ACC3DD94
BFE399C5E99FD0F2A8C4E49BB9D78FDBF6AFC6E19ACCE69FCFE9A2C6E099CEE8A1CDE7A0
D6F1AAC3DE97D2EDA6C7E59DD1EFA9C4E29CCEECA4CAE8A0D7F3A9CAE69CC7E198CAE49B
CEE89FC5DC94D5ECA6CADF9CC7DC9BDBEDAFD1E3A5CCE4AAC6E8B580A4769FBC90C4DDB3
A8BA9263734C899B71BFD5A7C8E3B0CFF0B7C6EAAAC6EBA5CDF1A7C1E494D7F8A7C5E091
CEDF99DEEFABCADE99869D57DBF2ACCCE39DD5EAA5CEDF9BD5E19FD9E4A2515C1AE0EFAC
C3D792C5DF98CBEBA2C7E99FC6E59FD3F1ABC6DD99DAF1ADD0EAA3D2F2A9B5DE92C4F0A1
B9E596CDF6A8D3F3A8C8E298D2EAA0D3EBA1C9E89CC4E69AC8ECA2BDE69AB7E094D6F4AC
D3D8985B5B1DB3C27FCCE7A0BEE499C5EEA2CDEFA5C2E89DB6E99ABEED9FCEE8A1CEE29D
CCE69FC2DD98CFECA9D3F0ADC0DD9BC8E5A5D2EFAFC7E4A4C6E3A1CAE7A4D0EBA6CBE69F
C5E196CCE89BD1EE9ECBE896CBE896CFEBA1C5DEA7F5FFE6F2FFF0F5FFF8F5FFF3CDDEBC
D5EAB2C9E39AC8E48DD0EE94D2EF9BCAE69CC7E3A6D3E8AFB7C28696A05BD5E48FCAE388
C0E691CCF2A7C7E5A7D2E6ABD6E0A3CDDFA1B2DFA45091593785518DD49CBBE8A7CDEBA5
CBE59ED2E9A394AB658DA45ED1E8A2CAE19BD1E8A2CEE59FD7EEA8C0D791839A54D4EBA5
CEE59FCDE49ECEE59FD1E6A1D6E5A0ACBB7697AB63D3E9A0CEE69ACDE599D5EA9FD0DD95
D2D995A5A865575518DFDDA0DCDCA0DADEA3E0E8ADCED89C9DA26A939860636B32404910
818B4F959D62B5B97EE3E2A9E1DCA2ADA76DA39D61D9D79ADBE29FDAE7A2CAE098CBE59C
D2EDA6C8E39CC2DD96CCE7A0CCE89EC9E59BC8E49AD0ECA2
D0F2A8C0E298BFE197D4F4ABCCEAA2CDEBA3C3DE97DBF6AFC3DD96D1EBA4DEF8B1BFD992
C6E19ACCE7A0C1DC95D4EDA9CDE3A2C8DD9CC8DD9CD3EAA6C7DE98C9E098D5EFA5DEF9AC
D0EC9FCBE898D7F4A4CCE999CBE697D4EFA0C9E495CDECA0C2EAA3C6EDACC9E8AD839E69
526537B4C59BCFE1BB5267402B461B81A170C9ECB4C0E7A6C0E59FBBE092E3FFB3C5E292
DDF1AAD0E19DCDE29D97AE68B2CC85DEF5AFD1E6A1D4E5A1DBE7A5D2DD9B404B09D9E5A3
D5E9A4CEE8A1CCECA3C6E49CCBE09DDBEBAACEE3A0C3DC98CDEDA4CDF3A8BEE99AC8F4A5
D2FEAFA9D485C3EA9BD1F1A5CCE69CD0E69DCFE099E4F8B0D8F2A9CAE8A0D8F8AFD4E8A3
E1DB9F958B50C5CA8ACADE99CDEBA3C2E299C2DC95C8E69ECCF5A9D0F6ABD8E9A5D5E19F
DAEFACDDF8B3C0DB98BCD996D2EFACCAE7A4D3F0ADC0DD9ACCE9A6CFEDA7C4DF9AC9E49D
DDF7AECCE69DBED68CD5EDA3D0EAA1D0E9A8C9DFB0F5FFE8F5FFF3F0FFEFF3FFEDCDE2BB
C8E0A6CFE9A0CFED97C9E78FC7E492CCE89ECEE8ABCCE4AACEDEA0BBC882CBDD89E0FAA3
C1E794C8F1A5C3E7A1C8E3A0D6E7A1C5DE9CC7F7BDA8EBB668B78A2A74437CB070CCF0AA
C7E29DDAF1ABB9D08A91A862B0C781D1E8A2D8EFA9CAE19BCBE29CCEE59FC3DA94A6BD77
CDE49ECCE39DD2E9A3D2E6A1E4EEAFD0D9989AA664D0E19BD3E7A0C8DC94DCECA5D9E69E
DCE39D9AA05A565914C5CB85EEF8B3C8D58FD4E59EDDEEAACDD599DFE2A9D0D59BA5AD72
A3AB7072783C57581E5D5B20A49E648F864DA2995EDFD99DD9DB9AD7E09DD3E49EDEF4AC
BCD68FCDE8A1DDF8B1CFEAA3CFEBA1CAE89ED1EFA5C9E79D
C1E198D4F4ABC8E89FD0EEA6C4E29AD3EEA7CFEAA3C4DF98D2ECA5CFE9A2C1DB94DDF7B0
CFE9A2D2ECA5E7FFBAC1D894C6D698E8F6B9D4E2A5DFEFB0D1E5A0D4EAA2C3DB91C1DD90
C4E491C5E590CBED96C6E98FC9EC92C9EC90C0E387CEF298C5F097BCE694CEF0A6CEE8A7
899E66A2B386889A722B3F1A0015003E5F32C9EEBAC6ECB1C1E9A3D6FCB1B5D888CAE99B
C6DD95CBE09BD4EBA597B16A87A15AC4DB95DFF3AEC1D08DDEE9A7D1DA99525B1AC3CF8D
DBEFAACEE8A1C9E9A0CCE69FD8DE9EDCE1A1D2E7A2CDEFA5C2ECA0BFE99DD7FCAFB5D78B
C7E99CD1F6A8C2ED9DCBF6A6BBDE8ECCE297F3F9B3C6C785D3DA97D3DF9DCAD996D6DB9B
DFCA937E652FD0C68BE2E4A5D7E6A3D3E4A0DAE5A3DBEAA7CBE59EC0D791D0D293DEDEA0
BECE8DCEE7A5D1EAA6D0EBA6D6F1ACBFDA95D4F2AC8BA96378934E9FBA75CCE5A1D7F0AC
CEE5A1D0E5A2D5E8A6CBDD9FCEE2A7CADCAACADAB3F7FFE8F5FFEBE2F4DAE5F9D6CFE6B8
DAF4B5CDE99EC7E490CFED97D6F1A2D1EBA4CAE2A6C8E0A6D7EDAD798D46A1B262B7CE7C
D5F7AAC9F2A6B5DD94CDF1A7CBE699C5E39BBBEAB3B5F4C775C39C105B307EB87BBDE8A1
C8E6A0D6EDA7D6EDA7A6BD7790A761C0D791D4EBA5CDE49ED0E7A1C6DD97DBF2AC9DB46E
D8EFA9CBE29CBED58FDBEEACD0D89CE6ECB0909A5DCFDB9BCFDF9ED2E39FCDDC97CFDA95
D8E29B969D575D651CCAD48BD4E295D1E697CEE998C9E195DDE9A9DCE4A8D6E0A3CED89B
D8E2A5B1BA7B83874A656328575117554B107E7439CCC68AD7D797DDE4A1D4E19CD0E49D
D9EEA9CEE59FCEE8A1C0DA93CFE9A0C4E096CCE89EC3DF95
99B46DCDE8A1C8E39CCCE7A0BBD68FCCE7A0DCF6AFCAE49DCBE59ED0EAA3CFE9A2AFC982
849E57738D465D7730BBD08DDAE8AAC1CC90E0EBAFC6D496BACD8BE5FAB5D1EBA1C8E497
CBEA9ACCEE98CAEE96CAEE94D2F79ACDF092C4E789D0F596C9F294C2EA91C0E190D3EEA7
C9DFA1CBDDA9D3E6B8EDFFD8C6E3B5BFE0B183AA734E763AB8E19DB3DB92C4E99CD0F0A4
D8F2A9C4DB95C2DC95D1ECA5C3DD96788F49D2E6A1E3F2AFDCE5A4D8DE9E969C5C97A260
C5D692C9E09AC7E59DD1EBA4E0E9A8D8DE9EC4D893D7F2AB4C6E2493B86BBADA8FDFFDB3
C2DE93CCECA0C4E99BC1E396DBF7AAD5EA9F8F9650A4A5637A7C3B535818B1B777EAE6A9
F9DBA76B4A1758450D9F9B5E989E5EB7C280D1D696B5BE7D7B8F4A6E7F3BAAA669E3DFA2
E0EFAED5EBAACFE8A4D1EAA6C4DD99344F0859742DD4F2AAD2EDA6D0EAA3869F5B637938
A5B97AD0E2A6D2E1A6ECF9C4DFECC1D6E2BED7E5C4F8FFE8F4FFE4D5E6C2D4EABCCBE4AD
CBE6A3C7E398C7E494CCE798CCE69CCCE39FCEE4A6D1E9ADCBE5A4C0D79149570CE4F4A9
C2E096BEE49BCBF7AABEE798CBEB98D4F4A9B6E2ADA8E0B979C0A2569E79B7F4B9C1F0AA
CEEDA7CAE19BD2E9A3C6DD97889F5992A963C8DF99D3EAA4CBE29CDBF2ACC8DF99748B45
8AA15BD4EBA5D2E9A3CDE09ED1DB9EE5EBAFB3BD8099A867DCECABD6E7A3DDECA9D3E09B
D7E19CDDE49E828C43748036CEDF91DAF1A1C0DD89D9F6A6CEDF99CFDE9DD6E7A3D6E7A3
D5E4A1D0DC9AD2DB9AD0D293E0DC9F877E436B6227A09A5E7575353E450249561191A25C
94A561C7D894E9FAB6D2E6A1C7DD95D2E8A0DFF6AED5EFA6
D0E7A18AA15B607731C3DA94E9FFBACAE49DC3DA94D4EEA7CDE7A08CA65F5B722CB2C983
D4EBA5E0F7B1D3EAA490A5605B6A29000B00D6E4A6DEEEADE0F5B2CBE29CBDD891D7F5AB
CCECA0CBEC9BC3E591C8EA94CDEF99C9EA93C6E790C5E790BCE38AC8EE97CEEF9EC6E096
DCF1AED2E6A7C8DDA2C0D99FDEFDC2C1E7AAC2ECACCAF4B24B7631C5F0A9C6EEA7C4E8A0
BFDD95DAF5AECEECA4CCEAA2CEE9A28CA65FC9DD98D0DF9CD8E1A0D8DD9DD4D999606928
9FAE6BCCE19CC9E79FCBE9A1CAE49DD9EDA88C97559CA5649EA965475812DFF9B0B8D88C
C8E79BD6F0A6D5E79DD7E39B505A13515D15CFE499D6E7A0D5DE9BDEE3A1939A57474304
6A4F186C4D17E0D095E1E0A0D5DE9BD7E29EDCE3A0DEE9A5DBF1A9C5D99294945459571A
D1DD9DC8DD9CD5ECA87F98548BA55EB8D48ADDF9AFC3DF95D2ECA5C9E29ED8EDACCEE0A2
98A76E8A9761CCD6A2FEFFDCFEFFE8F7FCE6F7FFE5FBFFE6F5FFDED1E4B6CAE1A9C7E09F
C0DB94D5F1A6DDF7ADCDE79DC4DB95D1E6A3E9FDBEF7FFCFE0FFBCC8E19F3C4502E2E9A6
D2E5A5C9E8A4CDF9AABAE792C2E68ECCECA1C1E5B5BEEBCC7BB6A081C2A4B4F1B8BDF0AB
CBECA7CBE29CC7DE98DAF1AB93AA64708741C9E09AD2E9A3D7EEA8CFE6A0CEE59FE5FCB6
CDE49ECDE49ED5ECA6CEE39EDEEDACC8D494D5E5A4415510CBE09BBBD08BEBFCB8D5E29D
DFE8A5D4DB97D7DE9A58631EDBEBA2C9DF94E4FFB1BFDB8ED2ECA2CFE79DD0EAA1D4EEA5
CAE199D0E69EDBEAA5DBE4A1D2D493A9A8689E9A5BD2D191E6EBABE1ECAA92A35F445511
515C1A5E6726899251D1DC9AE1EEA9D4E39EC3D48ECFE39C
D0E49FB7CB868296518BA05BABC07BD5ECA6C1D89294AB658AA15BA9C37CD1E8A2CFE6A0
D9F0AADEF5AFB4CB85D2E7A27F904CAABB77364A05869B58778E4AC1DA96D7F5AFBFDD95
C6E69DC5E59AC3E197CAE99DC8E499CDE89BDBF6A9CAE699DEFFB1B8DB8BCBEA9CD3EDA3
D6ECA3C1D58ED6ECA4CFEBA1B9DB91C7EFA6C0ECA1ADDB92B3E19988B570BFE8A6C1E6A3
CBEAA4BFDD95B9D990D1F1A8D0EEA6B3CD8693A762D5E19FD8DE9ED4D999E5EAAA454B0B
838F4DD6EAA5D1ECA5C1E198CAEAA1C8E29B909C5AA4A969D6D696E0E5A38B9852D1E29B
CCDD96D6E39DC3C983B3B470919751C0CD85C3DE91CAE699DAEBA4CBD893E2F1ACD6DB99
F4DFA6A08A51B2AA6CE0E7A4CFE09AD5EBA3D5E49FC7DB94C5E59AD4F0A6D3DC99BBC080
B6C282CFE2A2E5FAB79BB26CC3DA92E0FAB0C7E197CAE69BBFD990D6EDA9D7EAAAD2E1A6
D0DDA8C0CA98C8CFA3F6FAD9FFFFF3FFFFF6FEFFEFF6FFDEEFFFD2D5E8B0D0E6A5CAE49B
DCF8ADC1DD92BDD78ED3EAA4D6EBA8CADD9DD9ECACF7FFCDDDFDBCD6F0AFEBEFB2BAB87D
C4CD94D0E9A8C6F2A3B9EA91BFE68BC9E99DCFECC0C7E9D177A79999D3BBADE9B3B3E8A2
C3E49FD6EDA7CBE29CD6EDA7A9C07A738A44D4EBA5CAE19BCAE19BD4EBA5D2E9A3BED58F
A0B77192A963E5FCB6C2D993D3E9A1C4DA92D0E79F59732A99B36ACBE29CCFE39ECDDC99
CAD392E5EBABE4E9A95A6020D3DF9DCEDF99C3DA92CDE99ED1F2A3C2E595B6DB8BC5EA9A
C9EA9BDBF7ACD5EBA2CCDC95E5EEABA0A563959756DADF9DDBE4A3CAD996C5DA95E5F6B2
B9BE7E777538646426ACAE6FE3E8A6E0E7A4D4DD9AE3EEAA
D3E4A0CBDC98CBDC98CBDF9AA0B46F90A56096AB66CAE19BD1E8A2D7EEA8D4EBA5D0E7A1
C5DC96C5DC96E7FEB8D0E7A1D8EEA6C7DD95DFF6AEC3DD96DDF8B384A25C56742EA6C581
CEEBA8CEEBA9D3EDACD7F0AFBFD595C8DD9CE8FBBBC7DD9CBBD896C5E4A0DAF5B0D5ECA4
C7DC91C8DD8ED7EF9BCEEC94CAEE96B9E48BD7FFB1BFF09FBFEFA586B370669051C7EEAF
C7E8A3D2F2A9D5F5ACC3E39AC0DE96DFF9B2B3C782D0DC9AD7DD9DDDDFA0DDDFA05D6323
768240D1E5A0D3EDA6C5E39BCAE89ED6F2A8A9C078A1B06BDBE29FE7E7A7999152F8EEB0
F3E9ABC3BB7C7D7E3ADAE19BD5E59CC4DC90D9F6A6D5F4A6C4E095CFEDA3C0E095DBF1A9
E4E0A1544C0E9EA562D4EAA2CAECA0CAF0A3CAEA9FC0E296BBEC9BCBF7A8D8F2A9D4E5A1
D0E0A191A464AABD7BC2D792CEE59DCEE89ECAE49ACFE99FD8EFA7C4DB95CFE1A3D4E3AA
D3DDABF0F7CBE0E5BD909076F9F6F1FFFBFAFFFFF1DDE4C3DEECB7D3E8A5D1E99DC6E192
B3CF8291AD6298B26BC9DF9ED7ECABBBCE8EB9C98AD0E6A5C7EAAA819B5C5E5D24C9BE88
F5F5C1D0E2A6B9E495CCFDA4CEF59AD8F7ABEAFFD6DCF3E18EB3ABA8D9C6C0FAC7BBF0AC
C2E39ED4EBA5D2E9A3CAE19BC6DD9789A05AD3EAA4CAE19BCEE59FC3DA94CFE6A0D3EAA4
C9E09A79904ACCE39DCEE89FCAE699D9F8A8CAEB9ABADB8C84A458E9FFBBC2D993D7E8A4
E9F3B4DADEA3D3D49A8A8D545D652AD0DC9ED4E7A7DCF7B2C0E595C9F5A0C5F29DC9F6A1
B5DF8BC0E595C4E395D9F1A5C9D9929EA9649FA663DBE4A1DBE7A5D1E5A0C5DF98D2E6A1
DDDD9FDFD59AC6BD82676125726E2F919151D4D695D2D795
CEE3A0D3E8A5DCF1AECFE49FC0D48FDDF1ACCADE99D4E8A3D2E6A1C9DD98D5E9A4CADF9A
DDF2AFCDE29FCBE1A0CFE6A2D4EEA5C2DE93CBE59CD5F1A7C1DC95C4DF98BCD792849D59
CBE4A2CDE3A3D0E6A6C7DB9C94A86998AA6CBFCF9193A5698FA368D4EAACCDE3A2C4DA92
D1E89AE1FAA7C2DF85CCEE90CBF091C8EF94B3DE85C4EF9FC0EBA3C9F3B16C9559C4EEAF
C3ECA8C2E7A1CDECA6CAE39FCFE49FB6CA85C7DB94D9EAA4CFDE99E3EEAAD1D895858C49
777D3DCAD392D7E6A3D6EAA5CFE49FC6DD957C934B9AAE67DDE8A4D0D291B2AA6C9D8F52
E0D4989D98587D823FDAEAA3C3DB91C8E79BD3F2A4BFDE92C4E499D5F5ACC6E89CC8E096
D7D598605A209EA66BCAE0A2C2E5A1C0E89FC7E99CC5EF9BBDF59CBDF19CC6E69BCADF9C
D9EEADD0E5A4D1E6A3DAF1ABCDE79ECAE49ACEEA9FCBE79CD1EBA2C8DF9BD3E7AAD9E8B1
D0DCACE0E9BED4DAB49EA186FAF7EEFFFFF6FFFFEDCCD4AFCFDEA7CCE19EC8E094B7D281
59762690AC5FC2DC93CEE8A1CDE4A0D2E7A6D3E6A6C8E19FC0E59FCCEDA6E4EDACD5D599
DADFA5C7DA9AC3E89AC5F19AC1E88FC7E69AEFFFD8F0FFEFA1C8B677AB94A5E3B4B9F0B6
C6EAACC4DE9DD4EAAAC5DA99E0F3B198AC67C8DC95D4E8A1CCE29AD3EAA2D2E9A1CCE39B
D4E9A49DB16CD0E19DD7EBA4C5E496CEF19FCAEB9ACCEB9D88A459CBE59CC9DE99DAEBA7
D4E0A0D0DA9DE9F1B5AFB77C525A1FDEE8ABDAE4A8C7DA98C3E898C3F49BB2E589C1F19B
C4EA9FD4F3B0C6DFA5CFE2AAD3E1A4AEB87BAAAD74D6DBA3D0DFA6D3E8ADCBE4A2CFE39E
E2E4A5DCD89BE6E2A5726D3368612A403902A19A64C6C08C
CBEBAACAE9A6CBE8A5D2EBA7C6DB96CBDC98E8F5B0D1DC98D8E39FD7E2A0D8E3A1D7E6A5
CADA9CD7E9ADCCE0A5CAE2A4CCEAA2CBEB9FCBEA9ECDE99ECCE39BBDD38BA6B77191A05B
91A05B96A56292A15E90A15DA8BC77CDE29DD7ECA7CDDD9CC0C58B74773EB2BE7ED0E49D
CFEB9EBFE18DCFF39CCBEF97C8E992CFEC98C6E393CAE89ECDEEA9BBE09D88B272BCEDAC
B6EFAABDEFAACAE4A5D1DCA0D5D69AA8AD6BC8D992D5F0A3CBEC9BC6E595D7E99FB8BF7B
878344797035C3BD83DFDFA3E0EBA9C8D9958FA05C9DAC69D4E09ED9E4A2AFB87758611E
939E5C96A560AEC27BC7E198CBE99FCBEBA0CCEEA2C8E89FD8F1AFBDD490D3EDA3CEDB93
ECDFA88F7D4FA19B77D7DFBAD2E8B9C9E5AAC9E495C9EE91C3F793C1F495CAE89ECFE4A3
CDE6A4CCE7A2CCE7A2CAE8A0CAE89EC9E99DC9E99DC9E99ECEECA6CAE5A2CDE5A9D5E7B3
D1E1B2CDDAAFDEE8C3FBFFE0CFD2B3DBDCBCC7CBA8949D7276834E899B5FB6CB86D1EC9F
CAE795CCE995CCE997D0ED9DE0FAB1ECFFC1E4FABCCCE9A7BEE997C4F097C8EA96CAE596
D1E99FCDE79DC5E496C8E99ACBEC9BC8EA9EBFE5A8CBF7C4AEE2BB36744F64A881B5F4C9
BBE7B6D9F7C3C8DFA9CBDCA5DCE5AC8A9354E0EAA5D7E49CDBEDA1C6DD8FD7EFA1D6ECA1
C9D893D7E09F57581CD5DB9DCEE8A1CAEAA1C4DE97D3E7A2B9C885475311D3DF9DE1F0AD
D1E5A0D1E8A2C4D994DAEEA9535F1D757C39CCCC8EE2EBA8CCEB9FBAE792C3F699BCE797
F7FFD8FEFFE8FCFFF1E6EBD7DBDFBCC9C79ED1C7A3FFFFDDFBFFE4D8EAC2CEDFA8D5E5A4
CAD994DDEAA5E0E9AAD5D89FD5D1A1D5C9A1B0A07F806D4F
C4E7A7BFDF9ECAE9A5CFE8A4D5EAA5DEEDA8C3CE89DBE29E6D72305156145A6022565E22
6D783ED3E0A8D9E7B2CADFA4CAEAA1C8EA9DC9E99DD0ECA1D8F0A6DAEEA6D4E59ECCDC95
D4E19BD7E49ED0E099C5D991CAE097D9F1A7D9F3A9D3E7A0D7D89EA2A067919B5CD5EBA3
C7E79BC2E996CAF29CC4EA93C9E996D1EC9DD5EBA0D1E8A0CEEBA8D8FBB9B3DD9B95CA86
AEECA9BBF2AFC6E2A7E5EEB5D8D69BB5B575E4F6ACBDDE8DC1EB95C9F19BCEE698CEDA92
A5A162988C52F8E8B4DDD49BD3D99BE6F2B0B9C583CDD997D9E8A5C9D895D7E8A4CEE29D
D0E5A0C7E19ACFE9A2D2F0A8C9E9A0C2E49AC1E59BC1E09ABED494EAFDBDCBE198E3EDA6
EEDAA5BCA37BB5A78CFFFFE8DDEBC7D1E8B0CEE597CAEC8DC1F48BC0F291CCE89ED0E4A5
CCE7A2C9E9A0C9E9A0C8EA9EC8EA9DC6EB9BC8EA9DC8EA9EC4E69CC8E7A3CBE8A8CDE6AD
D5E9B6E1F4C6F0FFD7FAFFDCFDFFD68C9360555D2C95A16FD9E7B2D3E5ABC3D998CEE89F
D1EE9ECEEB97C9E692CEEB99E1FDB3EFFFC7E5FDC3CCE9A9BCE692BFEC91C6EE98CCEF9D
CFEEA0CEEA9FCBE59BC9E399D8F4A9C6E89EC9F2ACADDD9FB7EDB93774485C9E7AA8E4C2
C0EDC6B1D2A7DAF1C5CFDFB099A26D5B6125D5DE9BDDEAA2CBE091C7E291C6E190D5ED9F
D8E8A1D8DE9E6A682D999A5ECCE2A1CEECA6CCE19EDCEBA8CFD8997B8443C3CE8CCFE09C
CDE49ECDE8A1D4F2A8D1EBA2C7D790565D19ECE8A8D0D390D4EEA5BEE997C2F599BAE397
FCFFE1FCF8EDFFFEFFF4F2F3DBDAC6D2CBAFE1CFB9FFFDEAFBFFF1E5F5DAE0EEBDCFDFA1
CDE6A5C8E2A3C6DBA2CFDBABE7ECC4FFFFE2FFFDEAFFFCEC
CCE9A9D5EFAEC6DF9DD4E9A6C7D894E2EFAABCC681767D396166249FA1609A9E6195995E
4A4F15656C36CDD6A1DDECB1CBE69FC4E699C4E498C7E69ACBE79CCEE89ED0E89ED1E79E
D2E89FD6ECA3D5EDA3CDE79DC7E398C7E398C6E599C9E098DCE5A6D1D79B829150D7F1A8
C3E89AC4EE9AC4EE98C2EA94C6E894C5E292D1EBA1CAE59EC1E09CCCF1AEC7F1AF77AA67
71AE6BC6FDBAC4E6A9D4E6AADAE3A4A1AA67D0E69DCBEC9BC2EC96C5EF99C9E898D3E79F
BBC07E837F42BCB17BDED89ED9DFA1DFEBA9818D4B798543DAE9A6CEDD9AD9EAA6D7EBA6
D3E8A3CAE49DCEE8A1CEECA4C5E59CC5E79DCCF0A6D1F0AAD7EDADD1E4A4D3E9A0CDD792
F5E1AEA78E66C0B297FFFFE6E3F2CBD5ECB4CFE698C8EA8CC0F08CBFEE90CCE69FD2E6A7
CCE7A2C9E99EC9E99DC8EB9BC6EC99C5EC99C6EC99C6EB9BC1E698CBF0A3CAEBA4C0DE9E
CCE5ABE3FCC5E9FFCEDEF0BCD5E3A8D5E1A3CFDDA0C9D89DC9DBA1CFE5A7D2EBA9D2EDA6
CAE699C7E696C4E393C3E294CEE9A4D7F1B2D3EAB2C5DEA4D7F9AFCDEFA2CAEA9FC7E59D
C3DD96C9E09AD3E8A3D0E79FC0DA90C6E49AC5E9A3DAFFC3B8E5AEB6E7B87BAF8830623F
E7FFECEDFFE8E0F9D2B2C49A546231909D65D5E5A6C2D991CAE99BD4F7A5BDE08ECAE99B
D7EDA4D8E5A0A9AE6E9AA362C9E29ECEEEA5CBE29CDBECA6DBE7A5B8C37FACB974C9DD96
CCE69DD1EDA3C0DC92C9E098DDECA759601DC6C282D4D695D4EBA5BDE698C1F19BC1E6A0
FBFFE3FBF7EEFFFEFFFEFDFFF6F4E7EBE3CEF8E5D6FFFCEFFBFFF4F1FFE9F4FFD6CBDCA8
CEECB8C5EAB7D2F1C5EEFFE0F7FFEAF9FFEFF6FAEBF8FAED
D9EEADC4D998CFE2A0D6EAA5DBEAA5C8D5902F3A005A611D919654D9DE9CCFD192EBECB0
9C9D6472723CB4B480E2EAAFD2E9A3CBEB9FCBEB9FCDECA0CAE99DC6E599C5E498C7E69A
C1E094C3E296C7E69AC9E99DC7E79BC4E498C7E79BD0ECA2D0DF9EE6F2B29EB370BCDA90
C6ED9EBFEA98C3EF9AC3ED97D3F6A2C8E797D1EDA2D5F0A9C9EAA5B5DA95CAF4B292C381
59924EA6DD9AC0E8A9C1DE9ED2E5A38FA05AC2DA90D6F5A7C8EF9CBDE793CDF2A2C7E398
CEDD9867692A4F460DEDE7ADD3D999E3EFAD99A56351601DD9E8A5D0E19DCFE39ECADF9A
CDE49EC7E19ACDE8A1CFEAA3C4E29AC3E39AC7E99FC5E49ECDE3A3CEE0A2C1D691E4EDAC
F7E3B1593F1AFFFEE1FFFFE4E0EFC6D4ECB2CFE59AC8E98EBFEE8EBFEB92CCE5A1D3E5A7
CCE7A0C9E99DC9E99DC8EB99C6EC97C5ED97C5ED95C5ED97C3EA97CCF3A2C8EDA0BDDE97
C3E29FD5F3B5D4F0B6C5DDA1D0E69ED7ECA1D8ECA7D2E7A4D1E7A7D3ECABCEE9A6C1DF99
C9E79DD1F0A4D2F1A5CBE99FC7E29FC8E2A3CCE3ABCDE4ACC5DE9DC2DB99CDE6A5D7EDAD
D2E6A7D5E8A8D8EBA9CFE39ED3EBA1D2ECA2708E4641611E7DA066C0E4B4C3E9C086AB89
5D806284A28699B292879D77C8DBAEB9D09AD8F2B5D4F3AFC4EDA1CFFAAABFEA9AC1E899
CAE89ED6EAA3E2EDA9CAD792CCEAA0CBEDA1C4E096D2E89FD7E6A1D9E8A395A660D4EAA2
C2DC93D0ECA2CDE99FE3FAB2D2E19C8E95525756159FA160CDE29FBCE096C0ED9CC9EEAB
FCFFE4FFFDF4FFFEFFFFFEFFFFFFF6F4EADEFAE6DFFFFBF4F5FBF1F5FFF1FBFFE3D9EABE
C4E0B7BDDDB6CCEAC6E9FFE4F4FFEFF5FFF3F8FFF6F9FFF8
95A46392A15E8B9A5799A8634E5D184C5B166F7C36B4BF7AE2EBA8DAE19EE0E2A3E4E4A8
D9D79EC0BB844F48129A9960CFE39CC9E59ACBE79CCDECA0CBEB9FC6E89BC8EA9DCDF2A4
C9F0A1C4EB9CC4EB9CCAEFA1CBF0A2C8ED9FC9EEA0D2F0A6CBE09DD9ECAAC0D9957D9F53
C9F0A1BDE896C8F49FC2EC98CBEE9CCAE99BC7E398CEECA4D9F8B2B5D894C5EEACB6E3A2
99CD8B78AC6ABBE9A8CCF3B0C2E19D99B36CD1E8A0C7E295CAED9DC3EA99CAF4A2C0E597
DFF6AE8994525A541ACEC58CD7DD9DDDE9A7D9E8A5A0AF6CBAC986D2E39FDBEFAAD1E6A1
D2E9A3CDE7A0D2EDA6D4EFA8CBE9A1CAEAA1CBEBA2C3E19BD6EAADDBEDB1DBF0ADD3DC9D
D5C091EED4AFFFFFDFE7EBC8D6E7BACEE6ACCEE499CCEA94C2EF94C0EC97CDE3A2D3E2A7
CDE6A2C9E99DC9E99DC8EB99C6EC97C5ED95C5ED94C3EE94C0EB92C6EE98C6ED9AC4E99B
C6EAA0CEEFAACEEDAACAE8A2C5E08FC1DA86C9E193D7F1A8D1ECA7BEDB99C3E29FDAF9B5
C8E7A1CCECA3CDEDA2C9E9A0C7E4A1CBE5A6CFE7ADD2E7AED7E8B1D5E4ADD6E5AED5E4AD
D1E0A7D2E1A6D3E3A4CFE39EDAEEA6C1D78C839B51BCD38F829A5E98AF7BD3E8BDD4ECCA
6680678FA893475F476E8568CFE7C3D1EEC0B5D8A2B5DF9FB7E6A0B5E89BC0F3A4C1ED9E
C2E79ACFE9A0DBECA6BFD38BCEEEA2C5EA9CC5E498CFEA9DCDE39ADAEEA6859B52D0E89E
D8F4A9CCEB9FCEEA9FBED68CC6D791B9C27F585818979C5CD3E3A4C5E29FC0EA9EC9EDAD
FAFFE4FFFFF5FEFFFFFEFFFFFFFEFBE2D7D1E9D1D1FFF6F6F6FBF5F3FFF2F9FFE6E9F8D1
F5FFE4F4FFE6F5FFE8F5FFEAF4FFEAF2FEEAF6FFEEFAFFF3
919E599EAB669FAC6781904BA1B26CEEFFB9B9CA84D5E49FCFDC97DCE5A4DADF9FD7D79B
EBE6ACE7DEA7534812A6A167DBE8A3CFE59CCCE49ACCE89DC8E79BC1E396C1E698C6EFA0
C8F1A2C1EC9CBEE798BFE899C4EB9CC4E99BC3E89AC6E69BD4EBA7C8DF9BCCE7A04A6C20
CAF1A2C0EA98CBF5A3C2E895BDDE8DCDEC9EC5E196C5E099DBF9B3CCECA9C7EAA8C6EDAC
C5F1B28FC07FB0E19FC9F8B2C3EBA4A4C37DB3CA82CFE59CCAE69BD0F3A3BCE797BDE899
D4F2AAC2D18EBEB87E766D34DFE5A5C3CF8DD6E5A2DEEDAA6B7C38ACC07BD6EBA6C9E09A
CBE59EC6E099C8E39CCBE69FC8E69ED0EEA6D3F1A9CAE5A094A66A91A067708244A0A86F
D5C095E6CCA9D3C9A6CFD4ACCFE1B1CAE2A6CEE49BCFEA99C4F09BC1EA9CCDE1A4D4E1A9
CFE5A4CCE89ECCE89ECAE99BC9EA99C8EC95C6ED94C5ED94C4EC93C3EB93C6EC97C9EE9E
CAECA0C6E89EC6E7A0CBEBA0D9F7A1D4F298CCE997C6E599CAE9A5D1F1B0D2F2B3CFEFAE
CDEDAAC5E69FC0E097C5E59CD0EEA8D6F1AED0E9A8C9DDA0CFDAA2D7E0ABD2DBA6CFD9A4
D7E4ACD6E5AAD3E3A2DBEFA8C6DB8EBCD184D3E599C8D993D8E6AB3A46148D966BDAE5C5
E1F2E0C3D7CC607566172F19748E717A9A75CDF4C5C8F7C0C2F6B6B5EAA4C2F6ACBEEEA2
BFE59ACCEAA0C3D9909EB66ACCED9EC2E797CDEE9FD1F0A2CAE598D0E89C88A258AFC97F
BEDA8FCBEA9EC4E095D6EEA4E3F4AEDFEAA6737836595E1ED9E5A7D1EAA8C3E8A2C2E4A7
E6F2CEF6F9E8F9FEFAFCFFFFFEFDFBDFD4D2E5CCD0FFF8FAFCFFFBF2FFF1F9FFE6E3F2C9
DCEBC2E5F4CBEEFAD4EEFAD6EFF8D9F0F9DCEEF4DAE6EFD4
D2DD98CFDC96D0E099E4F5AEC4D891BFD58DDBF1A9D7ECA7CDE19CEAF9B8C7D192D4D89B
E7E5AAE1DBA1675C249B9559D6DD9ACBDB94CDDE97D4EAA1D2EEA3C8E89CC4E99BC6EFA0
C3EC9DC3EE9EC3EC9DC2EB9CC5EC9DC9EEA0CAEC9FC9E79DD2ECA5C8DF99CFEAA3537127
CFF1A4C4E797CBEE9EC6E798CDE99CD8F3A6D5EFA5CCE69FC5DE9AC8E2A1BEDB9BD3F1B3
C4E6AAC4ECAE86B775B9EBA4C7F2ABB5D68F8BA05BDEEDA8CEE29AD3EFA4BDE899BEE99A
C4E69CD4E5A1EEE5AC61561EA2A767CDD997DBEAA7E9F8B560712D7E924DCEE39ED8EFA9
D5EFA8CBE69FC9E49DC7E29BC5E099C8E39CC2DD96B0C98753652B95A46DD4E5AE858C59
B09D75CFB795DCD4AFEBF2C6D0E2AECBE3A5D0E49FD0EAA0C5EEA0C3E8A2CFE0AAD7E1AD
D3E2A7D0E5A2D0E5A2CFE69ECCE89BCAE999C9EB97C9EB95CAEE97C8EC95C8EB97C8EB9B
C8E89CC4E49BC2E19BC3E197CBEC95C0E389C2E392CBEDA3C9E9A8C2E4A7D4F6BAEEFFD4
D7FAB8D1F2ADCBEBA2CCECA1CEECA2CAE69CBED891B6CB88848E51A9AE74AFB87FBCC78D
DBEBADD4E7A7C0D68ECFE59AD1E898AEC472D6E69BE1EEA8CDD59A7F8150A3A17AF1F1D7
DEE5DDD1DDDB9DACA58CA09458715C3C5D40628C66AEDDAFB8EBB3C0F4B6BDF0ADC0EEA6
BDE39ACEECA2C3DB9191A95DC8E998C1E794D1F4A2CBEC9BC8E797CAE999A6C2758AA659
CDECA0DDFCB0C1DD92D5EDA3C1D28CD5E29D979E5B565C1CCDD697D6E9A9CAEBA6C0E0A1
D6E3B8EDF3D9F3FEEEFBFFFBFFFFFBEFE3E3EDD2D7FFF5F6FEFFF6F1FFE9EBFBD7D4E4B7
D5E4ADD2E1A6CFDDA2CDD8A0CDD7A3D1DBA9D6DDB1D7E0B3
DCE9A1D6E69DD7E99FD2E89FCEE59DCFEAA3D3EEA7C1DC97D0E9A7C9DF9ED8E8A7D8E2A3
D5DA9AE6E4A7554F13A4A0619DA05D9BA560ACB973C5D68FD2E89FCCE89DC7E79BC8ED9F
C0E798C8EFA0CAF1A2C6EB9DC6E89BC9EB9EC9E99DC8E499C7E198D1E8A2D5EFA67A944B
D7F3A8C2DE93C7E295D0EB9ED2EA9EC8E096D2E8A0C5DA9591A66393A86795A96AC9DFA1
CFE8AECAECAF527F3EB9EBA4BBE9A1D2F3AE98A867CDD896D6E39ECEE49CD0F6A9C5EEA0
C8E89FCFDE9BDED59C9F925B535818DCE8A6D4E3A0CBDC98B0C47F93A863D3EAA4C8E29B
CFEAA3C9E49DCBE69FCEE9A2D0EBA4D2EDA6C6E19AB0C685D5E4ADD1DFACD6E6B5DFE5B9
D2BE9D644B2CC2BA95D4DCADD3E6AECEE6A8D2E5A5D2E8A7C6EBA8C4E6A9D2DFB1DBE1B5
D6E0ABD4E2A7D4E2A5D3E3A2D0E69ECFE79DCDE89BCCE999CBE896CBEA9ACBE79AC9E59A
CCE89ED1ECA5D0E9A7C8E39CCBEA9ACDEE9DCBEBA2C5E5A4CCEBB0DEFFC8EEFFDAEEFFD8
C7E9ACCBEBA8CAEAA1BFDE92ABC77A95B2628BA6578DA3589EA964B0B9768D9856768544
91A4628FA65E8BA359AEC97AC9E28FA0B765C5D78BD5E09CE2E7AFBBB88B8F8967F4EDDA
A9A8A4D5D8DDF2FAFCF5FFFFE9FFF3BDDDC85F866955815D86B587B9E8B4B8E5AACBF3B4
C3E3A0CEECA4C9E1978BA357C7E696C2E593D0F3A1BFE290C6E997CEEF9EC2E394759446
A2C175ABC77CDAF4AAD0E89ED0E19BDFEEA9D6E19D929B58B9BE7ED6E19FCFEDA7C5E3A3
D0E0AFE9F3CEF1FFE5F9FFF3FFFFF8F5EAE8E9CFD2FBE6E3FEFFF1EFFFE2E6F6CFD0E2AE
D3EAA6CDE599CEE49BD4EAA2D6E9A7D0E3A3D1E0A5D6E5AC
D2E498CCE194CFE59AC9E399DBF9B1C4E39DBFE09BCCEDA8C3E3A0C9E6A4D7EDACC7DA98
E1EDABC9CF8F6567265353135A5B19636623484F0BDAE5A0DDEDA6B9CF86D1EBA1D2EEA3
CEEEA2CAEA9EC5E599CAEA9ED0EFA3C7E69AC6E297D3EDA3D3EAA2C2D991DCF2AA92A860
C4D890D9EAA3D0E19AD3E49DCDDE97D5E69FDAEBA5CDDE9A667534D6E4A694A06294A267
D4E5AECAE3A9C7EEAFBBE8A3BDE6A0668541849352E2E8A8E3E9A9C9D895CDEBA3C7E99F
CFEAA3DAE6A4CEC4894536005B5D1EDBE7A5D5E4A1C5D692D8ECA78BA05BD0EAA3C4DF98
D5F0A9B4D28AD4EFA8D7F2ABB7D18AE0FAB3C7E19AC0D594D4E2ADD6E3B5CCDBB2DCDDBB
FFFCE160462BDFD7B0D9E1AECADEA3D2EAAC001200000D00001000456331040C006B6B45
D2D5A8E4EBB8C8D19ADBE6ACE0EEB0BFD08CD0E49DDAF0A7C8DE95CFE79DD5EBA3D3E8A3
D0E5A2D0E5A4D1E3A7CEE4A4CCE5A1C3E09DD3EFB2CDEAB4D5F2C2F0FFDFF0FFDFEAFFD6
C2E1A6CDEDAAC5E59CCFEEA0C8E593D1ED99C8E18ED0E795D4E595D3E194D1E196D4E99E
D1E99DBDD98C9DBA6A81A14E7F9C48D5F09FD6EBA0DBEAA9D3D7A4D6D4AD9A9377A09788
FFFBFFFFFCFFFEFFFFF9FFFFF4FFFFF0FFFDEBFFF8E9FFF32348278CB188CBECBDBEDCA6
CBE5A8CEE7A5D3E8A38AA057C6E295D1F0A2C4E596CBEE9ECFF2A2CAED9DBEE0938EAE62
214000BEDA8FD5EDA3D1E79ECBDF98D5E6A0D5E6A0DBE6A2545513E3E8A5C8E29BC6E5A1
D3E7AAE6F7C3F2FFDCF2FFE3FFFFF3FCF1EDF3D7D6FFFAF1ECF2D6E0F5CCDBEFBECBE5A6
CEF3A3C2EF94C4EF96BDE491C8ED9FD3F5A9C5E49EC8E7A3
C2D989E1F8AACAE598BDD98EC4E49BC0E19CCCEFABC6EBA8CFF2B2CBEBAAD1EEACC2DB99
DDF0AEECFBB8C6D18DD7DE9BD5D8959798568487445259156D7833E6F6AFDAEBA4C7DD94
CBE399C8E298C8E499CDE99ED4F0A5D4F0A5CCE89DC6E096C7E198E2F9B1D1E59EC1D28C
394600D1DC97DDE8A3DBE8A2DEEBA5D1E09BCAD996E4F3B07B8A49DCE8A8D8E0A498A266
A7B47EDFF4BBC5E5A697BE7DCBF0AD86A361E1EFB1C7CD8FCBD193EEF9B7CAE19BCBE59E
D5EAA57881405A5015B2A66CD7D99AD1DD9BCDDC99E3F4B0C7DB96B4CB859FB972CDEBA3
BFDD95DCFAB2D0EBA4C1DC95CDE7A0B1C8824B621CCCE0A1D9E7B4E0EBC3F0FBDBF2F2D8
FFFAE8DEC4ADA59D76626B366F8346A8C082BFD09ADDF1C0CAE9BDE5FFD8ECF1D1FFFFE3
71724AE2E4B5FFFFD4FFFFD1F0FABEE3EFB1E6F5B2B9CA84D6E7A3D0E19DCEDF9BD1E1A0
D2E0A3D2E0A5DCE9B1E8F7C0EDFFC9DCF3BBDCF2C1D3EABED6EFC8DEF8D1D6F1C8DCF8C8
CAE7AFD4F2B2C5E39BC5E19491AC5BC3DC89D6EF9CDFF6A4D2E593D1E493D1E697D4EC9E
D3EFA2CAE99BB9DA8BACCD7CADCC7CCFEB9EC1D691DAE9AED5DBADD6D5B6BCB5A2E4DAD1
FFFBFFFFFAFFFFFDFFFCFFFFF7FFFFF2FFFFF0FFFFEEFFFA99B29CC6DFC1E5FBD5E4FACC
E7FCC4CEE2A5D5E8A6B6CC84C5DD93E6FFB6BCD88DBCDC90C0E295C4E99BC6E89BA7C77B
708F43DBF5ABC8DE95D3E9A0D4EAA2D5EBA3C7DD95DCE9A358530FB1B06DC5DB93D9F7B1
CDE29FD6EAABEAFFCAF1FFDBFEFFEFFFFDF4E5C9C6EAD4C7F1F9D4DBF2BEBCD49AD1EEAB
BCE795B6E78EC2EF9ACBF6A4BFE89ABEE49BD2F2AFDEFEBD
DEF7A6C4DF90CCE79AD6F2A8CCEBA5CDEDAACBEEAEB8DA9DC5E7AAC0DFA3CEECAEBCD997
C0D997D5ECA6CEE49CE4F4ADE2E9A5E1E4A1E3E8A5888F4B5E652188924DC2CD88E9F9B2
D8E9A2D2E69ED2E89FCDE59BC7E197CEEA9FD3EFA4CAE69BCAE69BD6EEA4BFD38BE4F1AB
56601BD3D895DFE6A3CCD592D9E6A1D5E4A1CBDC98DBECA8A0AF6EDEEAAAD0D99A959D61
606B33BFD099C1DDA06A8A4BC5E5A4789251D5E5A7E7F1B4DFE7ABC0CA8BE5F5B4CBDB9A
8C9856595F1FA79E63D2C98ED5DA9AE0ECAAD2E19ED8ECA7D9EEA9C2DC955B762FC0DE96
D3F1A9B6D48CC8E39CE6FFB9D9F0AA8EA35EC5DA95D2E4A6CAD6A8D8E2C0FBFFEDFFFFEF
FFECE0E5CCB88C876189935EDFF5B7CAE2A6DAEABBCEDEB7BED9B6D5ECCFFFFFECFFFEE6
FFFFDDA5A67A5356277B824E838C534D581C4D5C1B5B6A27E2F1B0D4E3A2CEDD9CD2E0A2
D4DFA5D5E0A8EBF3C0FEFFD6F3FFD2F4FFD9E4F4CFD2E3C1F0FFE3F5FFE8D8EEC8CEE5B9
C7DFABD2ECAFC7E09CD0E79F8FA75BD1E79CD7EDA2C1D78CD4EB9DD2E99BCFE79BCEE89E
CDEBA1CEEEA3CDEDA2CCECA1C4E298D7F2ADC7DD9FD8E6B3D7DFBAF7F7DFF4F0E4FFFCFA
FFFAFFFFFAFFFFFDFFFEFFFFF9FFFFF5FFFFF5FFFFF5FFFFF7FFFAF8FFF2FAFFEBFAFFE2
F2FFD1CCDBA4CEE0A2CBDE9C687935C3D792D0E7A1DBF9B1CCEEA4C0E69BC6EAA0C4E69A
B0CC82DDF7AEC8DE96D1E79FD4EAA1D9F1A7BFD98FD9E9A0655C17DBD490D3E4A0AAC57E
DDF5ABE2F9B1ADCC88E4FCC8FDFFEBF5EBE2F5D8D2FFEDDAD5DEAFD0E8AAD8F1AFC1DF99
CFF3ABC3E8A2C7EAA6D1F1B0C2E0A4BDD8A1DCF3BFF1FFD4
CDE695B9D485E0FAB0BDD790C9E4A1CAE6A9C4E1A7E5FFCAEDFFD2E7FFCAF1FFD3EAFFC9
CDEAA7CEECA4C7E59BCDE59BC5D58EE0EAA5D7E19CE0EAA5B0B7734E5511838A46D1DB96
D9E49FD2E29BD4E8A0D1E99FC2DC92C2E195CEEEA2CFEFA3CCECA0BDD98EE2F6AEDAE7A1
464D09989D5AE4E9A769722F303F003B4F0AB5CA85CFE49F899C5AD0DF9EE5EFB0D3DDA0
CDDCA353662EDAF2B67D995C46632392AC6DC6DC9ED5E7A9D1DFA2DFEBADCDD99BA1AB6C
545D1CBBC080DFDDA0E1E1A3E3E9A9C7D391D8E7A4A8BC77556A256F8942D0EBA4DCFAB2
C5E59CDDFDB4C3DE97BDD790C0D7918FA45FDCF0ABD8E7ACFCFFDDE8F1D6F5FEEDFFFFF6
FFF8F3D6BCADCCC7A1E0EAB5C1D797E0F8BCF1FFD5F8FFE8F1FFF1F4FFF4FFFFF3FFFFEC
F8F8D2E6ECBCD7DEABDFE8B1D2DDA3CAD89ADAEAA9C8D995C1D28E8F9F5E677635758143
A6B177D6DFA8F2FAC7FCFFD5FEFFDFFCFFE3E9F2D3C3CEB0E0EDD1EFFEE1D0E1BFD6E8C0
C1D5A4DDF2B9DBF1B1D5EAA9A1B675CBDE9ED7E9ABD5E7A9E2F8B7DAF0AFCDE6A5C6E0A1
C7E1A4C8E4A7CAE7A7CCE6A7C5DFA0D0E8ACD2E4B0E8F5CAE9EFD3FFFFF1FFFFFAFFFDFD
FFFBFFFFFBFFFFFDFFFEFFFFF9FFFFF8FFFFF8FFFFF9FFFFFEFFFFFFFFF8FFFFF1F9FCE1
E9F1CAD1DFACC7DBA0C0D495C2CD91CFDB9DD8EBABC7E29FC2E39EC4E8A0CAEEA6C9E9A0
B9D48DABC27AD7EBA4CDE19AC8E096D9F3A9C2E195D4E69CC6BB79615314B6C584E6FFBC
BFD78BC8E394D6F8ACDCF8BDFCFFEAFFFDF4E8CBC5EED8C3D4DDA8CDE7A0B8D48ACBE6A1
97B0769AB17DADC490BED2A1E2F3C6F2FFD6E2EDC5F6FED9
8BA25292A95B6E843B2A3F00A8BC7FD6E9B1E5F9C6EBFFCEF5FFDAEEFFD1F4FFD6E3FFC4
C1E09DC1E29BC7E99DC3E397D7EFA5C8DC94C7D891D2DF99D2DD98959C5859601CB0B773
D5DF9ACCD792CEDF98D5EDA3CFEEA2C6E89BC3EA9BC3EC9DC9EE9EC9EA9BC4DC92D1E19A
5E67244E53119AA060C6D18FDDF1ACCEE8A1B8D38E8BA963A4BD79D1E6A3BCCC8BD9E9AA
D3E8ADD5EEB44B63274961254D672AC6E3A3C0DE9EC8E5A3C9E2A1DBEEAEDCE6A9494F11
A2A767C6CB8BDFE8A5E1ECA8D1DC9ADEEAA893A25F6A7E39C5DC96C4DF98CFEDA5B7D78E
D0F0A7BCDC93DCF7B0D1EBA4475E18B5C984CDDE9AC9D79CFEFFE1FCFFEDF7FFF4F4F3EF
FFF7F8DDC2B7E6E2BCD4DFA7C5DB9BF5FFD3F9FFE1F9FFEDEAFFF0F5FFFBF2EBE5FFFDEC
E9EEC5CFDCA6C9D69ED9E9ABD4E7A7CFE49FD8EEA6CBE198D4EAA2DAF0A8D1E5A0B8C887
A2B073A0AB73A8B27DAEB687FFFFDEFAFDDEE5E8CBDADEC3FBFFE9FBFFE8D0DEBBD0DFB8
D6E8B8CADCA8A1B47D90A16BB1C28ED0DDAFDAE6BEE4F3CAF2FFD8E3F9CAD4EABCCDE2B7
CEE3B8D0E6B8D0E3B5CCE0AFD9EBBBC6D6A7D1DEB3FCFFE4FEFFEDFAFDF2F5F5F3FFFDFF
FFFEFBFFFEFBFFFFFFFCFFFFF9FFFFF9FFFFFBFFFFFEFEFFFCF7FEFFFCFDFFFDF4FFFCE8
EBF1CFE0EDC1C9E0AAC4D9A059602C60652FD6E3ABD5EBADC9E7A7C1E19EC7E7A4CFEEAA
C5DE9A6E833EDAEEA7CDE19AC9E197D2F1A3C4E797D1E69BC9BB7C5C490FB2BB82CFE8A7
D2EA9EC9E694BCE191EDFFCDFAFFEAFFFCF6EED1CBEAD4BDC5CE95D4EFA299B56A8FA564
BAC698BFC3A2B9BD9C919272C8C9A9EAE9CAAEAA8DD3CFB2
CBE091D8EDA0BACB858C9C5D98A56D8B9765FCFFDAEFFACFFBFFDDF5FFD8F3FFD4E3FCC3
C8E6A6C8ECA4D2F8ABCAF1A2CAEC9FCBEA9EDAF4AAD2E69ED6E39DBAC47F6A712D9A9F5C
E9F0ACDFEAA5CCDD96C9E197D2F2A6C9F2A3BCE998BFEE9DC2ED9BC1E696D0ECA1D5E9A1
8C9753989F5CE0E9A8DDECA9C3DA94D1F1A8C4E8A0C9EDA5C0DF99BFDA95DFF6B2D6ECAB
C3E1A3BEDCA089A165384D128AA467C8E6A8C8EDAAC6EDAACCECABC4DD9CD0DA9D58591D
A8A86CDDE3A3D8E9A3C9DD96D7E3A1CEDA98A7B673ACC07BDAF1ABD1ECA5C1DF97D4F4AB
C3E39AC5E59CCBE9A1B6D0897D944ED8ECA7D3E29FE0EDB5F5FCDAF8FFEDFBFFFDFFFDFF
FFEEF5E6CBC4CECAA5D0DDA5D7EDADD9F0B8F5FFE0F2FDECF0FFFBF7FFFFFFFDFBEBE2D3
D6DFB2D0E4A5D3E8A7CFE6A2C5DF96C8E499D0EB9ECDE899CCE79AD2ECA2D5EBA3D3E8A3
DAEAABD2E1A6A9B67E7D8552CFCFA9EEEBCCFFFFE4EDEDD1E0E3C8E8EFD0DCE6C3D8E4BC
D4E1B5BFCC9E9BA87A99A67BE7F3CFECF7D9E3EBD6EAF3E0F7FFEDEEFFE6E2F4DAE1F1D7
E6F4DBEAF7DDE6F3D5E3EECCF1FBD8E4EECBE9F0CFFDFFE9FCFFEFFCFFF8FCFDFFFDFEFF
FFFFFAFFFFF8FCFFFBF9FFFFF8FFFFF9FFFFFCFEFFFFFCFFFFFAFFFFF5FCFFFBF8FFFFEF
F7FADDE9F8CFC9E4B1D3EAB4A0A3747A7848CBD3A0C4D59ECEEAADD6F6B5CCECABC5E2A0
D8EEAD687B39CFE09CD3E79FD3EDA3CAEB9CC0E796D3E99EA494597C6634DEE5B2BAD296
CFE79BD8F5A1BDE390E0FEC0FCFFEDF5E7E4D2B3B0FFE9D3EBF3B898B364597528CDE3A2
E4EAC4F3F1D8D9D7BE89886CA7A688BDBC9D7F7E5FABAB89
E3F5A9C3D38ACCD896E9F3B6C5CC98ABAE81F4F6CEF3F5CEECF0CBEAF2C9E3F3C4DAF1B9
CAE7A7C3E7A1C5EEA2BAE596B8E393C0E798C1E396D2ECA2DEF2AABECB85A4AB675D621F
C3CA86E5F0ABD6EAA2BDD98EC8ED9FC5F2A1B5E996C1F7A3CCFEA9C0EB99BEDE92D0E89E
EEFBB6CAD591C5D18FCADE99C2E09ADBFFB8B4DE94C0ECA1D0F9ADC0E49AC4E29AC4E29C
C4E9A6D7FBBBB6CF95E1F6BD5D773AC5E8A8BAE7A4BDECA6C0E9A5C5E2A0E0EAAD535317
98985CDCE5A4D4EEA5C5E197E4F5B1BCC886A8B774CCE09BCBE29CD1ECA5CAE8A0C8E89F
C4E69CD9F9B0BCDA92859F58DAEFAACBDF9AD8E7A4D2DDA5FFFFE3F4F8E9FBFFFFFFFCFF
FFF5FFFEE2DED8D4AFDEEBB3D1E7A7D5ECB4FBFFE8F9FFF6F2FFFFF1FCFEFFFBFFEBE4D4
D7E8B4C7E59DC6E49ACDEDA1D4F5A4CAED99C0E28CCBED97C8E895CAE999CAE598C6E097
CDE29DD5EAA9D3E5A7CFD9A4BDBB94BAB492DED9B9D1CEAFA2A183ACB08FDBE1BDFEFFDF
D0D9AEE7F2C7F7FFDAFCFFE4FCFFEDF7FDEFF6F8F5FBFFFFF7FFFFF4FFFCF2FFF8F3FEF8
F9FFF9FCFFF8FDFFF3FCFFECFAFEE5FFFFE8FFFFEAF6F9E4F7FBEDFEFFFBFCFFFFFAFEFF
FCFFF8FBFFF4F8FFFAF7FFFDF7FFFFF8FFFFFCFEFFFFFBFFFFF9FFFFF2FCFFF7F8FFFDF3
FAFEE5F3FFDCC4E2B0CDE5B1AEAF83CEC79DE6E9BCD9E7B4C4DDA4C6E4A8C0DE9ECDEAA8
BDD392A0B371CCDD99D8ECA4D3EDA3C5E697C1EB97D0E89EA5925A593E11D7DDAFD7ECB4
DDF7AECAEA97C6ED9AF0FFD1F6FEE9F1E3E3F6D6D7BDA49090985DABC677CAE99BD7F0AF
D7E3BDFFFFE8FEFFE6F8FFDEFCFFE1FBFFDDDDEABCE1F1C0
CFDF98D3E29DD6E5A4CFDA9ED9E2ABD6DDAA909366DCDFB2D6DCAEDDE5B6D6E3AED2E6AB
C9E6A4C5E9A3CAF4A8C5F1A2CAF7A6BCE797D0F7A8C1E195CFE79DD3E49DE2ECA7565B18
676A27CACF8CE5F2ACC9DF96CBEDA0C3F09FAFE492BFF6A2B5E591CCF6A4CBEB9FD4EEA4
BFD089E0F0A9D8E9A3D4EBA3CEEEA5B8DE93C8F2A6CEF8ACB9E296CBF1A6C9EAA3D0EFA9
BFE29ECDF0AEC2E0A2C9E7A95A7D3DBFE8A6C9F6B3BBE8A3C6EEA8C6E3A0DBE7A7999D60
2E3200D2DB9CD4E7A5D5ECA8C7DB96E9FDB893A4608B9F5AD5E9A4CEE39EC7E19AD0EBA4
CCECA3BEDE95D5F3AB88A35CCEE59FD8E9A5D9E5A3D4DFA5F6FFD9FBFFEDF9FFFBEDE8EC
FFE9F1DDBEB9E0DEB8CCDBA4D2E8AAE1F5C2F8FFE9F5FCF4F1FFFFF8FFFFFFFEFAEEECD5
CFE3A8CEEDA1CAEA9EC3E598CCEEA1C7EC9CBAE08BCBF19AC9ED96C9ED96CCED9CCFEEA2
CEE9A6CBE3A9CEE2AFD7E4B9D5D5B1342F0F3D381BC9C5AAFFFFE8FFFFE8FDFFE5FDFFE4
FFFFE4FEFFE4F6FCE0FEFFEDFBFFF1FEFFFBFCFBFFF9F9FFF9FFFFF8FFFFF9FFFFFBFFFF
FCFFFFFEFFFFFFFFFAFFFFF6FDFEF0FEFFEFFFFFF1FFFFF4FEFFF8F6FBF7F4F8FBFBFFFF
FBFFF8F9FFF4F8FFF8F8FFFDF8FFFFFBFFFFFFFDFFFFFAFFFFF6FFFFF4FFFFF9FFFFFCF8
F8F9E7F9FFE8C7E0B8BBD0A7A8A98AFFFFE4F4F5D5FEFFE1F9FFDDF7FFD8D3E8AFCFE5A7
899C5CDFF0ACD3E49DD9EEA3CBE399C5E498CBF0A2CDE29DB3A26E5E471BE0E3B6D0E5AD
CDE79EC4E393C9EC9CCBE9ABD5E3C9E7E0D6DDC1B5907B5CD3E09BD1EE9CC2DE94D3EBB1
E5F3D2FBFFECF3FFE2F8FFE3E5F8CBC9E0ACD8F1B7C0DA9D
D6E6A7D1E4A4D5E8A8D2E6A7CCDEA0D4E6A889995BDBE9ABD5E1A3C9D597D5E3A5D6E9A7
C4DF9AC5E9A1BFE99FC9F5A8C6F1A1BCE694C5EC9BC6EB9BC8E799DEF6AACEDB958E9350
635F20DED89ADEDD9DE0E9A6BFD68EC9EFA2BBF0A0BBF09EC3EC9DC9EA9BCCE89BCDE89B
CFE79BD0E69BCFE799CDE89BCBE79CC8E89CC7E99DC7E99FC5E99FC6EAA2C9EAA5CBE8A5
D6EDA7C3DE99B9DE98CAF8B083B671ADDF9AB6DF9BD2F2AFCEE7A3CFE49FCFE09AB4C380
6E7839CDD097CFCD9AE0E5ADCBE29EC7E59DB0C7816D7E3AB9C583D2DD9BD6E5A2D1E5A0
CDE7A0C8E69ECDEDA488A85FD1EBA4C6DA95D9E4A2D5E1A3EAFFC7DAF1C7F7FFEFFFFFF6
FAD1D5E3BCB5C6C8A1D0E5ADD2E5AEE3F0C5F6FEE9FCFFFAFAFFFEEFF6EEE7ECD6DFEAC0
CDE2A1D4EFA2D0EBA4C5E29FCFEFAEB9DC98C6EAA0C2E998CAF299C3EB92C9EF9AC3E599
C8E5ABD5EEC6CEE1CBD2E1CECCD2B8DEE1C6E6E8D2FBFCEAFFFFF4FCFCF2FFFFF6FEFFF5
FFFFF4FFFFF4FFFFF4FFFFF6FFFFFAFFFFFDFFFEFFFFFDFFFFFEFFFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFDFCFFFBFCFFFBFCFFFAFCFFFAFBFFF9FBFFFAFCFFFDFBFFFFFBFFFFFAFFFE
F5FFF4F9FFF6F3FAF2FCFFFFFCFBFFFFFCFFF2E5F6FFF8FFFFF0FFFFF8FFFFF3FAFFFCFB
FFFFF6F4F8E7DBE8CE8A9680F7FDF3FEFFFBF9FAF2FEFFF1FFFFECFFFFE2DAE0B46A733C
929E5CD8EAA0CBE091D1E898D1E99FC1DB94D4EDABD8E3A99D915F594B1CDEE5B1CBDFA2
CFEBA0CEED9DCCE89EC4DEA1C0D9AFF4FFDC816F479C8D54DFF5A0C5E790CBE4A3D4E5BB
E9F7E0F0FDEBF7FFECF1FFE0DEF6C4BCD89DD8F7B4C7E8A1
D1E3A7CDE1A4CAE0A0D0E9A7CBE4A2D4EEA794A964C8DC95D8E8A1DFEFA8DFEEA9B8CC85
CEE9A2DBFDB3C6F0A6B2DC90C8EFA0BFE695C7EE9DC7EE9DC3E696D4F0A3D2E29BA8AD6A
605A1C948C4EFEF8BAD5D796E0F1ADC3E59BBBEA9CC3F4A3C6EB9DCCE89BCCE89BCCE89B
CDE899CCE999CDE897CCE999CEEA9DCCEB9DCCEAA0CBEBA0CBEAA4C9EAA3C8E9A4C9E6A3
D3E7A0D5ECA4C9F5AA7DB368AFEBA3B4E9A3CBF0ADCEE7A5D4E5A1D2E19CD3E79FD3E7A0
CEDD9C494C155F5426E0DDAAD8F1AFCCEEA4CFE9A2CBDC985B6423989E5ED8E3A1D0E19D
D0E7A1CCEAA2BADC92D1F1A83C560FA8B975D2DB9AD6E2A2CCE6A7CDEAB4F3FFE6FBF8E7
F7C9CBFFF4ECDCE1B9CEE6B2D4E4B5E5EFCCF8FCEDFEFFFBFAFCF9EAF0E4DBE4C7D2DFB1
CDE1A2CEE5A1C8E0A2C7E0A7DBF6C1C8E7AED2F5B1C9EFA2C4EC94BFE88CCAF099C9EDA3
D8F6C0EDFFE6EBFFF4F2FFFAFAFFEEFCFFECFCFFEFFCFFF3FEFFF6FAFDF6FCFEF9F3F5F2
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFF
FEFFFDFEFFFDFCFFFDFBFFFDFBFFFCFAFFFCFBFFFEFBFFFFFCFFFFFBFFFFFCFFFFFBFFFD
F9FFF8F4FFEFFCFFF8F4F5F0FAF6F5FFFCFFFFF9FFFFF8FFFFF9FFFFF5FCFFFBFFFFFDFB
F3F0E99A9C8FE5E9DAFCFFF6F3FBFDFBFFFFFFFEFFFFFCFBFFFDF3FFFCE6D1CFA9A7AA75
D7E29EDEF1A2CDE492D6EF9CCFE59CD3E8A5D8E7ACCFD6A0A69F6B59521ECFD8A1D8EEAD
C9E59ABEDD8FD4EBA5D9EEB3CBE8B8D8E9BC625520AFA560D0EB8ECDF199C1D69DD9E7C6
E8F3E5F3FFF3E9F6E2F7FFE6DEF6C4DBF7BCCDECA8B5D78D
E7FBBEDEF4B6C9E2A1D2EDAAC8E3A0D0EBA4A6BD77B2C880D4E59EC1D18AD0DF9AD5E9A2
CBE69FBDDF95B9E198D2FBAFC8ED9FC3E696C9EE9ECAEF9FC0E393CCE89BD5E9A1C6D08B
9A9959666022CDC98ADADC9BD8E7A4CCE7A0C4EDA1BEE99AC8EA9DCAE99DCAE99BCAE99B
CCE999CAE999CCE999CAE999C9E89AC9E89AC9E79DC8E89DC8E7A1C6E59FC4E5A0C5E39D
C9DE99CFEAA3C9F4AC6BA358BFF8B1B9ECA7CCEFADC5DB9BC7D391EEF9B5D1E29BCDE199
E1F0AD8C9459645E2CD8D7A1CFE4A1C2E098D3E8A3D9E8A5ADB876798241CCD896DBEFAA
D0EAA3C7E59DD9FBB1C4E29A869D5795A461C3C989D9E3A4C3DE9BCBE8AEE7FBD6EAE7D4
FBCDCDFFE6E0F2F6D5E0F7C9E5F4CDF1FADDFEFFF6FEFFFDFCFEFDF0F6ECE6EFD4E0ECC4
E9F9C8E4F6C2E1F2C5DCF1C6E2F9CDC4DEAECAE8ACBFE197C9EC98C1E88DCCF099CDEDA2
DEF9C2F4FFE6F4FFF8F7FFFAF9FFEFFBFFECF2FCE4F5FEE9F7FFEDF6FEEFFCFFF8FCFFFB
FEFFFDFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FEFFFDFEFFFDFEFFFDFCFFFDFBFDFCFBFFFEFEFFFFFCFFFFFEFFFFFCFFFFFDFEFFFBFFFC
FBFFF4FBFFEFECF3E1FFFFF3FBFBEFFAF8ECFFFBF3F4EDE7B7AEA9968D88807973ABA79E
CDCAC1D0D0C4FBFDF0FEFFFAF8FDFFFCFFFFFFFEFFFFFCFBFFFBF1FFFFEAADAD87D4DBA7
D4E3A0BED386C7DE8CD1E896C9DD95DDEDACAEB97F838852504D18A6A56FE2EFB7B9D290
D5F4A8D4F0A3BCD18CCCE0A5C2DCAFC5D2A7A89664EEE09FB7CF77D3F6A2E8FCC7C8D2B7
F0F5EEFCFFFBF1F9EAF9FFEADEEFC5CBDFAAC6E0A3DBF5B4
F7FFCFEDFFC7CDE7A6D1EEABC1E09CCDEBA3BFDA93B5CC8492A65E9BAC65CDDE98EDFFBA
C1DB94CDEDA4C3E9A0BDE398CCECA0C4E596C9EC9CCDF0A0C3E696C6E597D5EBA2D7E49E
DADF9D8887476F6E2E9FA160D1DC9AD2E7A2CAEAA1C2E69CC8EA9EC9E99DC9E99DC9EA9B
C9EA9BC9EA99CAE999C9EA99C8E799C6E798C6E69BC6E69BC7E6A0C9E8A2CBEAA6CDEBA5
CCE69FC3E199BEECA4A6DE95ADE6A1BDEEACC6E4A6CEE0A2E9F2B1C1CB86D9E9A07E924A
8D9E585E6829504F17B0B178D7EAA8C8DF99D9EDA8C5D491E3EEACD1DD9B6C7D39D9EEA9
C2DD96C6E69DC7E79EC2DD96DCF0ABB9C4826D6F30D6DF9ECDE7A0CEEEAFCFE6BADDDBC4
FFDAD7A87C79F6F9DCF4FFE4F9FFE8FEFFEFFFFFFBFFFFFFFEFEFEFCFFF6FEFFECFCFFE4
F6FFDFF8FFE1F9FFE8F8FFEAF3FFE4CFE4BBD9F2BBCDEAA7CEED9DC6E790CDED98CDE99F
DCF3BDF2FFE1F2FFEFF6FFF7F8FFF1F8FFECE3F0D4DBE8CCD7E4C8DBE7CFF2FDECF8FFF5
FBFFFFFBFFFFFCFFFFFCFFFFFCFFFFFCFFFFFEFFFDFEFFFBFEFFFDFFFFFFFFFFFDFFFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFDFDFFFDFDFFFEFFFB
ECF3E1E2EBD0CCD2B8D5DBC1F2F6DDD0D4BB7F8169FFFFEAFBFAE5FFFFEDFFFFEFFFFFF3
EFEFE3FFFFF5FFFFF8FFFFFBFCFFFFF8FBFFFEFDFFFFFEFCFFFFF4FFFFEC80845FD9E3AE
DCF0ABD2E99BE4FDAAD8EF9FD5E69FD9E5A57A7F47464914E4E5ACD2D79DC8DC9FCFECA9
D1F0A2CAE699D5E6A2DCEBB4D8EDC4ABB38C7F6A3BC4B478DFF7A3CAED9DDAF0BFFBFFED
F5F6F1FFFEFFFFFFF6FEFFEDEFF9D6CCDCADCCDEAAC3D89F
E4FCBEE0FABBC7E6A3CDEEA9C0E49ECEF0A6D6F6ADC6E298C3D9908E9F5896A761BACE87
DFF6B0C4E29AB9DA93D4F8AECEEDA1C8E497C7E899CCEF9FC8EB9BC6E798CEE89ED5E9A1
DCE7A3BDC2806D6F2E505211C2C888CEDA98CCE09BD4EEA7C9E99EC8EA9DC8EA9DC8EB9B
C8EB9BC8EB9BC9EA99C8EB99CCED9ECAEB9CC8E89DC8E89DCBEAA4D1F0AAD7F6B2DDFAB7
D5F0ABC4E59EC1F3ACAAE39CB8EFACC0EEAECFE9ACDDE8ACB5BA7A9BA05D9BA860344900
42580F889955AAB074E1E7ABCBDA99E0F1ADD4E3A0D2DE9CD1DD9BD9E8A5758A45C1DB94
D0EEA6C4E49BC6E69DDCF6AFC8D995D2DB9A454306DCE19FCCE69CCDEEA9C4DCAAD5D4B8
FFE9E3A37774FDFFEAF4FFECFBFFF1FEFFF6FEFEFEFCFBFFFBFBFDFEFFFAFEFFEDFEFFEA
FAFEEDF8FCEEFCFFF4FBFFF4F8FFEEDAE9C8E1F4C6C9DFA1D3EB9FCBE493D1EA99D1E8A2
E2F4C0F8FFE4F9FFF3F9FFF6F8FFF3F7FFEDE1F0D1D0E0BCC8D8B3D0E0BCF1FFE6F9FFF4
F9FFFFF9FFFFFBFFFFFBFFFFFBFFFFFBFFFFFCFFFAFCFFF8FEFFFBFEFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFDFFFFFEFFFFFEFFFFFFFA
FFFFEDD6DDBCDBE2C0D5DDB8DDE8BE8C976CD1DCB1F2FDD2FEFFDDF0F8D3F7FCDEF9FCE7
FFFFF3F9F9F1FFFEFBF0EEEFFEFFFFF8FBFFFEFEFFFFFFFBFFFFF4FFFFEC6D754ED4E2AD
CFE4A1CCE498CEE796BBD282D0DD97B0B6766C6B337A7943DBE0A6D4E2A5CAE3A2D2F1AB
BBDC8DC8E394E2F1B0C3CD99CCDAB6A6AA87987F56D9C48DCEE394C0E296E4FACCF5FEEB
FDFBFCFFFDFFEEEBE6AEAF9D83886A96A177CFDCAEE0EEBB
C9E3A4CBE8A8C6E5A2C9EDA7C2E7A1CAF0A5D3F5ABC7E59BD4ECA2D9EDA5B6CA83546821
D0E7A1D3EEA7D0EFA9CDEDA4CFEBA0CBE699C7E698CBEC9DCDF0A0C8E99AC7E69ACFE79D
D3E49ECDD894BCC380868B496B7030C5CB8BDBE4A3CFE09CCAE8A0C6EB9EC6EB9EC6EB9D
C6EB9DC6EB9BC8EB9BC8EB99CAED9DC8EB9BC7E79CC6E69BCAEAA1D0EFA9D9F6B3DDFAB7
CBE9A3C2E7A1C3F7AF5E9752C7FEBDB7E1A2D5EAB1C8D09776763AA9AC69909C54D0E598
D6EEA2D7EBA4B6C17FDDE6A7CED997D8E4A2CAD694E7F3B1D8E7A4C0D48F778E48C6E49C
D7F7AEC3E39ADEFCB4CEE59FCEDD9AE0E5A55E5A1DDFE1A0C4DF90CCEEA2CDE6ADD6D6B4
FFF3ECFFD7D6FFFFF3ECFDEBF8FFF5FDFDFBFFFCFFFFFDFFFFFEFFFEFFF9FDFFEDFCFFEC
FFFFFAF9F9F9FEFEFCFEFFFAFCFFF4FAFFEAFBFFDFCDDEA7D6EAA5CDE199D4E8A0D4E7A7
E7F4C6FBFFE6FBFFF2FBFFF6F8FFF2F8FFEDE3F3CFD2E3B9CCDCAFD7E6BDF9FFE8F9FFF3
FBFFFFFBFFFFFBFEFFFBFEFFFCFFFFFCFFFFFCFFF8FCFFF6FEFFFAFEFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFEFFFFFEFFFFFEFFFFFDFEFFFBFCFFFCFDFFFEFFFFFEFFFFFEFFFFFFF8
FFFFECC1C7A5DCE4BDDDE9BB606E3BBCCD96D6EAAFCFE3A8D8E9B3D6E6B7E7F1CCFEFFEA
FEFFF2FEFBF6FFFDFFFFFDFFFEFDFFFEFFFFFFFFFFFFFFFAF7F9ECF8FDE67B875FD2E5AE
D2EBA7CFEA9DC9E291CBE091EEF9B492975796915AE4E1AAD6E0A3DCF1B0C2E19DCAEEA6
CEEF9EC7E293DBE5A6DEE5B248522FC8C7A8A68864C9B27ECADC92D8F9B2D2E9BFF9FFF3
FFFEFFA39DA13E3933777664767B5D959D766F7B4D515D2D
C8E2A3C8E5A5CBEBA8C5E9A3C3EBA4C4EDA1C1E79CC3E599C5E196D5EDA3D4E8A18B9F58
DCF1ACC4DE97BDDB95C7E59DCDE79DD0E89CCBE79ACAE99BCEEFA0C9EC9CC5E599CAE99D
D4EBA3CFE09AE1ECA8E1E8A54446079C9E5FE6E6A8CCD594CCE7A0C6EAA0C6EAA0C6EB9E
C6EB9DC5EC9BC6EB9BC6EB9BC6EB9BC5EA9AC5E79BC5E59AC7E79ECAE8A2CFEAA7CFECA9
C4E39DBEE69FBDF2AC528B46B0E4A4B7DFA3CFE2ABA5AA725A581DD7D696DEEAA2BFD487
DBF3A7C4DC92E5F4AFDFEAA8ECF5B4CFD897D3DE9CDAE6A4BCCD89E3FAB4445F18D3F3AA
BEE096CAEAA1C4DF98CADF9AD0DC9ADFE4A45A5619D6D996C6E190CDF0A0D0EAABDADBB3
FFF4E8FFDEDDFFFFF6F1FFF7FAFFFFFFFEFFFFFDFFFFFDFFFFFEFFFFFFFAFDFFEFFAFCEE
FFFEFFFFFAFFFFFDFFF9F8F6F9FAF2FAFDEAFEFFE3D3DCADD8E3A9CFDB9DD6E1A5D7E1AD
E8F0C9FEFFECF9FCF1F7FDF3FBFFF3F9FFECE4F2CED6E6B9D4E2B1DCE9BBF2FEDAF0F9E4
FCFFFFFCFEFFFCFDFFFCFDFFFEFEFFFEFFFFFEFFF6FEFFF3FEFFF8FEFFFBFFFFFBFFFFFB
FFFFFDFFFFFDFFFEFFFFFDFFFFFDFFFFFAFCFFF9FBFFFCFCFFFDFDFFFDFDFFFCF9FAF7EE
F6F6DEE3E7C6D6DEB58E9C6BD1E3A9B1C787D9F2AECDE8A5C3DB9DD6EBB3D9E8BFFCFFEA
EDEFE2FFFEFDFCF2FDFDF5FFFEFEFEFEFFFBFBFCF6FFFFF8F9FBEDF8FFE69AA982BDD19C
C5E09DCFEBA0CAE596D1E699E5F1A95A5A1A9D945DDED9A2D0DC9CC5E09BCFF3ADC6ECA1
BADD8BD6EEA0CBD4954F5120E4E9C9FFFBDEAA8767EDD3A2DFEFA8D2F2AFDCF2CCF9FFF4
FFFFFD7B7575343226CFD1BBEEF4D2FEFFDDF5FFD1FBFFD6
D2EAACCBE5A6CEEDAABFE39DC4ECA5C6F0A4BDE69ACCF1A4C8E79BC7E197D0E69EB3C780
A0B570CAE19BD9F2AECCE7A0CCE49AD3EB9FCEE99CC9E89ACDEE9FCAED9DC5E79ACCECA0
C9E59BD9EFA7C9D893DAE3A08385465F5D20DED89CE3E5A6CFE6A2C8E9A2C8E9A2C6EAA0
C6EB9EC5EC9DC5EC9DC5EC9BC9EE9EC9EEA0CAECA0C9EB9FCAE8A0C8E69EC9E49FC6E49E
CFF0A9C2ECA4BBF0AA97D08C89BD7DCAF1B8CDDEA89699649D9860DDDC9CDFEBA3D2E79A
C8E396D7F2A5CEE29ACBD893C8CE8EE5EBABBDC68592A15EB9CD889FB972CCEAA2C3E39A
CDEDA4C7E59DD2ECA5D9EAA6D7E2A0ADB2726E6A2DD4D996CDE995CBEE9AC3DE99D9DBAC
FFF4E4AE8281F2F1ECF5FFFFFBFFFFFFFDFFFFFAFFFFF9FFFFFDFEFFFFFAFFFFF3FFFFF4
FFFDFFFFFCFFFFF8FFD4D0D1AFACA59D9E8EACAF92797D58CFD5A7C8CF9CD2D8A8D6DDB4
ECF1D3FFFFF1FFFFFAFFFFFADFE3D2E2EBD0D3DDB8D4E0B2E3EDBBF4FDCEFEFFE1FEFFED
FFFFFDFFFDFFFFFCFFFFFCFFFFFDFFFFFEFFFFFFF4FFFFF3FFFFF8FEFFFAFFFFFBFFFFFB
FFFFFDFFFEFDFFFDFFFFFDFFFFFCFFFFFCFDFFFAF8FFFDFBFFFEFAFFFFF8F7F4EDEBE9DC
EBEBD3A3A78698A077B5C392D4E8ADD7F0AFC1DC97CFEDA7D5EFB0C9E0A8E2F3C9FBFFEA
FFFFF6FEF9FDFEF3FFFFFBFFFFFFFBFEFFF6F0F2E5FFFFF3FEFFEFFCFFE8AEBF959CB37D
AAC483C9E59BCFEA9DCFE497DBE59E535313CABF89E3DEA6D5E4A3CEECA4C7EDA4C0E99D
C5E89691A95B8D9657A6A575D8DBBEF1EAD0967252C1A576E0EFAABEDE9DE4F9D8F8FFF4
F5F6F07D7D75686B58D6DCC0DBE6BECCDAA9D3E4AECDE0A8
C8DEA0CEE6A8CBE8A6C4E8A2C4ECA5C3EDA1C0E99DC3E89BC5E599CCE69CCAE098CADE97
8FA35EDDF2ADC1D894CAE49DCFE79DCFE79BCDE89BCCE89BCAE99BC8EB9BC8EA9DC8EA9D
D3F3A8BFD990D6EAA3D8E5A0949959626023EEE4A9D7D598D7ECA9CCEBA5BEDD97D1F3A9
C3E89BCAEFA1C1E899C5EC9DC8EFA0C6EB9DC5E79BC7E99DCDEBA3CEECA4CEE9A4CBE6A1
BFE099C7F1A7BDF2AAA9E29D538749ABD299CCDEAA9DA16E9F9D64D9D99BD1DE96D5EC9E
CAE797C6E295D5EBA29AA964939959B8BD7D9FAA68909F5CC4DB95DBF6AFC4E49BC5E59C
C9E9A0BFDA93D4E9A4DCEBA8DBE4A3959A5A68682ACED893C6E391C3E692D4F0A6DCDEAC
FFEDD9EBBFBCFFFFFDF4FFFFFAFCFFFFFCFFFFF9FFF4EDF5FFFDFDFDFAF3FFFEF2FFFFF6
FFFDFFFFF8FDEBE2E5D1CCC9DCD7D1FFFCEDFFFFEAFFFFE2FFFFE1979974A9AA88D5D8BB
E4E5D3FCFCF2F6F6F4FFFFFAF7F8E6EDF0D3E7EBC6D6DCB0EEF4C4FFFFD8F7F8D6FFFFEC
FFFEFBFFFCFFFBF2FFFFFAFFFFF7FFFFFCFDF9F2E8FFFFF3FFFFF8F7FAF3F8F9F4FFFFFB
FFFEFDF8F2F2FFFDFDFFFAFBFFFCFDFFF6F5FFF9F6FFFEF6F2EEE3FFFDF0F7F8E8E1E2D0
FBFDE5FAFFE1DBE3BECFDCB0CFE3AEC8E1A7CDEAAACBE9A9D1EDB3BED6A4E9FBD5F9FFEC
F8FBF2F7F5F8FFF9FFFFFCFFFFFFF6F9FFEAFEFFEFFAFFE9FEFFECF8FFE29BAA7F435722
96AF6EBDD98FD8F3A6D4E99CC9D38C646424CBC28BE5E3AAD2E39FC1E198C0E89FCEF7A9
9ABD69BAD284C3CC8DFFFECEF2F5D8FFFBE2825B3ECDAE82D6E2A0D5F3B3CFE2C2F8FFF4
FCFFF4ABAF9E8C957ADFEBC5CEE0AECBE0A7DCF4B6C1DB9A
E0EFB4CEE2A5D4EEADD5F6B1BCE49DBBE599CAF4A8CAF0A3CDEDA1CBE79CE1F7AFD1E59E
A8BC77C1D590DCF1AED1E8A2CDE79DCDE89BCDE89BCCE89BCAE99BC9EA9BC8EA9DC8EA9D
CAECA0CBE99FD0EAA1CBDC96949A5A565417C0B67BE9E4AAB8C889D8F3B0CDEAA7B6D58F
D7F9AFC1E699C6EB9EC7EE9FC6ED9EC9F0A1CEF0A4C9EB9FC5E39BC3E199CBE4A0CFEAA5
D3F3AAD1F9B09CD086D1FFC5477B3B7AA369D5E9B48B925E9E9D65E3E5A6DEEEA7CAE294
B5D484EAFFB9C9DF965D6C275F6827B3B979D8E4A2D0E49FD2ECA5C6E49CC0E097D7F7AE
D2EDA6DFF6B0C8DC97D1DD9BE2EDAB939959727838E1EEA8DCFBABBAE08BC1DD92E0E3AA
FFF6DCE7BCB5FFFFFDF5FFFFF3F5FFFFFCFFF6EEFBFFFDFFFBF6F3FFFEF8FFFEF8FFFEF8
FFFDFDD5CCCDC5BDBBEEE6E3FFFEF6FFFFF3FDFAE9FCFAE5FFFFEAEFEDD49C9C84ABAA96
ECEDDFFFFFF8FFFFFBF0F2E7FFFFECFCFDDDECEEC7D8DBB0EAEDC2FFFFDCFFFFE1FBF9E4
FFFCF6FBF5F7FFFBFFFDF3FEFFF6FCFFFCFBFFF6EFFFFFF4EEEEE6FEFFFAFFFFFBF3F2EE
FFFEFDFFFDFDFCF3F4FFFDFBFDF3F2F5EEE8A69F97BDB9ADFFFEECD5D8C3A3A98FFEFFEA
FAFEE5FEFFE7E2ECCAD7E3BDD3E4B8C8DEADCBE3AFC7E2ADCCE4B4C8DDB2E2F1D0F5FFE7
F8FBF0FFFFFDFFFDFFFFFCFBEDF2DCFCFFE6E4EBCC737A5BB4B99BA6AD8B909D7190A36C
ACC282D1EBA4C3DB8FCEE398E4EFAA4E500FBAB57DD9D89FCADB97DBF9AFC0E69DBAE395
739944C8E392E7F0AFF5F7C6F7FCDCFFFFE6947050C3A476C5D18FC0DE9EE1F4D4F3FFEE
E0ECD6F2FFE5CEDCB9BFD2A4CDE5ABD4EFACC8E6A0C8E89D
CFD89FC2D095E5F9BAF2FFCCCDF2ACBDE79BC8F2A6BCE295C5E599C1DD92D2E8A0CBDF98
96A763859954D8EBA9C3DA94CCE89DCAE99BCDE89BCDE89BCCE89BCCE89BC9E99DC8EA9D
B7DC8FD0F2A6CDEBA1D5EBA3BDC886787A3B948E52E6E1A7F2FDC1C4D899DEF4B3C4DF9A
CDEBA3CCECA1BFE497C8EDA0BEE596BFE697C5E79BC8EA9ECCEAA2CAE8A0C9E29EC5E099
C2DE94B6DB8EC6F9AEC2FAB3B0E7A693BF84D8F1BA9AA46F83864DE2E8AACCDD97D3EEA1
D1F0A2A0BC6F6D8139D8E7A2CCD795DAE5A3D2E39FC7DE98CBE9A1CCECA3C4E49BC6E49C
BAD18BDBEFAAB5C48189955395A05EBCC886DEEAA8D4EAA2BFE091D0F6A3D3EFA2DFE3A6
FFF7D851271BFDF9F6F6FFFFFEFDFFFFFCFFFFFCFFF9F0F1FFFAF4FFFEF6FFFDFAC5C0BD
CCC7C3DED9D5FAF5EFFFFEF8FFFEF6FCF5EBFFF9EFFFFFF3F6F2E6FFFFF19795868A887B
FFFFF2F9FBEEE4E6DB858875ACAF90AEB089A0A07AA1A17BC0C09CF5F4D5FFFFE8FFFFED
FFFFF3FFFEF8FFF5F4FFFBFCFCF2F1928886C5BCB7ADA9A0B6B5B0949790FFFFFBFDFCF8
F7F3F2F8F2F2FFFDFBFCF2F1E9E2DCACA59DB3B1A2CED0BB989C83A1AA8BD2DEBADEE9C7
EAF3D6FAFFE8EDF6D9E9F4D4E7F6D5DEEFCBE2F7D0E0F5CEE2F3CFE7F6D5EDFADEFBFFED
F7FBECFFFFF4D6D6CEC8CBBAD6E2BE97A4789FAA82C6CCA6DDE1BCE2E7BFDDE6B9D6E3AE
CADC9EE5FAB5DAF0A7D6EBA0626F29586120E0E1A7CFD398CFDE9BD9F3AABEE29ACEF7A9
96BC67D0EB9AE3EFADE8EFBCEFF9D7FEF9DC7C5A37CFB383EEFBB6D2EFADE6F7D5F9FFEF
F8FFECE8F9D7ECFED4DFF8C1C8E5A3BCDC91C6E89BD0F3A1
E4E7B0E9F1B8FBFFCDF1FFC8C8E9A4BAE397C5EEA2C5EB9ED3F3A7D5F1A6C9DF97DDF1AA
899A5672833FDBEBAAD1E6A1CAE99DC9EA9BCCE89BCDE89BCFE79BCDE89BCCE89DC9E99D
CFF4A7D4F9ACBCDE92C7E399C9DA96A3A969888649CFCD92CDD59ACCDA9FD3E5A7DFF5B4
C4DD99CEECA4C3E599C6EB9EC8ED9FC8ED9FC8EDA0CBEDA1CCECA3CDEBA3D0E9A5CFE9A2
D3EEA1D2F2A6BEEEA2A6DE95ACE3A0A6D398BAD79F93A16C9EA66DDCE6A7CEE29BD9F5AA
BAD98D7A964B7F904AD3E09BE0ECAAD5E6A2CFE6A0CFEAA3CCECA3CCEEA4CDEDA4CBE69F
D6EAA5CAD996A6B16FACB775D8E4A2D8E9A5C6DB96CCE7A0BEE094CCF1A3C3E294D1D696
FFF8D3633929FFFFF8F3FEFFF0EFFDFEF8FFFFFDFFFFFAF4FFFEF4FBF4ECB5ADAB999393
DDDAD5FCFCF4FFFFF8FEF9F3FBF6F0FFFEF8FFFDFAF8F3EFFCF7F3FFFFF8D0CDC4A4A597
FFFFEFE4E9D39EA38C747B5A959C72989E708C8E679798769F9F83B6B5A0D4D1BEB3B09F
A19E8DB0AD9CB3AD9FE6E0D4F0E9DF7D766EC7BFBCA9A4A09C9D97858680DBDAD6C6C2BF
FFFDFDFCF4F2FFFCFBFFFCFAB3ACA4FFFDF1FFFFEDFEFFE8EDF7D4DCEBC2CFE0B3DFF0C4
D9E7C6F6FFE5F6FFE5F9FFEAF9FFEDF5FFE9F9FFEDF9FFEDF8FFECF3FDE5EEF8E0FCFFEC
FEFFECF4F8DFABAF96ABB290CEDEADCDE0A8C0CC9AD3DBACD3D6ABE4E5BBCED1A2D5DEA9
DDEBADB0C17DD0E49CC9DE93283900707C3ADBE3A7DCE4A8D9E5A3CCE29AC5E49EBAE093
CBF19CCFEC9ACBDA97DAE4AFCBD9B5FFFFE37D5F3BB49A67CBD890C8E5A2D9E7C4FBFFED
F7FFE9F2FFDFEBFFD3BBD49BD3F0ADD1F1A5BDE08ECAF09B
95925DD0D39CE6F1B5D2E7A6C8E7A3C5E99FC0E99DCAF0A3C8E89CCBE79CC0D68ED4E8A1
90A15D687734CCDB9ACEE39EC9E99DC6EB9BCAE99BCDE89BD0E69BCFE79BCDE79DCAE99D
C1E699C6EC9FC3E99CD9F9AECDE49EA9B573585D1D595A1E3E410ADCE4ABCCD79DD3E3A5
D6EDA9C5E099CBEBA0C8EA9EC5EA9CC9EEA0CAEFA2C5E79BBDDD94BDDB93CAE39FD7EEA6
C8DD90CFEC9CB9E598CFFFBABEF7B388BA7BC4E5AE657A4259662EC2D092C7DE98C7E59B
C8E69C9BB56CD3E29DD1DC9ACADB97C2D993CDE8A1D5F5ACC6EAA0C1E59BCBE9A1D1E8A2
D3E29F55601E8C9554E3EEACD3E4A0CEE59FCDEDA4C9EDA3D2F8AFBDE197C4E395D2D995
FFDDB3EDC4AEF4F1E8F7FFFFFEFEFFFFFCFFFFFDFBFFF9F01F170AE2D9D0FEF4F5FFFBFF
FFFFFBFEFFF9F6F5F0FCFBF7FFFEFBFFFDFDFFFBFDFBF5F9FFFDFFF7F3F2E7E7DF9FA291
BBC1A7A5AF8CA3B084D3E1AED2DFA7DAE7B1E1E9C0F9FFE1EFF4E0DEE2D4E3E5D8C0C3B2
9B9F88A9AE90E2E5C6E5E8CDFFFFECFFFFF4FFFFFBFDFBFCFFFFFBFFFFFBFFFFFBC2BEBB
D9D4D1F0E8E6FFFCFAE3DAD3D0CABEFBFAE6FFFFE8F0FAD7E7F8CCD2E9B5C1DAA0C1DAA3
D2E4BCF5FFE5F9FFECFBFFEFFCFFF3F8FEF2FEFFF8FBFEF5FEFFF6FEFFF3FCFFEDF4FADE
ABB2909BA37A939F71DAE9B2C7DD9CCEE5A1E5F5B7D7E0A9E4E3B3D9D7A7E9E7B6D2D59E
D4DCA0EBF8B3D9EAA3566B205A6E2798AC67DAE8AADCE8AAD9E4A2D7E6A1CDE8A35A7C30
C0E68FCEEE99CDE19ACFDEA7C5D7AFE9EFCB846841CCB57FE4F2A7CCE7A0E3EFC9E8F0D8
A1AE92B4C5A1E0F3C6C2D9A1CAE7A4D2F2A6CAED99C6EA93
332C009B9863CAD297C6D697D4EFACD2F4AABCE297C1E79ACDEDA1CDE99EDDF3ABD7EBA4
CDDC998C9B58CFDE9DDAEFAAC6EB9DC5EC9BC9EA9BCDE89BD0E69BD1E69BCFE79DCCE89D
CBEDA1C2E89BBBE496CAEFA2C7E29BDDF1ACD4DD9CDBDFA264642E949762D1D9A0C7D296
DAEDADD1E8A4C2E098CCECA1C1E397BFE496C1E699CBEDA1D3F3AAD5F3ABD0EBA6CCE39B
DCEFA0C9E291C2ED9EA7DD91C3FCB781B575BFE5ACB8D19A485C21D8ECADD7F2ADCBE99F
D7F5AB7D944EC6D18FE0EBA9E8FDB8CDE8A1BFE197C1E59BC0E69BC3E79DCAE8A0CBE09B
CEDA98A7AD6DD2D898D5E09EC6DA95D5F0A9BEE499C3EDA3C4ECA6C5E9A3DAF9ABD6DD99
EFCA9EF6CEB4EFEDE0F7FFFFFCFCFFFFFDFFF5EEE60E0600FFFFEFF2E9E0FFFBFFFFFCFF
FFFFFFFCFEF9FEFFFDFFFFFFFFFDFFF3EEF4FBF3FEFFFCFFF8F3FAFFFEFFFFFFF8FEFFED
FAFFE1CCDAA7D4E6A8D1E5A0C6DA95CDDFA1DEEDC2F9FFEAFBFFF6FBFFFBFBFFFAFCFFF3
D0D9BCD7E2BAE0EBC0DFE7C0F6FCE0FEFFF3F5F7F6F6F7FBFFFFFDFFFFFBFAF6F3FFFBF8
BFB7B5E2DAD7F1E8E3BBB4AAFFFFF1FFFFECF4FBDACAD9AEC8DCA9C6E2A5D2F1AED1EFB1
CCE3B5F3FFE0F8FFEAFBFFF1FEFFF6FBFCF7FFFEFFFEF9FDFBF7F6FFFFF8FFFFEFF4F9D9
B3BC8FAEBB83ADBD7CD3E9A0D1EC9DDCF7AAC8D993D1D99DE4E3ADDED8A6DBD5A3E8E5AE
D5D99CCDD6934F5F18495D15DCF2AAD0E7A1CADF9ECFDFA0DBE1A1DDE6A3BDD4903B5B10
BCE28BCAEC96D3EAA2D2E6ABD7EEC4CBD5B0AD966CDEC990D6E799BAD48BEDF8D0C5CBB1
5F69507E8D6CE2F3C9EDFFCCBAD391BFDE92DDFEADC6E892
5D511FAFA874D7DAA1CCDA9CC9E2A0CAEAA1C4E89EC9EEA1BFDF93C2DE93D5EBA3C5D992
DBEAA7A7B673AAB978CCE39DC5EC9DC2ED9BC8EB9BCDE89BD1E69BD3E59BD0E69DCDE79D
CAECA0C8F1A3C0EB9CC6EFA1C1E198CDE49ED6E5A2DBE1A3EAE9B3555320A8AB74D9E1A6
D3E1A3D5EAA7C6E19AC7E79CCDEFA3C8EDA0C4E99CC5E79BC7E79ECAE8A0CDE8A1CFE79D
CBDC8CD6EC9AC1EA9BBAEFA1B8F1AAB7EEAD6E955CB1CE96637B41C0D696C9E7A1C6E69D
B9D78F96AB66E6EFB0D1DB9CC6DD97C7E79ECCF0A6CEF4A9C8F1A5C6EAA0CFEAA3DBEFAA
99A2619FA464DBE0A0E8F1B0C9DE99CAEAA1C1EDA0B8E69BBDE6A4C7EAA6C9E89CCDD48E
FFECBFD5AE91FFFFF1F7FFFDFEFFFFEFE9EB888276F2EBD9FFFBEAFFFDF3F7ECF2FFFBFF
FBFCFFFCFFFFFCFDFFFAF9FEFFFDFFFFFDFFFFFBFFFBF4FFFFFCFFFFFEFFF2F4E9F4FAE0
ECF9CBCDE0A0E0F7A7C9E28ED7F09FD5EEAADAF0C2D8EAD0E6F3ECF2FEFEF0FDF6F8FFF4
E1F1CDEAFCCCBACD96D6E6B5F9FFE4EEFAE6F9FFFFFBFFFFF6F8F7FFFFFBFBF7F4FFFEFB
F5EDEBD5CDCA928B85B0A99FF8F5E4FFFFEAFCFFE3D7E8BBCAE3A9C9E8A5D3F7AFBDE09C
C9E4B1F0FFDEF7FFE7FAFFF0FEFFFAFFFEFFFFFCFFFFFBFFFFFBFFC0B8B5979481969A77
A8B27DD5E49FD6EC9ACEE88FC0E188D4F19DD3E59BDCE5A477763DA39C689E94614B440D
49490BA8AF6C84914BAEC27ACFE69ECAE39FD1ECA9D4E7A7DBE0A0DBE09E9CB16E85A55A
D0F69FC3E790CFE99FD1E9ABC7E2B5CFDBB39C875AC6B378D2E393DFF9AF929A710C0E00
696E57E4EFD1F3FFD9C5D7A5C6DC9CD7F1A8CDE99CC8E895
5E521E9C955ED9DAA0E0ECACCDE4A0CAE8A0CDEFA3C7E99DC9E99DD4F0A5CEE59DCCE099
D9E8A3CCDB9894A05ED3E9A1C6EB9BC2EE99C8EB99CAE999CFE799CFE799CFE79DCCE89E
C5E59CCDF1A7C0E69BC9EFA4CFF1A7C7E399CFE79DD4E3A0E9ECB371703A57581FEBEEB5
DCE4A8C4D090EBFBBAC5D994D0E5A0D5ECA6C5DF9896B06969803A687F399BB26ED1E59E
DAE49BDFEDA2C9E39AC4E8A2C9F2B0C3E9ACA9C88F91AC75829A60DAF4B5C2E19DC6E59F
D6F0A990A15D989C5FD8DEA0D0E7A1CCECA1C1E699BFE497C7EC9FCAECA0CAE69CD2E69F
97A361DAE3A2DAE3A2CBD795D4EBA5CAECA2BFEB9EC6F4A9C5EDA7C7EBA5D2EEA1D2DC95
EBD19EA98B67DBD9C2EEF4E8FDF9F8FFFCFD7B7269FFFDF1F2EADDFFFDF4FFFCFFFCF9FF
FBFEFFF9FFFFFCFFFFFEFFFFFFFDFFFFFCFFFFFAFFFDF9FFFAF7FFFEFFFFFCFFF8FBFFEC
E9F9CCCEE0A2CCE395D6ED9BC2DD8ECBE4A0D7EEB8CAE0BAE4F6E6F4FFFDECFCF2F5FFF1
F7FFDDF7FFD3E0F4B7C4D6A2F9FFE6FBFFF4EFF5F5FCFFFFFFFFFFE8E7E3FFFFFBFFFBF8
FFFDFDFFFEFBF8F3EDFFFFF4FFFFEFFFFFE8F3FFD9CADCACD3EDB0BFDE9AC2E79AC9EDA5
CDEAB0F2FFDAF5FFE1F7FFE4FEFFEFFFFCF3FFFDFAFFF9F6CCC8BFA2A391C1C6A8DEEABC
D7E5AACEDE97D3E192D9EB97D2E893ABC16F5E6C21555C187A7B3F9A9960A9A86F909157
B4BD7CD4E19CD4E8A0C9E098D6F1AAC2DD98CDE8A5D0E5A4D0D998E1EAA7879C57C7E69A
CEF19DC4E692D5EFA5C5DD9FC5E1B0E4EFC57E623ABFA572717D35556F28223203A5B18D
E9F9D5F7FFE1D9EFC0D4EBB3CDE7A6C7E59DC2E296C9EA9B
5854179F9F5FDBE09EDDEAA5CBDF98CAE49BCDECA0CAEA9ED0F0A4C0DF93CFE99FD2E69E
DAEAA3DAE7A2949D5AD4E49DCAE999CBF19CC9EF98C2E891C3E992CBEE9ACAED9DC3E398
C7E4A1CCE9A7C8E5A3C5E4A0CAEAA1C8EA9DC3E994CEED9DD8E4A2BBBC807C7D41A4A468
9E9C61E4E2A7DCD79DE3DEA4D6D499E1E1A59E9F6354581B3F4507293200505A1DBFC889
E0E1A5E2E2A6EAEBB1D2D59ED4D9A3DAE1AED6E0AC85935E556D33D1EDB0CAE9A6BCD794
D3E6A4A2AB6A717030E2E2A2CFE59CCEEDA1CEEDA1CAE99DCAE99DCFEBA0CCE69CC5DD93
94AA62CCE099C9DF97CFE69EC8E49ACCEEA2C5EB9EC7EDA0C9EEA0C3E495DAF2A4D2DF97
D8D6995D5322BDB795EAE2CFFFFAF3FFF7F7C9B9BAF4E8E8FFFDFAFFFFFAFFFFFAFAFFFB
F4FEFFF7FFFFF6FBFFFEFFFFFFFCFFFFFDFFFFFCFFF9F6FFFEFFFFFAFFFFF9FFFAF7FFF0
E4F2CFD8E8B9D7E6ADCFDFA0D1E6A5D1E8A4CFE6A0CEE6AADDF3CDF2FFEDF4FFF1F0FFE3
E2F7BEE1F6B3D3E5A9CFDAAFFEFFF1FFFFFBFDFCF8FFFFFBFFFFFDFFFFFDFFFFFDFFFFFD
FFFEFFFFFEFDFFFEFBFFFFF8FDFFEFFEFFEAFBFFE3C9DBABD4E9AED1ECA9C7E59BC8E89D
C5E8A6D8F7BBDCF0BBEEF7C8F4F5CBECEAC3F0F0CAA6AB838C9C6FE9FFCED5F0B9D0E9AF
D6E8ACD6E2A4D4D599E6E5A5AFAE6B8788425F621D7E8541C7D28ED9E8A5CADD9BD1EAA6
CFEDA7CBEBA2C2E299CAEAA1D1EFA9CBE6A1CCE5A1CFE6A2CFE49FD8EFA7839F54CFEEA0
CAE999C4E191D0E79FD1E7A7C4DBA5ECEFC47D5436D1A98604070066804383A267DBFEC4
DAFEC1DBFFC1CAF1AEC1E9A3C8F0A9BAE299C8F2A6C3EDA1
3A3D00878C49CCD691DCE9A3CFE39BCCE69CCFEBA0C8E89CC8E89CC1E094D7F1A7D8EEA5
D9E9A2CAD590757C3897A35BCBE395C8EA96C7EB94C2EA92C0EB92C5EC99C6EB9EC6E5A1
CFE7ABE2F7BFDFF2BBCEE3AAC9E3A4C8E9A2C0EA98C6E999CDE19ADDE6A5BBC080A4A667
514F125E581C5E551C756A32847941635A217E7740BCBA81E2E3A9E1E7AB9DA569383E02
77783ECDC8913127006F6331675B2B574F20686A38798650536B3192B072C9E7A7CBE5A4
E1F4B2C3CC8BA29E5FE1E2A0CDE297C8E799CAE699C8E497C8E396CCE79AD2EAA0D3EBA1
89A359D7F1A7DDF9AFD2F0A6C2E096CCEEA2C9EB9FC3E598CAE999C7E291BED585E0F0A7
DEE7A654541EBDB58EFFFAE0FFF9EDF6E4E2FFF6F9FFFAFEF7F1F3FAF9F7FEFFFAF2F9F2
F7FFFFEAF5F7FBFFFFEDEEF0F1ECF0FFFAFEFFFDFFFFFEFFFBFFFFF5FEFBF8FFFAF0FEED
DBE9CFD1DFBBD5E0B5D3DFAFCEDFABD1E5AAD3E8A3D5EBABE2F7CCF4FFECF4FFEFF5FFE6
D3E9ABD5EAA5D8E7AED7E1BCFFFFF6FFFEFFFFFEFBFFFEFAFFFEFDFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFDFFFFFAFBFFF0FCFFECFBFFE4CBDCAFD0E5ACCCE5A3C6E298C8E89D
C7EBA5CCECABD9EFB1B5C086ACAF78C8C892979C64D3E1A6D6ECAEB9D797CDEDACD1EFAF
CADEA1DAE3AAA19E69615A238E884A8F8C49D3D693F9FFBECBDC96BED58DD3F1A9C5E9A1
C0E69DC0E69DD8FCB4C8E9A2BEDC96D0EAA3CDE29FCEE59F6783398CAA60DAFAAEB7D889
D0EC9FD4EEA4D3EAA4C6DA9BDAEFB7CAC79E96644DDDAB94EBE8BFC6DFA8C1E5A7BEE9A2
BAE498C5EEA0D9FFB4B0D98BCFF5A8D5FBAEB3D98CC6EC9F
4C510E8F9652CCD792D8E9A2CFE59CCCE89DCCEB9FC6E89BCBEDA0C5E599D2EEA3CEE49B
D1E19ACDD89387914C929D58CFE59AC9E89ACAEB9ACBEE9CC6EB9BC5E79BCAE7A4D2EAB0
D8E8B9F2FFD4F0FBD3D7E4B9CEE0B0CFE8AFCBE9ABC7E6A3C8DD9AD5E5A4CEDA9AC9D293
A5AB6DA7A86C89894D6E6C31817F44808044CACB8FF0F6B8CFD899D9E5A5CEDD9C768544
848A4C78793F48460D938E57AEA87493915E5B622E2E3D065A73394F6F30ADD08EC5E4A1
D8EEADD5E1A1CACC8DCBD08ED3E9A0CEEA9DCEEA9FCEEA9FCCE69CCCE49AD0E89ED6EEA4
829A50C6E096CBE79DC9E79DC0DE94CBEDA1CBEDA1CCECA0D6F1A4D0E799DDEFA3DAE7A1
D9DF9F80804AA09B71F3EACDFFFDEDB7AAA4FFFBFBFFFBFFFFFDFFFFFDFEFFFFFBFCFFFB
F1FCF8F8FFFFFBFFFFFFFFFDFFFDFDFFFEFBFFFEFDFDFCFAFCFFFFF9FFFDF7FFFAF7FFF4
EAF9E2E2F1D2EAF6D2EDF9D3E9F7D3E4F5CBD7E9B5CBDFAED1E1C4E3F4E1F2FFF3F5FFEC
C9DDA8CFE3A4E2F3BFE8F2D0FFFFFAFDFBFFFFFEFFFFFCFDFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFBFEFFF4FBFFEDF9FFE4D1E2B5D1E9AFCBE6A3C7E59BCDEDA2
C1E09CD5F2B0A2B677687639CAD498D3DBA0D4DEA2D2E2A4DAEEAFC5DE9DD8F2B1C0D998
CFE1A3B2BD815B5E255F6026B0B573DDE7A2DAE7A1C5D68FD5EBA3D6F0A7C5E399CBEDA3
C2E49AD5F7ADBBD991C9E49DD7EEA8C8DE96D0E19DBACE875F7930BBD98FBCDC90DDFDB1
B9D58BCDE7A0CBE1A1DBEEB6D1E3B3EDE7C3B07B69BE8977EBE3BEDCF0BBC4E3A7C3E7A1
D3F2A4C3DE8DB9D483DAF5A4C7E08FC5DE8DDBF2A2D0E797
96A05BBBC681D7E7A0D5E9A1C9E399C9E89CCAEC9FC7E99CCFF1A4C8E89CCDE99EC4DC92
D0E19ADEEBA5B9C37EAEB974D6EAA2CEE89ECBEA9ECCECA0C8E89FC4E19ECEE6ACDFF1C1
E8F2CFFCFFE5F9FBE3E9EDD4E5EECFE4F4CFDFF4C9DEF6C2D7EFB1D5ECA8D5EAA9D4E4A3
D1E09FDDE7A8DFE8A9D3D99BE1E7A9D9E2A3D7E1A2CAD996C5D692D5EAA5D0E7A1ACC17C
727E3C4E5416E8ECAFE6E7ADD7D89FD8DDA5D3E0A8B7CC918BA96B5F824296BB78BFE2A0
C6E09FCDE0A0D1DB9CA6B16FD3E9A0CCE89DCDE99ED3EDA3D5EDA3CEE69CCCE49AD0E89E
BBD389D7F1A7C9E39AD4F2A8D1EFA5CAEA9FC1E397CEECA2CDE19AD6E39DE1ECA7C9D38E
D7DD9D898C53D1CEA18C8865DBD5BF948C81F4ECE9FFFDFFFFFBFFFFFEFFFFFEFFFEFFFD
F4FEF6F9FFFBAFB4ADF0EFEAFFFEF8F7F0EAFFFEFAFDFCF7FBFFF9ECF6EDF0FEF1F5FFF4
F3FFEFEFFFE5F5FFE6F7FFE8FBFFEDF7FFEAE6F4D1D4E3C2D2DFCEDEEBE1EFFCF2F7FFEF
CCE0AFD3E6AEF4FFD5FAFFE5FEFFFBFAF9FFFFFEFFFCFAFFFFFEFFFFFEFFFFFDFFFFFDFF
FFFDFFFFFEFFFFFFFFFEFFFBFCFFF6F1FBE3F1FFDDD0E3B5D1EAB0CBE8A5C9E99ECDEDA2
CFEAA5D9EFAE809455D0E3A3E2F2B4C4D294D1E1A3E5F5B6C6D89ACEE3A2D8ECADCFE2A2
89975A3D490B98A266DBE5A6D9EAA4CADE96CBE198D5EDA3D0EAA1C5E197C7E59BD1EFA5
CEECA2BFDB91E5FCB4C6DC948A9E5770813A707D38A8B973CEE89FC6E49AD4F4A9C1E196
CBE9A3D4EDACC0D59CD6E8B853643A645D40CF998DEBB3A6F6ECC9DFF1BFBBD79CCEEDAA
CAE19BD4E8A0DDF1AAC3D78FE4F5AFD1E29BCAD994D2E29B
D0E099D9EAA3D8EEA5CCE69CC5E498C9EB9EC9EEA0C5EA9CC6EB9DC6E89BCEEDA1CCE49A
D9EAA3E2EFA9CBD590A0AB66D5E9A2CCE39BC8E299CAE59EC9E4A1C9E3A6DAECBCEEFAD6
FFFFECFFFFF3FFF9F1FFFAF4FFFFF4FDFFF2F6FFEAF7FFE4DFFBC1CCEBA7CDEAA8CBE6A3
C8DE9DC5D898D6E6A5DBEBAACDDE9ADCEDA9D5E9A4CBE29AD0ECA2CEECA2C6E69BCCEAA0
D0E49DCEDB96D6E19FD4DD9ECBD598D9E7AAD6EAADC6E0A3C7EAAAACD39291BA78C7EEAB
C8E8A7C7E1A0CCDEA0899C5CCCE69FC6E298C6E097CBE59CD2E9A1D1E8A0D0E69ED0E69E
B6CD85D3EDA4C5DF96D2F0A6D0EEA4CAEA9FC2E498D1ECA5D7E3A3E2E8AADADF9FEEF3B1
0409005A5E235759278B8C64B2B195D1D0BEFFFFF8FDF9F8F4F2F5FFFEFFFFFEFFFAFAFA
FBFFFAF0F8EB76796E9F9C93FFFAF0FFFCF2FFFEF3FFFFF4F7FDEFE0EDDCE2F3E1F4FFF3
F4FFF1F5FFEFF8FFEFF9FFF1F6FEF3F9FFF8FAFFF2F5FFEFF3FCF7F5FFFCF8FFFDF8FFF3
D0E1B5D7E9B5F8FFDBFBFFE8FCFFFAFAFBFFFEFFFFFCFBFFFFFEFFFFFDFFFFFDFFFFFDFF
FFFDFFFFFEFFFFFFFFFEFFFAFAFFF2DAE6CEDAEBC7C5DBACCCE8ADC7E8A3C3E89BC5E599
C2D79296A967D1E6A5DDF4B0C1D796D8EFABCEE3A2C8DB99E3F1B3CBD797D9E5A72E3A00
485416E1F0AFD1E1A2CBE09DC2DE94CFEFA4D3F1A7CCEAA0D1F0A4D9F5AACFEBA0C0DA90
D2EAA0CDE39A43570F576821E3F3ACDEEBA3C2CF89EAFAB3D2ECA2C3E197BCDC91C2E19B
C9E6A4CEE7ADCDE1B0D9E9C2000B00FFFEEAE5ABA7EFB4ACFFF6D7BDCA9CD9F1B7C9E5A8
BAD39CDAF1BDD5E9B8CBDFACCCDEAEDAECBA000A00E1EFBE
D5EBA2D3EBA1CBE59BC4E397C5E79ACAEFA1C8EFA0C3EA9BC7EE9FC6E89BCCEB9FCBE59B
D3E79FD6E69FD1DC97919E58D3E79FCEE59DCAE49BCBE6A1CFE9A8DAF1B9EEFDD2FCFFE8
FFFFF3FFFDFBFFF4F8FFFBFFFFFDFFFFFFFDF9FCF5F8FFEDDDFBC5BCE19CBADD99CDEDAA
D9F6B3D2EDAACFE6A2C5DC98D4EBA5C0DA91C1DB92C9E89CC9EB9ECCF1A1CEF5A4C6E999
CDE599E6FAB2C3D48ED7E8A4DEEEADCEE3A2C6E09FCDEBABCAEFACD0F9B789B371BEE8A6
CCF0B0C8E8A9C9E5A8839D5CD3EEA9D1EDA3CDE79EC8E299CBE29AD0E79FD2E8A0CFE59D
778E46BFD68EC6E097C8E49AC0DE94CDEDA2CCEEA2D1EBA4ABB378A6A56D8A8A4E4B4D0E
B0B575464A0F7F844ECDD3A7C5CAAAFDFFEBFFFFF6FFFFFDFFFEFFF8F6FBF1EFF4FFFFFF
F9FEF7FBFFF5CED0C55A584CB1AAA0FFFEF3FFFFF3FDFEEEFCFFF1DEECD5DAECD4EFFFEA
F4FFEDF0FFE9F5FFEDF8FFF4F8FEFAFCFFFFFCFFFBFBFFFBFBFFFFF9FFFFF9FFFDF8FFF1
CEDDB4D5E5B4EBFBCCEDFBD8FBFFF4F9FDFCFCFFFFFEFFFFFFFEFFFFFDFFFFFDFFFFFDFF
FFFEFFFFFFFFFFFFFDFCFFF8FAFFF2CFDCC0D0E2BAC3DBA7CDEBABC6EAA0C5EC9BC5E697
E4F5AF404C0AD1E6A3BED891E6FFBEC1DF97D7F0ACCFE49FD5E1A1B5BB7B73773A6C7131
B9C384CFE09CC7DE9AD4F2AAD3F7ADC1E79AC8EA9EC3E398B7D68ACFEBA0CCE69C97AD62
889D52899B51CCDE94D6E69DC3D38AD6E69DD0E097CBE095CAE49AD0EEA4DAFAB1CAE9A5
DAF6B9C8E1AAC7D9AF000800C2CEB6FFF7E9AA6E6EE4A4A2EDD9C0DAE3B66E834A000E00
0819000F1B00606C44CCD7AF9CA77F0007001D2300000600
C8E499C8E499C5E498C5E79AC7EC9EC7F0A1C4ED9EC0E99ACDF4A5C5EA9CC7E79BC9E399
CEE49BCEDF98DDEAA495A25CD2E69ED1E99FCDE99FCBE9A3D3F0AEE5FEC7F6FFDDFCFFEC
FFFFF6FFFCFFFFF5FFFFF5FFFFFAFFFFF9FFF8F7FCF7FFF3DEFCCACCF1AEC4E9A6C8EBA7
BBDC97C1E09CCEE9A4D8F3AED1ECA5C6E49AD4F3A7D6F9A9BFE494BBE28FC5EC99BDE390
CFEC9CBCD78AD4ECA0C7E197DDF7AEC6E19ACAE9A5C8EBA7B7DE9BC5F0AB88B572A2CF8C
C3EDADC2EAABC7EBAD85A566C0DE98D1EBA4D6F0A9CCE69FCAE19BD2E7A2D3E9A1CCE29A
849A52D3EAA2DBF5ACD4F0A6C3E296CEEEA2C9EB9EC9E09AA4A46E746C3BA49F68EDEDB1
D1D394C9CF939EA56FD4DDAED6E0BDE3EBD3F1F4E9F3F5F2FFFFFFB6B3BAB9B4BBFFFEFF
F7F9F4FEFFF8FFFFF8615C564D443FFFFBF2FFFAEEFFFFEFF7FFE7D2E1C2C6DBBAD3EBC7
D3EBC9D1E6C5DFF2D4F1FEEAFBFFFBFEFFFFFCFEFBF7FCF8F7FBFCF8FEFCFBFFF8F9FFEC
CFDCB1D3E4AED9EAB6D8E7BCF9FFEAF8FFF1FAFFFAFEFFFDFFFFFDFFFEFBFFFEFDFFFEFD
FFFFFDFFFFFBFFFFFAFCFFF4FBFFEFCCDBBAD0E6B8C8E4AACEEFAAC6EB9DC6F09ACAEC98
D0E099A5B06CD6EAA5CDE99FBADC92C2E498D9F7AFC9DF97D2DB9A5858185F5D20DDDD9D
E0E9A8CFE39CDAF8B0B4D88EC1E79CC4EA9FBBDD91D0F0A5D5F1A6879F5571873CC9DE91
D3E599D2E498DAECA0E3F5A9C5DA8DCAE193E9FFB4C2DA8EBCD68CDBF9AFB6D58FBCDB98
D0ECB16F8755021400E2F1D4F9FFF1FFF6EDC08287B67476FFEDD6E4E9C09FB079000B00
0406001D1800827D558F87609A916A9B8F69B3A781655933
C7E79BC9E99DCAEC9FC9EEA0C8EFA0C4ED9EC1EC9CC0EB9BC9F0A1C2E799CAEA9ED1EDA2
D4EAA1CCDD96DCECA58B9B54CCE297CCE89BCAE99DC6E69DCEEDAAE2FBC2EEFFD6F0FAE1
FAFAF2FFFCFFFFFAFFFFF3FFFFF7FFFFFCFFFDFDFFF8FFF8D2EEBECBF0ADC5E8A6CEF1AD
C3E49FD3F2AECCEAA4C2E098CBE99FD0EFA3C7E899BFE292C7ED9ACAF19EC5ED97C6EC97
C9EA99D1F0A0CCEB9DBEDD8FD3F3A7C0E296CBEFA7C2E7A1C2EBA5C3EEA99ECB8894C17E
BAE6A7BBE7A8C1EDAE82A96A93B06DB9D38CD1EAA6CFE6A0CCE19CD4E9A4D6EBA6CDE39B
92A860C9E098CAE199CFEBA1CBE79CCFEEA2C7E79BCDE49E979562ADA274D2CB95EBE9B0
D5D69ABBC1859FA871D6E2B2D6E0BDE0EAD1FCFFF6F0F2EFF6F6F88481889D989FFFFEFF
FEFFFBFAFDF6FFFBF8D9D1CF695F5EFFFDF8F2EBE1FFFFEFFCFFE8D7E7C2C7DEB2CDE7B8
C8E2B5C6DFB5E1F6CFF7FFEAFAFFF2FBFEF7FDFFFAFEFFFBFCFFFDFCFFF8FBFFF0F8FFE3
D2DFB1D7E6AFD1E0A7CADBA5F9FFDFF6FFE7F5FEEDFCFFF6FFFFF6FFFFF6FFFFF8FFFFF8
FFFFF8FFFFF8FFFFF4FCFFF1FBFFEACADAB5D0E6B5CAE6A9CBEDA3C0E693C3EE94CAEC95
D5E29AD2DB98D6EAA3C7E59BC9EEA1C1E699C7E59BD3E9A1B8BF7C565515797335E7E6A6
CFD895C7DD95CDEFA3CBF4A6C8ECA2C3E49DD1F1A8C5E19791A95F889D52B6C87CD5E79B
D6E99AD9EC9DC9DE91C2D98BD5F0A1CEEA9DB9D88AD0EFA3D6F2A8BED992D5F2AFC7E5A5
D0ECB23048182E3F1BEAF8DFF9FFF3FFFBF4C0818AF4B2B6FFE9D5DCDEB7ADBA856F7C44
3C400E211E007F7B4ED6D2A5C9C296F0E7BCD0C79C6A5E34
C8EA9DC6EB9DC6EB9DC5EC9DC3EC9DC3EC9DC2ED9DC2ED9DC5EC9DC5EA9CC2E296DBF7AC
CFE79DCCE098D8E9A28BA055D1EC9DC9E996CAEB9AC8EA9DCCEDA6C2E0A4C6DCAEF9FFEA
FFFFF6FDF9FAFFF8FFFFF6FFFFFAFFFFFDFFFAFDFFF8FFF8DCF8C8C3E6A4C6E6A3C9E8A5
CFEEAAD1EEABC4E29CCEE9A2CCE89ECAE99DCAE99BC9EA9BC9EA99C8EB97C8EB97C8EB97
C5E793CFF19DC0E391CDF0A0C2E797CDF2A4BBE196C3E9A0C0E8A1BAE39DCDF6B290BA78
7BA969CFFFBFB5E7A8C0ECAD85A46189A25ECFE5A4D1E8A4D6EBA8C2D792D4E8A3CEE29D
ADC37BA0B76FD3EAA2CFEBA1C7E398C5E498D0F0A4CEE39E9A9764928558E8DEABE6E1A9
E3E4AAB5BA808E9762D7E3B5CED8B6E6F0D8FCFFF6EEF0ED8F8F913E3D42F2F0F5FFFFFF
FEFFFBFBFDF8F6F2F1FFFCFFEDE2E6FFF9FAFFFEF8FCFDEBFCFFE6CCDDB1D4ECB8CFEBB1
BAD69CD0EBB4E6FDC9EDFFD3EDF6D9D2D7C1E1E5D6FEFFF6FEFFF4F3F7E6E0E7C8CCD7AD
D3E0ABD3E1A6D5E3A5D3E3A5DEEDB6DEEBBFC6D3B5A7B199BCBFACAEAF9FDCDDCFFDFEF0
FFFFF3FFFFF1F1F4E1FCFFECFBFFE6C4D3AAD6EAB5D0EAA9CAEA9ED0F69FB6DF81D6F79E
515D13D0DA95CDE199CFEBA0C4E699C0E597CDECA0D8ECA4989F5B9D9C5BE8E3A3DDDC9B
D6E19CD1E99FC3E89AC4EA9DCCEAA2BAD38F9AB16B4B6119CADE96DAECA2D0E095DAED9E
CCDF90D2E999D1E99BCBEA9ACDF0A0C6ED9EBEE799C5EBA0BFDD95D6F1ACC8E5A2C1DE9E
9BB77D627A4AE5F9D4F7FFECF8FFF3FFF9F1FFC2CBFFD1D5FFF1DDD4D6AFC1CD9BCEDFA8
D5E7B3657946000F005C6C3BD1E1B0D9E7B6D2DEAE243000
C6EB9DC6EB9DC6EB9DC5EC9DC5EC9DC3EC9DC3EC9DC3EC9DC9F0A1C8ED9FC1E195D3EFA4
C9E197CCE299D9EDA591A75CCFEA99C7E792C6E995BEE393C5E99FCAE8AAD5EBBCF9FFE8
FEFFF4FFFEFCFFFCFFFFFBFFFFFDFFFEFFFFF4F9FCF0FEEDE5FFCFC7E6A3C6E5A2D4F1AE
EAFFC4EEFFC6D5F0A9CBE79DCCE89DCCE89DCCE89BCAE99BCAE999C9EB97C9EB97C9EB97
CEF09CCBEC9BCBEE9CC2E895C5EC9BC3EA9BCBF1A4CDF3A8D8FCB4CAEFA9BBE09DC1EAA8
8AB776B3E6A4B8EFAEBBECABD1F1B0506927D0E6A5CCE2A1D4E9A8CADF9CD5E8A6CFE39E
CEE39E96AC64C9E098D1EBA2D8F4A9CAE99DCAE99DD2E7A2A8A771887E4DD9D29EDBD8A1
D3D49BB7BC84AEB484F7FFD6FEFFE8FAFFEFFCFFF8F2F4F1000002707072FFFFFFF7F7F5
F4FAF0F2F5ECFBFAF8FFFDFFFFFBFFFFFAFFFFFDFBFCFDEFF8FFE2DAEBBEC5DEA4D1EEAC
CCE9A6C7E1A0E5FDBFF8FFD4DCE9BBDEE6C1EAEFD8F8FDE9FCFFEDF7FDE3E7EFCAD1DAAD
D0DAA6F5FFC8C8D494D4E3A0CEDC9EC7D69FABB791FBFFE8FFFFEAEFF1DBADAF9AF8FAE5
F3F5E0FFFFEDFFFFECFAFFE4FAFFE1DFECC1D8EBB4BDD694BFDE92CEF29BBDE285D1EF97
4F5D12DFEAA5D6EAA2CBE59BD1F1A5C7E79BD1EBA1CADB94979E5ACACB89E7E3A3DCDD9B
D5E29CCCE49ACDF2A4C0E598D3EAA4EEFEBD8E9F5BCFE09ADEEEA7D5E59CE0F2A6C3D687
D3EA9AD2EA9CC7E696C5E898C7EDA0C1EB9FBBE99EC4EEA4D1EEABC1DA98D3EDACD2EFAF
CCE8AEF0FFD8F5FFE1F7FFE8EFFEE7FFFDF3AC6F76CB898BF8E2CDEAECC7B5C191DDEFBB
CCE2B1C6DEAE697F51000C00697C4FD6E9BBCADBAFDDEEC1
C8EA9DC6EB9DC6EB9DC5EC9DC5EC9DC5EC9DC5EC9DC5EC9DC7EE9FC9EEA0C3E397CDECA0
C6E096CDE59BD2E89F8DA358D2ED9EC9E996D0F1A0D1F4A4D0F2A8C6E4A4C7DDACF0FEDD
F6FAE9FFFFFAFFFDFFFFFDFFFBFBFDF6FAF9F7FFFBF7FFEFE5FDC9C7E4A1C5E29FD4EFAA
EBFFC1F1FFC5D6F0A9CAE49BCDE79DCCE89DCCE89BCCE89BCCE999CAE999CAE999CAE999
C4E393C8E799C5E898D1F6A6BBE291C7EE9DC2E799C5E79BB6D68DD2F1ABC3E3A0D4F9B6
8AB47485B67583BB7ACAFDBBCBEBAA9BB171B1C586D1E6A5CADD9DD0E3A1D4E7A5D3E7A2
D5E9A4849954C6DD95C6E097D5F1A6CAE99DC5E496D4EAA291925978713DF3EEB7E0DDA6
DFDFA9C3C593E3E6BBFFFFE1F6F8E2F6F8EB878883454746A4A6A5FEFFFFFEFFFDFCFFF8
FCFFF1FCFFF1FFFFF8EDE9EAFFFBFFFFFAFFFFF8FBFFFFF4FCFFE8F8FFDCE0F8BACEE9A2
CDE99FCBE79DCDE49ED4E9A6DBEBAC9EAB759AA481E0E9CEF1F7DDA9B08F858B65A6AD81
C7CEA2828C58DBE5A9DCE8A6BAC9848C9C5EE4F1C6CED8B6D5DCBDF5F9DEF5F7DF989A84
E6E8D2EEF0DAFFFFECFBFFE4F8FFDDD1DCB2CADBA7D5EBABD4EEA5D8F7A7D7F8A1C6E38F
42540ADDECA7D5E9A2C2D991DBF5ACC8E299CDE19A97A66159601DDADC9BDEE09FE1E8A5
D6E5A0C1DB92D3F5A9C6E69BCBDF9AA5B171ACB876DAE7A2D2E29BCCDE94DEF3A6D8EFA1
D1EC9DC7E696C3E598C5EB9EC7F1A7C4EFA7C1EFA7C8F1ADD8F5B3C3DC9BC9E3A2BCD999
C5E1A4D2EDB6BAD1A3CBE0B9CEE1C3FFFDEBA86D6FCA8D8CFFF7E2FFFFDFB0BD8F839364
2E38139EA584767D5E000600697051696E4E0005006A6F4F
C9E99DC8EA9DC8EA9DC6EB9DC6EB9DC5EC9DC6EB9DC6EB9DC2E799CAEC9FC9E99DCEEDA1
C9E59ACDE79DC7DF95879F55C5DD91C8E396D2EEA1C4E298C2E09AD0EAADDAEEBDF5FFDE
FFFFEFFFFFF6F5F0EDF9F3F3FFFFFBFCFFFAF9FFF6F7FFEADEF7BECCE7A0CCE7A0CAE59E
CFEAA3D4F0A6C9E59BCEEAA0CCE89DCCE89DCCE89BCCE89BCCE89BCCE999CCE89BCCE89B
D1EC9FCCE89BCEEFA0D5F8A8C6EB9BCAEF9FCBEDA0C5E498D7F1A8D9F3ACC0DB98C2E0A0
BFE6A792C08039722EB9ECAAB8D899E2F8B898AC6DC6DA9BCFE1A3D2E5A5D2E5A5CFE2A0
CEE29D829752D6ECA4C2DC93CAE49ACDE99EC6E597D2E89F9CA2644C4B13D8D79FE2E1A9
FFFFD1B7B688E5E3BDFFFFE6FFFFF1FFFFF80403016F6F6FFEFFFFF7FCF6F5FBF1E2EBD8
D0DBBBC8D3B1C9CDBCFFFFFAFFFBFFF6ECF587818573736BFCFFEAEFFFD4E7FFC1C5E099
C6E297DEF9ACCDE39BC7DB934C6114B6C783FAFFDCFCFFE6FEFFE8FEFFE6E8EECAD0D6B0
D8DEBCC3C9A399A06DE0EAAE7B8745D6E4A7CCD7ADD0D9BAC5CCADFAFEE3FEFFE8E1E3CD
484A35EEF0DBFFFFECFFFFE9FFFFE6D7DFBAC9D5A7DEEFB8C9DE9DCCE39BD3EEA18BA657
4C6219CDE19AD2E69FC5D992DBEFA8CCDD97D1DE995D68244D5613DCE5A2D0DB97D6E5A0
D7EBA4C9E39ACDEBA1CBE69F99A8675A6425DDE9A7C8D792D8E9A2D4E99EC4DC8ECFEC9C
CCEB9BC2E595C4E99CCBF1A8C6EEA8C0E9A7C0E8A9C4E8AABAD497CEE4A6051E00CEEBA9
BEDB9BC9E7A9D2EDB6D5EFC0CAE0B9F8F6DDFFE7E1FFEEE8FFF6DEEEF6D1F3FFD64F6033
717C540A12000007009AA27DE9F1CCD5DDB8CDD5B0050D00
CAE99DC9E99DC9E99DC9E99DC8EA9DC6EB9DC8EA9DC8EA9DC3E598C8EA9DCBEB9FCCECA0
CAE99DD0ECA1C6E2979AB169E3F7B2C8D995CEE29DD8EDAAD0E6A6C8DBA3D6E3B7FEFFE4
FEFDEBFFFEF4FFFCFAFFFDFAFFFFF8F4F8EAFAFFF0F1FFDEDAF4B7CDEBA1D0EEA4C5E399
C1DF95C6E599C3E296CFEEA2CAE99DCAE99DCAE99DCAE99DCAE99DCAE99BCAE99DCCE89D
D9F1A7C6DE94D2EEA3B6D68AD0F3A3BCDF8FD5F4A6CAE49AC2D890CFE39ED9ECACCFE8A7
D2F5B586B3724C8340C5F8B6DAFABBC2D89A9BAF729CB071E1F3B5D0E3A3D4E4A5CCDC9B
D6EAA57C914CCEE49CCAE49BCEE89ED2EEA3C7E698D0E89ED9E6A1959B5DD8DC9FDFE0A7
FFFFD3F3EEC6FCF5D8FFFDEAFFFDF67E7674050003EDEBEEFBFDFAFCFFF8F9FFF4E0EFD2
CEE0AED3E4B0DCE6C4FFFFF3F5EFF1FFFBFFC1BAC17F7E7AF3FBE6F4FFDCDAEFB6D1EAA6
C8E299CEE59DD5E9A49DB169BBD37DD9EFA4E3F3C6E8F3D5FCFFECFEFFECF8FCE1F8FAE2
FFFFF1FFFFEDC6C7A7B5BB8DBAC38AE2ECB7CDD4B3DEE3CCDCE2C8ECF2D8F4F7E2FFFFEF
A9AA9ABDBEAEFFFFF1F2F1DF9A9C86ACAF94AAB08CC4CFA4D4E2ADD2E4A8CDE0A092A762
829C55C9E39CD6EAA5D4E3A0DAE5A3DCE2A2E2E8A8494F0F919C5AE7F6B3CCE09BC4D994
D1EBA4D8F2ABC6E099D1E8A28B9A59ABB777D7E6A3DFF3ACC9E197D5F0A3C4E393C1E492
CAEF9FC3E89BC9EDA5CBEEAAC1E0A4C1E0A5CAE7B1CBE3AFCEE3AB72864B30480AD5F2B0
C1DE9BD6F5B1BEDC9EC6E3ABC9E3B3FFFFE1D2A193CA9488FFFEE3FCFFE1D8EBBE6E8652
A2BA7E7891509CB675C7E1A0C2DC9BD1EBAAD1EBAAC6E09F
CCE89DCAE99DCCE89DCAE99DC9E99DC8EA9DC8EA9DC8EA9DCAEC9FC8EA9DC9E99DC8E89C
C9E89CD1F0A4D0ECA1BFD68E889456969F66BDC88ECCDA9FD2E1AAE0EEBBD4DCB5C5C8AB
AAA494B2A89FB4A6A3E8DDD9FFFFF4FAFBEBF6FEE7D9E9C2D4EEAFC6E69ACAEA9EC5E599
C8E89CCFF1A4C3E598C6E89BC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DCCE89D
CAE098D2E8A0C7E198C6E599CDEE9FCFF0A1C9E497D2E89DD4E49DD7E49FCDDC9BC8DD9C
CEEEADBCE6A4B8EFAB7DB06DBDDD9ED0E5AA8DA1646E8245D7E9ABCDDFA1D5E5A6D6E6A5
D0E3A15A6E2996AC64CBE29AD3EDA3D3EFA4C3E294D1EC9FD0E19ACED995BFC887D0D39A
D5D3A3EAE5BFC2B89FF7E9DEFCEEED6D6067766C74FFFDFFFEFFFBE9F1E4E9F6E2ECFED6
D5ECA8CCE19CDBE9B8F4F8DFFFFEFAFFFCFFE5E0E7474546838A7AF9FFE4DFF3BEDAF0B0
CDE4A0C1D693DBEBAC3F530BB8D176D6EF9CE9FACDECF9DFF3FAE8FBFFEEFFFFF1FFFFF4
FFFEFDF9F5F2FFFFEEFFFFE0EAF0C2E6EDC1ECF0D9E0E4D5E5EAD4FDFFECF5F8E5FEFFF2
FFFFF3B3B3A78C8980B1AFA3D7D5C8F6F5E1BABDA2B3B997C8D1A67D8957606D3796AA6D
BAD794CEECA4D6EAA5DDE8A6D9DB9CE6E4A7DFDFA152571798A462D0E49FD6F0A9C3E199
C7E59DD1ECA5C4DB95D7EBA695A463E4F3B0CADE99D1E99FB7D68ACFF2A2CAF09DCBF2A1
C9F0A1C2E89DCAEEA8CBE9ABC4DDA4DAEEBDEFFFD3E8F8CB697A46000C00D2EAACC4DF9C
C6E69DC4E49BCAE9A5CEECACC9E6AEF2F7CEC2937FD9A695FDF2D6F3FFDBEBFFD6CDE8B3
9BB574D2EDA6BEDC94CFEDA5CBE9A1C5E59CD5F5ACC6E69D
CDE79DCCE89DCDE79DCCE89DCAE99DC9E99DC9E99DC9E99DCFEFA3C8E89CC9E99DC9E99D
C8E89CCCECA0CCEB9FD3EAA4CAD19B7B7A4A8B8F5DD7DEABDBE3B29DA47A818260A5A188
998D817B6C6563514FB2A39EFBF3E8FEFBEAF3F7DEC4D3AACCE9A7C0E393C7EA9AC2E797
C8ED9DD0F5A5C1E899C0E798C5EC9DC5EC9DC6EB9EC6EB9EC8EA9EC8EA9EC8EA9ECAE89E
CDE19CE4F5AFD1E8A0C3DF94D0F1A2C9E89AC5DD91E2F4AAE6F1ACD2DB98D4DE9FE2F2B3
BFDC9CC0E9A7D5FFC67EB16E97B778C2D79C83975C516528C7D99BD4E4A6D0E0A1DCECAB
CADD9B566A257A9048CDE49CC9E399CFEB9EC5E496D0EC9FD8EDA2D1E19A98A35FD8DDA3
E8E6B6C9C09F857865FFFBF4FFF9FDA897A10A0007FAF3FAFFFFFBF2FAEBF8FFEDD8EEBF
CEEA96CCE68FD8E8AAFDFFE0D5D3C7A7A1A5B1ACB36B696C000600E5F2D4E6F7CACBE0A7
D7EBAED7E9ABD8E6AB4B5C18DCF69BCBE793C4D7AAC9D6C2E0E8DBFEFFF8FFFFF8FFFDFE
FFFBFFFFFBFFFFFEFBFFFFEFFFFFE1FCFFDFFEFEF2FFFFFAFEFFF3EAEEDDFFFFF3FFFFF6
F7F7EFFFFFFAF7F2EFFFFEFAEFEAE4FFFFF4FCFBE9FFFFEAFFFFE48A906A454C2283945E
CCEBA8CFF0A9CEE19FDAE3A4DBD69CE4DBA2B8B2785B5C2094A060BCD38FD8F7B1C5E9A1
C6E59FCAE5A0CBDE9CBBCB8A8C9F5DC5DA95D3EDA6C6E599CDF2A4CFF9A7B9E492BFEA98
C2ED9EC0E69DCCECA9CEE7ADCEE0AEF0FBD0FFFFDFECF1C92B370762733CC3D99BE6FFBC
C8E89CBDDF92E3FFB9B6D790C0E0A1DCE4B3A97F66B88975F8F2D2F3FFDCD5EEC4CCE6B6
8CA169BFD197CFE3A8DFF3B8C7DCA1CEE3A8D0E5AAC7DFA3
C9E99EC9E99DC9E99EC9E99DC8EA9DC8EA9DC8EA9DC8EA9DCDEFA2C5E79ACCECA0CEEEA2
CBEB9FC6E798C2E195D2E9A3E7F1BCBFC5959EA673838B58A0AA78F4FBD1FFFFE4FAF8E3
FFFCF3FFFBFAFFF1F1FFFBF7DAD4C8A0A088C6CCAAE4F2BFCDE7A0C8E799D1F0A4C9E79D
C5E59CCDEDA4C7E79ECDEFA5C9E99EC9E99DC9E99DC9E99DC9E99EC9E9A0C9E8A2CCE7A2
D5E6A2C6D590DBEFA8637B31C9E399769144C2D88DD8E89FD4DF9A5C65226A7533D1E1A0
D7F0AEC6E9A5B0DD98C7F2ADC1E09D445C2095AC7641561ECDE2A1DEF3B0C8DAA0CFE1A7
DCEDA97F934B95A961DFF5ADBFD990CFEBA1CCECA1CAE89EC7DD94DFF3AB899B517F8E49
DEE3ABE2DDB5A68F7FFFF6F5FFF2FB877986070007F6F1F7F9FBF8FBFFF8EAF5E4E6F6D1
CDE59BDBF2A0899759A1A87EACAB99FCF7F4FFFCFF878288000100C6CEB7EDFACFC2D39C
E0F0B1D6E6A5AAB87A98AC64CCE98DC4E28CD0E7B3D8E8CBD7E0CFE8EEE4FFFFFBFEFCFF
FFFBFFFEF5FFFBF4FBFFFFF8F9F8E4FFFFEFFFFFFBF7F7F7FCFEF1FFFFEFF5F8E5F5F8E5
E9ECD9EDF0DDF9FAEAE7E8D8F1EFE0FFFFEFFFFFEDEDEDD3E1E5C4D7DEB4D4DDAEDDF1B6
C1E59FCBF1A6C7DE98D7E2A0E0E0A2DCD69C8D884E5B5C20D5E1A1D4EBA7D1EFA9BDDE97
CEECA6D5EEAAD5E5A4899855B2C681D9F0A8C4DE97D0EEA6C7EBA1C1EA9CBDE698C5F0A1
C4EDA1C2E69ECFEDADCFE6AECDDDB0EEF6D1F3F6D9C2C7A7344417D5EAB2CEE2A5CDE6A2
C4E298CFF0A1BAD98DD4F4ABCBEBA8DAE4AFBD9A7A936B51E6E0BCE5F4C9E5FDCDC8E0AE
A4B581E9F6C1DEECB9CFDDACCEDEAFDEEEBFD3E3B6F3FFD8
C0EC9FC6F2A3BFE99DC8F3A4B8E394C2ED9EBCE596C6ED9ECAF1A2C7EC9EC4E797C9EC9C
CFF0A1C6E796C4E395D0EEA4CEE8ABCBE2AADAF2B6E9FEC3F8FFD3FBFFDAF1F8D9FFFFF1
FFFFFDFDF8FEFFFDFFFFFFFDF1F4E3FEFFE37F8C57D1E09FD7E99FD1E397C9DA96CBDB9D
EBFAC1CAD9A2D1E0A9D2E4A8D6E7A3CADE96D1E69BD8EDA2D3E9A1CBE09F253B008DA164
909F5C4E5B15596922869750D8E9A2D3E49D8B9C55D7E7A091A15ADAEAA3D2E19C8A9B55
D4EAA2CCE69FC5E099CEECA4D1EDA3C7E4A497B086849E71C6E49ACCE89ED1E4B6CEDEB1
CFE09CD5E69890A057D9EDA6C2DB99D2F1AED0F3AFC1E29DCCE2A1DAF0A8CBE894C5E38D
96AB5EDAD9A1EEC9B6FFF0F1FFF9FF696671E8E2ECECE9F0FCFFFFFCFFFFFCFCFEE9EBE0
D3DEB6DAE7B1929A69ADB289FFFFE8FAF3E9FFFBFFF3E9F2070001A9A798EEF3CBDFE9AD
97A45C495A0C4B5D11D7EE9CC6E588D1F49AC5E09BCBE1B0D1DFBED8E1CCFBFEF3FFFEFC
FFFCFFFFFDFFFFFAFFFDF9FAFFFFFDFFFFFFFBFAFFFFFEFFFFFFF4FEFCE7FFFFE4EAF2CB
CAD7A9DBECB8D3E3B2CBD8AAD5DDB6FFFFE1FAFFDAD5DCB2E7F1BFCBDA9FD0E49FD0ECA1
C7F0A1B5E090D6F6ABC9DF97D1DC98E8EDAD9FA1624C5111DAE5A3CDDC99CDE29DD7EEA8
CAE19BD4E9A4D3E4A08E9D58D2E79CCCE297CEE59FD6EFADD3EDAEC9E7A7BFDE9BC9EAA5
C3E49DD2F1ABC8E5A3CBE4ABCFE1B7E6F5D6E4EFDE606F587E996ED1EEB8D6E7B0D0E2A4
D5F0ABC7E59BCAE199D0E7A3D4F2B2D9E8B1CAB38ACEB08CE4DDB1CBD3A0D7EAB2D0E5AA
C6D7A1E9F7C4EFFCCED2DFB4C6D2AEDFEACAF5FFE6F5FFE9
BEEA9DB8E497BAE498BEE99ACAF5A6CCF5A7CAF3A4C4EB9CC2E799C1E698C4E797C9EC9C
D1F2A3D1F2A1C9EA9BC2E297CAEAA9C2E5A5CDECA9CEEBA9D7EFB1DBEDBBDCE7C5FBFFF2
F7F9F8FBFBFFF4F4FCFEFFFFE5ECDAE0EBC397A66BCEDE978E9B539FAA65A5AF73959E69
6C7445C8CFA3D3DBAADDE8B0D6E0A1DCE9A3DBE99ED3E39A5D6E2A9CAC6ED1E2ACD4E3AC
DEEDACCDDD96D8E8A1D2E29BE6F6AFC8D8916C7D3674853E788942CCE098D9EAA39DB169
6D8139C1D58DDFF3ABC2D88FD1EC9FBEDB999BB68D739062D2F4A8BDDD91D2E9BBD0E2B8
D5E6A2D3E4949AAA5F80944CC5DE9DB6D494CAEDABCFEFAED4EAACC7DE98C7EB93D4F99A
9DB96297995A8A6048FFF1F1FFF7FEEBEEF7000005FEFDFFF2F6F5EDF1F0FFFDFFFDF9F8
F4F8DFE1E9C099A0749FA579F4F3D4FFFAE7FFFCFDFEF3FBE5DAE0968F8590926B7B8348
B7C57AD3E593CFE293C8E18ECAEB92D2F49DC6E49AD0E8AEDAEAC3E3EDD4FEFFF4FBFCF6
F9F8F6FFFFFDFFFEFDFFFEFFFFFFFFFAFBFDFBFCFFFEFFFDFFFFF3EFF2D7EAF5CDD9EBB7
C5DF9EC5E39DC6E3A0CCE6A7C9DEA6F8FFDAF9FFDAC9D9A8CFE3A8CDE6A2D2EF9FC5E894
BBE792BCE795C4E498C9E197E3F2ADC7D08D4D53136B7131D7E2A0D2DE9CD4E5A1D7EBA6
C9DD98D4E8A3D4E59F92A35C91A455CDE295CADD9BCFE3A8DCF0BBDAF0BFEBFFCFE1FCC5
E3FFC2C8E5A5CFE9ACC8DFA9D5EABFDAEACD7A8976697C66E6FFDDC7E5B3EFFBC9C8D39B
CFE8A6DBF6AFD2E6A1D0E3A1C6E3A1C2D49AA08F637C653B817948939B62849757839958
C8DA9EE0EFB8E5F3C2D4E1B6D4E0BCEEF9DBFBFFEFFBFFF1
CCECA1CBEBA0D8F8ADC6E69BCCECA1B9D98DC6E69AC4E498CEEEA2CAEA9ECBEB9FC7E79B
C2E497CAED9DCFF1A4C6E89CC8ECA6C4E8A2CDEDA4C7E59DC7E09ECADDA6D1E0B9FBFFEE
FAFCF9FEFFFFF9FAFFFEFFFFE9F0DED3DDB8C7D49CD8E7A6BAC686DDE8ACBDC792D6E0AE
FEFFDAF7FFD35D6735DDEBB0D3DF9D5F6F282D3D00D2E49AD7E7A6C9DB9FE0F1BDCADBA5
CADA99D5E69FDBECA5CADB94D1E59DDFF3ABCEE29AD3E79FC3D78FE1F7AEAEC27ACDE39A
CAE09791A75E596F26CBE198C4DE94D5F0AD627E4B000F00C6EAA0CAECA2C8E5AFCFE8B1
CBE199CBE091D4E59790A258C8DF99E4FFBCB6D591C6E3A1CEE4A6C9E09AC9ED95CDF497
C8E690CACC8D80563EFFF2EFFFFBFFDEE3E70C0D0F70726FF7FEF6FBFFFBFFFFFFFBFAF5
FFFFE8D8E1B6A4AC7B909668DFE0BEFFFFEBFFFEFBFFF7FCFFFCFFFFFFF3B1B5904C551C
D0DD95EBFCAEC8DA90D6EEA4C9E898CCED9EC4E19FD1E8B4E4F4CFF2FCE3FCFFF4FEFFF7
F8F9F1FFFFF6FFFFF5FBFDF2FEFFF6FAFFF4F8FEF4FBFFF4F9FFEDE6F7D3C4DCACC6E5AA
CCF4ADC8F4A9C8F3ABBEE7A3C9ECB2E7FFD1F1FFDCCBE9B5C6E8ABC3EBA4C1EC9CC1EE99
C8F3A1CDF4A5C3E197D5EBA3D0DD98D8E19E606626484E0ED4DF9DD5E4A1D5E9A4D4E9A4
C6DB96D2E7A2D0E69E92A65E8FA155E0F5AAE0F3B3D3E5B1F4FFDCF4FFE3F4FFE5EFFFDF
F4FFDFD8F0C0D3E9B8D5EBBAC7D9AFEAFAD66E7D60788B6DE8FFDEF1FFE1FEFFDCDFE7B4
DEF4B4B9D28EC9DA96D7EBA6CBE8A5D4E6A84234034A35066C66328F995DE2F7B4CEE7A3
CDE29FD5E7A9D5E7ADD3E4B0DEEEC1F2FFDAF9FFE6F8FFE7
D1E59EC9DF97CDE39BC7DD95D3EBA1D0E89ED6F0A6D3EDA3CEEA9FCAE69BCDECA0CBEB9F
BEDE92C0E295CDEFA3CEF0A4C5E99FC6E89ED1F1A5CDECA0CDE7A0CEE2A7D4E3B8FBFFEC
F8FDF6FEFFFFFBFCFFFDFFFCE6EDDBD0DAB8DEEAB8D7E4ACD3E0ABCFDBABEFF8CBD5E0B5
EBF6CBFCFFDAAFBC87819153899A549FB167A2B468D0E49CD4E7A7D5E8B0C9D9AAD8EAB6
D2E7A4D5EDA3D6ECA3D3EBA1CAE298C7DF95D1E99FD1E99FDCF4AAC3DB91DBF3A9E1F9AF
C8E096C1D98FC0D88E8FA75D94AB63CAE39F5E7C3E001100C5EAA5C3E8A3BADC9FDAF8B8
D1EBA2D2E99BD5E899A6B86C9EB26AC8DF97D4EDA9D1EAA8D2E6A7D8F1ADC4EA93B9E284
D3F19BEFF4B47D553CD5AAA4F3E9E8DAE3E0000400BAC0B4F0FBEBF8FFF3FCFEF9FCFEF3
FEFFE4CCD5A8B8C28E929A67D8DDB4FFFFE8FFFFF6FEFAF9FCF8F5F8F9EBE8EEC8E2EDB5
CBDA95C7D891E2F5B3C4DB97CDE8A1CAE8A2C8E1A7D0E6B7E4F4D0F4FFE7FCFFF1FAFFF1
FEFFF1F8FDE9E6EBD4E9EED7FCFFECFBFFECF8FFEAEEFCE2D1E2C2DDF6CCCAE8B4C6EDAC
BCEA9FAFE293C5F5A9C1F0AAC3EBAFCAEFBBDAFCCAC7E9B6C2EAAEC9F4ADC0EF9FBFEF9B
C7F0A1B3D589DCF6ADD5E6A0D5E09CDAE19E2A3000E7F0AFD3DF9DD5E9A4D2E9A3CEE8A1
C6E099D1EBA4CCE39B8FA55C91A659C9DA93D8E7ACC4D4A5F8FFE6F7FFEFE8F7E4F5FFF1
E7F9DFE8FBDBD4E6C0CDDFB5D2E3B9E3F2C9E4F3CCF8FFE4EDFFE6F4FFEAEDF1CECED4A8
C6DA9FDCF5B3DFF0AC738740809E569DB26F9B8F5BB29E6CD4D299CDD99BC6DD97CCE89E
D2EAA0CFE59DCCE19ED0E4A5DBEEB6E4F6C4E6F7CAE2F3C9
D6E09BDFEAA5DEE9A4E2EFA9CFDF98D1E29BCEE29AD7EDA4CCE39BC2DC93C7E399D0EEA4
CEEEA3C7E79CC6E89EC8EA9EC6E89BC3E696CCED9CCDEA9ACFE9A0D1E5A6D4E4B5F8FFE5
FCFFF6F8FCFBFEFFFFFBFDFAF0F4E6EBF1D7F1F9D0E5F1C3F0FAD5E2EECAE2ECC9DDE9C3
FBFFDFF4FFD3D0DFA8DEF1B1DBEFA7C8DD90D4E99CDBF1A8CEE3A2D8EDB5D8E9BCE4F8C5
C5E09DC3E296C7E398D9F5AAD2EEA3C8E499D3EFA4C7E398C5DF95C9E399D5EFA5BED88E
DFF9AFCBE59BD3EDA3D0E79FCBE09B94AB6745631B496D27C8EEB1CFF7BBC3ECA6B9DF94
B6D68BD4EEA4C7DC8DD5E899D0E394889A50D8ECA7C9DE9DD0E4A5D1ECA7BCE48CC4EF93
CAEA95D3D9996D482EA67E76EBE4DC616D638C9584EDF7DFF8FFECF8FFEDF5FDEEFEFFF1
FCFFE3CCD8A8D1DEA69AA56DD8E1B2FFFFE3FBFEEDFFFFF8FFFFF8FEFFEFE7F2CACEDDA6
D5E5A6D5E8A6CFE1A7D5EAB1D2ECABCCE9A9CEE7B0D0E6B8E0F1CFF3FFE7F7FFEBF9FFEA
FBFFEAEFFAD8D6E2BCD9E5BDF7FFDBF9FFDFF2FFDAE6F6CFCEE0B8D4EBBDC5E4ABCDF4B1
C6F2A5B7E897C7F5AABAE7A2BFE5ACC9EBB9C9E9BABEDEADBFE2AACFF8B6C7F3A8BDE899
B9DB8FE1FCB5C5DA95D7E6A3D4DD9CB2B87859601DD2DB98D1E29CD4EAA2CAE59ECAE8A0
C9E79FCFEDA5C5E0998EA85F94A95CCFE099D4E3AAC5D4A9F9FFECF4FFF2F2FDF5F7FFFB
F7FFF8ECFBE8D0DEC4CAD8B5D1E0B9B4C196DDE8BDD9E8C1F2FFEDF3FFEFFFFFEADFDFBB
DFF0BA819757677633D9EAA3CEEEA3C2D890CCC189AA9963E9E9ADE0EFACC5E197D1F2A3
D1EC9BCEE796CBE395CFE69ED2E9A5D2E8A8D0E5AAD0E5AC
D4DB95D6DD97C8D28DDCE6A1D3DE99E1EEA8CDDE97C9DD95DFF5ADD7EEA6C6E097C6E298
D3F1A9D0EEA6C4E49BC9E99ECEF1A1C6E894C9E996C6E393CAE49ACEE4A4D3E5B5F6FFE3
FBFFF4F5FAF6FEFFFFFEFFFFFEFFF8FEFFEFFEFFE6FEFFE4F4FCE4FBFFEDF6FFE7F9FFE6
F6FFDEE9FBCBDEF2B7CDE29DD0E69BCEE796CAE294CDE49CCFE5A5DBEFBAF7FFDDD8EEBD
CFEEAACDEFA2C4E699C2E497C2E296CCECA0D6F6AAC5E599C5E498D9F8ACD2F1A5BBDA8E
C3DF94D0ECA1CEEA9FC6E097D5EAA9BBD08D8DAC5EA8CC829FC592B5DFADC3F1A6CBF6A4
D7F9AFD6F1AAC6DC91D8EB9CCFE09093A156899553E2F2B3CADE9FC6E49EBBE58FCDF89C
C8EA96D5DE9F7E5B3FB18B80C9C5B9202F1CE7F4DAF4FFE2F4FFE2F5FFE6F1FDE5FBFFEC
FCFFE1D4E0AEDAE8AD95A366D1DEA8E8F3C9E8F0D8FCFFF3FCFFF4DBE5CDDEEBC0C7D8A2
E0F2B6DCF0B5C6D8A6CBDFACCCE6A9C5DFA2CCE5AECEE4B6E0F5CEF7FFE6F8FFE8F8FFE6
E4F4CDDFF0C4D0E2B2D0E0AFDFEFBEE4F4C3DEF0C0E0F0C3D7E2B7CBD8AACADFA6CFECA9
BEE094BAE093CFF5ACC7EAA8CCE7B2D6EDBFC8DDB6E3F8CFDEF6C4C5E1A6BFDE9ACDEDA4
D8F3ACCEE3A0D3E3A2D5E09E878D4D585D1D6A712ECFDA96D1E59ED0EAA1C5E39BC8EAA0
CCEEA4CDEDA4C3E39A9FB970879C51DBEBA4DDEAB2D5E2B7F1FBE2D5E0D0F9FFFBF3FEF8
F8FFFBE1ECDEE2EEDAF1FBE0576240C1CCA4F5FED3ECF6D4F7FFF6ECF6EDFFFFF1EBE7CC
E4F1C3899D60B0BC7AD0E19ACFEFA3D3EBA1B7AF71807138D7D99ACEE29BD3F3A7BDE08E
CBEC95CBE991CCE894CCE997CCE69CC9E59BC9E29ECAE5A0
D3E098E3F0A8E3F0AACBD8929DAD668B9C5596A761ACC079B9CE89DEF3AED4EBA5BED891
CFE8A4D1EAA6C5E09BD0EEA4D0F1A2C9EB97CCEC99C8E595CBE59CCEE4A6D5E7B7F9FFE6
F8FFF1F3F9F5F7FBFCF9FDFEF9FBF8FEFFF6F8FBEAFEFFF1FCFFF8FBFFF8F0FBEAF9FFEC
D8E8C3E4F8C5E3F9BBC3DD94CAE596DDF8A7CEE99CCAE49DE0F8BACFE6B2F2FFDAEAFFD2
C1E29DC4E99BCAEFA1C5EA9CC8ED9FD0F5A7C9EB9EC0E295CCECA0C5E599BEDE92D0F0A4
C8E79BD4F3A7C9E89CC3DE97D2E4AAE8FCBDC4E491CDF3A88BB18AC3EDC5C7F7ADB2E28C
C1E6A1BAD797D6EDA5E1F3A7D2E093D5DF965D6625ACB67AD5E7A9CAE8A2C5EF99BEEB90
BEE18FDBE4A5735135BD998BAAA9953D5034E2F2CDE8FBCEECFFD4D4EBBFD2E1C0F9FFE6
FBFFDFD6E2B0D4E4A68C9C5DD0DFA4D4E2B1D5E3C2F9FFEDF7FFEE98A78A708155C1D49D
D3E6AEBCD09BD3E5BBD3E6B9D0E8AEC3DB9DCBE2AACCE3AFE2F8CAF5FFE1F1FFD9EFFFD5
CCE0AFD2E6B1CFE4ABCDE0A8D1E4ADCFE1ADCEDEADD8E4B4DBDAAEE4E2B2E7ECB48B9757
182900142800354806303F0690976BDBDFBADFDEC0FFFFE3FFFFDCD7DFACD5E0A4DCEBAA
D2E5A5C5D596727E405A63248A8F4F919656CDD693DAE7A2D0E69ECDEBA1C2E498C8EDA0
CBEFA5C5E99FC9E8A2BBD78D687A308D9D56CEDC9FCAD8A7D7E3BFCCD9BFF9FFF3F5FFF2
F3FDF2F6FEF1F9FFF1C1C9B4040A009EA385EFF4D4FEFFEDF9FFFFFEFFFFFEF3EFFEF6E3
FCFFDDB0BF88D6E2A4D3E49EBCDC90CEE69CF2ECAEA2965AD5DC99DDF3AABADD8DD4FCA6
C8EA93CAEB92CDEB93CAEA95CBE896CAE99BCDE99ECAE99D
D7EBA380964D485C14556B22B9CF86E1F7AECCE29A91A75F5A6F2ABFD48FDFF4AFC9DE99
D3E8A5D2E7A4C3DA96D2ECA5C7E698C4E594CFEE9ECDE99ECEE7A3CDE5A9D3E6B8F8FFE8
F9FFF3FBFFFBF6FAFBFCFFFFFEFFFFFEFFFDFBFCF6FEFFFAF2F6F7FBFFFFF1FBF0F1FFE6
DDEFC9CDE4AEC3DC9AD3EFA4C7E492C0DD8BD5F1A4CDE8A1F2FFCEF5FFD8F7FFDDD5EDBB
CDEEA9C2E99AC7EE9FC2E99AC5EC9DC3EA9BBADF91D0F5A7C4E699D0F2A5C4E699BFDF93
D1F1A5C9E99DBFDF93D3EEA9D2E3ADCBDCA5C4E393C6EBA5274E2F749F81C6F8AFBEED9C
C7EEAFCDEAB0D4EAA9C4D58EDBE79DDDE7A0D4D89D98A067D7E9ABBEDC94CDF7A3C4F097
C8EB99D9E3A668462AFCD8C8676951C6DCB8CBDEB0D2E9B1BCD89DCEE9B4E0F5CCD5E3C0
F7FFDBD8E4B4D0E0A28E9E5DD8EBABCEE1AACFE1B9F7FFE8F5FFEAF5FFE40F2500102400
000C00586B3DF7FFE6EAFCD6E7FCC1CFE8A6D1E9ABCDE5ABDFF6C2F1FFD7D5EDB9CAE3AC
C7E0A6CFE7ABD0E6A8D0E5AAD7EAB2D3E4B0CBDBACD5DBAFE3DAAFE8DAADDDD69F5A5A1C
04090046500B676D2F2C2F00120E00D5CCADF9EAD3FFFAE0FFF9D6FFFFD6FFFFCFD4D89D
D8E3A7243200555F2393995DDBDFA2DEE4A4DAE5A1D6E7A1CDE79ECCECA1C0E598C9EFA2
C9EFA4C1E59BCEEFA8D2EDA6899A5356631DDDECABCDDBA0D1DFAEDBE7BFC4D2B1ECF9DD
FBFFEFFBFFF1EBF2E2868A7BFCFFEEFDFEEEFFFFF1FFFFF8FCFFFFF6F4FFFFFAFDFFFCF1
A6AC8AD4E0B0DBE4ABD0DF9ECDEBA3D3EAA2948E528C8245D7E09DCFE79DCAEF9FC0EA94
C6EA92CBEC93CAEB94C8E893CAEA97CEED9DCEED9FCAE99B
809E5496B66BA3C177C5E399CEECA2C3DF95D2ECA5CEE8A1B3CA848CA15C829752D5E9A4
D5E8A6D0E3A1CEDE9DD0E5A0CFEBA0BCDB8FD4F0A5D0EBA4C4DD9CC9E0A8D4E7BAF4FFE4
F9FFF3FBFFFAF8FCFDFCFFFFF9FAFFF8F7FDFFFEFFFCFBFFF8FBFFFBFFFFF8FFF9F3FFEA
CFE1B9D2E9B1CFEAA5CDEC9ED1F19EBBDB88CEEDA1D0EBA6E2FABCDDF4BEE2F5C7D3ECB5
C6E7A2C2E99AC4EB9CC2E99ACAF1A2CBF2A3C2E799CAEFA1C6EB9DC6EB9DC6EB9DC8EA9D
C8EA9DC8EA9DC8EA9DCAE7A4C7D7A6D6E7B3CCEAA0C2E6A680A68D7BA58DCBFCBBD3FFB6
CDF3BACDE9B8CCE1A6DBEBAAD2DD98D9E29FDFE2AB909761D6E8AAC6E49CB9E38FC7F39C
CEF1A1CED89C7452361E00004B5030CDE4B8D2E7AFD7F0AFBEDD99C9E7A9D5EBBCDBEBC4
FBFFE0D9E4B9D9E8AD849755CFE4A1D2E8AACEE4B5F3FFE2F3FFE3F4FFE1E2FAC6CBE2AA
ACC08D57693F6D7C5FECFCD8E5FBBDD6EDA5BAD38FD2EBAADFF9BCECFFCDD3EFB2CEEBAB
CAE7A5CDE7A6CCE5A4D8ECB1D3E4B0CDDAACD3DEB6D7D9B2EEE1B77E6C3C6B60287D793A
DDDE9AE4E7A4D6D69ABCB8883228050E00004F3A277C67529A896BA99B74A9A26E93925A
131B00727D45B3BB82D3D89EDEE4A6D5DE9DD4E19CCFE39CCAE69BCDEFA2BFE598C6EFA1
CDF3A8C0E49AC7E6A0CFE9A2DBECA5A0AD67BECE87D5E49FCFDF9ED7E7A9CFDEA7E5F3C2
FBFFE1FBFFE8CBD3BE4D5143FFFFFAFFFFFDF7F2F6FFFDFFFEFDFFF9F5FFFFF8FFFFFBF4
7F8267D3DBB2DEE4B4D2E0A5C8E5A3D4EAA9CFC98FA89D65C9D28FD2ECA2BFE695C7F19B
C8EB97C9EB95C9EB97C9EB97C9EA99C9EA9BC9EA9BC9EA9B
C8ECA2CCF0A6C0E49AD6FAB0C9EBA1D8F8AFC4E29AC9E49DD2E9A389A05A546823CFE39E
CEDF9BD1E29ED9E8A7D3E7A2D8F2A9BAD88EC7E29BD1ECA9D4ECAECEE5AFCFE2B5F5FFE4
F1FFE8F9FFF6FBFFFDFCFFFFFBFCFFFFFEFFFFFDFFFFFDFFFCFEFFF9FEFFFBFFFAF8FFED
D3E6B9CAE4A7C4E29AC5E494BDDF8BD4F5A4CEEDA1C8E39ECAE2A4C7DCA3DEF2BDCCE4AA
C8E7A1CCF1A3CEF3A5C2E799C1E698CAEFA1C4E99BBDE294C6EB9DC6EB9DC6EB9DC6EB9D
C8EA9DC8EA9DC8EA9DCAE7A4DFF1C1D3E5B5D3F0ADB8DBA17FA28C91B9A1C6F3BAE7FFD1
CEF0BDCCE6B7D8EDB5D1E1A3CDD997E1EAA9D0D89F9AA36CC8DA9CC7E29BD0FAA6BFEB94
C0E295DDE6AD6442261B00006A704CDCF4C2CAE3A2D1EDA3C5E59ACCEDA8D0E8B4DDEDC6
FCFFE4D0D8B1CDDAA48FA260DCF1ACBCD594C9E4AFC6E2B2CEE9BCE8FFD2DFFBC1DBF4BA
C9DDAACCDDB328341CF9FFE6E2F6B7CFE79BD3EDA4E5FFB9CDEAA7C0DF9CBEDD99C2E19D
CEEDA7BBD691DCF5B3BED297FBFFD8FEFFDDFFFFE4B1B18F4D4117746834CCC68AD9DA98
E9EFA9D3DA96D7DD9FECECBAAEA8840B00009C8B77B6A68F55472A5A5128534D19595A21
707942B4BE89D0D7A1D5DDA4DBE3A7D6E0A1D6E7A1D2EAA0CBEB9FCBF0A2BEE799C4ED9F
C6ECA1C6E89ED6F4AED7EEAACBDC98AABA73D1E198D8EA9ECBDE8FD5E79BCDDE98D7E7A9
D1DFACEAF6D0000400878880FFFDFFFEF8FFFFFAFFFFFBFFFEFCFFFFFAFFFEE8F4FFF9F7
D8D7C3FEFFE3F7FCD3C9D5A3C6E2A8BDD297CDC6928E824EE0E9AACFE9A0CCF3A2BAE691
C8EB99C9EA99C9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9EA9B
C0E69DBBE198D8FCB4BDE199BDDE97C4E39DC5E39DDAF5B0D0E7A1CBE29CCCE099849851
BDCE88CAD994D7E3A1D2E39DCCE39DCFEAA3D3EEA9C7E1A0CBE5A8CEE7B0D3E9BBF7FFE3
F8FFEAF9FFF1F5FDF0FCFFFBFAFBFDFFFEFFF1EEF7F9F6FFFEFEFFF9FDFFF7FFF2F3FFE4
C4D8A7CFE9AAD8F6ACD2F3A2B0D1807A9B4C7A984E7B96518EA668D4E9AED4E8ADCAE0A2
D9F7AFBEDE92BADA8ECBEB9FCCECA0C4E498C6E69ACAEC9FC8EA9DC8EA9DC8EA9DC8EA9D
C6EB9DC6EB9DC6EB9DC9E8A4C4D8A5C6D8A8CBE7ACE1FFCF92B499577E63E3FFDBC9F0B7
D6F3C390A878879A628F9F6194A36297A3639DA86CD5E3A8D6E9A9CDE79EBEE592B9E38F
D3F3A8CBD29C6C482E1E0000616741DDF6BFC9E39CCFEB9ECAEB9CC9EAA3CAE3ACE5F5CE
FCFFE6D8DDBDD6E2B0A6B678D0E7A1D7F2AFD0EEB2C8E6B0C6E4AEF0FFD6D6F2B5C7E1A4
D8ECB7CBDCB2000800EDF8DAEBFFC0CDE597CEE89EC7E399BEDC94CAE9A3DDFFB5C7E99F
C8E89DCFEDA5D7EDACCFE1A7F1FACDEDF1CECECCB33D391C858456BDC087E3EEACD1E19A
D3E89DD9EFA6CADF9ECBD9A4C4CCA5161900222007D4D0B5DDDDB9DDE0B3D0D89FD7E2A6
C1CE98EAF7C2E3EDB8D4DDA6D6E0A4D2E1A0D2E8A0CAE69BCBEDA0C7EE9DC1EA9BC8EEA1
C3E59BC9E79FDBF2AEC2D796677736768743BED086D5E897D3E792E1F7A2D5EB99D0E49D
D2E1AA98A47C1B200ABEBFB9FCF9FFF9F2FFFFF7FFFDF5FFFAF7FFFFFCFFFFF6FFC0ACAD
F2EFE0F8FCE3FFFFE0E8F0C9D1E8BADCEEBEDFD6ADAFA275D4DCA1D1EBA4C1E897C4F09B
C8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99EC9E99D
D1EEACD6F3B1C7E4A2CBE8A5C3E09DD2EDAACBE4A0C8DF9BC3DA94D6EBA6CEE29BDCF0A9
AABB758FA059C7D790C7DB93CAE199D7F2ABCFEAA5C2DC9BCCE6A9CBE4ABD1E7B6F5FFDD
F1FFDDF7FFE7F2FEE6FCFFF4FEFFFAFFFEFFFDF8FEFFFDFFFCFBFFFEFFFFFCFFF3F9FFE4
CADEA9D1ECA9C1E09495B6659BBC6BD0F0A4C5E39BDBF6B3AFC58585995AA5B878CEE3A0
BDD48CCBE79CD8F2A8D9F5AACAE69BC8E499D0EFA3BFDF93C9E99DC8EA9DC8EA9DC8EA9D
C6EB9DC6EB9DC6EB9DC9E8A2CFE6AEDDF1BEE1FCC9E0FFD1EBFFEA7DA07FC5EABECEEFC0
9FBB8AAEC591C8DAA0CFDFA0D8E8A7D3E4A0BFD292D4E7A7CFE39ED8F0A6C7ED9ACBF29F
BBD991C1C592714D355F3A272B3008CCE5ABCEE89ED2ED9CC8EA96C3E59BC6DFA8ECFCD7
FEFFEDF6F8E2FEFFDC96A56AC2D995D5F0ABC7E5A5C5E4A8CDEFB3E5FFC6DCFBB7DFF9B8
C7DCA4C6D5AC48503BFCFFEADEF0B6D1E99FDBF5ACCBE69FC9E7A1BFE197CCF1A4C1E397
C3E397CBE79DCBE29ED6E5ACFFFFDABCBB9C4A442E817B610107007A8A4CCFE6A0D6F2A7
C1E293C6E89BBBDA96CEEAB0C7D9AFF9FFE6737C5FDBE2C3D3DBB4D3E1AED7E9ABC9DD9E
D4E5AFF7FFD2E6F3BED2DFA7D4E2A5D3E3A2D0E79FC4E397C7EC9CC3EA99C4ED9ECDF2A5
C5E39BCBE4A0CDE0A09AAA6BBBCB8DBFD292E4F5AEDBF0A1C9DF8CCFE791CCE192CDE19C
CADBA50E1A00D4DBC9EBEDEAFFFDFFFFFBFFFEF5FFFFFAFFFFFDFFF5EDFAF0DBE45D494B
F4F0E5FFFFEFFFFFEBEFF5D9E9FFDBF8FFE4F6E9C9C6B893CED5A1D1EAA6BCE394CDF7A5
C8EA9EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99E
D4E1A9CBDAA1E3F2B7C7D69BDBEAAFCCDEA0D9E9AAD3E6A4DAEEA9CCE09BD0E49DDAEEA6
CCE098A7BC7161772CB1C77CC6E096CDE79DC1DB94CCE5A1DCF6B5C9E3A6C6DFA5E8FFC9
D6EAB7E9FACEF4FFDEFCFFE8EBEEDDEBEBE1E7E3E0FFFCFDFFFEFFFAFBF3F0F8E1F0FCD6
CCDFA7D2ECA5C2DE91A3C272A0C172C4E499C7E59FC6DF9DE0F5B2CFE39E83944EC8D992
E2F6AED6ECA3C3D78FCEE49BD1E99FCAE298D4EEA4C8E499CAE99DC9E99DC9E99DC8EA9D
C6EB9DC6EB9DC5EC9DC8EAA0CBE5A4E4FBC3DAF6C6EEFFE1E4FFD6628354C3E2B9C3DEB5
93AA76D2E6A9D8E8A9CEDF9BD0E49FCEE59DD5EFA6D4EEA5D2E69FC0D68DC0E391D2F7A7
D9F4AFF0F2C169432C361200161800C5DDA1D1E99DCFEB96C5E793C7E79CCAE1ABEAF8D5
F9FBEDFFFDEEF5FBD785945DDDF4B0B6D18ACFEFACC1E4A4BBDE9CF0FFCDD8F8AFC6E19C
C9DDA2D6E3B81F2410FCFFECEDFECAD0E6A5C7E09FC5E2A0DEFDBAC2E39CC0E49ACFF1A4
CDEE9FD6F2A7CADE99CFDA9ED8D9AD4D4727766A54585135566230A8C180BEDE95C7EC9E
C0EA98D0FBACC0E8A2C9ECB2C9E4B7F2FFE38D9C7DD0DFBED1E2B6D3E7B2C7E09FD5EFAE
CFE4ACF4FFD4E6F7C1D3E4ADD5E7A9D3E8A5D0ECA2C7E79BC6ED9CBFE997C3EA9BCFF1A5
CCE7A0D5E8A6CEDA9C8D985CD1E0A7C8DC9FD4E7A5D0E69EC7DD92CAE296D1E6A3DFF2BA
D0DFB6101A01F5FBF1FEFFFFFFFEFFFFFDFFFCF5FDFFFDFFFDFCFFFFFCFFD3BEC5897577
FFFFF8FEFFF4FFFEF2FEFFF3F4FFF1F0FEE5F7E8D3A8977BE4E7BACCE2A2CAEFA2C2EC9A
C8EA9EC9E9A0C9E99EC9E99EC9E99EC9E99EC9E99DC9E99D
DBD9A9DFDFADCBCB99DCDFAAE3E8B2D4DCA3E1EBAFD0DC9CD9E8A7CEDF99D2E69EC9DF94
CEE69ACBE395E5FFB1AFCA7B99B465CEE99CD8F2A8D0EAA3CCE7A2C7E29FCEE8A7D0EAAB
D2EAACD8EBB3DFEFBEEDF8D0E0E5C7CECFBDE3DFD4DED9D3DCD9D4B3B5A78F957998A579
8CA06397B1689FBC6CB3D282CFEFA3DAF8AEC2DD98D1EAA6CDE29DCDDE97CCDC9198A95B
ACBC73D2E29BCEDE97D6E7A0D8E9A2C6DC93D5EDA3D4EEA4CCE89DCAE99DC9E99DC8EA9D
C8EA9DC6EB9DC5EC9DC6EB9DCEECA2E4FEBFF1FFE1ECFFDDD7F9BDBBDA9F6C8661CDE3BD
889B63C6DA95D1E19ADDEEA7DAF2A8C1DD90C8E998C7E696DEF3A8CFE59AD0F1A0BFE292
C8E19F4C4E1D77513A4B25103D3F17D0E8ACCBE395CAE691C5E791D0F0A5D1E8B2E1EFCE
FAFAF2FFFFF6ABB090CBD7A5F7FFCBC2DD96D7F8B3CAEDA9C5E8A4C9EAA3C9E99DE1FDB3
D4E8ABE2EFC3C7CCB6FEFFEDDEEEC1D4E9B1C8DFA7BBD79CC8E6A8C5E5A2C3E79FC4E699
C3E493D4EFA0CCDD96E9F1B5A09E6E5D5330BFAD97595033A6B280CEE8A7C7E79ECFF5A8
C0EB9BC0EC9DB9E29CC3E6ACC2DDB2F4FFE6F7FFE8F0FFDEF5FFDAD5ECB4D1ECA9C0DB98
CEE5AFF2FFD5E4F8C3CFE4ABCEE4A6CCE5A1CDEBA1C8EA9DC7EE9DC2EC9ABEE596CBEBA0
D4EBA5DEEDACD8E0A5A4AC73D7E5B0CEE1AAD3E7AADCF2B2DCF2B1CFE5A7CBDFAAD5E7BF
F6FFEBA6B1A3F9FFFBFEFFFFF7F7F9FFFFFDF7F4EDFCF9F2F6F6F6FFFEFFC4AFB4FFEDEF
FFFFFAF2F5EEFAF7F2FEFFFAF4FFF9F5FFF2F5E5D8B2A08ADADCB4CDE2A7C3E79DC5EC9D
C8EA9EC9E99EC9E99EC9E99EC9E99EC9E99DC9E99DC9E99D
AB99713322001203001D10000B0300DEDBA667682FE2E8AAD8E2A3D1E09BE1F5ADD8F0A4
C2DD8EDAF7A5B2D27FCAEA958EAA56C4DD8CCEE99AC9E399C1DD93C6E298D7F2ABC6E19A
CEE8A1CAE09FD0E2A6DEEAB8D6DCB6BEC1A4FFFFEDFFFCF0FFFFF4FFFFEFE1E6C6E0ECBC
D8EBABD7EFA5C7E494D7F6A6D0EFA3A9C77FD9F4B1D8EFABC0D48DE0F2A6D9EB998F9E4D
384400CAD48FEBF6B1D4E19BCFDC96D0E19ADCF0A8C4DA91CDE79DCCE89DCAE99DC8EA9D
C8EA9DC6EB9DC5EC9DC6EB9BD4F6A2BFDD97C0DBB0D2EFC3CBECA5D6F5B190A680495A38
95A567D2E297E0F1A3C5DA8BC2DD8ED5F7A3D3FA9FBBDF87C7DC8FCCE196C8E797D6F9A9
CFE8A64E4D1F79503C1D00006E7048D7EFB3C5DD8FCFEB94C7E993CDEDA2D1E8B2E2EDCF
FFFEFBFEF9F59A9D82FCFFD8E8FCBDCFEAA3C5E6A1C0E49ECBF1A8CEF3A6BADB8AC9E598
D7EBACBBC799FDFFEAF4F7E4E8F4D0CEE1B3D6ECBDDFFAC7BBDAA1C2E5A5D5F9B3CEF0A3
D7F6A6C8E190D3E398D7DD9DA19E6B63552E120000AB9C7DDBE1B1DAF0B0C1DC95CAEA9F
C3EA9BC1EA9ECCF1AECCEBB2CBE2B8F8FFE6FBFFE8FBFFE6FBFFDDBBCC96CFE4A1D5EEAC
CEE7B0F1FFD7E0F7C3CAE2A8C9E1A3C7E29FC9E99EC3E89AC2EC9AC8F2A0C0E597C9E79D
D5EAA5D9E5A5D8D9A0B8BB86D8E6B3CEE2AFC1D5A0C4DBA3CBE2ACCAE0B1D5E9C4E7F6DF
F8FFFBF9FFFFFBFFFFF0F1F6FAFAF8FFFFF4FFFFECFFFFEDFAFDF4F4F0EFBDA9ABFFF9FB
FFFEFBFEFFFDFFFBFCF6F8F7EEFDF8F9FFFBFFEEE8D9C3B5DCDCB8DEF1B9C0E19ACEF3A5
C9E99DCAE99DCAE99DCAE99DCAE99DCAE99BCAE99BCAE99B
5C4F23695E315B5324837F4F80804C555A225D652950591A505B19535E1AC2CF89CEDE95
E3F5A9C0D787DEF5A5CDE693C6E1909AB5668AA256C8E096E3F9B0CAE199CFE69ECCE69D
C7E19AD0E9A5DBF1B3CADBA59AA2796D7150FCFAE3FFFFEFF4F2E5FFFFEDEEF6CFCFDEA7
C9DE9BDCF4AAC6E298C7E59DC8E5A2D9F6B4D1ECA9BCD68FDCF2A7CEE394D1E493D3E496
AFB9749AA360555E1B8A9551E3EEAAD7E49FD0DF9CD7EBA6D0E5A2CFE6A2CDE6A5CCE6A5
CAE6A9C9E7A9C9E7ABCAE7A5C8E497CDE7A0D9F1C1C0DAAACEECA2BFDD93B2C99B304218
D1E4A4C5DA8DD7EC9DD0E799CCE798CCEB9BBBDF87D0F19AD3E697E2F2A9C7DD92C7DE96
4D6325E5E8B975573B492E117C8654D3EDACC3DA8CDDF4A2CBE79AC6E09FD1E1B4EBF1D5
E1DDD2979387ABB18FD5E3B0D4EDABC4E499CFF1A5CAEFA2C1E396D0EFA1CBE697D4ECA2
C7D99BE3F0C2DDE6C9FCFFECF6FFDE343F170009005A6C426E845699B47FC4E0A5C9E3A2
C6E099D8ECA4D7E49ED7DD9D999661342700574322E7DAB7D5DDAAD2E6A7C5DF96D0EFA1
C9EA99C0E094D1EEAEC7DDACD4E3C2FCFFEDFBFFEED4D7C2929978AAB384D0E0A2D2E4A6
CEE4B5F0FFDDE0F8C8CCE5AECEE8ABCBE8A5CAECA0C2E799BFE695CEF5A4C4E99BCAE89E
D3E8A3C9D897C5CB8FB3BB82F4FFD1F7FFDAF2FFD9F4FFDEF7FFE4F3FFE6F2FFECF5FFF3
F8FFFAFBFFFDE9EBE6FFFFF8FFFFF3FBFAE5FFFFE6FFFFE4C7CAB5A9A896EEE2D4FFFEEF
F5F7E9FEFFF4FFFFFAFEFFFAF8FFFDFCFFFDFFF9F7CFBBB2FFFFE6F1FED2DDF5BBCAE9A6
CAE8A2C9E9A0C9E9A0C9E99EC9E99DC9EA9BC9EA9BC9EA9B
DEEDB4CDDFA5C6DC9ECBE8A8CFEEABC8E7A3C7E59FD1E8A2DCEBA8959C599FA05E5D5C19
BFBF79D1D38AEBEDA4CAD48BD3EBA1C9E59BB7CC87869552C0CC8ADFEBA9D0DF9CCFE2A0
D0EAA9D1EEAEC3E0A6CDE5B3EAF9D2EBF2D1C7C5AEFFFFEFFFFFF4F7FFEAEDFACED7EBAE
C0D78FD9F3ACC1DB9EC8E3ACC9E6B0C9E6ACC9E8A2CAE99BCCE995CDE897CDE79ED0E5A4
D5E1A3E5EDB1CFD79BAFB97C566023889255B8C387DAE5ABCCD9A3DFEDBAC9D8ADF9FFE1
F9FFE8F8FFECF4FFE9D9E7C4D9E8AFD2E2A1B5C78BB1C78994AE6788A35C829E61274306
ACC986C8E39CCFEAA3C4DE97D5ECA6CFE6A0CAE098B8CC84909E5399A35C939856979F63
D8E7B0D8E2AE0A0300C8C695BEDB99E0FFBAC2D88FC5D690D2E6A7E6F6C5F7F8D8FCF6DC
C2BEA1D0D5ADDDE9B7C8E1A0C7E99DCDF4A1C2E893C9EB95D1ED99C5DA8BE0F0A7D5E4A1
CCDBA2CBDDADE9FED5F8FFE3FAFED9EEEBC8ECECCA8C8F70818668636D4B58643E69764B
A9B583CCD6A1D8E0A7D8DBA2313000393100E1D6A9E2DEAFD2E1A8CEE7A5CBE699CDE995
D1EA96CBE493D1E3A5E6F3C7E7ECD8FCFBF6FFFDFFFEFAF97F7D706C6F50EBF1C1D1DBA9
D2DFC1F2FFE7D9EDC8D3EBBBCCE5ABBDDA97D1F1A6C6E89BC0E597D1F6A9C9EBA1C7E79E
CEE9A4CBE4A0CDE29DC3D897E1F6BBDDF3C2ECFED8E3F3D8F3FFEFF1FBF2ACB6ADA8B0A1
F1F6E2DADEC3F4F8D5EBEDC6FEFEDAFFFFDFB8B396AEAB8CBABC94C6CC9EE0E3B6EFF6CA
EBF6CCE1EDC9EBF1D5FCFFECFCFCF0FFFEF8FFFBF8C9BAB5FEF7E7FFFFEAE2E9C7D0E1B5
C9E2ABC8E8A9CAEAA9C8E9A4C3E79DC3E89AC6ED9CCBF29F
BCE0A0C2E7A4C4EDA9C2EDA8C2EDA6C2EBA5C2E7A1C3E19BD1E6A3D6E2A0CCD18F888747
706C2CCCC787E9E1A0E0E3A0C4D994C9E49DD0E5A06D7C398D9653D4DD9ACAD694D1E4A2
C8E2A1BCDC9DC9EBAFD3F1BDE1F3C9EFF9D6747357FFFFECFCFFF3F3FFE7DDEFBDC7DD9C
D3EDA3CEE9A2C1DCA5D4F0BFC8E5B5C8E7AEC8EAA0C9EB97C9EB94C9EB97CAE7A4CCE6A7
D7E9ABCAD89AD2E0A2E7F5B792A0626C7A3C79874AAAB77FDBE5B1CAD6A8D6E0BBFCFFE8
F7FCE8F4F8EAFEFFF8C2C7B1CBD5A18D9C599DAD6CD9EEABBFD894CAE8A2D8F7B1597A33
91B26BCEEFAAC0DF9BE5FFBDC5DB9AC4D998E4F4B54453106D7A329AA15BE1DFA4DADAA4
CAD7A2CFDDA82327009FA96DCFF3A9BDE495D7EDA5F2FFC0C3D69FE6F3C8FFFFE6D3CCB2
D6D8B0D4DEAAD5E7ADC7E09CC8EA9DCFF5A0C2E990C8EC92D5F39BCCE592CFE39BCBDB9A
E0F1BAD3E5B3DCEFC2F7FFDBECEDC3DDD8B0DBD7B4F2EED1E9E9CFD0D2BA868A6F737858
7C825CD3DBACE0E7B3DCE1A96E6F365D5C24EEEBB6CED39BCEE4A6CBE9A3CAE797CDE994
D2EA92CDE391D4E2A4E9F1C8FFFFF3FFFEFFF7F1FDFFFCFFAAA7A235341F7A8054E9F0C6
DAE4CCECF9E5F2FFE3CADFB4C0D9A0D0EDABC8E69ECBEB9FC8E89DCEF0A6BAD993C3E29C
D5F3ADD6F4AEC7E29B8FA962DFF8B7BFD39ED1E3BDD6E4CDF9FFFAF3FCF71F261E949B89
D6DDBCCAD1A5E3ECB5E2EAB1ADB17E94976A9F9F7D9FA17CD8DFABD4E0A2D3E3A4D3E5A7
CEE2A7CEE0ACE1F0C5FAFFE4FFFFEDFEF8ECFFFDF4B9B0A7FFFFF1FFFEEAF4F8DDD5E1BD
D2E5B7CEE7B0CBE7ACC9E6A6C7E6A2C6E69BC5E79AC5E896
B9ECA9C0F2ADC5F2AFC1EAA8BEE2A2C1E4A4CCECABD5F3B3BEDC9CD4F1AFCCE5A4D0E2A4
727A3E55561CB9B27BDBDB9FD5ECA6D0EEA4D0E79FBCCD8696A35B929F57DAECA2DAF2A8
CDEDA4D5F9B3C2E7A4C4E6AAC8DFABE5F2C7A1A580FBFEDFFBFFEDF7FFE8EDFFCEC7E29D
CAE99DCBEBA2F0FFD3E8FFD4C6E7B2C6E8ABC6EB9DC8EC95C8EC94C8EB97C9E8A2C9E8A5
C5E39DCCE89ED1EDA3CAE49BC2D991D8EFA9CFE4A1A3B6767382478E9B66DBE6BBFEFFE1
FFFFE8FFFFECFFFFEF888F7055622ACFE39CDCF1ACCAE49DD7F2ABC2E299C1E399D2F6AC
C7EBA1C2E39CCAE9A3B9D791D2EBA7B2C78450601FBFD08CDDEEA7CDDA95DDDEA4DBDEA9
A6B47F233100626432C3CD91BFE197C9EFA2D2E8A0C6D695C6DBA3EBFCCFDBDCBDB8B799
ECF9CDD4E7B0D0E4A9CBE09FD1E8A0D4F1A1C3E790C5ED94BDEA8FC3F199CFF8A9C3E49F
CFE4ABCEDAAAF5F5CFFFFFDCF0F2C1D1D5A3B7BA8F949873A8AB8CC3C7ACFAFFE1ECF2D0
FAFFD8ECF4C5CDD69FDEE6AB979F63494F11DCE2A4DBE7A9CBE5A4C9EAA3C7E897CAEB94
CFEB94CBE493D1E3A5E6F2CAF2F9E9FEFFFFF2F0FBFFFEFFFFFFFA7A7E6731380F575F36
67715973806CF0FFE0E9FBD1D7EEB6D2ECAB87A55DC5E59AC0E097D4F4ABCAE8A2D4F1AE
C5E09DB5D08BC5DF9898B26BBED390E3F7BAD1E2B5C7D4B6C4D0BC0005009CA894A3B094
819065AFC0898C9F5F90A361B6C688C7D69FDCECBDC6D6A5D8E7ACD2E5A3D0E7A1CEE9A4
C8E5A2C4E0A3CEE6B2DEF0C8E4EDD0F7FBE4F1F3DEBEC0ABEFF3DAE1E8C9E2EEC8E4F3C8
EBF8CAE4F2C1DBE9B4D4E3AAD0E2A4D0E49FCFE59DCEE499
A0DF98639F5960914F93BB7C93B2766480457A965BC5E4A8DFFFC7B2DC9DC0EAABC4E6AA
AFC48B838C57777343C7C793CDE4A0C8E69CC1DB91E9FEB3BCCE826D8031A0B767C2DD8E
C2E394C2E79AC2E89FC6E9A5C7E0A6D3E4AEDAE3B4B4BC93F9FFE6EAFFD8E6FFC5D7F5AD
BEDD91C7E99DF0FFD1E1FFC9C5E8AEC5EAA7C6EB9BC6ED94C8EC92C8EB97C8E9A2C8E9A4
CAEFA1C2E797CCF1A1C4E797C9EA9BCDECA0DFF9B0D1E8A2A8BB7B839259B1BD8BF4FBD1
FBFFDAFCFFDFFBFBDF8C926C94A368D8EEA6CDE79EBBD78DCDEDA2D3F5ABCAEEA4B8DE93
CBEFA5C2E49AD5F4AECEECA6CCE39F8EA3607F8F4ED6E6A594A8636E7E3D6C7137737842
6E7C4796A36E969662D4D99FD2F0A8C5E79BC8DC95D7E7A8E0F8BEDDF0C2AAB08EBAC09E
F8FFDCD1E8B2CEE2A7D0E2A4D3E7A0D1EC9FC2E591C3EF96C1F69ABAF299C5F9A7BBE59D
C1D99FD8DEB0FFFFDDF8ECC6E4E7B095A064707A465A63385F6543555A3CE2E7C9FFFFE3
ECF1C9FCFFD3D2DBA4D1DD9F6975338A9752E5F2ACC5D994C8E7A4C7EBA5C6E999C9EB95
CEEC96C9E495D0E4A7E4F3CAFBFFF3FCFFFFFAFDFFF6F9FFF2F7F0C2CAB359643C061100
000900000B00EAF7D9EBFCD2DEF3BBD6EFAE223D006E8C4495B36BC5E39DC9E6A3D7F2AF
D3EEABDBF4B2D3ECA8657C36DEF2AAD0E09FDBE9B4C9D8AF3B482C000700D3E2C350623A
4C602BD0E9A7D7F1A7CCE89BD8F4AAC0DD9ACAE6ABCEEAAFC9E2A0C9E39ACBE99FD0F2A6
CDF1A7C4E9A4C4E3A7C7E2AFD5E7BFF9FFE4EEF7D8C5CEAFD7E3BFDAE9BEE9FDCAF7FFD6
F9FFDAF5FFD4E9F5C3DBEAB3D3E2A7CFE2A0D1E5A0D4E8A0
1B651A5DA158A5D997C8EEB1D0E9B0B9CD987C955E3E5F26356529B2EAADB1EBAEBBEEB3
C9EBB8C7DAAC6C6D45515324C9DE9DC6E49AD7F1A7C3D98ECADF90B1C7756B84319FBC68
D3F7A0B4DA85D0F7A6CDF2A5C8E39ED3E7A8CFDCA4B2BE8CD4E5B9D4EABBBFD99AD5F3AB
C8E79BC4E69AD1F1AEC4E7A7C5E9A9C5EBA2C6EC99C6ED92C8EC92C8EB97C9E9A0C6EAA0
CFFBA6B4E288C3EF98C8F29CD3F9A6B2D583C1E092CEE89FD4E9A4CDE0A09FAC74DDE5B2
FFFFD8A3A67B71724AE0E6B6D7EAAAB8D288CBE79CE1FFB4BBDB8FB5D78BD3F8ABC4E99C
C2E49AC5E79DCAE8A0DAF5AEC8DD9A859856E9F9B87A8A495066257B8D4FD4DBA59B9F6C
CBD8A3D1DBA6837D498A8950D2ECA5BEDC92DFF0ACC4D2941A3200667C4BC2CCA7F4FED9
F8FFDCCFE3AECFE2AAD6E8AAD0E5A2CBE79CC0E693C3F199B8EF94B4EC95AFE391C2E7A2
DFF2BAB6B5899A8665675831969F608CA15C98AA6EE1EFBEC4CCA59BA0809DA0836A6D4E
D4D6B1FFFFD8E4EDB4CFDE9D6D7E37C5DA8DC6DD8DD8F3A6C7E8A3C6EBA5C4E99BC8EB97
CCEC97C8E497CFE4A9E3F3CCF8FFF2F1F7F5FBFFFFFBFFFFFAFFFAFBFFEFFBFFE3E2EEC8
E0EAD1FBFFEDF0FEDDECFDD1E0F5BDBCD594AEC984819C5578934E607B3866803FB8D291
D2EBAAC3D998CEE5A1AAC0788EA05492A2595B692C0816000A19009EAE89899B71D2E8B7
D7F1B2CEECA2C3E692C5EB94C1E895B8E192BEE69FC0E59FCBEBA2C7E79BC2E797C0EA98
C1EC9CC1EB9FC6EBA6CCEBB0CDE5B3ECFFD2DFEEC58B9A6FC7D9A9BFD69EDFFCBCD2EEB1
F2FFD6F2FFDAEFFFD2E2FBC2D3EDB0C7E4A1C7E59FCAE89E
AFFCAEB0F4A9B8EBA8C3E7A9CDE4ACD1E3AFCFE8B1CCEFB7C6F8BD054105519155B1EAB3
B6E0AED5EEC4959C7A53582FE0F2B6C9E39CD6ECA4D4E99EC9DE91DFF4A5B3CC7991AD58
BBDC85E2FFAFC8EB97CBEC9DC3DD93D7ECA7D6E6A5D8E7AC7B8D59D8EDB5CEE7A5C5E197
CEEA9FD4F2A8B8D793C8E8A5C8E9A4C8EA9EC8EB97C9EC92C9EB94CAEA97CAE8A0C9E9A0
BFE995C2F096C9F59EB6E08AD0F6A3D8FBABDCFBAFC4DE95C9DE99E9FCBCD9E7AA99A269
505721959966D4D6A4DBE3AAD9EDA8CEE89EC2DE93C7E69AD4F3A7CBEB9FC4E499CEEEA3
D1F1A8C6E49CD3EDA6B8CD8ADAEAA997A567CAD698637134BED398E4F7BFCBCE9FDDDFB0
DEE6B3E3E7B4938755BDB67FDAEBA7C8DF97C8D391434D10BFD4999DB47ED8E5BADEE9C1
F9FFDACCDEAAD0E3ABD6ECAECAE3A1C6E69DC1E899C3EE9CC0ED9AD9FFB4C2E69CD2EBAA
F4FDC8A49F75AA9776E6DBAECCDB96D4EEA4D1E7A6D1E2ACD5DDB6E5E8C9F1F1D788876B
9E9E7CDDE0B5D3DAA44A561691A55DD8F1A0CFEB97C7E696C5E9A1C6EBA5C6E89BC9EA99
CCEC99C8E499CFE4A9E3F3CCF7FFEFF9FFFDFBFFFFF9FFFFFBFFFAF3FFE9EBF9D6FBFFE3
F6FEE6F8FFE8E2EDCBC9D9ACCFE2AADAF0B0CFE8A4C2DD98BED9962A4403000F006C8446
D3E9ABD7EDADD1E7A6D0E69EDCED9F839446112000011000526231C8D9ACD1E5B2CFE8AE
BEDC96BBDC8DC6EC95C5ED94CDF89FCFFBA6BBE697CAF3A7CCEEA2C9E99DC3E898C0EA98
C0EB99C2ED9DC6ECA3CAEAA9D4EDB4F7FFD8E8F8C996A675B8CB93CBE4A3D7F5AFD3F2AE
E0FDC7E9FFD5F1FFDAECFFD2DBFABECCECA9C6E7A2C7E99F
A7EA9BB4F1A4C2EFAAC4E7A5CCE4A8D3E8AFCCE5AEBCDDA6C0F0B694CB9285C0887DB37F
B5DFB1C9E5BCCEDCB998A37BAEBC87C9D99BC1D190ECFBB8C8D891CBDD91EAFFB0A6BD6B
8DA955CDEA96C0DD8BD1EC9DD1E79CD6EAA2D6E5A0CAD998778749C4D698E2F7B4C8DF99
CDE49CDCF6AFCCE7A2D6F1ACCCE89ECCE89BCCE995CDE994CDE995CFE79BCFE6A2CDE6A2
C3E495CAF09DD4F7A7C9EA9BC5E498B9D58BC7E09CDEF3B2D3E5A7C2D294C8D699BFC98D
A7AF74CED69BEBF0B6D2DC9FCADE97D1E99FDBF2AACAE49BC1DB92D2ECA3D4EEA7C5DF98
C3DA96D4E9A6E1F1B0D6E4A6D8E2A5979F64E2E7AD3740096D7F4BBFCFA0FFFFDAFAF7CC
E2E4B5D6D4A3AB97659E8F58D3DC9B94A35E737838ADB377C8DAA0CCE1A9D3DFB1EBF2C8
FFFFDAD0DCAACFE2ABD1EBAEC2E29FC5EBA2C7EC9FC7E79BC2DA90D4E39ECED798DADBA2
C7C393726E419D9870DBDFACDEF6ACC0DD8DCFE5A4C6D49FE4EAC4D1D1B5FFFFEAEDE7D1
7570534D4B25777B49454F12D6E7A1BBD385C5E28ECDEE9DC7E8A1C9EAA5C8E79BCCE89B
CFEA9BCBE29AD1E2ABE6F2CAFBFFEFFBFFFAEAEEEFEBF1EFFCFFF8F0F9E4E5F0CEF9FFE1
FCFFEAFCFFEAE7F3CFD8E8B9D1E4ACC5DB9ACBE29EDDF6B2DAF3B1DAF3B2BBD39552682A
001400152900718645D2E69FCCDF90B9CC7DA3B46ED4E7A7C4D59EDAEDB6D3E8AFCAE4A3
C8E69EE2FFB2D7F9A2B0D47CC1E790CFF7A1B9E091CAEFA2C6E49CCBE69FCBEB9FCAEF9F
C9F09FC7EE9FC6E89EC4E19FC3D89FEDFEC8D9E5B3A1AE79A1B075CFE4A1BAD48BD1EFA9
D2F1B8D8F8C6E2FFCCDEFFC8D4F6BACBEEACC7EAA6C8ECA4
BFF2A5BDEBA0C4E9A3CEEDA9D0E9A8CAE0A2C8E1A7CDECB1B8DFA6CDFAC1ADDCA674A06D
274D1E98B48BCEE2BDA8B790515A2BE1EAB5E0E7B1CED89CD7E3A3D8E7A2C5D78DDBEDA1
D3E899899E4FD9EEA1CCE194D4E69CDCECA5C5D28DE6F2B0D4E09E8D9C59C2D190DCECAB
D4E7A7C9DE9DD1E6A3C9DE99D0E69DD0E799D1E697D1E697D3E59BD3E4A0D4E2A5D3E3A5
D3E8A3D1E8A0CBE09BCCE19ED9EBADD7E9ADD1E0A7D3E2ABD3E0AAE8F5BFF6FFC9CED99F
D7E1A5D3DDA0D5DFA0D5E19FD0E19DD3E7A0D5E9A4CEE29DD4E8A3D4E7A5CADD9BD7EAAA
DAE8AAD3DEA2C6D094D9E1A8E1E4AF999965D7D5A2535526616E43DEE8C3FBF7D4FFFFDC
DBD8ABD3CB9AFFF5C6907B46666829BBC483D5D398DBDAA1E1EFB4CCDDA6DAE2B1EAF0C2
FFFFD8D1DDABCEE1A9CCE8ABC1E19ECCEBA7D1EBA4CEDF99E9EBAC87814550430C514410
453B0A636131D9DFAFCEDDA4CDE79DCCE999D1E6A5D9E7B4CDD1AEE0DCC3FFFEEDFFFEEC
DFD5BCB6B08EBEBD8FD6DEA5BDCE8ADBF3A7D4F19FC3E292C9E79FCDE8A3CBE59CCFE79B
D2E89DCDE19CD3E2ABE7F2C8FBFFE9FCFFF4FBFDF8FEFFFAF8FCEED1D9C2E0EAC8F6FFDD
F9FFE1FCFFE6E8F3CBD0E0AFD0E2A6D1E6A5D2E9A3C9E09AC6DF9DC6DF9EDAF0B2C5DA9F
CFE3A6E4F8B9C9DC9CCFE39CD3E89BC9DE91DBF1A9D3E8A7CBDFA2D8EDB2C4DA9CD1EAA8
D1EBA2BFDB8ECBE894D5F29EC5E290CBE898D4F3A7C6E097CEE3A0CFE4A1CFE6A0CAE69C
C7E69AC9E79DCEE8A1D1E6A5D7E4ACDAE3AEDEE2B0969A67C9D397DDECABCBDC95D3E8A3
CFE3AECDE3B4CCE2B1C9E0ACC6DDA5C7DFA3CBE4A3CFE8A6
C6E297CDE99EC4E096D5F0A9C7E09CD7F0AECCE4A6CFE9ACC5E1A7D4EFB8C7E2AF92AC7C
415B2C668051BDD7AAD6E7BD52542DDDD9B3DEDDB1D0D2A1ECF4BBCAD497DEEAA8D4E19C
D3E09A94A159D9E49FCAD590E4EFABD6E19FD6DF9ED9E2A1D8DF9B616824A6AC6ECCD49B
DBE4ADE1ECB2CCD89AD2E19EDCECA3CEDC91D7E399E2EDA8C5CE8FECF4B9CFD3A0E2E4B2
DEE1AAD4D7A0E8EAB8C9CB9ADFE2B5E9ECC1D7DCB3CED3ABD7DEB5FFFFDCF9FFD3C6D09C
DFECB4DFEDB0D0E09FD1E09FD6E2A2DFEBADD0DC9ED4E0A2DBE6AACDD89CD6DFA6D6DFA8
DEE3ADD9DBA9CECD9DE9E7B7A39C70978E63E5DCB14F4A24727757CFD3B8FFFFE3FFFEDD
ECE3B8DFD1A2C09F727559277E7A3DD3D898D8D298EAE5ADCED79EDBE8B0D7DBA8DEE2B0
E5EFBBD7E8B2D3E6AECEE3A8D9EFAFD1E1A2D6DC9EE5DFA3816D38533906735727624C1B
6157247A7D48D2E1AAC9E1A3C6E096CEE89EC4D69ACED7A8E6E7C7F6F0DAFFFBEDFFFDED
F8ECD6EEE5C6E2DFB6DADFA9D8E4A6D3E7A0CDE59BC6E096CEE8A1D2E9A5D4EAA2D2E69E
D0E19AD2E19EDCE7AFE5ECC2FFFFE6FFFFEFF3F3E7FFFFF4FEFFEED9DDC2DFE5C1E5EDC6
E8EFCDFBFFE0E8F3C8CEDFA9D7E9ABD4E9A4C8DF99D4EBA5CDE6A4CBE4A3CCE2A4CDE2A7
D0E4A7D0E5A4D0E3A1CDE39BCAE298CEE89ECFE6A0C8DE9DCBE1A3D4EAACD4E8ABCADF9E
D3E8A3C8DC94D7ECA1D6E89CD4E69CD1E29BCBDA95DFEBABDDE5AAD2DBA2D7E3A5DCECAB
D3E8A3CEE39ED3E3A2D4DFA3DADEABD8D7A7E5E1B2A19D6DD6D59FCDD194DFE6A2D4DD9C
D7DBA9E3E4B8D9DAAED4D6A7E3E5B3E1E4ADD8D9A0DEDFA5
CDD991B1BE76C5D68FC7DD94AAC17BB8D18DBCD291B4C889C4D39AA1AE78A0AA76A8B482
6C7C4B455B2A5B764361744753502F4E4325948E6A9A986F898C5D929963959F63A9B273
9DA665777E3B9CA15FA5AA6A939858969C5EA6AE72999F5FC0C37C777A357879409C9E6D
94976AA9AF7FA0A86F98A160949E57B7C178989F5C525619A0A06C9F9E70C6C197908861
B1A87F998D65D6C9A6DED3B392896CC8C1A5D0CAB2D4D2B9BFBFA3FFFFE3F3F9D3CFDBAD
BECD9677894D9CAF6DC5D594747D44838852A5AA748E935D5E622F929664545627575628
6E6B40928F6697926CBFB7927B6E4CBAAD8B8576553D34175F5E49C5C4B0CABBA6D4C3A5
B2A67C8D7C4E8161327055206F6B2E7C7E3F665D26938C5590955BA3AC73B9B983E0E3AC
A2B37CD6EBB29DB176D6E4A9C5CA90ADAB72DFD29B6A5520644816806230E2C897EFDEAA
DAD59EBCC48BE3F5B9D0E9A8D7EEA6D5EBA3DFEEB3DAE3B6F0F1D1FFFFEAFFF6E6FFFDEC
FFFEE6FFF7D6E7E4B9D6DAA7D2DDA1D6E6A5D8EDA8DAF1ABC9DE99CADF9ACCE099D0E19A
D5E59EDCE8A6E4ECB3E8EEC0FFFFDFFEFEE4FFFFECFFFFECF2F5DAD8DEBCD0D7ADDBE4B7
DBE3BAF9FFD9EBF9C6CBDDA3CFE4A1D2E9A1CBE29ACFE9A0CCE5A1CEE7A5D0E8AAD1E7A9
CFE5A5CFE4A3D1E6A1D2E9A1D3EDA4D2EDA6CCE7A2C7E09ECCE5A4D5EBABD0E4A5C4D797
CDDD9CDCEBA8899651DBE6A1CDD693D7E09DD5DB9BB8BC81ACAC78BBBE89C1C68EAFB97C
A8B776BFCE8BC5CF92AEB379A7A574C1BA8CB5AA7D8A7F517D764299975EA8A868CCCE8F
ADAA77AEAA7B9D9668958F5FA9A371ABA571908B537E7941
8786457C7F3CA1A8648C9953677B36738742A3B372CCD89A9FA46A65652F5D5B28C4C492
727B469EAF797B945B2B3B0C4B44272818004F4428524E29797C519CA272707741B1B97E
9CA065B7B87C50501472723697985EC5C98E858D52959B5DB0B36C999A56676532A19F78
91916FA2A47D9CA06D9197599CA35FABB06D717236B8B683B4AF87433D1BBDB294CBBDA0
D8C5A7B19C81E9D3BCFFEAD7AB998BEADACDE9DCD3EBE3D6EEEBDAFFFFECD8DDBDCAD5AB
D4E2AF92A46AA5BA79C4D4958D915FB4B3878B8A5E67663A807D5494906AA7A17D9D9773
B4AB8AE0D7B8F9EED2ECDEC4E2D3BCCFBFA866563F483B2AB6B2A7DCD5CBEAD9C9D2BEA3
C6BA92A294636F511F806731969457A4A969938C55968F58646A2E6B713587854CA7AB70
80985A83A06093A267A8A970BDB07C725B299D7F4D5D3F0D684E1B705C27A59C63A1A165
9BA165849052A1AF7198A867889C557E924D9CAB72919A6BA5A986C6C5A9B0AA92C7C0A6
B5AF8FABA7819D9F6E959C66929D618F9F608A9D5D869B589EB16F9BAF6A9BAC669CAD66
A1B16AA5B26DA7AF74A6AD79CBCEA3B6B893CFD3B2C2C6A5A9AD88A8AF85959D6C97A16D
939C6DB7C391B0BF888EA0628EA45C97AF6592AC6291AD6291AC6596B16E9AB47399B271
95AB6A93AA6697AE669AB46B9DB87197B56F8FAC698DA86594AD6B9DB37296AB6A8B9B5C
8B995BAFBB7B525B1CAFB577919558989C5FA1A26687864D7371408989578E915C767E43
727C3D8F9A58979D617A7B4296905E9085577D6E437F71445E54235E59216C6A2DC6C889
B2B27CBDC08BB8B884ADAD77B4B57CB4B57BA4A56B97985C
DAD498E4E0A1DADC9DDBE1A1DFE9AACFD99ACED69ADCE0A5DBDAA2E5E0A9E5DFABD1CE99
D4D9A1CDD8A0CFE3A8A7B381504529210F0042371B878461ABB087CED8A6CFD8A3D5DEA5
D6DCA0DDDEA2ACAC706B6B2FDCE0A5D5DAA0DFEAAEDAE4A5DEE49CDCDD9BB3B284FAF7D8
FDFBE4F3F3D7DCDFB2DFE4AADDE4A1CFD492A5A571FFFFD8F4EDD0FFFEE8C6BAA4D9C8B4
FFEBD6FFE8D4FFF9EBFFF3EBFFF4EEFFFAF8FFF6F5FFFCFAFFFFF6FBF9EAFFFFEAD6E0BB
D6E4B3CFE1A7CCE19EE4F4B67C7F54908C69A39F7CBFBB98E6E1C3B9B295746D51766C53
918670B7AC988477668E81719C8F7F8173668C7C6FC6B9B0FDF8F4F1E9E6FFFBEFFFF9DF
F4EDC35B5420A7905CB1A166D4DA9AD9E5A5D8D69DDFDDA4C8CE92DDE6A7E5E3A6DEE0A1
CAE09FC7E1A0DDE7ABEBE6AED5C18E957949674917C7AD7AF5E6AFDCDA9FD9E2A3C9D895
D8E9A5D2E39FE1EDABD5E49FD3E7A0D0E49FE5F4B9DCE9B4EFF8CDFFFFDFF5F6D4FFFFDF
D5D8ADD4DBA8D8E0A7DBE6AADBE9ABD4E4A5C7D99BBCD190CDE29DCCE29ACBDF97C9DD95
CADA93C7D691C6D292C5CF93F0F8C5CDD5A6D6DDB1CFD8ABC4CE9CD3E0AACBD99EB5C489
CAD7A1E2F1B8DEF0B2C9DE99CAE296CEE99ACBE898CBE79ACCE89ECFEAA5D2EDAAD1ECA9
CEE7A3CEE59FD1E99FD3EDA4CFEDA7CDEAA7C9E7A1C9E49FD0E9A5D8EFABD4E9A6CCDF9D
D0E0A1D8E6A8D4DEA1E2EAAED5DDA1D6DC9ED9DDA0E1E5AADCDCAAD9DBA9DBE3AAD9E5A7
D3DF9DD8E5A0DDE8A6D6DCA0DDDCA6EDE7B5EEE3B5B1A776C5BE8AD5D39AE4E6A7E9F0AD
CEDA9CD7E5A7DCEAACD8E6A8D6E2A2D2DE9ED3DF9FD8E4A2
E2E1A9EDECB3C9C68FE3E0A9E9E6AFDEDBA4EFEAB3DAD7A0E8E5AED5D29BE3E2AAE9EAB1
DFE4AAC9D198E4EDB4D2D6A4F0E2C57060470A04001E2000889466DCEDB7E3F2B9CCDA9D
D8E2A5DAE0A29FA064515518DAE3A4E5F1B3C7D99BCDDD9CD7E198D6DB99D1D3ABE9E9D1
FFFFF1FAFCE7D4D9B1DDE4B0DAE3A4D9E1A5959869050500FFFFECFBF1E5FFFDF19A8C7F
D5C5B5FFFBEBFFFBF1FFF6EFFFFAFBFFF7FCFFF9FFFFFCFFFFFCF9F5F5EBFFFFEDD7E1BE
C5D3A2DCEEB2D5E9A4B9C98B4C4E27CFCBB0E8E4C9D5D1B60B06000701000700000B0200
857C6D3F35290800000A0000B7ACA6A29994FFFCF8FFF7F4FFFDFFFFFDFDFFFCF3FFFBE1
626337EFF0B7C5BB80958F51E1F2AECCE39FD0D89CE2E6ABD3DFA1DBE6A4DDDD9DE2E2A2
DDE9A9D6E4A6D4D89DD2CC92EBDCA572612B9F925BEAE4AAD6DC9CCFE09CCFE9A2C4E298
D0EAA0C8DE95CEDE95CCDC93CBDF97D3E9A1CCE1A0C9DDA0D2E3ADD3E4B0D2E3AFD3E4AE
D4E6AAD2E5A5D1E5A0D2E69FD4E9A4D5EAA7D3E8A7D0E6A5CDE7A0D2ECA2D7EFA5D6EEA2
D4E99ED1E59DD5E6A0D7E7A6E7F7B9D5E4A9CAD9A0D3E5A9CCDEA0D5EAA9E4F9B4BFD491
CCDEA0CFE1A3CDE09ECCE299CFE897CAE692C7E492C9E898C8E79BC8E69EC7E4A1C9E4A1
CAE59ECBE59CCBE699CAE49AC8E39ECAE5A0CAE59ECAE49BCBE59CCEE89ED1E8A0D0E5A0
DAEFACC2D595DFF2B2C8D899D9E9AADBEBAACEDD9AD7E6A5E0EBB1D2DDA5D3E3A4DAEFAA
D3E9A0CCE297D0E49CD5E49FD1D99DDDE0A7E6E5AF9A9963D1D299DEE4A6E3EEAABFD089
D7F3A9C3E599C1E196CAEA9FCCECA3C7E79EC9E79FCEECA2
D3DAA6CACC9AA5A171A39968A39264A89769E3D2A4C9BF8E95925D9B9E672C3400586226
737B40AAAF75888950BEBA8AEEE1C1EDDFC4B3B08D121900465625B3C88FB7CD8FDCF1B0
D8E7A6D4DD9CD0D696EBF1B1727E3CD1E4A2D5EEACD5ECA6D5E698D7E2A0E8EEC8C1C5B4
F6F9F0FEFFF4E5ECCAE6F0BED1DCA0DDE8AEDADFB67B7B61FFFFF3FFFEF8FFF9F4E9E0D7
C9C2B2E8E1D1FDF5EAFFFEF8F6EDF0FFF5FDFFFCFFFCF7FDFFFEFFFFFFF8F0F5E1D4DBBA
D5E1B1D2E0A3C6D7917B894C969A79E9E8D362604B7B7865A8A594E7E4D5FFFEF2FBF4EA
FFFEF6FFFEF8F9F1EEFFFBF8FCF6F6FFFEFDFFFEFDFFFDFFFFFEFFFFFDFFFFF7EEFFFFE6
7A8354BDC88CE0E0A2A0A562B8D68EC1E29BDAEAABD8E4A6CBDE9CD5E4A1D5D895E1DE9B
D3D194F4F2B79F9A607E793F58561BA9AA6EEDF7B8C8D897D0EAA3CBEBA2CDEFA3C9EB9E
CCEB9DCEE99AD8EDA0DAEFA2CEE69ADAF4AACAE49DCAE3A1CEE8A7C8E2A3CCE9A7C9E7A1
CBE99FC9E89AC8E595C8E595CAE598CCE69DCCE5A1CCE5A1C1DF95C5E697CBEA9CCCE89B
C8E396C7DF93CBE399D0E79FC8DD98CFE6A2C7DE9AD4EEA7C8E299BEDA8FD7F3A6BFD98F
D5EAA7CADF9CC9DF97D2EA9CD2EE9ACBE993C8E992CCEE9ACAEA9EC8E89DC7E59FC8E6A0
CDE99FCEEA9FCDE899CBE699CCE69FCFE8A4D1EBA2CFE99FCDE899CCE798CEE99CD0EAA0
D0EAA1CBE6A1C7E09ECAE5A2CDE8A3D0EBA4CBE79DC9E39CCFE4A3CCE2A1CEE8A1CAE99D
C3E493C8EA96CDEC9CC8E396DBEFAACEDD9CC9D397B2BC7FD1DD9DCEDF99C8DD92D2ED9E
D0F3A3BDE493C1E696CBF0A0C5EA9CC0E597C9EB9FCDEFA3
D5E7B5B3BF8F83805545360DAF9570A0825E7D643C5140157E7C4B939C658EA0648FA165
939E6293965D8780496155259D906D9E9574D8DAB3010F00000D0088A565D5F2AFCEE8A1
D8ECA5D9E6A1DAE5A1DDE8A492A35DA7C17ACFEFA6C2E297D3E899D9E8A5E9F3D0B9C1B2
F0F6F2F9FFF8F9FFE6F9FFD8CEDDA2DFEEB5CFD7B2DADDC8C8C8C0ECE8E7FFFEFBF5F2EB
F3F4E4C2C5B2FDFFF2FFFFFAF7F7F9FFFEFFFFFEFFF6F7FCF7F7F9FEFFFAF9FEEADFE6C4
DBE5B39AA6688B9852A5B1737075552C2D1DB5B6A6FFFFF3FFFEF1F5F3E7FFFFF6FFFFF8
FBFAF6EDECEAFFFEFFFFFFFFFCFCFEFEFFFFFEFFFFFCFCFFFEFEFFF5F4FAFFF8F0AEAC93
A5B584E2F6B7CBD49382924BC8F1A5CBF5ABD6EFADC8DB9BD3ECA8D1E59E99A05A827B37
745E25543B057D7338C9CE8ED0E3A1C7E6A0C3EBA2C4F0A5C2ECA0BBE498C0E598CAEA9E
CAE999CFEC9ACCE997BFDC8AC5E290CBE898CBEA9EC2E297C7E99FCAEFA2C2E99AC7F19B
C2ED93C5EE92C9F093CDF197CFF19DCDEC9ECBE69FC5E39BCCEEA1CCF1A1CCF1A1CDF09E
CAEB9CC9E89ACAE99BCCEB9FCAE69BCEEDA1D2F1A5D6F5A7CEEF9EC5E894CBEE9ACEEF9E
D3EAA2CCE29ACDE599D0EB9ACBE993C8E990CCED96CBED97C8E99AC8EA9EC9E9A0C9E9A0
C9E79DC9E89ACCE997CDE899D2E9A1D2E7A2D1E79ED1E99BCEEA96CDE995CBE896CAE999
C2E296D0F2A6C0E49CCDF3AABFE59AC0E699C4EE9CC5EC9DC6E89EC9EBA1CBF0A2C2EC96
BBE88DC7F499CFF79FC4E793C4E095DBF2AACFE2A0A1B570ACC37BCFEBA0CBEA9ACAEC98
C4E692C3E591D1F0A0D2F1A1C5E496C9E89ACFEBA0C0DC91
D5E1AFD7DDADA79F782E1B00FFF5DBFDDDC4A58B70BAAB8ABEBF95D5E1AFCDE2A9D3EBAD
D0E2A4D3DDA1C0C1879B98635E5A2D5F6034AFB7861425001C340087A462C4E39DC8E69E
C3DD94DAF0A8CFE39CC9DD9695AC64809A51CCEAA2CAE99DCCE798CEE5A1D9E8BFC9D5BF
F8FFF5FBFFF6FBFFEBFBFFE1EFFCD0E2EFC4E6F0D5E5ECDCBABBB6FFFEFDF8F3F0FFFEF8
FFFFF4A2A698FEFFFAEFF1EEFEFFFFF9FAFFF6F7FCFEFFFFFEFFFFFEFFF8FFFFEFD2D7B7
D4DBAF767F48444E0FD6DDA901030059594FEBEBE1FFFFF6F8FAEFFEFFF6FBFEF3FBFFF1
FCFFF6E1E7DBE7EDE1FCFFF8F9FCF5FEFFFAFEFFFDFBFDFAFDFDFBFBFBF1F5F4E0515733
CFE6AEBDD695D3E4A094A861C9EDA3BEE29AD0E5A4D1E1A2CDE29F8FA35C4B550E5B5A17
A08D52BDAA6FB2AE6EDEEBA5C2E096D0FBACB1E291C2F7A7C5F6A7BEEA9DC6EC9FCDEFA2
BFE091C8EA96D2F69FCDEF99CDEA9AC9E195E0F6ADCAE097CDE49CD9F5AAB8DB89C6F198
C2EF94C2EF90C4ED8FC7EB91C8EA94CAE99BCBE99FCAEA9FC4E99BC2E797C1E794C2E895
C6E999C8EB9BC8EB9BC7EA9ACFF0A1C0E192C8E99ABFE290C6E997CDF09CB9DF8AD0F3A1
C8E69CCBE79DD1EE9ECAEA95C0E18AC7E88FCFF099C9E996C6E599CBE99FCEECA4CCEAA2
C7E59BC5E496C9E996D0ED9BD2EAA0CDE49CCAE296CCE798D0EC98CFEC98CAEA97C7E897
CAED9DC1E699C8EEA3BDE69AC3EC9EC6F1A1C0EB99C1EB99C7EE9FC2E99AC4EE9AC4F099
BCEB8FC0EF93C6F198C4EA95CAEA9ECDE99FCAE19BA0B771B8CF89C2DC93C6E597D4F1A1
D3EA9AD0E394D1E397CFE195CFE497E0F5AACDE19995A961
A0955DA5986497855F675237B69F91FFF9F1FFFBF1EEE5D6D9DCBFD5E0B8D0E2AECBE3A7
CBE4A3CDE6A4D1E7A7D2E4A6CFDDA298A369919F62364608091E00657E3CCFEDA7C8E9A2
C8EAA0BDE197D1F3A9C4E499ACC87E687F37D6EAA3D5EBA3D3F3A7CAE9A3D6EBB3CDD8B0
7D7F67D3D2C0FFFFEFFBFCECFEFFF3F6FCEEFBFFF8F3F8F1FFFEF9EBE3E0C3B6B0FFFBF8
FFFDFBFFFDFEDDD8DCE9E4E8FBF9FCFFFEFFF8F8F8FFFFFBFEFFF7FEFFF2FAFCE7D9DCBF
999D78B3B98DE1E7B732340F969084F6EEECFFFEFBF8F9F4F9FFF5F9FFF4F8FFEFF1FFE4
DEEFCBD8E8C1E3F2C9FBFFE0828866B0B396C7C5AE9A987FB1B18DB3B689A5AD7CD2E1A8
D1EAA9BDD895A2B774A0B16DDAE9A8CDD798EAEBAFB5B67A262C007B86449BA765B3C27D
D9E9A0D4E69ACDE293CCE393CCE894CBEB98C6EC99C0E99ABEE89CBBE79CC7F3A8C9F3A7
BBE495C1E895CEF49DC9EB95CAE298D7E3A1C4C287938A51A79D62D0CE91C5D48FC7E69A
BEE594C3EA97CBEC9BCAE596CAE294D4ECA0D2F1A5C6E69AC9EA9BC9EA9BC9EA9BC9EA9B
C8EB9BC8EB9BC8EA9DC6EB9DD3F5A8BEE093C2E497C7E99CC8E89CCAEA9EC6E599C6E69A
C7EC9FC7EE9FC9EE9EC0E38FBEE08AE6FFAFC4DF8ED1E99DCDE49ECEE7A3CEE7A5CBE6A1
C7E79CC7EA9AC6EA93C5E992CAE99BCAE99DCAE99DCAE99BCAE99BCAE99BC9EA9BC9EA9B
C9E99DC8EA9DC8EA9EC8EA9EC8EA9DC6EB9DC6EB9DC6EB9BC6EB9BC6EC99C5EC99C5EC99
C5EC99C5EC99C6EB9BC9E99DCEEAA0CDE7A0DCF1AEAABD7DC4D495C9D799E2F0B2D3DE9C
DCDF9CDDDC99ACAD69A2A5609AA05A333A001A240098A35E
605110695A217364396B5B41C1B1A4FFF7F4FFFCFAFFFBF2F2F5E2EAF3D4E6F5CAE6FAC5
E0F7BFD3ECB2CAE6ABCBE5A8CFE4A1D9EAA6D8E8A76C7C3D1D2F004D6227A4C085CFF1B4
C3EAABC8F2B0BEE7A3C7EFA8CEEEA5819850DEEEA7C7DB93B9DB8FC4E8A2DFF4B9EBF7C9
DEDDBED6CFBCFFFCF3FFFEFAFDFBFCFCFFFFFBFFFFF9FDFCFFFFFBF1E8E3C3B4AFFFEFED
FAEEF0FFFCFFFCF3F8CFC6CBFFFDFFF5F1F0F6F2EFFFFFFAFFFFF6FEFFF1FFFFEFDBDDC5
A6A98CE7EACB888C69858569FDF6ECFFFDFBFFFDFAFFFFFAFCFFF8EDFAE8E4F4D9E8FCD7
E1F7C8C9E0AADCEFB7C4D39C252D007C7F54CECEA8F0EEC5E6E9B2EDF6B7D4E3A2CFE4A1
CCE7A2D0EBA6BBD08D8E9D5CD7DB9EE3E1A6D7D1977B753BA3A367B6BF80C0D08FD2ECA5
C1E396C5EB98CEF09CCFF099CEEA95CCE893CEEB99CFF0A1C9EDA3CDF5ACBDE79FBDE79D
D4FAADCDF0A0BEDE89CEE998D2E6A1A4AC70958C5562511D695822796E36707636D5E9A4
CDEBA1DAFAAFC4DE94C4DC92D5EBA0CBE397C7E698CBEC9DCAE99BCCE89BCAE99BC9EA9B
C9EA9BC8EB9BC6EB9DC6EB9DBEE396D1F3A7D9FBAFC7E79CC1DF97CFEAA3D2ECA5C9E79F
C8EEA3B3DC8EC8EF9EE0FFB1CFF19DB5D280CDE597DBF3A9D0E7A3D1E7A6CEE7A6CCE7A4
C9E9A0C9EC9CC7ED96C6EC95C8EB9BC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EB9BC8EB99C6EC97C6EC99C6EC99
C6EB9BC8EB9BC9E99ECAE89ED2ECA5CAE19BC2D595A7B577D8E2A6DBE3A8CACF97ECEDB3
E4DEA2A8A061605A1C545312797939909552A9B26FD0DB96
E1E197DAD998DDDBA8D5D1ACFFFEEAFFFFF4FAF7F0F7F7EFFEFFF0F8FDE6F7FFDFFBFFE1
F4FFDAE2F1C8D4E3BCD0E2B2DCEFADBCD088C6D997EAFEC3CBDDAB758B5D516C4396B68F
C7EEC2B9E3B3C1EEB7BDE7A8CEF2ACCBEA9E4A6111D7EFA1CEEEA5CAE8A8DEF3BBF4FCD3
FFFFE4B9B2A2FCF3EEFFFDFDFFFEFFF9FCFFFBFFFFFAFEFFF3F1F2FFFDFBF6E8E7AB9C99
FFFCFAFFF5F3FFFDFBFBF3F1D5D0CDFFFEFBFFFEFAF2EFEAFEFBF4FFFEF5FBF9EC969485
959480A4A38E3D3C27F1F0DBFFFFF0F5F3E7F4F4E8FCFEF1FCFFF4F9FFF1E9F7DDD4E5C1
BED1A3D5E9B491A46CA6B57CD0DDA7D8E0AFD4DAAEE3E9B9D9E3A7E0EFAED7ECA9C5DE9A
C8E39ED0E9A5BDD08E6E7839B7B87CDFDAA05E581E79743AE0E1A5D1DB9CD8EBA9CFEDA5
C6EFA3C3EE9EC4EB98C6E995C8E893C9E692C6E393C2E195BBDB92D6F7B2D2F5B1C2E39E
C5E39BCDE599CEE394DAEA9FC3CE8C686E329D9E62E2E2A6B9B97D717236545A1A7A8543
8C9B56D2E8A0D9F1A7D5EFA5D9F5AABDDC90BEDD8FD4F3A5CAE99BCAE99BCAE99BC9EA9B
C9EA9BC8EB9BC8EA9DC8EA9DC8EA9EC0E095BDDB91CEEAA0D8F2ABC9E39CC5DC96D3EDA6
C9EAA5E3FFBFAFD185BADB8CCFEF9CC3E08EE9FFB5C3DE91CFE9A2CCE7A4CAE4A3C9E6A3
C9E9A0C9EB9EC7ED9AC7ED9AC8EB9BC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EB9BC8EB99C6EC99C6EC99C6EC99
C8EB9BC9EA9BCAE89ECCE89EC6DD97D6EBA6E4F4B5B1BD7F9BA368E8EDB3CACF95969A5F
7C7C3E7C7C3C9B9D5ECCD18FE2E8A8D8E39FD0DF9CD4E59F
D8E595D0DE93D3DEA2D8E1B4FEFFE6FEFFF1FFFFF6FFFFF6FFFFF3FFFFEFFFFFECFFFFEA
FFFFEAFFFFEAF5F9E2EAF1CFCFE1A5E6FBB6D0E4A7C9DBA7CCDEB4C7DDB96A836626472A
547B5CBDE9C5AFDDAEBDEAB1C6EFADD1F5AB83A050CFEB9EC7E6A2C2DEA3E2F4C2FEFFDF
FFFFEAD9D1C6FFFCFAFFFDFFFFFDFFFAFAFFFBFEFFFCFFFFEDECF1FFFDFFFFFBFDA39896
BCB2A9F9F0E7FFFEF4FCF5EDB2ABA5D3CEC8F5EDEAFFFCF8FCF7F3FFFFF8F6F3ECB3B0A7
AEABA27D7B6F0D0B00FFFFF1F3F5DFE4E8CFF7FCE6FEFFEFF7FEECFBFFEFE5F2D6C1CFAC
E0F1C440521E8A9C62DAECB0E6F5BACCDBA2D5E2ACC6D59CCCDF9FC2D794CCE5A1CDE8A3
D6F1ACCFE6A2C7D7967E8748CCCC90756F35565016918F54DFE5A7CFDE9DCAE19DBFE099
C2EDA5BFEDA2C1EC9DC5EA9ACBEA9AD0ED9DD4EFA2D5F1A6E4FFBAB4D18EBED897D7F0AE
CADE99CEDB95E2ECA3DCE29A4C4E0FA7AD71DBE7A7E3F3B2BED18FDCEBAAE5EBAB424405
ADAF6ECAD390CDE199BBD58BC8E89CD6F8ABCBEC9DCDEC9ECAE99BCAE99BCAE99BC9EA9B
C9EA9BC8EB9BC8EA9DC9E99DC8E89DE0FEB4D6F2A8CAE49BD1E8A2D5EAA5D3E7A2C6DB98
B9D392BCD997D4F2AAD4F3A7CFEC9AD3F09EAECB79D7F3A6CCE89EC7E59FC6E3A0C8E7A3
C9E8A2C8E89FC6E89BC8EB9BC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EB9BC6EB9BC6EC99C6EC99C8EB99
C9EA9BCAE99DCCE89ECFE69ED2E7A2CADB97D5E1A1D2DC9F94995FD0D39AA7AA714F5318
5D6325C5CE8DF1FCBAD9E5A3D6E5A2DAEEA9CFE49FCBE29C
D3EF98D2ED9CCBE4A0CAE1A9F7FFE0F3FFE6F7FFEDF8FEF0F7FBEDFFFFF3FFFFF1FBF9EA
FFFCEDFFFFF3FFFEF6EFF1DCC4D4A5CDE2A9C8DAAAD8E9BFCCDDBBD5E9CDC1D9C1AACAB2
12391E7EAA87B6E5BBB9E8B4C6F2B5A6CD8AD1F2AB1E3C00C3E0A0E3FAC4E4F4C7FBFFE0
F6F4DFF9F2E8DDD5D3EFE8EFF3F0F9FEFEFFF1F3FFFCFFFFFFFEFFF7F2F8FDF4F9FFFCFA
F2EADDE5DECCFFFFEFFFFEF1FFFCF3EAE3DBFFFDF8FFFDFAFFF9F7FFFAF7FFFDFDC8C2C2
EDE9E86D69665A5653FFFFF4FCFFE4CEDDB4E3EECCF8FFE5F4FCE4F9FFE9EBF4D9DBE5C3
A7B489D7E5B2DDEFB3D3E6A6C8DD9ABFD692F0FFC5D0E9A7D6F4AEC2E19BC8E7A1CBE9A3
D1ECA7C7DC99CFDB9B9A9E61D8D69B7A743A635D23FAFABEC2CB8CD0E09FD9F4AFBBDF99
B7E49FBFEEA8C9F3ABCAEEA4C5E498C3DE91CAE298D0E79FC3DA96D2E8A7E1F5B6D5E3A6
D5DE9FEFF1B0B5B26F342F007B773AD7DD9FC0D995BFE39BCAF0A5C1DF97E1EAA9C6C285
807639888445D6E19DDEF5ADC5E79AC9F0A1BADC8FCBEB9FCAE99BCAE99BC9EA9BC9EA9B
C9EA9BC9EA9BC9E99DC9E99DC8E69CC1DD93C0D78FD9EFA7BACE897B8C4892A15EC7D798
F8FFD1D3E8ADD8EEADD2ECA3BDDA8AC7E492E1FFAEBDDE8DC7E79BC6E69DCAE9A5CFEEAB
CEEDA9C8E7A3C6E69DCAEA9FC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EB9BC6EB9BC6EC99C6EB9BC8EB9B
CAE99DCCE89DCFE69ED0E69ED9EAA6DBE7A59BA5666D73351B1F0043440A73743B9B9F64
CFDB9BD5E5A4C9DC9AC5DA97CEE5A1C2DB97C1DC97DCFAB4
BEE48DCDF09EC6E7A0C8E6AAF4FFDDF5FFE4F8FFECF7FFEDF7FEECFEFFF1FFFFF1FAF7E8
FFF8EEFFFDF6FFF9F7EEEADFD9E4C6F3FFDFF8FFE4F9FFE8EBFADDF2FFE7EEFFE9C4E1C3
CFF4D2355F394372463B693881AD78B1D89FCFF2B877945A6F884FC7DBA6C8D5A9E3E9C7
FEFDE8FFFFF3A8A09EB3ADB1FDFAFFFFFDFFF4F7FFFCFFFFFEFFFFF0EEF3FFFAFEFFFEFB
FFF7EAC3BCA9ECE5D5FFFEF1FDF4EBD4CBC4F2E8E6FFFAF9FFF8F9FFFCFFDFD6D9D6D0D4
C5BFC3474344D2CECFFFFFF4F8FFDFC3DAA4D0E1B5D9E7C3E7F2D4FCFFEAEEF4D8CDD4B3
8B936ACFDBA9F0FFC4F2FFC4D4EEA5DDFCB0A3C377CFF4A7C0E69BC6ECA3C8ECA4C5E49E
C5E09BC8DB99C8D192949559E7E2A8585218E0DBA1DCDDA1D7E3A3D1E6A3CEEDA7C7ECA7
C1EBACBEEAADC2E9A8CCEDA8D6F0A9D9EFA7D2E69FCADE97DFF2B0D1E3A5A8B67B97A165
999D627472356C6425A09859D8D497E3EDAED0F1AABBEB9FC2F5A6C0E99DC2D18EE5E1A4
CABA7F716227919352C0D18BC6E69ACFF6A7C2E99AD2F7A9C9EA9BCAE99BC9EA9BC9EA9B
C9EA9BC9EA9BC9E99DCAE99DC9E59BDBF5ACD9EFA7D5E9A2ABBC7892A15EBFCB89CBD799
495621B0BE89D2E4A8ABC07BEAFFB8BEDB89C9EB97CFF29EC6E89BCAECA2D4F5B0DCFCBB
D7F5B5CCE9A7C8E5A2CDEBA5C9E99EC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EA9DC6EB9BC6EC99C8EB9BC9EA9B
CCE89DCFE79DD0E69ED3E49ED2DE9C87904F4D5315595D2076773DC7C88EE5E4ACCED498
D4E4A3D3EAA4DEF8B1D4EFA8C7E59DDDFDB4DCFCB3AFD187
BCE392CEF4A7C6EAA4CAE9ADF1FFDAEDFFD8F7FFE4F1FFE1FAFFE9F9FFE9FDFFEBFFFFED
FFFFF1FFFFF3FDF6ECF1EEE5D7DDD1EFFAEAF5FEEDF5FDE8FCFFEAF9FFE6F7FFE3C7E1B4
CEF0BE81A97568945F6C9865426C3C34592D6989609AB58AB7CB98D7E8B4CDD9ABDCE2BE
FBFBE1FFFFF0DFDAD6C4BEC0FFFDFFFAF9FFFEFEFFFEFFFFEFF0F5FFFEFFFFFEFFEDE9E6
FDF7EBF6EFDFBFB7ACEAE1D8FFFCF6FFF6F2C8BCBCF1E5E7FFFBFDFAEFF3CCC3C6F9F3F5
726C6E948E8EEDE9E8F3F7E6F5FFD8CDEAAAD5ECB6CBDCB0DDE8C6FEFFE8D8DCC1AAAD8E
959974D9E3B1E0EFB4F4FFC5CBEA9CCFF29ECAF29AC2EE99B0DF8FC9F7ACC6EEA5CDEEA7
D0E9A5DCECABCBD1939E9E62D6D19769642ADDDBA0DAE0A2D3E3A2C5DE9ACDEEA7C4E9A6
C8EDB7C6E8B5C4E1A9C6DEA2CBDE9ED1E09DD3E29FD4E3A0637133818F5269773C566024
64682D5654197C7436E6E1A1EAECADC3D490C1EA9EB7EC9CAFE897C8F7A9D4EBA5DADC9D
F0E1A6AC995FA1995BD8DF9CDFF6AEC0E598B9E596BFEC9BC6EB9BC9EA9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DD4F0A6C5DC94BED28BD6E7A1AEBA78949F5DCFD897DAE2A7
D4DAAA757D4CD7E4ACDBEEACCEE69CDCF9A7B9DB87C8EB99C2E79ACBEFA7DBFEBAE7FFC8
DEFCBECCE8ABC9E3A4D0EBA8CAE89EC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EA9DC6EB9BC6EB9BC8EA9DCAE99D
CDE79DD0E69DD3E49ED6E39ED8E1A05B61217C804395965AAEAF73DBDCA0E2E3A9D5DE9F
D8EDA8C4E096C9E79DD1EFA5BDDD92B4D68AC5E79BD1F6A9
C2E5A1D0F3AFC1E1A2BDDB9FD9F4BDC6DEACD3E9BBD1E2B8D8E7C0CEDAB6D6E0BEF1F8D9
F8FCE1E6E8D0D8DAC2D8DBCAD4D9D3FCFFFDFFFFFAF5F7E9FFFFEAF9FFDDF7FFD9D1E5B2
C0DDA7D1F4BCC4EBB4B8E0ACBDE2B6CBEEC6B2D0AE000C00000C000411006F7849D7DEB5
FFFFE4F5F4E0FFFFF493908BFDF9FAF8F6F9FFFEFFFFFFFFFEFFFFFEFFFFFEFFFDFFFFFB
FFFBF5FFFDF6FEF5F0DAD1CCFBF0EEFFF3F3F8ECEEE4D8DAFFFBFF524849F3E9EA827A78
6E6965FDFAF5FFFFFAFCFFEDF4FFD4BDDC98C6DFA5D4E8B7ECF8D4FDFFE5DCDFC4DFE0C1
F2F6D1CBD5A3DBEBADCBE59CC8EA96BAE289CBF89BBCEF93BAEE9CC9FCAFB4DE94C5E69F
CCE39FDBE7A7C7CB8EB2B075E8E3A94F4D12E6E7ABD0DA9BDBEEACC5E39DC9EDA5CAEEAE
D4EFC2E3F9D2DEEFC2B0BE8B757E455C6526747D3C96A0618D995B99A76A99A76AAAB579
D2DA9EE1E5A8DCDB9BE0E0A0D1DC98D8F2ABBDE69AC2F7A7C2FBAAAEE192C8E89FDDE8A6
E9E1A3BDAA706D5D22A19B5DD5E29DC6E69BCEFFAEB3E795C5EC9DC9EA9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DC8E299D4EBA3D6EAA3D0DF9A929E5C929D5BE2E8A8D7DCA2
CDD0A1E1E7BB828C57D0E0A2CBE199CBE79AC9E898CAED9DBEE298CAEEA8DFFFC2ECFFCF
E0FEC2CAE6ABC6DEA2CEE8A7CAE8A0C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EA9DC6EB9BC6EB9BC8EA9DCCE89D
CFE79DD3E49DD6E39ED8E19E5A5F1F6C6E2FE8E9AD9C9D61B4B579E6EAADCED297E1EBAC
C2DA90D9F8AAC6E597BADB8CD9FAABD2F5A5BBDE8ECAEF9F
C3DBA9D0E8B4CAE2AED5ECB6CDE4ACD2E9B1C8DDA5D4E8B3D1E3B1D0E2B0CCDEAEE8F8C9
F6FFD9E4F4C7DBEBBED0DBB9D3D6CDFFFFFD7E7B76908C80AAA591817D60D4D6AFC5CE9F
D4E6B4CAE3ACC0DEA8CCECBAC7E7B8C0DCB4CFE9C4CEE3BAD2E0AB414C121F2900DAE3B6
F8FEDAFFFFE8F7F8E6DFDDD1A6A39EFFFEFBFAF6F5FFFFFDFCFCFAFEFFFBF0F5EEFCFEF9
F8F4F3FFFBFEFFFCFFDFD4D8F7EBEFFFFBFFFFF2F9E7D8DD625658FFF5F4FFFCF7948D85
666257FCFAEDFFFFF1F4FFDFECFFCBCCEDA6CFE8AED6EAB9E1EDC9FFFFE8AAAC94FFFFE6
EDF1CCD8E2B0D1E1A3D1EBA1C8EC95C2ED91C1F390BBF193B5EB97B5E89BD3FDB3B5D48E
DCEFADCFD899A4A468959358DFDAA059591DD4DA9CD3E2A1D7EEAAC7E6A0CBF1A8D8F7BB
F5FFE0FCFFE6FFFFE09C9D735C5C2AA2A369D9DDA0D4DD9CD6E2A2D3E3A4D0E4A5D0E4A5
D3E3A4D4E3A2D8E1A0D6E39ECFE69EC9E99EC5EB9EC1ED9EBEEF9EBEEF9EC5EB9ECFE69E
D9DB9CE6DAA0B29D6657460EDBDD9EDAF1ABB3E495BCF3A0C3EC9DC9EA9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DD5EFA6D0E79FC9DD96D9E8A3CDD9978E9957ECF2B2CDD298
E3E6B9FBFFD5A3AB7899A76CCEE19FD6F0A7B5D187D7F7AECBEAA7C3E3A4E0FFC3F1FFD4
D9F5BBCDE9AED6EEB2CCE6A5CAE8A0C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C8E89CC7E79BC7E79BC7E79BC7E79BC8E89CC9E99DC9EB9ECAEFA1BFE496CAEA9FCFEBA1
CCE29AD5E49FD7E09DD2D795565819E1E1A3E4E4A6C9CB8C919656DFE5A5D8E1A2D0DC9A
D3EB9FCEED9DC9E898C3E493C9EA99C2E593C3E694CCEF9D
F8FFE5F9FFE3F9FFDFEEFFD0CCDFA8D1E5AACDE3A5D2E8A8C9DFA1DEF4B6C9E1A5CAE2A6
D7EFB3C1DB9CBCD695CDE1AE8C917BE0DDD6CFC8BEFFF8EBFFFDEFE6DBC7DFD9BFB6B797
9CA68190A1778BA173A0BA8AA1BB8B8DA77782996B697D4AD6E4A97681458590588F9B69
E3EEC4DDE4C2FFFFEAF4F5E3E1DDD2F7F2ECFFFEFAF4F1ECFEFDF8FEFFF7FCFFF8FCFFFA
FFFEFFFFFCFFF8F1F9FEF4FDCABEC8F4E7F0FFF9FFFEEFF4D4C8C8FFFDF8FFFCF2787566
2F2E1AFFFFECF1F5DCE3EFC9D4EEB1C1E09DC5DEA5CBDCB0E4EECCF7FBE2C8CAB2FEFFE4
EDF1CCD8E2B0CFE1A3D1EBA1C8EC95C2ED91C1F390BBF193BAEE9BC1EFA4BFE59CDCF7B2
C7D695DEE4A6D1D195BBB97E8A8A4E7E8245D0DC9CD5E8A6CAE5A0C0DF99C5E9A1DEFAC0
FEFFE8FFFFEDFFFFE6B6AE8A696234CDC891E4E5A9DCE5A4D4E3A0D0E5A2CDE6A4CCE7A4
CDE6A4CFE6A2D1E5A0CFE69EC8EA9EC5EB9EC6EB9EC5EB9EC2ED9EC1ED9EC2ED9EC8EA9E
D0DF9CE1DDA0A28D567E6731DBD599D8E9A5B8E799C3F8A6C5EC9DC9EA9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DC6E298CCE39BCEE29BDCEDA7D7E3A19AA563D1DA99E2EAAF
D5DBABEBF2C6DBE5B18C9961C7DA9ACBE09DE7FFBEBED897CDE6ACC8E3ACE2FDC8F2FFD8
E3FEC7D0E9AFCBE5A8C5E09DCAE8A0C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C8E89CC8E89CC8E89CC8E89CC8E89CC8E89CC9E99DC8EA9DBDE294D6FBADC4E499CFE9A0
D0E49DDBE8A3E0E7A47B7D3C6A6A2CD4D496DADA9C97995ABAC080CFDA98DBE7A7E2F3AD
BBD387CBE896C8E797D1F19ED0F1A0D6F8A4C7EA98C8EB97
FDFFF2FAFFE9F9FFE1FCFFDFD7E5B0D8EAACD5EAA5D0E79FCAE199CCE69DC6E19AC5E39B
C8E89FD5F7ABC9EB9E8DA865C2CEA6F9F9E1FBF6E3FFF6E7FFFBF4FFFAF6FFF8F2FFFBF4
FDFEF0F9FFECF6FFE4F7FFDFEBFFCED1E9ADD2E8A7C7DB96596827667234D1DFA47A8853
DBEBBEB7C39DFDFFE7FFFFEDDEDACECFC6BDFFFDF6FFFEF8FFFFF8FFFFF6F7FDF1F1F8F0
F7F6FCFEFAFFFFFCFFFFFBFFFAEEFADDD1DBFFFAFFFFFBFFFFFBFBFFF9F2FFFFF17E7D69
6E7058F8FFE0F6FFDDC8D7ACC6DDA5C8E1A8CFE2B4D1E0B9F2FBDEE4E8D1F5F7E1FDFFE5
ECF2CCD6E2B0CFE1A3D0ECA1C8EB97C2ED93C3F294BEEF94CFFEAEB3DB92C9E8A2CCE19E
D7E1A2DBDCA0CBCB8F555519616528BDC788CEE19FD4EDA9C7E59FC5E69FC6E7A0E7FEC6
FEFDE8FFFCF3FFF4E1B8AA8D60542AE2DBA5DDDDA1D4DD9AD3E49ECDE7A0CAE8A2C8E9A2
C8E9A2C9E8A2CAE8A0C9E99EC3EC9EC3EC9DC9E99DCAE99DC8EA9EC5EB9EC1ED9EC3EC9E
DAF4ADD0D696AC9B6358430CE1D69EDEE7A8C4EAA1BEED9FC6EB9DCAE99BC9EA9BC9EA9B
C9EA9BC9EA9BC9E99DCAE99DC6E298CFE9A0D4EAA2D5E9A2CDDE9A8E9D5A84904ED2DEA0
C9D39FE0ECBAC6D39ED9E8AF7F8E53B3C589CEE0A6DCEFB8CCDEAED1E4B6E0F6C8EDFFD4
E4FDC6D1EAB0C9E3A2CAE8A2C9E99EC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C8E89CC8E89CC9E99DC9E99DC9E99DC8E89CC8E89CC6E89BBCE194D3F5A9C2E096CFE69E
D5E49FDCE5A2CACF8D5B5B1BCDCD8FE6E6A8DFE1A28F9555CAD593C6D592D3E7A2C5DB93
D0EB9EDDFAAAC8E799C7E696BDDE8FCDF09EC2E595C7EA98
FFFFFBF1F1E7F6F9E4FEFFE1D6E0ACC9D99ACBDF97D1E79CCCE498CCE79A8CAB5F7F9F53
AFD184ABD08083A9546F8F44CEDFABFFFFE3FFFFEAFFFDF1FFFAFAFFF9FFFFF3FFFFFAFF
FFFDFFFEFFFAF9FFEDF6FFE1D8ECB7C1D796D2E89DD5EA9DCCD9949AA66899A86F5D6E38
D1E2B5DCECC5FBFFE8FEFFECEAE4D6D9CFC6EFE2DCFFFCF8FFFAF4FFFFF8F4FAEEFBFFFB
F8F9FEFFFDFFFFFCFFF2ECF8FFFBFFDFD3DDEBE0E6FFFBFDFFF9F7FFFAF1FFFCEB8E907A
7E8365D7E1BEDBE7BFD0DFB4CADDAFDBEEC1E4F4CFE9F4D6FCFFEDC4C9B5FFFFEDFEFFE7
EBF3CCD5E3B0CEE2A3D0ECA2C8EB99C4EC94C4F097C1ED96BFE89AC2E39CE5FCB8CDDC9B
E1E5A8EDEDB157571B636428909A5BE4F4B3CBE29ECBE9A3CAE9A3CFF0A9C8E7A1E6FAC5
FFFFEFFFFBF6FFF6E7B2A2885D5129E1DAA6DFDFA1D9E39ED1E59ECCE89EC8EAA0C5EBA2
C5EBA2C5EBA0C8EA9EC6EB9DC3EC9DC5EC9DCAE99DCCE89DCCE89EC8EA9EC2ED9EC3EC9E
C0DE96D5E4A1E3DDA155490FB2A970D9DDA0C6DF9BCBEFA5C9E99DCAE99BC9EA9BC9EA9B
C9EA9BC9EA9BC9E99DC9E99DC9E79DD3EFA5D4EBA3CDE39BCBDF9A97A864566522C8D899
E0F2B8BED199EFFFC9E1F2BBBECD967E8B56C7D3A3CBD6ABDAE4BFE9F5D1EAF9D2DEF1C4
D6EDB9CFE9ACCBE8A5D1F1A6C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C8E89CC9E99DCAEA9ECAEA9ECAEA9EC9E99DC8E89CC7E79BD0F2A6BEE094CDE99FD3E9A1
D5E29DB6BF7C8C8E4D9D9D5DF2F0B3DDDD9FDCE1A1B4BD7CA8B774CCE09BE1FBB4C1DD93
C1DF95C9E79DC2E297C3E599C5EA9DC7EC9FBFE497C2E89B
FFFEFFFFFFFDFFFFF1FEFFE4CED8A4C9D998D5EA9FDCF3A5B0C87C8EA85E94B066C6E49A
C8E89DB9DB8ECFF2A0D6F6ADD2E6B3FBFFE3FFFFEBF9F2E8FDF1F5FFF2FFFFF7FFFFF8FF
FFFBFFFEFFFFF6FEEFF8FFE6ECFFCDD4EDABD7EFA1CBE292D7E6A3D4E2A7D1E2ABCADEAB
D3E9BBC7D9B3F1FEE2FBFEEBFFFBEFFFF2ECDCCDCAFFF0F0FFFCFAFFFFFAF9FEF7FBFFFD
FAFEFFFCFFFFF7F6FCFCF9FFFFFAFFFBF2F7BCB1B5D9CFCEFFFCF7FFFDF3FFFFEF3E422B
71775BD3DEBCC1D1AADAEAC3CFDDB9E7F2D2F4FCE4FAFFEDFEFFF3A6AA9BFEFFEFF9FFE5
E8F4CCD3E4B0CDE3A3D0EBA4C9EA9BC7EA98C7EE9BC5EA9ACBEBA2CDE6A2CBDB9ACBD495
86864A2D2B0087874B909658CDDC9BD6EDA9C4E29CC2E39CC8E9A2CBEAA4C4E29CE3F5C1
FFFFF1FFFBF9FFFAECA2967C5C532ABFBC87DADF9FD9E69ED0E69DCAE99DC6EB9EC3ECA0
C3ECA0C5EBA0C8EA9EC8EA9DC6EB9DC8EB9BCAE99DCCE89DCCE89DCAE99DC6EB9EC6EB9E
C0DE96DAEFAAD3DC9D9A9B5F6D6D31D6D79BE0EAADCADA99CDE79DCAE99BCAE99BC9EA9B
C9EA9BC8EB9BC8EA9DC9E99DC5E59ACBE99FCCE89ECCE69DDAF1ABC1D691748843DCF1AE
CBE5A4D3EDAEDBF3B7F8FFD3D9E7B2CAD3A4B2B6918E9271EAEDD2FDFFE6F7FEDFD9E8C1
CBDFACCAE4A5C9E9A0CCED9EC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DCAEA9ECAEA9ECAEA9EC9E99DC9E99DC8E89CD2F4A8C6E69DD2ECA5D9EEA9
CFDB99757B3B58581AE3E1A4D5D494D4D494E0E7A4BDCA858B9F58C0DA91D5F5AAC8EAA0
CFF0ABC8E9A4C6EAA4C4E9A3D2FAB3C2EAA3C1EBA3C9F4AC
F4F4FFFEFFFFFEFFF4F9FFE1D6E2B0E3F3B2CCE196A7BC6F92A85DC3DA92C7E09CD3EEA9
E3FEB9C4E29AB9D78DCEEBA9C7DEB2F3FFE6FBFFF2FFFFFAFFFBFFFFF5FFFFF8FFFDEFFF
FFFBFFFDFEFFF6FFF3F7FFEAE3F9CACAE2A4CFE9A0CAE097D2E0A3D6E3ADD0E2AED0E6B5
C8DFB5C7DBB8F8FFECFDFFF0FFF9F2FFF4F1D5C1C2E2CFD1FFF8FAFFFCFCFEFFFDEFF5F1
FBFFFFE9EFEDFEFFFFFFFFFFFFFDFEFFFDFDCFC6C7ACA4A1FFF9F3FFFCF1CCCABB30331E
C4CDB2CDDBBAD7E8C4D0DFBEDAE2CAF0F5E1FAFEEFFEFFF4FEFFF6ACB0A2F9FFEEFAFFE9
E6F5CCD2E4B0CBE3A5D0EBA4CAE89EC8E89CCAEC9FC8E89DD8F2ABBED18FE3EDAEF5F6BA
4A480D97925898985C929B5CDCEFADBCD792C7E8A1C7EDA4C8E9A2C4E39DC7E09CE9F9C8
FFFFF3FBF6F3FFFCEFA39D836863399C9D64D5DC99D3E39ACFE79BC9EA9BC6EB9DC3EC9E
C5EB9EC5EB9EC8EA9DC9E99DCAE99BCAE99BCAE99DCAE99DCAE99DCAE99DCAE89ECCE89E
DAF5AEC7E29BB6CD89C4D493525C1D8F9054FCF7BFD2D397D1E59DCAE99BCAE99BC9EA9B
C9EA9BC8EB9BC8EA9DC8EA9DC8EA9ECAEA9FC6E49ACBE79DD8F2ABD3EDA69AB16BC6DF9B
BBDC97D4F4B1DCF9B9F4FFD0FCFFD8F2F9D0D9D8BAB6B19BE2DDCAE8E5D2E7E9D1D8E2BF
CBDDABC8E2A1C8E89CC4E795C9EA9BC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC8E89CC8E89CC9E99DCAEA9ECBEB9FCCECA1BADC92D6F6ADC5DF98DAEEA9
D0DB995C6222616123EEECAFDAD999E6E8A7DFE8A5A3B26DA9C078C8E89DBCE194BCE599
C6EBA8BFE6A7B9E1A2BCE4A5C6F0B0BCE9A8B6E4A3BFEDAC
FBFFFFFBFFFFF6FEF1F4FFDFDFEDBAD4E7A5A2B66E7A8F44B2C87FCFE4A1D1E7A7C6DC9E
BED496D2E8A8E8FEBDCEE7B0E6FDE0F2FFF8F8FFFDFCFFFFFFFCFFFFF6FFFFF9FFFFFAFF
FFFCFFFCFFFDF8FFF4F5FFECD8EFC5BFD7A5CFE8AED6EBB0E3F1BCE5F3C2E4F8C7D8EFC1
DCF6CFE3FBDBF8FFEFF7FBECFFFDF8FFF6F8E1CAD0D2BDC4C5B6BDF8F2F6FEFFFFFBFFFF
F9FFFBE9F3EAFCFFFAF4F7F0FBFAF5F8F3EFFFFDFADFD8D2DED7CFFFFFF47071618C917D
F8FFEAEBFADDE7FADADDEBD1EEF2E1FEFEF4FEFEF6FFFFFAFEFFFAD2D8CEF5FEEBF8FFE9
E5F6CCD1E5B0CBE3A5D0EBA6CAE8A0C9E79DCBEBA2CBE69FCDE09EE3EFAFA5A96C4B490E
999359E4DEA4B7B77BB2BC7DD3E8A5BFDE98C6ECA3CCF4ABC5E9A1C8E6A0D0E7A3E9F9C8
FCFFF4FEFFFDFFFFF3C9C9AD8C8D61999E64DAE5A1DAECA0CDE899C9EA99C6EB9DC5EC9D
C6EB9DC8EA9DCAE99DCCE89DD0E69BCFE79BC9EA9BC8EB9BC8EA9DCAE99DD0E69ED1E59E
CEE59FC1DF97D2F6AEC7E8A17E935262662BC2B17DE6D7A0D4E49DCCE89BCAE99BC9EA9B
C9EA9BC8EB9BC6EB9DC6EB9DC9EEA1CCEEA2C4E69AC8E89DC6E49CCDE8A1B3CD8692B068
C9EFA6D1F6B0DEFDBAEFFFCBFCFFDAEFF3D0FFFFE8FFFEEFEBDED5CDC5B8CFCCB9E0E7C6
D6E8B6CBE6A3C9EC9CC5EB96C8EB9BC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
CAEA9EC9E99DC7E79BC6E69AC8E89CCAEA9ECEEEA2D0F0A5C7E79ED1EFA9C5DC96D4E8A3
D6E19F8A8F4F7E7C3FCAC88BE2E1A1DFE1A0D1DC989CB069BBD78DDBFFB3C0E99AC5F1A6
BBE5A6CAF3B9AAD69BB5E1A6A7D499C9F9BDB8EAADBFF3B5
F8FEFFF9FFFFF6FFF3F9FFE6DAEBB7B9CC8AA7BB73C2D78CC9DF97D6EBA8CCE0A5D5E8B0
D9ECB4C6DA9FCFE3A6E1F7C6F1FFF3EAFFF8F5FFFFFBFFFFFEFBFFFFFBFFFFF5FFFFFCFF
FFFFFFF8FFF8F0FDEBF4FFECE6FCD6CDE7B8CEE9B6C4DBA5EBF9C8F4FFD3F7FFDCF0FFDD
F0FFE5F2FFEAE8F7E2FEFFF4FFF6F4FFF9FDFFF7FFFFF7FFA897A1FFFBFFFBFCFFF7FFFF
EDF7EEF9FFF6F3FBF0FEFFF8FFFFF8FFFFF8FFFEF8FFFDF7D7D3CAFEFCF0818274878C78
EEFAE4F6FFEBF5FFECF8FFEDFCFEF1FFFFFAFFFCF9FFFFFDFFFFFBF5FBF1F4FDECF1FFE3
E5F6CCCFE6B0CBE3A5D0EBA6CAE8A2C9E79FCCEAA4CCE5A1D3E3A2D4DD9E9FA064645F25
E6DDA4E6E0A6C3C387959F60C9E09CD2F3ACBCE49BC7F1A7C0E49CCDEBA5D2E9A5E0F0BF
F8FFF1FCFFFDFEFFF3DEE3C59C9F72959D62D3E09ACEE396CDE897C9EA99C6EB9BC5EC9D
C8EA9DC9E99DCAE99DCDE79DD3E59BD0E69BC9EA9BC5EC9BC8EA9DCAE99DD3E49ED4E39E
D2E7A2CBE9A1C2ECA2BEE89EE0F9B7CED297624B19B49F6AD7E29DCCE89BCAE99BC9EA9B
C9EA9BC8EB9BC6EB9DC6EB9DC0E598C6EB9EC3E599CCEEA2C3E199D1EFA7D6F1AA83A35A
C0E99DC4ECA3C1E19ED3EBB1D4E0B2E2E3C1FAF3E0FCF0E4FFFBF4CDC3B9CBC5B5EEF3D3
E4F6C4CAE7A4CAED9BCBF19AC8EB9BC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
CAEA9EC8E89CC6E69AC5E599C7E79BCBEB9FCFEFA3D2F2A7F1FFC8C4E29CD3EAA4D2E39F
DAE5A3C3C888848245A3A164E4E3A3D3D896D9E4A0BBCF8893B167BFE598B6E191C2F0A5
C5F1B4BCE7B146733C204F18001800487B4253864D77AD73
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.65873 0.349206 0.97619 0.666667 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
D5DAC6CDD5BDD9E2C3D2DEB6CBDCA8D7E6ADD0DEA3C9D397A3A8704E531B5C61297A8549
D6E9A7D0ECA2C4E797BFE494CFF1A5C6E49CCDE49E4B5F1ABBCC88C9DA96C9DA94D2E8A0
C8E49ACDEDA2C9E99EC1E397C9E79DD2EEA4BFD78D9DB368ABBE6FDFF0A0D2DC93BBC07D
807E4354511E6F6A421B1B00575E3FC8D7B8D6EAC5D7F1C2C8E5ABC4E39DD3EFA2CDE39B
B6B98EB8B497DFDFC3E0E4CBF2F9E7FBFFF6FEFFFBE4E4E6040007DACFDD948695FBEFFB
FFF8FFFFFEFFEFF1ECFFFFFAFAF2F0FFFBFBCBC1C07C7472FDF4F5FCF6F6FFFEFDFFFEFB
FEFDF9D0D0C6EDEEDCC2C5AAE4E6C1A8AB7E8E925F6B753890A65EB1C97FCEE3A0D9E9AB
AFBC84283300545B25E5EDB2CBD694ACB9734B5810D0E296D9EFA6CAE49BCFE9A2C8E5A3
C9E6AEC1DDACF7FFDFF9FFE1F2F9D8FFFFE3FAFFDACDD6A9616F3CB0C38BCEE0ACD1E2B5
D4E2C1E3EAD8FFFFFAF9F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFF4F4F43B3B3B
E7E7E7F5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FEFFFFFFFEFFF4ECEAFFFBF8F2DDDAFFF8F6FAE4E7FFF7FDFFFAFFFEFBFFFCFFFFF8FFF6
EEFFDDD6EDB9CEE5A1CFE99FCAE59ECFEDA7C3E29CC9DC9AB1A86D5A4E14DFDFA1D9E8A5
C8E49ACCECA1D0ECA2C5E79BB9E897BDEC9BCCE89DD2E19CD2D89AE1E5AACDD6972D3900
B5C982C8E096C9E89ACCEF9FC0E391CAF09DD2F5A5C9EC9CCCEB9FA9C87CF1FFC2C3DD93
D1EC9D7F9C4ACDEA9AC6E796C8E998C5EB98C1E79498BF6C
F6F9E6FEFFEDFCFFE8FBFFE1E4F1C3D3E1ACE2ECB7D9E2ADE5E9B6CED29FD8DCA9B4BF85
C7DA9ACBE79DD0F3A3CDF4A3CCEEA2C1DF97D5EFA88DA25D94A561D9E8A5DCEDA9CADF9A
C9E39CCEECA4CCECA3C3E39AC5E39BD1ECA5D1E8A0C6DC934D6215D2E395D9E59BDFE4A1
DEDEA2C6C58F999669575932000700637251C6DCB5CFEBBBB8D59BCCEBA7CAE99D93A863
878D61FFFFE3FAFBDCF4F8DDFCFFEDFBFFF3F4F9F2EAEAEA0300057B717C897D89FFFAFF
FFFAFEFCFBF9FEFFF8FEFFF8FFFDFAF9EFEDC4BAB8FEF6F3FAF5F2FFFEFBFFFBFAFFFEFA
FEFDF9EFEFE7BBBCACB0B29AAEB28FB0B68AE1E8B4D4E0A2C2D68FCCE49AD0E3A1CCDC9E
808B530E1700E3EBB2CFD79BB8C3814C5913D4E499CFE497CBE196CBE59CDDF8B1C8E5A3
C9E6ACD4F0BDEFFFD7F4FFDAF9FFDEEEF6CFC6CDA4B5C193C3D19CDDF0B9D2E6B1D6E7BB
E6F3D5F5FCEAFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFAFAFAF1F1F1
6A6A6AFFFFFFFFFFFFF7F7F7FDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFEFEFEFEFEFEFEFEFF
F9FAFEF8F8FAFFFDFBFFF2ECCEBBB4A49089E2CDCAFFF7F7FFFCFFFFFEFFFBFFFBF8FFF3
EBFFDAD4EBB5C9E09CC8E298CAE59ED1EFA9CCEBA5D2E5A3C3BA7F564A10B6B678C5D491
CAE69CC9E99ECCE89EC7E99DC0EF9EC2F1A0CFEBA0D5E49FDFE5A7D1D59AA7B07192A15E
C6DA93CEE89ECCEB9DC5E898CDF3A0C7ED9AC1E494C5E697D8F7ABD8F4A9C1DB92CDE59B
CDE5978FAA59C7E494D4F3A3D1F2A1BEE18FC3E996C4EA97
CBCCBCDEDFCDFCFFE8FCFFE4E5EFCAD1DCB2D2DBB0D6DBB2DDDFB7D7D9B1E1E4B7D7E1AD
D2E6A7CAE8A0BDE390C0E794C9EEA1BFDF96DBF6AFC4D9948A9A59D8E7A6DAEAA9CDE09E
CBE29ECCE7A2CCEBA7CAE9A5CBE8A5D0E9A7D1E7A6CFE4A16E843BD0E298E7F4ACC5CF8A
CACF8FE0E4A9D8DAA8969E6F707F565C7148BAD5AAC1DEAECEEDB4CDEDACBCDC93BDD392
9BA276ECEDCBFFFFE1FEFFE3F3FEE0FAFFECFCFFF4E4E7E0050306575058B0A6AFFFFBFF
F5F1F0FFFFF8FCFFF3E6EDDDFDF9F0F3ECE6BFB8B0FFFEF6FFFEF8FFFEFAFFFCF9FFFFFB
FFFFFDE2E3DEB6B8ADFBFEEBF5FADAD6DDB3DFE9B4D2E0A2DFF3ACD3E79FD8E8A7CFDDA0
727D436A733CE1E9B0B4BC8078833F7C8941ECFEB2D4EB9DCBE397C7E398CBEBA2CBEAA6
C8E7ABCDEAB2ECFFCFF7FFD9D2DFB1A3AF8197A071C7D5A2D7E8B2D7EBB6CBDFAEDCEEC6
F6FFE7F9FFF1FFFEFAFCFAFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF3F3F3F2F2F2
636363FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFF4F4F6FFFEFAFFFDF3B6A999918171E6D6C7FFFDF1FFFEF5FDFFF4F9FFF4F7FFED
EAFFD6D5EEB5CAE39FCAE49BC7E29BCCEAA4CFEEA8D5E8A6DDD4995F5319969658CDDC99
CEEAA0C7E79CC9E59BC9EB9FC4F3A2C3F2A1CDE99ED5E49FDCE5A690965A909A5BDAE9A6
D0E69ED5F1A6C8E99ACAED9DC5EB98C9EF9CCDF0A0C7E698C2DE93D0E89ECAE098E2F6AE
A2B969B3CC79CBE695C8E593BFDE8EC2E392CCED9ECDF0A0
BFBCADC0BFADF8FBE6FEFFEAFEFFE6FEFFE4F1F6D8FFFFE5FFFFE6F1F2D3D4D8B3DCE5B8
D4E8ADD7F5ADC7EE9BCEF8A2CAF1A2C2E49AD5F0A9CBE29C9FAF6ECBDA99C7D796D7EAAA
CFE5A4C7E1A0C3E0A0C8E5A5CEE8A9CDE5A7CCE2A4CBDFA0CBE09D758942A9B972E7F2AD
E5ECA9CBD191E3EBB0D2DFA9D8ECBBBED8A85E7B4B83A572C3E6AEBCDEA1D0F0ADC1D99B
879061E4E9C0C9D0A4DBE6BBCEDDB4D1DFBCCED8BFD1D8C8010000130F10928C90FFFBFB
FFFFF8EAEEDFDCE6CDFBFFECF1EFE0F5F1E5B9B3A5F2EFE0FFFFF1FFFFF3FFFFF7FFFFFA
FFFFFDA9ABA6B3B6ADFCFFF1FCFFE6E0EBC0C7D49ECDDD9EC8D993CDDE97D3E2A1E8F3B7
D6DFA6D7DFA6555D225C65266F7A35E2F0A5BED182D2E999D0ED9DC9E99DBCDE94C8ECA6
C7E7A6BEDC9EEBFFC9E9FCC58E9C67828F5AABB882D9E8B1C5D8A1D3E7B2DCF2C3F2FFDE
F9FFEDFCFFF6FCFBF9FFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9F8F8F8FFFFFFFFFFFF
3131313A3A3AF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFE
FCFFFFFAFCF9F6F4E8FFFFEDA79D8492876BD0C5A9E8E3C6EFEFD7EAF0D6E6F5D8E5F9D4
DEF6C6D3EDB0CDE8A1CFEBA0C8E69EC8E6A0CBEAA4CDE09EE8DFA462561C7F7F41DCEBA8
D1EDA3C8E89DC9E59BC9EB9FC1F09FBDEC9BC9E59AD4E39ED0D99A636B2FB2BC7DD6E7A3
CDE49CD6F2A7BFE091D1F4A4C7ED9AC0E391C9EA9BCCE89BCDE59BC9DD95DDEEA87A8A43
77893DC8DD8ED2E79AD6EEA0D4ECA0DAF4AAD1EDA2C4E096
FFFFEFD5D2C1A3A492A7AA95C7CCB6EEF3DDFFFFEFFFFFF1FFFEEFFFFFEDE1E4C9D3DEB6
B7CC94C7E6A0BDE791BAE68DCAF1A2C3E89BC8E69ECAE19B94A463D1E09FD0DEA0D7E7A9
D6EAADCFE7ABCEE7ADCFEBB0CFE8AFCBE2AAD0E5ADD8EBB3DAF0B2697E3B697A36DCECA5
C4D088E7F2ADD4E09EC9DC9CCBE3A9CCEBB284A771597E48A3C892CBF1B6E2FFC7B1CA90
B7C48FB3BC87DBE6AECAD9A0D1E4ADDAECBACAD9B2CCD6BB00020001010096938EFFFEF5
FFFFEFE7F0D3C4D3ACF3FFDBFFFFE8EFEED9B3B19AFFFFE8FFFFE6FFFFECFAFBEBFFFFF6
F6F7F1C5C8C1BDC3B7EAF3DEECF7D5D2E2B3D1E3A7DCF0ABD2E19CE6F3AECAD495DBE3A8
D2DAA19BA068484E12687130B7C27DD6E69BD2E798CCE594CAE999D0F2A5CCF0A8BFE49E
C6EAA4C7E6A3D9F3B2C4DA9C86985CB9C88DD4E3A8C9DBA1CEE3AAE3FAC6F4FFDCF4FFE3
FAFFEEFDFFF5FFFBFAFFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEEEEEF0F0F0
AFAFAF000000FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFDFFFE
FCFFFDF6F9F0FFFFEFFFFEE1ABA67E8F885ACFCB9CDCDBABD9DFB3D3E0B4D0E3B6CEE6B4
CBE7ACC9E6A3CBE79ACEEB9BCFEDA5C7E59FC9E8A2C8DB99E5DCA1584C126B6B2DD3E29F
CFEBA1C9E99ECCE89EC9EB9FBFEE9DBCEB9ACBE79CD7E8A2B7C1828D975ADDE9A9C9DD98
CCE39BD0EFA3C0E393CAEF9FCCF29FC2E593C7E698CDE89BD4E8A0D5E59ED1DE996C7733
B3BD78E3EEA9C5D08CD4E39ED1E09DCADB97C8DB9BD8EDAC
F4EEDEFFFFEFB8B7A5B5B6A6999B8D898B7EECECE4E5E4DFFCF7F3FFFFF6FBFDE8FCFFE3
DBEFBAD0EFA9C4EE98C2EE95C3ED9BC3E89BC3E199D4EEA7738342DDEBADE5F3B6CCDBA0
D1E5AADFF7BDF2FFD2F2FFD6E6FECAD3EAB6CDE1B0D0E4B1BED69CD9EFAFB5C8864E5F18
C6D489CFDD92D4E69CD6ECA4C7E4A2CCEEB1BEE4ABC0E9B17AA16A7DA46DB6D9A1DCF8BE
D9E8AD727C3F899857D8ECA7CDE4A0D0E6A8CEE0ACAAB68E040A00050800C4C5B7F6F7E5
F1F7DBF5FFD9D5E7B5CEDEADF1F7D3F3F4D5C4C5A3B4B895EEF2CFEFF4D4F0F4DBFDFFF0
FEFFF6FCFFF8B5BDAEF9FFEDF7FFE1CCDEAAD0E5A4CEE29BD3E39CD0DB97DAE3A4D5DDA1
4B5018575C22A4AA6EF1FAB9D8E49CC9DA8CD9EF9DD3EE9DC4E594C9EEA0CEF6ADBDE59E
C9EDA5CFEFA6C4DF9ACAE19DC0D391DEEEADC6D999D4E8A9D2E7AEE6FDC9F5FFDFEEFFDF
F6FFECFEFFF8FCF8F9FFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBEBEBFFFFFFFFFFFF
FFFFFF1E1E1EE2E2E2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFD
F6FBF5F5FBEDF0F3D8EEEEC8A9A673B8B67BCECE8EEBF0B0D5E1A3CFE1A5CAE2A8C6E2A5
C6E5A1C7E79BCAEA97CEEB99CEECA2C5E39DCBEAA4D0E3A1E6DDA25C5016747436CDDC99
CAE69CCAEA9FCEEAA0C8EA9EC0EF9EC3F2A1CFEBA0D2E39D8F9B5BD1DB9EDBEAA9CFE49F
CDE79ECDECA0D0F3A3C3E898C2E895CBEE9CCDEC9ED1E99DCDDE97D4E19B78813E858C49
D2D495F5F7B8D9DDA0E3E9ADDAE0A4D6E0A4D5DEA7D7E1AC
F7F0E0FFFFEFE7E4D5FFFFF3FFFFF8F7F8F3FDFBFCACAAADF9F3F7FFFEFBF9FAECFAFFE4
D7EBB8BCDB95BFE993C6F398C0EA98C7EC9FC7E59DCFE9A280904FC4D294D1DFA2CFDEA3
CEE1A9DFF6BEF4FFD8F2FFDAF4FFDCE7FDCED5E8BBC7DAACD4EBB5CAE2A6C7DC99E5F6AF
8B9B50C8D98BDFF4A5CBE397CFEEA8C0E5A2C7EFB3BAE5ADC7EFBA001400BADFABC0DDA5
C7D798E4F1AB384A00E4FBADC9E495D3EDA4CFE5A5C3D3A2000A00060A00C0C2ACC5C9AE
F3FED6DFEFBECBE1A3D9EDB0CFD8ABEEF3CBE0E6BA73794BD8DEB2D4DBB2E3E8C8F6FBE4
FBFFF0FAFFF2A5AE9DF5FFE8F8FFDFC9DEA5CDE7A0D4EA9FE7F4AE5D6623727B3C9AA064
7B7E47EEF1B8E0E6AACBD493CEDA92DEEFA1C5DC8AD4F19FC9EA99C2E99AC1EBA1C4EEA4
C7EDA2C6E89CC1DD92DCF4AAC7DD95D1E59EBBCF8AE0F5B4D0E5AADFF6C2F5FFE1F3FFE4
FBFFF1FEFFF8FBF7F8FFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFFF6F6F6
FEFEFE7070707A7A7AFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFCFCFCFAFCF9
FBFFF8F2FAE5CFD5B3CACD9E9F9F61C5C77EA1A558D0D98AD6E799D2E89FCDE8A1CAEAA1
CAEB9CCBED99CBEC93C9EA93CCEB9FC1DF99CBEAA4D7EAA8E2D99E63571D939355D2E19E
C8E49ACBEBA0CDE99FC5E79BC2F1A0C9F8A7C9E59ABACB85899555E4F0B2CFDF9ECEE39E
D4EEA5C8E89CCEF3A3C3EA99C1E794C8EB99C3DF92D0E89CDEEEA7D9E49F565D1A626425
58531B625B25544E1A514E195C59269C9C6AE0DFB1F8F9CD
CCD3AAD9DFBBFAFDDEF5F7E1F4F6E8FFFFFAFFFAFEEBE8EF95969BE9EBEAFFFFF6F9FCE1
D2E2B3C6E49ED2FAA4BBE68CC1E899D0F2A8CFEAA5BCD38FB0C08199A76AA5B376DBEDB1
D4E8ADD0E7AFD0E8B4DBF3C3EFFFDBF7FFE4F1FFDEDCEAC7C7D6ABD6E7B3D5E4ABCBDA99
D6E39D99A95E8DA051899F54C6E49CCBEBA8BDE1A3C5EBB2C2E7B1C1E6B093B680AECD94
D3EDAEC5DF98DAF5A684A04C89A455D1E99FD6E9A7D1DFAA060E00565B3DE7EDC97B835A
EBF8CAE4F7C0C5DE9DCCE2A2DCEBB4D8E2AEEFFAC2BCC78FBDCA94CCD8A6D5E0B5E8F2CF
E1ECCEFBFFECE8F5DBDDECCBF8FFDDD2E7AFCCE5A3D0E49F919A5B34350084824F757342
B2B080CFCD9DDADCAADFE7AEDAE9A8C6DC94D7F3A8C2E394CDF0A0C9EEA0C5EA9DCBF0A3
C5EA9CC2E497CCE89DCDE59B95A962D4E8A1DCEDA9C7DA98CBE1A3D3EAB2E9FFCFDFF4CD
E2F0D6ECF3E3E6E7E1FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFF9F9F9FEFEFEFEFEFE
FFFFFF717171F1F1F1FBFBF9FFFFFDFFFFFBFBFEF7F7FAF1F2F5EAECF2E4E8EFDFE6EDDB
ECF6DDD2DDBBD8DFB5A4A973BFC27FB8BC70A2A959D7E391CFE291CDE695CAE99BC8EB9B
C9EC9AC9ED96C6E98FC2E48ECFF1A5C1E29DC9E6A3D6E6A5D2CC905D5318A2A264D2DF9A
C9E59BCCECA0C8E89DC1E396C4F1A0CEF7A8C1D98FA0AF6AA9B875D7E7A6DAEEA9C0D791
D9F5ABC5E599BFE194C7EC9EC0E595D2F5A5CCEB9FC6E096D0E49CD4E59ED5E29DD2DB98
E3E3A5D0CE93E2E0A7E7E6AEB7B781969662989A699FA273
D6F7A0BCD788E8F8B9E5EEBFEDF2D4EDEBDEF8F2F2FFFEFFF3FFFFADB9B7867B75FEF2DC
F1F8CCD1E8A4C7EA96BEE48DCAEA9FC8E3A0D5EBABD2E4A6D3E3A592A06396A668C4D899
D3E9A9CFE9ACD1EAB3E0F6C8F7FFE7FBFFEFFFFFF6EEEEE2FBFDE7E2E6C5EEF4C8DDE4B0
DDE5A9D4DF9BD8E59FAEBD785367228DA362CAE2A6C2DBA1D4F0B6BAD69CD8F4B97B9A61
8FBA85B8E5AACBF4A6C7E8978EA55F879557DEE8ACB6BC8C0A0D005C6045DFEBB9C8DA9E
798E55CEE5ADCDE6ADC7E1A4D7EDACB9CE89DAEFAAD8EDAAA7BC7BD7EBACDAEEB3C8DBA4
D3E3B4F3FFD6F8FFDD9DAE81F7FFD9DDEFBDD0E2AED1DDABACA9807B6E4B7162436E5D41
837258EDDFC5D6D1B3E1E7C3C7DAACD3F0B8C4E7A7C2E7A1CBEDA1C9E89AD1EC9BCCE796
CBEC9DC3E598D5F0A9CEE59F8FA2607B8B4AD9E8A5D0E49FD2E9A3CBE6A1C5E2A2CBE7AD
D3E9BBCFE0BED9E5CDF5FCECFFFFFAFBFAF8FAF9F7FFFFFDFFFEFFFFFDFEFCFCFEFFFFFF
FFFFFFFFFEFFFEFFFFFDFEFFFCFDFFFBFCFFFBFCFFFAFEFFFAFBFDF8F9FBFEFFFFFBFCFE
FDFCFF828284969696FEFFFAFEFFF8FBFFF0F4FCE5FBFFE8CFDDB9D0E1B7D8E9BCCFE1AF
C8D9A5DCE9B4959C66A0A36AD0D293C8CB88A7AC69D4E098D1E69BCDE79DCAE99DC8EA9D
C8EB9BC8EB99C9EB97C8EB9BC8F0A7C0E5A0D5EFAED2E0A2A2A065706A2E868646DEE9A4
CEE89EBBDE8EC9F0A1C9F0A1BADF91DEFAAFC9D691BBC682D5E69FD6ECA3D3E9A1C8DF97
C6E298CCEAA0CBEBA0C3E398C1E397D0F2A6BDDF93C6E89CCBEBA0CFEFA4BCDC91D6F0A6
D7EA9BD7E598DDEBA0C7D78ECFDF98E0EFACCBDB9AD4E4A5
9BC863C8ED90CEE398D9E2A9CDD3ADE5E4CFF1EAE2FEFFFDF0FFFFC8DCD16E6158B19F8B
85865C738549C6E599D6F7A6CAE59ED1EAA8C1D596D8EAACE4F4B6C2D29496A969B1C683
CEE7A3C6E09FC8E1A7E9FFD0F9FFE8F7FEEEFFFFFBFBF6F3FAF6EAFFFEE9FFFFE3D6D8B0
D3D7A5D8E0A5E1EBACC8D49497A6656F7F40B0C286D7EBB0D1E5AACCE2A4DBF1B39BBA7F
679767B0E5AFC0EEA3BADD8DE4F9B89FAA70CDD29AB2B5880103000F1500D1E0A7D9EEA9
859D61C9E2A9E8FFCAD4EEB1BDD790E6FFB4C9E399B4CE84B8D28B9DB672C8DE9DD5EBAB
CBDFA4E3F6BEE5F8C18EA06CC5D5A4C2D2A1CFDFB0ECF5CAF1EDCAB1A38877654D77624D
A08977E6D5C3FFFBE6E0E4C9DDF1CCE0FDCFC6ECB3C3EAA9CCEEA4CAE699D2E997CFE694
D2F3A2BFE194CDE8A1CFE6A2ADBD7E859453D1E09DD2E39DD0E89ED5F1A6CFEDA5C7E6A3
CDE6AFD3E9BBE5F6D4F9FFEFFDFFF9FFFEFFFFFEFFFFFFFFFEFCFDFFFFFFFFFFFFFDFFFE
FBFBFBFCFEFDFEFFFFFCFFFFFEFFFFFCFFFFFCFFFFFBFFFDFCFFFDE7ECE6FCFFFDFEFFFD
FAFCF9B1B1AF9C9D97F4F6EBF7FBEAFCFFECEDF7D5D7E6BBD3E5B1DEF3B8BDD393D6ECAB
D6E9A9A9B779475114BBC185DDDEA295965ABCC282DDE8A6D1E59ECCE89EC9E99DC8EA9D
C6EB9BC8EB9BC9EA9BC8EA9EC0E8A1C5EAA7C3D999D8E2A5939357545011A3A564D9E49F
D0EB9EC2E797C3EE9CC1EB99C4E498D0E69DBEC582A8B26DD3E9A0C4E093C2DE93CFEBA0
D8F4AAD0EEA4C8E69EC7E59DC9E9A0CEEEA5D3F5ABCBEDA3C7E99FC4E69AC4E99CC0E097
C4DB97CBDE9CD8EDACD9EDAED8ECB1D1E4ACC4D7A0CEE3AB
E0FFBBB9D9908C9A5D9FA6738C936ACACDAEFFFFECEEF3DFE8FFEBEAFFE9FFFDEDFFFCE6
D9D9B3DCEAB796B071708D4AD6F1AAD9F3ACCADF9CCFE2A299A96ADAEAABC8DB998FA660
D0EBA4CEECA6C1DE9ED8F0BCE0F0CBEEF6DFFFFFF6FFFFFAFFFFF6FFFFF1FFFFECE9EDCC
EDF2C9E2EAB7F1FAC3E3EEB2D5E3A6CADA9C8EA0648FA36670844765793ACEE2A3D3F0B6
C3F1C271A36ECBF6AECEF0A3C0D495859358DFE7AEC1C799000400000600D3E5ABCDE29D
93A96BD7ECB3F7FFD4E4FABCCCE69FCAE49AC7E197D7F1A798B26B425B17D9EFAECCE2A2
CDE1A4D4E8ADCBDEA6A7BA83C3D49ED5E6B2DCECBBF2FED0FFFFDCCDC7A54D4224827258
6F5D45FFFDE6FCF4DDFEFFE4F8FFE3ECFFD8C9ECB2C4E9A6CCEDA6C6E597D0E998D0E996
D0F1A0C2E497CDE8A1C9E09AC9D99899A867D0DF9CD2E39DC7DF95D0ECA1C9E79FC0DF9C
CDE6ADDDF3C4EBFCD8F8FFEEF8FAF7FFFEFFFFFEFFFBFCFEF8F8FAF8FAF7FCFEFBFCFFFA
FDFFF9FBFFF5FBFFF5FAFFF3FAFFF1F9FFEFF9FFEFF7FFEFDEE7D4FBFFF3F9FFF2FCFFF4
ECF0E23B3F30C9CDBCFEFFEDFEFFEAECF6D3CED9AFDAEBB7D1E5AACFE5A4D1E8A2D1E8A0
6D803E889859E3EFAFE3ECADD7DB9EDEE2A5A1A767CFDB99D0E69ECCE89EC9E99DC6EB9D
C6EB9DC8EA9DC9EA9BC9E99ECAEEA8CFEDADD2E4A6D8E0A49A9A5E484707DADF9DD8E8A1
CCE89BC7EE9DC0EB99BEE896D0EFA3CCE098ADB2709DA762CEE89ED0F3A3D0F2A5C6E69A
BCDC91BEDE93CAE8A0D4F2AACDEBA3B1CF87C9E49DCFEAA3D5EFA8C3DD96D7F1AAD1E6AB
D4E4C0F9FFEDF9FFEFEDF9E5E8F4E0F7FFF2F8FFF3F8FFF3
D0F4C6BDD7AADCE3B7CCCE9F828A57697341DDE0B5FEFFE1F0FFE8F4FFEDFFF6E7FFF8E8
E4E3C5D0DDB1879C64304A09CEE9A2B5D1878FA660889D585C6F2DCEE19FD5EAA5869D55
C3DF94DBF9AFCAE7A4CAE3A9C7D8ACEAF5D5FFFFEFF4F2E6F7F7EFFBFBF1FFFFF1F9FDE4
F5FBD9FEFFDCFAFFD2C5D29CDAE9B0C4D398C2D49886985C67793B1F3300CDE0A0BBD79C
B5DFB1689763B0DA92CAEA9FE2F8B893A269E7F2BAC4CDA0000800000C00D6EAAFC5DA95
B0C485DEF2B7DFEEB5E2F4B6D0E7A1CBE59BC9E399D3EDA4ABC57E5D7730CCE39FD4EAA9
D4E8A9D2E6A9C7DBA0CCE0A5C1D29BD5E6AFD4E5AFE3F1BCE0E9BAF3F6CB4B47223A3110
51432683785CFFFADEFFFFE3FBFFDFEFFFD7C8E7ACC2E5A3CAEBA4C4E397CEE998D0ED9B
C5E695CBEE9ED6F2A8C2D993D5E5A4A6B572CBDA97D4E59ED4ECA0D3EFA2CDEBA1D2F1AD
EBFFCAF5FFDAF7FFE1F9FFEDFCFFFDFDFDFFFEFFFFFCFFFFFCFFFFFCFFFBFCFFF8FBFFF4
FBFFF1FBFFEDF3FDE2E7F4D6E2F0CDE2F0CCE5F4CDE7F7D0F8FFE4EBFADBCFDCBEDBE5CA
F5FEE3464F32E6EDCEECF3D2EDF5D0EAF5CAD9E5B3D7E6ABC6D997CFE59CD9EFA4A8C074
1A2F00A8BB7BC6D594DBE5A6D9DFA1A5AB6DB6BF7EDDE9A7D0E69ECCE89EC8EA9DC6EB9D
C6EB9DC8EA9DC9EA9BCAE89EC6E3A0CFE5A5D8E4A6D6DC9E7A7A3E6F6F2FDDE6A3D0E19A
C9EA9BC5EF9DC1EC9AC2E998CDE99ED2E39C8A8C4B949D5ACCEB9FC1EB99C3EA9BCAEFA1
CEF3A6CDEFA3C5E59CBFDD95D1ECA5D5EFA8D5ECA6BED38ECCDF9DDAEAA9E0F0AFCBD9A8
E0E8D9F2FAFCF3FBFDF9FFFFF9FFFFF3FCF9F9FFFDEFFAF2
E1FEFAE4F6EAEFEBD0D3CFA0D5E29C98AB5C98A45CE6F4B9D2EDC2E0F2DAFDF4EFFFFAF8
F3F0DDDBE5C0CCDFA7D0EAA38FAB60CEEA9DDFF7ADE1F7AFB7CB8691A55E62782F718C3F
90AF5FBADB8CC0E095CCE9A7D0E4AFF1FDD5ECF0D5E8E9D7B7B9AE484B424D51429CA48D
B1BA9DFCFFE3F2FDD2F0FECBD4E2ADE0EFB6CFDEA3DCEBB0C9D99BCCDEA0849455D6EEB4
CDF2C6ABD5A3577C36CBEBA0C2D89A94A56EC3D29BD6E3B7000800000800CCE1A6D4EBA3
BDD090D9E8ADC6D197D7E5A7D5EAA5CEE89FD2ECA3C2DC93C7E19AC7E19ABBD28CCFE6A2
D2E7A4D5EAA9CDE1A2D3E7A89CAE70A3B577BBCD91DBEDB3DAEBB4D1DFAA777F50232400
9B957158502CC3BF9CF9F9D5FAFFD8EEFFCECCE5ACC5E3A3CAE9A3C3E397CDEA9ACDED9A
C4E795CBEE9ED5F1A7C8DF99D7E7A69CAB68B1C07DD7E8A1D4ECA0CFEB9ECCEB9FD9F9B0
EEFFC9EDFFCEEFFFD5F9FFEAFBFFFDFBFFFFF9FEFFF8FEFCFBFFFBF9FFF8F8FFF2EFFBE3
F5FFE4EDFDD8E2F3C7D7E9B9D1E3AFD0E3ABD3E7AAD4E9AEC5D9A6C5D8AAD2E3B6DCEDC1
66754A38451AD0DBB0D4E0B2D1DDABCCD9A3EAF8BBCFDF9ED2E69EB2C979778E3CBBD483
CFE69ED9EEABDFEFAEC9D595DBE4A3C1CA899CA765DAE9A6D0E69ECCE89EC8EA9EC6EB9E
C6EB9DC8EA9DC9E99DCCE89ECDE2A1D9E7AAD7DFA3D9DA9E646428C5CA88CBD893D1E99F
CAED9DC2ED9BC4F1A0C8EFA0C0DA91D7E6A16B6B2D989F5CCDEDA1B6E390B9E494CAF3A4
CEF3A5C3E598C8E89DDDF9AFC8E29BD6EBA6C3D694D5E5A4E4F0B2D3DDA0C8D295FFFFDC
F2F7F0FBFFFFF7FCFFFBFFFFFAFFFEF9FFFAF9FFF3D5E1CB
EDFFFFF7FFFFF4E7D7E1D3AED5E1A1CEE5979FAD62CDDD9CCFEAB5CFE3C0FFFFEFFFF4E8
FDFBE6FEFFE4D3E3B4CFE5A7C5E196CEEB9BC3DE91CCE49AE2F6AFD1E79EB7CF85C3DE8F
CBEB98D5F7A3D1F2A3D5F3ABCADFA4C2D2A18A926BB6BA9FF6FDEBF7FFEFFBFFF1FBFFED
DCE7C9121D00FBFFDFFBFFDAF1FFCAC6D59CDCEBB0C1D095E0F0B2D4E4A6A9B97B8FA46C
B5D4AAC9EDBDD4F8B2456319E1F6BB93A66FC4D7A0DFF0C4000700000900D1E9ADCAE199
9AAD6BCBD99CE3EBAFD5DFA0D8EDA8BFD990D4EEA5D0EAA1CEE8A1D2ECA57E954FCBE29C
D0E5A0CEE3A0CCE19ED4E9A6AABD7BA2B573C5D898DAEFAEC5DF9EC7DFA1E1F2BB929A67
86875B524F26100C00E1E2BAE1E8BCE8F6C3D3E8AFCBE5A4CCEAA4C5E599CAEB9AC9EA99
CEF19FC5E898C9E59AD5ECA4D7E7A693A25F95A461D4E59EC8E094C7E494C8E799CEEEA3
D1EBAAC8E0A6D8ECBBF8FFE6F1FBF0F9FFFFF9FFFDEDF9EFF1FDEFF8FFF1F5FFE9D4E5C1
D6E8BED5E9B6D4E9B0D0E9A8CEE7A3CCE69DCAE49AC9E39ACFE8A7D0E8ACCAE2A8D2E7AE
000C00879862E3F1BCCFDCA6CDDBA0E9F7BABAC986D2E39CC2D4886177259FB560CAE390
CFE99FC2DB97D5E8A6D4E3A2D6E19FCBD694CEDA98C8D995CFE69ECCE89EC8EA9EC6EB9E
C6EB9DC8EA9DCAE99DCFE69EE0EEB0D8DEA2E1E2A8A5A66A969859EBF2AFD3E49DD2EEA3
C4EB9ABDE896C6F1A1CCF3A4C4DB93DBE8A3808042BCC282C5E599CBF6A6CBF4A5BDE495
BDE294CCEEA1CEECA2C0DC92D0E7A1BDD18C6676354D5C1B495316495316777F44FFFFDA
FEFFF1FBFFFAF8FFF7FBFFF8F9FFF2FAFFF0F3FDE4C4D1B3
E1FDE7F3FCEBFFEFE5FFF2E1E2E9C7EBFFD2D2E0ABB0C288496626B7CD8FE7E9B7FFFDD3
F3F5CEDBE2C1F4FEE3D7E7C0D3EEA9CAEA97CEE99CCBE399C1D58ED6ECA3E3FBB1CFEC9C
C7E993C2E68FC2E591C3E296CCE2A1CEE0A6828B5CE1E9C0E7F5D2EBFADBE5F4D3E6F5D4
D7E7C3E9F7D3CCDBB096A677D7E5B0F1FFC7D7E5AACEDC9FE6F4B9D5E3A8CBD8A094A473
668158BBDBACD3F2AECDE99F2D4207CADCA8576B36192E03000800001200D5EFB2C0D78F
9BAE6C9CA86AD2D89ADAE3A2C7DB96D7F1AACAE49DC4DE97DDF7AEBED88F546B23CAE199
D2E8A0C9DF97CEE49CD6ECA4D0E49DB6CA83D6EAA3D1E8A2C9E8A2D3F4AFCBE5A4C2D498
CCD5A09DA0715D5C30D7D8ACBDC091DAE2AFD6E5ACCFE5A5CDE8A3C6E69BCBEE9EC5E896
CAF09DC8EB9BC5E196D7EEA6D3E3A2ADBC7999A865C8D992CDE597D2EF9FD0EF9FCCECA0
CCE7A2C9E1A3D6EAB5F0FFD7EFFDE6F8FFF4F8FFF3F7FFEFF7FFECF7FFE6EDFFD7D8EEBF
C7DEA8C8E2A5CBE6A3CDE99FCEEA9DCDEA98CBE894C8E895D6F4ACB5D28FD3EDAC627B3A
000E00D2E6A9C1D397D7E7A9DDEBADC9D895E4F5AF8A9C52859849C0D684C4DA85D0E996
CCE89DC9E49DCDE29DEBFCB8D1DD9B8B9654C4D08ED8E9A5CFE69ECAE89EC8EA9EC6EB9E
C8EA9EC8EA9ECAE89ED0E5A0DEE7A8CFCE95AFAE755F5F23C3C888D4DF9BD4EAA1C2E195
BFE997BEE997C1EC9CC9EEA0D0E69EC8D391B0AE73E0E5A5C7E198CCF1A4C8EDA0C0E296
D0F0A4DEFDB1B6D2877892484B621AB1C580D6E6A5CEDD9CDDEBADE4EFB3CAD39AC6D09B
99A577727D55A3AD88F1FBD6FCFFE4FAFFE3FBFFE6FBFFE6
DAF4CDFFFFE6FFF5ECFFECE6FFFFEFE6FBDCEFFFDACFE1AFD2ECABACC37D9CA360B2B377
DAE1AEE6EEC9EEF6DEF8FFE4C4DF9CCEEE9BC9E497D8F0A6D4E8A1D1E79FC3DB91D2EEA1
C5E793CBEF98D2F69FC3E292D3EAA2E1F4B47B864EDFECB7CCDEAAD3EAB6C3D9A8CCDFB1
DCEFC2CEDFB3C5D6A9D5E5B4B2C38C96A56AB3C184DAE8ABBECC91D6E3ABE0EAB6CADAAB
B2CBA34B6737839E59D0EAA1D2E6AB60723EB6CA95778C63000800000A00C5E1A6D5EFA6
D9ECAA5864247C8242DDE6A5D6EAA5C7E19AD0EAA3D1EBA4B9D38ADDF7AEBED58D96AD65
D1E79FCEE49BD9EFA6CBE198C8DC949CB068CADE96C6E096C7EC9FC8EEA3C6E59FCDE6A4
E2F1B6D0D9A24044123E400F9EA06FCAD19DD3DEA4CEE0A2CCE5A1C9E79DCDEFA2C2E797
BDE292D3F6A6CBE79DD0E7A1CDDD9CD4E3A2B1C07DBACB84CCE496D0ED9BC7E696C0E192
CDE8A1D2EBAACFE4ABCFE1B1D7E8C4C5D8B8D2E3C1EEFFDDEFFFDBCFE7B7C3DAA6D0E9AF
CDE7A8CBE9A3CAE89EC8E99AC9E996C9EB94CBEC93CBED97BFDF93DBFBB2BEDC961D3800
90A967CBE1A0DBF0AFD0E3A3D3E3A2CCDD9991A25B8B9D53D8EA9ECCE290D2E896D5EE9D
C4E397D9F7AFCBE29CC6DA95D3DF9D94A05EACBB78D4E5A1CFE69ECAE89EC8EA9EC8EA9E
C8EA9EC9E99ECCE89ED1E5A0DCE0A3E8E6AB6A682D5E6021C5CE8BDAEAA3CCE69CC7E99C
C4EE9CC7F2A0BEE798C2E297D2E7A2A5AE6DC6C489E2E3A7D4E8A3C8E39CCFEAA3CEEAA0
A8C47A829C5294AE64C9E197D0E79FD0E69ED1E6A1C5D896D7EAAAC6D89ACDDFA3D9E8AD
D6E4A7D4E2A7DFECB6AEBA88A3AE83EFFBD5FBFFE6EDF8DA
CDE5B3F5F5CFD1A193F9CAC4FFFFEFEBFFE9E4F7D7EFFFD9D7EEB6D0E4A5CCD6979DA365
C8D19ACED7A8E9F3CEDDEDC0CBE4A0C8E595CCE69CCEE59FCCDF9DE0F5B2BDD48ED0EAA0
D0EF9FC1E38DCEF09AD0F09DCBE397A7BB76BDC98BD1DFA1D1E8A0D0ECA2CFEAA7CCE4A6
CAE1A9CEE2ADCFE3AED0E3ACD9EBAFD3E6A6AABA7BC0D091E5F2BADCE9B4DCE8B8D6E5BA
CDE2B9859D6B87A15A758B43E1F3B97F8F5E778957667852000A00000900C6E2A8E2FDB6
C8DD9AAFBE7D919A59D9E4A0C7DC97D4EEA7CDE7A0D0EAA3CBE59CD7F1A8C8DF97526921
D1E79ECCE299C9DF96DFF5AACCE19699AE63DCF1A6C2DD90C9EE9EB2DB8CCFF4A7CBE9A3
CAE09FD3E3A57D864F161B001F2200A8AB76D7DFA6CEDC9ED4E9A6CDE8A1CAECA0C4E99B
C2E797D2F4A7BED992D0E7A3DEEEAFDAE8AAD1E09F97A862D0E89CCFEC9CC4E491D3F4A5
C8E49ACFE8A6CDE3A5CEE3ABCEE5B1C8E0ACD6EDB9EDFFCFEDFFCDD3EFB2C8E2A3CBE8A5
CAE8A2C9E99EC9E99DC8EB9BC9EA99C8EB97C9EB95C8EB99CBEDA1BDDC96D2F1AB6B8943
C9E2A0DEF4B3CFE4A3D0E3A3C7DA98D6EAA597AB64BED28AE2F7ACD5EC9ECFE698D0E89A
CAE99DCBEBA0CDE79EC8DE96DAE9A495A25DABBA75D4E59FCEE59FCEE9A2CDEDA4C4E49B
CEECA4D0EBA4C2D993D5E6A2E2E3A7ABA96E555519747939CCD793DCF0A8D1EDA2C0E595
BFE899C3EC9DCCF2A5C5E399D6EAA5919A5BEBEAB1D5D49BD5E1A3D4E7A7CFE2A0D3E6A4
5E722DB3C981CAE097D2EAA0CFE79DCDE79ECDE7A0CCE7A2CCE7A4CCE6A5CCE6A7CDE6A5
CEE1A1DAE8ABC6D59CDCEAB57E8B5FF5FFDDF7FFE6F9FFED
D2E3B6B4AC886B2D1E8A5042FDFEDEF0FFE3F2FFE3E5FAD1ECFFD4C1D3A3DCE8B8D3DDA9
505A2589965EEAF8BDDAEDAD3B550C8AA65BBBD28C516625A6B87ACFE1A3D9EEADC1DB94
C5E196D8F9A8C3E58FC4E18D869E5043540DD3DE9CDCE9A3CCE68FCAEB90CEEB99CDE8A1
CEE6A8D1E9AFD3E8B0D2E7AECCE0A1D8EBA9D3E6A4CEDE9FC2D196FAFFD3F2FDD2C9D8AD
CDDFB5CCE3ADDEF4ACCFE39B7A874FACB8887B885A33431F000700000C00C6E3ABC0DE96
C3D998DDF0AEB2BE7C8C9B5693A863DBF5AEC5DF98C4DE97D6F0A7C7E198CFE69E799048
D3E9A0C6DC93DFF5ACD7EDA2CCE196D1E69B4E63189CB468C5E898D5FCABC0E598CDEFA5
CBE6A1D6EBAACFDDA04A52194C4F1874774071763C8D975A5E6E2D809A53D9F9AEC6E89C
BDE294CBEDA0DDF8B3D1E7A6BFCF91CAD89BD3E1A38B9C5892AA60C7E494C2E191CEEF9E
C5E197C7E09CC7DD9DE2F8BACDE6A5C6E19EC9E4A1D5F0ADD3F1ABC7E59FC4E29AC9E9A0
C9E99EC9E99DC8EA9DC8EA9DC8EB9BC8EB9BC8EB9BC8EA9DD0F2A8C0E19CC8E7A3072400
C2DD9AC8E19FD8EEADCBE09FCEE1A1809351A0B46FE2F8B0C2D890CAE298D3EB9FCDE89B
CFEFA3B8D88DCFE9A0D7EDA5B9C8837F8C47CBD893D5E6A0D4E9A4BED891C3E199C6E49C
C8E39CD1E8A2CFE49FDCEBA8B6BA7D8B8B4D949959E0E9A6E3F4ADBCD48AC7E698CEF3A3
CFF6A7CFF6A7C8EA9EC5E099495918B2BC7DD6D79DE0E1A8DFE7AEC9D49AA2AD712F3D00
C4D392C8D995D8ECA5CBE399CDE79DCCE89DCAE89EC9E9A0C8E9A2C6EAA4C6E9A5C9E8A5
D2E7A6DEEEB0CEDDA2D6E5AE8D9B6A9EAD82E0EECAE1EFCE
E9F1D9D9C7AF833A277F3D1DD0D593BCE194C6E5A2CEE6B4D2E3C3F8FFEFF4FFEDF7FFE8
D2DFB1A4B3703B4E00385000C7E293D0E9A5C6DA9B8FA167A9B782D1DFAACCDEA4E2F8B8
C9E39CDAF9ADC3E292CCE9977E95473A4A01E7F0ADD0DC92CDE889CCEF89CCED94C8E799
CAE4A3CCE5ABCBE2AAC9DEA5D6ECACC7DC99CEE49CBFD38E87995DD0E1ABE8F5C9F9FFDD
F1FFD6B6CB92DBF0A5E2F2A7545D245C64354C552A556040000500071A07BBD6A1CDEAA7
D9F4B1CBE4A2D2E7A2D9EFA7C7DE9878924BD3EDA6D5EFA8C1DB94DAF4ADCBE29AA8BF77
C9DF97DFF5ACC8DE95C6DC93C9DD95D8ECA44E621A849C50D2F1A3C1E494BEE094C7E99F
C0DF99CFE8A6D0E2A495A06460652BCED198CFD2994A50140C18000B2000B3CF85D4F4A9
CAECA0BBDD91CFEAA7C4DA9AE0EFB6D9E6AEDBE9ACD7E7A63D540CDFFBAECFEE9EC9EA9B
CBE79CCBE59EDEF4B3B6CC8BCDE99EC7E698C6E597C8E799C8E799C6E597C6E69ACAEA9E
C9E99DC8EA9DC8EA9EC8EA9EC6EAA0C6EAA0C6EAA0C6EAA0C6E7A2C8E8A5CBEAA7001000
D4EEADC4DD9CD3E9A9CBE1A0A6BB7AB0C582D2E7A4E3FAB4C6DD97D2ECA5C9E39AC7E399
CCECA0CAEA9EC9E399DAF0A7D5E49F909B57D0DB97D2E19CCFE39ECEE59FE1FBB4D3EDA6
C7DE9ADCF1AEDBEBAAC6D2922E3400979D5DCCD795CEDD98CDE39ACFEBA0D3F4A5C8EB9B
C1E698C8EA9DC8E69C93AA64D6E6A5E0ECAEEAEFB5D3D69FDADEAB5D64308A915BE3ECB3
D3E1A3D2E2A1E3F7B0CCE49ACCE89DCAE99DC8EA9DC6EB9EC5EBA0C3EBA2C2ECA4C5EAA5
CBE1A3D1E3A7D3E5ABCBDDA390A16A8C9F67CFE2ABD1E4AD
D0D4BBDEC4AD812A16994D29D2D68AD1F9A1C2E498DAF6BBF4FFE1E0EED7F1FFEDF4FFE9
DEF0BED3E59BD5EB89B7D06BD0E89CCEE6A8CEDFA8D8E6B38C986AE2EEC0CBD9A8C2D59D
D2E8A8C9E49DD1EDA0D6F1A295AA5D818E46E0E7A4D0DC90CFEA89CDF08ACCED94C7E69A
CBE5A6D2EBB4D5ECB6D0E7AFD2E8A8CDE49ED3EBA1E6FCB4B7CC8B71844C708051F2FFD6
E5F9C6CFE3A6E0F1A3C9D589CBD096DDDEB2DADCB4C9CDB2464D46000600708A5ACEEDAA
C4E3A0C7E6A2C2E09ACFEAA3D8F2AB97B16AC1DB94CFE9A2DCF6AFCBE59EC7DE96CFE69E
96AC64D5EBA3C7DD95D7EDA5DCF0A9CFE39CB4C8816A8037C6E096C9E89CD3F3A8D0F0A7
CDEEA7D1EFA9CDE6A4D2E2A4A9B3776D7037E0E1A7CFD398E0EAABC7D894D2E9A3CBE99F
99BB6F4D6E27A3BD7CC0D698CCDBA4CBD8A2DFECB4CEDE9FD2E9A3577328CAE99BBADB8C
CBE79CDAF4ADD0E6A5DAF1ADCAE797CBEB96CDED98CBEB96CBEB98CDED9ACAEB9CC7E899
C8EA9DC8EA9DC8EAA0C8EAA0C6EAA2C6EAA2C6EAA2C8E9A4C0E09DCFEDADCEEBAB021C00
DCF4B6CAE3A2C6DC9CD4EAA9586E2DDDF4B0CEE5A1C4DD99CFE8A4CCE7A0CCE7A0CCEAA0
C7E79BD6F6AAC7E197D7EBA3D6E39E86914DCDD894D3E09BD7E8A4CBE09BCCE39DC4DB95
CEE3A0D3E3A298A4645C662766712FBFCC87D9EAA4CAE097D0ECA1CAE99DC0E192CBEE9E
D3F3A7C6E599D3EDA63E530EDDEDAEC9D799848E52939C65B9C190EBF3C4FEFFD5E8F2BD
C4D398E1F4B4CEE39EC4DE94CCE89BC9EA9BC8EB9BC6EB9DC3EC9EC2ECA0C1EDA2C5EBA2
C6DF9BC9DE9DD8EBABC8DD9C879C5BCDE3A2C6DB98D1E8A4
E7E8BCE7C9A381210B9B4428D6D698D1FAACB3D791BBD999D4E8B3C3D7A6D8F3BEC7E3A9
CDE6A5BAD087DAF09DD5EB99C7DD9CD3E8B0FBFFD8FCFFDCBDC59EDAE2BBE4EFC5D9E9BA
CEE1A9CCE5A4CFE9A2CFE59C8A9B54919C57CCD18FE6F0A7CEE78BCEED8FCDEA9ACBE6A3
D5EDB9E8FFD1F2FFDAF1FFD6E6FEC0C3DD96D6F1A4CEE69AB5CC86D4EAAADCEEBA445825
8A9F67D3E6A6D2E190DDE697EBECB3EDEABFE0DCB6D6D4BBFAFCF9F8FFF8637A4CD0F0AF
C8EDAAC9EEA9D1F6B0BADC92C6E19AB2CC85DCF6AFCAE49DC6E099CDE7A0D0E7A1D6EDA7
8FA45FB9CE89DFF4AFD0E5A0CEE29DD4E8A3D7EBA68EA25D71853ED5EBA3C0DC92BBDB92
C4E59EB9DA93D6F3B0C6DC9BD9E5A7A0A66A53541AD9DAA0EBF4B5C2CE8CDDF1ACC3DE97
A8C87F0C2D00000F0000140098A673D2DFAACCD9A3D9E8ADD5ECA8C6E298001A00D7F8A9
BEDA8FCEE8A1C1D796D6EDA9C7E293CCE995CCEC97C9E994C9E996CCEC99C9EA9BC3E495
C9E99DC9E99DC8EAA0C8EAA0C8E9A2C8E9A2C8E9A2C8E9A4CAE8A8CDE9ACC8E4A7062000
C6DEA0CBE4A3CCE2A2CCE2A18BA160C8E19DBFD894D7F2ABC6E49CB9D98ECDEDA2C9E99E
C7E99CC2E394CEE89ED6EAA298A55F57611CD5DE9BD8E39FDDECA9D4E5A1D0E3A1D5E8A6
E3F3B2BAC988656F32434D0EDAEBA7C5DB93D3EAA2DDF9AECAEA9EC3E696C9EA9BC9EA9B
B8D489D6EEA4C8DD98172B004E5E1F4E5E1FFAFFCCFBFFD3FBFFDAF8FFDAFBFFDAE7F8C4
D1E5AAC5DB9AC7E19AD3EFA4CAE99BC9EA99C8EB99C6EB9BC6EB9DC5EB9EC3EC9EC6EB9D
CEEB9BD2EB9AD7EEA0CDE5978EA65CE4FEB4C4DB93CDE7A0
D7D5A2D1AE848C230E8E3016D7D59ABFE99DC8EEA3D0F0A7D0E7A3CBE29EC1E198C4E69C
D3EEA7D2E9A1CCE299C9DE99DDF0B8CADCAAF4FFD6EEF6D1DEE3C3A3A888959C7AC6D3A8
CDDFADDDF2B7C2D897CFE59D8B9A5579823FD1D394E2E9A3D1E792D0EE98CDE8A1C9E2A9
D6EDC3EFFFE1F5FFE4F5FFDDD5EDB3D4EEA7C7E295BED98AE1FBB1C3DC98D7ECB3B0C58D
60753AC3D792D7E693D5DC8CDBD9A0DED5AAFFFFDCFFFFE9FFFEFFF4FBF3C6DDB14C6C2D
ADD493B6E19CBBE69EDEFFBDCDEBA392AC65D1EBA4D3EDA6B8D28BDEF8B1CDE49ECCE39D
98AD68CBE09BCFE49FCBE09DC5D896D2E5A3CEE1A1D4E4A3828E4CBECD8AD0E7A1CCEAA4
D0F4ACC9EDA5C8E9A4D8F1AFCEDE9FCFD79B9192587071358F9555E2EDABC6D793D5ECA6
CAE9A3BEDE9BD0EAAD52672F172500505C2CA6B37EC7D69DC9DF9ED2EDA6D0EFA34E6E22
E0FCB2D5EFA8C3D998D3EAA6CEE99CCEEB99CAEA97C6E693C6E595CAE999CBEC9DCAEB9C
C9E99DC9E99DC8EA9EC8EAA0C8EAA0C8EAA0C8EAA0C9E8A2CCE9A9C5E1A4CEE8AB000F00
C5DE9DD1EAA8DCF2B1B1C884D2EBA7CAE49DD3EEA7D9F7ADC2E297CFF1A4C2E498C3E89A
C4E797CAE99BD0E89ECEDF98AAB57069732EC7D08DD9E29FC5D18FDAE9A6CDDD9C829251
4F5E1D5B652693995DE0EAABCCE19CCDE99FCCECA0B7D98CBEE393D7FCACD1F2A3C6E597
DAF2A8CBE198C3D490B2C180869657DAECAEF0FFC6D3E8B0D9EFC1DBF0C7EEFFD6F5FFD8
CFE8AEDCF6B5C8E69ECEEDA1CAE99BCAE999C9EA99C9EA99C9EA9BC8EA9DC8EA9DC9EA9B
CCE997D4F09CCBE493C3DE8F9EB96CC0DA90CFE9A0CEE9A2
B7B181B88E688D1E0DA13D25E2DE9FC5F09ECBF39DC3E58FC2DB88DCF5A4CAED9BC8EF9E
CAE89ED0EAA3C7DC99DCF0B3C8DAA6D6E6B9F9FFDEFEFFE6FFFFEAFFFFEAC9CFB3CFD9B6
CBDBAECDE0A9C6DA9BD9ECAA9AA664646D2CE1E3A4D1D895D2E79AD2ECA3CEE6ACC8DDB2
D4E7C9ECFEE6F4FFECF0FFDFDEF7BED4EFAAD0ED9DCBE894E2FFAFC0DC91C3DC9BC8E0A4
CDE6A598AE6695A34EA0A553E6E1A791855BC0B390DDD2BEFFFEFFEEF3EDD9EEC5D7F9BC
7EA667D4FFBFBAECA3ADD98EBFDF96D0EAA1809A51C7E198EBFFBEC7E19AC5DC98D1E8A4
819653DAEFACC5DA97E3F8B7DDF0B0D4E7A7CBDD9FD8E6A8BAC3847F894AC4D795D0EBA8
BFE39DCAEFA9A8CC86D1EEABE0F3B3CFD99CE5E9AC97985C494E0E8F9857DAE6A4CEE3A0
D1F0ACBBDB9AD0E9AFD9EEB6C3D1A0596535202C0062713AC8DE9ED2EDA8C3E197A9C97D
4662188AA45DD2E8A7C6DC9BD2ECA3CEEA9FCCE89DCCE89DCAE99BCAE99BCCEB9FCFEEA2
C9E99DC9E99DC9E99DC9E99EC8EA9EC8EA9EC8EA9EC9E9A0C8E5A3C9E3A6D2EAAC000F00
D3E9A8D3EAA6DAF1ABB7CE8690AA61C7E398CAE99DB9D98DC2E497DCFFB1BFE697CAF1A0
C4E797D6F5A7CDE599C8DA90E2EDA8A2A965C0C784DAE19EE3EEAC909F5C74834281904F
A7B174DAE2A6E2E6ABC8D293CDE7A0D6F8ACCBF0A2B9E091D3FAA9CFF4A4B1D283D7F3A6
CCE299D2E39CD6E2A0D8E4A4DBE9ABB3C587E2F8BACDE6ADCCE9BBC7E6BCF0FFDFEDFFD9
C9E8ADBADA99CCEBA5C5E599CAE999CAEA97CAEA97CCE999CCE999CCE89BCCE89BCCE89D
CAE69BCCE89DC7E198A2BE7495B069B9D48FD5F0ABCEECA6
6145209661418A2310C77054DDD596CBEC9BC4E891CFF19ACCE995CBEB98C2EC9ABBE697
C3E79DCCEBA5D0EAA9CBE3A5D4EBB3CADEADF9FFDFF6FFDEF7FDE3FFFFECFBFFE8E0E4C9
C4CBA9ACB48BE1EBB9DCE5AC8E965A4E5313E7E7A7DADF9CCCE192CFE99FCDE5ABC9DEB5
D8EAD0F1FFEFF5FFEFF3FFE6E9FFCCC8E19FCDEA9AC7E490C8E591CEED9DC4E29AD6F1AE
C6DF9DD6ECA4CEE08E8E994BD5DA98ADAC76AAA679B4AF92C5BDBBFFFFFDC6D3B5BFDBAA
97BE8599CC8AB4EDA6C3F9AEC8ECA4CFE9A099B36ACAE49BC2D991D0E7A1D2E7A2D4E9A4
93A863CEE39ED6EBA8CBE09DC2D796D5EBAACDE3A2D0E3A3D4DE9F828C4DADC07ED7F0AC
BAD995CCF0A8DCFDB8C5E09BC8DB9BDDE9A9D0D698B7BB7E5C61219CA262D2DD9BD1E29E
CDEBA5C5E6A1C6E3A3D2E7ACD4E5AEAEBD8677864F7B8D51D1EAA9CEE9A4C7E59DCCEAA2
718C45829857C8DC9DDBEFB0CFE6A2C9E39ACAE49AD0EC9FD0ED9DC7E696C6E597C9E99D
C9E9A0C9E8A2C9E8A2C8E9A2C8EAA0C8EA9EC8EA9EC9E9A0CFE9A8D4ECB0C7DFA1001400
CEE4A4C7DD9CC9DF9EDFF6B25B722ECAE49DCAE59ED0EEA4C9E79DC1E196C8EA9EC4E69A
CCECA3C1DC95D2E7A2D3E29DD5DE9BAAAF6DD5DA98DDE4A1D6E19D4F5C176C7B36D5E49F
DAE5A3C9D291DADF9FE2EFAACCE89DBBE291CDF6A7C3EC9DBAE395CAF0A3C7E99FCEECA4
D3EDA6CFE49FD6E9A7CADD9BD1E6A5D8EEAED1EBACC1DEA4CAECB9C2E6B6D6F8C5D0F1B8
CAEDADD0F1ACC9E99EC5E494CAEA97CCE995CCE997CCE997CCE999CCE89BCCE89DCCE89D
D3EEA7CAE59ED2EBA7859E5A79924EDDF6B2CAE5A0C9E49F
C6856F914E3473270DBA7E59F4E1A9CDD490DBF1A8C2E195C6EAA0C2ECA2BFEDA5BEEDA5
C1ECA5C3EBA4C6EAA4C6EAA2C4E8A2C7E5A7C7E0A9D7E9BFF6FFE1FFFFEDFFFFF1FFFFF1
D9D2C2B3AB96AEA78AE7E2BA9F9967706B31DAD696DFE699D5EC91CDEB91D1EBA4C5DCA8
CADBBBF8FFF1F8FFF1C4D3B6CEE1B4CDE3A5CCE69CCEEB97CBEC95C7E993C7EA9ACDEBA1
D4E9A4D2E6A1CEE39ECDE49CD0E89AD7EEA0E3F2AFEBF1C3F1EBDF494041C5C5BDE5F3DA
BFE3B3336A2985CC86B6F8B0C4ECA5D8F2AB79934CD6EDA5CDE39BD0E49CD8E9A2CDDE97
6F8039C6DA92D9EFA7D2E9A1CAE59EC7E59FC9E8A2C7E59FD0E5A2D7E8A4B5CA85677E38
D0E9A5D1ECA5CEE7A3C7DE98D4E7A5D5E6A2E0EBA9D4DD9C9BA161595F1FD1D797DBE7A5
CBE99FC5EA9DD1F1A8CAE49DCEE39ECCE09BD4E9A4CCE39DD1ECA7CBE9A3D4F3AD213E00
C7DFA1D4E8ADA6B37D89965EACBC7DD3E9A1D6ECA1CEE794C7E58FDCFDA6C7E794C9E99E
C9E8A5CBEAAECCEBB2C9E8ADC6E6A7C6E7A2C9E9A0CBE9A1D6EFAEC2D79CCFE4A9000D00
CFE4A9D2E7AECFE2AACDE0A8B3C68E3D5018D5E9AED9EDB0C0D497DAEEB1CAE0A0CCE2A4
C9E1A5E1F6BDE3F2B9DFE8AFBEC48885864ABCBE7FD7DC99D8E29B9BA95E7586388B9C4E
B9C77ADDE99DD4DC91DFF0A0CDEE97C0EB92C7F19FCAF3A5BEE69FBDE4A1C5E8A8C9ECAC
C4E4A5C9E7A7D3F2AFC2E19DC7E6A3CBEAA7BADA99D8FBBBC2E9AACAF1B2B4D996CFF3AD
D8F8ADC5E496CCE997CCE893CBE792D2EE99CFEC98C3E390C6E798CFF1A4C2E79AC6E89E
C8E69EC8E29BD3EAA48EA35E8FA35ED5E9A4CBE09BCDE49E
FFECD3FFD2B5643612EBCC9DCABE84E7ECA9D3E7A0C7E79EC3EBA4C1ECA5BFECA9C1ECA7
C3EBA5C6EAA4C9E9A0C8EA9ECCF1A4CFF3ABCFEDAFD8EFBBEEFDD6FBFFE5FEFDEBFFFFF1
FFFDF1DED3C1968C71978F6A928E5EA4A468E6E7A3CDD987D4EF8EC2E483CBE79CD3EAB2
D6E7C5F0FEE7F8FFF1D9E8CBD4E5B9CFE4A9CCE69CCDEA96CAEC95C6EA93C5EB98CBEB9F
D3E9A0D2E7A2CCE6A5C7E8A3C5EB96C8EC94CFEA9BD8E5AF0A04001004069C9195FEFFF4
C6E1B891C386519655A2E5A0BAE39FC1DE9B9CB774CAE39FCCE19CDAEEA7BFD38CDEF2AA
8EA25A72883FC7DD94C8E299BFDB91C3E199DAFAB1C0E097CEE8A1CFE49FBCD18CD3EAA4
93AA64CBE29CCEE39EDAEFAAC9DD98C5D994DDECA9D4E09ECBD4935D6323D2D797D7E09F
D0E69ECEE89FBFD68ED6EAA2DAEBA4DFF0A9CBDF97D8EFA7BAD58ED6F5AFC6E5A11B3800
698145BDCE97E3F0BBDFE9B49FAD72CCDF9DC8DE93CFE895CAE68FC0E188C7E792C7E79B
C5E6A1C6E6A7C7E6ABC8E7ACCAEAA7CBEBA2C9EA99C6E597D2EAACC7DCA45D713C697D4A
C9DDAAC7D9A9CEDFB2E6F7CADEEEC1D0E0B3AEBE8FC7D5A4C7D5A4E2F0BDD8E6B3D5E6B2
C9DDACE6F7CAF6FFD4F9FFCFD9DBA99C9C66CCCD93E5EAAAD1DB96D2DF97A0B0654D5D12
8F9D52DDE99DDBE39ACFDD90CBE993C1E790C7EC9EC3E7A1C8EAADDBFCC3BCDAA4D2F0BA
DFFEC5E7FFCADFFFBEC7E7A4CDEBABD1EFAFC0DEA0C3E3A4C4E7A5C6E9A5DBFCB7B3D38A
C0DC91CFEA9BCCE592D7EF9BD2EA96CAE390DAF3A2D0ED9DCCEB9FD2F2A9C4E5A0D1F2AD
CEECA6CEE8A1D1E6A1859954889752D4E59FD2E69FD4EAA2
F6DFB6E7D5A7F6ECB7D7D99AD9E49FD8EEA3C5E496C2E799C5EBA0C5EBA2C6E9A5C9E8A4
CFE6A2D1E59ED4E49DD1E69BC4E395C6EB9EC5E4A0C5DEA4D1E3B3D7E3BDDFE4C4ECEFD4
FAFAE0FFFFE4F2F7CFCBD3A2C2CD93C5D491D5E79DD1E896D0EF91C2E388C9E79FD1EAB3
D3E7C4EDFDE3F7FFEDEEFFDDDAEEBDD0E8AACAE699CAEA95C9ED96C6EC97C5EA9AC8EA9D
CDE79DCDE8A1C9E9A6C4ECA5C2EE97C3EB92C6E595CDDCA5040100080000E0D4D6A09E92
C8DAB4B4D9A399CF95AEE4A8C3EBADE5FFC67C9A5A8BA866D0EDABD3EEABC8E19DCDE49E
CFE6A0879E568AA159E2F9B1E4FBB3C9E098C7E198D0EAA3BDD48EE9FFBAD0E7A1CFE6A0
A7BE7897B16A8AA15BCCE39DDBF0ABE0F4AFCAD996CFDB99E0EBA9939C5B858B4BB3B979
CFD597E5EBADECF1B1C8CA8BDCE1A1CED592D3E09BD2E69FD8F2ABD8F7B1AFCE8A90AF6C
2F490A384C11D2DFA7C5D29CA9B8817B8D51BBD08BD6EEA2CBE792D4F59CD1F29BC3E591
C8EA9DC5E79DC3E59BC6E69BCBED99CEEF94CBEE8ACAE88EC6DBA0D2E3B763744A5D6E44
E9F9D2E6F4D0EAF8D4D0DEBBD9E4C2E5F1CDC3CFAB98A27DD9E4BCE3EEC4E7F2C8E0ECC4
DFEFCAF1FFDBF8FFDBEEF0CBC8C69F8D8A5FB9B787D8D8A4ECF1B7D8E2A5C4D0926E7D3C
576323A7B06FE4E8ABD6DF9CD4EA9FC9E59ACEE9A4C5DFA2D0E8B4BED6A6DBF1C3C4DAAB
E6FDC9F5FFD4E1F9BDC9E1A3CAE2A6D3EBAFDCF1B6D3E8AFD5EDB3C2DA9ED2EAACD3E9A8
DDF4AED8EEA6BFD58ADAEFA2DAEFA2CADF92D4E8A0C4DA92C5DA97D2E8A7CDE3A5C8E0A2
C2DD98C9E39CD5EAA596AA6599A863D8E9A3CDE19AC6DC94
D0D9A4C1CE96CFE2A2CCE39BE0FFB1B5D884CBF39DCAF19EC5EC9DC8EA9ECAE8A2CFE6A0
D4E39ED7E39BDBE199D7E397CBE896CDF0A0C9E99EC7E29FCDE2A9CFE0ACD3E0B4DFEAC0
F2FDD3FBFFDCF9FFD6DDF2B9D6EFAECEECA4C0E094CCED9CC8EA93CBED99CCE9A7C1DCA9
C9DFBBF0FFE7F7FFEAF3FFE1DDF4BED2EDAAC8E799C8EA94CAEE97C6EC99C3E99CC4E99C
C8E79BC8E89FC6EBA6C3EEA6C2F29CC4F097C8EB9BCFE2AA070600080000FCEDF0FFFDF4
E2E9C78CA273D3F8C53D653150733DB9DAA36F905766884CC0E2A5B7D798CAE8A8CAE9A6
CEEBA8BAD590D6F0A94158127D934BD4E8A1DAEEA7C5D992E1F6B1BFD690C5DC96BCD68F
D9F3ACC2DC95C5DF9892A963CAE19BC3D893CBDC98D7E6A3DFEBA9CDD8964C551458581C
AFA26DB6A270735F2C675622655821D2CC90DDE2A2D5E19FD4EBA5BEDC94CCEDA6D8F9B4
B1CB8A8DA3636A793EDEEBB3DCEDB7C4D79F8298588EA85FD1EC9BBCD985CFEF9ACCED9C
CDEDA1C9E99EC7E79CC9E89ACBEB96CCEB8ECDED88D0EC95DCEEBC677655000800C9D6B8
F9FFEAFBFFECFBFFECFBFFEDFAFFECFCFFECFCFFECF5FEE3D6DCC0FCFFE6FCFFE4FCFFE8
F9FFECFBFFECFFFFEAEEECD3CDC8AB9A9474C0BA96DEDBB2D3D4A8C8CE9EDBE5B1E7F1BD
929B66989F6BE7E9B7D5DAA4CFDD9FD9EBADD8E7B0D3E3B2D7E6BDD4E3BCF3FFDBF7FFDD
F1FED2FBFFD8E7F5C0D4E3ACCCDBA4D2E1AAF7FFCEF7FFCFF2FFCAFBFFD4D9E8B1D0DFA4
C3D395D5E5A4DBEFAACBDF98D0E19BCFE09ACDDC9BD0DEA0E5F0B6EEF9C1FEFFD3D6E5AC
D9EFAECBE59EC4D9948DA15C909F5AC7D892CFE39CDAF0A8
D3F2B6CDF0B0B9DE98C5EB9EB9E38FC5F198BEEA91C4EE98C6EC99C9EA9BCDE79ED1E59D
D4E49BD8E299DBE295D7E494CFEB97D0F29ECCEB9DCBE79DD2EBA7D3E9A9CFE5A7D5EAAF
D8EDB4C9E3A6CDEAAAC4E4A1C1E6A0C8F2A6BFEB9EC0EB9CC5E79ACAE8A0CAE6ABC6E0B0
D3E9C3EEFFE0F5FFE4EBFFD3DDF5B9D2EDA6C8E797C8EA94CAED99C6EB9BC3E99EC4E8A0
C8E89CC8EA9EC3EBA5C0EEA5C0F29BC2F39AC9F09FD1E9AF0003000E0402F1E1E2FFF7EE
FFFCDDBAC198A4B48DD1EAC099B68A91B18290B2806B905CA1C690C1E7AECFF5BAC9EDAF
C5E8A8D2F2AFD1ECA9D1E8A4ABBF7ABDCC87CDDA94DFEFA8C0D68ED7EEA8DCF6AFD4EEA7
CAE49DCBE69FCAE59E8FA962D3EDA6C7DE98E9FDB8C9DA96CFDE9BDCE8A6C8D391A6A167
76532959290565350F6238106342157F6937C2BC82D0D696D4E8A3C3E199CEF0A6BFE39B
D8F6B0C9E2A04153155D6C31DCEDB7BBCE97B2C88A768F4B9EB86ED2EEA1CCEB9DC7E59B
C9E7A1CCE9A6D3F0AED9F4B1D4F0A6CBE697C9E591D0E7A1CDDBB7A9B59F000500E9F2E1
F5FEEDFCFFF4FAFFF4ECF2E6F8FEF2FEFFF6F2F6E8FEFFF3CCCEC0CDD1C0F7FAE9FEFFF1
F9FFF1F9FDEFFFFFF3FFFAECF3EAD9CCC1ADE2D7C1F6EFD3F5F2D3FFFFE1DEE4BEC9CFA9
AAAE89747651EEEBC8F1EFC8E5E8B9F9FFD1E2E4BDE9EDCCDBDEC1FFFFE9DADDC2FFFFE6
FFFFE1FFFFDCE5EBBBE0E7B4D8DFACD8DFACFEFFD2FFFFD6FFFFD8F5F8CBD4DAAADDE6B1
CFDAA2818F528191528D9D5E9CAA6C7D8B4D333E023139004D511E575928D0CDA0E4E8B6
D2E7A6CCE69FDFF4AFD0E49FD3E29DE2F3ADD0E49DD2E8A0
D3F9BEB4DB9CD0F8B2C2EB9FC5EF9BD5FFA7B2DA82C8EE97C8EB99C9EA9BCCE89DCFE79D
D0E69BD3E599D4E595D1E794C7E490C8EA96C4E594C5E494CFEBA0CDE99FC7E19AC7E29D
B9D791C0DF9BD8FCB6CDF5AEB6E199C1EFA6C6F9AEC0EBA3C7E8A3C5DFA0CBE4ADE0F7C9
EBFFD9E2F7D0DDF0C3DFF6C0D8F1B0CFEBA0CAE797CAEA97CAEB9AC9E99DC7E8A3C8E9A4
CCEB9FCAEA9FC2EAA4BFEAA3BCEE99BEEE98C4ED9ECCE8AD000500040000FAECE9FFFCF1
FFFFE3DBD9B3D9DFBDD5E0BEC9DFBB809A7394B38A6F90652046171A421088B07C87B078
C2EAAEB3D799DEFCBCB8D390D3E8A3B9C8838D9A54BCC983D5EBA3CFE6A0C6E099CEE8A1
BDD891D9F4ADD1ECA55C7730556F28C9E39CD3E8A3D3E7A2DEEFABCCDB98DDE9A7D4C993
612A0B6A1F08A55F45FFDABB9E6C475B390C6D5C28E0E0A4CDDE9AD1ECA5BDDF95C6EAA0
C6E59FD2EDA8D1E6A367793B6C8045EBFFC4C0D696819756B7D18AC9E49DCEE9A4CAE7A5
C8E4A9D1ECB7E2FAC8EDFFD2E4FBC7D4E8B3CDE2AAD1E2B5E9F3DB5A62556C7268FCFFFA
FCFFFAEFF1ECFEFFFDFDFFFCFEFFFDF2F2F0FFFFFBF7F8F2F9FAF4D0D1C9DADAD2F8F9F1
FEFFFBF8F9F4FFFEFAFFFAF3FFF3ECE4D3C9F3E3D6FFF8E8FBF5DFFFFFE8FFFFE8D5D8BD
D6D6BC5F5D44FFFFE8FFFFE6FFFFE1FFFFDFF6F0D6FFFFECFFFFEFEEE8DAFFFFEFF6F1DB
F1EDD0DFDFB9D3D1A8D8DAABDEDDADE7E9B8FFFFD3FFFFD2DCD9AE9D9A6F939264363A08
737C4572804592A26490A2648F9F619DAB6E9AA36CD4D8A5DFDDAD787145B3AA81D0CE9E
D1E4A4C4DE97CADF9ABFD38EC2D18CCDDE98C8DC95D0E69E
D2E8B9B5CC9870884CCFE8A6CDE99EC5E292C8E895D8F8A5C9EA9BC9E99DC8EA9EC8EA9E
C6EB9DC6EB9BC6EC97C6EC97C6EC97CDF09EC9EC9ACAEB9AD2F1A1D0EF9FCBE79ACDEC9E
D3F2A6D2F2A7C6EAA2BDE29CB8E19BC3EEA9C8F5B4BCE4A5CDE6ADD0E2AEDAECBCEEFFD3
F1FFD8D9EABECCDEACD7EBB0D4E9A4CFE79BCEE796CEE998CDE99CCAE59ECBE5A4CEE9A6
CEE89ECDE99EC8E8A5C2EAA4C0ED9CC0ED98C4EB9CC9E5AA000700010100F7F0E6EEE5D4
E6DFC2FFFCD9A8A78992967BCCD6BB94A4877F9475819C7B56765132572E86AF835B8555
87B27CBBE4AA93B779CAE8A8DFF8B4D2E8A08898518C9D56A7BD75E0FAB3CBE59EBAD48D
E4FFB8CDE8A1C6E49CAECC8468833CD0EAA3C0D791D2E7A2D1E5A0CFE09CD0DF9CF1E1AD
863E267C1C10A95040FFB7A1D0917261340D6C5523EBE6ACD0DC9ADBF5AED2F4AAB4D88E
C9EBA1D7F5ADC6DD97CFE4A1AABF7ED4E9A8CFE5A495AB6A90A967C4DE9FCAE3A9DEF6C2
DFF6CCE2F7D6EDFFE5F5FFF1F3FFEFE5F2E1E0EDDCE6F1E3FCFFFA555A54DFE1DEFEFFFD
FEFFFFFFFFFFE3E3E5FFFEFFFFFEFFFFFDFFFFFEFFFFFEFFF6F5F3FDFCF8B5B1AED7D6D2
FFFEFFFCFAFBFFFCFDFFFBFBFFF8F8EFDCD8F9E6E0FFFCF1FFFEF1F2EFDEFFFFEFEFF1DC
EFEEDC7B7867FDF6E6FFFBEAF1E9D6C3BBA89C9384948A80A69B95857C75FFFDF4FFFFEF
F6F0D6E4E1C0E7E4BBD8D7A9D0CE9EE7E6B6FBF8CBFFFCCF8985585652236A6A384B501A
A0AB73A9B87DC4D899D2E6A7D2E4A6CFDFA1CED9A1DDE1AEE3DFB0766D429E8F68E5DEB0
D3E3A4D3EDA6DAEFAACCE09BCFDE99DDEEA8D7EBA4D0E69E
7A825DBAC59BBFCB9B9EAB738E9E5DD1E59DDBF1A6C3DB8FCCE89DC9E99EC6EAA2C3ECA0
C1EDA0BFEE9DBEF09BBFEF99BFE997C9EE9EC6EB9BC6E997CBEC9BC9E996C6E693CDEC9C
C6E597DAF8AED0EEA8D6F5B2D6F6B7BEE0A4BFE2AACCEAB6D0E2B2E5F2C4ECF9CDEAF7CB
E6F3C8D9E6B8CFDEA7D3E3A4D0E49DCFE497CFE696D2E999D0E89ECDE4A0CEE4A6D3E8A7
D0E59AD1E69BCEE7A6CBE9A9C8EEA1C7EE9DC8ED9FCBE7AA041300000400C6C4B5DDDBC4
E7E4C1E8E6C0FFFFE4F2F2DAF5F7E2E9EEDAD5E1CBA4B69EC6DFC2C6E7C8BAE0BBC1EAC0
8DB88A77A26D7AA168BCE0A2B2D18ECCE69FCFE59CD6ECA3B1C880C6E099C5DF98E7FFBA
C0DB94BCD790D7F5ADC3E199CBE69F849F58D7F1AAD7EEA8C5DA95CEE29DDDEEAABEAE7A
782714A0332E9A352BD77E6CAD654C76421D67481AE1D8A1D6E0A1D5EFA8BFE099CFF3A9
CFF0A9C1E09ACFE8A4D1E6A3D7ECA9CBE09D9DB26FA9BF7EB6CC8EC7DFA5D2E9B5F4FFDD
F4FFE6F2FFEBF1FFF0F7FFFAF8FFFFF2FCFDF6FEFFFBFFFFF0F4F33F413EFCFEFDF7F9F8
FEFEFFFFFEFFFFFEFFFAF9FFFDFAFFFFFDFFFFFDFFFBF9FCFFFEFFF2EEEDFFFEFDD8D4D3
DDD8DCD9D4D8FFF4F8FFFAFDFFF9FAF5E0DFF6E3DFFFF6EFFFFBF1FFFFF3FFFFF3F4F5E7
FFFFF39B978C60574E453B31554B418C8279B4A9A5A89D9BBFB5B4B2A8A71E150EAAA295
A19D849794739D9B746665373938085150206463357271439C9A69DBDBA7DBDEA7D5DFA3
CEDEA0D0E5A4E0F9B7CDE6A4C9E2A0CCE1A0E2F0B5D0D89FE9E7B49D95669E8F64E1DBAB
D4E4A5D0EAA3C0D59098AC679BAA65C3D48ED4E8A1D1E79F
FFFFE9FEFDE1F7F7D3CACDA0A1A970C4CE8FE5F1AFC7D892CCE39DD2EDA8C6E6A3C5EDA6
B9E49CCAFBACB1E694BBEF9DBAE498BEE497CAEFA2CBEDA0BADB8CC9E898DEFBABC4DF90
D1EBA1E3FAB4F1FFC5E3F7BCCCE1A9CCE0AFD2E5B8CEDFB3D7DFB6FAFFD7FFFFDCD0D7AB
D8E1B24B5521D1DFA297A66348580F5B6C1E879A4BC8DA8E54651F576726839257D3E1A3
D4E096D6E29AD4E4A6CCE2A4C6E49CC7E79BCDEDA1CAE7A7000A00031000CCD4BCC9D0B1
DFE6BCF2F8CCF8FDDDFFFFEAFFFFEDFFFAEDF5F3E4F9FFEEF7FFF3DFF9E0BEDFC4C0E5C4
C7EFCAB7E2B4C7EFBB1A42065B7F3FD3F4AFCEECA4C3DF955E78315D742ED1EBA4D1EBA4
C9E49DC9E49DD9F7AFC2E098D3EEA785A059C9E39CC6DD97D0E5A0DAEEA9D6E7A3E8D8A4
94433081140F962F268B2F206C210A844E2CAD8C61E8DBA6DEE6AAD3EAA6C7E6A2C1E59D
C6E7A2CBEAA6CEE9A6CFE5A4CADD9BE0F0AF708341586C2DD3E7ACDAEFB7C8DFABCBE1B3
DCF1CAF5FFE8EDFCE5C9D7C6DEEAE0F8FFFFF9FFFFEDF2F6FEFFFF777873FFFFFDF9F9F9
FFFFFFFEFEFFFFFEFFFFFDFFFFFEFFFFFEFFFFFDFFFFFDFFFFFEFFFFFEFDFFFDFDFFFEFD
FFFDFEB7B1B344383AFFFAFBFFF8FAE4CFCEF2DFDBFFF7F0FFFDF4FAF3E9FFFFF4FFFFF4
FCFAEEF9F5EC6E655EA39A93FFFBF6FFFAF8FFFCFDFFFCFFFFFCFFEBE2E398938D7E7B6C
57573D4B4C2A53592D545A2A545B28DCE3B0C5CB9BEAEEBBDADFA5D8E1A2D7E1A2D3E4A0
CFE6A0CCE89EC9E99EC9E99ED0EEA6CFE9A2CADD9DDCE8AADCE1A7979660B5AE7AD6D59D
DCEFADC7E19AD0E5A099AD6885944FD8E9A3CFE39CD6ECA4
FFFFF1FFFEE9E5E4C6E5E5BFDCE0AE919960818B4ED2E1A0D6E9A9BED494DCF9B9C3E3A2
C1E6A1C4EEA6BAE69BCEFAAFCAF2A9CCF2A9C5E99FCAECA0CBEB9FC0DF91C7E295D8F0A4
D5EBA3DCECABE9F7BAF4FFCBF1FACBE1EABFDFE7C0ECF2CCE2E7BFFFFFDAD9DFB1D6DCAC
99A26DE3EEB4D2DE9ED4E19BD9E79CCCDC91D5E59AEBFBB2C5D48FCFDE9DC7D296AEB879
DCE49BD0D79199A2699BAA71899E5B97B167CFEBA0C4DF9C000F00000900DDEDC9D0DFB6
DCEAB7E6F4C1F2FCD7FDFFE5FFFCECFFFCF1FFFDF1FFFDF0F8FFF1E1F2E0C9E2CDC7E7CF
BDE0C0BAE0B9BCE3B4BBE2AD86AC6F9FC280BBDC95D8F6AE8BA55E9AB16BD6EDA7BAD48D
D5EFA8DAF5AEBCD790CFEAA3C4DF98C9E49D8DA760A4BB75CCE19CC5D994D7E8A4BEB17C
792E17922D23BB5B4F873120540E00703B199372479184509BA066BDD192D1EEACCEEEAB
CCECA9C9E8A5CAE4A5D5E9ACE0F0B2BAC88BC9D89D48571E2536008B9E67DFF3BECDE4B0
EEFFD1EEFFD5E0F2C8D4E5C1EAF9DCF8FFEFF9FFF4FBFFF8F5F8F1787974F7F8F3FBFBF9
FFFFFFFDFDFFFEFCFFFEFCFFFFFEFFFFFEFFFFFDFFFFFEFFFFFEFDFFFEFBFFFEFBFFFEFB
FFFEFDF6F0F0FFFBFBDBCBCBAB9695D0BBB8F7E2DDFFEEE7FFFDF4FFFEF4FEFCF0FCFCF0
FFFFF6FFFFF6E7E0DAFFFDFAFFFEFBFFFAFAFFFAFEF8F3F7FFFDFFFFFEFFF6F6EEFEFFEF
FCFFE5FDFFDEF0F9CAD0DAA6CBD5A0CEDBA5DCE6B2D1DCA4D6E2A0D4E49DD1E59DCFE79D
CCE89BC9EA9BC6EB9BC6EB9DBFE194CAE89EDDF4AEC5D692D9E3A49EA265AAA970E9EDB2
CDE09ECBE59ECFE49F8EA25D97A661CADB95D3E7A0C1D78F
F2F5EAFEFFF1F1F7DDD6DEB9DBE4B5D0DDA7C4D295D3E3A5879759394B0FBCD093CFE5A7
D1E7A9D3ECABDFF8B6BAD794C4E5A0BFE099BDDE97CCECA3DDFBB3D5F1A7C9E098D1E59E
CADA99D8E4A6DDE6ADE7EEBBF3F6C9E7E9C2E6E6C2FDFDD9FFFFDAD2D5A6D9E0AD5B622C
9CA66AC4D090DBE8A3CFDF96D9E9A0CDDF95D3E59BC5D68FD8E7A2D8E7A4C8D496909B59
A2AA5F878E484E561DD4DEA9D1E1A297AB64CCE297CAE19D001500000B00D9EFC1C8DCA9
CEE3A8DDF2B9F7FFDCFEFFE6FFFEECFBE9DBFFF4E9FFFEF3FFFFF6F9FFF8F5FFF8EAFFEF
EEFFF3ECFFECEBFFE6BBDFB1D1F4BECEF2B4C8EBA7C9E8A297AE6A7E924DCDE29DD3EAA4
C9E09AD2ECA5CCE69FD4EEA7D3EDA6CBE59EC1D89293AA64455A15C5D994E4F5B1E4DBA4
783D1F9C4A35F5A791FFC7ADF6BB9DA3755176592D5B4F1D575A23A3B579CCE6A7C4E2A4
C4E2A4C7E3A8D4EBB3F2FFCEFEFFD4E1E9B8E2ECBA869262364413687945C8DBA3D0E6A6
CAE19DD6EDA5CFE9A0C6DF9BCCE2A2CCE1A8C7D9A7C7D5B1C7CEBC8D9089FAFDF6FEFFFB
FFFFFDFFFFFFFAFAFAF8F8F8FFFEFFFFFEFFFFFEFFFFFFFDFFFEFBFFFFFAFFFFFAFFFFFA
FFFEFAFFFBF8FFF6F5FBE9E7CBB6B35D4843DFCAC5FFFBF3FFFCF2FFFFF3FCFCF0F9FBEE
FEFEF4FFFCF5FFFDFAFFFEFAFFFEFDFFFEFFFFFEFFF5F3F8FBFBFDFFFFFDF7FAEFFEFFEF
FCFFE4FBFFDDD7E5B2DBEDB3D8EAAED8ECAFD7E9AFC9DD9ED0E69DCFE897CCE997CAEA97
C9EA99C6EC99C6EC99C6EB9BD7FAAAC0E094CDE79DD5EBA3556421333E00D5DB9DD3DD9E
D6EBA6D2ECA5D4E9A48A9E59889752DBECA6DCF0A9D5EBA3
F8FFF8F8FFF4ECFAE0DDEDC8D8EABADCEFB7D9EDB0CDE2A1E0F2B483955799A86D8F9E63
CEDCA1CAD89BD2DEA0D0E09FD4EDA9D4F2ACD1EFA9C0DB94C2DC95CFE6A0CCE29AD4E5A1
DFEEADD1DCA09FA8718B925FB6B98CCBCCA2B9B993B0B1899FA5759EA770909960889456
ABBA77CEDF98D0E59ADEF3A8CCE297CAE097DAF0A7CCE099E2F6B1D0E19DD9EAA6D5E59E
DAE69ABAC67EDBE4ABE8F2BDC7D395D2E19C91A65BDBF0AB000C00071D00C9E2ABC9E3A6
D1EAA6D8F1B0E2F8C7E2EECAFFF9E2FFFCECFFFDEDFFFEF1FFFFF6FEFFF8F8FFF9F2FFF5
E9FAEAF2FFF1F1FFECD2ECC5B8D5A5D0EEB8C3E1A5C9E3A2C8DB99869753B4C883D1E6A1
D1E6A1C2D993DCF3ADC8E29BDDF7B0CCE69FE0F7B1BCD18CDFF3AE8CA05BD1E29EE1DFA4
A57B53692E10AD7554C18C6A8A5D36724D23BFA779A094624F521BAAB77FD1E6ADC4DDA4
CCE5AED1E9B5DBEFBCF9FFDCF4FBD2D7D9B4CCD0ADE1E7C39AA27B4D5A2C62733DD7ECAB
CDE599D8F19DD0EC95CFEB94CEEA96CDE599D7EEA8DBEDB9666E57888B82F5F8F1FAFCF7
F4F6F3FFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFFFEFBFFFFFAFFFFFAFFFFF8
F9F4F0FFFDFAFFFBFAFFF0EEFFF5F2D3BEB9D6C3BDFFFCF3FDF4EBFFFFF4FFFFF4FFFFF6
FFFFF8F5F4EFFFFEFBF2EDEAFAF9F7FEFEFEFFFFFFFEFFFFFEFFFFFCFFFBF5FBEDF6FFE7
D7E5C1DCEEBED2E5ADCFE5A5BFD594D4EAA9BDD395D5EEAACAE999C9EB95C9EB95C8EC95
C8EB97C6EC97C6EC99C6EB9BC3E495D0EFA3C1DB91E1F8B05E6F295A6926DFEBA9CBDA97
D1E8A2C0DA93CADF9A94A863576621DBECA6C1D58ED1E79F
F5FFF6F5FFF4EEFFE5EFFFDEEAFFCEC6E0A3B8D390D5F0ABD3ECA8BAD18DD8EBABCBDB9C
95A163727B3CC0C686E3EEACD4E8A1BCD38BD0E79FDDF3ABC8DE9697AD65657934677B36
80904FBDCD8FDFEDB2E8F3BBF4FECAE8F0BFD4DCABDBE5B1D4DFA5DEECAED2E2A1D6EAA3
E4FCB0CAE596CBE898D1EDA0D2EEA3CBE79DC8E39CC6E099D5EFA8C6DD95C9E197DAF0A5
D1E896DFF5AAD1E0A7D4E1ACD6E4A7CFDE9964742B74853F495D226E834B9CB4788AA562
8EA85EA8C27BC8DCA7D6E2BA8A896AFAF3D9FFFFECE7E1D1FEFAEFFFFFF8F3F4EFFEFFFB
FCFFFAAFB7A8A1AD97EFFEE1BED0A886996BE8FFC9CCE0A5DBEBACCBDA977A8946687935
E4F8B3C9DE99CCE39DD1E8A2BBD28CD0E7A1D9EEA9C3D893CDE19CA7B874CCDB98D7DB9E
D3BF8CAC8D5F826134563508927345D6BB8CEEDCAA615A269A9D68E4EEB9F8FFD4F1FFD4
F5FFDCF5FFDDEAFCD2FBFFE3FFFFE8FAF5DFFFFFECB8BAA4BCC0A5FCFFE3C8D5A79FB376
CAE296C7E08CC0DD81D9F89BD9F79FC6E190CCE69CC9DEA6667058A1A69FFCFFFBFCFFFB
F1F6F2FEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFAFFFFFAFFFFFA
FFFDFAF0EBE7FFFBF9FFF9F6FFF9F8F7E2DF93807CE2D3CCFFFDF6F5F2E9FFFFF8FBFEF7
FEFFFBFBFCF7FFFEFDFFFEFDFBFAF8FCFCFAFDFFFCFEFFFDFEFFFBFCFFF8FCFFF1FBFFE8
DFEEC3C9DCA5DAEEAFC0D793E0F7B1D4EEA7D0E9A7C7E59DC8EB97C6ED94C6EC95C6EC95
C8EB97C8EB99C9EA9BC9EA9BC4E095D5EFA6D6EDA5879C574A5E198C9C5BC3D291E3F6B4
D9F0AACFE9A2DEF3AED2E6A1798843D1E29CD3E7A0CFE59D
F8FFF6F4FFEFF0FFE5E4FBCFD1ECB5D3F2AFD6F7B0CBEDA1BBDB90E2FFB6C8E29BD0E5A0
DAEBA797A45F7F8944949E57748139DDEDA4DFEFA883944D8E9F58A0B46D859954B4C883
D8EDAAD3E8A7C8DC9DD5E9ACECFEC2E1F3B9CEE0A6D2E6A9D4E9A6D4EAA2CAE296C5E292
B6D683D3F5A1B9DC8AC9EE9ECAEFA2CCF0A6C4E59EC3E29CCAEAA1CEEDA1C7E698C7E794
CAEC96C0E192BFD79BC6D9A2E7F7B9D4E39E3A48003747009CAE70D8ECB1CAE09FCAE49B
CCE594D1E99DD5E8B0D0DDB1BFC59FD3D7B6FEFEE4FFFFEDFFFFF3FFFCF6FFFDFAFFFEFD
E6E2DFBAB7B0EDEEE0F4F8E1DBE2C1717C52D6E2B4C8D5A0BCC88AF0FCBA8793514A5916
D1E29ECFE39ECEE39ED5ECA6EAFFBBC6DD97D0E5A0D8ECA7D5E6A2839450DDECA9D5E09E
DADA9EF2ECB2C3B880988952C8B783E5D5A1E4D8A46C6632D9DCA7F9FFCFF9FFD8F3FFD8
F7FFDFF7FFE1F0FFDBFCFFE8FFFFEDFCF2E8FFFEF4B5B1A6E4E5D7F7FCE5FBFFE3D4E4B3
D2E7A6DCF7AACDE897CAE795C1DD90C5E09BE0FABDC9DFB198A490B1B6B0FCFFFBFCFFFD
FCFFFFFBFFFFF3F4F6FEFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFBFFFFFB
FFFDFAFFFEFBFFF8F8FFFAFAFFF8F9EBD7D6DCCAC8B5A7A4FFFEF8F4F4ECFEFFFAF1F6F0
F9FBF8F5F7F6F8F6F9FCFAFBFFFFFBFFFFFAFAFBF6FEFFFBF5F8F1F0F6E8FCFFEDF1FCDA
F5FFD6DCF0B5BFD491D2E9A1CFE9A0C6E097D6F1AAC5E399C5ED97C3EE95C5ED95C6EC97
C8EB99C9EA9BCCE89DCDE79DCBE29AE2F7B2C4D9966275338C9F5FB7CA8AD1E4A4CBE09D
C5DF98CCE69FC9DE99D6EAA5A4B36E9AAB65DDF1AACFE59D
FFFFF4EDF2DEE0EBCBDAEBBFC0D99FC1E09AC8EEA1B6E08ECCF6A4C5EF9DBBE092C3E397
D0ECA1D0E89CDDF2A5DFF0A29FAA5E323A006D772EB0BC72A4B169CCDD96E0F4ADC1D691
D4EBA7C8E19DC3DE9BCCE7A4CFECA9C9E7A1C8E6A0D1EFA7C9E89CC0DF8FDBFDA9C9ED96
C9F097D7FFA9C0EC95B8E391B6E192BDE79DC5EDA6BFE7A0C3E99EC6EB9DCAF09DC6EE96
ADDC80E8FFC1C8EAADBDD69FC4D698D0DF9AE1EFA2D3E196CBD99BDEF0B2C9DE99CDE597
CEE692CEE394D8E7ACD3E0B2D3E0B488946CA1AB89F0F5DEFDFEEEFEF9F3FFFDFBFFF4F8
B1A5A7F7EBEBFFFCF6FDF6E6FFFDE4FFFFDEB1B38C8F9565B3BB80DBE6A4D5E19FACBB78
A4B571CADE99D8ECA7C9DE99C3D893CBE09BDBEFAAC2D691D0E19DE8F9B568773473823F
C5D491B5C17FCDD393F6F6B8D7D298EFE8B1FFFFCD8E8B56D9DBA9D7DFAECEDBADCBDCB0
CEE0B8CCDDB9D9E8C7F9FFE9FFFCF0FFFBF8DCD1CFB8B0AEFFFEFBFFFFF8FCFFEFEBF9D8
D6E7BADCF3BBBDD5999CB57B66814E6C855DCCE4C4F5FFF1778178818783E8EEECF1F7F7
FCFFFFFCFFFFF4F8FBFCFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFEFDFDF7F7FFF6F8FFF5F6FFF3F5F7E3E4F2E0E0DCCECDF7EFECF9F8F4FEFFFDF9FFFD
FCFFFFFEFFFFFFFEFFFFFEFFFEFDF9FFFFF8FFFEF9FFFFF8F6F9EEE8EFDFF7FFE7E4F0CC
D9E9B8B9CD90A4B974D8F0A6819B517E984E758F4692B165C5EC99C2EE97C3ED99C6EB9B
C9E99DCCE89ECFE6A0D0E5A0D0E09FC8D8972C3C003C4C0DD0E0A2D3E5A7D3E5A7D1E6A5
D0E9A5D4EEA7CCE19CD4E8A3CDDC9794A55FB5C982E3F9B1
DBE0C9FCFFE6F2FED6C4D8A5D5EFB0D1F3A9BAE190CAF69FBEEA93BDE992CFF9A5BFE592
D3F6A4D0F09DC5E08FC7DE8ECEDC8FD6E195E6F2A6CDDB90D7E79CDFF4A9BFD58DDAF1AB
C9E29ECBE6A3D0EBA8C8E6A0C4E29CCEECA4D1EFA5C1E195CDF09EBCE28DCAF29CBFEA91
C1ED94B4E288CCF9A4BAEA96C8F4A5B9E59AC6F2A7C1EBA1C7F1A5B7E091C5EF9BC2EE95
C6F79BB2E28CC4EBA8D1F0B4CFE8A7CCE29ACFE290D2E596DCECAEC6D89ED2E7A2D7EFA1
D6EE9ACBE093D7E7A9D0E1ADD3E5B1CADCAC99A67BA5AC8AFBFEE3FFFFECFAF4E6FFFEF4
B1AAA2FFFEF4FFFFF3FFF9E9FFFFECFCF8DFFFFCE2DCD9B6959A64919B5CD3DF9FDCEBAA
82934FCADE99D3E8A3CFE69ED3EAA4CFE6A0D0E5A0D2E7A2D1E5A0C9DD98D4E4A3CDDD9C
4C5F1FDAEAACDFEAAECED69BDBDEA5F8F9C0FDFCC695955FDCE0ADD2DAA7D2E0AFD9EABD
CDE3B5BFD6ACCEE7BFF6FFE4FFFFECFFFDF4DCD1CDDBD1D0F7F1F1FFFFFBE8EBE0FBFFEF
E6F5D4D3E5BDC9DEB3CFE4BD5A6D4F000700616E65E4EEED656B697F8382FCFFFFF8FCFD
FCFFFFFCFFFFF8F9FDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F6F4F7FFFEFFFFF6F7FFFBFBFFFBFAF5E7E4E3D5D2FFFCFADED9D5FFFFFBFEFFFFF8F9FB
F8F9FDFDFEFFFFFEFFFAF8F9FFFFF6FFFFF1FFFFEEFFFFEDE5E8D3D2D7C0E1EACDCDD9B1
CCDFA8566A2B859C58CCE39FCEE3A2D4E9A88DA05E91A661CAE89EC6EB9DC5EB9EC5EB9E
C8EAA0CCE7A0D1E4A2D6E2A2D9E1A5747A3E414B0EDFEDAFD6E9A9D3E8A7C6DC9BCDE6A4
CFEAA3C9E49DD4EBA5D0E5A0CFE09A9DAE684F631CCADE97
E2FACAF4FFD8D9F2B9C4E1A1CDEEA7C5EA9CC4EA97C6EE96BCE48BD7FEA5C1E58DCFF39C
BFE18BC8E895D4F19FCDE899D0E69DCBDF97D2E89DDAF1A3CFE799C4DF90CBE699D4EEA5
C9E29EC8DE9ECAE0A0D0E4A5CEE3A0C9DD98D0E19AD8F0A4C7EC9CC8F3A1BFEA98BFEA98
C8F5A2BFEC99B8E592C7F4A3C3EE9ECCF7A8BCE798C2ED9EC7F2A3BEE999C3EE9CBDE992
B5E285CBF89DC9F2A4C9EEA8C5E6A1C2E195D1F395D1EF99CFE6AECEE4B3CFE8A4C1DC8F
D6EEA0CBE399CBDFA0D3E7ACD6EBB0C6DA9DABB880959E69FFFFD4FFFFD2FEFFD8BCC49B
828E6AEAF9D8CAD9BCF9FFEFFEFFF3FFFDF4FFF7F3FFFEEFE9ECC1DCE6AA6B763A536324
5D702ED2E9A3D3EDA4C1DD92CAE69CCDEBA1C9E59BCFEAA3C3DD96D6EDA9C9DE9DCEDDA2
A1A978FFFFDAFFFFDAF6FCCEFFFFD6ECF4C1D1D8A44E551FD2DBA4D4DFA7CDDCA3D5EAB1
C2DEA4CBEFB2BDE6AAC6E7B2D8E2BDF4F2D9E3DDCDDDD6CCFFFDFAFFFFFAFFFFF6F6FDED
E2EFD5D7E6C7E7F8D8F8FFECF7FFF0FEFFFD3E3B44010009000004F6F8F7FEFFFFF2F4F3
FEFFFFFEFFFFF5F5F7FFFFFFFEFEFFFAFAFCFFFFFFFFFFFFFFFFFFF2F2F2FFFFFFFFFFFF
FDFEFFF0F1F5FFFFFDFBF8F1FFFFF4F4F0E4EAE4D8FFFEF4E0DBD5FFFEFBFFFEFFF9F7FA
FFFEFFFFFFFFFFFEFFFFFFFAFFFFEDFFFFE4D1D2AABEC196B9BB96ADB39188926F86976B
93AB6FA4BE7DC5DDA1D3E7B2DAE7BCCDD4ABB3B5849C9F6AE6F1B7EEFFC4C1E19EBAE29C
C5EDA7C1E09CDAE8AAE2E3A9DDD79D544F15969B5BD3E29FD1E8A2C9E59BCCE89ECCEAA0
C7E79CD4F4A9BDD98FCCE69DDBF0ABAEC27D4B5C18D7E6A3
C5E3A7D8F8B9C7E7A4C4E5A0CFF1A7C7EC9EC6EC97C3E992C9ED95C1E58DCBED96C8E893
CDED9AC7E494C5E194C9E399D0EAA3D5EFA8C5DF95BED98CD1EE9ED5F2A2CAE699CBE79D
D0E9A5D5EBABD4E8ABD3E5A7D9E9AADFEEA9D9E69EC8DA8EC1E092BCE193CFF1A4CEF3A5
BFE496CBF0A2D6F8ABBFE194C5E79AB6D88BD3F5A8CCEEA1BBDD90C8EA9DC7E99CCCEF9D
D1F49AD1F29BB2D183CFEDA7D5F2B0C1DF97D4F698BDDD88000D00000C00D2EFADB7D68A
D5F4A8CBE9A1B9D694D8F2B3CCE2A1DBEBACCDD798999D60B8B97FAEAF75DDE5AAD8E7B0
DCF3BFB9D4A7C7E3BDECFFE8E9F6E5FEFFFBFFFCFFFFFEF8FCFDDDEBF5C3D4DEAADAE9B0
DDF1B4CBE1A0C4DF9ADAF8B0C6E49ADBF9AFBEDC92C9E79DD6F1AACFE9A2D4EBA78B9D61
A6AC80DCDEB7F7FCD4E5ECC0F4FFCEDFECB7CFDAA25C672D3D470BD1DD9FD8E6A8D7ECAB
BCDB98CBF3ADC5F4ACBAE3A1D4E6B4EBEFCACBCAAEDDD8C4FFFFF3FEFAEFFFFFF3E7EBDA
DFECD2E0EFD2DBEACDF9FFEDF5F8EFFFFEFFFFF8FF3C314208060BE0E0E0FFFFFFFFFFFF
F4F4F4FCFCFCFAFAFAFCFCFCFEFEFEFFFFFFFBFBFBFCFCFCF9F9F9FFFFFFFCFCFCF9F9FB
FEFFFFFEFFFFE6E8E5F6F7EFFFFFF3E0DECFF6F3E4F3EFE3DFDBD2C5C0BCFFFBFDFFFEFF
FDFBFCF6F5F3F9F8F4FFFFF3FAF9E4BBBB99A1A371CED19CF4F5CBFEFFDFE4EECCD5E5BE
C6DDA5C9E3A6D2E9B5CFE0B6D6DCC2DDDBC4D8D0ACD8D1A5FDFDCBFCFFD1CFEFB0C0E9A5
C5F0ABC9E9A6D5E1A3B6B479574C14786F34D4D997DEEDA8C5E196C7E79BC7E698C9E89C
C5E59AC3E398CEECA2D5F1A7BFD690D1E5A0C1D08F9BA767
BEDA9DC6E4A4C1E09CCAE9A3CEEEA3C7EA9ACCEF9DC4E891CCEE98BBDD87D1F19EC6E595
D0EC9FDAF4AAC9E39AD6EDA7C9DF9EC8DF9BD4EEA5D3EDA3C7E494D2EF9FBBD78A79954B
7E99548CA563879D5D7287467A8D4BA8B973CFDF96DAEA9FE4F4ABD3E49DCCDC95CBDC95
CFE099DAEBA4D9EAA3CADB94D7E8A1E1F2ABD1E59DC9DD95DCF0A8D7EBA3C4D890D3E599
DCE999C2CD7FE9F4B0E8F2B6BECB95D0E0A2DDF3A1CEE69C001400000B00C7E5A7CFF4A7
C5EA9CD1F7AAC4ECA5C9EAA5CDDD9EE3E9ABE1E2A6BCBA7FB8B379B1B077D8DDA3D8E7B0
CCE4B0C5E5B4D5F5CCDFFEDEF1FFF3F7FFFAEDF2EEFFFFFAFBFFE8FEFFE3EEF6D1CAD7AC
D5E5B4CDE2AAC9E1A5CCE6A5C9E49FD3EEA7C8E49AC3DF94CDE79DBCD68CD5EDA393A664
929A67D6DCAED9E1B0D0DDA8DEEBB3D3E1A6D7E3A58E9A5A424C0DC9D492E2EEACCEE29B
CCE7A0C7EBA1BBE79AC8F0A9D1E5AAE0E8B9ACAE87DEDDBFFFFFECFEFDE9FCFEE8DAE0C6
F1FFDEF5FFE1F7FFE6F8FFEAF3F9EBF9F8F6D5CBD66C616F3D3B407E7E7ECACACAFCFCFC
FFFFFFFDFDFDF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFF9F9F9FFFFFF
F4F3F8FAF9FEFFFFFDF9F9F1FDFDF1E8E6D9FFFDF1FFFFF4DDD8D2A39E9BE5E1E0F8F4F3
FFFFFAFFFFF8FFFFF4FFFFEFEFEFD7999977B4B385DEE0AFF1F1CDFAFDE0F3F8E1DEEBCD
E5F8CBE7FBCAEBFBD4E4EFD1EAE8DBF6ECE0E9D9C0EEE1BEF3F3C1EBFABFC8E8A7C5EEA8
C2EDA6C9EAA5D3E1A3A0A064726930C5BF83DAE19EC7DB94C9E89CD6F8ABC4E498C8E79B
C4E298D6F4AACAE89EC6E097CBE29CDCF0ABEDFEBA879653
D0EAA9CDEAA7C6E49ECFEDA5C8E89CC4E596D1F2A1C9EB97C9EB97CDED9ACFEEA0CAE69B
C0DA93D9F0ACC8DE9DCEE2A3D5EBADDFF5B5CFE8A4BDD78EA2BE716E8A3D6C883DACC87E
C6E19CD5F0ADCDE6A5A9BF7E91A66193A75F98AA5E93A1567279339FA461A2A764A0A562
A6AD69868D49919854E8EFABD7DE9AD7E19CACB671B9C47F98A35E8D9853DEE9A4CAD18B
8B8D426060182220007B7946E0E1B5DFE6B3DDEAA4CADA9B000C00000900A1BD83C8EAA0
B5DB8EC2EB9DC2ECA0B4D890D0E5A2D5E1A1D6DFA0DBDFA2DEDFA3E2E6ABDFE9ADC7D69D
C8E1AABDD9A9C4E3B9F0FFEAF2FFEFE8F4E6FEFFFBFFFFFAFFFFF4FFFFF1EAEFD9E8F1D4
E8F6D3EFFFD6CDE1B0D0E7AFD9F1B3BAD592D9F3ACCFE9A0CAE49ACFE79BD1E99DD1E59E
879258F5FFCACBD8A0CFDEA3D0E0A2CADA99DDECA9C4CF8B5D672266702BCBD78FCDDD94
E5FDB3CFEFA3ACD586CAEFA2CDE2A1D6E1A9969C6CDEE0B8FFFFE3FFFFE4FCFFE0D8E2BF
CDDCB5EDFFD7E2F4CEF6FFE6FCFFF1FFFFFA2E282CBDB6BEFCFAFD454545191919000000
7B7B7B5A5A5A8F8F8FA9A9A98080807B7B7B9191918787878181816E6E6E5555559C9C9E
88878C787679F8F7F5F6F3EEFFFFF6EEEADFDDD9D0FFFEF8FFFEFBFFFBF8FCF8F7C5C4BF
F4F6EBFDFFF0F5FAE4E7EDD3ABAE938E8E6CDADCADE3E5B6E9E8C9FFFFECFEFFF3FBFFF1
F0FFDCF5FFE0F9FFE8FDFFF0FFFCF9FFFBF8E0CABCDFCEB0E0E0AECCDF9FBCDD98C9F3AB
BDE99EC3E49DD6E5A4A0A062565014D2CE8FDAE5A1D2E8A0C9E99DC7EC9EC1E195D0EFA3
D2F0A6C6E298C6E298E0FAB1CBE29CB7CC87D5E6A28C9D59
CEE7A3D2EBA7CEE8A1D2EEA4C7E69AC3E294D2F1A1CBEA9AC1E090CAE99BCEEAA0D3ECA8
D7EDADC3D79CD6E7B0D3E4AEC1D49CCBE1A3C3DC9A8FA962749045B7D386E4FFB7C2E096
CBE9A1CDE8A3CDE8A5CFE8A4D1E8A0C7DD92AAC17193A456474C09818141919151979757
9C9E5D7173326B702EB7BC7AD6DB99DDE4A181884597A05DC7D08DADB673ADB673848B45
B7B76F8C8946A6A16A9894679A9774CFD1A9D3DBA0DBE5B0000500000600D2E8B7C7E29F
D2F2A7C1E396CBEDA1DCFFB4C8ECA4C5E69FCAE8A2D4EBA7CCDF9DD7E7A8D2E4A6CFE3A8
CFE3AEDFF5C6D4E6BEF4FFE3F7FAE5FFFFF3FCEFE9FFF4F3F5EFEFFAFAF8FFFFFAFEFFF6
FBFFEEFBFFEADCECC7D9ECBFD8ECB7B7CF93CBE1A0D4EBA5CBE29AE0F6ABC7DD92D2E69E
9DAB6DC0CE91D5E5A7D5E8A6D1E5A0C7DB94DEEEA7D6E29A90984F3F47009CA45BD3DF95
D3E59BD2EDA0C4E797CDEE9FCBE399D1E09D97A165D6DDA9FFFFD8FFFFDBF6FDD4D8E3B9
CFDFB2D7EABDE6F8D0EEFFDDF9FFEBD3D5CA686463FFFDFFFAF8F9C9C9C9797979676767
2C2C2C393939000000383838151515000000676767111111838383242424666666929292
4D4B4E3B363A625E5D8C8783FCF7F1FEF7F1DBD3D0FFFDFBEDE7E7FFFEFDF0EFEB92938B
9599889FA88DE5F0CEE8F2CD8E94729B9D76E4E8B6DADDAEEFF0D1FFFFEFFEFFF8F8FFF3
F9FFECF9FFEAFCFFEFFFFFF8FFFBFFFFF9FFD2B7B0D0BCA3DDE0ABD1E6A1C2E69CC9F5A8
BEE89CCDEFA5D3E29F7C7E3D656122D9D999E1F0ABD7F1A7BDDF92C4EB9CCEF0A3C5E498
BAD68CDEF8B1C9E39CCCE39DCEE59DA7BD758FA35CB9CD86
B0C580C9E098CEE59DD1EBA1CDE99CC6E597CFEE9EC9E89AD5F4A6C9E59BCFE8A4C3D999
CADDA572834F909D6F8895679FB17D8DA26970894889A25EC7E398D4F3A5C2E195C8E79B
D2F0A8C6E49EC3DE9BCCE7A2D5EFA6D3EB9FCEE595D0E394DCE6A1D5DC99D8DD9BDDE4A1
DFE6A3DDE6A3D0D996B6C17D939E5A99A661C7D48FDFEEA9D4E39ED7E8A2DEEFA9D1DE98
C9D188E0E5A2E9ECB7CCCEA6929374A8AC8BF2FAC7EAF3C600040010180B9FAC81C7D99B
D4EAA2C5DB90CEE499C4E397C0EC9FBAEA9EC6F0A6C6EAA2C1E09AC8E3A0CEE4A4E7FBC0
E8FBC4DDEDBED8E3BBEAEDCEFAF4DEEBDECE8E776FFFF3F2DAD0D8CECBD4FEFCFFF3F3F1
F1F4EBFCFFF3F6FFE7E0EECBDFF0C4ECFECCCCDFA7D2E6A7C3D897D1E6A1D0E69ECDE19A
A7B7784F5F20D1E6A5CFE4A1D4EAA2CCE098DBEBA2D1DD95E7EDA57578315C5F18D5DD94
CEDB93CDE398D5F1A4CCEB9DCDE599D2E69EAAB978C5CF93EAF1BDF0F6C6E6EFC0D4E0B2
D3E4B7B9CC9FE1F6CDE0F1CF333C27979A8FBCB8B5FCF8F9FEFCFDFFFFFFFFFFFFF4F4F4
FFFFFFFFFFFFDBDBDBD8D8D8EEEEEEF4F4F4FFFFFFF4F4F4FFFFFFFFFFFFF6F6F6FFFEFF
FFFDFFD5CFD1E6E0E0181310FBF3F0E7DFDCFBF3F1FFFBFCFFFDFFFFFEFDF6F5F1F9FDEF
FCFFECDEEAC6D4E4B7616E407A855A969E6FC9D299D2DBA6EEF2CFFBFEE9F1F7EDF9FFF8
F3FFE7F9FFECFBFFF1FEFDF8FFFAFFFFF8FFBCA09CBCA88FD7DCA4DAF2A8C6ED9EBFEC9B
BFEA9ADDFDB1D0DD98535514E1E0A0EAECABCADB94CAE99DC2E99AC4ED9ED3F5A8C1DF95
CDE7A0CBE29CD7EEA8B4CB85829951A9C078C4DA92CDE39B
97AB64C9DD95D1E79ECEE69AD0EB9ECAE797CCEB9DCAE99BC8E49AC4DF98CDE6A5CDE1A6
D4E5B1C2CDA2D5DDB6DBE6BCCEE0B0C1D5A0C9E1A5CFE8A6C0DC92C1E094CEED9FC9E99D
C4E49BC6E69DCDEBA5D4EFA8D0EAA1C6E194C9E291D3EA9AD2E89FCCE29AD6EAA3D1E79F
C1D78FCFE69EDEF5ADC9E39AC8E49ACAE89ED3F1A7BEDE93C3E398C9E99EBADA8FD9F8AC
CAE699D8F2ABD1E6AEC1D2A8E1F0D3ACB99B7B885AFCFFE1010300000100121600666B33
626725989E58D7DD95D2E49AC3EDA1B6EB9DC3F3A7BFE99FD2F6AED0EFABCBE5A4EDFFC5
F6FFD0F6FFD2FFFFDCC6C6A4A69C81FFFCE8FFF4E6FFF4EFFFF4FCADA7B3DCD6E0FFFEFF
FFFFFDFEFFF8F8FFEFFCFFECF8FFE3FBFFE1D9E9BCC9DAA6D2E3ADD1E3A9CDDFA3D5E7A9
96A86C586A2CC7DB9CCDE3A2D2E7A4CFE39ED9E6A1D4DE99DEE19E9E9F5D5253119EA15E
E0E9A6D5E4A1CFE49FC3DD96CDE59BD5EBA3C6D793B0BE80CFD8A1DDE5B2D9E3B1D1DEB0
D6E7BBDEF0C8C1D5B0CCDCC1000600F1F7EDEDECEAFFFEFFFFFEFFFBFBFBF9F9F9F8F8F8
FFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF4F4F4FFFFFFF6F6F6F9F7F8
FFFAFCFFFCFFFFFCFD837B796E6664DCD3D4D6CDD0FFFCFFFFFCFFF5F3F4FFFFFAFEFFF1
F3FEE0CEDDB2DEEFB9B9CD92C3D49DD1E3A5DCEDA7E2F2B1D8E4B6D4DFBFCCD8C4D6E5D2
E1F1D4F1FFE2F9FFEFFEFFF6FFFAFDFFF9FBB0988EB9A88AD0D89CD3EEA1C0E796BFEA98
C1EB99D5F4A6CBD691646724E2E3A1D0D793C8DE95CFF1A4CBF4A6B3DE8FC3E89BCFEDA3
D2E7A2DEF2ADC8DC9781965197AE66C2D991D3EBA1DEF6AC
96A760D4E69CD7ECA1CBE196D1E99BCAE797CCE89BCDECA0C6E298DDF8B5CDE3A5CCDFA8
AEBB8DFEFFDDF0F6D2FEFFE1D1E0B5D2E6B3CCE4AACCE5A4D2EDA6D1F0A4CCEB9DCBEB9F
CCECA1C7E79EC4E29CC7E29BCDE79ED0EB9ED1EA99CDE897CAE69BCEECA2C7E59BC8E69C
D1F1A6C7E79CBEE094CDEFA3C4E99CC7EDA0C1E79AC8F1A3C4ED9FBCE798C8F3A4BEE799
CCF3A4BCE098C4E3AAD0EBC0DFF6DADAEDD1ADC09397A582000304000000A7A888D9D9A5
B4B476BDBD77BFBC77B8C077D2F0A6C6ECA3CDF1A9BBDC95D4F2ACC9E49FC3D998ECFFC3
AFC0898B9966919A6D92976FB9BA98EAE7C8F2ECD2FFFFEFFFFDFDCBC6CDD2CBD2F7F2F6
B7B6B4FFFFFAFCFEF3FBFFF0EFF4DEBBC4A9BAC4A2A4B08AE0ECC4D6E6B998A579ACBC8B
8F9D68CDDEA7C8DCA1DBEFB4CFE3A6D1E1A3D1DD9FDEE4A6D6D59CE7E5ACA5A0683B3A01
C0C38CD0D9A0D1E3A9D7EDAFCAE3A1D7EEAAD8EAACA5B378BFCA92D5DDAAD5DEAFD5E2B6
D1E1BADFF0CEABBBA02B3A25B2BDAFFCFFFAFFFEFFF5F3F4FFFEFFFCFCFCFAFAFAFFFFFF
FAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBF5F5F5FFFFFFFFFFFFFEFEFEFFFFFFFFFEFF
FFFDFFF5ECEDFFFCFDFFFDFB4B424362595AE6DDE2FFFDFFFFFCFFFFFEFFFAFBF5FCFFF1
F5FFDED6E6B7C4D79FDFF5B4D3ECAAD1EBA2C3DC89D0E89AC1D69BD7EABDD6E9CBC0D5B6
E3FCD2F4FFE1F7FFE8F9FFEDF9F6EFFFFCF6B9A493D1C59FDAE4A5CFEC9CBEE592CEF8A4
C7EC9CBDD88BC5CF88969954D9DA98DEE8A3D8F2A8B4DB8CC1ED9EC3EE9FCFF1A5C8E49A
D1E5A0D1E29EB8C9858DA15CD7EDA5D1E8A0CDE79DC2DE93
6A7A318C9E54D1E69BCBE294C5DD8FCCE999D7F3A6C2E195C9E79FC9E4A1D5EAAFC9DAA6
4E592ED7DFB8FFFFE3F4FAD8E6F5CCE5F9C8CAE2A8C9E2A1CFEAA3C6E599CBEA9CCCEB9F
CAE89EC8E69ED0EBA6CDE8A1D1EBA2D3EBA1D0E799CDE899C5E59ACBEDA3CFF1A7C6E89E
C1E59BBFE399CDF3A8C1E79CCAF3A7C1EB9FBFE99DC9F3A7B9E397C9F5A8BDE99CC5F1A2
C1EC9DC0E8A1C1E4ACCEEDC3EDFFECF2FFEDF5FFDFC5D4B3000505000002ABAE8FD8DDA7
DCE1A1DFE29BC6C78194954F9DA260D6DC9CD9E2A1D6E19FB3BF7F909F5EA0B0718A9C5E
BDCF958DA06893A772BFD5A4D5EDBDC2DCAFCFEABFEEFFE1FEFFF5FFFEFBFFFDFBFAF5F2
F1ECE8FBF8F1D0CDC6CFCFC5A9A99DE9ECDBDEE1CED4D9C3FCFFECFBFFEAA3AC91A4AF8F
CCD7ADD5E2B4CBDBAADAEAB9C6D7A3D7E4AFD8E0ADD7D9A7D1CD9EEBE4B6DDD4A97E7A4D
A3A47AD8DFB3CBD8ACD2E6B5D6EDB7BFD69ED6E9B2B8C691ADB785D4DBAFD7DFB6D8E2BD
EDFBDAEDFBE2485744758175F5FCF5FEFFFFFFFEFFF4F2F5FFFDFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFEFEFEFDFDFDFDFDFDF8F6F7
FFFDFFFFF7F8FBF2F3FFFDFBD6CDCE584F508C8388FEF8FCFDF6FDFFFEFFFFFFFAF7FEEC
FBFFE4CDDDAEC4D79FD3ECA8C3E398CAEE97CBEF8FCAEB90DDFBB1F1FFD3E2FECEC0DDAF
C9EAB1C4E3AACDE7B8D0DFBEFFFFEFFFFBE8C5B79ACFC89AD1DD9BD2EF9FBEE491D1F8A5
C5E898C7DF93BCC37D989955DDE09DD6E39DCAE99DC3EC9DBFEE9EC2ED9EC8EA9ECDE79E
C8D995B8C48291A05DB3C480D5EBA3C8E299CEEA9FCEEDA1
9EAE678B9B52D4E69CD4EB9DD8F0A2C7E494C9E89ACAE99DC1DF97CAE5A2D3E8ADD5E6B2
7B865BF2F8D2E2E6C5FFFFE1F5FFDBEFFFD4D2E9B1CDE6A5D0EBA4C8E497CAE99BC9E89C
D3F1A7C7E29BCAE39FBBD490C2D792E0F6AECCE196D5EBA0D0ECA2CAEAA1BAD890DDFDB4
CDEDA4E0FFB7ADCF85D7F9AFC0E298CEF2A8BEE298C2E69CD9FDB3B6DA90CBF1A6BEE298
C2E498D0EFACE4FFCDD9F3CCEBFFE6E7FBDFE6FBD0E4F5D1000703010A07C0CCA8DAE7AF
DCE8A6D5E29AD5E197C0C781565213C6BD82EDE9ACD8D89A9EA2658F995AD1DD9FE4F2B5
D0DFA4D8ECB1C6DEA4CCE7B0CBECB5CBF2BBC1ECB6E0FFD4EBF0DAFFFFF3FFFBF1FEF7ED
FFFEF6FFFEF6D7D2CCDCD7D1FFFFF8EAE7E0F9F9EFEAECE1ECEFE4FCFFF4FAFFF4FCFFF1
F3FADBD8E0BBFCFFE1DCE8C0F2FDD5F3FBD2D6DBB3FFFFDDFFFFDDD9CFACABA0806E6848
9A997AE5EACAFAFFE5DCEDC9CFE5BEEAFFD5E4F5CBE6F3C8C7CFA6F1F7D1F4FAD8E2E8CC
EFF9E1F2FDED051107848F89FBFFFFFEFFFFE1DFE4FFFDFFFFFEFFFFFFFFFBFBFBF2F2F2
F9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFEFF
FAF4F6FFFCFFFFFCFDFFFAF8E8E0DEAEA5A6473E41FFFCFFFFFDFFFFFEFFF6F7F1FDFFF0
FBFFE8CAD9AED4E5AFD0E9A8C5E79AC9F198CBF48ECDF390DCFDACEAFFC6E0FFC8CBEEB4
C0E8A2C5EAA5C6E5AAC5DBADFCFFE8FFFFE7D7CFABE4E0B0D0DF9CD2EEA1BEE393C7EC9C
CBEA9CD6EBA0BABF7CA6A564DDE09DD6E39DC9E99DC1EE9DBFEE9EC1ED9EC9E99ED0E69E
E9F5B3737E3C9DA967CEDF9BC7DD95D7F1A8CBE79CC5E498
CEDB9695A55ECDDE97D0E69BD7F2A5C4E093C4E596CBEB9FC5E59AD2EFACC6DEA0CBDEA7
D8E4B4C8CFA5FFFFDFFFFFDFF8FFDDF5FFDAD5ECB4CBE5A4CFEBA1C9E598CDE99CCAE699
CCE89EC4DD99D9EFAEE1F6B5D1E1A0D0E19D89985396A65FD5E9A4CFE49FCCE09BCDE29D
C6DB96BACF8AEBFFBBCBE09BC6DB96D6EBA6D5EAA5C8DD98DBF0ABBFD48FCDE29DDDF1AC
D8E7A4C7D598FBFFD9FCFFE3FBFFECEEFBDFC9D9AAD5E5BE000500000800A7BE94C3DD9E
C6E49CBFDE92C7E899CFE59CCED08FB3AD71848245A4A969D0D99AD9E5A5DFEBADC3CF91
DBE6AACBD99ED2E1A8D6EBB2C9E5ABB8DA9EBCE4A8C9E7B3F1F8D7FEF8E2FFFFECFFFFED
F7EFE2FFFEF3FFFDF6FFFDF8FFF9F6FFFEFBFFFEFDFFFEFCFFFFFDF0F2EFFEFFFFFAFDF6
FDFEECFFFFE8F7FBE0FBFFE2E0E5C7A5A88BB4B397453F2550462D63543F877A67B1A996
FFFCE9FFFFEFF3FCE9F7FFF1F4FFEFF2FFEBEDFCDFF5FFE0A2A789ECEFD2F7FADFFFFFED
FCFFF4AAB1AA9FA8A7E4ECEEF9FCFFFFFEFFFFFDFFFFFDFFF4F2F5FEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFBFBFBF7F7F7FEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFEFEFEF6F4F5
FFFDFFF8F2F4F6F0F0FFFEFBFFFDFAF3EBE8625A58060000EAE4E6FFFEFDFFFFFBFEFFF4
F1F9E1CEDAB6E6F6C9C8E0A6C9EAA3C5ED97C3EB8AC2EA89C8EB97CBEDA3C5EAA7BDE59F
C5F0A0CEF7A8C6E9A5C0D9A2FBFFE4F3F4D5BDB892DCDAA9D5E5A4D6F2A7C9EB9EC1E396
CDE79DCEDE979393539F9B5CDDDF9ED4E39EC8EA9DBFEE9DBEEF9DC1EE9DCAE99DD1E59E
D7E2A03F4807919D5BD9E8A5C0D48DD9F0A8CEECA2C6E69B
D8E4A2B1C07BBFD08ACAE097C9E399C4E395CCEF9FC3E598CCEEA2C3E29CCEE7A6DBEFB4
C5D3A0B8C091FEFFDAFDFFDAF3FFD7EFFFD2CFE8AEC7E1A0CCE89EC9E696CFEC9CCCE79A
C7E198DFF6B2CDE0A0C5D5979EAA6C99A364565F1E4D5615929E5C939F5D99A56384904E
BDC987EBF7B5C8D492D5E09EEBF6B4D3DC9BD2DB9ADBE4A3D6DF9EEDF6B5CBD493DAE0A0
EBEDAEF2F3BAFFFFD8EDECCDE5E7CFE6EBCBE1EEB9D3E3B6000D00000E00859F70C4E4A1
CBEFA5CAF1A2BDE698CFEFA4E2EDABB9BE7E939C5BB9C583D4E4A3CBDB9AD4E2A4DAE6A8
E0E8ADD4D99FE0E5ABCED79ED3E2A9D0E5AADBF7BAC5DCA4E2E6C1FFFFE4FFFCE2FDF5DE
FFF9E6FFFDF1FBEEE6FFFCF8F9EEECFFFCFDFDF7F9F7F2F6FFFEFFFBFAFFFFFEFFFFFEFC
FFFFF4FDF7E7F9F6E3FFFFEDC8C7B2595742595440B6AD9C928575928275DCCEC3F3E9DF
FFFFF6FEFFF8F9FFFAF5FFFBDCF0E5F2FFF8F8FFF3E9F2DDA0A48DEFEED9FFFFEDFFFFF3
F3F4EEABAFAEB0B5B9FBFFFFFEFEFFF9F8FEFEF8FCFFFDFFFFFEFFFFFFFFFCFCFCFCFCFC
FFFFFFF9F9F9F9F9F9FFFFFFFFFFFFF4F4F4F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFFFDFFFFFEFDF6F1EDFFFCF6D9D2CCC4BCB92F2725999393FFFEFDF3F2EEF0F1E9
FEFFF1E4EDD2D8E3C1F3FFD8D8F5BBCBEFA7C7EB93C9EC92C9EA99C4E69CC1E4A0C1E9A2
B9E38FBFE993C8E9A2CFE8AFFBFFE4FFFFE3A09A78EAE7BAD1E1A3CFEAA3CEEEA5C4E29A
CDE29DB2BD7B615D209E985ADEDE9ED4E39EC6EB9EBEEF9DBEEF9DC2ED9DCCE89DD3E49D
D6DF9C696F2F97A260E1F0ADCFE39CCCE39BCEECA2C5E59A
D4E0A0D0DF9EB5C984D5ECA4CBE79CC7E79BCEF3A3BFE494BEE395C3E599D2EDA8D2E8A8
D1E0A76A7440E3E9BBE7EFC0E2F4C4E4FCC8CBE5A8C5E09DCBE79CCAE797D1EC9DCDE899
C6DC94DEF1AF6F7D40535E2460682DB5BA80E0E4A9D9DDA2E4EDAEAEB8799AA465525C1D
4D56171C25009DA365A0A467D2D699E1E2A6DBDCA0D7D89C9C9C609C9C608C8A4F514F14
595319726B359F986ECBC5A3E8E4C9D6D6B2E2EAB1CFD9A5000800000700607846C9E6A3
C6E89ECDF2A5B0D68DC6E7A0C9E39CD2E9A1C9E49DC8E69EC6E59FC7E29DD0E5A2CFDB9B
D4D59BE2DBA4A59C65B8AE7994915A717239222A004F56206E6C45615B3B716A4DA59B82
B0A591E5D9CBFFF2E9EADDD7FFFBFAFFF4F6FFFBFFFFFCFFFAF5F9FFFEFFFAFAFCFFFCFB
F4E9E3FFFCF3FFFEF1C6BEB1938D7FDAD2C5FCF2E6FFFBEFFFF5ECFFFBF4F2E3E0887E7C
ACABA9ACB2B0596561627571798B8BC7DAD6C3CEC6D4DACEE1E2D2FFFEEDFFFFF1F4F1E8
8988864F4E53FBFBFFFEFEFFA2A1A76B696C1F16176D67674E4C4D6969695C5C5C767676
6E6E6E959595868686929292BEBEBE8A8A8A6F6F6F7979797D7D7D7979797E7E7E858587
87868B6A686BFFFFFDFFFFFAFFFFF6CFCBC0E7E3DAFFFCF64D48458E8986BDB9B8FFFFFA
FAFCF1FAFEEDFEFFEDEEFBDDDAF0CAC9E4B1C5E09BCEE89ED1EAA6CBE5A4C9E7A9CDF1AB
C8EE9BC2E893DCFBB5F1FFD2FEFFE8FFFFED7B7158E2DCB8CDDAA2C5DE9CCBE8A5CAE5A2
D0E09FA0A668534D13C8BF84DEDEA0D4E39EC5EB9EBEEF9EBEEF9DC2ED9DCDE79DD4E49D
D7DE9B6469278C9552DBE8A3CFE39ECAE19BCBE9A1CBEBA2
D7E2A6E0EEB0BBCE8CD0EAA3D2F0A6C8EA9DC5EA9AC5EC9BD1F8A7B9DB8EC3E199DCF5B1
B6C88AC6D1996C733FDFE9B7D0E4B1DCF5BECDE7AAC8E39ECCE89DCAE797D1EC9BCEE698
D3E7A0CEDE9D5F6A2E969E65D2D59EE2E2ACEFEEB8D4D59CCED69AD7E3A3CDD999DEEAAA
D5DFA0D7E0A163692B54581B575B1E2A2B00E1E2A6EDEDB1A09E63615F24534E14DFDAA0
D3CE94BCB6824D491C595530E3DEC0D7D8B0C7CD8FE2ECB0000500000600677844DAEFAC
CBE29CD8F2ABC9E4A1DAF3B1C0D791CDE79ED1EFA7CBEDA3CAEBA4D3F1ABD8EDAAD6E0A1
7A783F312600655521594A13665B235F5D22D2D699D8DDA5E5E2B9CFC9A77F765961573C
5548355C4F3F5D4F46695A55A09090FFFBFBFFFBFDFFFCFDFCF6F8FCFAFBFFFEFFFDF9F6
FFFBF6FFFBF4FEF0E76E6158998F85FFFDF3FFFCF3FFFBF4FFFAF6FFF6F3FFFBFBF6EDEE
FFFFFFF9FFFFE9F9F8E9FDFEDDF0F619282D586261D2D7D0FFFFF4FFFFF3FBF4EAFFFEF8
D7D3D4E8E5ECF8F6FFFFFDFF110F14D6D2D3FFF9F6FFFDFAFFFFFD999999C5C5C59C9C9C
CDCDCD0000000000000B0B0B5555551E1E1E000000090909080808000000000000000002
0000043B3A3F0000000101000C0C000503008682760C0800EBE6E0040000030000FDF9F8
FFFFFAFDFEF6FFFFF4F9FFF0E3F0DCD6E7C7D1E3B1D6EAADD6E9B1CCE1A9C5DEA5C8E5A5
D7F8A9C9EA9BE4FEBDF5FFD9F8FBE6FFFEF3655546BBB196E2EEBCD1E9ABCEE8A9D2E8A8
D3E1A49B9C6260551FEBE0A8DEDEA2D4E3A0C5EB9EBEEF9EBEEF9DC3EC9DCFE79DD6E39D
DEE5A24F5412959E5BD7E49FC5D994D6EDA7C3E199CDEDA4
D6E4A9DBEBADC6DB9A90A965BBD98FC5EA9CBBE291C9F39FD0FAA6C8ED9DBADA8FCCE69F
DDF0B0D5E3A697A067ADB782BBCF9ACFEBB1CAE7A7C9E79FCEEA9DCAE795D0EB9ACEE597
E1F2ACA4B372434C13A7AC76FFFFCEE0DDAADDD7A5E1E0AAD2E0A2DBF2AED0E5A2D6EBA8
CFE2A0DAEAA9CEDD9C8D995996A06180894A2E34003A3E0178793D8D8E52EBECB0D9DA9E
E0E6AACFD49CDBDEAF9EA0785A5C377E8154E1E8A4D8DEA00E0E00121200929663DEE4A4
CDD292D4DA9CE0E5ABD2D79DDEE7A6D9E6A1D2E6A1CEE59FD4EEA7CBE29C96A665636C2D
48460BBAAF77A1945D998F54A09C5FEBF1B1CCDB98E4F2B5D8D9AFE5DFBDF4EBCEFFFEE6
D9CAB7BCAC9DAA998F7E6D6672605EE0D0D0FFF4F2FFF9F8FFFEFAFDFCF7FFFEF9FFFDF7
FFF4F0FFF9F46C59535F5049FFFCF3FFF7EEFAEDE5FFFBF4FFF4F0FFFBF8FFFBFBFEF8FA
FEFFFFE9F3F5F2FFFFF0FFFFF1FFFF000A15667072F2F7F3FFFDF4FFFFF3FFF6EDF6EFE9
706A6AFDFBFFE6E5ED77767E545255FBF6F3FFFDF4FFFAF0F9F8F4FFFFFFFEFEFEF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F4F4F4F4FFFFFFFFFFFFFFFFFFFFFFFFFDFDFF
FDFEFFFCFDFF8D8F8C696A6298998B6E6C5D5A5748625E522622190F0A060C0608716D6E
AAA8A9FFFFFDF5F4F0FEFFFBFCFFFFF9FFF6F8FFE0F5FFD5E9F4C9D8E5B9CFE1B1D0E5AC
C5E197C0DA91D0E5ACDAE6C2FAF8ECFFFBFB947F7CB1A493FEFFDAEAFFC4D3EBAFD5E9AC
D7E0A79B9A62635621DBCE97DFDDA2D4E3A0C5EB9EBEEF9EBFEE9DC5EC9DD0E69BD7E29D
D9DE9CA2A765D3DA97E0EDA8CEE29DD7EEA8BFDD97CAE9A3
CFDFA1D0E2A4CFE4A3435C1894AF68C8E89DBEE191CFF2A2B9DE8ECFF2A2D1F0A4D1EDA3
C4DB95D0E5A2D4E4A591A365AABF84C7DFA3C9E4A1CBE79DCEEB9BCBE695D2EB9ACEE597
CAD9949EA8695E632BA6A674FFFFD4F3ECC0E3DAAFDFDFADD2E4A6CBE6A3C7E29DC9E39C
CCE69DD7EEA6CFE59DD9EDA8CBDF9AD2E2A196A564B9C585DFEBABDDE7A8CCD697DEEAAA
D9E8A7D5E3A6D8E2ADD6DFB0FCFFD9A3AB7A4F591482884A0402000402007B7A4C95965C
8383477D7C4394935B5F5E26373500949456DCE2A4D6E0A1D1E09FD7E6A59BA7674D5617
E6E7ABD0CE93E5E3A6E3E5A4DBE4A1C3D48DCFE99FC7DE9AD3DDABE6E6C0E5E2BFFFFFE3
FFF9E2FFFDECFFFCEFFFFAF2D4C1BD5B4947FFF5F5FFFAFAFFFAF8FFFCFA867D789C918D
B5A39F65524E897775FFF2EFFFFAF7FFFCF8FFFBF8FFFBF8FFFAF9FFFBFAFFF6F4FFFDFD
FEFFFFF3FCFBF5FFFF66787C2E3F498997A2CAD3D8FBFFFFFAFBF5FFFFF8FFFFF86D6864
B4B0B1FFFDFF4A454C030004FFFEFFFFFDF9FFF8EEFFFFF4FFFFFAFFFFFBFFFFFBF6F7F2
FFFFFBFAFAF8FFFEFCFCFCFAFDFCFAFFFFFFFFFEFFFFFFFFFAF8F9FCFCFCFFFEFFFFFFFF
FCFFFFFAFEFFF8FAF7FFFFF8FFFFF4DBD7CBF1EDE1D2CEC2D9D5CCC0BDB8817D7C4B494A
353334E8E6E7FFFEFFFFFFFFF9FDFFFCFFFBFEFFECFDFFE2E9F4CCD7E4B8D0E0AFD1E6AB
D2ECA3D4EEA7D2E7AECCD6B1FFFFF1FFFBF8C4ACAAAB9B8EFCFFE3F1FFD4D2E6B3D6E4B1
DADEAC9E9B685E541FB7B079DBDFA2D1E5A0C5EB9EBFEE9DC1EE9DC6EB9BCFE79BD4E49B
7A8540DFEAA6DCE9A4C5D692D4E8A3CDE4A0D1ECA9DCF9B6
D8EDACC7DC99CDE29F9BB06B849B55C4DB93D7EEA6CFE79DD3EDA3C6E297D0ECA1C8E79B
C7E59BD2F2A7BEDE93B0CB84566B26C7DB96DFF5ADC9E497C3DE8FC9E493D8F0A2C9DE93
E1EEA8B0B6785E5D27AAA676E8E1B7FFFCD7ECE6C4F0F2CAEBFFC7C7E4A2CDEBA5CAE99D
BFDE8EC9E996CFEC9CCFEB9ECDE99FCCE7A0CDE6A4CDE6A4C9E2A0C6DF9BCCE5A1D6EDA7
CCE29ACBDE9CD4E3AAD2E0ADFCFFDAF2FCCA7984424D561F0102000202000F13005E6531
757E45B4BE81D5DFA294985D61582161541FC8BD87DBD49DDBD8A1BCBD844C4F16586024
D5DFA0D3E29FD2E39DCFE59CCDE99CCAED9BC4EB98C0E597CCE4A6D3E4B0EAF7C9FBFFDA
FFFFE3FFFFE6FFFEECFFFBF1FFF5EF604848FFF7FAFFF4F9FFF6FBC4A9AE290E13594346
5949495C514FDCD0D2FFFBFFFFFCFFFFF8FFFCF2FAFFFCFFFFFCFDFFFCF9F8F3EDFEFBF4
F6F5F0FFFFFACDCFCC030909333C41F7FFFFE5F3F4F5FFFFF7FFFFF8FFFFEEF4F2696B6A
B6B1B5FFF9FD10070C362D30FFFBF8F2EFEAFFFFF6FEFEF4FFFFF6FFFFF5FFFEF5FFFFF6
FFFFF6FEFEF6FFFFFAFFFFFAFFFDFAFFFFFDFFFEFDF2F1EFFDF9FAFFFEFFFFFDFFF7F7F9
F6FBFEFBFFFFF4F6F3FFFEFBFFFDFAE3DAD5EAE1DCE6DFD9E1DED7FFFFFAECEEE9C9CBC8
7375728080807C7A7BFAFAFAF1F8F1F9FFF6FBFFECFBFFE3E8F8C9CCDFA7CEE4A3CEEAA0
CEED9FCAE89EC5DE9DD4E4B3FFFFE1FFFFEC99857CB6A89DFBFFEDF1FFE6CDD8B8D3D9B7
EAE8C29F9C6F615F2C979D61CFE09CD0EFA3BDE795C4F19EC2EC9ACCEF9DCFEA9BCCE297
839B51C3DD94CAE19BCAE39FDCF2B1C7DD9DCDE2A7F7FFD1
C9E09CD0E7A3D4E9A4D4E9A4BCD08B92A661CFE09ACFE39CCCE29ACEE59DCFE99FD0EFA3
C3E598C7EC9EC2E99ACEF0A3ADC37AA2B36CC7DD94CFE79BD8F5A5CCE997CDE597DDF2A7
D2DF99E0E6A66F7037797746EAE7BEECE8C3FFFFE1FFFFDFF1FFCECCEBA8D0F0A7CFEFA3
C7E995CEF09ACAEC98C8E99ACDEDA4CAE9A5CAE8A8D0EEAED2F1AECCEBA7C6E59FC4E298
D5F1A6D4EEA5DAF0B0C2D59DD1E1B0DEEDB6BFCE89D6E3AB0F130400020058623FC6D39E
D1DFA4D6E6A5D9EAA6DBE6A4E3DDA3BBAE79655A24463F0848430C595A21A2A86CD6E0A3
D4E4A3D0E7A1CDE99EC8E99AC5EB98C5ED97C2ED94C3EA97C8E9A4CBE7AAC7DEA6D6E8B8
E2EDC5FEFFE2FFFEE8FFFAEAFFFBF3584340351D1D583E41614449816268FFE0E6FFEEF2
FFFBFAF5EDEAFFFCFDFFFCFFFDF6FEFFFBFFFFFBFFF8F1F8F6F0F2FFFEFAFFFFF6FFFEF5
C2BFB68F8C85DFDCD79393917F8789F5FFFFF4FFFFF1FFFFE1F5F4F2FFFFF5FFFF222A2C
A4A4A6767072908788FFFDFBFFFEFAFFFFF8FDFFF7F8FBF0FFFFF4FFFFF3FFFFF4FFFFF4
FFFFF6FEFBF2FFFCF5FFFFFAFFFEFBF8F4F1FFFDFCFFFEFDFFFEFFF9F5F6F8F3F7FFFFFF
F8FEFEF9FFFDFEFEFCFFFEFBFFFAF9F3E8E6EFE4E2FFFAF4F9F6F1FFFFFAFBFFF9FBFFFA
FDFFFCC5C5C3585455FFFFFDFBFFFAF9FFF4DFEBD3DDEBC8DFEFC2D3E6AECCE5A3C8E39C
C6E69BCBEAA4C8E0A2D4E4B3FDFEDCFFFFE8A18D82D4C6BDF2FAEBF7FFF3F1F9E4E9E9D1
E7E2C4D1CDA7818352A0AA6ED5ECA6C3E397C4EB9ABCE692C7EC9CC3E493C2DD90D6F1A4
84A258CAEAA1D1EFA7C5E09BCEE7A5CFE5A7D8ECB1E6F9C1
D4EBA7D2E9A5CADF9CCEE3A0CFE39E839752C6DA95D2E6A1D7EDA5DBF2AAC2DC92CFEEA2
CAEA9ECBF0A2C3EA9BCEF0A3CBE29A9AAE67A2BA70C9E598CAE999C8E797CAE797C7DF93
CADE96D2DE9C9CA469636734BBBE8FE9EBC3EFF1CCE8F1C6E6FEC4C7E4A1CBE9A1CDECA0
CAE99BCEED9FC5E498C5E39BC4E19FC1DDA0C2DEA4C5E1A7C6E2A5C5E2A0C7E4A1CBE99F
C5E695BDDC8ECFEDA7C8E2A3CDE2AAD7EBAEC9DE93DBEDAF0005000004008C9870D5E7AD
D3E6A4D4EAA2C4DA91D5E69FD5DC99DEE3A1939858A0A666A4AD6E919B5CCDDC9BCCDD99
D3E8A3D1E8A0CDE99ECAE99BC7E995C6EA93C8EC95CAED9BC8E9A2D5F3B3C7E3A8D4EBB5
DFEFC2FEFFE1FFFFE6FFFFEAFFFAEBB0A39A877871AD9B97B19D9CCDB9B8FFF9F8FFEFED
FFFCF6F5EEE8FFFCFAFFF9FCFFFBFFFFF9FFFFFCFFFFFCFFFFFDFFF3EEEBFFFEF8D0CBC5
B7B2ACC0BBB7FFFFFAF2F4F1949FA1D9EDEEE0F5F6EEFFFFE6FFFCEEFFFFC5D9D7526060
2B3131222222E1DDDCFCF8F5F8F7F2EBECE4FCFFF8FCFFF6FFFCF5FFFBF5FFFEF8FFFEF8
FFFEFAFFFDF9FFFCF8FFFEFBFFFEFBFFFAFAFDF9FAF6F2F3F0ECEDFFFEFFFFFDFFFBF9FC
FCFFFFF4F9F5FFFFFDFFF8F6FBEFEFFBEDECEADCD9FFFDF6FFFEF8F8F8F0FBFCF6FFFFFA
FFFFFBECEBE98983839E9A99F1F6F0F4FEF3F1FAE7DDE7CCD8E4C0CCDCAFCBDFAAD6EEB4
C2DEA1D1EDB2D0E4B1D9E5BDFEFEE2FFFCECAE9791F8E9E4F2F8EEF8FFF6FEFFF3F9F8E3
DDD8BBEDE9C49D9C6E9BA46DC8DB9BD0EBA4E2FFB7C0E595C8EA9DD1F0A2CFE79DD1E99F
8AA85EC3E39AD3F1A9CFEAA5CFE8A6CFE5A5D4E8ABCBDDA3
D0E7A3CAE19DD2E7A4C2D794DFF3AEC3D792B8CC87A1B570C6DC94DAF1A9C0DA90CFEEA2
C9E99DCFF1A4C2E799C4E69AC8E29BC9E09A95AF66D8F7ABCCEB9DC8E998DBFAAAC2DE91
D7EFA5CADE99CDDD9EA6B179757F4BBAC394DEE7BCD0DDAFD5EDB1BEDC96C7E29BC8E69C
CBE79DCBE9A1C8E3A0D2EEB1D2EBB2D0EBB6D0E8B6CAE5B2C8E1A8CCE8ABE5FFBDF2FFC6
E5FFB4C0E691C8EA9ECBEAA6CBE7AAD5EEACCAE392C6DD99000E000A1703A5B689CEE2A3
CEE49CDBF3A7D5ED9FD4EC9ED9EEA3DEF0A6C7DB93C7DB94D0E49DCDE29DD8EDA8DBF2AC
CFE69ECCE69CCDE79DCDEA9ACCE997C9E692CBE894CDEF9BB8DA90C4E7A3C3E1A3C3DFA5
CCE0ADD8E7BCE4EEC9FEFFE5FFFFEAFDFAE7FFFFEFFFFCEFFFFAF0FFFDF3FDF3E9FFFEF3
FFFFF3FFFEF4FFFEF8FFFCF9FFFCFDFCF3F6FFFDFFFCF6FAFEF8FA8A8484DBD6D3FFFEFA
F7F2EFF9F4F1FFFEFBEBEBEBF8FFFF86959A798B8F6E8384A6BCBAA1B5B4657574BCC6C5
FEFFFFFFFEFDFFF8F6F9F1EEFFFEF8FFFFF6EFF1E6C0C0B6BEB9B5A99F9E897F7E6E6664
605758615B5B716B6B827C7CAAA4A4A8A2A4D8D4D5FFFEFFFFFEFFFFFBFCFFFDFFFFFDFE
FEFFFDFDFFFAFFFEFBFFFCFAFFF3F3FDEEEBEADBD6FFF9F3FFFAF2FBF8EFFFFFF7FFFFFA
F2EFEAFFFEFBF0E7E8464040FEFFFDF7FEF6FBFFF5D8DFCDE3ECD1EFFAD8E6F5CEE3F6C9
D9EFC1E8FDD2E2F2CDE6EFD0FFFFEDFFF6EBA8908CFCEAE8FEFFFAF8FFF9FEFFF4FFFFEF
EBE5CDF1ECCCC1BF96929966DAE9AEC8DE9DAAC880D4F4A9C6E49ACAE49BD1E79F80964E
ADC881BCDC93C7E59DD6F1AAD2E9A5C9DE9DD3E5A7CBDD9F
CADF9CDAEFACDAEFACC6DB98D7EAA8E3F6B4C0D48F99AD6892A860C0D78FCEE89FD3F1A7
C0E094C7E99CC9EB9ECEEEA3D0EBA6D4EDA997B26BB4D288C9E89CBBDC8DD2F3A4D1F0A2
CAE69BDBF5AECCE2A1D7EBAE5B6C35566431D2E0AFCDDEAAD3E9A9C5E099CEE8A1CDE8A1
CEE7A5CDE7A8D0E7AFEBFFD1D3E8BDCFE6BCCDE2BBCBE2B6CAE0AFCDE6ACDCF5B4E8FFBC
DFFFAFC0EB92CAF1A0CDF1A7C0E09DC6E49ECFEC98D1EBA2182909000E00708453C4DA99
D2EAA0BDD887C9E591CEEB97C5E592C3E493CEEFA0C5E697CDECA0D3F1A7BFDD93CBE79D
CAE69CC9E399CBE59BD2EA9ED1E99BCDE695CEE794CFEC9AD1F3A7C9EFA6CDF0ACC8E6A8
CEEAB0C9E0ACE3F4C7FBFFE1FAFFE2FEFFE6FFFFE8FFFFEAFCFEE8F4F6E0FFFFEDFBFAE6
FCF9E8FFFFF1FFFFF3FDF9EEFFFEF8FBF6F2FFFBF8C7C1C1ACA6A8FFFDFFF9F3F3F6F0F0
FFFCFDFFF6F7FFF8F9FFFDFFFFFDFFFBFFFFA2A9B3868F96F8FFFFF1FBFCFBFFFF6D6D6D
FFFDFBF5E7E6FFF9F7FFFAF6FFFAF365574ECEC1B8FFFCF6FEF2F4FFF4FBFFFAFFFFFBFF
FFFBFFFFFCFFFFFCFFFFFCFFFFFAFCFFFDFFFAF5F9B4AFB3787475A09C9DE9E7E8FEFCFD
F3F3F1FCFBF7FFFDFBFFFCFAFFFAF8FFF0ECFBE8E4FFF4EDFFFDF4FFFEF6FEFAF1FFFFF8
FFFEFAFFFDFAFFFBFBACA2A32C2C2A767875FCFFF8FEFFF6FCFFF1FAFFEDF6FFE8F8FFEC
F7FFECF7FFECF7FFEBF6FBE7FFFFF3FFF2EB9E8485E2CECFFFFFFDFBFFFDFAFBF5FFFFF4
FFFFEDFEF8DEFAF7D486895ED4DEAAD6E8AEE5FBBBBDD694CFE8A4D1E6A31C2C00E0F3B1
D0EBA4C9E9A0C4E29ACDE8A1CAE19BCCE19EE1F1B0D5E5A6
A7BC79CEE3A0CCE19ED2E7A4C6D997C7DA98DAEEA9CADF9A91A661A3BA72CFE9A0CEEAA0
C4E397CFEFA3CCECA0C6E69BD0EBA6C2DB99B7D08C637E37A0BC72BCDB8FC5E498C8E79B
C3E197C9E79FC8E39ECBE4A299AF71697C449AAB75CCDDA6D4EAA9CCE69FD4EBA5CFE8A4
D1E7A9CBE2AAD1E4B6F5FFE3F7FFE8F0FFE5F0FFE3F4FFE3F7FFDDF0FFD1E4FABCD4F2A8
C1E991B5E287C3ED9BCEF4A9C5E5A2C6E59FCFED97C9E39A112502000A00586A38D0E7A3
E4FCB0C7E08FD5EE9BCEEB97C6E995CDF4A1C5EB98C6EB9BCCEEA1C5E59AC7E79ECCEAA2
D1ECA5CBE59ECBE29AD1E99FD4EAA1CFE59ACFE497D1E99BCAECA0B9DF94C2E6A0CCECA9
C8E4A7C6DFA6D2E6B3D2E4B4CEDDB2DCE8C0C3CDAAD0DAB7FCFFE4FCFFE4FCFFE6FEFFE8
FFFFEAFFFEE9FBF8E5FFFFEFFFFFF1D6D2C7D5D0CAC8C3BFFFFDFDFFFDFFFFFAFEFFFDFF
FFFBFEF4EBEEFFFCFFFFFDFFF5F8FFEAF3FC929FA7849398DDEFEFE0F0ED6E7A76394039
8F908ABAB6ADABA198CABDB4EBE1D5FFFAEEFFFFEFFDF6ECFFFBFDFFF9FFFFF9FFFFF8FF
FFF4FBFFF4FAFFF9FFFFFCFFFFFCFFF4EEF2FFFDFFFFFDFFE0DCDDAFABACC1BFC0EDECEA
EAE9E5FBF6F2FFF9F7FFFBF8FFFAF6FFEDE8FFEBE6FFF6F0FFF5EEF8EEE5FFFEF6FFFCF4
FFFEF8FFFCFAFFEFEFFFFBFB767271797977F8F9F4FFFFFBFFFFFAFFFFF8FEFFF6F9FFF4
F9FFF4F8FFF4FBFFF4FFFFF6FFFDF6FFFAF6A58B8CD0BCBEF9F5F6FCFFFFFCFBF9FFFBF5
FFFEF1FFFBE8FFFFE4696945E0E6BAEBF7C5BDCC95D6E8ACD0E2A6DCECAE637134D3E6A6
C7E29DD3F1A9CEE9A2CBE59ECEE39ED9EDA8D9E8A5AEBD7A
75884890A363CFE2A2E3F6B6D7ECA9C6DB98D3E8A5D2E7A2BFD48F91A862CCE69DC5E197
CFEBA1D5F3A9CBE99FBFDD95CFE8A6CFE5A4DEF5B1758C468CA35BD6EEA4D2ECA2C7E398
D5F1A7C1DF95D5F3ABCAE5A0D8EEAED0E2A6718047D7E6ABD3E8A3CDE49CD1E6A1CDE3A2
D2E5ADCBDFAECDDDB8F7FFEAF8FFEFF7FFF1F7FFEEF7FFEAF6FFDDE5F9C4D3E7AAC4E096
D3F9A4C8F39AC2E99AC2E69EC4E3A0CEECA6DBF7A3D3EAA40008000009005F6F40D0E3A3
D3E79FCEE597D4EB9BC6DF8EC6E796CCF1A1C5E79ACAECA0CCEEA4C2E299CCEAA4DAF5B0
E0FBB8D2EBA9CBE29ED0E5A0D4E8A3D0E49DCFE39CD1E99FCDEBA1CBEDA1CBEBA2E1FFB9
B1CE8CD7F1B2D6EEB4C8DDA5C4D8A3D6E8B6DFEFC2DCECBFE2F1C6E6F5CA829168A2AC87
B5B89999997D96967CB3B399D4D4BCC2C1ADEBE7DBFFFFF6FFFEFBF4EEF0FFFCFFFDF6FD
FFF6FBFFFCFFFFF6F9A2A3A5809598C8E7E97B9F9D6A938D86B1A7B1DBCD517A687FA28E
D4EFDCE2F8E3ECFBE6DAE8D1F8FFEDDBEBD1E2F5D9F9FFF1F9F0F1FEEEF8FFF5FFFFFAFF
FFFAFFFFFBFFFFFBFFFFFCFFFFFCFFFFFDFFFFFDFFFFFDFFFFFBFCFAF6F7FBF9FAFFFEFC
D0CCC9D2CAC7E0D5D1C8B6B2B7A29FB39B97A38B87C0ACA5BBAAA2B2A59CE4DBD2FCF3EC
FFF5EFFFFBF8FFF3F3FFF7F6ADA8A572716DF7F3F0FFFEFBFFFDFDFBF7F6F8F7F5FEFFFD
F7FDF9F3FAF3FEFFFBFFFFFAFFFCF8FFFAF6B09695C5AFB1FCF6FAFFFEFFFDF9FAFFFCF9
FFFCF3FFF8E8FFFFEA736F52888864EFF4CBD7DFB0D9E3B1C7D19DE0EAB58C9661D4E3A8
BED795D0EEA8CDE8A1CEE8A1D8EEA6D4E8A1BAC98485924D
8A9D5D697C3CD7EAAAC3D696CEE3A0D9EEABC6DB98D3E8A5D4EBA5879E58D7F1AACAE49B
CEE89FCBE79DCEEAA0D6F1AACAE09FD5EAA9D8EBA9CEDE9D97A663CFE09ACDE19AD1E79E
C8E299D4F0A6C1DC95D4EDA9C3D897DDEDAF6C763ADCE8AAD5E6A0CCE29ACEE39ECEE2A3
D7EAB3D1E2B6CEDDBCF8FFEDF8FFF4F8FFF4F8FFF3F1FFE5DDEDC6CEE0ACD0E4A5D7F1A8
BEE18FCBF19ECCEEA2C9E8A4C6E0A3C7E09FD1E89ACBDE9C000600050E00747F54E0EEB1
CDDE9ACFE099D0E298DCF1A6D1EBA1C5E197D2EDA6C8E39ECBE6A3D3EDACCFE8A7F5FFCF
F0FFC8DBF1B3CDE1A4CFE3A4D2E6A7CFE4A3CEE3A2D1E8A4C9E59BD5F1A7BCD88ECBE69F
6D8642C3DC9AD0E9A8CFE5A7D7ECB1C9DCA4CEE1AACEE0AC6476428FA16F7D8D5C95A276
A2A8829EA281989C79919572CDD1B0F8F8DCFFFFEDF8F6E9FFFBF7FFFDFFFFFBFFFFFCFF
F7EEF3C3BABDFFFAFB9CA09FACC6C3DEFFFFD4FFF86C9F90558A785E947C7AAF9381AF92
C4EBCEC1E2C3C3DEBFD2EBCBBFD8B8C8E3C0E1FFDBF5FFEDFFFEFAFFFAFFFFFAFFFFFBFF
FFFAFFFFF7FBFFF8FCFFFCFFFFF9FCFFF9FCFBF5F7FFFAFCFFFEFFFFFEFFFDFBFCFFFFFD
FFFEFBF9F2ECFFFBF8CDBBB7A78F8BA58C88836A65B59E988B7A7284776E736960A1988F
D1C4BEFFF3EEFFFAFAFFFAFAF8F3ED6C6962CEC9C5F7EFEDFFFCFDFFFCFFFFFAFEFFFEFF
FEFFFFF6FAF9FFFFFDFFFEFBFFF4F0FFFAF6AC938EB09B9AFFFCFFFEFBFFFBF6FAFFFDFD
FFFBF5FFFDF2FFFFEDA7A18B5B573AEBE8C7F9F9D3F9FBD3E7EDC1E3E9BB92986AD5E2AD
D8EEAED4EFAAC1DB94CCE39DD9EDA8C4D58FA8B57086934D
D1E4A4B8CB8B869959CADD9DD8EDACCEE3A2D0E7A3CCE39FCDE4A0B7CE88203700C4DB95
D9F0AAD3EDA6C1DB92CBE29CD9EEABC4D797D2DE9EDCE6A7D4DD9C7B8441AAB772D3E49E
D3E9A1CBE59CCCE69FCFE6A0CBDB9AABB57894985DDBE1A3D1E09BD6EAA3C2D593E6F8BC
D7E8B4C7D6ABD1DFBEF9FFEDF9FFF4F6FFF3ECF7E6E3F0D6DCEBC2D6E7B3D3E6A6CFE69E
D9F5A8B9D88CD0EBA8DBF3B7C3D5A1D5E7ADD5E69FCEDC9F0E13000002007F8561DFE8B3
D4DEA1D4DF9DD7E49FDAE7A2D6E5A49FAD6FD2E2A4D1E0A5DDECB3C2D39CDAEBB4F3FFCE
F7FFD3E9FCC5D8EBB4D2E7AED2E7AED2E7ACC9E1A5C4DD9C788F49A9BF77768C44899E59
9DB46E91A8646F8642D7ECABCADE9FD8EAAED7E9AD83955B8B9D63BCCD96C6D59EDAE8B5
DDE6BBCED5ACD4DBB1DDE4B8D2D9AFE4E8C3F5F8DBEAECD7FDFAF1FFFEFDFFFDFFE9E4EA
D8D2D6F0EAEAFFFEFAFEFFFBF0FFFFE6FFFFE4FFFFDFFFF8DBFFF5D0FFE5C1F2D2BCE8C5
C0E6C1C7E7C0C3DDB6D0E9C2C8E1BAC8E1B9DAF5CCE5F6D6FEFCF0FFF7F5FFF7F5FFFAF8
FFF7F7FFFCFBFFFCFBFFFAF8FFFCFDFEF8F8FFFDFDFFFDFDF6F2F1FFFEFDFFFFFDFFFFFD
FFFAF7FFFEF8FFF6F3FFF0ECFFF8F4F8DFDBE7CEC9FFF9F3FFFBF3FFF5ECFFF8EFFFFDF4
ECDFD9C5B6B1F7E5E5FFFBF8FFFAF0C4C2B6726B63B6ACAAF5EBEAFFFBFFFFFDFFF7F2F8
FEFEFFFFFFFFFFFFFBFFFEFAFFFCF6FFF9F2A0887ED9C4BFFAEFF5FFFDFFFFFDFFFDF7F9
FFFEFAFFFEF6F8F0E3E0D9C75A523DBAB399FFFADDFFFFDFFFFFDFE9E9C393956ED2DBAC
D8ECAFC3DC98DDF4B0CBE09BCBDF9AD2E39D53601BD7E29E
D3E6A6CBDE9E2A3D00DBEEAECCE1A0C2D796DDF4B0D5ECA8CBE29EC3DA96DDF4AE5F7630
CBE29CD0E5A0D6ECA4DEF3AEC9DE9BE2F2B1C7D192E4EAAAE0E2A3DBDD9EE5ECA9D8E5A0
CFE39CD9F0A8C9E39CCEE59FE1F0AF666F307C7A3FDDDD9FD2DF9A70843D768947B6C88C
C7D8A2E5F4C9000800BCC9AFF6FFF0F9FFF3EFFBE5D8E5C7CBDAAFCEDFA8D0E3A1CAE097
C1D98FDCF3ABD5E9ACCBDCA6D2E0AFE0EDB8D2DF9ADBE4AD090A000101006F7253D5DCA9
DBE3AAA0A96A535D1E434C0DD8DDA3464B13595E28545B275D6532D7E1AF091500455322
5E6E3D0D1F00102400C4DBA5C9E0A8698249000E000820005E7330738440C7D894D0E49F
C9DD98CEE39ECCE19C6B803BD1E4A2CCDF9D415414DFF2B2D5E5A7CFDFA1718045CBD8A2
C6D2A2E8F4C4C5D29DDCE9B3727C48C7D0A17177510B0F00080A00010000010002030004
040001030000040000010100282F282E3B32000700314A37000C005E7F60000E00000F00
000B0000110035411929340A000800616C4499A57D000800040200170F020D05000F0700
06000006000006000009050004000017120E050000040000030000030000010000858180
FFFEFBFFFDFAFFFCF8FFF4F0FBE6E3F4DCD8CCB4B0F9E5DEFFF3EBFFFCF3F0E7DEFFF7F0
FFFCF6F3E5E26F5D5DAD9E9BFFFFF3F1EDE1635C520C0300FFFBFBFFF7F9F7EEF1FFFDFF
FFFEFFFFFFFDF9F8F3FBF7EEFFF5ECFFEEE4A38D80DAC6BFFFFBFFFFFDFFFFFCFFFFFBFC
FFFEFBFFFEF8FFFEF4FFFEF1D1C5B56D604FF4E8D2FFFCE3FFFEE2FFFEDF9B9A7BE6EDC3
D2E4AACFE6A2CEE3A0C4D795DEEEADD3E29F55611FCAD593
61713368783A657739354709374C0B283D005E743362783771884469803C7186433B500D
2A3F005165208A9E598296517A914B92A661737E3CA2A7678D8B4E6463237A7F3D8A9551
8FA35E7F965095AF68AEC57F8F9E5B6D72325D571BA8A4679AA664859A55899E5B8B9F60
9CAF7791A37390A0794C5B3C67755B83917893A2858D9D788D9F6D98AC6F98AE668BA156
9EB26A758944909F664A5624273003656D3C6D76355256230301000906012F2F13282B00
1D2400242C00353F027880457575417D7D4B63623275774862653872784A3F481B6E7A4C
626F41687A48617542566D37526B325E7A4059773B506A2D7083435463227C8B4A61722E
5F732E62763181954E384C052B3F007185405464236A7A39667436606E306D7B3E647237
82905B5A6B3568773C6474365F6F306F7E456F7B4B232A0820251164655F888888817F82
7D7C7A7E7E76838172908A7C9F8E8788756F7F73677E79668E90785E63437177536E7049
706E45827B512C1E0038290246371050421D3024005D553143402139381A79785C75735A
97957E8B8974B6B3A0999788A8A699A09E929491889D9A93918E89B7B3B0ACA8A7676362
2824212B2622392F2D3A2B2836231F2F1A1527120D3F2C26685952281E152E271F6F6860
231C167B706E7A6A6A736562575145898579554E44070000887D7B8C80808E8485746B6C
827E7D85848081817987857990887D988A7D564335827066857B7C7570747472758C8C8C
9B9C978B8A85827D77948B826E60573F2D21938173A59484736856958F799F9D86262C08
778851607534768B4A8093535C6C2D5B6A294A5616909A5B
D5E5A7D3E3A5D3E5A7BBCD8FBFD493D0E6A5D2E8A7CFE5A4CEE5A1CEE5A1C3D895DAEFAC
3D510CE0F1ADDAEBA7DCF0ABD7F1A8D1E8A0CFDE99E9F0ADDEDD9D5655159EA05FDDE8A4
D2E7A2C2DD96CBE69FD0EAA3D9E8A59FA162BBB277CCC68ADBE7A5C1D693D6EBA8D3E8A7
D3E7ACC5D7A3D3E4B7F4FFDDF8FFE6F8FFE6EFFFDBD6E7BBC9DCA4CEE3A0D1E89ACDE494
D1E399D9E8A5D6E4A9CED8A4D3DAAEE1E8B5CDD695D3D7A407050003000024270858602F
A2AB72DAE6A8CEDA9AD0DA9DCCCF9ADDDCACD1D3A2CED1A2EFF5C7C6CE9FDFE8BBCEDBAD
D0E0AFCCDEACDAF1BBCCE5ACD4F0B5BFDB9ECDEBADD0EDADCEE0A2D6E4A7CDDD9ED8EBA9
DDF0AECBE09BBCD28AD5EBA3CEE49CC3D991E2F6B1DEEFABD5E5A4D7E6A5CFDB9DDFEDB0
BBCF94D7ECB1CDE2A1CEE39EDBF1A9BCCF8D84935C7F8C61B1B9A1F7FDF1FEFFFDF7F9F8
FFFFFAFFFFF4FDFFEAFEF9E3FEE8DBFFF4E9FFFBEAE6DAC0C9C4A4F0F1C9D6D7ABDFDEAE
777343423A0964562761502493825654451A9A8D61A19A6E65663A4A502452582C3D421A
CBCFAAD5D9B8FFFFE6FFFFE9FFFFEDFFFFEFF9F7EAFFFFF6F7F4EDF6F3EEFFFDFAFFFCFB
FDFCF8FFFFFBFFF9F7FFF4F2FFFAF8E5D2CEF5E2DEFFFAF3FFF9F0FFFEF6FAF6EDFFFCF5
DFDAD6C3BBB8C1B5B5B5AAA8ABA79E7470654C453B6259523C2E2BBEB3B1AFA3A3B4ACAA
AEAAA7B3B2ADACACA4ACAA9EABA398A89C9073615583726AB6ACABB0ACADBFBFBDEAECE9
FEFFFBF8FBF4F3F0EBFFFDF8FFFBF4533F385B443CF3DFD6FFF4E7FFFEEFD9D6C5545939
8C9A65E9FCBCCBDE9EBDCD8ED5E3A68792565C672BCFD99D
D1E1A3E1F1B3D0E2A4D7E9AB97AB6CD1E7A7B1C786DBF4B2C3DC9ADEF4B3D7ECA9C8DD9A
536624CFDF9EC8D794D9EDA6C7E79BC3E397CFE39BCBD691DDE09D595A18A1A664D0DD98
D7EEA8D0F0A7C6E59FCCE7A2C4D493D4D89B5D521AF1EBB1C8D494F1FFC4C2D995C7DD9C
CDE3A3DBF0B5CADEA9F7FFDAEBFED1DCEFC2CEE1B3C7DBA6C7DD9DCAE298D1EA97D9F19D
CCDE92E0EFAAC3D193D6E1A9E5EDBC838C57A5B06C9AA36A2C2F1E0A0C016B734ECBD8A2
D8E8AAD0E49FC8DC95DBEBAADBE6ACCFD8A3EDF7C2E6F0BCE3F0BBEAF8C5E1F2BED4E6B2
D2E7AFCDE4ACBFD79DD4EEB1C7E4A2D2EFACC3E29ECBE8A5C9DFA1D6E8AEC8DC9FD8EEAE
BCD38FD4EEA7D2ECA3E1FBB2CCE69CD2ECA2CAE199B8CE86C7D894DCECAB7A884A8A9A5C
B3C88D617B3C708A43DFFAAD94AC5EA0B86CBCD091E3F5C5E2EFD1F9FFF2F5FAF4F2F7F1
FEFFF6F1F6E2DFE6C7F1F2D2F9EFD4FFFFE4FFFCDBD2D9B0D1DEB0C3D69FC8DDA28FA364
ADBD7ED0DC9CD7E1A4D4DCA0D4DCA1D8E0A7E4EDB6D3DEA4D5E0A4D0DEA0DBE9AEC8D59D
929C689FA879CFD6ADE0E6C4F7FADDFFFFEBF0EFDDFFFFF4FFFFF6FCF7F3FFFDFAFFFEFB
FBFDFAFEFFFBF7F3F0FAF0EEFFFAFAE3D4D1AFA09BFFF3EDFFFEF6FFFFF6FDFDF5F8F7F2
FFFFFAEFEAE7FFFCFDFDF5F3FFFFFAFFFFF8C7C0BA7C736E281A19EEE3E1FFFCFAFFFDFA
F5F4EFFFFFF8FDFFF4FFFFF6FFFEF4FFFCF4FCEBE3F8E7E0FFFCFAFFFEFBFCFDF8FCFFFB
FBFFFAF8FDF6F3F2EDFFF9F3FFF5F3AA9592674E4AFFF8F4FFFAF4FFFCF3FFFFF3B8BCA1
9DAA75BBCB8CD2E2A4F2FFC3D1DFA4A0AB73D4DFA7DEE8B3
D3E3A58D9D5F687A3C55692A8FA364D9EFAFCEE7A5CAE3A1C9E2A0D6EFADBFD491CFE2A0
5F6F2ECBDA99D7E3A1C9DF97C5EA9ACDF4A3D1EC9FDAEAA1DEE5A1888D4A9EA764CEDF99
C2DD96D0F4AAC8EEA5C2E19BEAFDBBCED2958C834AA39C65DFEDAFBBD190D7EEAAC7DE9A
D5ECA8C6DC9BDCF2B4EAFFC6E2F6C1D5E9B6D3E8B0DCF2B4DEF5AFD1E99BC6E089C6DE88
DDF09FD9EBA1D0DF9CBAC88B8C9661B6C187CDDA92CFDB9D111902000500637247D3E7AA
CDE4A0C9E399CDE79DCEE89FD6ECABC4D89BC9DEA3E0F5BAECFFC8F6FFD2F7FFD3C9E1A5
D2EAAEC8E2A3CDE7A6D4EFACCEECA4BDDB91C5E399D9F4ADCDE5A7D0E5ACD4ECB0D4EEAF
CAE5A2CBE9A3C7E59DB6D48ACEEDA1C7E69AD9F3AADDF4ACE2F7B28D9E5A96A667AFC183
C1DB9CCFECAAD4F3A7B4D17FCCEA94CCE796D4EEA7CCE0ABCEDDBCEBF7E3F7FFF6FBFFFA
FCFFF3EEF6DED9E0BED9E0B7ABA9839F9D77C0C79BC6D7A3A7C086A4C380769750A0C276
D0EFA3D0ECA1CBE29AC9E09ADFF4B1C4DA99CEE7A6D2EBA9C9DF96DCF1A4CEE29ACBDC98
D6E6A7C8D59DA1AD7B9FA87D8F9571FFFFE8FFFFEDF1EFE0FCF8EFFFFEF8FFFAF7FFFEFB
F7FCF8FBFFFCFEFDFBFFFDFBFFFBFBFFFBFA897B78FFFDF6FFFBF5F1F1E9FFFFFAFFFFFA
FDFEF9FFFFFDFFF9F9FFFBFBFAF9F7FFFEFBFFFBF9E8DEDD493D3D080000FEF3F1FDF5F2
FFFFF8FFFFF8FFFFF8FEFEF6FFFAF4FFFAF6FDEEEBDECFCCF5ECE7FFFEF7FDFFF7F3FAF2
F7FFF8FBFFFAFFFFFAFFFDFAFFF9F9D2BABA6F5254FFEEEFFFF3F2FFFCF6EEEAE1CACEB7
B1BD8BD7E7A8D3E1A4D7E5AAC5D0988B9560DDE7B3EFF9C7
CEDCA19CAB704E602493A76AC8DC9DC0D696DBF4B2CAE3A1D4EDABC7E09EE3F8B5D6E9A7
6A7A39E6F5B4E3EFAFC8DE96C1EB99C5F29DC5E695DAF0A5D4DF9AA0AA65909D58CEE49C
C3E59BB9E198CCF6ACC6EAA2BFD493E6EEB2A29B64555018909E61D5EEADD0E9A7C9E29E
CFE9A2CEE8A1D4EDABE9FFC1DAF2B6D0E8ACC6DEA0C5DE9CC7E197CAE692CEEB91D4EE93
CFE590C0D684E5F6AF657534DCEBB0D2E0A2D8EB9CDEEFAB111E02000700708453C8E19F
C0DE94CDEE9DD2F3A2C3E696CDEEA7B9D996E1FFBEC5E5A2DDFDBCD8F6B6D5F4B1CEEBA9
CEEBA8C7E59FD8F6AEACCA80D7F3A6CAE797DEFBA9BDD98EDDF7B8DAF3BACEEAAFBDDB9D
D5F4B1C3E49FC2E69CD0F5A8CAEC9FC1E396BFDD93D3EFA5C4DB957E934EDAEDADCDE1A2
CDEAAAD2F1ADCBEC9DC9E994D3F499D3F19BCAE49BCEE3AAD3E5BFE8F6DFF7FFF4F6FFF5
F4FDEAE4EFD1C0CBA3A0A77B5A582F939468B1BB87B3C78C9BB876A2C67CB9E091C7EE9D
B9DF8CD6F7A6B4D385D9F8ACC8E49ADAF8B0BEDF9AC6E69DDBF7A3C2DC85D5EC9AC6DD8F
DEF2AAD0E09FDCE9B1B6C08E656C439DA081E2E2CAFFFFEFF9F5EAFFFEF8FFF8F5F7F3F2
FCFFFFFBFFFFFFFFFDFFFEFBFFF5F4FFF8F68E8381FFFAF4FFFFFAF9FAF4FCFFFAFCFFFB
F0F2EFFFFFFDF9F5F6FFFDFFFFFEFFFEFCFFFFFDFFFFFBFF877B7D0C0000F7ECEAFFFDFA
FBFAF5FFFFFAF5F8F1FBFCF6FFFEFBFFFCFBFFFBFBE2D4D4E5DCD7FFFDF4FEFFF6FAFFF7
F7FFF7F9FFF8FBFEF7FDF8F4FFF8F8F2D9DC5E4145FFF6FAFFF8FAFEF0EDFFFFF8BEC1AC
8F9B69E3F1B3D3DEA2CCD79DE9F4BC9BA571D8E2B0FEFFD8
393C116F7547E3EBB8D2DDA5D4E2A5DFEDAFCBDB9AD7E7A6CEDE9FCBDB9CD6E4A7D4DFA3
E4EEB14A5216D6DC9ED6E5A2C9E99DCCEF9FCCE498C9D690E4E6A5DCDB9BC1C183E7EDAD
D0E09FD5ECA8D0E9A5C3D895E9F3B6D0CF96F2E5B09F935F494913D2DAA1D4DEA1D8E4A4
D6E5A2D2E19ED1E1A0CDDD9CD0DEA0D9E4A8DBE7A9D5E19FD5E09BDAE89DDAE899D5E292
D9E495C4CF8347510CDCE5A6D3D8A0E5EDB1D1DB94D1DB9E1B2201000700657745CBE4A3
CEECA4C6E69ABFE292CAEC9FC0E19AD1F5AFBFE29EBFE2A0D6F6B7CBEAAEC8E6AACBE9AD
C9E5AAC8E4A7CBE8A8CEEBA8CDE8A1C6E298C9E59AD2ECA5E2FAC0EFFFD0EAFECBD5E9B6
C7DBA6CDE2AAD1E6ABCEE4A4D2E7A2D9EFA7CFE39C97A862D6E2A0828E50E3ECB3D4DFA7
D4E1A9CADA9CCFE09AD6E89CCFE290D0E392D8E8A1D5E3A8D4DDB0E2E7C7FFFFEAFFFFEC
CDCCB09E9E7CAEAC83D5D1A4E3DAAFDBD2A7E2DEB1D9DBAAD3DCA7E0EEB3D0DEA0DAE9A6
D5E09BDBE59EE2E8A2DBE19BD4D695D7D89CEEF1B8D5D99ED8D995E2E29ADFDF99DEDD9C
E0DEA3E1DEA7DBD5A5DAD3A9DCD2AFE9DEC2B8A9929A8B78B6A496B6A498A18D84FFFBF2
FFFCF3FFFFF6FCF8EFFFFAF4FFFBF6E8D5D1D8C5C1FFF5F1FFFAF7FFFCF8F7EEE9FCF4F1
FFFDFAFFF9F6FFFCFBFFFCFDFFFBFCFFF9FAFFF8FAFFF1F1F1E1E2D4C4C43D2F2CFFFCF8
FFFDF7FFFEF8FFFBF5FFFEF8FFFCFAFFFBFAFFFAFAC9B5B4E6D5CDFFF8E9FFFFF1FFFFF3
FFFEF2FFFEF6FFFCF8FFFAFAFFF8FA8D797B6A5053FFF2F6FFEFF0FFF9F8FFFAF4FFFFEC
DDDEB2DFE4ACD7DCA4D9DEA8D4D6A4A2A473FAFCCDDBDCB0
49392A736751E2D7B7E3DCB0CFCC95EFEEAED6D795DDDD9DE2E3A7E4E3ADD1CF9EE6E2B2
E1DEAB918E59F1ECB4D7D79BE1E7A7D8DE9ED1CD90E0D39CE7D09CDCBE8C9F814FCAAE7C
EBD5A3C5B480A69964A99C67BDAC78CFB987E0C695EDD1A26C4F23B09568DAC694DACD98
948B54B6B177F6F4B9D6D497E0DAA0E0D59DEDDEA7D8C992EDDCA6F0E1A8EADBA2E6D79C
EDDEA3A19257ECDDA6DFCF9CF2E4B5E2D4A7D8CE9DEAE2B43E38140404006E7647D7E6AF
C9DDA0E0F9B7C3DE99CBE6A1C4DD9BD9F2B1C2DA9ECCE3ABC8DEADD7EDBFD3E8BFCEE2BD
647A54000B00000E00CEE5B7C3DEABD6F1BABCD89DDAF1B9E9F6C87A805A010500030300
E2DEC3070200DFD6B5DFD6ADDFD5A2ECE3AAFBF3B5655B1EEADFA9DAD09FE6DAB0E4D6AF
E7D8AFE6D5A9EBDEAAE9DEA6E6DCA1E0D89AE5DD9FE3DA9FEAE1AAD3C795EFE1B4FFEEC4
8F7950AB946BDBC299765A32CCAB88ECCBAAF2D0B4E7C5ACF2CFB9FFF7E1FFF5DAD4AC89
CCA177FFEFC1F5C392FECA9BBB81597E4220F6B89FFDBFA6F2BA99A87250FFEECFD19C7D
DAA88D996952D9AB94F6C7B5C79989DBAD9DAE8070774939D4A794CB9E8BFACDB8DFBBA5
B4A3896B5F45120200FFFAE5FFF8EAC3A19799726BFFF3F1FFEEEEFFF4F3FFF0EEFFF2EF
FFF7F3FFF3EFFFF8F3FFF9F3FFF8F1FFFAF3FFFAF3FFF9F4DBC8C2FFFAF40F0000FFF7F0
FFF3ECFFFBF4FFFBF3F5E2DBFFFAF3FFF6F1FFF7F3EBCDC5C9A99AFFEDDBFFF8E5FFFAEC
FFF6F1FFF3F4FFF0F4FFEFF5FFF9FBFEF0EF5F4D4BFFEFEEFFF3F4FFECECFFF6F1FFEFDE
B6A682EADFB1EBE0B2E0D5A7EADDB0AC9F72FFFFD3DED1A4
1B070037261676674A65582E9A8F59867E3F9991505E5617736A338C82513023006A5B32
5B4D2097895870632C7A713668672E7A7B41756E375E4E1A725B297C5D2E6F4F205E3E0F
7458286D562466521F624E1B64501D6854216B55236E5223441F007E572E795A2C7F6937
72622E90874EAEA86C9E955A70642A5C4B139B84509278457359285F48168C7444957F4E
846F3A533F0A9C88557F6B398F7A4D6B582E796A4192855B261F000E0B00060C00031000
000C00B8D092DAF4B3C8E3A0D9EFAEC9DE9D566A2F071900000A00000900000800000700
000600000900020B0046502DABB68EE5F0C5D5DEAFC9D2A3A3A87F444523130F00110A00
0B0000645244786350624D30634D246C5624735E255B480E94834F816E434E3C18735F3E
6F5731644B226B53275943128C7845604F1961501865561B5E4E138070355441096A531F
6349187051238160355D3E126D512261441A6D4C2B6B472D6E48356D423265342384503A
5C25077A3F1D6B2C098E4C2C863E286B1F129445417D2F2F9C534D8C483F85423AA4635D
81453DC38A8370393269372E805046A97B6E774939754833784B347A4E33885C3F956E4D
A486627E623D5A391A8D684D9D6E5A915D4F945951AE716C955555B57778E0A4A4FFD9D6
FFE4DFFFD3CDFFD7CEFFD7CFFFE4DEECC1BBCA9E9BDCB0AFC19896C59D9D582E2FA77F7F
FFD6D8FED4D5DAAEAFFFEFEFF8C8C8D3A1A09E6B6AC18A87C38681AD726ABB8B81C8968F
D89899E59EA4B56C75DE9FA7F9D1D1B697947B5854B48784DC9B9FFFC3C6B47776B8867B
8F6E4FA79066715A309881578770467E673B8D754981693B
5C4F3C342A0F8E865F544C1B7D773B5E56155D55148B8143AB9E695D4C1E6F5C32604A21
60491DF3DDAB675118645A1DE3EFAFCDE2A1A4B274D6DCA0DCDAA1D7D099CDC68FACA76F
D1CF96DDDEA4E0E4A9D9DDA2D7D89ED9D89FD0CE95C7BB876E5628DCBF93E2CE9CE4D9A3
CFCA929D9D61686A2B5454165854174940058C7F486859226F5F2B62521F877948685C28
5D541B675E23655C23857C45504613665E2D514B1B7D7B4B65643649501D88925EC8D9A2
D1E6ABD4EEAFCFECAACDECA8C3DE97DAF3AFD0E8AA93A86F748453AAB58BF1F7D5D5D6B7
A7A1874F452A5F513470603F4E3C184E3B137F6A3F5C4D2297986CE0E6C0C4C4A897927E
0800005A4C3F665744D8C7ADC3B1895D4D1C71622950440AE4D9A3897F4E655C33463D14
635727AEA26E746933574C167C733AD5CC93938A515B521763591E948951E3D69F584B16
60501D554311F8E4B262551EC3C37D6C7026979757C4C18CCCC599E1D5AFEBDBB9FFFDDA
FFE8C4F5D8B6FFE2C3FFF7DFFFF3EAFFF1F3FFEFFBFFEBF9FFE9F2FFF2F8FFF3F8FFE2E4
FFF2F3FFF7F4FFF8F1FFFAEFF1DED0FFFCEAFFF9E2FFFEE1D3C6A69E916E625630614E26
6F49226B3B156F3A1A7E452882402A7E3627C5796C80312AFFB5B17728246A1C187F3630
59140DBC7C72FFC8BD783731702126B6636DD78390C674808E3C4A7726358936467E2D3C
762335C47181A854647A2333852D3BC66C78D77D89C86A78983144710E20C16B76FFC1C9
C4656DC15C64D26B6F79191B81322EA158528D3E3A8C32348B212B8C1E2B7B1723843531
77482C7E5D3459380F79582F7352296342175D3C11725124
DAE5BDB9C499B2BF8ACED99DF4FFBBD4DE99CDD490EAECADE3E2AAA6A370999162D4C99B
FFFECCD0C38CDBCD90D8D796CEE5A1CDEEA9B1CC89DBF0AFDCEAACCDD99BD6E2A4919F61
D6E9A9D8EDACD4EAA9D1E6A5D5E8A8DFEDAFDAE4A7D2D3996B5E2AEDDDAAF1E8B1E5E5A9
DAE0A2C9D394C7D290E0E9A8E3E8A8F7F7B9DAD59BE1DCA4D6CF99EEE8B4A4A16C9B9A62
D9DE9EE3E8A6D8DD9DE3E7AADCE0A5DADDA4D7DCA4E3EAB4CFD8A3D6E3ADEBFDC3CFE4A9
D1EBACBDDA98D2F1ADBCDB95C9E79DBFDB91D6EFADC8DEA0CEDFA9FAFFD8E3EAC12F2F0B
9A9575DED3B3E5D7B4FFFBD5FFFED3FFFECFF5DFAEFFFFCFF3F7C5C8D4A6D3D9B7D7DABF
0B05000F0700DFD3C3DED2B8F2E9C2E3DBAAD9D399EEEAADDBDB9FE3E3ADCAC999F0F2C0
CFD398DCE19FD5D798E1E2A6F0F0B4D8D79ECAC88FF6F1BAE6E1AADDD8A1A09A66C4BE8A
EBE5B1E9E3AFCDC793E0E2A3D3E792CAE78BDBF4A1D0E69ED0E2A6CCD9A4C7D0A1FFFFDA
F1F4C9DDDBB5F3EED0FFF8E4FFF5EEFFF4FAFFEDFEFFF7FFFFF6FFFFF9FFFFF8FBFFF9F8
FFFEF6F7F5E8F6F8E3FDFFE6FEFFE4FCFFDFEFFACFF7FFD4DBE8B3C7D69DCFDCA4D9DEA4
E5D49EF6DBA6FFDDADEAC398FFDCB8F7C5A4AD755ABD836BFFE4CFFFCFB9E8AF9BF7C3AD
FECEB7D8AC91D2AA90EFBEADE7A3A4FFB2BCFFC6D3FFD4E0E89CA9C87B8BA65969D28597
FFC9DBFFD3E3FFCEDEF5A4B3FFCBD9F19DAAFFC0CDFFD3E3E5839CFFD6EDFAB0BDFFC0C3
FFCDCAF8A89FF49E91FFB8A6FFBFA7FFC9B0691A09892F26D56D6EF38C90FFC9CEDA968D
8B6242B19669B99C70C1A679A18659856A3BAC9162C8AE7D
BBECAAAFE19C7BAA6287B56AA5D182CBF4A6C5E99FC8E7A3C9E3A6839B61DAEDB6D1E0A9
C0CE91E1EDABE5F1A9DDF2A7C2E299C6EBA5D3F4AFD1EEABC5E09D748D4B9AB5727D9A57
CBECA7C3E7A1BEE29CC2E39ECAE5A2D2E7A6D9E7A9DEE6AA535118D0CE95DBDFA4D2DE9E
CADD9BD2E7A2D3E8A3CFE39ECFDE9BD2DD9BCDD395E5EBAFE2E5ACCBD098A2A973D2DDA1
D0E19BD6EBA0CCDD96D0E19BDBECA8D0E09FD5E5A6D0E0A1D1E3A5D0E4A5B2C888D1EBAA
C7E4A2C7E6A2C5E6A1D9F9B0D8F2A8D0E89ED8EFA7C7DC9B9DB17475864FB2C08DD7E3B3
CBD4A5E4ECBBD1D8A5DDE4AEC1C68CF3F9BBE1E7A7D7E09FD3E3A5D7E8B2DDEABFC5CFAD
010300090700F2EFDCFFFFE6EBE9C2D4D4A2DEE2A7C9CF8FDCE7A5D8E4A4DEECB1D0E0A1
DAEEA6DCF1A4D1E29BCDD997D5DFA2E7ECB2DBDEA9CAC999DDDCAC9A996BD7D9A8D6DAA8
D0D7A3D8E1ACDDE8B0D3E7A2CFF399B4E07FBCE78EC8EFA0C7EBA5F0FFD1F1FFD4DAF5C0
DEF6C6CDE2B7DCEDCBF8FFEFF9FFF8FBFFFFFAFEFFFBFDFFFCFFFFFCFFFBE4ECDFF9FFF1
DAE8CED3E8C1CDE5B5CFECB2CAEAA7C4E69CCBEDA0CAF09DD0F49DC5EC93D5F9A1C1E58E
C0E28ED3F2A2C9E195DCF0A8D1E09DD7E0A1D1D49B6D6D37E8E8B2D3D6A1D3D7A4F4FBC7
EAF7C1C8DAA0D2E5ADE7F0C3F6E6D6FFF1EDFFF2EFFFECEBECD2D1FFF8F8C2A9ACBEA5A8
FFE8EBFFF7FAFFF4F6FFF6F6FFF5F6FFF5F3FFF0EFFFF3F6FFD2DFFFEBF6FFF6F1FFFFED
FFFFE1FFF3C9D5BF8EF8E1ABE2CF95E4CF96533101865834C78F76FFD2C0FFF5E2DAC6AB
96895DE0D9A3DDD39EEFE8B29C955F9C955EDDD69FE7E1A7
C0FFAEAFEE9DB7F5A284BF6D78AF5E90C37692C078C1EAA8CBEFB27B9C6390AD75D4EDB3
D7F0AFBBD58ECDE599C1DD90D2F2A9CBECA7C1E09CCEEBA8B6D18E7F9C597D9C58A9CD87
C5EAA4C3EBA4CAEFA9D1F2ADD2EBA9CFE2A2D2DEA0D9DFA3606429D6DCA0DCEBAACCE19E
BFDA93D0EEA6D6F4ACC7E29BD7ECA7CBDB9AE0EEB0D8E3A7AEB97F9CA971ADBC85D0E4A7
CBE59CD6F3A3C5E194DEF9ACC5DF95D2ECA3CDE49ED3EAA4CDE4A0DEF7B3CFE8A4D4EFAA
CCEAA4CFEDA7C3E29CC4DF98C5DD91CFE497CBE198AAC0788095547F9354BED297D3E7AC
D9EEB3D3E8ADCCE5A4D3ECAACAE49DC7E197C2DE91C9E598C6E097D3ECAAD0E2AEC8D7B0
000600101501FFFFEDF8FCE1E9F0C7DEE7B2E1EDADD9EAA4CFE39BC8E096CCE69FC6E19A
BEDD8DCFEE9EC7E197DFF4B1BBCA8FE1EBB7DBE1B3E3E5BDEAEAC4868863E5ECC3E5EEC3
D4E1B3D2E4B2BFD39ECDEAAABAE492D5FFABC4F1A0BEE89CCEF7B1D9FFBFECFFD3EDFFD6
D8F9C2D1F1BFD8F5C9F1FFE8F2FFF1EEFFF4F2FFFFF3FFFFF5FFFFF6FFFCF7FFF8E8FBE5
C7DFBDB3D0A0CCEEB2C6EBA5C0E99AC2EE97C1EE93BEEB8CB3E17FC1ED8CC7F392BEED8D
C4F79ABAED91D8FFAEAEDA83BFE592DCFCB0BEDA9047611ABDD692D0EBA6D5F2AFC9E8A4
B0D58FBDE79FD3FEB6B7D89FF1FBE2F9F6EDFFFFF6FFFFF8D2D3CBEBECE680817CB2B3AE
FFFFFDFFFFFBEBE8E3FFFFF8FEF7F1FFFEF6FFFAF3FFFBF8CFBCBEFFF7F4F0FFEDEDFFE8
E4FFD0E1FBBEE1EEA9DDE59CE2EA9DE4E69D58480C8B713EA17F59F1D7B6FFFFE1E2EAC1
A5AE77DCE5A6D5DE9FD1DB9CADB77898A263E5EFB0D5E19F
B3E995BDF19EB0E190BFEEA0B1DC9477A05E95B97C83A16B90AC7BCDE7B788A06E8DA46E
D3E8ADD7EDACDDF4ACD4ECA2BCD38DD9F0ACCCE19E8A9D5BB4C785EAFFBCC6DF9BD4F2AC
C3E29CC6E7A0CAE9A3CFE8A4D5E5A4CDD697B4B47897975B4E5416D0DF9EDDF0AED1EAA6
C7E79EC5E79DC0E298C3E39AC6DF9BE3F8B7C6D698D7E5AA8F9E67E3F4BED7E9B5F5FFD1
D5F5AABDE08ED4F7A5C5E695CCED9EBCDB8DD3EFA4CAE69BC0DC92C5DF96CEE8A1C6E099
D2ECA5CFE8A4CCE5A1CDE49CCFE4978093446B8033BBD188D0E69EC6DD99D0E9A5D4EFAC
B4D18ECAEBA4D1F5ABBAE093CCF3A4C1EB97C4F099C7F19BC7EA96C5E498CAE2A4D7EABC
000800000600F4FEE5D3DEBED4E1B5CBDDA3C4D994CFEA9BC5E592C6E894CBEE9ECFF4A4
D2F9A8C1E899CBEDA3C1DB9CF8FFD6FCFFDCFFFFE3F7FADDF2F2D8AEB098F3F9DDF6FFE1
F2FFDDEBFFD6C2DEAEF0FFDAF0FFD4C4E3A7BEDDA2C6E5AAC4E3A8D1F0B5D4F1B7C3E1A5
C6E4A8BFDDA1CBE8AECBE6B1C0DAABC2DBB1CAE2BED5E9D0E2EBEAF9FFFFF9FFFFF7FFF6
F5FFEDF4FFE3D0EBB6C0E09FCBECA5CFF4A6CFF5A2CCF29DC3E994CDF09EC7EA98CAED9B
CBEF98B3D77FC8EA93D6F39FD0E998C5DA8DF0FFB8405007DDEDA6D7E7A0C8D993D5EBA3
DAF4ADC9E79FCAEAA1CCE3ABE1E6CFFFFFF8FFFFF8F1F0EBB9BAB5FFFFFD6B6B69EEEEEC
FDFDFDFFFFFDFFFEFDFFFEFBFFFDFAFFFEF8FFFDF8E7DAD4998880FFFFECD4F0CADBFFD1
D0FABBC4E8A2E8FEB5CBD78BC9D083EFEBA2705A1EAD8C599B764CD0B48FFFFFDACBDBAA
B3C788D0E7A1DAF1ABC4DB95D9F0AA92AC65BBD58ED0ECA2
C8F29EC3ED9BCEF4A7C7EBA5B8D899CDEAB2CFE9B9C4DBAF96AD8396AB82D1E7B9849A69
001400C2DC9DD2EDA8C9E39CDCEFADD4E3A2FEFFCA4F5B1BE0ECACD2E1A0CFE2A0D2E9A5
D3EEA9CEECA6C7E09CC8DB99DCE5A6DADA9EA39A615B551B535C1DD3E3A2CBE29EC3DE99
D2F4AAC8ECA2BCDE94D5F4AECBE4A2D2E6A7D4E3A894A36CD4E2ADC8D9A5DFF3C2F4FFD4
E4FFBCC3E898BDE292D8FBABB6D987D7F8A7C7E696CBE79ACDE99CD4EEA4C3DB91DFF6AE
BFD58DD1E6A17085424B5F1854691CC6DB8CD2E79AC8DE93CCE299DBF2AACBE29ACBE59C
E2FCB5C3DF95C3DF94CCEB9FCBEA9CC7E897CBED99C1E38DD2F59BC3E58FCCEAA4C5DEA7
000E00041300D2DFC1D7E7C2D5E7B7CEE4A6CEEA9FC7E995D5F9A1C1E990C8F29CBAE691
B9E495CDF5ACC6E6A7CCE5AEF8FFDFFCFFE4F1F3DDFFFFEFFFFFF3D4D2C5FFFFF3FBFFEF
EFFFE4E6FBDAC9E5BDEEFFE1F4FFE3C9DEB5D3E8BDCDE3B4CEE5B1D2EBB2B9D396D3EDAC
D0EBA8BED994D6F1AACDE8A3C9E4A1D6F3B1C6E0A1CBE1B3E4EBE3FCFFFFFBFFFDEBF6E6
F8FFEAF6FFE0C6DDA7D7F1B2C9E7A1C0DE94CAEA9EBDDD91D5F3A9C8E69EC8E39ECBE69F
C9E694D7F59FC9E591CAE390DBF19FD1E294CDDB905A661CD1DD95DDEAA2CEDE97CFE09A
D3E9A1CBE59CD0EAA3D0E5ACE4ECD4FFFFF8F5F6F0FFFFFBD6D8D5FCFFFD000100FCFFFF
FCFFFFF9FBFAFBFBFBFFFFFDFCF8F5FFFCF8FFFDFADBD3C8CBC4AAE0E8BFBAE1A8B9F0AD
BBF1A6C1F0A2C5E196D7E79EDFE9A0D8D5925F49107555246D4B1EC7B084FFFFD4CDE2A9
97AE6AC7E198C7DE96D3EDA4C6E097809C525B772DC1DD93
C5E292D1EDA0CCE5A1CEE6A8C6DAA7D6E9BCCFE1BBCCDDB9CEDFBDB7CBA6A0B78D93AF7E
95B37D416327D9FDBDBBDA97D2E5A3DAE6A4FFFFC87A8543CDD896D0DC9ADDEEAACEE39E
CDE7A0CAE49DD0E5A0CFE09CC1C787706E31877D42CDC48BDFE5A7CFDFA0CDE4A0C9E49F
C9E8A2CAEBA4C6E59FCCE9A6E3F9BBF2FFCACCD9A38D9765E8F4C4F7FFD6E5F6CAC4DBA7
D0EDABC9EB9FC5E79BBFDF93D5F6A7C8E797CAE797D0EB9CD4EC9ECBE294D0E59ACDE199
B8C9835F6E2B5E6D2CA5B672C0D68BDEF6A8CEE698C9E092D3E89DD2E39CDEEEA7D0DD97
D1DA97DAE19DDBE09DDFE29FE4E5A3D1D08DABAA678F974A8DA74C91B45A98B66CC4DDA3
000C00000F00D0E0BCC5D6ACD1E5B0CDE6A4CBEA9CBCE088BDE489C7F296C5F498C5F09E
C1E9A3CAECB0C7E1B1D2E4BCFAFFE7F2F5E2FFFFF6FFFBF8AFA5A6FFF8F9FFFFFBFCFFF6
F4FFEFF3FFEFF2FFEDF2FFEAF8FFECF9FFE6EDFBD7CCDBB0F0FFCFC8DCA1C9DE9DCFE49F
CAE296C9E193C7E291CAE594CDE995CEEB97CDE995CEE4A4ECF5DAF6F8EDFEFFF1FCFFEA
FBFFE1ECFCCBDCF0B5D0E7A3CDE7A0CDE79ECDE79ECDE7A0CFE5A4CFE5A5CFE4A9CDE6A5
C4E397D5F5A2C5E290C8E392D3EC9BC8DD90D6E89C54661CD3E49DD1E29BD5E9A2CBE29A
CCE69FCCEAA2C9E7A1E4FDC4F4FFE9F7FEF6F6FFF8F9FFFBC4CFC9F6FFFD000C0AF7FFFF
F8FFFFF2FDF9F4FDFAF7FDF9FCFFFBFEFFFAEEEFE9C8CBB6D6DCACC3DA96BDF2A4AAEE9B
B4F5A3B4EA9CCFF3ABCBE29ED2E1A0DCDDA36E5E2AD2BA8A553A0BB2A674EEFFC4CBE5A4
899D58E3F3ACC6D38DDDEDA6CDDD96D5E69F9AAB64A9BA73
D8F0A2C8E096D8EDACC0D39BF6FFDAEAFAD5F2FFE0CCDDBDCEE2BFBDD6AFBBD8AA91B682
88B1793A672C9ACA8CCFF8B6CDE6A4D3E4A0DBEAA7B9C583BBC785D7E6A3BBCF8ACFE6A0
D0EBA4C3DE97D8F2ABD8ECA7717C3A626425D8D296FFFFCAF6FEC2DEEEAFCFE5A4C8E3A0
C8E7A3CAE9A5C9E6A4D1E9ABE8FAC0F7FFCFB6BE8DBDC498E4ECC3FCFFDFEAF9D2D6E9BC
CEE7ADC7E4A1C8E6A0D3F1A9C8E499C0DD8DE2FDAEC1DA89C7DE8EF3FFB9C6D88C56661D
B7C47ECCD795D8E2A3D0DC9AE3F9B0B7D285CCE498DAF0A5CDE297DFEFA886934D545D1A
666B29717131616020595315837A3FC1B77CE4D89EE4E3A0D3EA92BADB82C5E399D8F1B7
000B00000900C7D7B2E5F6CAD3E8B0C5DE9CD9F5A8D1F39DDCFFAABDE88EC0EC93C2ED9E
D8F7BEE6FFD5E0F4CFE0EDD3FEFFF1FFFFF6FFFCFDDED1D8DCCFD8FFFAFFECE6EAFFFFFD
FCFFFAF9FFF6E9F7E6F7FFF1EAF6DEF4FFE1EBF7D1C8D8A9B9CA93D1E6A5D5EBA3D1E99B
D8F1A0D7F39FD0EC98D3F19BC9EA91CCED92C5E68BC9E497DDEABEE2ECCAE7F3CBE8F8C9
E5F8C0DCF2B2D0EAA1C9E497CCE999CCE999CCE89BCCE89ECDE6A2CDE6A5CDE5A9CDE6A5
CBE99FC4E395CBE79ADAF5A8C2DA8EE9FFB4B3C87DBCD088D2E69ECDE39BD2E9A1CBE59E
CBE6A1CAE7A4C9E8A4E9FFCDF0FCE4F8FFF7FBFFFBF9FFFBC5CECBF9FFFF111B1AF8FFFF
F9FFFFF9FFFFFBFFFFFCFFFDF9FBF8E6E7E2A7A6A1979B82DDE7AACCE894BFF59DB8F99F
CDFFB8B6E99CBFDE9BCFE3A8E3EEB65959255D4F20E7D1A26D5223AEA36DCDDD9EBDD891
93A45EC9D690D5E29CE2EFA9D5E29CD0DD97C6D38DBCC983
CDE89BCDE79EC1DA99D7EEB8DDF2C7F2FFE1DBF1CDCBE3BFD5F1C9B1D2A5CEF6C2BBEBB1
BBF1B3619C5C4F8D4EB7EEABC5EAA4BFDA93D0EAA3D1E8A2BCD18CD6EDA7CDE7A0D8F6AE
C8EAA0D2F4AAC8E89FB5D089596D2874803ED2D898FEFFC6F6FFC3DEEEB0CCE0A1CDE6A5
CFECAACBE8A6CBE3A5CFE3A8EBF8C3E4ECBDABB087DADCB5DEE2BFFCFFE1E1ECCCD0DEBA
C1D5A4D2E7AEE5FBBDCCE2A1C7DE98DEF6ACC1D98BD3EA9AD4EB99BED384B1C1768C9951
D8E39ED5DE9DE6ECAED7E1A2CDE19CD7EEA6D1E79FD3E9A1879B54A4B56FAAB97494A360
86914F9AA4659AA364989E62B7BA81DCDFA8E7E7B1DBE4A5DAF1A1C0DD8BD9F2B0D7EBB6
000900000800A5B390BBCAA1CEDFABD2E8A8C8E298C7E696BCDF8DC6ED9AC4ED9EC9ECAA
F0FFDDF8FFECF9FFEDF7FBEDFFFFFAFDF7F7F6EBF1D3C3CDFFF8FFFFF3FDFFFBFFFCF6FA
FFFFFDEEEFE9FCFFF8ECF5E4F8FFE8B9CBA1D2E6B3EAFFC2C7E19AD2EEA1D5F2A0C4E48F
C1E38FC6E995BFE290C9EF9CBCE390CAF29CC4EC94CEF19FCAE5A0CDE6A5CFE8A4CFEBA1
CDEC9ECAEC96C6EA90C2E98CC6ED90C6ED90C6ED94C6EC95C8EB99C8EA9DC9E9A0C9E9A0
D1ECA5D4EEA7CAE49BCCE39BCEE69CC1D78E97AB63D3E7A0D3E9A1CCE19CD1E8A2CDE6A2
CCE7A4C8E5A3CBEAA7F4FFD7FFFFEFF8F3EFFFFEFBFCF8F5DAD6D7FAF8F9525053FCFAFD
F9F7FAFFFDFFFFFDFFFFFCFDFFFCFDFFFAF9BBB0AEE7E1CBD9DB9CCEE08CC3EB93B2E28E
BEE79BCAE7A5DFECB4DBDFAD706F41575024B39D74ECCFA579582BA38D5BCACF8FEFFFBC
B1C57D8EA35892A65ECADE96D2E69EDBEFA7DEF2ABB9CD86
A5BB7099AF67A9BD80CCDDA9F3FFD9F7FFE1F7FFE3F4FFE0DBF2C6CEEAB7C5E8B0729B5F
81B1739CD392579154609756C7F2ABC1E59BD1F1A8C4E29AA4BE77C2DC95D3EDA6BDDB93
C0E298CBEDA3C3E59B97B76E829C55BCD08BD2E19EDDE9A9DBE9ACD1E3A5CDE1A4DFF7B9
E3FDBED2ECAFCDE5ABCBDEA7ECF5C6CCD1A8D4D6B1E0E1C1F0F3D4F9FDE2F3FCE1DDEACC
E9F8CFD2E2B3C3D4A0CCE0A5DBEFB0B5CA85D6ECA1CEE59590A7579AAF60BDCD82D9E69E
D6E19CD2DB9AD8DEA2D6E0A3CEDC9ED7EAA87F925096AB68BED28DD3E8A3C9DE9BC7DC99
D0E5A4D2E8A8D0E6A8D2E7AEDAEFB7D3E7B2C7DBA8C5DCA4C7E09CC6DF9BD5EAB1CDDEB1
000800000600B1BA9D939D7A909C6CCEDDA4DCF1AED5ECA4BFDA93D3F2ACD2F2B1BCD8A5
F9FFECFBFEF3FFFFF8FFFFFAF5EFEFE0D7DAE9DCE5F1E4EDFFF2FBFFFAFFFFFBFFFDF4F7
FFF8F9FFFEFBFFFFFAFBFDEFF3FFE1EAFFD1F2FFD1B0CB88CDEC9EC3E38EBCDE87CEF29A
C8EE99CFF4A4C3E99CCDF6AAB9E495C6F1A1BDE896C7F19FC6E89BC7E79BC8E89CC7EA98
C6EC97C5ED95C4EF95C3F095C2EF94C2EF94C2EE95C3ED99C3ED9BC5EB9EC5EBA0C8EAA0
C4E29CD9F4AFCAE39FC1DB94E2FCB3C8DF978EA55DD4EBA3D4EBA5C9E39CCEE9A4CBE9A3
CAE9A5C5E5A2CAEAA9F5FFDAFFFFEFFEF4F2FFFCFBFFFDFBE2D9DAE8E2E4352F33FFFAFE
FFFCFFFFFCFFFFF5F9FFF4F6FFFBFBFFFBFBB9A9A9FFFEECDAD9A1D4E297D8F8ACC7EBA1
C3DE9BE2F0B5D2D2A0787445585528B3AC7EF4E3B7EED6AA67481AA28B57F0F0B2BDCC87
D3EBA19DB96C8DA95EE0FCB1BEDA8FC3DF94CAE49BD2ECA3
E3EDA4B6C07B9DA268D1D3A2F3F1CAFFFFDFFFFFDEFFFFDCE7EABBD7E0A9BAC98E7E9454
85A164CAE9AD9ABD856E9457C2ECA4C7F0A2BFE497D2F0A69EB86FCAE098DAF0A8CCE39B
D4F0A6B9D78DDAF8AE8AA85E839D54D5ECA4DDF1AACDDD9CCEDEA0D0E4A7D4E9AEF2FFCF
F1FFD0D2EBB1CFE6AECCDEACCCD5A8B6BB93F1F2D2D7D7BBF0F2DAFEFFECFBFFEDF5FFE8
E2EDCDD6E2BCDEEBC0C7D7A6DDF1B6DBF0AF879E56ADC57989A251C7DE8ED0E598C8DA90
D2E19CDFEBA9D3DDA0DBE6AAD9E4AA849257BACA8CDBEDAFB8CD8CCFE5A4D7F1B0CBE9A9
C7EAAAC5E9ABBAE2A6B6E1A9BDE8B3BAE6B3BAE8B9CBF3C1CCE7B0DBEDB9CBDAB1D1DCBC
081000000400DDE0CBB2B59882875FADB584CEDBA3D5E4A9D6E9B1BDD49ED3EABCCDDEBE
FFFFF6FCF8F7FFFDFFFFFDFFE5DCDFDED5D8F0E5E9FFFBFFFFFCFDFFFCFDF8EEEDFCF2F1
FFFCFAFEF4F2F2E9E4FFFFF3F9FFE8EBFFD5F4FFD4C5E09DDAF9ABD5F5A0D2F49DC2E68E
C4E999C8EDA0C0E59FC7EFA9BAE39DC3EDA5BDE79BC3ECA0C7EBA5C7EAA6C7EAA6C6EBA6
C4ECA5C4EEA6C4EEA6C3EEA6C1ECA4C1ECA4C1ECA5C2EBA5C2EBA7C3EAA7C3EAA9C5EAA7
C7E7A4C7E8A1CCEBA5CBEBA2C1E196DCFAB058772BCDEDA1CDEDA2C4E69ACAECA2C6EAA2
C6EBA5C1E9A3C4EBA8EFFFD8F5FAE6FFFEFAFFFEFBFFFEFBCECAC9D6D2D1050304FFFEFF
FFFCFDFFFEFFFFFAFCFFFBFCFFFCFBFFF7F7A19392E5DECEF6F8D0E4F5BECAE8ACC9E7A9
D9EBB1D4D9A39E986666602E4A4F17E2E7AFE3E0A9D7CC96735F2CA1925BE3E3A7DFF0AC
CBEB9F9FC6777FA657C3EA9BC8EDA0D6FBAECAECA2C6E69D
D4E297C8D38EA3AB6FDFE3B0ACAD81A5A37A5A572C59582887884F72783A899450C5D48F
C9DE9BD3EBADCFEAB3D0EFB4C3EBA4BAE395C6E69BD6F0A7CDDE98A9B671D4E19CDEEBA6
DEEFA9CCE099E0F6AE7B924A8EA45CD4E8A1CCDD97CCDC9BD0E2A6D5EAAFD1EBAEF2FFD3
F1FFD2C8E4AACDE4B0CDDFAFABB68CC3C9A5F1F2D3D6D6BEDEE0CBFEFFEFF4FDEAF8FFF0
EFF7DFDEE7CAE7F3CFE4F4C7CADCA87C92548BA25CB6D086D0EB9CCFE897DBF3A5CAE095
E0F4ADD8E8A7D3E1A4ABB97E89965EB3C289CFDEA5C6D89CD8ECAFD5EBADC6E0A3CFEBB0
C3E2A7DAFDC5E0FFD1D7FDCCDCFFD7DFFFE0D7FFDBD3F7D1DFF6CCEAF9D2D9E4C6EFF7E2
212316010100F7F5E8E9E7D2DBDABBBEC09892986AEEF7C8EBF6CCE4F2CED9E8CBF5FEED
FFFCFDFFFAFFFFFBFFFDF4F9DED5D8FBF5F5FFFEFBFDF8F4FFFAF4F8F1E9FFFDF6FDF4ED
ECE1DBC5B8B2FBEEE8EBE2D9FBFFEEE7F6D5DEF1C3DBF0B5C2DC93C3DE8FCEEB97CCEC99
CAE99DC7E6A0C8E8A7C5E8A8CAEDABC7ECA7C7EDA4C4E89EC7E8A1C8E9A4C8E8A5C6E9A5
C5EAA7C3EAA7C2E9A8C1E8A7C2EBA9C2EBA7C3EAA7C3EBA5C5EAA5C5EAA4C6EAA4C8E9A4
CFEEAAC8E7A1C8E6A0D2F0A8BBD98FA3C2766A893DC6E599CAEA9EC5E79BCBEDA1C4E89E
C5EAA4C3EBA5C1E9A3E2FECBF7FCE8FFFFFAFEFAF7FFFEFAC2C1BF6464628B8B8BFFFFFF
FBF9FAFFFEFFFFFBFAFFFDFDFFFDFBFFFCFABBB1AFE1DAD0FEFFECF8FFE4C2DDB2CBE3B3
DEE6B7989464695D29B8B278DFE8A7CAD994CFD895E1E1A1584E13ADA26ACCCD9395A463
89A75DABD082C3E89ABEE093C4E499BBDB90D4EFA8C7E29B
CBEE9ABDDE8FCBE9A3B4CC8ECDE2AABCCD97DEEBB5E2F0B3C3D28DCDDF93D2E896DDF6A5
C5E196C5E4A0C9E8ACBFE1A4CEF2AAC4E499D6EDA5CBDA95DFE4A2666626A5A464C8C787
D6D897E3E8A6D5DE9B8F9A569DA864D3DE9AD9E29FE5F1B1D2E4A8D1E9AFC6E2A7F0FFD3
F0FFD4C7E4ACD2EAB6D2E5B7A8B38BF0F6D4EEEED2E0E2CCE9ECD9FCFFF3F6FFF1F9FFF3
FAFFEFFCFFECFBFFE6F5FFDD001200DAEFB4D3EEA9BFDB91CFEB9EBAD787DCF8ABD1EBA1
BDD48EC8DD9AD9EBAD93A56B5B6E36D0E3ACD0E3ACD4E5AED8E9B2D4E6ACD8E9B2CCDAA5
D9E7B6F3FFD4FAFFE0F2FDDBF7FFE5FCFFEDFBFFF0F9FFECFAFFEBFBFFEBFDFFF2FFFFF8
353130040000FFFEF8FFFEF1FFFFE8F8F5D6B4B490FFFFE1FFFFE6FEFFEDF7FDF1FBFDFA
FFFBFFFFF9FFFFFAFFFBF2F7D9D3D5FFFFFAFFFFF8F7F7EBFFFFF1FFFFF1F9F3E5E9E1D4
65594D7A6C63907F7760534D2E2B26CBCFC1D9E2C7C6D1A7DFEEB3D8E9A5CDE199D9EFA6
D5EAA5CAE09FD2EAACC5DFA0DAF4B3CBE6A1D0ECA1C3E090CCE798CCE798CCE79ACAE69B
C8E69CC7E79CC8E89FC7E99FC8EAA0C8EA9EC9EA9BC9EA99CAEA95CAEB94CCEA92CDE995
CCE39BD2E7A4C9DE9BD8EDA8D2E8A094AA61D1E79CDDF3A8CCE498CCE79AD1EBA1C7E399
C9E7A1CDECA8C4E39FD6EEBAFBFFEAFEFBF4FBF8F3F9F8F4D4D3D1000000E8E8E8FEFFFF
FFFFFFFFFEFFFDFCFAFAF6F5FDF8F5FFF8F5DCD2D0DDD8D4F3F8F2F7FFFAEAFFE9F6FFE7
E6E6C0998E6066551FA49C5BD4E293D2EA96E1F4A3D6E097615C1C9E955CAEAD75CDD79A
CBDC98D5EBA2E0F4ADD1E29CDEEDAAD8E7A4D6E0A1959F60
BEEC94C2EF9ACDF6A8B5DA94CBEBAACBE8A8D5EEACBED58FD3EB9DD4ED9AC9E590CAEA95
CAEB9CC6EAA0C4E7A3CCEFABC0E097DAF6ABCBDF97DDE8A3D3D69172712EA09D5AE7E6A3
E2E39FDDE29FD3DA96B2BB785E6522939858E0E1A5CCD498CEE2A7CAE6ABC0DDA3F1FFD4
F0FFD6D4F1BBE2F8C7E1F1C499A178FAFEDBDBDCBDD3D6BBF6FBE4EAF6E0F5FFEFF3FFED
F7FFEAF5FEE1EBF2D1CDD9B1BFD3A0D4EDB3BAD794D3F1A7D6F1A4CDE597C7DF91D4EFA2
97B26B829D5A96AC6ED0E3ACDAEBBFE9F8D1E1F0C7EAF6CEDDEABFF3FED4D2DAB3FFFFE1
F2F8D6FBFEE1FFFFEAFFFFEDFFFFF1FFF8EEFCF5EFFFFFF6FFFFF3FBFFF0FEFFF8EDEEE9
1C1819060002FFF8F6FFFDF6FFFEEEFFFFEAFFFFE7A9A790CDCCBAB6B6AAFFFFFBF5F3F6
FFFBFFFDEFFCFFFBFFFEF5FAD4CECEFCF7F3FFFDF4FFFFF3FFFFF1FFFFF1DCD6C8DED6CB
FAF0E6FFF5EDFFF5EFFFFCFAFFFDFFEBEAE6DBDCCEB7BBA09EA77C93A06ADCECAE869959
8A9D5D8196559EB2739BB06FCEE3A0C6DB96DCF2A9D0E59AD2E798D2E798CFE698CEE69A
CCE79ACCE89DCEEA9FCDECA0CCE89DCCE89BCCE999CDE995CFE894CFE990D0E98ED1E792
D5E69FD3E4A0D2E39FD7E8A2A8B972B8CC84D4E99EC9DE91CAE095CFE79BD2ECA2C5DF96
CAE59ED0EEA6C3E19BCCE5ABE5F0D0FBFFEEFFFFF3FBFDF0EBEBE303020082817DFFFFFD
FFFEFCFCFCFAFFFFFDFFFFFDFFFEFBFFFFFAFFF9F6E9E4E1FFFEFFFBFFFFF0FFF5F1FFED
D4D9BBDDD8B0BAA878827437D9DD93DBEA99D0E391D4DF91837B3A93874DA8A56EE4E9AF
DFEBA9CBDC95C4D38EE2EFAAD3DE9AE2E8A8D0D595909555
BDED99C3F09DC2ED9DC4ED9FCBF0A3C6E69BC4E397D1EDA0CCE999DFFCAAC0DF8FC3E493
C4E797C9EEA1D8FCB2BCE096C5E599D2EDA0D6ED9FCEDF91DAE79899A45699A455CBD888
DCEA9BD1E294D2E299DAE7A18E97564C5015EFECB7DADDA8D5EAB1BEDDA2C4E3AAF1FFD6
F2FFD8EEFFD1FBFFDAFFFFDA9FA078CECCA6DFDFBBD3D7B4EBF7D3F4FFE4E4FFDAEEFFE3
F5FFDDF5FFD3D1D7AB9DA677D6EBB3C7E5A7CCF0AAC3E197D3E398CDD88CE3F1A46B8234
9BBB70C8E7A3D4ECB0E1F1C4FCFFEDFEFFF4FEFFF4FEFFF4FEFFF4FEFFF4FFFFF4FFFFF4
FFFFF6FFFFF6FFFFF8FFFFFAFFFFFAFFFFFBFFFFFDFFFFFBFEFFFAFEFFF8F6F9F2FFFFFB
30302E010000FDF9F6FFFFFAFFFAF4FFFDF4FFFDF2FCF8EFFFFEF8D7D2CEB2ADAAF5EFEF
FFFBFEFFF9FCFFFAFDFFFBFCD6CCCBCCC2C0FFF8F3FFFBF5FFFAF2FFFEF8A29B95FFFDFA
FFFDFBFFFBFBF3EDEDFFFDFFFFFCFCFFFEFBFFFFF8FCFEF0FCFFECD1DCBACCDDB0D1E6AE
B3C98990A965889F598DA35B8A9E5791A25E97A66589985796A560788841DFF0AACDE19A
D4EAA2CEE59DC4DE95CDE99FC3DD94D2ECA3D3EAA2D0E69DD6EAA2D0E59ACEE096DAEAA1
D5E69FC5D690DBEFA8DBEFA7657931A5BB72E2FAB0C9E195CDE79DCCE89DCAE99DCAE99D
C9E99EC8EA9EC8EA9EC9E8A5C4DAA9D6E6BFDEE8C6E6EACFD8D5C27973658D867CFDF6F0
FFFEFBFFFEFCFEFFFDF9FBF8F8F8F6FFFFFBFFFEFBD0C7C8FFF6FEFFFBFFF9FFFDEDFFF4
CAE4CBCFDABCE0CDAD91744C68541FDDD594DBE199D8DB94B2A062F0D9A39A915AE4EAAE
D0E19DDFF5ADCCE299D2E69ECFDF98E2EDA9C8CF8CA0A764
C0EB9BBEE999C4EE9CBAE190C6E999D4F5A6C7E698CCE999C6E295B6D285D4F3A5DCFBAF
CDEDA1BCDE92ABD083D4F6AACEEAA0D7EFA5C9DE93DEF0A4D5E3968A994894A352DCEE9C
D3E997CDE494D0E59AD0E19BA2AB6C75763DA7A16FE0E0AEC8DDA4CAE9ADD0EDB3DEFBC1
DEF7C0DCEEBAEDF9C7EBF1C39D9C70FFFFD7DADBB1DEE5B9DFF0C3D6F0C0E1FFD2D2F5BF
D8F1B8FBFFD3B7BB88DDE6B1C0D59CC6E6A5D2F8AFD3F1A7E0ECA2DEE296A3AE60A3B569
CBEBA2CBEEAACCE4AAE9F8D1FEFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFBFEFFFBFEFFFB
171813010200E7E6E2FEFDF9FFFEFBFFFEFBFFFEFBFFFBF8FFFEFBE5DDDBAAA2A0B8B0AE
FFFAFAFFFDFDFFFDFBFFFAF8F7EDEBBEB3B1B3A8A6FFF6F4FFF7F5FFFCFABEB5B6FFFBFB
FFFDFFFBF9FCFFFEFFF2F0F3FEF8F8FFFEFBFFFFFAF6F7EFFCFFF3E2EFD5E0F2CCCBE3AF
C4DE9FC1DC95D0EAA0DDF3A8DAEBA4D7E6A3C6D195A2AD718A96564E5D1A82934F91A560
C5DA95E3FAB4D5EFA8C5DF98DCF6AFC8E29BCCE39DD6EBA6CDE19CCADB97D1E09DD0DF9A
DFF0AADBECA5C2D68EADC179AEC47BC8E096CEE89EC4DE94CCE89DCAE99DCAE99DC9E99D
C8EA9DC8EA9DC6EB9DC8E9A2D0EDB5C2D8AAF3FFD9FFFFE49D9882070000DDD3C9FFFDF8
FFFEFAF8F7F5FEFFFDFAFFFBFEFFFDFBFCF7F3F2EED2C8C7FFEEF4FFF7FBF7FCF8F0FFF9
CEEED9D0E4CBEBD9C3AE8C70694D25EDDCA8F0F0B2E3DFA2A08452DABB8D938659CACF99
D9EEABB4D086D8F4AAC4DE94DBF1A8DBEFA7CFDF9898A55D
C9EE9EC7EA9AD5F8A8CCED9ECAE99BD2EEA1C6E194D3EB9FD2EAA0E8FFB6B9D389CBE59C
D1EDA3C7E59DE5FFBCC2E09ACAE3A1B9CE8DE6F6B5D0DD98CAD590A1AD65849046DFEDA2
D4E69AD2E79CD5E9A1D2E39FC5CD91B2B27C6E6838D3D3A1CDDFA5D4EEAFCBE8A8CCE9A9
CAE4A7CADFA4DAE9B0D5DFAA6A6E3BC3C795EEF5C2CCD6A2CCDFA8D6F2B8C1E4AACAECB0
D1E9AD9EAD74555926DAE3AED3E8ADC6E6A3BDE39AC6E49ACCD88EF2F6AC8D954AC9DB91
CCEBA5C0E0A1C8DCA7E2EECAFEFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFBFFFFFDFFFFFD
0706040A0907E2E1DFFFFFFDFFFCFBFFFEFDFFFEFDFFFBFAFFFEFDFFFDFDEBE5E5E1DBDB
C7C1C1F5EFEFFFF8F6FFFDFBFFFCFAFFFCFAFFFBF9D5CAC8E1D7D5B4AAA8FFFCFDFFFDFD
F4EFF3FFFEFFF7F6FBFFFEFFFDF9F8FFFEFBFFFFFAF4F7EEFBFFF3F6FFEAF5FFE3C9E1AD
D3EDAED2EDA6D0EB9EC7DF93C6DA92DAEBA5DFEDAFCAD89AD7E6A5CBDC98E4F5B1C9DD98
94AB657F995288A25B99B46D839E57718B44A0BA73D8EFA9CFE39EBECF8BB0C17D8FA05A
82934D99AD65A0B46C93A75FD8EEA5CEE69CC9E399D1EBA1CCE89DCAE99DCAE99DC9E99D
C8EA9DC8EA9DC6EB9DC8E9A4D3EDBDCBDFBADFEACAFFFFEAADA79780766CBBAEA8FFFAF8
FFFDFBFFFDFCFFFFFDF7F9F4FFFFFAFFFFFAF2F2EAF4EDE7DFCBCCFFFAFAFEFFFAF4FFFA
DEF9E6F6FFF0FFF5E3AD8F77634B29CFC095FAF6C6FEF3C68F6D4ADDBA9EF5E7CA97A075
C6E0A1CBEDA3C4E69ACAEC9FC2E296C2E193C7E396C7E494
D5F1A4C6E295BEDA8DCEE99CD2EA9ECCE299D2E89FD4E8A1D1E59EC6DC94D2E7A2D1E8A2
D0E9A5BAD590BED996CBE4A3E1F4BCCCDDA6D8E5ADD2DCA0E0E8AC929B5A9CA763CBD892
D2E39CD2E8A0D2E6A1D9E9A8DBE5A9D7DAA37B77479B9B67DCEAADD3E9A8C2D897CAE3A1
D1EBAAC8E1A0CEE2A3D1E1A33F4A0E7E884CDDE7ABD0DEA1D7EBACC2DF9DCAEDABC8E8A7
D0E9A892A166AFB47ECDD69FD7EDAFC7E7A4CAF0A7C0DE94D3DF95D6D992A4AC63DCEBA6
CDEAA8C5E4A9DAEDBFEEF9D9FEFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFBFDFDFBFFFFFDF8F7F5
100F0D050402EAE9E7FFFFFDFFFEFDFFFEFDFFFEFDFBFAF8FAF6F5FFFEFDFFFEFDFFFCFB
B1ABABFFFAFAFFFDFBFFFDFBFFFCFAFFFCFAFFFCFADCD1CFE3D9D7FFFDFAFFFCFDF0ECEB
FFFDFFFFFEFFF8F7FCFFFEFFFFFEFDFFFEF9FFFFFAFBFEF5FBFFF3F8FFECF5FFE3CBE3AF
C6E3A3C9E79FCAE699C4DF90C6DC91D2E69FD8E8A7CEDE9FDEEFABCDE19CC0D48FD5EAA5
C9E39CD1ECA5CBE69FBBD991E2FDB6BDD891B8D38CBED891ADC27DA4B974A7BB7699AD66
8A9E5694A860C2D68EC2D88FD6EEA4C1D98FD3EDA3CDE99ECCE89DCAE99DC9E99DC9E99D
C8EA9DC8EA9DC6EB9DC8E8A5BBD5A8DCECCFE7F1D9FFFFEFD1CBBFD6CBC5827473FFF4F4
FFFBFCFFFCFBFFFFFDF7F9F4FAFBF5FFFFF8FFFFF6FFFEF6CBBEB8F8EDE9FFFFF7F9FFF8
ECFFF0F9FFF3FFFCEDCBB1A08A795D8B7E5CFFFFDDFFFDDFA57A6AFFE2D6FFFDEDD3DCBF
AEC694D4F4B5C3E3A2D5F6B1C0E19ACCEEA4CDEFA3CEF0A4
CCE395DDF4A6CCE297DDF2A7D2E69EC6D790E3F4AEC4D591D6E6A5D1E1A0D5E5A67B8E4E
96AA6B93A969BBD1939DB2798A9A696D7A4CC4CD9EDCE4B1E2E9B3C5CD92909A5DE7F6B5
CDE19CCEE59FC6DB98D9ECAAD6E4A7D4DCA3B3B37F545720CBD397D9E8A7CCDF9DCEE5A1
D4EFA8CBE69FCEE8A1D0E7A1899D58637430D8E7A4D9EAA6CCE39DE4FFB8B7D98DD3F3AA
C8E19D95A566C6CB91D4DEA2D4EAAABFE09BCBF1A6CEEDA1D2DE9661641D9EA360C4D392
C8E4A7C1DDAAD3E3BCE7EFD7FEFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFEFDF6F2F1
34302F030000F1F0EEF9F8F6FCFBF9FCFBF9FFFFFDFFFFFDFBFAF8F9F8F6FFFFFDFBFAF8
FFFEFDB1ABABE4DCDAFFFDFBF6ECEAFFF9F7FFFCFAFFFCFAF1E7E5FFFDFAFFF6F7FFFEFD
FFFDFFF5F3F6FBFAFFFFFFFFFFFFFBFCFBF6FFFFFAFCFFF6F9FFF3E6F6DBEDFFDBCCE4B2
C8E5A5CCEAA2D0EFA1D6F3A3D9F1A3D1E79ECADF9ACBE09BC6DB96D0E79FC4DB93DEF8AF
CBE79DCFEDA3CFEDA3CDEDA2C3E197CCEAA0CEECA2D1EDA3D9F3AADAF1A9D0E69ECBE199
DDF3AAC6DC93D7EDA4DDF5ABCCE49AC9E197D8F2A8CBE79CCCE89DCAE99DC9E99DC9E99D
C8EA9DC8EA9DC8EA9DC9E7A7E5FED6F7FFEDE4EDDAFDFDF1D4CDC5FCF1EF100202FFFBFF
FFFCFFF9F5F6FFFFFDFFFFFBF8F9F3FFFFF8FFFFF6FAF6EBEEE7DDDED7CFD3D0C9FCFFF6
F8FFF8ECF2E6FFFCF3FFF9EBFFFEEAA49C854C412BFDE6D8FFE3E4FFE4EAFFF5F5FAFFF5
F3FFE46F865AB6CD9FE3FECBF1FFD5D6F3B9BDDD9EBEE19F
CBE093DBF0A3C5D78DD1E399DAEAA3D8E7A2BECD8A4C5C1B66763789995B4D5C21E5F7BB
BFD398DCF1B6BED398C9DEA6D4E4B7C9D6AB949D72CFD7A8D2D9A6E7F0B9A0AB6F7E8E4F
CEE5A1CFE8A4C2DB97D7EEAACEE1A1CAD698DDE5AA4D5017929659D9E2A1E4F3B0CFE49F
C9E39CC9E79DD0EEA4CCE89ECDE79DB9D187849850D7EDA2C6DE94CAE699D6F5A7C0DF91
C9E39C8EA15F646C30CED89BD3ECAAC8E9A2BDE396C9E89CDEEAA24A4D08DADF9DD6E1A5
D8F1BAE2FCCFF5FFE3F8FFEBFEFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFDFFFEFDFFFCFBFEFAF9
5E5A59030000F3F2F0FFFFFDFFFFFDFBFBF9F8F8F6FFFFFDFFFFFDFEFFFDFEFFFDFFFFFD
FBF7F6FFFCFC938B89CFC7C5FFFCFAF6ECEAFFFCFAFEF4F2FFFCFAFFFDFAFEF8F8FFFBFA
F5F3F6FFFFFFFCFBFFFEFEFFFFFFFBFAFBF5FDFFF7FCFFF6F8FFF2D2E2C8D7EBC6C8E3B0
C9E6A6C7E79EC0DF91C1E18ECAE596C4DF92C7DE96D8EFA7D1EBA2D7F1A8C4E096D2EEA4
C3E197C7E79CBFDF94BFDF94BFDF94D3F3A8CAEA9FBBD98FC8E49ACCE89EC6E097CAE49B
CFE79DD0E89EC5DD93D1E99FCCE49AD0EAA0C8E499D5F1A6CAE99DCAE99DC9E99DC9E99D
C8EA9DC8EA9DC8EA9DC9E7A7D1EAC2F3FFE9FBFFF1FFFFF4D3CCC46055537F70737C7074
FFFCFFFFFDFFF6F4F5FFFFFDFFFFFBFFFEF9FFFFF8FFFBF2FFFFF6F0EDE4DCD5CFFFFEFA
FEFFFAEFF0EAFFFCF6FFFCF3FFFEEDE6E3D0534A39A78A84B57C85FFEEFBFFFAFFF6FAF9
F7FDF1E7F0DB7C866EAEBB9FF8FFE6C2D4AED3E9BBDFF7C7
889B4CB1C377E0F2A8CBDD939BAC6599AA6494A4636E8141889A5E91A568D1E5AABFD499
D3E8AFCFE7ADD8F0B6E9FDC8E1F4C7EAFBD1D0DDB2A9B5876D774595A26C8392579FB473
CDE8A3CFEFA6C7E79ECDEBA3CFE9A2CBDF9ADCEBA8949D5E5D5D21C2C387E2EBACD1E29E
CAE49DC8E89FCDEDA2C9E99ED8F7ABCEEA9D8CA458A0B86AC0D88CD5F0A1C5E292CBE898
CEE89FD8ECA7ABB475B3BD7EC0D995D5F7ADCFF5A8BFDE92D1DB945A5B19DEDFA3D6E1A9
C8E0AEE0F9D1F9FFECF8FCEEFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFF9FBFFFDFF
6E6A6B050102D1CFD0FFFEFFFFFFFFFFFFFFF5F5F5F8FAF9F9FBFAF1F5F4FCFFFFF5F7F6
FFFFFDFFFCFBFFFEFBD0CBC8D2CAC7FBF3F0CCC2C0BDB3B1251D1AFDF5F2FFFDFDFDF9F8
FFFEFFF8F8FAFAF9FEFEFFFFFDFEF9FFFFFAFEFFFAF8FFF5F8FFF3CDDDC3CDE1BCC8E2B2
C6E2A5D0F0A7CBEC9DC8E895D2F29FD0ED9DC9E399CFEBA1C4E298CDEBA1CCEAA0CBEBA0
C6E69BCCEEA2C7E99DD5F7ABCEF0A4CEF0A4CFF1A5CDEDA2C9E99ECDEBA1D0EEA4CEEAA0
C2DC92D5EFA5CEE89ED3EDA3D2ECA2CDE99EBDD98ECFEBA0CAE99DCAE99DC9E99DC9E99D
C9E99DC9E99DC8EA9DC9E8A5E1FBCEF7FFE8F8FFE9FFFFEFFFFEF4E3D8D4B6A8A84A3E42
A69DA2FFFDFFFDFBFEFFFFFFFFFFFFFEFDFBFFFEFDFFFEFBFEFFF8FFFFF6F2E8E6FFF6F6
FFFEFBFFFEFBFFFDF8F6EFE5FEFFF1E3E6D16259488F706BBC808AFBC5D3FFFAFFF6F7FB
FFFCFFF5EAF0FFF9FDB9B1AF78746BFFFFF3FFFFEDE7EDD3
B3C8797E93449FB4679AAE66A2B66FD7ECA7D3E8A7DCF2B2CBE0A5DAEFB6CDE5ABC8E0A6
D4EBB3CAE3AAF5FFD4F1FFD2F5FFDCF3FFD9F8FFDCF9FFD8DEECB78B9D6394A869A4BF7A
C3E59BC8EDA0C7EE9FC0E597D0EFA3D0EAA0C5D991E0EBA7444408A2A067CAD094D3E2A1
D9F2AECAEAA1C5E99FCAEFA2B7D98CD9F8ACB4CF827B9347D9F1A5D1E99DC8E394D5F0A3
D1EBA1C4D891E0E9A87C8745CBE59EC1E397C7EE9FC9E89CDDE7A05A5A1A9B9C62D7E0AB
D4EABCDDF2D1F5FEEBFEFFF8FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFBFDFFF9FBFFFEFF
625E5F010000989697EFEFEFF0F0F0FEFFFFFEFFFFFCFFFFFCFFFFF8FCFBFBFFFFFCFFFF
FEFDFBFFFEFDFAF5F2FFFEFBFFFDFAFCF4F1FFFCFAF7EDEBFFFDFACEC9C5F9F3F3FFFFFD
F7F5F8FFFFFFFEFFFFFAFBFDFAFBF6FFFFFAFEFFFAF4FCF1F9FFF4D2E1CACEE2BFCCE4B4
E2FEC3EFFFC8DBFCADC2E490C9E996CEED9DC7E698C9E89CC9E99EC6E89CCBEBA0C2E498
CAECA0D1F3A7BEE094C6E89CD0F2A6B5D78BC5E79BD5F7ABC3E599C5E79BD3F3A8C4E499
D6F2A7CCE69CCAE49ACCE89DCBE79CD1EDA2D3EFA4C6E599CAE99DCAE99DC9E99DC9E99D
C9E99DC9E99DC8EA9DC9E8A4D1ECB7E7FCD3E9F4D2E2E6CBFAF5E2FFFAF0AC9E9B796D6D
0E050AFDF8FEFFFEFFF9F8FDFFFEFFFBFAFFFFFAFFFBF9FAFBFFFAF4F7F0DCD0D0F5E6E9
FFFBFCFEF8F8FFFDFAFFFFF3F3FCE7E8F2D9E7E1CB5B3F33DC9FA4FFE6ECFFF8F7FFFFFF
FDF1FDFFF8FFFFF9FFFFF2F9F9EDEFCCC3BEEEE8DCFFFEEE
CCE592C6DF8EC0DB8CC4DE94CDE7A0D1ECA7CDE7A6C6E0A1CEE7ADC2DEA4E1FDC3DEFAC0
CCE8AECFEBB1DAF3B9E1FDC3DAF5C0E6FECCDFF6C2F3FFD0CADEA3D6ECACC3DE9BC4E49B
C1E79AC7F19FC3EF9AB5DF8BD4F7A3CFEF9CD0E998D3E39AA0A064635E27A0A56BD6E4A7
CDE6A5CFF0ABC0E59FC0E69DCCEEA4C7E79ED1EDA392AC63A6BE74CDE59BC8E298D3EDA3
CBE59BCCE099E4EDACA9B472B1CB84D0F2A6BEE395CEEA9DD7DE98AAA96993925AD9E1B0
D7E9C1E0F3D7FAFFF5FEFFFAFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFAF8F9FFFEFFFFFDFFFFFCFDFFFDFE
6A6667010000868485FEFEFEFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFBFFFFFBFFFFFCFFFF
F9F8F6FFFEFDFFFDFAFFFEFBFFFDFAFEF6F3FFFDFAFFFDFAFDF5F2BBB6B2F2ECECFFFFFD
F2F0F3FEFEFFFEFFFFF6F7F9FBFBF9FAFBF6FEFFFBFCFFFAF3FBEEDAE7D3CEDFBFCEE5B7
E5FFC7E4FFBEDDFDB1D3F4A3C9EB97C6E796C7E899C7E899C8EA9DC6EB9DC8EA9DC8EA9D
C8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC6EB9DC8EA9DC8EA9D
CAE99DCCE89DCCE89DCCE89DCCE89DCAE99DCAE99DCAE99DCAE99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E9A0D2EFAFCBE2AAC4D2A1E8EFC6EDE9CCF6EFDCC0B6ACC4BBB6
423C3C858386BEBDC3FEFEFFF9F9FFFFFDFFF7F4FFFFFEFFF9FFFFF9FEFACCC1C5CAB9BF
FFFBFFFFF7F8FFFCFAFFFFF3F7FFEBDEEDCCE2E1C3654C36925950EDB8B2FFFDEDFEFFF3
FFFCFFFFFAFFFFF8FFFFFBFDFFFCFABEB5ACB7B0A0D8D1BE
CBE894C7E492C4E191C5E498CBE9A1CDECA8CAE9A6C6E4A6BAD89CD4F1B7F1FFD4E5FFC8
C4E0A5C2DEA3CEEAAFCFEBB0CCE9AFC7E3A9C3DCA2CBE3A7C3D999D1EAA8D3F1A9D3F5A9
C8EFA0C8F3A1C9F5A0C3ED97CCEF9BC3E38EC9E28FD4E49BDBDAA15E5B26848951D3E2A7
CCE6A5C0E09DBDE29DD0F5AFBEDF9ACEECA6BAD38F879E58B1C882D0E7A1CFE9A2C8E299
CDE79ED2E8A0C2CB8AA8B371D9F3AAC0E295C1E698CFEB9EE2E9A3898848A3A26AD4DAAC
EDFDD9F4FFECFCFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
747273000000818181F6F6F6FEFFFFFEFFFFFCFFFFFCFFFFFBFFFFFBFFFFFBFFFFFCFFFF
FFFFFDFFFEFDF9F5F2FFFEFBFFFEFAFEF6F3FFFDFAC8C0BD948C89FFFDF9FFFEFDEDECEA
FFFFFFFEFFFFF0F4F7FEFFFFFFFFFDFFFFFDFDFDFBFDFFFAFBFFFAF9FFF3E5F5D8D1E6BD
CDE6AFCCE9A7CBE99FC8E998C8E998C9EA99CBEC9DCAED9DC6EB9DC6EB9DC6EB9DC6EB9D
C8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC6EB9DC6EB9DC6EB9DC8EA9D
CAE99DCAE99DCCE89DCAE99DCAE99DCAE99DCAE99DCAE99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99ECDEDA4C6E19EDEF0B4CCD6A2F1F1CBFFFFE4928B78FFFAEE
EBE6E22624256B6C70FCFFFFFCFFFFFAFAFFFFFDFFFEFFFFEFF8F7FBFFFCFCF1F7DCCDD4
CBC2C7FFFAFBFBF0ECFFFFF1F4FFE6F2FFDECDD3ADE0D0AF7845309C6C58F4E6CBFFFFEA
FFFFF3FFFFF6F7F7EBF4F5E5FFFFEDE1E1C7C3C4A4A2A381
CAEA95C8EA96C7E897C7E99CC9EBA1CAEBA6C9E9A8C8E8A9D9F8BCE3FFC7DAF8BCD6F4B8
D1EDB0D6F0B1D1EBACBBD596D0EDADCAE7A7D4EEAFD4EDACD3E9A8CEE5A1CDE8A1C0E095
C3E89ABEE594C4EB98CAF29CC4E692C8E392D4E99ADFECA4DADBA170703C949D64D6E8AC
CAE4A5C3E3A2C5E8A6CEF1ADCBEAA7D2EDAAABC18099AE6DCEE3A2D0E7A3D1EAA6C6E19C
C4DE95D6ECA4E2EBAA8A9553C9E39AD1F3A6BBE092D5F1A4DFE4A1625E21B8B580D4DAAC
F8FFE6F7FFF1FDFFFAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEF5F5F5F6F6F6FFFFFFFCFAFDFDFBFEF7F5F8FDFDFF
717173010103868688FEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFEFFFF
FFFFFDFEFDFBFFFEFBFFFEFBFFFEFAF6F1EDFFFDFAB8B0ADBDB8B4FFFEFAFFFEFDF6F5F3
FFFFFFFCFDFFFBFFFFFEFFFFFFFFFFFFFFFFFBFBFBF7F9F6FCFFFBFBFFF6F6FFEADCECC8
CFE6B2CBE5A6C7E59DC9E89ACBEC9BCBEC9BC8EB9BC6E89BC6EB9DC5EC9DC6EB9DC6EB9D
C8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99DC8EA9DC8EA9DC6EB9DC6EB9DC5EC9DC6EB9D
C9E99DC9E99DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9EA9BC9EA99C7E698D7EDA5D2E0A2E8ECBAFFFFDDB3AF92FFFFED
FFFFF45556504F5450F7FDFDFBFFFFF6FAFDFDFEFFFCFFFFFAFFFEFCFFFDFFFDFFF6EBF1
CDC7C9FFF9F9FFF9F3FFFFEFF9FFE6ECFFD6C4D1A3D6CFA37D5232774A2DDDCAA9FFFFDD
F0FFD9F4FFE1F5FFDFF5FFDDF7FFDAE4F9C1D2E6ABA9BD80
C9EB95CAEC98CBEC9DC9EB9EC8EAA0C6EAA4C8E8A7C9E9AAD6F5B9E4FFC6CBE7ACCFE9AC
C6DEA0C6DC9CCEE3A2DAF0AFC6E19EC3DE9BCAE09FCFE4A3C8DB99CFE2A0D4E9A4D0EAA3
CAE89EC2E296C5E599CEEDA1CAE598DEF3A8DFECA4C8D18E8B8F54999E66CFDA9ED4E8A9
C4DE9DD3F2AFCEEEABBEDD9AC8E2A1A3B9789DB172B4C787D8EDACC7DD9CCDE6A4D4EFAA
D4EEA7C5DA95E2EBAA6F7A38D0EAA3C2E498D1F6A8C8E497D4D996534F12B7B47FDEE1B6
F9FFE8F6FFF1FAFAFAFFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFBFCFEFEFFFF
78787A0102047F8082FEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFFFEFFFFFEFFFF
FFFFFFFCFBF9FFFEFBFFFEFBFFFEFAFFFEFAFFFDFAE3DBD8FFFEFAF7F4EFF7F3F2FFFFFD
FBFBFDF3F4F6FCFFFFF8F9FDF8F6F9FFFEFFFFFEFFFDFDFFFAFCFBFBFFF9F9FFEFF1FEE0
E0F3C5D5EDB1CDE8A3CCEB9FCEEFA0CCED9EC6E89BC1E698C6EB9DC5EC9DC6EB9DC6EB9D
C8EA9DC9E99DC9E99DC9E99DCAE99DC9E99DC9E99DC8EA9DC6EB9DC6EB9DC5EC9DC6EB9D
C8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9EA9BC3E790D0F29CC8E094D7E8A4E2EAB1EFF2C5C3C39FFFFFE3
F2F5E0E3EADA677264F0FAEFF9FFFAFAFFFAFAFFF9FCFFFBFCFFFBFDFFFCFFFBFCFFFEFF
FAF8F9C9C4C1FDEBE7FFFDEFF8FFE2DBF0C5DFF6C2C4C798CEAC87C79C7C9E8863F8F7CB
DBF2BAD7F9BCDCFFBFE6FFC5D6F7B2BFDF96CCEAA0C8E79B
C9E996CBEB98CCEB9DCAEA9FC7E6A0C5E5A2C8E6A6C9E7A9E2FEC3F4FFD3D8EDB2D7EBAE
D9E9AADFEEADCCD896D6E5A2D7EAA8D5EAA7CEDE9DE9F5B5D6E0A3E8F2B5D4E0A2CAD89A
D4E7A7D0E5A2D0E5A2C9DC9AD1DD9DE2E8AAC1C1857575396C7536BFCB8BE5F8B6C9E09C
C3E19BD1F0AAC7E4A1C7E29FD5EAA997AA68C8D899D8E8A9D2E5A5C8DE9DC6E19ECBE6A3
DAF3AFC7DC99495213D7E1A2BED891D0F2A6C6EB9DC8E497DADF9C686427A19E6BDEE0B8
F1FEE2F3FFEFFFFFFFFDF8FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7F9F9F9FFFFFFFEFEFEF2F4F3F0F4F5F9FDFEF3F7F8FCFFFF
808183010506767A7BF6FAFBFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFEFFFBFAF8F9F8F4FFFBF8FFFEFAFFFEFAE2DDD9FFFBF7FFFEFAF8F5F0FFFEFDFFFFFD
F8F8FAFEFFFFFBFFFFFEFFFFFEFCFFFFFDFFFFFDFFFFFDFFFFFEFFF7F9F6F9FFF1FBFFEC
E2F3C9D4E9B1C8E1A0C9E49DCCEB9FCBEB9FC8EA9DC6EB9DC6EB9BC5EC9BC6EB9BC6EB9B
C8EB9BC9EA9BCAE99BCAE99BCCE89BCAE99BC9EA9BC8EB9BC6EB9BC6EB9BC5EC9BC6EB9B
C8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC8EB9BBFE58ED1F7A0CCE89BCBE09BE0EBAFD7DEAB8A8C64FFFFE1
FEFFE6FBFFEA6F7D63E5F3DAECFAE1F1FFE6FBFFEDF9FFECFFFFF6FDFEF8F8F9F4FEFFFD
FCFFFDA4A09DC9B4B1FFF5E9FFFFE8DCEEC6CEEAB9DDE9B9C8AE8BFFD7BB5F4224E8E1B7
DBF1B3C3E9A0B7DD94CCF0A6C7EC9EBFE292C9EC9AC8EB97
CAE795CBE898CCE89BCAE89EC8E6A0C8E5A3C8E5A5CBE5A8E5FDC3F4FFCECDDFA3C4D295
D4DE9FDFE8A78D94517D86434E5A18515D1D515A1B8F95599FA368DFE0A7DCDFA8DFE4AC
D1DAA1DBE6AEE3EEB6CAD19BE5E5B1E5DFADB2A67649420CAAB573D3E7A0D3EAA2C3DF95
CFEDA3C8E69CC1DC95E0F7B1B8C9859CAB68EBF7B5E0EFAECADD9BD8EFABD0EBA8BBD993
BFDA9792A7665C6629E2ECAFDAF3AFBEE094C7EC9ECDE99CE6EBA88F894D9F9967E0E1B9
EBF8DCF9FFF6FFFEFFFBF6FDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFFFFFFFEFFFFF9FFFFFBFFFFF5FBFBFCFFFF
7D8182000304767A7BFCFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFEFDFBFFFFFBFDFCF8FFFCF7DAD5D1BCB7B3FFFEFAFBF6F2F8F5F0FFFFFDFBFBF9
FAFAFCFCFFFFF4F8FBFEFFFFFFFDFFFFF9FFFFF7FFFFFCFFFFFDFFFDFDFDFBFEF5FCFFED
E7F6CFD6E8B4CAE0A2C9E49DCBE99FC9E99DC7E99CC9EEA0C6EB9BC5EC9BC6EB9BC8EB9B
C9EA9BCAE99BCCE89BCCE89BCCE89BCCE89BCAE99BC9EA9BC8EB9BC6EB9BC5EC9BC5EC9B
C6EB9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC8EB9BC6EE98CCF49EC4E397E0F7B1BCCA8D9EA77293996BEFF6CC
F8FFDBD4E3BC778963B3C59FE2F4CEE1F3CBE9F8D1E4EECCFFFFEFFFFFF6FBFEF5F9FFFB
F9FFFBE3E2DEC4ACAAFFF2EBFFFFEAE1F2CEB3D3A4D3E6B99A8566FFE0C6997660A59573
C9D89DD0F0A7C2E299CAEA9FC7E79CCFEFA3CEEFA0C2E394
CCE796CCE798CBE699CBE79DCCE7A2CCE6A5CDE5A7CEE3A8E9FDC2F0FFC6E0EBAFDAE2A6
D8DD9DD0D18F6C6B2892934FE9EEAED5DB9FB5B67CAAA77089834F98905F9B9565A09E6D
ABAA7AC0C293D9D8AAB1AE81E1D5ABD5C39BB8A07A615324DCE7A3D5ED9FC5E292C7E696
D2F1A1CDEA9AC6E194CAE09775853E909D58D0DB97C8D492CCE09BD8EFA9CBE9A3AECD87
91AC699BAF70BDC78BDAE6A8C1DA96D6F8AEB7DC8ED7F2A5D6D996A8A266CAC492F4F5CD
F4FEE3F9FFF6FFFEFFFFF8FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9F9F9F9FFFFFFFFFFFFFFFFFFF4F4F4F0F0F0F6F8F7F1F7F7F9FFFFF2FAFCFBFFFF
7D82850001046F7376FCFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F8F8F8FFFFFDFFFFFBFDFCF8F4F1EC9A9792C7C2BEFFFEFAFFFFFAF9F6F1FBFAF8FFFFFD
FDFDFFFBFFFFFCFFFFFEFFFFFFFDFFFFF8FFFEF6FFFFFAFFFFFCFFFFFEFFFDFEF8FBFFEC
EBF7D3DAEAB9CEE4A6CFE8A4CFEAA3C7E79CC5E79BC7EC9EC6EB9BC5EC9BC6EB9BC8EB9B
C9EA9BCAE99BCCE89BCDE89BCDE89BCCE89BCAE99BC9EA9BC8EB9BC6EB9BC5EC9BC5EC9B
C6EB9DC6EB9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DCAE99DC8EA9DCBF2A1C6ED9EBFDD93D5ECA884925798A26DD1D9A8D3DCAD
CCD9ABCBDDAD758B5A90A773D7EEBAD1E5B0CDE0A9D3DEB3FFFFEAFDFBEEF3F9EDF1FFF2
F7FFFBFFFFFAF5DBDCFFE7E3FFFBE8E4F3D4CEF1C7DDF6CEC7B79DFFEEDCFFDDD0614730
9EA071D5E4A9D7E6ABD6E8AACBDD9FD4E8A9D0E6A5CFE5A4
D8E0A4D6E0A1D5E09ED6E0A1D8E1A8D9E2ABD8E1AAD7E0A7E2E9B3ACB17B929462B3B37D
CFCD90C1BD7D514D0DA09F5FD1D598DDE3A7ECEDB4CECD97928F5C646030595727575628
595B2C7475499594686460339F93698D7B539079505D4F1ED2DD98CCE594CDE897CDE899
C9E495D9F1A3CFE59A96A85E909D57C2CD88D7E29ECFDE99E1F5B0C0DA93A6C47C8BAB62
85A35DCCE39FDDEDACD0E09FC6DF9BD5F3ADC4E29ACEE3A0B3B77CADAA77FDF8D0FFFFE4
FCFFF1F6FBF5FBF8FFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8FCFCFCFFFFFFD6D6D69494947474747A7C7B6C706F969C9AB2B6B5E0E4E3
7A7E7D0001006F7170FCFEFDFEFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFBFFFDF6FFFFF8F3F0E9F9F6EF87847DF0EDE8FFFDF8F0EFEBFFFFFBFDFCFAFEFEFE
FFFFFFF8F9FDFCFFFFF7F8FDF9F6FFFFFCFFFFFCFFFFFAFFFEF7FFFFFDFFFFFFFAFDFFF0
DFE8CBD0DFB4C9DEA6CDE7A6CFEAA3C8E79BC7E899CDEE9DC9EA9BC8EA9DC3EC9DC3ED9B
C9EA9BCAE99BCCE89BCCE89BCAE99BCAE99BC9EA9BC6EB9BC3ED9BC3EC9DC9E99DCAE99D
C8EA9DC6EB9DC6EB9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99D
C9E99DCAE99DCAE99DC9E99DC5EA9DC6E89ED8F3AC8EA561627234DEE9AFD4DEA9D8E2AE
D4E2AFD8E9B55B6F3AA2B981C9DEA3C3D99BDDF2B1D1E0A7E9EDC8EFF4D6E6F7D7DEF3D4
E6FADEE4ECD5FFFBEFE9D3C8FFFEEDECF4DDD9F4D5EDFDE2DEC7B9FFD7CFFFF6EC654F3A
97926CD9DCADDEE4B4EBF3C4E7F0C3EBF7C9E3F0C4EDFDD0
654D35867152F6E3B8F7E5B7B39F7AA4926CB2A17358481565572896895FB4A785786F48
57501A5B571AD8D59EDFE0A7D5DFA0D9E5A5D7E3A5D2DBA2D9E2ABECF5C0F6FFCEF4FECC
D6E2B08F99679EA673A0A56F6C6B356A632DA19660DED89CDAE69ED1E699D0E598CDE297
CEE398E2F4AA52621BA8B871CFDE99E8F7B2C6D592E5F9B4C9DE9BC5DE9A8DA863C6E49C
CCECA0BFE091DCF6ACD7EEA6CBE29EC9DF9FCBDDA3D6E2B0949970FBFADBFFFFECFFFDF1
FFFFFDFCFBFFFFFCFFF8F4FFF9F8FDFFFFFFFFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFF4F4F4373737737373828282CBCBCBD5D5D3D5D4CFC8C8C09C9C949B9B93
08080001010034352FFAFBF5FBFCF6FFFFFBF9F9F7FFFFFFFAFAFAFFFFFFF7F6FBFFFFFD
FFFDF4FFFAEBF8F0E3D3CDBFD8D4C9FFFCF3FFFFF8FFFFFAFEFFFDFEFFFFFEFFFFFFFEFF
FFFEFFFFFEFFFFFEFFFEFEFFFCFFFFFCFFFFF9FAFFFFFDFFFFFDFFFFFDFAFFFFF8FBFDF0
E9F1DCD3E2C3C5DAAFC8E4AACDEBA5CAE999C8E990CDEB93D5EBA0D1EFA5BDF19FBDF39F
BCE191D0EFA1C6E796CAED9BC5EB98CAF19EC7EE9DBBE895B9F39EBDEE9DD0E69EDAE9A4
CBE99FC4EA9DC9EFA2C1E699BEE396C5EA9DC9EB9FD3F5A9C3E398C9E99EC9E79DC9E79D
CEECA2D0ECA2CCE89ECDE99FA7C27D88A15D92A96592A661D7E8A4D4E3A2D4E2A5D2DFA7
D1DEA9D2E0AD62733F98A973D1E5AADFF4B3CEE39ECEE39ED1E1A3D5E9ACC5E5A2B9DC98
CEECACEFFFCBEDF2C9D4CDB1DCCFBFFFFEF3EFF7ECFFFFF8E5B8BBFFE3E4FFF7EBDCD1BB
746E4EDDD9B6D7D4B5FBFBDFFFFFEAFEFFEDF4FDEAF9FFF3
E6CCBD967E665D481D6B5629927D5E584324615024B6A675DED1A5EFE3BDFFFFE4FFFBDB
EAEBB2D0D696ECF4B9C3D194CDE6A2CDE8A1CDE3A2CEE0A2DFEAB2F0F9C4F2FAC9E8F2C0
DAE6B4CFDDA8D0DFA8CDDCA1DAE6A8D9E2A1CBD28FE6F0ABCBDD93DBF1A6D0E59ACCE196
D5E9A17A8B44CEDF99EBFAB5D8E9A3C4D58FD2E6A1CCE09BD7ECA9D5ECA893AC68CFEBA1
C9EA99D1F4A0C1E090BDD78DC7DC99EDFFC3CEDAA8D8DFB68E9172EEF0DBFFFFF4FFFEFB
FFFEFFF6F3FEFFFDFFFFFDFFFFFEFFE8E8E8FFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFFFFFF
FFFFFFD2D2D26B6B6B8E8E8EF2F2F2FFFFFFFFFFFFFFFFFDFFFEF7F5F1E8FFFCF3FEFBF2
2A271E0300000D0D05FFFFF7FFFFFAF6F5F0FFFFFDF3F3F1FFFFFFF3F3F5FFFEFFFFFEFD
FFFDF3FFF8EBB2A89CFFFEF3FCF5EBFFFEF7FFFFFAFDFFFAFEFFFFFCFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFDFFFFFEFFF7FCFFFBFFFFFCFFFFFFFFFDFFFEFAFFFBF5FFFFF6FEFFF4
E4EDDCD3E3C9C6DEBAC9E5B4CBE8A6C6E597C5E68BCDEA90CDDF95C1DB94BDF19FC1F8A4
C4E99BD0EC9FC5E494CDEE9DC7ED9AC7EE9BC1E897BAEA96BDF8A4C3F4A3D0DF9CD4DA9A
D3EDA4C0E598C6EB9ED2F7AAD6F8ACC9EB9FBDDD92C2E297D5F3A9C5E399CEEAA0D1EDA3
C0DA91C2DC93D2ECA3CEE8A1859E5CCEE7A3DCF3ADC4DA92D3E7A0CFE39CD9E9AACDDCA1
E3F2BB5B6934273804D8E9B2CBDFA2C0D793CCE69CCEE99CCAE199CEEAA0CAF1A0C2EE99
C7EA9AD3EDA6DDECB5E3E5BECCBFAEF8E9E2FFFFFBFFF5F7B57F8DFFEDF6FFFAEEFFFFEA
A39C82E7DDC2EBE5CDFDFAE7F9FAECF7FAEFF3F9F5F9FFFF
F2F7CFCDD3A5E1E9ADE2EAAFD2D7AEDFE3BEDFE5B7909865DAE3B6CED9B1EFFCDEEEFFD8
CFE8A6C8E497CDEBA1C5EBA0BDF0A1BCEFA0C5E9A1D7ECABF5FAC2FFFFD3FFFFD3F8F4C5
D0D4A2DCEBB4D8F0B4C5E4A1CEEDA7CCECA1BDDC90D6F2A5D3F2A6BFDE92C5E196DDF9AE
C5DF96ABC27ADAF0A8BDD38BD7EBA6D5E9A4D6EAA5C2D691CBDF9A8EA35EB1C683C4DB93
C4E491D2F29DBBD685D8F0A6D9ECAAB3C289858E5F797F59BCBFA2FFFEEAFFFFF4FFFFFA
FFFEFFF6F4F9FFFEFFFDFCFFFFFFFFFFFFFFF2F2F2FEFEFEFEFEFEF9F9F9FFFFFFF8F8F8
B0B0B0111111404040FFFFFFF4F4F4FFFFFFFBFBFBF2F1EFFFFEFBF4F1ECFFFFFAFFFFFA
7D7A750706010100005E5D596B6A66FFFFFDFAF9F7FFFEFFF0EEF1F6F4F7FFFEFFF4F0F1
FFFCFAB0A29FD6CBC7FDF5F2FFFEFBFFFEFDFBF9FAFDFEFFFEFFFFFCFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFBFDFAFCFFFBFEFFF8FFFFF6FFFFF4FFFFF2FBFFF3F9FFF3
EAF7E5E2F4DCDBF4D4DAF7C9D3F0B6C8E6A0C9E694D0EB9AE4F8B0C5DC96C8F1A3C8F3A3
D3EFA4D8EEA3C5DD8FC2DD8ECBEA9ACDEE9DC5E697C5EA9AC5F1A2CAF0A3D2DE9CD8E1A0
C0D78FD0EFA3CEEDA1B9D88CBDD98FD6F2A8D9F3AAC2DC93CFE6A0BBD28CD5ECA6E6FDB7
C5DA95AEC37E97AC67647B35D1ECA7D1EFA7C2DE94C9E399D9F1A7D1E99FC7DC99E1F5B6
B9CD92000F0062773FC8DDA2D8F1B0D4EFA8C3E292D6F2A5CDE7A0C8E6A0C5EE9FC9F4A2
C7E99CC1DC95D0E2A8ECF1C8F6EBD5C7BAB1FEFFFAFFFCFDB17D8AFFE4EFFFFBF3FFFFED
BCB19BA99D85D3CBB6FFFFEDFFFFF3FFFFF6FCFFFDFBFFFF
E9FEC5CAE0A0C6DE94D5EAA5D8EAB8CCDDB1CDDFAFCEE2AFD0E6B7C9DFB8F2FFEAF1FFE1
C0E49CC5ED97BAE490D1FEABBCF09DBDEE9DC5EBA0D6F1ACF0FEC1FFFFD1FFFFCEF1F3C1
E0E8B5C5D49DCAE4A5D1F1AEC3E9A0C1EC9DC1EE9DB5E08ED4F9ABBCDE91D1F1A6D0F0A5
729046DEFAB0C6E097D6EDA5C5DC96CFE49FE5FAB5CEE29D899D58495D18DDF0AECDE39A
D3EF9BC1DD88E5FEADC9DF96E9F9BAD6E3AD5A61358D916EF9FCE1FFFFEFFEFCF0FCFCF4
FFFFFBFEFDFBFFFFFFFAFAFAFAFAFAFFFFFFF7F7F7F8F8F8FFFFFFFFFFFFFCFCFCFFFFFF
000000DADADAF9F9F9FFFFFFFBFBFBFCFCFCFFFFFFFFFFFFF2F1EFF7F6F4FFFEFDEBEAE8
87868408070561605E8D8C8A010000FFFEFFF3F1F2FFFDFEFFFEFFFDFBFEFFFEFFFFFDFF
FFFAFE584C4EFFFBFFFFFCFFFFFDFFEFEDF2F7F6FCFEFFFFFEFFFFFCFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFFFBFCFFF6F6FEEFF8FFF0F6FDEBFFFFEDFFFFEFFBFFF0F9FFF1
FBFFF2F8FFF1F1FFECECFFE2DEFAC7CCEAAAC5E79DCAEA9ED5EFA8C2D993CBE79DC0DC92
CAE097D8EDA2D9EEA3DFF6A8CAE294D2ED9EC9E497CCE89DC3E197CAE49BCEDD9AE2EEAC
D7EDA4D4EEA4D0EAA0D9F3A9D4EBA3C3DA92CDE39BD7EDA5D8ECA7D5E9A4D2E6A1B6CA85
98A965AABB77D0E09FD5EAA5C7E59DBDDD92E0FFB4CAE99BC0DC8FD1EDA2C2DC95C2DB99
E5FDC11C340095AD73C8E2A5CCE9A6D0F0A5CBEC9BC4E594D4EDA9C5E29FBCE599C4F1A0
CAEFA1C7E29BCEE0A4E1E7B9F5EBD0B6AD9EF7FDF1FFFDFBDEACB8F9C3D0FFFBF6F9F7E8
CBC0AC4C3D26918672FEF7E5FFFCF0FFFFF8F2F4EFF8FEFC
D2EBA7F1FFC1CCE893BDD587EFFFCCF7FFDCD7EBB8E2F6C3CFE5B7C8DDB6F4FFEAF2FFE1
C2E49AD4FAA3B6DC87C3E694CCE89BCCE69CC7E59BC7E99FCBEFA9CFF2AECDEDAEC8E4A7
D8EDB4C5D99ECEE2A3D5EEACBEDE95BDE698D0FFAFC5F6A4BCE295C7E99DD1F3A9C9E9A0
8DAD64CBE9A1C7E59DC5E099CEE8A1D9F0AA93A8636A7E39CDE19CCDDE9ABFD08CD7E8A1
C9E18DDCF49EC4D98ACDDE98445217899361E6ECC6F6F9DCFFFFEDFFFFF3F4F4EAF7F7EF
FFFFF8FFFFF8FFFFF8FEFFF9FCFCFAFFFFFFFFFFFFFFFFFFE9E9E9F9F9F9FFFFFF020202
949494FEFEFEF5F5F5FFFFFFFFFFFFF4F4F4FFFFFFFAFAFAFFFFFFFFFFFFF2F0F3FFFFFF
7E7E802D2D2F888689DFDDDEC6C4C7040203FFFCFDFFFEFFFFFEFFFFFEFFE5E1E2FFFEFF
9F969BFFFAFFFFFBFFE0D9E1F9F3FDFFFDFFFBFAFFFEFEFFFEFEFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFDFFFFFBFEFFF8F7FFF1DEF2D7DCF0D4DBE8CEF5F3DCFFFFECFDFFEBFFFFEF
FFFEF0FFFFF1F5FFEDF0FFE8DEFBCDC8EBB1B8E7A1BBE99EB8D992D5ECA6E0EFAAD9E4A0
D2E29BD1E198CADA91C9D990D5E79DDBEDA3CDDE97DBECA5D7E29EDCE7A3C9DA96D3E8A3
C3D990CFE59AC6DC91CEE499D2E69ECFE39BDAEEA7CEE29BC6D793C5D69296A665728241
97A665C8D796D1DFA1C8DB99D8F8ADB1D688CBEE9EC3E495C9EA9BD6F5A9D6F1AC617B3A
000E00ACC88EC1DDA3CEECAEC2E19DCBEDA1C3E996C9EC9CCFEAA7C7E4A2BDE79DC0EC9D
C9EEA0CCEAA0CFE3A4D4DCA9C5BF9DC1BBA3FBFFF1E9E5DCDCADB7FECCD8FFF5F4FFFFF4
FFFDEC594834A19483FFFEEFFFFEF4FFFFF8FFFFFBFCFFFD
D6F2A8C2DF8FC3E086D8F4A0D0E6A8DFF3BEDBF0B7C9DEA6D5E9B8CBE0B5F3FFE6EEFFD9
C0DE96DBFDA7CAEB9AD4F1A1D1E69BD2E49ACBE59BC6E69BC2E89FC0EAA2C0E9A5C3E8A5
BFDF9ED0EDADCCE2A1CCE39FCFE9A2CCE89EC9E99DB8D88CD4EFA8B5CF8895AE6A9DB770
A3BD76CBE69FCBE69FD1ECA5D0EAA3C9E09A98AF69A8BD78C5D994D4E8A3E3F4B0D1E399
D5E896CADD8B9DAD62778645E7F1BCCDD4AAFFFFE6F4F6E1FCFDEFFEFEF4FFFFFAFFFFFA
FFFFF8FCFEF3FEFFF3FFFFF6FFFFFBF7F7F7FFFFFFF8F8F8FFFFFFFFFFFF313131CDCDCD
FAFAFAFFFFFFFFFFFFFFFFFFF1F1F1FFFFFFF4F4F4FFFFFFFFFFFFF1F1F3FAF9FEFFFFFF
F5F4F9EFEFF1F3F1F4FFFEFFF6F4F53C3A3B676362FFFEFDFFFEFBECE8E5E5E1DED2CECB
D8D2D2FFFDFFEFEAEEFFFDFFF9F6FDF9F8FEFEFEFFFEFEFFFEFEFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFDFFFFFBFEFFF6F4FFECD3E8C9D4E5C5CAD7B9E0E6CAFFFFE7F9F7E2FFFFED
FEFCEDFFFFEFFBFFEDEEFFE1DAF7CBC7EEB5BAECA7BCEBA3CEF6AFD6EFAB878C4C818141
8F9A559BAC6598A85F96A65D919E568F9C5479864097A15C9D9C5CA2A4656F864268863E
94AC62D6EBA0D9EEA3CDE297D3E79FD7EBA3B2C37D4C5D1742530FA5B672CFDE9DC6D594
D8E6A8DFEDAFD5E3A5DDF0B0CFEFA6C7EC9FC4E699D5F5A9CCECA0A8C67ED5F0AD294306
415A21DAF5C0C1DCA7D1EEB4CAE8A8C6E7A0C6EB9BD4F6A9C5E09DCBE8A6C8F2A8C2EE9F
C2E99AC7E79BCFE6A0D5E0A6E8E5BAA29F7EFBFFEAFFFEEFAE8186FFE2ECFFF7F7FFFFF6
FFFDED5E4D3BB5A596FFFDF1F9F0E7FDFAF3FCFBF7F6F8F5
C7E59FD5F1A6D0ED93D7F39ECDE4A0D7EDAFCFE4A1D5EAA7CDE1A4CEE0AEF8FFE3F7FFDD
C9E29EC9E598BFDB91C1DC95CEE99CCFE79BD0E69DD1E79FD3E8A3D1EAA6D0EDAAD0F0AD
CDF2ADC0E8A2BEDF9AD9F4AFE0EFACD5DA98CFCB8BA49E60ADAE729BA163B1B97DCED899
C8D796E6F6B5C5DA97DCF3AFD2E9A3C6DD978DA45CD2E9A1D3E9A1C5DB93E1F5AEC1D68B
CEDF8FB5C6784C5914A4AF75D5DDAEDBE1BFFFFFEDFFFFF4FFFEF9FFFEFCFFFFFDFFFFFB
FFFFFAFEFFF5FEFFF3FEFFF5FBFCF7FFFFFFEFEFEFFFFFFFFCFCFCE7E7E7181818D8D8D8
FFFFFFFFFFFFE4E4E4FFFFFFFFFFFFFFFFFFFFFFFFF0F0F0FEFFFFF5F7F6FFFFFFE7E7E7
FFFFFFFFFFFFFFFEFFF3F1F2FFFEFD9E9A970A0702F7F4EDFFFEF5CDC9BED6D2C7FEFCF0
FDFDF1FBFBF1FFFFF8FFFFFAFFFFFBFEFFFFF5F6F8FEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFBFEFFF6F9FFEFE0EDD1EDEDD3D1D7BBC5DFBAE1F7D3EFE7D2FFFFEC
F4FFEDEEFFEAF6F8E2EBEECFD0F0BFC3EFB2C4EDA9C4ECA5B6DE95CAE39F605E21A49E60
DAE5A0D5E9A1ADBF7596A85E8F9F56919E567A87419EA360A1975AA4A2656A8842679044
84A055889E536A80357F954A93A96094AA61A8BC7592A66196A967CBDE9CDEEEAFCFDFA0
D1E1A3D2E2A4CDDD9FD1E5A6BCDA94D7F7AEC4E49BC5E39BDAF5B0DFFAB7CBE3A7001100
5B7142C2D8AAE1F7C9B3CB9BD2EEB4DCFABAB6D68DC9E9A0C7E29FCAE9A5C7F1A5C3F09F
C1E897C4E594CEE69AD8E7A4E0E0AA87885CEAF8D4FFFFEAA9807EFFDFE4FFFCFAF5F6EE
FFF1E4624F41BDAB9FFFFCF3FFFCF6FFFEFAFFFEFBFEFEFC
C8EBABC7E8A1BDDF88CCEF95BFDD93CFEAA3CBE697D1EC9BD1EBA1C1D99BDFF5C7E7FFCF
CBE6A3C7E59DCEEBABD0EDADCFEBA1CBE898CCE498CDE59BD0E69ED0E5A0CEE3A0CEE3A2
D3E5A7ADBD7EC7D194CED295635D23514209C4AF76EAD39DF2DCAAE4D2A0EEE1ADE4DDA6
E3E1A8D3D79AE2ECADC8D796CBDF9A90A76193AA62CDE79ECEE89FD2ECA2C3DD93D7EDA2
DBEBA0828F49E1EBAED9E2ADDBE1BBCFD3B8FFFFF3F9FAF5FFFEFFF6F5FAFCFBFFFCFCFC
FCFDF8FFFFF8FFFFF6FDFFF4FFFFFDFCFCFCFFFFFFFFFFFF7474740A0A0AC4C4C4FFFFFF
FFFFFFF1F1F1FFFFFFFBFBFBFFFFFFF9F9F9F4F4F4FFFFFFF4F6F3FEFFFDFDFDFBFFFFFD
FFFFFDF2F2F0FFFFFDFFFFFBFCF8F5FFFFF8737067030100B5B2A3E4E1D0FFFEEBFFFFEC
FFFFE8FEFFE8FCFFECF3FBE6FCFFF3FEFFF6F4F6F1FEFFFDFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFAFFFFF1F9F8E4FFFEEADEE1C6B8DBB3C9ECC4DDDDC3FEFFE8
EAFFEAE5FFE5EEEED2E2DFBEC8E3AEC3E7A7CBE6A1CAE59EC4E8A0DCF5B1544E14A9A065
D9E6A1CEE89EC2DA90D6ECA1D1E399DCECA3CAD791E9EEACDED298E2E0A3B5DB92C7F8A9
C8E89CD8F0A4C2DA90D6EEA4D5EDA3C1D890D8EFA9CFE6A0CFE4A1D0E5A2D2E7A6D1E6A5
CEE2A3D2E8A8D4E8ABCAE0A0D3EDACC6E3A0D3EEABCCE5A4C7DD9DCEE3A8A1B37F718255
D3E3BECDDDB9DDEDC9F7FFE1E2F8C9F2FFD2DCF6B7C7E29FD4EDABC6E59FBBE697C0ED9A
C6ED9AC8EA96CFE897D9E9A066672B9FA26DDAECBCDEE2C1CEA89FFCD2D3FFFEF8FFFFF8
FFFCF1624E43A8968CFFF6EDFFFCF6FFF7F4FFFEFBFFFFFD
C0EBB5C3F0AFB6E38ECCFB9FC5F09ECBF5A1BCE585CBF392C7EE93CEF3A6BEDFA6CBEEB8
C7ECA9C7EEABB8DDA7D0F1BAC9E49DC9E696CBEC9DC4E99BCEF3A6D9F7AFD0DF9ED8D399
67501E7751247C4B2267360B875E30927440EDDAA2EFDAA5FCD5AA70431C6D461D715224
4D3706DBD09AE0DEA5DFE5A7BECD8ABACF8ABBD58CC2DE94CAE99DCEED9FCCEB9DCAE49A
D0E19B9AA465D5E0A8DCE5B6FEFFE4FDFFECF9FCF3FCFEFDFFFEFFFAFAFFFEFEFFFEFFFF
FDFDFFFFFFFDF8F9F3FFFFFAFFFFFDFFFFFFFFFFFFF8F8F8636363363636F7F7F7FFFFFF
FBFBFBFDFDFDFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFEFEFCFFFFFAF9FAF2FFFFF8FDFEF6
FFFFFAF7F6F1FFFFFAFEFEF6FFFFF7FFFFF454524352513F060500E5E5CDE9E9CFD6DAB7
DCE8BAC7D8A4CDDAACE1EDC5D2DDBDDFE7CFFCFFF3F7FDF1FEFFFBFEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFDFDFFFAF6FFFBF1FFFCEDD0D2BACEEEC9C2E8BFC7DFBBF1FFE6
E1FFE0E7FFE0EBF5D0CCCFA4D9E8AFD2E2A1D3DD96DFECA4D1ECA5D8EDAAE3DDA3979155
DBEFA8CFEFA3C3E296CDE99ECDE59BD0E49CD9EAA4DDE6A3DCD69AD4D89BC1ECA4BBF1A3
C6EB9ED8F4A9BDD98FD4F0A6CFEBA1CDE8A1BFDA93D6F1AACAE5A0CCE7A2C7E29FCEE9A6
D2ECABC0DD9BC6E09FD2ECAD587032061B00000D00000D004E5F29000A00303B118F9976
D3DCC1DDE7CEE7F1D8F5FFE4F5FFDEF7FFDACFE4ACCEE4A6CBE29CC7E69AC5EF9DC0ED98
C8F09AC9EB97D3EC9B8D9B50666926D0D499CFE2ABEFF4CCA37E6EFFDDD7FCF5EDFEFFF6
FFFCF3523E37BFACA5FFFAF3FFFCF6FFFBF9FFFEFBF4F0EF
C6F0C2BAE6ABC3EFA0B9E78DCAF4A2BFE993CCF491C5EE86C2E787C4EA97C2E4A8CDF0BA
BCE0A0C5ECADDDFFD3D1F3C1C0DD9AD4F3A5CEF3A3C0E798AFD487C5DF96DEE4A6B5A46E
6E4318783A157F36158D44236F310C79461BAE8A5AF7D1A4AF72537734177B3E1F5E2C07
5A350BA18959A2966293925976804198AC67C3DD94D7F6AAD0F1A2C4E797C4E797CCEB9F
B4C581BEC98DCBD5A1D5E0B5F8FFE2FAFFEDFCFFFAFCFFFFF7FAFFF3F6FFF9F9FFFAFAFF
FFFEFFFFFFFFFFFFFDFFFFFBF6F6F6F9F9F9E7E7E7949494737373FFFFFFF9F9F9FFFFFF
FFFFFFFAFAFAFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDF9FAF5F8F8EEFFFFF4F2F2E6FDFDF3
FFFFF6FFFFF8FBFBF3FFFFF6C6C6BAB4B5A7FBFCEAFFFFEC8D8D75797C5FC8CBACDDE6BB
D0E2A4CEE59FCEE2A3CEDFA9CDDDB0E2EECAFCFFECFCFFF3FEFFF8FEFFFDFFFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFDFFFFFBF8FFF1E9FFFFEFD7DDC3CDE7C2B7D6ADD3ECC4EDFFD9
F4FFE1F8FFDFF3F4CCE6E4B4DAE0A4DDE8A3D0DB8DD2E091C5DB93CFDD9F625C22ACAA6F
C7DE98BCE295CDF4A5CDEFA2C9E89CC9E399CAE098D1E09DDEDFA3DAE6A6C1F1A7B7F0A1
CCF2A7B8D68ECBE9A1D4F2AABEDC94D3F1A9D4F2ACBBDA94D3F1ABCEEDA7C7E6A2D6F5B1
BFDE9A9DBE796A89464F6C2A42571C5D6E3783945D93A16CE0ECBCCED6ADD4DBB9E0E6CC
E8EBD8F1F5E4F8FCEBFCFFEDFAFFE5F9FFDFD2E2B1D2E6ABD8EEA6D2EF9FC9F39FBEE997
C1E696C2E193D0E79995A25AC4C583FCFFC3C8DCA1E8EEC2EFCAB7FFDFD7FFFEF4FEFFF6
FFFCF48C77727E6B65FFEFEBFFFBF8FFF6F4EDE5E3FFFDFD
D7F3CDD4F2C0D3F2ACD8F9A8BBD78CC7E494D0EB8CD3EF8BD5F093DFF7A9D1E6AECCE2B3
D3EBB1C7E0A9E9FFD8F1FFDFD2F5B1C8ED9FB8D88CD9F5AAE0F4ADE4EDAACAC48A3D2800
6C4619804C24C48562FFC1A0B66D4D74290A8B4021FFC7AB87301CBB6451FDB19AC7866A
7F4D2A634016C5B381E7E2AAD0D99AD1E5A0D2EEA4CCECA0C2E797C0E693C6EC99D2F3A4
8BA05DDAE8ADCAD7A2DDEABEFBFFE6F8FFECFBFFF6FAFFFCFBFFFFFBFFFFFBFEFFFEFEFF
FFFEFFFCFBFFFFFEFFF9F7F8FBFBFBFFFFFF636363000000FFFFFFF8F8F8FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFBF7F5E9FFFFF1FFFFF3F4F2E6
FFFFF6FBF8EFF1F1E7AEAEA4F2F2E6E8E9DBFFFFEFFFFFECFFFFE8686D4DD0D6B4D7E3B3
C9E197D2EF9DD3EDA3C5DB9AD1E4ADEBFACFF6FFE1FCFFEFFEFFF6FFFFFBFFFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFEFFFFFCFFF8F2FBE8FBFFEDDAE7C9C7D9B3C9D5AFFBF8D5FFFBD9
FFF3D2FFF0CEFAE0BBEAD8A8DCDE9FD2E596CDEB91D2F098E1EEA9E1E2A8534E14DCE0A3
CBE69FBBE697CAF7A6BCE797CCEEA1CEEDA1CAE49BCADF9AD8E4A4CFE6A2B6E69CB3E99D
C6ECA3C8E6A0DAF9B3C4E39DC5E49ECFEEA8CAE9A5CDEEA7C0DF99C9EAA3B8D992C6E7A0
D1F2AB022600D2F3AED2F1AEC9DDA2D6E4AFD0DDA8CFD9A7D5DEB1D5DBB5CFD4B6D7DAC5
F7F8EAFEFFF5FFFFF4FEFFF1FCFFE8FAFFE1D2DFB3D3E5ABCBDF97C5E08FC5EC9BBCE596
C7E99FCCE7A0DAEFAAAFBB79E8E8ACDDDEA4CEE1A9E5EBBFA98471FCD4CCFBF4EAFEFFF8
FFFCF6FBE9E5B3A19DAD9E9BFFFBF8FFFCFAFFFDFBFFFDFB
E6F4D1C8D8ABC9D998E0F2A8D3E2A1DDEAA5DEEB9BCEDC87D0DD8EC2CD8BF1F8CCE1E9C0
CBD8A3E6F3BEFAFFDEB2C19687A05F84A055839F5494AE657B924A81904DBCC083B5AA72
F7DBABEFC299FEC29EFFD0B2EB9A7F8E361E852A15BD5E4C973528BD5D4FFFBDACFFD1B9
BD86676C461FE0CB9CC8C38BE9F2B3D7EBA4C8E49AC4E797C9EE9ECCF3A0C7EF99C4E596
93AA64D1E3A7D1E2ABDBEBBCF1FFDAEBFADDF8FFF1F0FCEEF0FBF3F9FFFFF7FCFFFCFFFF
FEFFFFFDFCFFFFFEFFFEFCFFFFFFFFB5B5B52424249B9B9BFFFFFFF2F2F2FFFFFFF8F8F8
F6F6F6FFFFFFFBFBFBFFFFFFF7F7F7F8F8F8FFFFFFFFFFFBFFFFF4F6F0E2FFFFF3FFFFF4
CDC9C0030000030000D9D9D1F9F9F1FFFFF4EBEEDDF2F7E1EDF3D9777E5F8289688B9B6A
CCE89BCAEB94D4F0A3C8E19DD1E6ADEEFDD2F4FFDFFCFFEFFFFFF6FFFFFBFFFFFFFFFFFF
FFFEFFFFFEFFFFFEFFF9FFFDEEFFF3E4FFE3F5FFE8D3E3BEC3DAACE7ECC3DCB79ACF9C81
CEA587D2A787C68D6FB58A60E1E1A1CBEB98C7F495CCEF95BBBB7BA1945FA39E66D9E3A4
CDEDA4C9F3A7C2F1A1BAE998BEE596CDEDA2CFEAA3CDE7A0D3ECA8CCEBA5C0EEA5CBFBB1
C3E3A0D3EDACCBE8A6C0DD9BCCE9A7CFECA9C5E4A0C4E39FD6F5AFD2F3AC95B66F2A4B04
001A00B5D78DCBEDA3BDDC98D2E6A9D3E2ABE3F0BBFCFFD6FEFFDAFEFFDFF6FBDDFDFFEB
FAFCEFFEFFF5FDFFF4FEFFF1FBFFE7FAFFE1D0DDB1D0DFA6D6E7A0CCE496CFF1A5C5EBA2
D0EEAECCE4A8CBDCA5A8B17CDDDAA7D2D2A0D1E2AEE2E7BFAA8374FFF3EDFFFEF6F6FBF4
FFFDF8FFFBF8E6D7D4786A67E2D7D5FBF0EEFFFCFBFFF8F6
D5D6AEA0A271C7C9889192509F9E68716E3BD3D196EEEAADE8E3ABC7C396DDD6B9B5B092
B0B07EA2A26C939566B7B686EBE9B0D6DB99CDE19ACFF1A7C7F3A6BDE99CC2E39CD8E7A6
DECE9AFFD8AEC18060994930822C157E2610C16A56CD7462923226AA4A3EC26C5BCA846B
834E2E613E16F7E5B5ECEAB1C5CF90C6DC94CBE79DCBEE9EC7EC9CC5EB98C5EB96CAEB9A
C1DB92AFC483D2E8AAC7DCA4D0E6B5D7ECC1F5FFE6F5FFEDF4FFF0F8FFF8FBFFFBFAFFFB
FAFCFBFDFDFFFFFEFFFFFEFFFFFFFF343434FDFDFDF4F4F4EEEEEEFFFFFFFAFAFAFFFFFF
F3F3F3FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF9F8F4D8D1C7AEA69BA79E97B5AEA8
453D3A100B080F0B0AFCFBF7F7F6F2FFFFFAFEFFF6F9FFF0EEF6E1BCC6AD0006007E8F63
D2F0A8C3E692CBEBA0CCE6A5CAE1ABE3F3CCF7FFE6F5FCEAFFFFF8FFFFFDFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFF5FFFAE0FFECC5F7C4D6E5BAD1DDAFC6EEB2EEF6C3903E29842011
C69877C59776902F1E843419CBD090CDFFAAB6ED8FC4E48F9F8C546B4B1CE6DFA8C6D594
C9E9A0C7F1A5B9E898C1F0A0C1E79AC9E99ECAE59EC8E39CC3E79FBDE59EBCE49EC2E5A1
D2ECADCEE4A6CCE4A6DCF4B6C2DA9CD1EAA9CAE4A36A854292B06A32500A3D5B13AACA81
CEEEA5CDEDA2BCDC91D4F2AAD8EEADD2E4A8D8EAB0DAE9B2E6F2C2F9FFDAFEFFE4FEFFEC
FEFFF1FCFFF3F8FFEFFBFFEFFBFFE8F9FFDFD1E1B0CCDEA2D8E7A2C9DF96CFEEAAC7E9AC
DBF6C3D8EBBECFDBB3B9BD988C8460F4F0CAF2FED6EAEBCBEDC5BDE9BDBEFFFCFBFCFFFD
FEF6F3FFFBFAFFF2F1958A88807573FFFCFAFFFCFBFFFBFA
CACA98AFB077D0D18D8D8D4D7773463F3A14A19A70D7D0A6DDD5B0958E71D5CDBAFFFCE2
FFFFCEF8FDBDDCDFA6D6D79DDEDC9FDCE19FD6EDA7C0E69BBCF1A1C3F8A8BDE59CD5E8A8
E4D8A4F9D2A9803F217C2E177929128C3E28B56D55AB604B7F251ABC6055AA5948925038
77462676562DD9CB9AD4D59BDBEAA9DAF1ABD6F5A9CCEF9FC0E391BEE18DC7EB94D3F3A0
D6F2A787A15AD2EBA9C8E2A3C6DFA5CEE9B4EFFFD8ECFFDBF5FFEAF4FFECF9FFF4F9FFF5
FDFFFAFFFEFFFEF9FDFBF6FA7B797AB7B7B7FFFFFFFFFFFFFFFFFFE9E9E9FFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFF0F0F0F3F3F3CECAC7C5BCB7C1B6B0AEA39FA09695
6B6162080002040002FFFDFFFFFEFFE8EAE9F3F8F2FBFFF8C9D1C2DDE9D53A462E455A33
BDDC99CAEFA2C8E8A5CDE9AFD1E7B9E1F1CDFBFFEDF9FFF1FEFFFAFFFFFDFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFDF5FFF4E2FFE2BBE8ADC6D39EDAE5ADCBF6B1DDE8AC8E3D22B95440
FFD8B6FFDABA9E3629822712ABA66ECCF2A5BCE692DDEDA4B78E60794921F2E9B2D0E3A1
CBE9A3BDE69ABAE999C4F3A3CEF4A7C6E69BCBE59ECEECA4C3EEA6C6F4ABD1F1AEC9E1A3
D2E6ABD6E7B0DBEEB6C6DA9FA2B67B8B9F62637939000F00637C3A79924EA3BE77D5F1A7
C7E399C0DC91CDECA0D8F4A9C7E19AC6DD99D7ECABD1E5A8EAFBC5F4FFD5FBFFE3EEF9DB
FBFFEDFAFFF0F3FFE9F9FFECF6FFE2F8FFDDD1E6AED0E4A5D1E09DC1D590CBE9ABC9E7B3
E7FDD6EAF9DAE7F0D5E8E8D0DDD1BBE7E0C6F0F9DAFFFFE8FFDCDBFFE7EEFFFBFFFCFDFF
FFFAFAFFFCFAFFFCFACDC2C0625755FFF7F5FFFCFBFFFCFB
D6E7A3CDDE97CCDD8FD7E6A1D7E0B5C9D0B1B2B799A3A78CB2B69FFEFFF1FCFFF6E8F2D7
C3D599C9E092D0E69BD8EEA3CAE098CEE8A1C8ECA4C1EBA1BDE99EC8F0A7CFE5A4B4B87D
AA9664E0B990BA8261C48468A3664A784025A77658DAA2898132239A4739843B286D3117
906543B79E75F7EFBED7DCA2CCDF9FC9E39CC8E89CCBEE9ECEF19FCDEF9BC9E994C3E390
CDEA9A7D9C50CBE99FD8F6AEC7E4A1CCEAAAD5F1B7D3EEBBD3EAC0CCE0BDF6FFEBF5FEED
FFFFF8FFFFFBDDD9DACDC9CA6D6B6CC0C0C0F1F1F1FFFFFFFFFFFFFDFDFDF4F4F4FFFFFF
FFFFFFFAFAFAF9F9F9F2F2F2FEFEFEBBBBBBD6D6D6C6C2C1FFFCFAF7E9E8FFFBFBFFFBFF
E1D6DC0A00090F0712FFFCFFF4F1FAFEFFFFFCFFFFFBFFFDF9FFFAF0FCEEBECBB95C7150
708F56CEF3B0C7E6ABCBE7B6EBFFDBECFCE1F9FFF3FCFFF8FEFFFDFFFFFFFFFEFFFFFEFF
FFFFFDFFFFFBFFFFFAFCFFEFF1FFD4D2E6A9D0D89CDCE8A8CFEFA6CEDF9BCFA97AFFC9A2
EBC59EF3C5A4AA5944853B22C8AD82D9DAA0D9E2A1C4B87CA2623E773815DBD09ACFE4A1
CAE8A2BEE499CAF6A7C3F2A2C9EFA2BFDD93D5ECA6D6F4ACAEE196B4E79CD5EFAECDDCA1
C9D6A067743F596631202D00606F367584499EB072BED191CADF9ED4E9A6CFE6A0D3EAA2
CEE69CE2FAAECCE79ABAD588D1EDA2C5E197CAE49DCEE7A3E1F7B9DBF0B8E4F5C9E8F8D4
E6F5D8E7F5DCE2F2D7E5F6D6DFF4C9E8FFCBC9E3A6D1EAA8DFEEADD5E5A7E4FFC8DCF7CC
F2FFEAECF9E7E6ECDEF6F4E8FFFAEFA2998AFCFFEDFFFFF1BE9196FFE1EFF8EBF5FEFFFF
FFFDFFF7EDECFFFAF9F7EDECA19796AEA4A3F7EDECFFFCFB
CDE899CFE799D2EA9ECEE2A5F9FFE6F9FFF3FBFFF4F0F8E9FBFFF4F9FFF4BBC8B6D9EDCA
D4EEADC6E595D4F3A3C1E293D1F3A7C6EAA2B8E097D0F8AFC2E7A1C3E29EDEECAE9E9962
59380BAB7551CA806593452E8A442A642B0EB8906DFBCEAF8A3D2DD78076FFEADAFFCCB3
A37655785D32D6CC99DDE3A7D2E5A3CCE89EC7E99CC5EB98C6EC99C8EE9BCAF09BCDF09E
CDEA9A91AD60C3DF94DCF8AEBFDA95C7E4A1C5E1A4CEE7AED1E9B7C4D9AEF8FFE6F4FFE7
FCFFEFF8FCED8A8C8161625CFFFFFFFFFFFFFFFFFFFDFDFFFFFFFFFEFEFFFFFFFFFFFDFF
FFFEFFFCFAFDFFFEFFFFFEFFFFFEFFADABACF1EFF2FFFDFFFFFBFDFFFAFDFEF2F6FFFAFF
E9DEE60900070B010CFBF3FEFFFDFFF8F7FDFEFFFFF1F7F5F9FFFDF1FDF3F5FFF57B8D75
1F380ECAE6B5C2DBB1C7DDB9F7FFEFF7FFF2FBFFF8FAFCF7FFFFFFFFFEFFFFFEFFFFFFFD
FFFFFDFFFFFBFFFFFBFFFFEFFBFFD9E0EBB1CEDA9CCADE99D1EFA5CDE199F9EDB1EAC898
7A50287B4022923B287F311BFFE6C2ECDEAFE5DEA8644A198B452375340EEDE2AACFE49F
CFEFA6C2EB9DCBF6A7B4DD91CDEDA4C2DB97D7EDADBBD9995F904E4C7A3C6D8450667242
D8E6B3000D0051602764763AD5E7A9C4D998CBE09DD6EBA8CDE29FD4EBA5CBE199D0E69D
C9E092D1E898CCE391D8F4A0C6E796CEF1A1C9E99DC7E59BCBE6A1CEE8A9C9E2A9CCE4B2
C7DEB2CBE4BAC9E2B8CBE5B6C5E0ABD2EEB3BFDC9AD2EDA8D1E29CD0E3A1F2FFD2EFFFDC
F4FFEAF8FFF1F3F6EBFFFEF8FFFCF69E978DFCFFF4FDF9EEE7BCC3FFE6F3FFFAFFF6F6F8
F3EFEEFFFEFBFBF3F1FFF7F4C1B7B5A69C9AFFFCFAFFF9F7
C1DE8ADBF7ACC4DCA0C8DAB4F8FFF6F7FFFFFBFFFFFBFFFFFAFFF5E4F0D8D1E1BCCAE1AD
CEE8A7CFEDA5CCEEA4C9EDA5BEE39DCDF2ACC6EAA4C0E19CCFEFACC7E1A0DDEBAE635723
77461E8A361AA53122AB31248E2311802F14AE815AFFD4B295423473120BA24C3FC67E68
965F406D4A20EDDCA6D7D797D3E39CD4F0A3CAEF9FBEEA95BDED99BCEE99B9EA98C2ED9D
CBE79C99AF67849A52D0E5A0D3E8A5D0E6A6D4EAACCCE1A8CFE3AED0E4B3CCDFB2C6D8B0
F7FFE4BDCEAC4E5F3FAEBCA5FEFFFFFCFBFFFFFEFFF8F7FFFFFDFFFDFAFFFFFDFFFBF6FD
FFFDFFFFFCFFFFFCFFFDF6FDDDD3DBDFD6DBFFF6FEFFFBFFFFFBFFFDF2FAFFFBFFFFF7FD
FFF4FC2F242A070002FFFCFFFFFDFFFFFEFFFFFEFFFEFFFFFCFFFDFBFFFDF9FFFDF9FFF8
636F59E5F1D9F8FFF0FBFFF6FCFFFBFEFFFFFBFBFDF9F9FBFBF9FAFFFBFAFFFDFAFFFEFB
FFFEFDFFFEFFFFFDFFFFFFF8F7FFE4C9DDACC2DBA2D6F4B4C4E8A0CEE59FF1E9ABDFBB8B
80462189331C91160F9B2F25FFDAB9DDD6A8B6AE7FAD9265A66B43652F01E8DEA1CEE49B
C1EA9BBEED9DC5EB9ECDEBA5E2F6B7C3D49DD8EFBBC5E2B2022900001900000A00788969
839968DCF4B6C0DB98CCE89ECBEA9CD1F2A1B8D988CDEC9EC9E79DCCE89ECCE69DCCE498
CFE694D2E991D5EA8FCFEA8DC2EA92C5F19CC2E998C6EB9BCDEFA2CDEDA2C3E39AC4E5A0
C2E5A1CAEFACC3E8A5CEF3B0BFE29ECCEBA7C3E19BC9E59BD2E99BCDE496E2FCB5ECFFCB
DCF8C7EAFED9FFFFEDFFFCF0F8F8EEF3F9EFEDF7ECFAF5EFE3BCC1FFDEE5FFF9F6FFFFF8
F5F6F0FFFFFAFFFFFAFFFAF4DFD8D0867B75BBAEA8FFFBF6
C3DF94DDF8B5E7FDCFF7FFEFF6FFFCF2F6FFFCFFFFF1F5F6FCFFF4E8F6D5D2E4B2C8E0A2
C9E3A2C7E6A3C6E6A5C4E7A5CEEDAACAE7A5C8E1A0D9F2B1CBE4A3213700515F22E6DCA7
6F4219802F12952412981E0F801A047C3313A68759F0D5AAD290788C3A2C722B15783C20
7549248A6E3FEEE3ABD7D998D0E099CDE79DC5E59ABFE59AC5EDA4C8F2AAC2EDA6C4E9A3
C1D892A1B26E4D5E1ACBDB9AD1E4A4D3E5A7D0E4A7D2E5ADCFE4ACC3D7A2DAEEBBD7EDBC
ECFFD4CAE1B3D8EFC3E1F2D2F7FCF6FEFDFFFFFEFFFFFEFFFFFDFFFEFBFFFFFEFFFFFDFF
F4EFF5FFFDFFFFFDFFE5DFE39B9297FFFCFFFFFBFFFCF1F7FFFBFFFFF6FFFFFBFFFFFCFF
FBF0F661565A140A0BFEF5F6FFFEFBFFFEFBFFFEFDFFFFFDFEFFFFFCFFFFFBFFFFFBFFFD
797C73050800F7F9F4FBFDFCF7F6FBF6F5FBFFFDFFFFFEFFFFFEFFFFFEFBFFFFFAFFFFFA
FFFEFBFFFEFFFFFCFFFFFFFBF9FFECE1F6CDD4ECBACCE8ADC7E6A3CCE09BE2D89BFDD7A6
C2825EA5422DB12724871008D5AD8AF3ECBE4D3F12F6D7A9C2875D7F4B1BF3E5A8D5E79D
C5EE9FC1EE9DC4E69AC8E19DC4D398D0E1ABCEEAB952764A001B000F361790AD97CCE7C8
C3DFA5D3EFA5D1EDA2CFEE9ECAEC98C7E995D7FAA6C1E494C6E69AC9E99ECCEAA0CCE89D
C9E696CAE691CEE88FCDEB93BDE58FC3EF9AC5EC99C2E895C5E697C2E394C2E394CBEE9E
C2E99ABFE899C2EB9DC3E99CC9EDA3CCECA3D2EDA6D2ECA2D4ED9CD4ED9CD0EAA0BED996
B5D499DDF4C6FFFFE6FFFBE8FCFFF1F8FFF4F8FFF6FFFFF6FCD8D8FFF4F3FFF9EEF4F5E7
FEFFF8F7FAF3FFFFFAFFFFF8FFFAF391847C54433BFFFAF3
D3EAB2CDE3B2F5FFE6E7F4E3F8FEFEFCFFFFF2F6F7FCFFF8F7FFE7E4F1C6D2E3ACCEE4A4
D0EAA9CFEDAFCBEAB1C9E6ACD2E4A8D9E5A7D2DC9FD4DEA16D7B3DAFBF80D3E3A4D7DBA0
E4CE9CC5966CB46E4CCB8060EDB38DF3D7A7D9E3A6D0DB9FE6CDA4C7A17CB1916AAB9468
B2A571CFCD94E7EDB1CDDC9BD0E3A3CEE4A4CEE4A6D4E9B0E2F4C0EAFCCCE3F3C6D8E8B7
E2F4B6BCCF8DD0E3A1677A38D7EAAAC6D89AD6EAADCFE2AAC3D69FF0FFCF839764000E00
B0C493F1FFD8F5FFDDF8FFE4FCFFF6FEFFFFFBFDFCFBFDFCFBFBF9FDFDFBFBFBF9FCFBF7
FFFFFBF6F2EFE8E4E1AAA7A2D7D4CFFFFFFAFDF8F4FFFEFBFDF7F9FFFDFFF4EEF2FFFDFF
FFFCFF52494A060000FFF6F7FFFDFDFFFEFDFFFEFDFFFFFDFEFFFFFCFFFFFBFFFFFBFFFF
F7F9F4676863C2C2C2FFFEFFFFFEFFFFFEFFFFFEFFFBFAFFFEFEFCFFFEF9FFFFF6FFFFF6
FFFFF8FFFEFAFEFCFDFCFDF7FCFFECFBFFE2EFFACFD4E1ACD6E6A8BEC484938046B38957
FFC198FFC0A6BA382B9D2C1CE0B48DE9DCA8583E0DA77D4D8F4C226A2D00DFC98FD1D894
C8E79BC2E99AC8E89DD1EBA4D1E5A6D7EFB583A9705C8B579CD0A052875D4E7B5AC3EABD
CAE89ECFE791C0D884D7F09FC4DC90C5DF95CEEAA0D4F2A8D3F3AAC8EAA0BFE399C1E79C
C9EFA6C9F1A8C2EAA3B9E198CBF2A3CFF2A0CAEB9AC6E393D1EC9FCEE99CCDE89BD0EC9F
D6F6AACAEC9FCEF0A3BEDE92CEECA2C5DF96D2E9A1CCE299CDE496C7DF91C9E39AD3EEAB
D6F5B9DCF4C2EFF0CEF5F4D8E6F0D5BFCFB5E6F8E0EAEDDA997B73E5C3BAFFF3E3FFFFF1
FAFDF6F5F7F4FFFFFBFFFEFAFFFCF6D6C8BF67534ADBC4BC
F5FFE2E1F2D2F8FFF3F9FFFBF5F9FCFEFFFFFEFFFBEFF3E4FDFFE3EAF8C7DFF1B5E6FCBB
F2FFCDF1FFD3EBFFD5E4FFCAD9E7ACD4DA9CDADBA194985BB6BE82DAE9A8DDF2B1D7E7A6
CFD096E4D7A0FBDCADFBDDABE7D6A2CED798BEE69FC8F0A9DCE6AAE7E4ADE2E3AADBE1A5
DBE7A9F1FFC2D1E7A6D4EDACCFE7ABD2E7AFDDEFBDEDFACFFAFFDEFFFFE6FDFBE4EBECCC
DFECB6D7EAA8D1E4A4C3D6966A7C3E809254D3E7AA96AA6F4F622A000C004C5E2A8B9D69
D7E9B7CFE1AFD9EBBBEEFDD6FCFFEFFDFFF5FEFFF6FEFFF6FEFFF4FEFFF4FEFFF4FEFFF4
F2F4E6FFFFF3D6D8CAE7E9DBFAFDECFFFFF1F4F7E6FFFFF4FDFCF7FFFEFDF2EEEDFFFBFB
FFFEFB605856080000FFFDFDFFFDFDFFFEFDFFFFFDFFFFFDFEFFFFFCFFFFFBFFFFFCFFFF
FAFCFB0000005E5D62FFFEFFFFFEFFFFFEFFFAF9FFFEFFFFFDFFF9FCFFF4FCFFF1FDFFF2
FEFFF4FEFFF6FEFFFAFCFFF6FAFFE8EEF8D3F1F7CBD9DDAADEE6AABCBC7C614E13613E08
7B45179749258C1E07812108CDA979E2D39A775A225E2E008340167D4216F0D79FE5EAA7
D5F1A6C0E597C3E398CDE8A1D1E8A4CEEBAB001F0066985DACE5AE7DB7852A5F334E7E4A
C2ECA2CDF39ED2F5A5C1E094D3EFA5CCE69FD5ECA8C6DC9BC9DF9ECCE6A5CFECAAC9ECA8
BEE6A0B7E29BBCEAA2CAF4AAC2E296CBE697D2EA9CCBE294D9EEA3CBE095C9DE93C8DE93
C7E197C8E298D3EDA3CEE89EDAF2A8D0E69DD2E69FCADE96CFE59ADAF2A8D4EBA3C1DE9B
C3E3A2CDE6ADD3D9ADD0D2ABD8E4BEAFC49DD2E8C4EEF5D6BBA28EE9CCBAD1CBB1FEFFEC
F3F6EDFEFFFDFFFFFBFFFEF8FFF9F0FFFBF1E8D2C58B7466
F4FFEFF9FFF6EFF5F1F8FCFDFBFCFFFFFFFFFFFFF8FCFFEAFEFFDFE9F6C1DBEBADE1F6B5
EFFFCAF1FFD6E8FFD5DFF9C9BFCE93EAF0B0EBECB0505515DEE7A8CDDE9AB0CB86CBEBA2
D5EEAAD5E9A4D6DFA0D3DE9CD2E5A3CCF0A6BAF5A5B3EE9CC6E89ECDE49EC4DF98CAE8A0
D9F9B0F0FFCABADD99CDEDAEC8E5ABD1E9B7EAFAD3FCFFE8FFFFEDFFFEF3FFFBF5F1EAD8
DFEBBBCBE09FCADE9FDEF2B3C4D8993B4F105F7135314309485A20263700A8B982D2E3AC
C8D9A3D2E3ADDBECB6EEFBCFF6FFE0F7FFE8FCFFECF7FFE7FCFFECE9F1D9F9FFE7F8FFE6
FCFFEADBE4C9BFCAACFBFFE8F6FFE3FBFFE8FBFFE8EBF3DBFFFFF3F1F1E9FFFFF8FFFFF8
DEDBD6B1ACA8040000FFFEFBFFFDFDFFFEFDFFFEFFFFFFFFFEFFFFFCFFFFFBFFFFFCFFFF
FDFDFF716F743D3C42E4E3EBF0F0FAFEFEFFF3F4F8F2F7F3FCFFF6FCFFF1F8FFEAF7FFE8
F7FFEBF9FFEFF8FFF0F7FFEDF2FFE1D1E0B7E0E6B8D5DAA4DBE1A3D9DC999E9554937E3F
593400652F00A65832CB8A60F0DDA2D4CF8DA58C4CAD824B814B1D845527D3C388CED794
CDE99EC1E698CBEB9FD3F1A7BFD992C8E5A2153C00D4FFC2BEF2B4BCF2B8A6D8A3002E00
AEEDB49FE1A3AFEAA6D6FFC1AED68FCAE8A2D3E8A7D8E6ABE3EBB8D5DFADCCD8A6CEE1A9
D1EEABCCF1A1C3EE94C3EA8FD3EC9BDAECA2DFEFA6C9D990D6E39BC7D78ED8E89FE2F4AA
DCEEA4ADC27793A85DB7CC81C8DA90CCDE94CCDD96E5F6AFD2E69FCAE199C8DF99CFEDA7
D2F2AFC4E1A1CCD5A0DEE5B2C5D6A27A925EB9D5A4E7F4C8826F4FD1B99DE5E7C2FBFFE6
FBFFF4FAFFF8F6F7EFFFFFF6FCF2E6FFF9EAFFF7E6664D39
191E183F4440FCFFFFF7F8FDFFFEFFEFEDF0F3F3EBFFFFEDFFFFE1E5F1BFCFDEA3CADE9F
D0EAADD1EEB4CBE9B7C5E2ACE2F8B8C1D28CC6D18F5D6824D5E4A1D9EFA7C8EAA0CAF3A5
C3ECA0C3EC9EC6E89EC2E498BFE59ABDEC9CB8F3A1B9F39FBFE899C4E797C2E799CEF5A6
D5FEB0E2FFBFB5DE98C6EDACC7E8AFD0ECBCF0FFDFF9FFECFEFFF2FFFEF8FFFCFDF1EDE1
DAE7B9CBE1A1E8FCBDBDD192687C3D364A0B54662A54662AC2D498DBEDB1E3F2B7DCEBB0
C9D89FD2E1A8D1E0A7D1DDABEEF9D1E5EFCCEBF5D2E1EDC7F3FFD9E8F4CEECF8D2DFEEC5
C9D8AF909F76B3C49ADAEBBFEDFED2DBECC0E3F4C8EEFCD8E9F1D9FEFFF1FDFFF1F2F2E6
FFFFF6514E47030000EDE9E6FFFEFDFFFEFDFFFEFFFFFFFFFFFFFFFEFFFFFCFFFFFCFFFF
FAF9FEF9F7FC78757E000007FEFEFFFEFFFFF7FBFAFBFFF8FAFFF0F1FEE2E9F7D6E4F4CF
E3F4D0E4F5D3E3F4D4DFF5D1DFFCD0C0DBA8D8E6B1D8E2A6D0DD98E2EEA4DAE096D4D48C
C6BB7BB29960FDD5A2EFD09ADFE29FE3EBA2766422F0D296F7D6A1E0C995EBEBADCFE39C
CDF2A5C2EB9CC4E99BC2E296D6F2A8CCE7A06B8A4685AA67ADD495CDF5B7BFE5AA69965F
0020007ABA86B4F0BAA8DFA6C1F1B7B1DAA06E915989A6708DA4708498638A9D66A8BA7E
C8DC97D5EA9DD3E994D1E590D3E196D0DB96DAE5A0CEDA92E0EDA7ABB8707D8A424F5F16
63732AC3D38AD3E39A9BAB626C7C33B0C077CDDF95C5D991D6EAA5CBE29EC7E09CCBE9A3
C8ECA4C9E7A1D6E0A3DAE2A68EA263A3C080D3F3B4E0F1BA88794ED1BF97D1D9AAF8FFDF
F8FFEDF2FDECFEFFF1FDFEECFFFFECFFFEE6FFFDE3A48F74
878984000100FEFFFFFFFEFFFCF9FFFFFDFFFFFEFDF2F3E5FAFFE1EAF2C9D9E7B2D1E5A8
CEE6A8CAE6A9C9E6ACC7EAAACAF0A7C4E99BDFFBB1435B11CFE69EC1DD92D0F5A8BEE999
C0EF9FC1F2A0C7F3A4CAF5A5CBF1A4C6ED9EC2EB9DC4E99BD3EFA2D2ED9ED0EC9FC9EA9B
BBDD90C3E99CC0E8A1CDF4B1C9EDB0CAEAB8E6FFD9F2FFEAECFBE6F4FFF1FBFFFBE8F1E0
BCCE9ED8F0B2C7DD9DC4DA9AD9EFAFDBF1B1D0E4A58397589CAE70BED092CBDB9DD4E2A5
CEDC9FD9E7AAD8E6A9E6F3BBD5E1AFD7E4B6CAD7A9D4E4B3C9D9A8D7E9B5CEE0ACD3E5B1
516530C2D79FD2E9B1DAF1B9BED79EDEF7BEB4CD94D9EDBCDDEBC8FCFFEAF6FBE4FDFFEE
EFF1E3B5B5AB040400FFFEFBFFFEFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFCFFFFFEFFFF
F7F5F8FFFEFF74727707060BDFE0E4EEF0EFFCFFF8F2FBE8EDFADCE3F3CCD6E9BBCDE3B2
CCE4B2CEE6B6CEE5B7C9E6B6C5F2B7BDEAA9CFECAAD5EBA3CBE395CFEB97D2EF9BCEE796
CCDE94EFF9B4CFD192DBE4A3CDE99FD2EAA0A1A05DF0E7A6EDE9ACDAE3A4CEE8A1B6DC8F
C1F0A0BDEE9CC4F1A0C5EA9CC0DC91DCF3ABC1D6914F6423829456D1E3A7BFD197DDF0B8
C0DBA6000F00001400001200558C6C5E9B79C3FFDCB1F7C1A9ECA9BEF8ACCFFCABBFDC8C
8E984F625D1D5D4A126857216363254A5310545F1B626F29B9C883CDDE97E0F1AAD3E39C
DCECA3D5E29AD5E29ADEEEA5C9D98E98AA5E617629475D148CA15EC3D998E1FAB8C6E49C
BBDF95DBFBB0BECB855B671FDCF4AAC6E69AC2E69CBFD692514712B5A977D2DDA5C8DFA9
C7DCB5CCDFBFD9E7C6CDD7B5E1E2C0FFFFDFF9ECC9AD9F7A
F7FBEDECEFE6FDFDFBFFFEFFBDBAC3837D876F6A70BFBBB8D9DACAD7DEBFD5E2B6D4E7B0
CDE5A7C5E29FC6E5A1C8ECA4BEEA9BBFEC9BC8ED9F7E9D51B4CE84D0ECA1CAEA9EC5EC9D
C3F09FBBEC9ABCEB9AC1EE9DC7EC9EC8E79BCDE39AD3E59BCDDF95CEE096D5EBA0D3EEA1
C6E597CCEEA2CFF3A9BBE09AC6EAAABFE2A8D7F7C6E5FFD9D9F0D3E5F8E2F0FFEFDBEDD3
D1E8B4607938D0E9A8D1EAA9C7DD9DC6DC9CD0E4A5D4E9A891A464455818A0B071DDECAB
CCDB9ADFEEADCEDA9AD0DEA0C6D59AE8FAC0D0E2A8CCE0A5697D426C82445F753788A160
BCD594E7FFC0BDD796C4E19ED5F2AFC4E39FD4F3AFC2DC9FD9EABEEAF8D4E5F0D0F0F9DE
FEFFEFF6F8EAFFFFF8FCFBF7FFFEFDFFFEFFFFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFF
FEFCFDFFFCFDEAE8EB3131317C7C7AFCFFFAF5FCECEFFCE0E7F7D0DCF0BDCDE5ABC5DFA2
C4E0A3C8E4A9CAE6ACC3E9ACB8F0A7C0F6A8C2E498C8E394CCEC97C4EB92C4EF95C0EA94
CBEDA0C8E69ECEEDA9C8EBA7B7E199CAEBA6939959DCDE9FC8D897CDEAA7CFF5ACBFEB9E
C3F6A7B7EB99BFEE9DC5EE9FD1F0A4D1E79FDAE9A4D2DD9B3F45076B7135DCE2A6D7DCA2
DFE6B0D0DCAA94AB813C5E3B0021043C77573D845C317E4A5FAB6B73B9709DD387C5EBA2
D7E9ABDADAA6E1D4AAE8DBB1DCDDA4D1DB9CDBEAA7C1D590E0F5B0C7DE96D3E9A1CEE29A
D3E49DD1E198DAEAA1CDDD94D7EC9FCCE395D0EB9CC7E197CBE1A096AC6C80995785A55C
8AB162ADCE7FD7E598D2E091BFDB87D1F4A0C8EF9CCDE79D635D1FA89F64C1CF91D7F4B4
CEEBB3D1EDBAC3DBA9D8EABAD1DDADFFFFD6FFFECEA49E6E
EDF6D7E5EED3FEFFF3FFFFFBFFFDFFFDFAFFE8E2EEA29DA4A3A2A0050700697351CDDDAE
DCF4B6BAD88EC4E594D1F7A2C1EC9AC8F3A1C2E797C8E7996E863AC2D88DDFF5AAC8E497
C8EB9BC3ED9BC2ED9BC2EC9AC7E698CDE297D9E09AE0E39ED8E29DD6E39DD4E49DD1E69B
CFE79BCCE89DC9E99EC8EAA0C2E6A0BEE19FCEF0B4C8E6B2CCE7BAC7E0B9F2FFE8667C55
3D561D9BB574B3CD8CCCE7A4D9F2B0C4DD9BD2E8A7D1E8A4D5EAA7CADD9BB3C6849BAC68
899A568C9D599EAD6AAEBF7B677A388DA261899E5D92A965C8DF9BD1EAA6C3DC98D9F4AD
CCE7A0CAE89ECAE89EC9E99EC9E99EC8EA9EC8EA9EC9E8A4D0E7AFD8E9BCD5E4BBC4D2AF
F7FFE5FAFEEDFFFFF6F0F1EBFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFFFFFD
FFFFFDFFFEFBFEFDF9F8F9F43E3F37B8BFAFF3FBE3EEFCD8CEE0AED6EBB0C4DD9BCEE9A2
C8E6A0C5E4A0DEFDBABAE29CB8F1A0BEF69FC3E390D5EE9AD7F59DBBE488BEEF94B9EB94
C4EA9FD0F5B0BEECABAEDF9ECCFABACEEDB188915AE2EAB1CFE9A8BEE69FCEF6ADC6F2A5
C4F3A5B5E494C3EFA0C2EB9DC7E79CD1E79FD1DE99DFE5A5E5E6AA5F60241B1F0074783D
E5E6ACD0D39ADAE3AACBDCA5768F58759563C7F1C1BCEBBD85B88D2B5D372F613B376540
36603AA8CEA7C7EAC2CBE6B9D5E6AFE0EEB1CDE2A1C4DD9BD2F1ABCDECA6C1DF97CEEAA0
D2E8A0CEE29AD2E49AD6EBA0D3EB9DC7E494C5E894CFF0A1CBE4A0CCE2A1CBE4A0C8E89D
C6ED9CC9EC9AD4E595D5E493CCE893C7EE95C6EE96D4EFA08D8846C9C182D7E8A4C7E79E
C1E79EC8EDA7BFE09BD1EEABCCE2A2CEDEA0DBE3A8979C62
CDDBAADBE8BDFCFFE8FEFFF3FFFFFDFCF9FFFFFCFFF0ECFAFFFDFF7A7B7600050095A47B
D1E7A9DAF6ABC0E18ACAED93D1F4A0BBDE8ED6F5A7D3EEA1ACC1767A8A41A2AF67CCDC93
CEE69AC9EA9BC3EA99C0E796C9E89AD9EBA1E0E39ED9DA98D7E29ED4E39ED3E49ED1E59D
CFE79BCCE89BCAE99BC9E99DD0F0A5C8E7A1CEEDAAC8E4A7CCE5ACD1E8B4EDFFD2142800
294306B7D28FE0FBB8D0EBA6C7E09EC9E29EDAF3AFC4DB95CCE39DD4E9A4D0E5A0B8CE86
9AAE678DA15A9AAB65A8BC75C9E098DBF5ACCBE59EC2DC93D9F3AAD4F0A6C0DC92C8E79B
CAE99DC9EA9BC9EA9BC9EA9BC8EB9BC8EB99C6EB9BC8EA9ECBE5A4C5DCA4CFE3B0DAEBC1
FBFFE6FCFFEDFEFFF4FFFFFAFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFFFFFD
FBFAF6FFFCF7FFFFFAF8F9F1747669757D68E6EFD2CFDEB5D3E6AFC4DA99E2FCB3C9E59A
C3E197E0FFB7CBEAA6CFF5ACBFF3A0B3E08BDBF2A0DAE998C4DC86BEE28AD1FFA9CBF8A7
C3E29FC8E7ABB9E9ADCBFEC3C3EAB3BED6A4A1A779D7E0ABD3F0AEBFE59CC6E7A0BFE099
C6E89EC2E89DCCF5A9C4EA9FC3E59BCCE69FDBEAA7D6DFA0D4DA9CB1B77B909A5D2C3500
6D6E2C6A6929EFF0B4D9DEA6ADB78596A6799CB28BC7E5C1C9ECCB77A08077A6862B5E3F
0238165B93707AB28DB5E4BAC3DEA9CCE0A5CFEBAEC9ECAABBE39DBFE9A1C9F1AAC9EAA3
CEE9A2D0E69ED4E8A0CDE398CFEA9DC5E695C4EE9AC5EC9BCBE69FCDE4A0CAE59EC8E89D
C5EC9BC8EB99D3E496D5E394D1ED99C6EC95C2EA92D3EC9B8B8644CBC183D9E9A2C5E599
C4EE9AC8F49DBEE592CFF2A2C9E89CCAE199D1E29E8E9D5A
CCE1A0D0E4A9E4F4C7E7F2D2FEFFF4FFFFFFFFFDFFFFFDFFFBF9FFDCDDDF8A91815A6844
82975EDCF6ACC6E78CC6E387D0E596BFCF88DAEBA4CDDE97DBE6A1787F3B999A58E2E5A2
D7E29DD0E69DD2F4A7D9FFB1CFF4A6C2DE93CBD892DAE5A1D0E5A0CCE7A2CCE7A0CAE89E
CAE99DC9EA9BCAE999CAE999CAE797D0EB9ECEE49CBCCF8DD6E4A7EBF6BC000900303D05
8AA05FCCEAA4D1EFA9CBE9A1CDE8A3C6E19AD1ECA5C9E39AC8E299CEE59DD2E9A1D2EAA0
CFE79DCDE59BCEE69CD1E99FCAE69BD0ECA1C8E49AC3DF94CFEBA0CFEEA2C8E79BCAEB9C
C9EA9BC9EA99C9EA99C8EB99C8EB99C8EB97C8EB99C8EB9BCDEBA3CDE7A6CAE2A8CFE5B4
ECFCD7F9FFEAF3FAEAECEFE8FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFB
FFFFFAF7F4EDFFFFF8FFFFF6B4B6A82F3720A8B192DEEDC2CDE0A8D0E6A5C3DD94D8F4A9
D3F1A7DAF9B3F1FFCDBBDC97B9DD93E2FCB2DDE39DD5D58DE4F0A4D3EB9DCCF1A3B0CF89
D8E1ACD2DEAEC3E8B4C5EDBBC4D9AE656C43D9D5AFD0D2A3C2D697CCE5A1E2F2B1DEEDAC
CCDC9BC8DF9BC9E8A2C1E59DCFF3ADC3E29EDCF0B1DDEDAFD0E0A2D9EDAEB8D595D2E9A5
E3E99FC3C07B29270030300E9EA18EE3EBDEEDFEEE445C449BBB94BDE5B3CBF8C1B6E7AF
B0E2B1ADDFB97AAB8E073214809B6EB1CD93C3E7AAC0EAAAC6F8B3C1F5ADB7E6A0BDE79F
C3E29CC8DF99D2E8A0C4DA91D0EC9FC5EB98CBF8A3C3EE9CCAE89ECDE7A0CCE89EC9E99E
C4EB9CC7EA9AD3E39AD5E398CCE798C9EC9AC6EC99C4DC90635B1AA29759CCD993CEED9D
C4EF93C7F495BDE88CCBF39AC8EB97C6E595CCE49A94AA62
D6F1A4CAE49DCBE0A5D2E1B6FBFFEAFBFFF5FBFCFEF4F3FBFFFEFFFEFFFFFCFFF46D7B5A
1A2C00C7DE98CDEB95D8F09AD7E198E7EEAADCE9A3C9D992D6E39DB6BD79AAA666B9B474
E2E3A1CFDC96BAD98DB3DC8DBBE495C6EB9DD4ECA2D8EEA6C9E8A2C6EAA2C6EAA0C6EB9E
C6EB9DC8EB99C9EA99CAEA97C9E493C9E092DAEBA4E1EEA9D0D99A656B2F181B00A1A96E
E1F8B4D0EEA4B3D187C6E49AD7F5ABC3E197C8E49AD2EEA4D3EFA5CDE99FC8E499CAE69B
D1EDA2D4F0A5D1EDA2CCE89DCAE99DC4E498C4E298C4E498C5E498C8E89CCBEB9FC7E899
C9EA9BC9EA99C9EA99C8EB99C9EA99C8EB97C9EA99C9EA99C2E394CBE99FC3E09ED1EAB1
F0FFD8D7E6C7F0F9E6FCFFF8FEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFB
FFFFFBFFFFFAF3F2EDFFFFF8BDBFB23439259FA889C7D4A9D9EAB4D5E9AAD2E9A5C7E09C
BFDA97D7F4B4EFFFD0DDF9BEDAF2B6D4E2A5D3CC95DFD69DD9DE9ED6EAA5B8D793E3F8BD
DED7ADA29D7791AB7E607D516C744D07030079744C72744378884991A560D9DFA1D3D498
E7EBAED0DA9DDDF6B4C3E3A0B9DC9ADAFAB9ADC589DBEEB6D1E4ACD5EEB4C8ECAFC6E9A9
C7DC99DBE6AA9BA37CA0A5913F3F3DA3A4A8FCFFFF8B96888D9C7BB4CC98C0E09FBEE6A0
C2ECADB6E5AFBBEAC0507A521C3C0D496733A2CB91C6F8B9A6DE9DB4EDA8CFFFBEB4E19C
D3F3B0CFE8A4DCF0ABCCE29AD8F4A9C1E696C3F09DBAE794C9EA9BCDE99ECBEA9EC8EA9E
C2EB9DC6E89CD5E19FD7E2A0D0E79FCDEDA2D0F5A8CDE39B63591CA39459D6E09BDAF7A7
C3EA8DC5F190C1EA8CCAF196C8EC95C7E897CEEA9DAAC67B
C8EA96C7E698D0EBA6CEE6ACE9FAD0E6F0D5F6FDEDFEFFFAFBFDF8F4F7F0FCFFF3DEEBCD
86976A6B8143C3DD93C8DD90D2D995E6EDAAD4E59FCDE49CD0E69EE5F2ADC7C686A59D5F
AAA466D7DC9AE7FFB8CEF4A7BCE899C7F2A3CDEFA3BCDC91C5EBA2C3EBA2C3ECA0C3EC9E
C5EC9DC6EC99C8EB99C9EB97D2EF9FCBE395CCE098DFEEABB9C3866C7137D8DBA6DBE4AB
C9E09ACEEDA1C6E599C6E599CCEB9FC9E99DCDECA0C7E69ACBEA9ECEEDA1CDEDA1C7E79B
BEDE92BBDB8FC1E195C8E89CD6F6ABCBEDA1CFEFA6D0F2A6C8E89DC9E99ECBEBA0C3E397
C9E99DC9EA9BC9EA9BC9EA9BCAE99BC9EA99CAE99BC9EA99CCEF9BCAED9BC0E097D0ECAF
C9DFB0273615717A65DCE2D8FEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFD
FFFFFDF5F4F2FFFFFDF6F5F1FFFFF88C90811B2409DFEBC7CADAABD5E8B1C2D69BDCF1B6
D6EBB3B4CB97DEF4C5F5FFDDF6FFDCD2D7AFF5E7C2BBAE84666A38D9ECB4617E44000B00
5D4A2A3E2B0D7F8F68ABC298E6E6C0EBE3BCC7C698EBF4BDDFF4B1C2D890353A00635E24
0A050082864B4A5E215E7C3E698B4E547338BBCF9AC6D6A5CDDDACC4DCA8C3E8B2BDE9B4
B8E6B8DCFFE2D4F4DDF2FFFB8C9091868187AFA0A3FFFBF4E1D2BD948F69CDD29AD4E5A1
C5E399BCE597B8E99AC1F0A88CAD765B7B4A335E2850864A8AC6889EDB98A8DF9CC7F4B1
C5E5A4C2D898CFDF9ECFE09CD5EFA6BFE194BCE998BDEA97C9EA99CDEA9ACCEB9DC8EA9D
C1EA9EC6E7A2D6E1A5DAE4A8CEE4A6BEDB99C4E3A0D5E5A67D6E37C0AF77E1E8A5CAE296
C4E68FCAEE94C8EC94CAEE97C7E897C7E698CFEEA2C3E197
C6EC97C4E795D0F0A5C7E4A1D3EAB2D5E6B9F5FFE0FCFFECFEFFF3FAFFF1FBFFEFDEEBCF
DDECC5556735D7EDAFE2F7B4DBE6A4CBDA95C5E399C5EB9ECCF1A4D4EEA5E3E5A4D7CF91
4C40047B7A3AAFC37CCAECA0C3EFA0BAE697C3E99CCFF3A9C6EAA0C5EBA0C5EB9EC5EC9D
C6EB9BC6EB9BC8EB99C9EA99C7E698DAF6ABF7FFC8E3F8B7D2E1A6DCE9B1CFD9A5D2E1A8
C1DB92CDEC9CD3F2A4CAE99BC5E697CBEC9DCCECA0C3E397C5E599C5E79AC8EA9DC8ED9F
CAEFA1CBF0A2CCF1A3CDF2A5C1E59BBDDF95C3E49DCBEDA3C7E99FC8EA9ECCECA3CAEA9F
C9E99EC9E99DCAE99DCAE99BCAE99DCAE99BCCE89DCAE999C3E78FC6EC95C3E598CFECAA
D0E6B5000D004D5943F2FAEFFCFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
FFFEFFFFFEFFF1EFF2F0EEEFFFFFFBFDFFF4D4D9C5222B0C030F00F9FFDAF9FFD8ECFECC
F8FFDCCBDDB5F0FFDDF0FFE1CBD8BE70725C0B00000B00000008008BA576C7ECB9C4D7AA
FFFBE1FFF1D7D9E8C1D6EDC1EBECC2C0BE8EAAB37AD1E7A6BFE197E4FFB8D9E29FDAD89B
645F27585920203200234105001C00000F00071700E6EDC3C3CAA1CDDCB1CDEABCBEE5B8
CBF7D4CDF5DBEBFFFBE7F7F4FCFFFFFEF7FF6E5D63DBC8C2FFFCE6C3B791BDBC84D8E39E
DBF4A3CCF098C6F299C3EE9FC4E2ACCDEEBFAFDBA84A81480D4A0E5B995ABAF2B1C3EFB0
CAE8AAD1E3A7D7E3A5DCE8A8D2E7A2C9E99EC2ED9EC8F3A1C7EB94CBEB96CBEC9BC8EA9D
C1E9A0C7E6A3D8E3ABDDE5B2DDF0B9C9E2A9CDE9AED5E2AA6D5B29B29C6ADBE0A0C9DD95
CCE796D0ED99D0ED9BCDEA9ACAE699C9E59ACAE89ECEECA2
CEF5A4BEE594C9EEA0C2E297C8E3A0CFE4A9E9F9C8E1EDC5DFE8C9FCFFEAF5FFE6F4FFE5
EFFDDAE1F2C8CBDFAEC2D79ED7EDACCCECA3C1F4A5B7F2A0BAF1A0B7E094D1DD9BE9E3A7
E9DAA1BDB4799DA866ACC780C3E99EC4EEA2C5E99FCAECA2CAE8A0CCE89ECAE89ECAE99D
C9EA9BC9EA9BC8EB9BC8EB9BBEE093D3F5ABEDFFC9F1FFD1E5FFC8B3CE99D7F1C1C8E4AA
DAF8AEC9E996C9E898CCEB9BC9EA99C9EA99C6E999C7EA9ACDF0A0C3E898BDE495C1E899
C9EFA2C9EFA2BEE799B4DD8FC8EEA5C7EBA3C7EBA5CAEEA6C9EDA5C5E79DC5E49EC9E9A0
CAE8A0CAE89ECCE89ECCE89DCCE89ECCE89DCDE79ECAE999CAEE94CBF297CBEE9EBEDD99
C5DDA9000D00121E08D7DFD4FCFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
EBE9EEFFFDFFFFFDFFFFFEFFF8F8FAF0F1ECFEFFF4757D6559634115210078845CACBB92
69775456654639472E0007002A3A2D8D978C716D61B4B39FB8CDAEB0D6ADCAF9CBC3DFB6
FFFBE1FFFBE3CADFB4B6D6A4D6DEAB899158ADC883C5F0A1BCF09DBEEB9AC9DF97DEE4A4
D4D39ADCE1A9CEE3AAC5E2A8C1DFA9D9F1C1AFB68D504C29B0A7883F3C1D0D190082926D
6C7A56757E617C8072939393706D78726E7C726D73030000B1B495D3DDA991A25CB3CA7A
C6E190B7D484D9F9AEBDDB9BC6E0B1C8E7BDC1EDBCB7EEB787C78B3F7F42508849B0DC9F
C5E1A6E1F0B7D9E1A6D7DFA3BBCC88CEEAA0C1EA9CC2ED9BC5E991CAEB92CBED99C8EA9D
C0E8A1C7E5A7DAE4B0E1E7B9F6FFD9EBFFD3F4FFD8EFF9C56A5528A58D5DE1E1A5E0EFAC
D2E69FD1E79ED1E79ECEE59DD1E8A2CEE8A1C7E29BCEE9A2
C6EB9DBBE090D4F7A7CCED9EC5E197C9E09CE0F2B6CADBA5D7E4B6E2EEC6F6FFDEF9FFE1
EFFFD8E3F4CAD3E6B8D4E8B395AE6DC6E7A0BDEDA1BBF1A3BAEFA1D0F8AFCADA99DDDEA2
E4DEA4E7E3A6C4CF8D9BB06B9DBB73C4E69CD4F2AAC4E096CFE69ECFE69ECFE79DCDE79D
CCE89DCAE99DC9E99DC9E99ECDEFA5C3E49F23460495B77AB7D89FD2F3BEE2FFD0E3FFC9
C7E29FC4DE94D0EAA0CEEA9FC7E398CCEB9FCBEA9EC8E89CC4E498C8EA9DCBF0A2C8EFA0
C3EA9BC0E99AC4ED9ECAF3A5C5EEA2C7EDA2C3E9A0C4EA9FC8EEA3C2E69CC0E49ACDEFA5
C8EA9EC8EA9EC9E99DC9E99DCAE99DCAE99DCAE99DC9EA99C8EC94BADE86CFEFA3D1EEAC
CDE3B2000C00000700F1FAE9FCFFF8FEFFFBFEFFFBFFFFFDFFFFFDFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFEFEEF3FFFEFFF7F7F7FFFFFBFEFFF6FDFFEEFEFFECDBE4C7DAE3C4D3DEC0
CCD9BFD8E4CEE1EEDCF7FFF8F5FFFDF8FFFDFFFFFAF1F7EBF1FFF2EAFFF1DDFFE6F0FFEC
FFFEEAF8ECD4D8EFC5C8E6B2CFDEA5D4E3A288A95AB7E48FC2F79FB5E591D3EFA4CFDE99
DFE9AACCD89AD5EDAFC8E6AACBE8B0CBE1B0DFE6BCFEFBD8FDF7D7FAF5D7F9FFDDECF3D1
B4B897ADAD91757462AEABA4827D8177757A646462040800A7B093E1EEC29BAD73ABC07D
D3EAA4CEE7A3C8E1A0D1EAB1D3EABEC1DDB4BFE7B3CAFCBFA6DD9C5286442F581C4D6B35
5C6C3B8F976889905D919862808E53C5D799CBE3A5CDEBA5C5E697C8EA96D0E89ACDE89B
C3E79DC7E8A3D8E7B0DFEBBBE7FACDE1FAD0F2FFDFFEFFDD7D6742B3986DE0DEA5D2DE9C
D0E49FCCE29ACBE29CCBE29CD4EEA7D3EEA7C4DF98C9E79F
C3DF92D4F1A1CBE898C8E396D0EB9ED2E9A1C7DC97D5EAA9D3E7A8D8ECB1E9FCC4EBFEC6
F7FFD3E0F5BCC7DCA3CEE2A73F4E1376884CC9E1A3C1DB9CDAF4B3C2DB9AD1E4A4DAE6A8
D1DB9EE1EBACCDDC9BB9C988879B5694A863DFF0AACADB95CFE59DC7DD94D6ECA4D3EAA2
CAE199CFE9A0CBE69FC9E49FCBE8A5C9E6A4203E009DBB7DBAD99ECEEDB2F0FFD6D3EFB5
D3E6AED5E4ABD2E4A8D2E4A8D3E5A7D2E7A6D1E7A6CEE7A3CCE7A0CAE8A0C9E99EC8EA9D
C8EA9DC6EB9BC6EB9BC5EC9BC3ED9BC3ED9BC3EC9DC3ED9BC3ED9BC3ED9BC3ED9BC3ED9B
C3ED9BC3ED9BC3ED9BC3ED9BC3ED9BC3ED9BC3ED9BC5EC99CDED9ACDE89BCDE6A4CBE0A8
D0E1B7000800010E00DBE8CCFBFFEAFCFFEAF9FFE9FEFFEFFEFFF6FAFCF9FBFCFFFEFEFF
FCFFFFFCFFFDFEFFFDFEFFFBFDFFF9FCFFF6FFFFF4FEFFF1F6FAE9DFE7D2D1D9C4D3DCC9
D4DFCED6E1D1E2EEE0F3FFF3F9FFFAF9FFF9F9FBF8F8FDF9F8FFFDF5FFFDF4FFFBF7FFF8
FFFFF3FCFFE9CDDFB9DAF0BFC7D99DC6DA93BCD786C3E48DC8EB97C9EA99CCE89BCFE79B
CFE79DCFE69ECCE7A0CAE7A4C6E3A3C9E2A8DBEDB9F4FFD3FCFFDCFDFFDEFBFFE0FBFFE4
F8FFECF8FFEDF9FFEBFAFFE9FFFFEFE2E1CFEAE7D8857F737B7869FFFFEFB8BAA4CFD9B7
D0DFB4CBDFAAC9E3A4D1EAB0CBE0B7CCE3B9D0F2B5B1D990CEF3A5D4F2A8A1AE76030600
0404005B5A3B6C724C556035252E01797F53E4DEBAD9DAB2C1DFA1D3F2ACDAE49FD1D990
D3F09ECAED9BC4E29CD3ECB2D5F0C3C9E5BFF0FFEAFBFFE870583CA28661EFEAB2CEDB96
D1EBA2BBDB8FD6F6ABCAEA9FBADA8FD2F2A7CEEEA3C3E398
CCE498CBE699D6EEA2D3EEA1B6CE84CCE69DD7EEA6C9E39CC7DE9ADBF4B0C3D998DBF4B3
F7FFCDE8FFC0D0E6A8DDF1B4B4C287879258616E3638470C839559EAFCBED9EDAEC0D495
D3E8A7E3F8B7CBDE9CCCDF9DDEEFABAEBD7A8A96549EAD68D5E9A1CBE198CAE098DCF2AA
CBE29CC5DC96D8F1ADC1DA96CAE3A2ABC5845C7637C6E2A5CFEBB0BBD99DCDEBAFF4FFD3
F6FFD1E6F4BFD2E0ABC8D9A2CDDFA5D3E7AAD2E8AACEE4A3CDE6A4CCE7A0CAE8A0C9E99D
C8EA9DC6EB9BC6EC99C5EC99C5EC99C5EC99C5EC9BC5EC99C5EC9BC5EC99C6EB9BC6EC99
C6EB9BC6EC99C6EB9BC6EC99C8EB9BC8EB99C6EB9BC9EA99CFEA9BCFE79DD0E6A8CCE0AB
D1E2B8000900000E00D7E7C2CFDEB5CEDDB4D8E4BEEAF5D5F8FFECFBFFFAFAFFFFF9FEFF
FAFFFEFBFFFCFBFFFAFEFFFBFEFFFAFFFFF8FFFFF6FFFFF6FFFFF6FDFFF5F7FDF1F9FFF4
F8FFF5F4FFF2F6FFF4F8FFF6F8FFF3FCFFF6FCFFFAFCFFFDF9FFFDF4FAFAF5FBF9F7FEF7
F9FFF6ECF8E0E4F4CFB4C694E1F5B6CDE39AA8C06CD6F099CDE897CDE899CCE999CCE999
CAE99BCAE99BCAE99DCAE8A0CAE7A4C8E5A3D1EAB0DFF6BEE6FAC7E2F3C6E2F1C6E7F7D2
D9EECFE3F7DBE2F3D3F7FFE0FDFFE1F0EFD0FFFFE88980717C726979706BDCD7D1F2F4E6
ECF7D9ECFFD2DFF8BF5F784131411C5B6D45C7E4A2CFF09FD9F5A0D1E495CACA94564E29
2F280E14140066714FADBF9792A1767F835E44361C837E60AEC994BFDC9CDFDE9EE7E49F
CAE08DC5E791C6E69ACAE8AAC1DEAEE0FEDAECFFEBF6FFE9F2DEC5FEE6C2CDCC93DDEEA8
CCEB9FBFE496C9EEA0C9EEA0C7E99CC7E99CC6E69AD2F2A6
CCE69FCEE9A2BED891E3FEB7D5EEAAD4EFAAC3DC98CDE8A3C9E2A0CCE6A5D4EDACD8F2B3
E8FFC2D2ECADC4DCA0C5DB9DD0E2A6D3E3A5D6E8AC8FA364344A0A4E6424607938D9F2B0
CBE4A2B9D290D4EBA7D1E8A4C6DB98DAEDABC1D19084985399AD66DBF1A8C3D991C9DF97
DCF3ADCBE29CD9F0ACD1EAA6C2DB9AC3DC9B677F41BCD697D2ECAFDDF7BABAD399D2EBB1
F3FFD0E7FAC3D9ECB5D2E7AED4E9AED5EDAFD1EBACCCE7A4CAE7A4C9E9A0C9E9A0C8EA9D
C8EA9DC6EB9BC6EB9BC6EB9BC8EB9BC9EA9BC9E99DCAE99BCAE99DCCE89BCDE79DCFE79B
D0E69DD1E69BD1E59DD3E59BD4E49DD4E49BD6E39DD3E59BD1EA99CCE999CEE9A6CBE4AA
CFE5B6000B00000E00D0E6B8CDE1B0CADEABD1E5B4E3F5CBF6FFE6F8FFF1F8FFFBF9FFFF
F9FDFCFCFEFDFDFFFEFFFFFFFFFFFFFFFFFDFFFFFDFDFDFBFBFCF7FCFFF8FCFFFAFBFFF8
F9FFF6F8FFF6F6FFF2F5FFF0FBFFEFFAFFEEFAFFF2FBFFF4FBFFF8FBFFFAF9FFFAF9FFF6
F9FFF1F9FFEAC2D2ABDBEDB9D8EDAC8EA4598FA855D2EB97CDE899CDE89BCCE89BCCE89B
CAE99BCAE99BC9E99DC9E99ECCEBA5C8E5A2C8E4A7D0E9AFD1E8B2CDE1AECDE1B0D3E6B9
CEE5BBD1E8BED6E9BCFAFFDBE2E9BDD6D8B1ECE9CA69634D31291EEBE4DCFFFDF6FBFDF0
DFE9D0F7FFE3657D4B2F4516000700000C00CAE4A3D1F0A0C4E08BC8DD90F5F8C14D4923
5554384B51370C22007B986AC0DEACB2C89A888C6B484E2A677F4BC4DA9CE6E0A2E4DB98
CAD988D1EA97C1DB91DDF7B8D0EABADAF4CDF1FFEAF2FFE18B7E5EDFD0A7D4DE9FCDE79D
C8EA9EC8EDA0BFE497CCEEA2D2F2A7C1DF95C5DF96D1EBA2
DAF4B3C2DC9BCFE9A8C1DB9AC3DD9CCCE6A5D2ECADCBE5A6D6F0B1CDE7A8BED89BD4EEB1
C5DFA2BED89BC8E2A5E0F8BADBF1B1C7DC9BCCE2A1CEE7A587A25F647F3C45621FA0BD7A
CFECA9D4F1AED5F0ABD0EBA6CEE7A3C6DD99C4D998D4E9A6748A427A90478DA35BCFE59D
D7EEA8BFD690D5ECA8CEE5A1DBF1B0B2C888465C1EA0B678D4E9AEC2D79CD1E9AFD8F0B6
D2E9B1DFF7BDECFFCBEFFFCCE5FFC4D8F5B5CDEAA8C7E6A2C9E8A2C9E9A0C8EAA0C8EA9E
C6EB9DC6EB9BC6EB9BC8EB9BCCE89DCFE79DCFE79DCFE79DCFE79DD0E69DD0E69DD0E69D
D1E59DD1E59DD1E59DD1E59DD3E49DD3E49DD3E49DD0E69BCDEA96CAEC98CCECA3C9E7A7
CDE8B3000D00000D00CAE5B0D5EEB5CEE7ADC9E2A8CDE6AFD9EEC3E4F7D7EDFFE9F4FFF4
FCFFFDFFFFFFFFFFFFFFFDFFFFFEFFFFFEFFFFFEFFFCFAFFF9F9FBFEFFFDFEFFFBFAFFF7
F8FFF5F8FFF3F7FFF1F8FFEDE5F3D2D7E2C2CAD5B7D1DBC2E8F1DCF8FFF0F9FFF1F4FFEA
F7FFEAECFCD8D6E7BBD7EAB2BFD4914F671BB1CA77BED783CDE899CDE89BCCE89BCCE89B
CAE99BC9EA9BC9E99DC8EA9DCBEBA2C6E59FC5E4A1C9E5A8CBE4AAC7E0A7C9E0AACDE4AE
CAE3ACC1DAA1D0E5ACF2FFCAE3EDB8E4EABAE6E4BE9591743A3321FDF9EDF9F6EDFCFFF2
C3CFB7162707AEC59BE8FAD23C42268B9270DCF2B4BCD88BC9E692DAEFA2BDC58CCACBA3
66694CA9B69886A57B325A26648F59AACF9BB6CBA2DCEEC4B9D49D7D8F53686022A89D5B
B1B96CE4F7A6D6EAA2BED293C0D6A5DBF0C7E0F6D2ECF7D5A29A76FBF5C5CEE19FC7E99C
C7EC9FCDF2A5BFE195CCECA1D1EDA3C9E39ACFE59DB1C57E
C0D9A0D1EAB1CCE5ABD4EDB3000F00C0D99FC8E1A8D1EAB0D4EDB3000E00D6EFB5BDD69C
DCF5BBD2EBB1D8F1B7B6D091CDE6A4D5EEAACBE6A1D2F0AACEEDA7C5E49EC2E39CCDEEA7
BADB96D3F4AFBEDD99C5E4A0C8E5A2C0DB98D7F0AFD4EDA9E0F7AFD2EAA08CA35B758C44
BED58FE0F7B1C8DD9ACCE19EDBF0AFCBE09F1F3300000F00D0E4A7DEF2B5CADEA3CBE0A5
C6E2A7D7F5B9EEFFD0F1FFD1F1FFD1E2FFC0D3F2AFC9EAA5C8E9A2C8EAA0C8EAA0C8EA9E
C8EA9DC8EA9DC8EB9BCAE99BD3E49DD6E39ED4E39ED3E49ED1E59ED0E69ECDE79ECAE89E
C9E99EC8EA9EC5EB9EC3EC9EC2ED9EC1ED9EBFEE9EC1EE9BC6EE95C8EC94CBEDA0C9E9A6
CBEAAF000F00000F00C7E4AACCEAAAC9E8A4C4E19EC1DE9CC8E3ACD9F3C4EEFFE0F7FFF1
FEFFFAFFFEFFFFFEFFFFFAFFFFFAFFFFFCFFFFFCFFFDFAFFFDFCFFFEFFFFFEFFFDFAFFF7
F2FDECF2FFE9F4FFE9F4FFE1E8F7CCDAE7B9CBDAAFD2E1BAE9F7D4F9FFE6F9FFE8F6FFE4
F3FFDFF8FFDFDDEFBDCBE0A589A05AC6DE92D5EE9BD6F29ECDE89BCDE79DCCE89DCCE89D
CAE99BC9EA9BC8EB9BC6EB9DC8EA9DC7E99FC7E8A1CBEAA7CBE9A9CAE6A9CBE4AACDE7AA
D7F2AFCBE59ECFE69EC6DA95CBDA99D3DDA197996A5A5A36757158C6C5B3EBECDEF6FDED
727E68869679D4E8C5C4D3B26769531B1E00C5D99ED7F3A8D9F6A2D9F0A2D7E0A78C8E66
606746D3E4C4C6ECBD001C0040763AC7F9BEB8DEABC8E5B5BFDCA4DAE9AE91884D605213
65671EC6D185D2DF99D9E7A9D3E1AECFDEB3D3E2BBE9F1CCFCF7CFE4E7B2CBE69FCAF1A2
C6EB9ECDEDA4C7E59DCFEAA3CBE29CDAEEA9DBEAA78E9A58
5A703FE1F7C6B7CD9CC8DFAB001700001100D5ECB8C1D8A2C3DAA4435A22051C00869D65
D7EEB6D3EBB1C4DCA2D7EFB1C0D995DBF7ADCDE8A1BCDA92C7E79EBCDD96D6F7B0C3E79F
D4F5B0C9EAA53A5B16102F0063803EA0BA79C8E2A1C6DF9DBDD790CFE79DCFE69E849B53
576E2892A963CCE19EDBF0ADCBE09FD4E7A7AEC0824757192E3D02CBDA9FE7F6BBC4D89D
CDE9ACCCECADD3F3B4E0FFBFEDFFCCEFFFCCE5FFC1DBFAB6C9E8A2C9E9A0C9E99EC9E99E
C9E99DC9E99DC9EA9BCCE89DD0E69ED3E49ED1E59ED0E69ECFE69ECCE89ECAE89EC8EA9E
C6EB9EC5EB9EC2ED9EC1ED9EBFEE9EBEEF9EBEEF9EBFEF9BC6EE95C6ED94C9EEA0C6EAA4
CAE9AE001000001000C7E6AAC8E7A3CCECA3CDEDA2CCECA3D1EEAEDFFAC3F0FFDDF7FFE8
F9FCF1FFFEFDFFFDFFFFFBFFFEF8FFFFFCFFFFFCFFFEFAFFFAF7FFFDFEFFFCFFFBF6FEF1
E5F1DBD6E7C7CFE3BED1E4B6CEDFA8CDDFA3CDDEA7CEDFABCFDFB0D0E1B4D1E2B6D2E3B7
D6E7BAD5E9B698AD75768C4CA6BD77C9E497D5F19DBFDB87CDE89BCDE79DCCE89DCAE99D
C9EA9BC8EB9BC6EB9BC6EB9BC7EC9CC7EC9EC8EDA0CBEDA3CBECA7CAE9A5C8E7A4C9E6A3
C0DC91CDE899DEF6A8C7DC8FE6F6AFE7F3B389905A36390CD0D1AFEAEDD2E5EAD3434B34
2E3B21EEFEE1BFD3B0E0EFD0464531191900E2F3BCCBE79CC0DD89C7DF91E1ECB2D3D8AF
7E8564859674CAF0BFBBEEB3478240134B0ABEEBB4CDF2BECCEBB2CDDFA3EBE6ACECE2A4
75752F5D631B98A25DE2ECADDAE2AFDCE3B7C1C69EF9FAD27A7649B8C087C3E398C7F0A1
C7E79CCCE7A0CFE9A2D1E8A2CCE09BD9E8A5C9D492828B4A
1829006E7F55DEEFC5C3D4A858693C000A00586A3AE1F3C3D7E9B7ADBF8B000B00657841
C0D39CD9ECB5CBDEA6D2E6A9CDE49ED5EFA5D4EEA5D0ECA2D7F5ABC0E097C6E69DC6E7A0
C8E7A3C1E09CC3E29FBBD8966A8443425B1A8FA769CEE7A5D3EDA6D5EFA6CEE59DD4EBA3
CDE29DA0B5707B8E4C6A7D3BCADD9BCFDF9EE1F1B2CFDD9F627033DAE8ABCEDC9FDCEEB2
CDE9ACC4E4A5C3E1A3CDEBABDCFABAE5FFC1E2FFBDDCF9B6CAE8A2CAE8A0CCE89ECCE89E
CDE79DCDE79DCDE89BCAE99DC6EB9EC5EBA0C5EBA0C5EBA0C6EAA0C6EAA0C8EAA0C8EAA0
C9E9A0C9E9A0C9E9A0C9E9A0CAE8A0CAE8A0CCE7A0CAE99DC9EB95C7EB94C9EB9FC7E7A4
CAE7AF000F00000F00C9E7ABC3E09DC9E79DCBEA9CC9E89CCDE8A3D5EFB2DAF2BEDDEFC7
EAEFDBFDFAF1FFFEFAFFFDFFFFF9FFFFFBFFFFFCFFFEFBFFFFFDFFFEFFFFFCFFF8F9FFF1
E7F6D7D0E2BAC7DDACCCE4AACFE4A1D5EBA3D9EEA9D7ECABD0E4A7CCDFA7CCDFA8CEE3AB
C3D8A0B7CC93708648AEC785D1EBA2CEE99CD1EC9BD0ED9BCDE79DCDE79ECCE89DCAE99D
C9EA9BC8EB9BC6EC99C5EC99C7EE9BC7EE9DC7EE9FC7EC9EC6EAA0C8EAA0C8E9A2C7E79C
C6E393D2EE9ADFF8A5D0E596D2E49AA2B16C7883472831006C7347606841353F1CB5C09E
F2FFDFF5FFE2C9DDB8CDDBBA3431206C6C52C0D39CD3F1A7C0E08DDBF6A95F6A30DEE3BA
DADDBE98A683ACCC9BBAE7ACB9F0AD71A8654E7B429EC58EC5E9ACC7E1A4D2D89CE4E3A3
D5D692B0B6707D8440636C2D969B65C5C496E6E1B78C8358A29A69B9BF83DBF9AFBDE495
C8E39CCFE4A1D1E6A3D1E4A2D5E4A3B9C5858D96578D9355
0008002F3B15D3DFB9D6E2BAABB78F041100677448D1DEB0D4E1B3C9D7A628360332400B
6D7B46C6D59ED9E8B1C8D79CD2E6A1CBE198CEE49BC4DC92CDE79ED5F1A7C5E099CDEBA3
C2E09AD5F2AFCDE7A6C5DE9DCEE4A48EA464485C1F64783998AF69C8E299CDE49CD1E8A0
CFE49FD7ECA7C1D4924659176A7A399CAC6BD5E3A5D2E0A2D6E2A4DBE7A9D6E1A5CCDC9E
CBE5A6C9E7A7CCE9A9CEEBA9CDEAA8CBE8A5C8E3A0C5E09BCDE7A0CDE7A0CFE69ECFE69E
D0E69DD0E69DD0E69BD0E69DCFE69ECDE7A0CDE7A0CDE7A0CDE7A0CFE6A0CFE6A0CFE6A0
D0E5A0D0E5A0D0E5A0D0E5A0D0E5A0D0E5A0D1E5A0D0E69DCCE997C8EA96CBE9A3C7E3A6
CBE6B1000E00000E00CDE6ADCBE6A3CDE99FCDE899C9E497CCE69DD2EBAAD0E7AFCDDEB1
DDE4C5F6F5E1FFFFF3FFFFF6FFFBFBFFFDFFFFFDFFFEFCFFFFFFFFFCFFF8FBFFF2F7FFE8
E5F5CECCE3AFCBE3A9D9F2AED0E89CCEE595CBE294CCE299D0E5A0D2E9A5D3E9A9D2E8A8
97AD6F5B7433A4BD7BC6E099D5EFA6C5E194C7E492D1EE9ECDE79DCCE89ECAE99DC9E99D
C9EA9BC6EB9BC6EC99C5EC99C7EE9BC7EE9BC5EC9BC3EA99C4E99BC7EC9FCAECA2CBEB9F
D6F3A3CBE493C8DF8FD0E799B5CA7F6E7F39B0BF7E94A267000C00131F00222F01E4F4C7
E2F3C7F8FFDFDEF0C6C7D5B271705E6E6E56D5E9B4BFDF96D2F3A25E792C000B00DDDEB4
DDDCBD4E5333A2B98BC1E7ACC0EEADAEDD990F37006F955AC4EEAFC6EAAAD8EAACD5DFA0
D5DC99DCE6A1B0BB77576021585B24BEB886E6D5A9A59267A39763E5E6AAC2DC92CFEFA3
CBE09BD3E3A2D2E1A0D0DF9EDCE8A896A061545D1E989E60
000600333917858B67A1A7817E845E070E002E350BD4DBAFD2D9ADD0D8A9DCE4B3434B18
0E1700767F4888915A98A367D0DF9AE1F3A9D5E69FC5D991CEE49CD9F0A8D5ECA6C5DC96
CAE19DCEE5A1DBF0AFC3D897D8EAACC5D597CFDDA09AAA6B4158129DB76ED9F0A8C6DD95
DBF0ABCEE39EC6DA95DCF0ABA1B17068783767763595A4638F9B5B929E5E697537D8E8A9
C7DD9DE0FAB9B8D291C6E09FD9F2B1C5DE9CCCE2A1CDE29FD2E6A1C7DB96E6F7B1CCDD97
CDDD96B4C47D96A65F939855A3975BA8955DA8955DA5965DA3975DA1985D9E9A5D9B9B5D
969B5BDCE5A4D7E3A1E3F4B0C7DB96D2E7A2DFF6B0C7DE96D5F0A1CCE79AD0E9A8C3DAA2
DDF0C2000B00000B00D0E4B1D0E4A7CCE19CD0E69BCEE499D1E59ED6E9A9D2E3ACD7E5B4
D4DCB3F6FAD9F0F3D8E1E3CDF1EFE2FFFFF6F7F7EFFFFFF8FFFFF6E0E4D3E2EBD0EFFDD9
DFF1C1D0E8ACD3ECAACAE49AD1EA97C8E18DD1EA97D4ED9CCDE599A3BB719FB66E89A35C
B5CE8AC0DB96CCE7A0D0ECA2CCE89DC6E597C9E898CDEC9ECCE89ECCE89ECAE99DC9E99D
C9EA9BC6EB9BC6EC99C5ED97C1E993C5ED97D3F9A6C1E696D2F4A7C6E89BC3E398D0EEA4
D3EDA3C8E096CAE097798F47A5BA75CCE09BDBEEACCEDE9FD5E5A6CEE0A2C9DB9FDBEEB6
E3F6BFE1F3BFE1F5C2CAD9B2030200555742C5DCA8C0E49C8EB3630012001B2400747148
E1D8BB676244616A3FD1E8B0D2F2B1BDE09E9BB97D3A5C209BC989C2F3B1C3E6A4C6DF9D
D7E7A6DCEBA8C5D692B7C6859DA166877D48A88D60997D4EC6B581D7D598D2E39CCFE79D
D4E3A0A6B0715C68283642025E6829ABB576D8E2A3DBE5A6
6E724F010500E8ECC7BFC49C0106000D1200010700606638686E3E59602D434A175B622E
010800727A41D7DFA6C9D39665702CBFCC86DFECA6E8F8B1D3E49EB9CD86D8ECA7D8EDA8
DBEEACCADD9BC2D593D6E6A7EBF9BBD2E0A2D5E0A4CBD99BCDE29DBCD68DCFE69EC9E098
D1E6A1D7ECA7D7EBA6D0E49FC3D694D4E4A3D6E6A5D9E8A761702F41500F61702F485817
485D1CC9E2A0D7F0AFDCF2B1C3D998D8EDAADDF0AED0E49FE1F2AECEDF9BB1C07BE5F4AF
D4E19B53601A57621D5152106653196B501B6A511B68511B66531B64531B60561B5D571B
59571A575719515616CDD695DDE9A7CEDD9AC6D592D7E8A2C5DB90CCE39BC5D99CDBEDB9
C8D9AD000E00041300D4E4B5CFE1A7D8EBA9CEDF98D9EBA1DBECA6CFDFA0D8E5ADCAD7A2
DFEBB9C1CA9DD5DCB3D9DFBBE1E6C8F0F4DDFFFFEDECEFDCF4F9E3E4EDD0DEEAC6C4D4A7
CEE1AABAD392CAE49DD2EEA1CDE994D4EE97CBE490C2DB88DFF8A74E691AC9E497C1DD92
C3DF95C9E59BCFEBA1CDECA0C8E79BC5E496C6E597CAE99BCAE89ECAE89ECAE99DC9E99D
C8EB9BC6EB9BC6EC99C5ED97CFF7A1C4EA95C5EB98C9EC9CC6E69ABCDC90DCFAB0C3DF95
C8E29B96AD674F6421BDD28FD2E7A6D5EAA9C1D693E0F5B0D1E79FD2E8A0CEE39ED4E9A6
D0E4A5D7EBB0F4FFD1F9FFDB110F00626552C8E0AED7FCB6668D3EB4D38769703A6D653E
F5E4C897886B59572ED7E1ACC6DC9CCDE6A4D1E7A9CCEAAE255718B8F0AFAFE09ECAF1AE
C8E2A1C5DB9AE0FBB8CCE19ED1D99D9A8F59785829734F1FA7925BEAE4A6D6E39DD1E59D
515D1B535D1E6C76379EA869C9D595D9E5A5D5E4A3D1E09F
2C3309000700D3DAB0E7EEC24F5728182000000800D9E1AEA8B17C78814A2B34006B743B
040E00626C30E7F1B4D8E2A3818C48A2AF6ACBD893CBDA95D7E6A1E4F5AFD2E39FD3E7A2
C7D894E7F8B4D1E29EC4D392C6D594D3DF9FDBE5A8D7E6A5D5EAA5D3EAA4E0F7B191A862
172E009DB46EC0D590D7ECA7D4E9A4D7EBA65A6E296A7B37C7D894CFE09CD6E7A3CDE09E
D3E8A5ADC480869C5B5D722F869B584E611F85985698A96571803D73823DA0AD684F5C17
6B7832D5E29CD2DD98DBE5A0DBE29FDCE19FDCE19FDCE19FDCE19FDCE19FDEE09FDEE09F
E5E7A6DDDD9DD7D7979A9A5AACAC6C6160206766261F240091A1589EB46C9FB1757C8C5B
98A77E000C0000080056633778874E8A9A59C6D68FCFDF98D1E09BDCEAACCDD8A0DFECB6
C8D79CDEF0B4DDECB5D6E4B1CDD8ADEBF6CEF4FBD99FA987858F6C929E7695A2766F804C
96AA6F88A15FA6C079BFDB8ECEEA96A0BC67A0BC67617D2997B261BCD989C3E090E0FCAF
CFEB9ECDECA0CDECA0CAE99DC7E69AC5E599C7E79BC9E99DC9E99EC9E99EC9E99DC8EA9D
C8EB9BC6EB9BC6EC99C6EC99C6EC99C0E391C3E696D4F5A6CCEB9FCAE69CE7FFBA7F9952
415814AFC483D3E9A9E2F8BAD0E5AAD1E9ABD4EDABBAD48DCDE89BD0EB9CCBE697CFE79B
C6DD97CDE3A3F2FFCBFBFFDD2523144D503FCBE5B55D853F6A9344D6F4AAC3CA94584C26
B49C82AA92765D5127C5C58FD2DE9ED4E7A5D2E2A4D3EDB0497D3F0B490A86C380A6D997
C7E9ACC9E7A7BADF9AC7E6A2D7E6A5EAE1A6E2BE8C845C2B5842095B551748510E52611C
939F5DADB876C5D08ECFDB99D6E5A2DDEEAAD7EBA6CBE09B
636D3B909C6ACDD7A5D5E2ADD0DAA6E8F5BFD5E0A8D7E5AADAE5ABD6E4A7D3DFA1DCEAAC
C4D090D0DF9EE0ECAAC9D593E3EFADCAD7925F6C274857124F601A42530D4B5F1A1C3000
000E00859954D5E6A2D8E9A5DEEDAADCEBA8DDE9A7CEDD9ACCE09BCDE49EBBD28CC4DB95
E3FAB42E4500C6DB96021700001400051A00809550D4E9A4DAEFAACBE09BDAEFAAD0E5A0
CCE39FCEE7A3BDD490D0E7A3E1F6B3D2E7A2D1E5A0D2E6A1C9DD96E0F1ABC2D38DDCEDA7
E0F0A9BFCF88E0F0A9C8D992D2E8A0D1E8A0D1E8A0D2E8A0D2E8A0D3E7A0D5E6A0D6E5A0
CFDE99E5F2ADE3EEAACCD793CFD895C8D18EE5ECA9D2DD98DCEEA4B9CF86D0E4A5CFE1AD
C5D4AB000800000900E7F7CADBEAB1B8C88761722B50621852621B4B5A17616F3446551A
A7BC79B7CE8A000E004F632640511A5566323A4719F4FFD5F8FFD9F9FFDAF9FFD8E4F7C0
E4F9BEC8DE9EC8E19FD4EFA8496415D7F2A1BAD584DAF7A5BEDB8BCCE999DDFAAABFDE90
CDEC9ECBEA9CC9E89CC7E79BC8E89CCAEA9ECBEB9FCBEB9FC9E99EC8EA9EC8EA9DC8EA9D
C6EB9BC6EB9BC6EC99C8EB99C7EA98CAEB9CCDEC9EC9E59AC8E299CDE49EBFD491354A07
D6EBAABACE8FD7EDAFAEC388D8F0B6C8E2A5CFEAA7D7F5ABCCE999CBE896C6E38FD0EB9C
CEE59FCCE2A2D9ECB5D2DCB77C7A6D747668627C4D0A31007DA859C9E99ED1D8A2392B06
9F8469DFC4A78B7C519D9A63D1DC9AD0E19BD9E9A8BCD89BB9EBAE3E7E41286929CBFFC6
C5EDB1CDF1B3BCE9A4C8F1ABCBE29EDCDB9BE9C591774F1CBBA86EE0DF9FECF7B3CCDD99
D0DF9CE6F5B2E9F8B5D2E39FC5DA95CEE59FCFE9A2C5DF98
CADCA2C1D598D7E9ADD4E8ABD1E3A7CBDFA0D6E8AAC9DE9DCBDE9ED3E8A5E3F7B2C0D590
DDF1AADBF1A9CFE39CD5E9A2CFE09CCDDE9AD9EAA6CDE19CD8EDA8E5FAB5C9E09ACEE59F
DAF1A9A8BF77657B33526820ACC079C3D48EDBEAA5D3E49EDDF1ACDAEFAAD2E7A2D6EBA6
C0D791C4DB95EDFFBCBCD38BC9E098C4DB93ECFFBBC4DB93D2E9A1CBE29AB7D188D9F3AA
BCD790DEF9B2CCE7A0CEE9A2BCD68FD4EEA7CFE9A2CCE69DCDE79EC9E098D3EAA2CAE199
C9DF97DAF0A8CEE49BD6EEA4C9E399C8E499C8E499C6E599C6E599C5E599C5E599C4E699
C4E699BEE395B5DC8DCCF5A6CDF6A7C7F0A1C8F3A3D1F8A7BDDA88DFF7A9D2E9A5DBF0B7
E3F6C8C1D3A9001000AFC18FD8ECAFC7DC97DDF2A5C8DD8EC4D98CD6EAA2C7D798DAEFAE
BBD78DCAE89ECBE69FD2EBA7DBF1B1C3D99BF1FFCCDDEEB8E5F6C0DEF0BCE9FBC7F8FFD6
E4F9C1DAEFB6CEE6ACCFE7A9C0DB94D1EDA2D1EDA2C5E196DBF7AADBFAACC4E395CFEEA0
C9E89AC6E798C6E69AC7E79BCAEA9FCBEDA1CAECA0C8EA9EC8EA9EC8EA9EC8EA9DC6EB9D
C6EB9BC6EB9BC8EB9BC8EB9BCDEE9FCDEC9ED5F1A6C2D991D1E6A3D1E4A2BACA8B809051
D4E7A5DDF2B1E6FCBCCEE3A8C6DEA4DBF5B8BFDC99C6E69BCAE999C9E994C7E492D4EFA2
D3E9A8CFE4ABD8E9BCCBD4B506000035352941582C749B58BCE798D6F6ABDCE3AD6B5F39
A0856AEFD4B798895EA1A067D3E29DCBE399D5ECA6CEEEADBAEAB0CCFFCC498B4E78B478
90B981AED79BC2F9B5BDF3A8C7E8A1DDE4A1EFD29A704D17B9AF71C5CC89D7E8A4CAE19B
C9DE99C2D991C8DF97D4EEA5D5EFA6CAE69CC9E79DD3F1A7
CEE9A6DDF8B5C9E49FB8D38EDAF5B0C6E19CCFEAA3C7E29BC7E399C9E59BC8E499D2EEA3
CCE89DC6E295CBE79AC9E399C4D994E6F9B7C7DC99D1E8A2CDE49EB4CE87D5F0A9D0EBA4
C3DF95CFEBA1DEF8AFBCD68CB0C67D697F369DB169D4E8A0C4DA92C2D792D3E8A3DEF3AE
D1E8A2CEE59FC3DA92CCE69DD3EDA4CFE9A0CEE89FBDD98FD9F5ABD4F0A6D5F1A7CBE99F
DAFAB1BFDF96BFDF96C8E89FD5F3ABC0DE96C5E399CDEBA1CFEDA3C8E69CC9E79DD2F0A6
C9E79DCCEAA0BEDD91CAE99DCDEDA1CDEE9FCCEEA1CCEF9FCAEFA1CAEF9FC9F0A1C7F19F
C7F0A1C3F09DC9F6A5B7E793C5F6A4BCEE99BEF29FB1DE89C9ED93D6F39FBEDA90B3CD8E
C8E0AED5EDBD000C00C7DEA6CDE6A5D6F0A6C1DA89D5EE9ADDF6A5CFE799DAEFAABFD992
CAEA9EDAFDADBEDE92C2E096C8E39EC6DF9DD2E8A8CFE3A6DBEFB4C9DCA4CCDEAAF8FFD8
D2E6B3D7EBBAC6DCABC5DCA6D6F0B1C9E49FD0EBA6C1DC95D5F3A9B8D68CBBDA8ED3F2A6
C7E79BC7E899C8E89CC9E99DC9EB9FC9EB9FC6E89CC4E69AC8EA9EC8EA9EC6EB9DC6EB9D
C6EB9BC6EB9BC8EB9BC9EA9BC9E89AC5E196D7EEA6CEE39EDAEAABB5C386AFBA7EDAE6A8
CEDF9BD8EDA8B4C988D6EEB0CEE8ABC9E6A6C6E5A1C9EB9FC8E998CCEE9ACAEA97D1EDA2
CBE3A5D1E5B2F1FFDBFAFFE9E3D9D7C2BEB3BFD4A9BCE19EC9F4A5C6E89CD7E0A96C603A
7D6348A68D6F5B5023BABE83DBF1A8D0EFA1B2D488C5EDA7B7E2AAAFE1AEB1F0B90B460E
5B8651BAE5ADB8F5B0ACEA9FC2ECA2D6E69FE7D195A2854BE9E8A7DFF0AAC8E19DCEECA6
D8F6ACCEECA2C6E49AC6E69BCAEA9FCCECA1CDEDA2CFEFA4
C6E89CCBEDA1C0E296D4F6AAC9EB9EBFE194E4FFB9BDDF92CEF1A1C7EA9ABEE191D3F6A4
BFE290C5E896D0F3A1CDEE9FD1EBA4CFE5A4CBE4A2CAE5A0D5F0ABD3F1ABC3E39AC7E79E
C9E99ECCECA0D0EFA3C8E799CCE79A9FBA6D9DB56989A155B1C77FD8EDA8DEF3AEB7CC87
CCE39DC8DF99F1FFC2CAE49BCFE9A0C5E197C7E398D4F3A7CBEA9EB4D488CEEEA2C0E296
B7DB91CAEEA4C8EDA0DBFFB3B6DB8ED0F5A8BFE497C7EC9FBDE295D0F5A8B9DE91C4E99C
BBE093CAEFA2D4F9ACCDF2A4C2E797C2E895C2E797C2E895C2E797C2E895C4E797C4E795
C7EA9AC9EC9AB7DA8ADBFEACB9DA8BCFF09FBEDF90DFFFABD0F596C0E588D1F4A4C7E8A3
DBF8C0B7D49E000F00CDEBADC3E19BC6E595DFFDA7D1EF95C4E28CC8E591C3DF94D6F5A9
CBF0A2B9E08FBCE193CDEFA3D1F1A6C8E69ED0E9A5D1E7A7D4EAACCEE3AACADCA8E8FACA
DFF2C5ECFED4E4F6CEE9FFD1CAE3AAD6F0AFC6E3A1CAE7A4C6E49EC7E59DD2F2A7D1F1A5
C8E89CC9E99DC8EA9DC8EA9DC7E99DC6E89CC6E89EC6E89CC6EB9EC6EB9DC6EB9DC6EB9D
C6EB9BC6EB9BC8EB9BC9EA9BCBEA9EC9E39AD0E5A0D4E7A5CDDB9E8C955C9EA66DD7E1A4
CCDD96DFF5AAD3E8A3CCE5A3D3EDAEBBD896D0F1AAC7EC9FC7EA98CDF09CCBEA9CCFEAA3
C6DDA5D1E3B9F9FFEAFFFFF4FFF8F8FEF5EEE2F2CBD7FABAB1DB8FCAECA2D2DDA59A916A
5C44287D6948635D2DC3CF8FC9E89ACDF7A3B6E392C7F5ADD5FCC7AFDAACB4EEBB74AE7B
739D6DA8D49FA8EBA6B1F5AABBEEA1D4EAA1E2D2948C783BDDE4A0CAE49BC0E19AD5FBB2
C0E699CBF2A3CAF1A2BFE496C1E698CDF2A4CBEDA0B8DA8D
E2FFC5D5F3B7D0F0ADCDEEA7BBE092D1F7A4BBE28FC9F09DC5EC9BC4EB9AD1F8A9B7DE8F
C3EA9BD2F9A8BDE491C6EB9BC3E199D5F0ABC5E39DCEECA6CFEEA8BEDE95C8EAA0CBEDA1
C8EA9EC6E89BC2E296D0F1A2CAE99BC5E194D0ED9DCCE79A94AA62627631879B56BBCF8A
D3E7A2DCF0ABB9CD86D8ECA5CFE59DD6ECA4D2E9A1CAE298CFE9A0D3EFA4CDE99FCBE99F
D2F2A7C0E095D1F3A7B4D68AC9EB9FC3E89BD3F8ABC1E699C3E99CC7EDA0C5EB9ECCF5A7
BFE598CDF3A6BAE093C0E798C6EB9BC6EC99C6EB9BC6EC99C6EB9BC8EB99C9EA9BC9EA99
C9E89AC9E898D6F5A7C4E191CDE89BCEE99ACFEA9DC6E391C9EA8FC8E990C5E496D6F4AE
C1DE9EC6E2A8011900C3DCA5CEE9A6CBE79AC1DE8AC7E58DCCED92CCED96CDECA0C4E499
BDE294CFF6A5CCF1A1C9EEA0BBDB8FD8F6ACC8E39CCEE7A3C6DF9ED6ECAECCE1A9CDE1AC
E8FCCBEFFFD6ECFFD2F5FFDDE5FDC9CAE6ACD5F1B6C4E0A3CAE7A5CDEBA5C8E89FC4E498
C7E79BC9EA9BC8EA9DC7E99CC6E89BC6E89CC9EBA1CCEEA4C8EA9EC6EB9EC6EB9DC6EB9D
C6EB9BC8EB99C8EB99C9EA9BCBEA9ED1EBA4C6DB9AD9E8ADD9E3AFACB483E6ECC0FFFFD6
FBFFCDF5FFC9F7FFD0D0E5ADC7DEAAD1EAB3BFDB9ECEEFAAC7E99DCAED9DC6E69ACEE9A6
C9E0AAD1E1BCF3FDE5FAFEF0FFF7F4FFFFF4C8D7B0B7D398E1FFBACAE49DB3BC83636033
180E007B734CBDC490DCF1B0C0E295BEEA95C9F6A1BFE89ACAE9ADB9DCA6C2F5BCBDF2BA
A1CB992F5B26549054AEECA9B4E7A2CEE8A7EBDFA5625318DBEBA4C3E397CCEEA2C0E598
C7F0A2BDE899BDE899C8F1A3C7F0A1C0E798C3E89AD1F3A6
F8FFF4F6FFEBC9DBB3D3ECB3C6E49ACAED99C8EF96BDE58DC7EE9DC4EDA1C4ECA6C5ECA9
C6EEA7C4EDA1C3EA99C0E595C8EA9DC8EA9EC9E9A0C9E9A0C8EAA0C8EA9EC8EA9EC8EA9E
C9E99EC9E99DC9E99DC9E99DC9EA9BCAE99BCAE99BCDE79DD2E69FDAE9A6D4E09E8F9A58
4F5A185B6423CFD595E4EAAADDE3A3D3DC9BDFEAA8DDE8A4C8D492D4E39EE2F3AFCADE97
CEE29BD4EAA1CCE49AD1EBA1D1EDA2C9E89CCFEFA3C7E99CC1E698C8ED9FC8ED9FC0E798
C1E698C8ED9FCAEFA1C5EA9CC4E699CDF0A0CDEFA2CAED9DCAEC9FC6E798C6E69AD3F4A5
C6E69AC3E495CEEEA2CBEA9CC5E498CEED9FCCEB9FC7E396CDE597CEE396C9DD96DAEEA9
CEE29B52642A000900C9D7B4D1E2ABD0E5A0CFE69ECDE897CCEB8ECAEB92CAE8A0C9E8A4
C8EA9DC8EB99C8EB99C9EA9BC9EA9BCAE99DCAE99DCCE89ECCE7A0CFE8A4CEE7A5C9E2A1
C8E0A2D1EBACE7FFC3F4FFD4F2FFDAEDFFD8DDFAC4CDEAB0C4E2A4C4E39FC8E89FCCECA0
C9EA9BC9EA99C9EA9BC9EA9BC9E99DC9E99EC9E9A0C8EAA0C8E9A2C8EAA0C8EA9EC8EA9D
C8EB99C8EB97C8EB97C9EA99C4E397D3ECA8C8DDA2DAEAB9C7D2AAF9FFE1FFFFEAFEFFEA
FBFFE4F6FFE2ECF9DBDBE8CED1DEC4D0DFC0CDDFB5C6DEAAC8E6A6C8E7A1C7E79EC7E4A1
CFE3AEDCEBC2F2F8DEFCFFF1F8FFF3EBFAE3D4E2BED6E4B1CFDA9EDAE3A4363A00939860
99A36F6B7C46BED79DCEEEABC4E69AC8EB97BEE187D0EC95D1E697D1E8A0B9E19ABFEEAA
C6F3B883AF7A28542386B183BFEBBAD2ECBCD9D0A5968A58D5E9A2B9DA89E4FDAACCE894
BDE495D0FCAFBCE89BC3EDA1C1EA9CCCF2A5C1E698C5EA9C
FCFFFFFBFFFBE0ECD4E5F8CBCFE9A8CCEB9DCCF099C6EC97C4EB9CC1E9A0C3E8A5C1E8A5
C4E9A3C5EBA0C4EB98C5EB96C6EB9BC6EB9DC8EA9DC8EA9EC8EA9EC8EA9EC8EA9EC8EA9E
C9E99EC9E99EC9E99DC9E99DC9EA9BC9EA9BCAE99BCCE89DD0E79FC3D893D9EDA8EAFBB7
C9D8958D9957A3AE6CA4AD6C98A160909B5995A15F8A99567A8B479BAF6ACBE09BD6EAA3
DCECA5D6E69FC9DA93D3E79FD2E89FC2DC92CBE79CCCEB9FCDEDA1CCEEA1CDEFA2CDEFA2
C8EA9DC3E397C2E296C6E69ACDEDA1C7E79BBADA8EBDDD91CFEFA3D0F0A4C4E498C0E094
C4E498C6E69ACEEEA2C7E79BBFDF93C6E69ACBEB9FCFEBA0D1E59DDAEBA4D5E4A1D8E7A2
CCDC9393A164000900A6AF94D3E1B0D0E5A4CFE6A2CDE899CCEB8ECAEB90C9E8A2C8E8A5
C9E99EC9EA99C9EA99C9EA99CAE99BCAE99BCAE99DCAE99DCBE79DCDE99FCDE8A1CBE69F
C9E49FCFEAA5DCF7B2E4FFC1EAFFD3E3FFCFD9F5C2CFECB4C9E7A9C8E7A3CAEA9FCCED9E
C9EA99C9EA99C9EA99C9EA99C9E99DC9E99DC9E9A0C9E9A0C8E9A2C8E9A2C8EAA0C8EA9D
C8EB99C8EB97C8EB97C9EA99C8E499CBE4A2D2E5AEF9FFDDA8B192FEFFEFF8FAEDF8FBF0
FBFFF3F9FFF3FBFFF8FAFFF8F9FEF7FCFFF6F9FFEDF7FFE4DEF6C4D0EEB2C9E7A9D0ECB2
E6F9CCF9FFE6FEFFF1FCFFF3EFFFEAF2FFEAD7E6BDC8D09FEBECB3D9D99D6A6C2DD9E3A6
CBDFA2688449DAFCBFC2E7A4CBEDA3CDED9ACCE68DD6EB90D5E48FD5E896C7EA9AC4EFA7
B6E4A4BBE6B087AB7F1E4119598258A3BE955C522E807548CCE39FD1F4A4CAE28EC8E08C
CDEDA1C7EDA2BCE297C8EEA3CAEFA2BCDE92CEF0A4CBEB9F
F9FDFEFBFFFBF2FEEAF2FFDED7EEB8CCE7A4CAEA9FC9EB9EC6EB9EC5EB9EC6EAA0C3E99C
C3E898C4EA95C6ED92CBEF95C8EB99C8EB9BC8EB9BC8EA9DC8EA9DC8EA9DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9EA9BC8EA9DC8EDA0C0E699C0E598C9EB9F
D2F2A7C0DE94CBE79DC2DE94CCE89EC0DC92C6E49AD1F1A6CEF0A4CBF0A3B3D98C89A95E
465A1243500A515E189BAC65D8ECA4E1F7AEDBF3A9C8E298C3DF94C0DC91C6E297D2EEA3
D2EEA3CBE59BCDE79DD8F2A8C8E79BD4F3A7D3F2A6C9E89CC4E397C1E094C7E69AD7F6AA
CDECA0D1F0A4D3F2A6D0EFA3CCEB9FCAE99DC9E89CC7E398C9DF96D4E8A0CDE19CCFE39C
D5E79D546426000700637054D0E2B0CFE5A4CDE6A2CAE999C9EC8EC8ED90C6EAA2C6E9A5
C8EA9EC9EA99C9EA99C9EA99C9EA9BC9EA9BC9E99DC9E99DC9E79DCBE99FCBE9A1CBE9A1
CAE8A0CBE9A1CEECA6D0EDABD1EEB8D0ECB9CDEAB4CBE9ADC8E6A6C7E6A0C7E79CC7E899
C9EA99C9EB97C9EA99C9EA99C9E99DC9E99DC9E9A0C9E9A0C8E9A2C8EAA0C8EA9EC8EA9D
C8EB99C8EB99C9EA99C9EA9BD8F3ACC3DB9DCCDEACF6FFDC93997FF8FAECFFFFF8FFFFFB
F6FBF4F8FFF8FBFFFFFDFEFFFEFFFFFEFFFFFBFFFAF6FFF0DCF2CECFE8BEC5E0B3CCE5BD
E2F2D7F2FDEDF8FAF9F1F6F2EAFCE4F4FFE3C4D1A3DEE7B0DDDEA2DFE09E969857E1EAA9
D8EAAE5A7339C7E6AAC0E3A3C6E59FCDEA9AD8F29BD1E58CD9E895D1E795C5E898CDF9AE
B4E1A0C4EDB5D2F2C329481E53784DCBE2B8695F3B5F5329D1EBACBBE196CAE598D8EFA1
C5DD93CDE79ED6F0A7CBE59CD4EEA5CCE69DE5FFB6C3DD94
F8FDF7FBFFF8FBFFF3F7FFE9E6F8D0D7EEBACCE8ADC6E5A2CAEBA4CBEDA1CCEF9FCAED99
C7EB93C6EA90C9EC8ECBEE92C8EB97C8EB9BC8EB9BC8EB9BC8EB9BC8EB9BC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9EA9BC8EA9DBCE596D4FFB0C8F1A3ADD688
BDE295D1F3A7D5F7ABCAECA0CDEDA2C4E69AC5E79BC0E598B7E092C2ED9ECEF9AACCEEA2
E3F7AFC9D48F97A45E86964F84954E8EA25ABBD188D8F0A6D5EDA3D0E89ECEE69CD1E99F
D2E89FCEE49BCCE098CBE198C2DC92C4E397C4E095C5E498D5F1A6D4F3A7CAE69BC3E296
C6E297C7E69ABDD98EC1E094CEEA9FCCEB9FD0ECA1CBE79CCCE49AD4ECA2CEE59FCCE29A
C8DE93DAEEAF021100617154CFE3B0CDE6A4CAE8A2C9EA99C8ED8EC6ED90C5EBA2C5EAA7
C8EA9EC9EA99C9EA99C9EA99C9EA9BC9EA9BC9E99DC9E99DCAEA9FC9E99ECAE8A0CAEAA1
CBE9A1C9E9A0C8E6A0C5E4A1C4E1A7C5E2AAC7E5A9C8E6A6C8E7A3C7E79EC6E69AC6E796
C9EB97C9EB97C9EA99C9EA99C9E99DC9E99DC9E9A0C9E9A0C8EAA0C8EAA0C8EA9EC8EB9B
C8EB9BC9EA99C9EA9BCAE99DCBE4A0D2E7AECEDEB1FCFFE4BBBEABF9F9EFFFFEFDFEFCFD
FEFFFDFCFFFFFEFFFFFFFDFFFFFCFFFDFCFFF7FBFCF0FCF0F5FFEFF2FFE8EEFFE5EFFFE9
F5FFF4F9FFFDFCFFFFFCFFFFD6E6CBC6D9ACD7E5B0CFD79BA7AC692C2F00919653E3ECAB
C9D89D4D652B96B37BD2F0B4BEDB98CAE49ADBF2A0CBDF8AD4E694D6ED9DBDE294C6F0A6
C7F2ADB7DDA2D6F2C1758F6245663763784DA39673584F26829E6381AC6796B571CAE19B
DBEAA5D8E59FE0EDA7C7D790D4E39ED0E19BC7D894CDE19C
F9FFF1F5FDEEFBFFF4F8FFF1F7FFEDEAFDDDD8EFC3CAE5B0C9E6A4CAEA9FCBED99CBEE94
CAED8FC9ED8DCAEC8DCAEB90C9EB95C9EA99C9EA99C9EA99C9EA99C9EA99C9EA9BC9EA9B
C9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99DC9E99DC9E99DC1E396CCF1A3CAEC9FCAEA9E
D2F1A5CBE79CBAD68BCDE99ECBE59BCEEA9FD5F1A6D1F0A4C7E79BC5E79AC7E99CC5E498
C5D58EDFEAA5E4F1ABE5F2ACCDDD96A8B97290A45C758B428FA55C91A75E8CA058869A52
92A35CA2B26BA2AF6991A25B94AC62B4D085CCE69CCFEBA0CEE89EC7E398C6E096CDE99E
D0EAA0DBF7ACC7E197C9E59AD0EAA0C5E196CFE99FD2ECA2D3EDA3D0EAA0CBE59ED8EFA7
DFF7AB7A9050000A005F6F52CDE4B0CCE7A4CAE8A2C9EA99C8ED8EC6ED90C5EBA2C5EAA7
C8EA9EC8EB9BC8EB9BC8EB9BC8EA9DC8EA9DC8EA9DC8EA9DCAECA0C9EB9FC8E89DC8EA9E
CAEAA1C9EBA1C8E89FC5E4A0C9E7A7C9E7A9CAE9A6CBEAA6CCECA3CCECA0CCED9CCCEE9A
C9EB97C9EB97C9EA99C9EA99C9E99DC9E99DC9E9A0C9E9A0C9E9A0C9E99EC9E99DC9EA9B
C9EA9BC9EA9BCAE99DCCE7A0C7DD9DDFF1BDC7D3ABDAE0C4ADAEA0FFFFFAFCF6FAFFFDFF
FFFFFDFFFFFDFFFEFFFFFDFFFFFCFFFFFDFFFEFFFFFBFFFAE4F6E0DEF5D8DBF4D4DEF5D9
E8F9E7F1FCF6F9FEFFFAFFFECFDEBFC8DAA6C2D0959BA463898F474C4F08C5CB85C3CC8B
D6E5AC4E622DA3BB89D6F1BCC5DFA2CFE8A4CBE196CDE293CEE192D7EFA1C5EA9CB6E094
CFF8B2CCEFAFC6DDA7809461516D3C859568160800514821D0EEB8BEECAE7BA1648AA467
BCC7858E914C8D904D949956A7AE6B99A25F697432D6E2A2
ECF4DCE5EFD7F6FFF0F3FEF0F8FFF8F6FFF3E1F3D9D3E9C2CBE4ABCAE5A0C9E694CAE890
CCEA90CEEC92CDEB93CCEA94CAEA97C9EA99CAE999C9EA99C9EA99C9EA99C9EA99C9EA99
C9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99DC9E99DC9E99DCDECA0C6E599BFDB90C7E398
D0EAA0D4ECA2C2DA90E2FAB0D0E69DC7DF95C0D88EC1DB91CCE89DD3EFA4CFEEA2CDE79D
D6E69FDAE7A1C9D690CCDC95D9EAA3DAEBA4CDE199A8BE758EA25A96AA6293A75F91A25B
A5B56EC4D18BCAD590B7C78092A85F87A1577A944A88A258B8D288D7F1A7D3EDA3C7E197
A7C177CCE69CC6E096D7F1A7DEF8AEC4DE94C9E399CDE79DCDE79DC6E096C5DF98CBE29A
BFD78BE6FCBC0B1A0068785BCDE4B0CCE7A4CCE7A2C9EA99C8ED8EC6ED90C5EBA2C6E9A7
C8EA9EC8EB9BC8EB9BC8EB9BC8EA9DC8EA9DC8EA9DC8EA9DCAECA0C9EB9FC7E99DC7E99D
C8EAA0C9EBA1C9EBA1C8EAA0CBEAA6CBEAA6CAE9A3CAEA9FCAEA9ECAEB9CCBED99CBED99
C9EB95C9EB95C9EA99C9EA9BC9E99DC9E99EC9E9A0C9E9A0C9E99EC9E99DC9E99DC9EA9B
C9EA9BCAE99BCCE89ECDE6A2DDF1B6D1E1B0CED8B5767A63ABA89FFBF5F5FDF3FCFFFCFF
FFFEFAFBFAF5FDF8FCFFF9FFFFF9FFFFFBFFFFFEFFFCFFF8E1F1D7D3E9C5C9E2BBD0E8C4
E4F8DCF6FFF3F9FFFDF7FFF2CBD7B1DFEEB7697537515B164B5109A1A75FE0E7A3E8F2B5
DEEBB659693CD4E6BCC2D7ACD2E9B5D8EDB2C2D794D9EDA6D6ECA1C5E093CBF0A2C2ED9E
C3EBA2D0EFACCADEA39FB0792E450FC2CE9E0F0000261C00C7E7B5BCEDB6BBE6B1CCEAB4
D0DA9DA9AA68A3A363A0A2619CA15F858E4D37400098A263
D7E3BDD5E0C0F7FFEDF1FBF0F8FFFFF7FFFEE9F6ECE6F5DEDDEFC5D3EBAFCAE49BC8E392
CCE796D0EB9CCFE99FCCE69DCCE89BCAE99BCCE89BCAE99BCAE999CAE999CAEA97CAEA97
C9EA99C9EA99C9EA9BC9EA9BC9E99DC9E99DC9E99ECAE99DD0EAA0D7EFA3D5EDA1D0E89C
CAE296DFF5AAC2D88DCAE095CADF94D9EFA4E1F7ACDAF2A6CEE69AC3DB8FC5DD91D4EA9F
CADE96DBECA5D8E9A2D8ECA4D2E89FCBE198D6ECA3D1E99FCBE198D0E69DCDE199C8D992
CEDE97DBEBA4DEEBA5D3E39CD4EAA1CDE59BAEC67C8FA75D8AA2588EA65C8DA55B8FA75D
80984EA0B86E91A95FB4CC82D9F1A7CBE399D2EAA0D0E89ED6EEA4D1E99FD3EAA4DBF1A9
D5EBA0AFC384111E0069785BD0E2B0CFE5A4CFE6A2CCE999CAEC8EC9EC90C8E9A2C8E8A7
C9E9A0C9E99DC9E99DC9E99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC7EC9FC6EB9E
C6EB9EC6EB9EC7EC9FCAECA0C9E99EC8E89DC8E89CC7E899C7E897C7E995C7E995C7E993
C9EB95C9EB95C9EA99C9EA9BC9E99DC9E99EC9E9A0C9E9A0CAE89ECAE99DCAE99DCAE99B
CAE99BCCE89BCCE89ECDE6A4D8EBB3CAD7A9BAC1A0A4A792F4F1EAFFFDFFFFFBFFFFF7FF
FFFFF6FFFFF3FFFEFAFFFCFDFFFCFFFFFCFCFFFEF5FEFFEDEAFAD5DAF0C1CBE6AFCAE5AE
D6EEBEE1F6CDE5F4D7E6F1D1E2EEC0939E66586223A0AA65F2FAB1EAF1ABD9DF9FD3DCA5
C3CFA1919D79EBF9D8CDDCBBEAFAD3E3F5C5DEEFB8DEF3B2D7EEA6C6E297C3EA9BCFF8A9
BFE598C4E29AD3E1A3DBE6AAD8ECB1ADB783C3B18B3026025A7B4C97CB9AC8F7C9B8DCAC
CDDCA1D1D797E2E8A8D8E1A0D9E4A2E0ECAAC4D08ED0DF9C
CADBA7D0DFB4F9FFEAF5FFF3F8FFFFF8FFFFF3FDFCF8FFF8F0FFE0E2F5C7D3E7AACBE29E
CFE4A1D2E8A8D1E4ACCDE2A7CDE6A2CCE89DCCE89DCCE89BCCE89BCAE999CAE999CAEA97
CAE999C9EA99C9EA9BC9EA9BC9E99DC9E99DC9E99EC9E99EC7E69ACAE699D2EEA1D2EEA1
C0DC8FD5F1A4C1DD90D5F1A4CEEA9DCCE89BC3DF92C4E093CFEB9ECFEB9EC9E598CDE99C
D1E99FCFE59CC4DA91CFE79DCFE99FC5DF95CFE99FCFE99FCCE69CCEE89ED1E99FD0E69D
CFE39BD0E19AD2E29BD3E49DC7DD94D5EDA3D4ECA2CAE298CEE69CD3EBA1D0E89ED0E89E
D7EFA5CCE49A869E5496AE64CAE298CAE298D3EBA1CAE298C9DF96CCE299D3E7A2D2E69F
CADC92E6F6B81E290B677156D3E1B0D3E3A4D1E4A2D0E799CDEA8ECCEA90CCE7A2CAE7A7
CAE8A0C9E99DC9E99DC9E99DC9E99DC8EA9DC8EA9DC8EA9DC5E79AC8EA9DC8EDA0C8EDA0
C6EB9EC5EA9DC6EB9EC7EC9EC8EA9DCAEB9CCAEB9CCBEC9BCAEC98C9EB97C8EA94C7E993
C9EB95C9EB97C9EA99C9EA9BC9E99DC9E99EC9E9A0C9E99ECAE99DCAE99DCCE89BCCE89B
CCE89BCCE89DCDE7A0CFE5A4C9DCA4D6E3B7535A39FEFFECF9F6EDFFFDFFFFFAFFFFFDFF
FFFFF6FCFDEFFFFBF5FFFDFBFFFBFFFFFAF8FEFCF0FEFFEAF9FFDDF3FFD1E3FFBDD2F1AB
C6E3A1C6DEA4CEE0AED8E5B7D3DBA89AA16B9AA364DFE8A5CFD994DDE6A3DFE7ACEDF5C4
AEB691E3ECCFEDF7DFF9FFEDF9FFE8EDFDD8F9FFDADBEEB6C3DA96DEFDB1BBE293C1EA9B
C9EEA0D1EDA2CFDC97DAE4A5C8DA9C9DA66FDDCAA2544A2667885B4A8253B2E5BACBF5C7
D8F4BACCDEA0D7E9ABD3E6A6CADD9DC4D996E8FDB8C9E09A
CBE09FDAEDB5EDFDD8F8FFF1F8FFFFF5FFFFF5FDFFF6FFFAEBF7E3DFEECDD4E3B8CEE0AE
D1E1B2D2E3B7D0DEBBCBDCB2CFE7ABD2ECA5CFE9A2CBE79DCDE99EC8E497C9E696D5F4A4
CAEA97CAEA97C9EA99C9EA9BC9E99DC9E99DC8EA9EC6EB9EC7F0A1B8E393BCE797C8F3A3
C7F2A2C2ED9DC0EB9BBDE898C3EE9EC2ED9DBCE797B8E393C1EC9CCCF7A7C9F4A4C1E899
CCEB9FCEEA9FCEEA9FCBEA9EC9E89CC7E79BC8E89CCAEA9EC9E99DCAE99DCCE89DCDE79D
CFE79DCFE79DD0E69DD0E69DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79D
C7DF95D0E89ED7EFA5B2CA80839B518DA55B9AB2687D934AD2E69ED0E19ADBEAA7B4C37E
919E56DEE9AD1115004C50379FA87995A1638A9958B5C77BCCE389C8E088D8EDAACEE4A6
C5E09BD4F2A8C3E197CEECA2D2F0A6C0E095C6E69AC6E69AC8EA9DC8EA9DC6EB9DC6EB9D
C6EB9DC6EB9DC5EC9DC6EB9DC8EB9BC9EA99C9EA99C9EB97C9EB97C9EB95C9EB95C9EB95
CDEF9BCAEC98C7E897C7E899C8E89CC9E99DC9E99EC8E69CCAE69BD3EFA4C8E396D0EB9E
C6E096D1EBA1C8E29BD3E9A9D3E6AE1B2B00BDC7A4FEFFECF6F6EAFFFEFBFFFDFFFFFEFF
FFFFF7FEFFF5FFFDFAFFFBFEFFFBFFFFFCFFFFFDF4F8FEE4F3FFD6DBF3B5CFEDA3CEEF9E
CBEA9CCFEBA1D4EAA9D2E1A6D7DEAA979C66959B5FDAE3A2D8E39FD3DF9FD8E3ABECF5CA
C7D0B17A826DF2F8EAFBFFF4F6FFECE3F0D2F4FFDDD2E6B3CDE6A4C9E99DC3EC9DC3ED9B
C6EB9BCDE89BD7E29DD8E19EE3F3B2868E55EBD5AC71653F90B48611491843764DBEEDC1
BAE3ABD9FDC0B3D799D1F4B4C5E8A6C5E6A1D5F6AFBBDD93
CAE49AC9E2A0CEE4B3E0F1D1F3FFF2F8FFFFF9FFFFF8FFFEF9FFF6F9FFEFF9FFE8F8FFE3
F8FFE5EFFCE0DDE9D3CDDCBFC7DBA8CDE6A5CCE5A3CBE4A0D2ECA5CDE99EC7E396CBE898
CAE999CAEA97C9EA99C9EA99C9E99DC9E99DC8EA9EC6EB9EC3EC9EC4EF9FC6F1A2C4EF9F
BBE798B8E594BFEB9CC6F5A4B8E797C6F5A4D1FDAEC9F6A5BDE899B9E494BEE99AC5EE9F
C4E498C0DF93C2E296CBEDA0CAEC9FC1E698C3E89ACDF2A4C6EB9DC8EA9DC9E99DC9E99D
CCE89DCCE89DCDE79DCDE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79D
D7EFA5C6DE94C8E096CEE69CD3EBA1DCF4AAB4CC82657B324F60194C5C154A5614525F1A
87934BD2DCA0303318666850CDD5A6D7E1A4DDE7A858661B63761DD8EC95C0D08FD4E8AB
C6DF9BD9F5ABC0DC92CDE99FBAD68CD0EEA4D6F5A9C7E79BC9E99DC8EA9DC8EA9DC6EB9D
C6EB9DC6EB9DC5EC9DC6EB9BC8EB99C9EA99C9EB97C9EB97C9EB97C9EB95C9EB97C9EB97
C7E995C7E897C7E899C8E99AC9E99DC9E99DC9E99EC9E79DD1EBA1D3EBA1D0E89CC6E194
DCF6ACB6D087D7F1AACCE5A3465B20D5E7B5D4E0B8EDF6D9FEFFEFF2F4E7FFFFFAFFFFFB
FEFFFAFEFFFBFFFEFFFFFCFFFFF9FFFFFBFFFFFEFBFEFFEFE5F4CBD0E8ACC9E79DCAEB9A
C8E797C9E89AD0EAA1CFE2A2D7DCA6999965959B5FD9E3A4D7E3A1D0DEA0D2E0ABE4F1C6
ADB69B7F8676FCFFF8FBFFF5F8FFF0E0EDD3D5E5C1C3D7A6CDE6A5C9E99DC3EC9DC2ED9B
C6EC99CDE899D6E39BD7E29DBFD08CA0A86C715F31AA9E76B8DAA8B4EAB82F6335497A4B
7BAE76BDF0B5BEF0B3B6E7A6B5E3A2C0EDA8BBE59DD8FFB8
D0EF9FC6E49AC2DBA1CDE3B5E4F4D9F6FFF2F9FFFAF8FFF9F5FDF2F3FBECF5FEEBFBFFEF
FBFFF1FBFFF3F0FBEDE3EFD9CDDEB2D6EBB3D1E6ABCAE0A2D1E7A6D2ECA5CAE69BC6E295
CAE999CAE999C9EA99C9EA99C8EA9DC8EA9DC8EA9EC8EA9EC6E49ACFEDA3CBEBA2C6E69B
CAECA2CAEFA2C7EBA1C9EEA1C5E99FBEE396BDDF95C1E397C6E69DC8E89DC9E79FCBE99F
D4F3A7D7F6AACFEFA3C3E598C6E89BCFF4A6CBF2A3BDE495C5EC9DC5EC9DC6EB9DC6EB9D
C9E99DC9E99DCAE99DCCE89DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79D
D1EBA1CCE69CD3EDA3CFE99FC2DC92CDE79DD4EEA4C0D88ED3E79FD5E59ED7E3A1D4E19C
E0ECA4E3EDB141442935371F9EA476D8E2A5E1EBACCCDA8FB4C76E8397408C9C5BDAECB0
C9E09CC9E39CC9E39CD7F1AAE2FCB3BAD68CC2DE94D6F4AAC9E99DC8EA9DC8EA9DC8EA9D
C6EB9BC6EB9BC6EB9BC6EB9BC8EB99C9EA99C9EA99C9EA99C9EA99C9EB97C9EA99C9EA99
C5E695C7E899CAEB9CCAEB9CC9E99DC8E89CC7E79BC8E79BD0E89ECCE299C5DB92D7EFA5
DEF6ACDAF1A97F995291AA66C9E1A3DFF4BCB8C99CF9FFE1FBFFE8EEF6DFFEFFF1FCFFF6
FBFFFBFBFFFFFEFEFFFFFCFFFFF6FFFFF6FFFFFDFFFEFFF6E2F0CFCFE5B4C9E6A4CAEAA1
C8E89DD0EEA4DFF8B4E4F6B8D8DDA79B9B67979D61DAE6A6D7E8A4D0E5A4D3E6AFE4F3CA
E0EAD18D9484FDFFF7FCFFF6FBFFF3E7F5DBC5D7B1D9F0BCCCE7A4C9E99DC3EC9DC2ED9B
C5EC99CCE999D4E49BD6E39DE0F4ADA6B0716A5828756A3DBEDFAACDFFCAA2D2A0588A57
306932A6E3A8ABE7ABB5EFB2C8FFBFC0F5B1B6E89FAFDF95
CCEF9DCCECA0CBE8A5CCE5ACD1E6BBDEEFCDEFFDE4F9FFF3FBFFF4FBFFF6FBFFF4FAFFF3
FAFFF3F9FFF2F6FFF1F4FFE8E3F3CCECFECEDFF1BDCADFA6CBE1A3D2E8A7CFE9A2CCE89D
CCE89BCAE999C9EA99C9EA99C8EB9BC8EA9DC8EA9ECAE89ECCE09BDBEAA7D6E6A5CEE29D
D6E9A7D2E7A2C5DC98C3DA94D4EBA7D1E8A2D3E8A5D7ECA7D4E4A3CCDD99D0DF9EDAEBA7
B5CC84CAE69BD5F4A8CDEDA1C6E89BC8ED9FC8ED9FC0E798C5EC9DC5EC9DC5EC9DC6EB9D
C8EA9DC8EA9DC9E99DCAE99DCCE89DCCE89DCDE79DCCE89DCDE79DCCE89DCDE79DCCE89D
CBE59BC5E196CDE79DCEEA9FC6E096CBE79CD6F0A6D1EBA1CFE59CC6DA92DDEEAADCEBA6
BFCF86D6E1A552563B2C30179EA677DCE6A9D7E3A3C4D489E3F69DE3F7A0A6B9776E8046
BED392DFF4AFD2E7A2B2C983D5ECA4D6F0A7D0EAA1C8E49ACAE99DC9E99DC9E99DC8EB9B
C8EB9BC6EB9BC6EB9BC8EB9BC9EA9BC9EA99C9EA9BC9EA99C9EA9BC9EA9BC9EA9BC9EA9B
C9EA9BCBEC9DCCED9ECAEB9CC7E79BC6E69AC6E69ACBE79CDCF2A9CFE39BC7DB939AB067
778F45869E54E0FAB1C1DB94D9F2B0C2DA9ED2E6B1F7FFDCECFCD5F9FFE4F1FCDEF9FFED
F3FFF0F4FFF7F9FEFFFEFEFFFFFCFFFFFAFFFCFBFFFBFFF7E5F4D7D2E8BACAE6A9C9E8A4
C8E7A1D5F2AFEBFFC4F9FFCFDADDA89D9C66949D5ED5E4A1D2E8A0CEE7A3D1E9AFE2F5C8
FBFFE88B9280F9FDEFFCFFF4FBFFEDE4F3D2BDD4A6D9F2B9CCE7A4C9E99DC3EC9DC2ED9B
C3ED9BC9EA9BD3E59BD4E49DCAE199E1EDABA898645F5522C4E3A8C3F5B8C3EEB6B7E6AF
94CF9701420A49884FABE8ADA5E1A3BCF4B3BFF4B0C0F3AE
C2E797C6EB9DCBEDA1C8E7A3C8E2A5D1E8B4E6F7CDF6FFE3F6FFE8FBFFF3FBFFF4FBFFF4
F9FFF1F5FEE9F5FFE8F8FFE7F0FEDAF9FFDFF2FFD5D8EAB8CEE3AACFE5A7CDE6A2CEEAA0
CCE89BCAE99BC9EA99C9EA99C8EB9BC8EA9DC6EB9ECDE7A0DCE2A4DCDA9FD4D39AD4D599
DBDCA2DCE0A3DEE4A8E4EAACD0D69AD8DEA0D7DBA0B6BA7D89884F7A7A3EA4A269D7D89C
E7F6B1CFE79DC2DC92C7E398CEEDA1CCECA0CBEB9FCCEEA1C6EB9DC6EB9DC6EB9DC8EA9D
C8EA9DC9E99DC9E99DC9E99DCAE99DCAE99DCCE89DCAE99DCCE89DCAE99DCCE89DCAE99D
D4F0A5C8E79BC9E59ACFEEA2D2EEA3CEEDA1C9E59ABEDA8FDAF4AACBE399CEE59FD4EAA2
C1D68BDDEFB13E492B394328A9B786CBDB9CD5E5A4D6EB9ED0E78DC5DD85C4DB97B5C98E
869959C4D795D0E49FD0E5A0D2E7A2D8EFA9C0D78FD3EDA4CCE89DCAE99DCAE99BC9EA9B
C9EA9BC8EB99C8EB99C8EB9BC9EA9BC9EA9BC9E99DC9EA9BC9E99DC9E99DC9E99DC9E99D
CBEB9FCBEB9FCAEA9EC8E89CC7E899C8E99ACAEB9CCFEBA0C5D992C6D791E8F9B37E924A
90A65DCBE397D3EDA3CFEBA1B2CD86D6F1AED4EEB1DFF8BFE6FDC9E1F7C8DFF1C7D9EEC7
E2FAD6E2F6DBECF9E8FBFFFBFFFEFFFFFEFFFFFFFDFAFFF2E1F0D1CEE6B6C7E5A9C7E7A4
C4E39FCEEBA9E0FABDEBFDC3DDE0A99F9E65939C59CFE099C9E497C7E59BC8E5A5D7EEBA
E3F1CD606850E9EEDAFEFFEDF0FBDBE9FBD1C8E3ACC4E19FCDE7A0CAE99DC3EC9DC1EE9D
C2ED9DC8EA9DCFE79DD0E69DCCE89ECFE09AE1D29B867D46B4D390BDECA6CFF6B5B9E3A4
BCF3BA4B8A53326E3892CD95BAF4BAAEE6A9C9FDBFB3E7A7
C8EEA1C6EC9FC4E99BC4E797C7E69ACEE7A3D5EAB1D9EABDD3DEBEE3EDD5F7FFEFFBFFF3
FBFFEDEFFCDEE8F7D0E6F5CEE7F5D2F9FFE4F9FFE1EBFBCEDFF1BDD3E8ADC8E19FCAE49D
CCE89DCAE99BCAE999C9EA99C8EB9BC8EB9BC6EB9DCDE7A0DDE1A49B945D68632B636128
5F5E254F50163B3C02262A006061275F60265C5D2357561D504E15555018676029767439
B2BD79CADB94DAEEA6D3E9A0CDE59BD1EBA1D1EDA2C8E79BC9E99DC9E99DC9E99DC9E99D
C9E99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99D
CEEDA1CEEDA1CCEB9FC6E599C0DF93BFDE92C9E89CD5F4A8C1E094CDECA0BEDC94CBE79D
D5F0A3D1E7A71E2F0F546346C3D5A3D3E8A7CADF9CD3EB9DCFEC90CFED93E2FDB8C8E0A4
AFC282647433B4C581D6EAA5D8ECA7BFD48FE5FBB3C3DA92CDE79DCCE89DCCE89BCAE99B
CAE999C9EA99C9EA99C8EB9BC9E99DC9E99DC9E99EC9E99DC9E99EC9E99EC9E99EC9E99E
C9E99EC7E79BC5E599C6E69AC9EA9BCCED9ECCED9ECFEBA0D9EDA6C1D08D92A15CA6BA72
D5EBA2D9F4A7C1DD90C0DF91E9FFBDC3E39ABFDC99CDEAAACDE9AEBAD69CD6EFB8C4DFA8
CAE9B0C9E5B2D5EAC3E8F6DCF6FDEDF8FBF0F8FCEDF9FFEADCEEC6CDE6AFCAE9A6CCEDA6
C7E6A0C8E5A2CEE8A9CFE1A5DFE3A8A4A46497A35BD1E697CAEA97C7EA9AC5E6A1CDE9AF
CCDDB30E1800898F73F6FDDEF6FFDAE9FDC8CEEBA9CBEBA2CDE79ECAE99DC3EC9DBFEE9D
C1EE9DC5EC9DCDE79DCFE69ECEEEA3D0E49DF1E5A94D4308DAF8B0B5E194BFE399CDF2AF
B2E3ABC1FAC5A0D6A23970394E834D8ABD85A0D39BCAFDC4
C9F1AAC6EFA3C5EC9BC5EB94C8EA93CAE793CBE29AC9DDA2DCE8C0E8F3D5F6FFE8FBFFED
F4FFE3E5F4CBD5E6B2CBDBAAD9E7C4EEF8DDF6FFE1F6FFDCF0FFD2DDF2BACCE5A4CCE69F
CCE89DCAE99BCAE999C9EA99C8EB9BC8EB9BC6EB9DCCE89E9EA86B4F52194E51189BA066
C6D094D6E1A5DCE7ABCDDB9EDCE7ABD3DEA2D0DB9FDCE6AAE8EDB3D1D49B96996061652A
28310076813CC7D48EDFEFA8CFE39BC4DA91C8E096CFE99FCCE89DCAE99DCAE99DCAE99D
CAE99DCCE89DCCE89DCCE89DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C4E498C4E498BFDF93C4E498D2F2A6D4F4A8C9E99DC3E397C5EA9CD5FAACC3E79DC6E89C
CEEFA0C8E5A3566B4A64795AD3EBB7C8E3A0DFFAB5BEDD8DC6E88ADBFEA2B3D28CCCE6A9
D6E9A9C7D69595A463485817C5D692E0F4AFD2E8A0CBE29ACFE79DCDE79DCCE89BCAE99B
CAE999C9EA99C9EA99C9EA9BC9E99EC9E99EC9E9A0C9E99EC9E9A0C9E9A0C9E9A0C9E99E
C9E99EC5E59AC4E498C7E79BCCED9ECCED9EC6E796C3DF92CCDD994E5D1ACBDA95DBECA5
D7EDA4B5D083DCF9A9CDEC9EB9DA8BC6E89BDDFDB4BAD993CCEBA8D4F2B2C3E1A3D7F8B3
C1E794BEE491C7E4A1D5EAB2DCE8C0DEE8C5EAF4D1F8FFDCE1F6BED0EBA8CBEB9FCEF1A1
CAEB9CCAE89ECCE7A2CADD9BD2D7959B9C5895A155D3EB97CFF19ACBF19AC5EA9DCAE8A8
CBDFAE020E00535A38D0D8B1E2F2C1D0E8AAC0E095CFF09FCDE89BCCE89BC3EC9DBFEE9D
BFEE9EC2ED9ECAE89ECCE7A0C8EAA0C2D890E6DA9E6B6123CBE79CC6F09ECEEFA0C8E7A1
BCE5ABBEEDB9D1FFCCC8F7C37AA9755E8C5BC2F0BFADDDAB
BEE39DC4EAA1CAEF9FCAF09BCAEC95C9EA93CDE99CD2EBA9C8DFA9CCDEB4D0E2BCD7E9C3
DBEEC1D9EDB8D4E8ABCEE2A7D6E1B9E4EECCF0FAD5F9FFDBFBFFDAE9FAC4D7EBAED8EDAC
CFE6A0CFE69ECDE79ECCE89ECCE89ECAE89ECAE8A0CFE6A288925650551D7D854CDAE4A8
DFEDB0CBDB9CD2E5A5D1E6A3CBE09DD2E7A4D4E7A5CEE1A1D1DFA1D9E5A7D7E2A6D1DB9E
9BA1614D5411434A07A0A764E9F0ADDEE7A4CEDB96DBECA6D0E69ECDE79ECCE89ECCE89E
CCE89ECDE79ECFE69ECDE79EC9E99EC8EA9DC9E99DCCE89DCDE79DD0E69DD1E59DD1E59D
D3E79FDBEFA7D6EAA2CDE39AD0E69DD0E69ECDE39BD0E79FCBE79DC7E59BCDEBA3D5F0A9
C6E297C5DE9D71835B0009005A6F37D5EBABC6DD99CBE59BD9F5A0C0DC88DAF5B0C6E0A1
CEE9A6CEE7A3CCE39FC1D4923D4C09B1BD7BD4E09ED4E39ED1E59ED0E69ECDE79DCCE89D
CAE99BCAE99BCAE99BCAE99DC9E99EC9E9A0C9E9A0C8EAA0C8EAA0C8EAA0C8EAA0C8EAA0
CBEDA1C7E99DC5E59AC9E99DCEEDA1CAE99DBEDD8FB5CF8595A962ABBC78E2F3ADC8DE95
D3EBA1CDE89BC2E193CAEB9CD0F1A2C6E89BC8EA9DCAECA0C7E99FC8E9A2C8E9A4C4E99C
CAF397C7F092C9EC9ACBE9A1C8E0A4C9E0A8DFF6BEF4FFD1E1FEBBCDEDA2C4E795C6E995
C7E696CEEA9DD4EEA5D6E7A3B9BF7F858A47889647CDE58FCEEF94CDF199C5E79BC5E3A3
CEE5AF607041A1AF7ED4E2ADCDDFA3CDE3A2C8E69ECAE89ECDE79ECCE89DC5EC9DC1EE9D
BCF09DBFEE9DC9E99DCCE89ECBEDA3D5ECA6DED59A585214D6F0A6C6ED9ECBEC9DC4E49B
CCF3B4B9E2A8B4DBA4CAF1BAC0E7B268905C5E8A594E7C4D
C6E19CC6E49CCBEBA0D0F2A5CBEDA0C2E799C4EA9DCEF4ABC5EAA5C6E9A7C6E9A9C8E8A9
CAE7A7CCE6A5CDE6A2D0E4A5D2DAA7D3D9ABD9DFB1FDFFD3FFFFD4FFFFD3FEFFD1D7E2AA
D7E5AAD0DEA3D3E2A7CDDCA1D3E2A7D8EAAECCDEA2D3E0A8A2A2708F8D5CE5E5B1DCE1A9
CDD99BD3E4A0CEE49CD4EEA4CFEA9DC9E598CFE99FD3EAA2CDE29DCEE19FD6E6A7D8E4A6
D1DA9BC8CA8B99975A5B55196C6227756C31ACA86BE5E7A8D0DC9AD2E6A1D3EDA6C9E49D
D4EEA7CBE29CD0E49FD4EBA5C9EFA4C4ED9FCCECA1CEE49CD1DC98E9EBAAEAE6A69C9455
4F47085E5919545011807F3F868545E0DEA1D3D194E1E1A3D0D99ADDE7A8D7E1A2DDE7A8
D2DC9DD4DEA2727946010700363D0799A166DAE2A7D0DA9BD9E4A0D1DC98E4EEB1CAE09F
B5E39AC7FCAEC3EBA2C7E29DDDE9A9B4B87B7F7F437E8041D9E2A1CFE09CD8EFA9CAE59E
C9E79FCEECA4BDD790D1ECA5CAE8A0C8E89FCAECA2BADE94C9EDA3BDE197CDF3A8C3E99E
C9EDA3C6EAA0C4E69CCAE89EC7E399D5EFA6A4BE758CA35BB2C981C3DD94CFE99FD1EDA2
D2EEA3C8E79BC3E296C9E99DC9E99DCBEB9FCBEDA0CAEC9FC5EA9DC4E99CC7EC9FCAEFA1
C0E693C9F09DCAF1A0BAE395C1EA9ECBF3AABFE99FBDE79BC1EC9DC9F2A3C3E898C9EA9B
C0DC8FD9EFA6CADE96E0EFAE434A1480884DCFDD92D0E691D3ED94C7E490C9E6A3C8E4A9
C7E0A9647C42D6EDA9CDE49CD6ECA4C8DD9CD4E6B2CBDFAACAE0A0D0EBA4C4E498C6F09E
C1F99EBFF49AC8E998CCE79AB8DA90DCF5B1E9EAB14D4E15D2EBA9BEE49BCBF1A6C9EFA4
C0E89FBEE69FC5E8A4CBEBAAD6F4B8C3E4ABC4ECB787B37E
D7EBA4D1E79FCAE49BCBE79DCBEBA0C8EA9EC2E89BC0E699C5EB9EC5EB9EC6EB9EC8EA9E
CAE89ECCE89ECFE69ED0E5A2D7E9ABD4E3AAD0DFA6E6F5BCE7F6BDE3F2B9EAF9C0CADCA2
DBEDB3CADCA2E5F7BDD4E6ACC6D89ED2E4AADCEEB4C8D59D878958B0AE7DD4D7A2D4DCA1
DCEBAAD5EBA3CBE699C4E393C5E695C7E897C8E799C8E69CCAE59EC9E29ECDE1A2D4E4A5
D9E1A5E7EBAED7D79B9E9C618B864C6361266D6B308B8C509BA46598A464CDDD9CD4E7A5
CFE4A1C3DA96DAF1ADBBD691BFE59CB9DF94CFEAA3E3F2AFB5B7789D9759988C506B5B1F
75662BACA064A29A5C7C76384F4B0E9E9A5D9F995FA09A60ACA76F7E7941DAD59DE2E0A7
E2DFA8E2DFA8A09F6953521C3A3A044F4F1994975EA0A36ADBE1A5E2E8ACBEC488D8EBAB
D0FCB1ADE093BDE59CD0EEA8CDDD9CD8E1A2C9CA8E86874B979B5EB3BD7ECEDD9CCEE19F
DBF0ADC9E09CD3EAA6D5ECA8CEE8A1C4DF98D4F2AACDEDA4CCECA3CDEFA5BCDE94C3E59B
C7E99FC0E097D9F7AFE1FBB4C5DC96CCE19C96AA65A9BF77D3EDA4D2EEA3CDECA0C9E89C
C7E69AC8E79BCCECA0D1F1A5C5E599C8E89CCAEA9EC6E89BC4E699C3E89AC8EA9DC8EA9D
D0F0A4CAEA9EC7E99CC8EFA0CCF5A6C3EE9EBCE797CCF7A7CBF4A5BFE496CDEDA1D3EDA3
DAEBA4D2DF99E0EAA5A5AB6D646C3996A169D5E59AD3E792D1E991CAE594D4EEADCEE9B2
C0D9A2637D40C9E59BC1DC8DCAE097DAECAEDBE8BDD0DCB4D2E5ADD2E8A7CFE9A0CDF0A0
B7EE93B1E68AC9E694D5EBA0E2FFB8C7DD9CB2B27C64642EDDF1B4C0E09DC4E8A2BBE498
CFF8A9CEF5A4C9E99DCAE59EC7E09EC2DC9DCAECAFA3C98C
DAE7A1D6E69FD1E29BCDE199CFE79DD2ECA2D0EAA0CBE79CCCE89DCCE89DCDE79DCDE79D
D0E69DD1E59DD1E59DCFE69ECCF0A8C3EDA5BFE7A0C8F0A9C6EEA7C6EBA5D0F5AFC2E6A0
C1E59FC4E5A0CCEBA7BBDA96D2EFACC0DB9899B4718FA56559642CCAD39CCCD79DD2E2A3
D8EFA9C4E096C7E899C8ED9DC2E797CBF2A1C5EA9DC4E69CD2F1ADCFECAAC7DFA3D1E5A8
C9D396DBE4A5DAEAA9CEE3A0DCF7B2CFEAA5D1E8A4E2F2B198A1628C905368692D1B1F00
E8F4B4D4EBA7D7F6B0CAEEA6E3FFBDBDDB95879A5857612257581C646023B0AA6EDAD496
ECEAADD8DD9DD5DE9DE3EEACBFCB89AFBB79A5B06ED7DC9C968B53A5945E73632F4C3F0A
7F733F7F75407C754163602B6D6C36E6E9B2E6EBB1707A3E4E5A1C6D7B3DB5C483DEEEAD
D5E8A6D6EBA8D3ECA8D3ECA8D9F2AEBFD692BED18FDBE7A7E9EFB1BABB7F5F6024696A2E
A6AF70D0DC9CDFF2B0C2D794CADB97D8E9A5CBDF9ACFE49FD9EEA9C3DA94DBF2ACC6DD97
D0E7A1DDF4AEBBD08BCDDE9A9AA9669BA765AFBA78D0DF9ACFE69EC2E195C4E397C7E69A
C5E498C9E89CCDECA0C6E599C8E79BCEEDA1D0EFA3CAEA9EC9E99DCDEFA2CFEFA3CDECA0
D0E69ECEE29BC6DC94C9E39ACEEAA0C4E096C2DE94D1EDA3C6E097CDE39BCDDE98D8E39F
D3D896E3E2A2A59F614A480DB0B783C3D196E0F0A5CFE590D0E892CBE395CBE3A5ABC38F
4B61305B723ADAF1ADD9EFA7C8DB99E8F7C0F4FED9FCFFE3FBFFD5D8E6ABD1E1A0D0EAA1
C4F19CC4F09BD8EDA0D4E19BD1E6A1CCDA9CA69F694D4612D3E1A6CEE9A6CCEAA4D1F3A7
B8E290C1EB97C3E696D2EEA1CAE298D1E99FD6F2A8C5E399
CBE095D3E89BD4EA9FCDE597CAE296CCE798D0EB9ECFEA9BCDE89BCDE899CDE89BCDE899
CDE89BCDE899CFE79BCAE99BBFEB9CBDEE9FBDEE9FC1F0A2BFEB9EBFE99DC4EDA1C2E89D
C6EAA0CBEBA2CCEAA2C8E39CB6D0898DA45E526722536624708042DAEAACCCE1A0D3ECA8
CDEBA1BFE194C1E899C9F3A1C0E99ACDF6A8C1EA9EC2E7A1E0FFBFDDFBBFC7E3A9CCE4AA
D8ECADD4EBA7C2E09AB8DC94C5EDA4C2EAA1BFE099C4DD99E0ECACD6DC9E96975B686C2F
8D9758BED390C3E29CC1E09AC1D796CFDFA19EA86C54581D98975EA19F66D2D095E0E4A7
DDE7A8C7D796CBE29CD3EEA7D6F1AACFEAA3C1DB94D3E4A0DFE3A6E0DEA39C9A61A9A86F
5F5E2626270060632C878C54BDC58CDEE7AEC0CB91B8C68995A3655161226D803E889454
D5D599D5D599D7E1A2CEE19FC3DE99D1F0AADEF9B4CEE3A0D5DFA0D6D79B9D985EA29C62
8684499A9E61B2BC7DDBE7A7E9F2B1CBD191EAF3B2BFCA88DBE7A5DAE6A4D4E3A0DAE9A6
C2D18EE4F3B0DEEAA89EA967788140E3E9A9D9DF9FE1EEA9CDE79EC1E396C8E89CCEF0A3
CBEB9FCEF0A3D1F1A5C7E79BC1E195C7E79BC8E89CC4E498C3E598C8EA9DC9EB9EC6E599
CAE098E0F1ABD5E9A2CDE39BD1E8A0D3EAA2D6EDA5D0E79FD1E79FD9EAA4E0EBA7D9E09D
DEDE9EBAB476645A1D79743ADEE9AFD5EAA9D6ED9FC7E08CD2EE9ACFEBA0C1DAA07D9563
0C2300859D6BCFE4A9D0E6A6D2E4AAF2FFD1F1FCDAFAFFE2FFFFDCD1D8A4D0D89FCEDE9D
C6EB9DCAED9DDDE9A1CFD491D1DD9BC0C68A564613665625DBE0A6D5E8A8BCD18CC3E197
BFE899CAF5A5C9EEA0DBFAAECEE69AD6EEA2D0E89ACDE899
C4EA97C8EE99C9EF9CC5EB96C3E996C6E995C5E896C3E692C8EB99C8EB97C6EC99C5ED97
C3ED99C3ED97C2EE99C2EE99C2EC9AC4ED9EC7EE9FC4E99BC5E79AC7E69AC6E096CEE69C
D5E9A1C4D48DE2EDA8DAE49F686D2A7F823F999A58919855C7D894D8F1ADC8E39CD0EEA4
CAECA0D0F7A8BFE899BAE595BBE697C7F1A5BBE39CC2E7A4EBFFCFEEFFD3D3EEB9CBEAB1
BCE59FC2F0A5C4F0A5C6F0A6C6ECA3C5E9A1C7E59FD2EBA7C7DC99DAEDABD1E1A0BECD8C
7D8D4CBBCB8AD7EAA8D5E3A5D5DDA2F0F0BACBC8938F8955857F4BB0AF77E2E5ACD9E4A8
C6DC9BCFECA9D7FBB3B3DB92B3DC90C9F2A6CEF4A9C8ECA2BDE199C7EBA3C8ECA6C6E7A2
B4D390D8F5B5D2ECAFD0E8ACCCE1A6CCE0A3DFF1B5D6E6A8C7D798D0DEA0A9B877858B4D
877841BAA973BBB97EDFE9AACDE4A0CEECA6B4D28CD9F2AEDAE9A8D2D89ADFDAA0EDE4AB
DFD99FBFBA80939357A5A66A9A9A5C9B995C8C8C4EAEB0719FA4646A6F2F878D4D9AA060
C1CA89ACB272757B3BC9CE8EDDE2A2DBDD9ED7D99AC6D18DD0EEA4C3EC9DC2E99ABEE798
BCE394BCE596C3EA9BC2E99AC5EC9DC8EFA0C9F0A1C8EFA0CAEFA1CCF1A3CBF0A2CAEC9F
BDD98FD7F1AACAE59EC8E39CCAE8A0C7E59DCEECA4C6E19AD6F0A9BED38EE2F1AED0DB99
E8EDAD4A4A0C7D793CE4E8ABCDE2A1C4E29CC3E294BEE08CCEEF9ECEF0A6C0DFA6668353
001100CBE6B9CCE4B0C0D9A2D2E6B3E5F7CDF1FFE3FCFFEAFFFFDBD4D1A6E9E7B6D7E1A5
C9E49DC7E198E3E5A4E4E0A1EAEBAF938E56FAE2B2664E1ED3D299DEEAAAD7E6A1D7F1A8
C2ECA2C0EEA5B9E198C4E8A0BEDC94CFEBA1C6E297D4F0A5
C7F49FC0EC97BDE994C3ED99CCF3A0CCF3A0CAF09DC8EE9BC6EC99C5EC99C3ED99C2EE99
BFEF99BEF099BCF199BFEF99C4EE9CC8EB9BCBEB9FC4E395CFEBA0D5F0A3CDE39ADDEFA5
E0EDA7D4DE97CACF8C9FA25D525110A7A461E2DD9DE6E9A6E4F5AFC5E197C9E89CCAEA9E
C1E396CFF4A6C0E99AC3EC9EBEE79BC8EDA7C1E4A2CCEBAFF0FFD6F4FFDAEBFFD2DBF9C3
BBEDA6BBF1A3BDEBA0CAF2A9C9E7A1D2EBA7CCE39FCCE39FD3ECA8CCE5A1CEE7A3D3EAA6
DDF0AE3E4D0C444D0EE8E9AFD8D19DEEE2B2F8EABDFFF7C75A501FA19E6BDFE4AECDDCA1
CFE9AABEE19DC7F1A9C5F1A6C0ECA1B9E397B7E094CBF4A8BEECA1C3F3A7BEECA3B7E29A
DCFFBEBCDF9DB4D294CBE5A8C6DBA0D5E4ABD2DDA3D9E1A6B8BE82BDC184DEDFA3E6E1A7
8776406D5C26574E15060700ADB9796C813E9DB470BED3904151105D6929BCC083A4A267
9A955B655F258D874DDDD79DC6C285736F325F5B1EC1BF82C7C789C5C7886B6D2E8A8F4F
C3C888C9CF8FDDE2A2E1E6A6D5DA9AE4E9A9DBDD9EEBF4B1C9DF97CEEA9FCBE79CCBE79C
D4F0A5D0ECA1C8E499CEE89ECEE89EC8E298CAE298D1E99FD2EAA0CCE49ACBE198CEE49C
C9DE99D6EBA6C4DB95D6EDA7DAF1ABC2D993D1E6A1D6EBA6D3E4A0D1DD9BD3DC9BE3E8A8
D7D5985B571ADAD196E9E7AAD6E2A2D7ECA7D8EEA3D1E79CD3E9A1CEE2A3CADAAB6A7952
000700E6F1CFD5DFBAD1D9B2E0E6C2E1E6C6F7F9E4FFFFECFFFFE4DCD4AFEFEBBED1D6A0
D6ECABD8ECA7E5E3A6E1D79C080600DED49FE7C89AB09465DFD8A1DFE8A7CFDA95D1E59D
CDEBA5C9E8A4CBE6A3D2E9A5D6E9A7DAEBA7C6DA95D7EBA4
C6F1A1BEE999C0E798C6EB9DC4E699BDDD91C5E498D4F3A7C9E99DC8EA9DC6EB9DC3EC9D
C1EE9DBEEF9DBCF09DBEEF9DC5EC9DC7E99CCCECA1C3E397D2F0A6D6F2A7BED58DC9DD95
D1E29CCCD993A1AC686F7934959C59C9CE8BD3D594DDE4A0CFE197C3DB8FD3EEA1C7E396
C3E294C4E498C7E79BD3F5A9C9E8A2CDEAA8CEE8ABD3EAB2E8FACAF9FFDDF9FFDDE6FECC
C7F4AFBBEEA1B7DD94CCE7A2CCDC9BE0ECACD8E2A3CFDE9DCEE3A0DBF6B1C0DB96CAE39F
D1E4A2BCC6877D7D41786F38B6A476DAC399FFEBC2FFFED35B4D209B9364D9DBA9C9D6A0
CBE3A7C4E4A3C6EEA8C7EFA8CAF0A7D7FBB3C8E69EC6E49CD0F2A8BFE399BFE099C1DE9B
CBE4A3D1E5A8C3D0982D3601484A188986535D5622988C58B0A06C9F8B56AC9762827139
7D743B9F9A609C975D6863295C5A1F828246A0A6689DA9699CAC6B859A578C9F5D869554
ABB1739F9D62A89D65AFA46C989457939355868648D9DB9CB9BB7C969B5B8A9050B0B978
9AA362838C4B4F5A18626D2B848F4D778240868F4E616825929252A9A867A6A262ABA767
C9C585BFBB7BA6A262AFAA6AC0BB7BB1AC6CB3AB6CC2BA7BC4BC7DB5AD6EB2A86AB9B375
A5A768B0B678999F61ACB274AFB376979B5EAEAF73B5B5799E995FBCB67C9F945CAC9D66
8B7A448C7742CCB581927F47BBB174B9B375B1AC6CABA365ACA26DADA074AF9F7E48341C
281101C1AA9AAE9483BCA291D5BAA9D3B7A9C5A79FC1A69BE7D8C1AEA584B2AA83848655
A0B475A3B6749A955B86794297925AA59965A081538D7141898349787F3CA3AF678A944D
9194518E8D4D9C9859938D4F9E96588983476E6A2D7F7B3E
CBE69FCDE7A0D3EAA4CFE39EB2C37F9AA966ADBC79D4E3A0D4E3A0D3E4A0D0E5A0CDE7A0
CAE8A0C8EAA0C5EBA0C8EAA0CEE9A2D0E7A1D5ECA6CBE09BD4E9A4CADF9A9DAE6A9CAD69
8C9856707C3A85904E8B9654DEE7A6E0E9A8DFE5A5D4DD9AD3E39AD5EA9DD6EB9EC5DC8E
DDF3A8CFE79BCDE49CCBE29CD0E5A2D1E3A5D5E4ADD3DFADD8DFB3EBF0C8F5F9D4E7F2C7
C5DFA0CAE9A3D2E9A5E4F4B3CDD798DCE2A4DBE1A3DFE8A9D1DD9DCDDC9BDEEEADD3E3A2
CEDA9ADBE4A5D8DC9FA49D665F481C957751B69A73B49B73523F15918659E0DEAEE0E8B5
DBEEB6CBE5A8C4E2A2C9E8A5C1DA98CFE4A1C8D794DBEAA7D1E5A0CCE19CE4F7B5D3E6A6
CADA9CE2EDB55F68330307006F713FE1DFAEE0DDAAD6D19AE2DBA4ECE3AAD6CC91E7E3A6
D8E1A2D6E2A2E3E4A8D1CC92A99E664D420A6D682ED7DB9EC9D595E5FAB7C0D995DEF5B1
CCDB9ADFE5A7E0DBA1E5DFA5E2E4A5D5DB9BE3E9A9D2DB9ADCE5A4D0DB99D5E19FD9E5A3
CCDB98D9E8A5D9EAA6C7D894DAEBA7CEE29DD4E8A3B2BF7A969656ACA767968E4F928A4B
BBB374B5AD6E9A9052ABA163B2A86A9E94569E9355B2A769B4A96BA095579D8F52A79F61
959A5AAFB97A949D5E959E5F999F6194985BB1B276A7A76B9B995EA59F65A9A067736830
80733C9B8C55A6955FA3945BC0B879B3AE6EA2995EA69A66BDAF82D2C09CD9C3AB684E3D
A18379F5D7CFFCDBD4FFE7E0FFE4DAFFE5DBFEDDD6FFF1E4FFFEE6E2DDBDE4E0BAA3A775
B8CE90B4C988A6A4699A8F57DAD59D9F9560B69A6B5D4312E1DCA2C2CD89BAC77FEBF7AD
BDBE78BAB571CEC985C0BB79DBD694D1CC8CCDC989EBEAAA
E6E1AAD8D39CE5DEA87C723D7B6F3B5F521E877A46A79A66DFD29EF2E6B2E1DAA4CBC891
E7E8AFD8DDA3D5DDA2D6DEA3D4D89DDDDEA4DADBA1DDE1A6D6DA9F999D626064295E6227
94985DAAAE73CCD296E5EBAFE3E9ADD3D99DD2D89CDDE3A3D1DB94D9E599D9E599D2DE94
D4E098DCE9A1DBE8A3D2DD9BD6DEA2E8EDB5D1D3A1E5E4B6DDDAB1DBD6B0FFFFDFF4ECC5
E1DBA7E2E0A5DFE0A4D7DD9FDEE7A8D2DB9CE0E6A8D1D296E6E1A7E5DFA5E1D89FE7E2A8
DADB9FD0D99AD7E6A5DFE5A9B4A272AB8E66674A225E421B735D349B8C63E0D9ADE1E3B2
DBE5B1DBEAB3C6D59CD6E4A9DFE7ABDEDFA3D4D0938E8A4DBEBE7EDBE09ED2D898D5DDA1
DEE7AED1DCA463703A041500687B44CCE4AACBE5A8C7E4A4C7E8A3C7E99FC0E598C9EEA1
C1E59BD0EEA8DDECABDCE0A3DED89E7F723B5E531BBAB57BE1E5A8D2E1A0D0E7A3D1EAA6
CAE19DCEE19FDDE9A9DAE4A5D3E29FC8D995D1E29EDAEEA9CDE19CCEE29DD5EAA5CBE09B
D3EAA4C9E09AD4EEA7D3EEA7BED992C3E199D1EFA7C8E299CBDF98DCECA5D8E8A1D1E19A
CFDF98D3E39CDBE8A2D0DD97D4E19BD6E39DD7E29DD6E19CD5E09BD5E09BD9E39ED8E7A2
D3EEA7C4E59EC5E49ECBE9A3CDE8A3D1EAA6D4EBA7CEE3A0D5E8A6BECE8DEAF9B84D5919
849050DBE7A7D3DD9ED2DE9CCADE96D7EBA3CEDE9FDEE8B3D1D8AEDBDCBAB2B1958F8A76
FFF8ECFFFDF3FFFBF5FFFBF2FFFEF3FFFEF1FFFFEDFFFFEAFFFFE4FFFFDEFFFFDAD1DBA7
C5E2A2C8E19FAAAB6FDDD79DD2D198F3EEB7D6BE909D8756E3E4AADBECA8C5D991CFE698
CAE191DEF5A3CCE391C3DA88E3FAA8C8DF8DCEE492D6ED9B
A89263B9A374A0885A6B53257D6537644C1E61491B6E5628725A2C6F5A2BE1CF9F8D7F4E
F0E4B2ABA470C1BA86C8BE8BC1B180AA9866C3B380E4D4A1AB9E6A574B17665A26B3A974
9B945E99945D9A97609D9C649A99619B9C63B2B37ACCCD91C3C983A3AB60989E54AEB46C
B9BF79A8AE68979C5A969B5BCBCC92ADAC749A97649F986A9C93689E956CBAAD8AD1C29B
D2BC8DC6B17CAA9D66C0BB819B9C60979B5E898A4EAEA96F9A8F57B7A871B5A46E938850
BCBA7FA1AB6C7D924F909E608C804CA58F6091794D9D865CA69067A19269B3AA7F999669
C0C492BBC28F8C935F878751847F4893865174602B624F1755470A80783A9C965AA2A067
8787517F83503B4310000A0061743DC8E1A8BAD89CD5F8B6CBF5ADBFEB9ED5FFB4B7E696
BFE99DC2E69EC0D995CCDB9AE9EAAED8D399D2C99050470E959358EFF3B6D3DF9FC0D592
DCF5B1CFEAA5C8E6A0BEDC96CBE69FE5FFB8D4EEA7C2DC95CDE7A0D6F0A9C0DB94D5F0A9
CAE59EC6E49CC8E89FCDEFA5CEF0A6CEF2A8CFF3A9D0F2A6CAE69CD0E89ECCE49ACBE59B
CCE49ACCE49AD1E99FCFE79DCEE69CCFE79DCFE79DCFE79DCEE69CCDE59BCDE59BCAE69C
C9EDA3C7EDA4C7EBA3C7E8A1C4E39DC5E39DCCE5A1D3EAA6D0E5A2C0D5925E712F7C8F4D
B7CC89CADF9CD0E5A2CFE9A2CBEC9DCEEEA3C9E5A8D7EDBCDCECC7DEE9CB91967F7D806D
FDFEF0FFFFF6FFFFFAFCFDF7FEFFF6F4FBE9E6F0D5E4EFCDE7F1CCE7EFC6E2ECBADBEDB3
CAEEA8D0EFA9C9CF8F8B894C9B9F64D3D29ACFBA8BA0905FC6CE92D3EAA6D8F4AACBEBA0
CDF1A7AED68DD5FEB2CDF6A8A6CD7EDDFFB0BFDE8EC7E492
B69B70D1B68BAA9266634B1FAD966AB7A2759C875AA69466A49365534516A99D6D362A00
867C4B898150756D3CAC9E6D73562A87643AA7865B9C7B506A4B1F65481C7E66387F693A
6F5A2B6654245E501F5B4F1D574D1A5B511E6C6531817C449A9B5771772D66692282853E
8D904B7578336161216363259B995E6F6A326D67335D5524655D2E776C3F6F6437A39568
CDB585A187545D481395864F645720584F167B72397D743B61561E7368307B72394A450B
83874A707C3C6C7F3D9BAA6965632A897E488C7F4B9B8D5C97895C8174487E754A5F5B2E
DAD7AAE0DFAFB2B07FA19B699A8C5BB29C6A7D612F866834B89F66BAA66B83703873622E
938554A6996C4F4719080400737244D4DBA8A7B17CA6B57AC5D898C7DE98C8E298CEEDA1
C9EBA1C7EBA3D7F6B0CAE5A0D7ECA9D0DC9CD7D89C565117665B2391864EEBE6ACE2E8AA
C2D794D2F3ACC2F0A5C8F6ABB1D78CB8D88FC9E9A0CDEDA4BEDC94D8F6AEC2E098C7E59D
CFEDA5CBEBA2C0E298BEE298C5E99FBDE398B6DF93C3E89BD0EAA1CDE39ACDE39AD2EAA0
D5EBA2D1E99FCFE79DD4ECA2CBE59BCBE59BCCE69CCDE79DCEE89ECEE89ECBE59BC9E39A
C7E19ACFE6A0CEE39ED0E49FDBEAA7DAE6A4D3DC9BD3DC9BE2E8A89096565A6322CBD493
CED997DDE9A7CDDC99D2E8A0D1F0A2CAECA2BEDAA0C8DDB4F9FFEAFCFFEF5C5F4E9A9B8D
FEFEF4FFFFFAFFFFFDFCFEFBF9FFF5E6F2DED2E2BECDDEB2CEDFB2D2E4B2D3E4ADD2EBAA
BFE89CCDF2A5DDE8A4A8AD6D566023D9DEA4E4D6A5AA9E6CD2E0A3CDEAA7C7E99FB2D996
BDE7B5B8E6B8B5E3B488B47FB3DAA1BCDEA1CDE5A7D9EEAD
E2CC9DEBD6A7D2C090514312D2C694F2EBB7D9D39FE8E7B1DDDDA7CECE989999639B9B65
A3A36D777741605F29413A0654400E5A3F10796131A58D5DC5AF7EE6D2A0F6E4B2EADDA9
E2D6A2E1D7A2E3DCA6E7E2ABE3E0A9DDDCA4DEDDA5E2E3A7DDE49EDCE49BDBE39ADDE49E
DFE59FDCE19ED8DA99D4D695E2E2A4D6D69AE2E1A8CBC891D9D69FECE9B4D0CD98F2EBB5
D9CC97FFFAC4E0CC97AB9762A8945F907F49FCEDB6E6DBA3E2DDA3CFCF93DFE3A6D4DD9E
E1EDADC0CF8ECCDC9BD3E2A1CFD897E3E8A8DFDFA3E4E1AAE1DBA7D9D3A3E2DBADD5D1A4
F0EFC1FFFFD6EAE8B8DFD9A7DCD09EEEDAA8D1B786AD9660E6D89BE5DD9EE9E0A5DAD39C
A39D69A59F6F706C3F151200474618949665D4D8A5C2CA9198A064A3AE6C8C975293A45D
CAE49DC5E39DC8E9A2B8D992D1EFA9CDE4A0DFEBABE6E6AAAEA36B594A13B3A870E6E4A9
C1D08FCCEBA5BEEEA2B4E79ADBFFB8C0E298CFEFA6D8F8AFB4D28AD0EEA6C6E19AD1ECA5
C6E19AC4DF98CFEDA5DBFBB2D4F6ACC9EBA1C6EAA0CCEEA2CCE89EC6E096CCE69CCCE69C
CEE89ED0ECA1C8E499C9E89CC8E89CC6E69AC6E69AC6E89BC9EB9EC9EEA0C8ED9FC9E99D
CEE89FDBF0ABD5E9A4CFE09CD6E2A0D6E19FD7DD9DE0E6A6AEB474808646B7C07FDFEAA8
CDDC99DAEEA9C4D994D1EDA3B2D787CBF3AAD0F1BCC9E1BFF5FFF1F8FFF63F4537FAFEF0
FCFFF4FEFFFAFBFFFFF9FFFFF6FFF7E0F4D9C9E3B6C5E0A9C9E2ABCCE4AADAF0B0BDDB93
BBE897C9F3A1C9D990F3FAB7041000CAD297D3C998756D3CE1F3B7CBEBA8C0E59FC4F2B4
B1E7C3C2FADF82BB9B13492588B88EB4DBACD2EEBD95AC78
EBE2ABE2DBA4A6A46B5F6328D3DDA0DAEAABCCE1A0CAE3A1DBF6B3CCE7A4CEE9A6C4DD9B
DAEFAECCDC9DD1DFA1D8E4A6E7F1B2D6E0A1C9D394D9E3A4E8F4B4D3DF9FC4D392D9E8A7
D6E6A5D1E4A2D0E5A2D1E6A3CFE6A2CEE5A1CFE6A2D2E9A3C7DB93D9EBA1DDEDA4D1E19A
CEDE97D9E9A2DEEBA6D7E49FD1DC98E0EBA9E2EDABD9E2A1E2EBAAE0E9AACED899D6E0A1
DAE3A4CACE91E9E3A9A3945DEDD8A3624D1894854EF0EAB0DAE0A2CBDB9ABFD894D6F1AC
DAF3AFD3E6A4E7F3B3CFDB99D0E49CD4EA9FD2E19CD7E1A2DBE0A6DCDFAAE3E5B3DDE0B1
EAF0C0FFFFD6EFF6C3E4E8B5E3E1AEE2DBA5F7EAB5888447CDDE97D8F7A9C0DE94C6E19E
DBF3B5D1E6AD586A36000A00778554CCD8A6D9E3AFC4CD94D8E2A5C7D08D5A611B4F5B13
96A763CAE19DCAE5A0D5F4AED8F7B1B6D18CC9DC9AD5DE9FD4D297A49B62574E159E9C61
DEE7A8C3D895CEF2AAC7EFA6BADC92CEECA4CDE8A1C6E19ACEE8A1DEF5AFC1D691DEF3AE
DEF2ADC6DA95D0E5A0D5ECA6BCD68FC1DB94D7F2ABD2F0A6CAEA9FC3E598CCEEA1BFE496
C0E597CBF2A3BEE798C2ED9DC4F1A0C2EF9EBEED9CBCED9BBDEE9CBDF19EBEF29FC1F09F
B9DF92C3E398C3E197C2DE94CCE39BD3E7A0D4E59FD3E49E60712BC6DA93C9E098BEDA90
DCFCB1BBE093C5EB9EC9F4A5C8FCA9BCEEA5B0DAAABADDBFEEFFF8ADC3B77E8E81F7FFF6
F7FFF6F5FFFAF2FFFFF0FFFFEDFFF6D7FBD7C1EDB2C2EDA8CCECABCAE5A2D0EBA4C0E393
C3F49BCBF7A0C0D286CED893495817E9F3B7DFD7A6504A1AD1E4ACB8DB9BC0E9A5BFF2B9
A8EBCC347D6A347E67337C5F549774B6EEC7BDE6BA729668
E9E3A7CECC8F616324A3AE6CD7EBA6C4DF98CCEEA4BCE599B4DD91C5EEA2C2E89DCDEFA5
D3EEA7B9D08ADAEEA9CEE39EBBD78DDBFBB0D0F0A5B9D98EC8E89DD0F0A5C6E69BCBEBA0
CDEDA2CAEA9FC8E89DC6E69BC5E59AC7E79CCBEBA0CEEEA3CEEA9FCBE59BC8E298C9E197
CCE49ACEE69CCDE49CCCE29ACDE39BD3E9A1C5DB92D3E9A0D7EDA4C5DB92CAE298CAE298
CDE29DDFEFAE4E5718E5E5A9E0DAA0EEE5ACC7C288717538CBDA99E2F9B5CEECA6C5E49E
BFDD97C4DD99D0E09FCFE59DC9EA99C6E995C8E497CEE49CD3E3A2D7E2A8D5DFAACEDBA6
E7F5C2FBFFD6F4FFD1EDFCC5EAF5BDCFD79EF0F1B8566021D7F7ABBAE593BDE698CCF4AB
B8DC9CC7E6AB78955D000F005D7440C7D9A5D4E5AFE7F5BACFDB9DCAD591E2EEA6D2DE96
93A25F415110D9EEABCFE8A4ABC480ECFFC1D0E5A2C8D796E8F1B2D1D5985051155A5B1F
CCD294DDE7A8D0E09FD2E7A4C8DF99D9F3ACC5DC968A9F5A5E722D445310333F001F2B00
D8E3A1C0CB89C7D290D7E3A1D5E4A1DEEFABDCEDA9BBCF88CCE39BC2DC92D7F3A8D0ECA1
CDECA0D2F2A6BEE093C8ED9FC8EFA0C6EFA0C5F0A0C1EE9DBCEB9ABAEB99BCED9BC1EE9D
D3F8ABC7E79CCBE99FDAF4ABDCF2AAC2D68F81924C364701889953E8FEB6C3DD94C2E096
D0F5A8BEE799CCF8A9B9E898B8E796BCE9A4E1FFDAE2FEE8A5B9B0081712D7E1D8F9FFF6
FBFFF6F8FFFAF3FFFFF2FFFFEDFFF3D6F9D1C1EBA9C3EDA1C6E89ECBE9A1C7E396D6F9A5
B8E98DBDEA8FE2F5A6939D5691A05DD6E0A4E2DAAB5F5B2CD0E3ACCFF3B6DCFFC3ABDEA5
5E9F7D0F593E4F9A7BA1EBC68BCFA686C193CAF6C591B784
C1B676968D4C5E5D1AD7DE98D1E198C8E396D1F4A4C7F19FCCF6A4BCE694CDF2A2CAEB9C
BFDA8DE6FBB0CFDC94DBEDA3C6E798C2EC9AC5EC9BCAF1A0D0F5A5C9EE9EC4E797C7E899
C6E798CAE99BCFEB9ECFEB9ECEE99CCEE99CCEE99CCCE89BD4F6A9C8EDA0C4E99CCCEEA2
D1F3A7CCEEA2C8EA9ECBEBA0CCECA0CAEA9EBFE292CAED9BCAF09DC6EC97C9EF9AB5D685
778E46758A47D2E7A4D9F0ACC6DD99D5ECA8CCE19ED1E4A291A4628B9E5CCEE19FD1E6A3
CFE8A4CFEDA7C4E59ED0F9ABC6F79EC0F196C3ED99C5E79ACAE49DCEE4A4CCE0A5CEE3AB
D4EBB5E9FFCBE0FBC4E1FDC3E2FBC1CBE1A3D1E5A65C712ECBE79CD2F1A3C9E79DCFEDA7
CEE8ABC9E2A9647B47000C005B6F3EDEF2BFC4D7A0D1E5A8DAEDADC4D891D2E79CD1E69B
D1E5A0E3F3B2838F4F546020E9F5B5D3DF9FD5E5A4D7EAA8C3DA96D8EFABE3F8B5A2B170
7A8042737136877C44E4DEA4D6E19FD2E39FD6E5A2B9C5838F9A587C8242C9CE8EC4C687
D7D799A3A3655B5B1D5355169A9F5FD1D797D0D696C1C885A4A6659D9E5CD0D390E7EAA7
E1E6A3C9D08C9CA762AEBB75CADB94CEE29AD3E9A0D2EAA0CBE59BC7E398C8E499CCE89D
BCD48ACDE39ADEEFA8A3B36C47520D525C17B1B874ECF3AFD9E39ED4DF9AD9EAA3D6EEA4
BFDE92CFF1A4CBF2A3BDE294D2EEA4D0E5AAF8FFE5F9FCF3777276120810FFFBFBFFF1EE
FFFBF6FFFCFAFFFAFFFFFEFFFCFFF4E2F2CDCBE4A3CAE99BC7E69ACBEA9CC7E492D7FBA3
B1E384B5E084E3F4A4939B52CDD997D5DDA2DED3A5787145C8DAA6C1E4AA7EA66826561A
164B15A7E0ADBFFAC2BAF6BAB8F0B172A361CBF0AD90AF6C
877F3E504B07959652E6F0A7C6D88ED3EE9FC2E595C1E895BBE593C4EE9AC8ED9DCAEB9A
CEE99CCBE294E1F1A8C5DC8ECFF5A2B7E48FBFEC97C8F49FBBE591C2E996D0F6A3C8EB99
C7E897CBEA9ACEEB9BCCE798CCE496CEE597D1E89ACFEA9DBFE194C3E99CC8EEA1C6EC9F
C6EB9EC7EC9FC8EDA0C9EB9FC4E699CAEC9FCDF2A2C1E794BEE48FD1F7A2BDE38C83A654
5F7B31DAF4ADCFEDA5B6D88ED1F5ABC3E79DBEE096D4EFA8D2E7A24A5B17B7C683CDDE9A
CEE39ED5F0A9C2E69CBEE799C1EE99BEEC94C8EF9CC8EA9DCAE59ECFE5A4CBE1A3D1E6AB
C8E0A6D4EDB3BFDBA0C2DEA1CBE8A8CBE8A6C5DF9E90A965D1EBA1C6E194C5DF96D3ECA8
C7DD9DCDE2A7758A52000D00697D48C9DEA6D0E5AACFE8A7C9E29ECCE69DCCE79ACFE99F
D1E6A1D1E1A0C6D2923D4708AFB879C5CF90E2F1B0C8DD9ACFEAA5C9E7A1CEE9A4CEE3A0
9FA8695553185C4D169F925BB1B173CED494DBE0A0DEE3A3DADA9C757537AEAC6FD7D396
E2DEA1BEBA7D5F5B1E5C5A1DD3D395F6F6B8AAAC6D807E415F55185B4F13ACA064E1D79A
DCD496A49E60625E1F747434C5C786CFD492D8E19EDBE6A2D6E39ED0DF9AD3E29DD7E7A0
E1F1A8ADBA7295A05B808A456B7431A1A865DBE29FCFD895DAE49FD0DD95DAECA2CBE196
D3EFA2BEDF90C3E89AD0EEA6E7F6BDEAF1C8FFFFEFFFF8F6635660705E6AFFF1F7FFF9FB
FFF7F8FFF9FAFFF9FEFFFCFDFFFFF3EBF2D1D3E2ABD1E6A3D6F0A9C6E297C4E18FC7E992
CAF59BC7ED96B3C17697A15CD8E9A5DBE7A9C7C191767348C9E3B4BCE7B22B581F001500
194709C6F7B6B6E7A5BEEDA9BEECA495BA7495B06BBDD28D
A1A864B5BF78CEDB95D8EAA0D2EAA0C9E598C6E89BC7EE9DC5EC9DC5EC9BC5EC9DC6EB9B
C8EA9DCAE99BCCE89DC9EA9BC3ED99BFEF99BFEF99C1EE99C2EE99C3ED99C5EC99C6EC99
CBEE9CC3E493C6E595CEEB9BD1EC9DD1E99BCEE698CEE99CD1F0A4C9E99DC3E397CAEA9E
D2F1A5C9E89CC2E195C9E59AD2EEA3CBE79CCDE79DD6F1A4C3DE91DDF8AB95AD618CA75A
C9E99DC8EA9EC8EA9EC8EA9EC8EA9EC8EA9EC9E99ECCE89ECDE49CD8EEA6A4B8714D611A
BDD18ACAE098D1E79FC9E39AC6E599CAE99DD1EBA2D5ECA4D6EAA5D5E5A4D3E2A1D2E0A2
D4E2A4DAEAABCCDF9FC2D796D3E8A5D5ECA889A05CA4BE77CBE79CCFEEA2C6E298C0DB94
D8F2ABD0E9A56D8342000E006C8242CBE1A0C6DF9BC2DD96D9F4ADBBD98FDBFAAEBFDE92
C3DD96DDF2ADC7DB96CCDD998C9D59B0C17DD1E5A0CEE29DC8DD98CEE39EDAEFAAD4E8A3
CBDA97D1DC9ABDC3838A8C4D625D2352491070672EA69D64D9D097E0D79EA39D637F793F
EFE9AFD8D399BFBA8087854A707034E8E8ACDCDDA1C1BF84EADEA4E6D59D65541CA7985F
E0D49A6E6429DBD297E6E2A5575518D7D799E7E9AAE1E6A6D6DC9CE1EAA9B1BA79747D3A
4B550C535E1296A05BD6E19DD8E4A4D2E0A2DAEAA9D2E7A2D3E9A0CFEA9BCDE897C9E994
C8EA96C6E997C4E797C7E1A2FAFFE4FEFEF4FFFCFBBCB7BD504853FFF7FFFEF7FFFFFCFF
FFFDFFFFFEFFFFFFFDFDFEF8F6FAEBEBF4D9DAE6C2CADAADD4E5B1CBE1A1D3EFA2C1E18E
D2F1A5829C55656F33D9E4A8D3EFA5BED58FE0E0AC31380E628C644782566EA472ACDFA6
8EC081B3E1A0CFF9B9B8DFA0C2E1A594AC70293A037C8951
C7D891CEDF98D2E89FD3EBA1CDE99EC8E79BC6E89BC6EB9DC6EB9DC5EC9DC5EC9DC6EB9D
C6EB9DC8EA9DC8EA9DC6EB9DC2ED9BC1EE99C1EE9BC2EE99C3ED9BC3ED99C5EC9BC6EC99
C4E797DCFDACC9E89ACEEB9BD5F0A3C2DD8ECCE498D2EDA0CFEBA0C3E296CEEDA1D2F1A5
C6E297C8E499D3EDA3CDE79DC6DE94D2EAA0C5DB92CCE299CCE299C5D991798D45ADC57B
C8EA9DC5EC9DC6EB9DC6EB9DC8EA9DC9E99DCAE99DCCE89DC7E197DCF4AACFE59C7C9048
98AC64A0B16AD0E19AE1F2ABD8EDA8CEE59FC6DB96C5D994CDDE9AD6E5A2DCE8A6DCE8A6
D6E19FD3DF9DDCEBA8E3F4B0CCE09BABC07B879E58DAF4ABC2E096CDEDA1D1EFA5CFEDA3
D6F2A8BBD58C5D742E000F00586F29D4EBA5D0EAA3D2EEA4BFDB91CAE89ECCECA0D0EFA3
D8F2ABC8DF99E1F6B1D9EEA9B9CE896D823DABBF7AD1E5A0DDF1ACC8DC97D6E7A3CEDF9B
D8E9A5D1E29ED4E5A1B5C07EA09E639F965D948B52C4BB82FAF1B8E8DFA6E6E0A64B450B
D8D298E3DEA4E2DDA3B2B075747237E3E1A6D9D99D938E54BEB17AF4E3AD9D8C56A69760
DCCF98594E16E4DBA2E5DFA55C571DA6A469D6D69A696A2E9B9F629096587E8446787F3C
A5AD629DA85CC2CC87E1EDABD3E3A4CBDFA0D3E9A8C9E49DCAE99BC9E996C8EA94C9EB95
CAEE97CCEF9BCDF0A0D2EAB0FEFFF1FEF9FDFFFDFF9F9AA17F7C85FFFDFFFFFDFFFFFEFF
FCFDFFFEFFFFFCFFFBFCFFF8FAFFF1F4FEE6E9F3DADDE8C6D2DFB3C4D89DD8F4A9D6F5A5
B8D28B8A9C5ED3DBA8D0DDA5CAEA9FD5F1A7E7EAB50008003E704A579A71BEF9C9B9F2BF
8AC69397D3A0B5EBB9B5E3B4D3F7C9859F723243179FAC81
D6EAA2D2E89FCDE59BCAE49ACBE79CCBEA9EC9EB9EC6EB9DC6EB9DC6EB9DC6EB9DC8EA9D
C8EA9DC9E99DC9E99DC8EA9DC5EC9DC3ED9BC5EC9DC5EC9BC6EB9DC6EB9BC8EA9DC9EA9B
C5E599C5E496C8E79BCAE699CCE69CD0EB9ED0E89EC9E399C2DE93D7F3A8CDE99EC5E196
D4EEA4CFE99FC7E197DAF4AAA6BE7471893F93AB6198B066475F159AB067D2E89FC6E096
C8EA9DC5EC9DC6EB9DC6EB9DC8EA9DC9E99DCAE99DCCE89DD6F0A6C6DE94CEE69CCAE097
E2F8AFDBEFA7B6CA82687C34778E4896AD67BED38ED4E8A3D6E7A3D1E09DCFDE9BD2E19E
CCD896C0CF8C8B9A5740510D4D611CADC27DBFD690C8E49ACCECA1CEF0A3C9E99EC0DE94
C6E19AD5EFA8DAF1ADD3EAA6D3EAA6CBE29CCEE8A1C5E099D0ECA2D9F7ADB0CF83D4F3A7
CCE69FCFE6A0C6DD97BFD690DEF3AED8EDA8B7CC876B803BDFF3AEBDD18CD0E19DC8D995
D8E9A5C7D894E5F6B2E0ECAAD6DC9EE6E7ABD9DA9ED2D296C7C78B69692DD0D094B5B378
A4A267BAB57BDAD59BFCF7BD9B965C8C874DD4CE94847B42877A439F925B60531C9F945C
FBF2B96D672DCEC98FE3E1A687874B717236D8DC9F595F21A5AB6DA3AC6DB2BB7CD8E39F
D9E59BCCDA8DD8E59FDDEEAACDE0A0CBE1A1D2EBA9C9E49DCBEA9CC9EB97C8EA94C8EA94
C8EA96C8E998C9E99DCEE5ADF8FCEBFDF9FAC6C1C5706B71BEBBC4FDFAFFF5F4FCFDFCFF
FBFCFFFDFEFFFEFFFDFCFFF8FCFFF4FCFFEFF5FDE6ECF5D6D6E3B8E7FBC0BFDB8EC3E390
4C661FC9DB9DC3CD99D1E0A7BEDE92C4E095E0E3AC2A330866966EA5E6BBBAF4C1A9E8BB
9BEBCE20786254A18D6BAF9A6CA28B0E361C000B00889D7E
CBE399CAE298C7E197CAE69BCCEB9FCCECA0C8EA9DC5E79AC8EA9DC8EA9DC8EA9DC9E99D
C9E99DCAE99DCCE89DCAE99DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DCAE99DCAE99D
D6F2A7B0CC81DFFBB0D3EDA3B8D288D9F3A9D2EAA0C8E096CBE59BCFEBA0D4EEA4C2DC92
C6E096EBFFBBBAD48A3D570D879F55C5DD93D3EBA1C2DC92C3DB91E1F9AFC5DD93D6F2A7
C8EA9DC5EC9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DCAE99DC9E59AC9E399D7F1A7D4ECA2
BED68CC4DA91D1E79EC6DC93CEE89FCBE59EB8CF898DA25D5C702B4357124C5D195C6D29
4657138FA05CDCEDA9D7EBA6C7DC97DEF5AFD8F2ABD2EEA4BEDE92C5E79AD1F1A6D5F5AA
CFEDA5C5E099C4DB97C5DC98C6DD99E0F7B3CAE19DD0EAA3CAE49BC8E49AEAFFBBB8D489
C0DA93DBF2ACD5ECA6D9F0AACCE19CD0E5A0C8DD98CEE39E3D510C627631BECF8BE5F6B2
DFF0ACBFD08CCDDE9ACDDE9AD1E09FD4E3A2E7F3B3D0DA9BD7E1A25861226F7537C8CC8F
5A5B1FAEAE724C4A0F8C874DE6E1A7605A209C935A9C935A5F541CD9D097E7DEA5ECE6AC
CFCA905D5B2097955AE3E4A898995D4B5113ECF2B4D0D99ADEE8A9D9E3A4CFDB9BD4E19C
D3E398CDE091D1E59DD2E7A2CBE1A0CFE8A6D3EEA9C6E49CC8E99AC9EA99CAEC98CAEC98
C8E998C8E79BC7E59DCDE1ACFAFFEBFFFEFD5F5B5C807B7FFFFDFFFFFDFFFFFEFFFFFEFF
FDFCFFFEFFFFFDFFFCFCFFF8FBFFF5FCFFF3F7FFEAEFF8DBCBD8ADD4E8ADCFEB9E466613
97B16AC4D698CED8A3DCEBB0D2F2A6D8F4A7DADDA47D865795C498A5E4B5B4EAB6B2F2C0
AAFFE01E7C643E927B0040270D492F8FBDA04D6F4E89A380
CCE69CCDE99ECFEBA0CDECA0CCEB9FC9E99DC5E79AC4E699C8EA9DC9E99DC9E99DCAE99D
CCE89DCCE89DCDE79DCDE79DCCE89ECCE89ECCE89ECDE79ECDE79ECDE79ECDE79ECDE79E
D7F1A8CBE59CC8E299AEC57D91A8608FA65E8EA55D91A86090A85E8BA55B81994F8DA55B
98B066738B416B853BA3BD73D1EBA1D2ECA2D6F0A6D7F3A8C7E197CCE69CC4DE94CFEEA2
C6EB9DC5EC9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DCAE99DC2E195C9E59AC7E398D0EAA0
D2ECA2D8F0A6D2EAA0D3EDA3D0ECA2CFEBA1CEEAA0CEE89FCEE59DCCE29AC9DD96C6DA93
E0F4ADC6DC94CEE49CCEE59DC7E198C4E096C5E197C7E59BD8FAADC6EB9DBDDF93C4E499
CDEBA3D1ECA7D4EAA9D6ECABDAEFAE778C4990A562879E58829951CBE59CCEE89ED2ECA2
DDF4AEC4DB95C5DC96C9E09ADCF3ADC6DD97CCE19CE4F9B4D6EAA5B3C7829AAE69AFC37E
BBCC88E5F6B2E4F5B1CCE09BCFE6A0C8E29BD3EAA4BBD28CD7EBA692A35F3F4B09606B29
868C4CD9DE9E5C5C1E636124A8A467655F239B9257B2A96E696327BAB679E8E4A7E0DEA1
D9D99B9FA162999B5CDCE2A2949A5A5D6826D2DD9BD6E2A0C4D390CBDA97DAEBA7D4E8A1
CFE698CFE897D1E99FCDE7A0CBE6A1CEEBA8CDECA6C3E39AC2E497C5E896CBEC9BCDEE9D
CDECA0CEE9A2CEE8A7D3E5B5FFFFEFC4C0BD464241B3AFB0FFFEFFF9F7FCFFFDFFF2F1F7
FFFEFFFFFFFFFDFFFEFBFDF8FDFFF7FEFFF4FAFEEFF1FADFD3E0B5D4E8AB96B2658CAC59
D2ECA5D4E6A8D8E2ADD8E7ACBDDD91DCF8ABC2C389535B2A81AF80599764C5FAC2BEF8BD
8CD59D6EBD84A8F1B9A8E9B188BF86B2DFA63F6228A2BF85
CBEA9ECCEB9FCCEB9FC8E89CC5E599C5E599C8EA9DCDEDA1C9E99DCAE99DCAE99DCCE89D
CDE79DCFE79DCFE79DCFE79DCFE69ECFE69ED0E69ED0E69ED0E69ED0E69ED0E69ED0E69E
BDD38BDAF1A9889F5797AE66CFE69EBDD48CD1E8A0D9F0A8D3EBA1CDE59BDBF3A9DBF3A9
CAE298D5EDA3D3EDA3AFC97FC4DE94D1EDA2C8E499C6E297D3EFA4D4F3A7C6E599CBEB9F
C6EB9DC6EB9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DC9E99DD1F0A4DBFAAECCEB9FC6E297
CBE79CC5E196BFD98FD0ECA1CCEAA0CAE89ECBE79DCDE99FD1EBA2D4EEA5D6EDA5D6EDA5
C9E098CEE59DD7F1A8C5DF96C7E399CFEDA3D8F6ACC3E398CBEDA0C8ED9FC9EB9FC9E9A0
C8E6A0C8E3A0CCE2A1CFE5A4D0E4A5788D4CDCF1B0E5FAB7D4E9A47B924AA7BF75CAE49A
C7DE96D4EBA5D7EEA8D1E8A2C6DD97DEF5AFC7DC97B9CE89CADE99D1E5A0BED28DB4C883
7E8F4BA7B874C3D490D5EAA5CCE7A0CCECA3CAE8A0D1EFA7D0EAA3D6EDA7D0E49FD3E4A0
DEEAA8D9E4A2DCE2A2DADF9F5E5E20949456C8C689CDCB8EBBBB7D5E60214F51125E6323
DEE3A3C6CC8C6F78374F5A1855611F8A9956DBEAA7D3E4A0E3F7B2CFE39ED8EDA8C8DF97
D2ED9ED1EE9CCBEA9EC7E59DC8E7A1CBEAA4CAEBA4C9EBA1C5E79AC8EB9BCBEC9DCBEA9E
C9E49DC7E09FC9E1A5CFDEB3FFFFEF7A7772B5B1AEFFFEFDFFFEFFFCFAFDFFFEFFFDFBFF
FEFDFFFFFFFFFEFEFEFCFEFBFEFFFAFEFFF8FEFFF6F7FCE6FCFFDD8DA16492AE61D3F3A0
CDE7A0CBDD9FDAE4AFCBDA9FCBEC9DCAE797E6E7AB6F7643A4D09F89C48E6B9D6072A45F
30681FAFE79CA7DD92BBEAA2BAE59EC8EDAA567635C1DF9F
C5E79AC5E79AC4E699C3E598C4E699C6E89BCBEB9FCEEEA2CAE99DCCE89DCDE79DCFE79D
CFE79DD0E69DD0E69DD1E59DD1E59ED3E4A0D3E4A0D3E4A0D1E5A0D1E5A0D1E5A0D1E5A0
D8ECA7CFE49F92A762AABF7ADDF4AED2E9A3D1E8A2CCE39BC1D78ED3E9A0CFE59CC7DD94
CDE59BCDE59BCDE79DDFF9AFC4E095DEFAAFCDE99EB9D88CCDECA0D4F4A8CAEA9EC4E699
C8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC1E195C3E397C5E599C6E599
D4F3A7D0EFA3CDE99EC7E69AC2E096C7E79CCDEBA1CBE99FC7E399C4E096C8E49ACDE99F
CBE79DC5E197CCE89ECCE89ED4F2A8BFDD93C8E69CC8E89DBEE093C8ED9FCFF1A5CBEBA2
C9E7A1CFEAA7D2E8A8CCE2A2CEE2A5A3B577CFE2A2B7CC89D3E8A39CB36B95AD638CA45A
D5EFA6C6E099C5DF98DEF8B1C2D993E5FCB6CDE49ED4EBA5CBE09BD7ECA7D7EBA6CCE09B
90A45F94A86392A6618DA45EC4E29ACCEEA4C2E299D3F1A9C1DF97C5E099D2E9A3CEE39E
D5E9A4C6D793CFDE9BE1EDABADB675DEE7A6C7D08FE4EDACD0D696ADB675A4AD6C8A9352
DAE3A2E6F1AFC3CF8D8B9A5790A15DCBDF9AD7EBA6C3D893D1E8A2C3DA94D0E7A1C9E39A
CBEA9ACBEC9BC5E79AC4E69CC6EAA2C5E9A1C5E9A1CDF2A5CAEC9FCBEE9ECAEB9CC7E59B
C6DF9DC9DEA3D1E3B1DBE7C1A6A996414139F3F2EDFFFFFBF6F5F3F7F5F6FFFEFFF8F6FB
FFFDFFFFFEFFFFFDFEFEFEFCFFFFFDFFFFFBFFFFFAF7FCE8D9E4BC72864BACC87DCDEC9C
B9D48FD6EAADD7E1ADDEEDB2D1F2A3B7D283EAEAAC7C814BB8E0ACAEE5AC1846052E540B
385908D4F19DD7F2A3D2ECA2C9E29EC5DFA0446026AEC994
C8ED9FC8ED9FCAEC9FCBEDA0CBEDA0CBEB9FC8E89CC6E599CCE89DCDE79DCFE79DD0E69D
D0E69DD0E69DD1E59DD3E49DD4E3A0D4E3A0D4E3A0D4E3A0D4E3A0D3E4A0D3E4A0D3E4A0
CFE39E8FA45FCBE09BD6EDA7BFD690D8EFA9CDE49ED3EAA2D5EBA3CFE59CD0E69DD0E89E
CBE399CAE49ACCE69CC6E297DAF6ABBBDA8EC6E599D9F9ADC7E79BBEDE92D2F4A7C4E699
C9E99DC9E99DC9E99DC8EA9DC9E99DC9E99DC9E99DC9E99DCBEB9FC2E296D2F2A6C8E89C
C6E599C2E195D4F3A7C8E89CCFEFA4C9E99EC5E399C9E79DD0EEA4D1F1A6CBE99FC3E398
CEECA2C8E89DC6E49AC0DE94D7F5ABC4E298CCECA1C8E89CCDF0A0CBEE9EC3E598C2E299
D2EDA8CFE8A7A2B87A6B7F4293A569D7E9AD455719D4E7A5D5EAA5D2E89FC8E094B4CC82
8DA75E87A15AD5EFA8CAE49DCEE59FBFD690D4EBA5CEE59FD5EAA5C6DB96CDE19CD8ECA7
D0E49FCBDF9AB6CA858FA45F8AA55EC5E39BD5F3ABC0DE96CCE7A0D5F0A9C3DD96D7F1AA
D0E7A1D5ECA6CCE19CC9DE99D6EAA5D0E49FD1E5A0D0E49FD4E3A0DDE9A7D0DC9ADEEDAA
D6E5A2CCDD99D1E5A0D4E8A3CFE49FD8EDA8C3DA94DCF6AFC5DF98D0EBA4D2EDA6C9E79D
C7EA98C8EE9BC6EB9DC7EDA0CBF1A6C2E89DBFE399CAEFA2C7E99CC9EA9BC9E89CCAE5A0
D0E5AADCEEBAEDFCD1FCFFE6373A2947473FF6F5F0FEFDF8FFFFFBFFFFFDF9F7F8FFFEFF
FFFEFFFFFEFFFFFEFFFEFCFDFFFEFFFFFFFDFBFAF6F2F4E6A2AC87D5E8B0CDE99EC7E698
D5F0ABD7EBB0CFD9A5D0DFA6C7E69ADEF9AAD5D4944C4F18CAF1BAB7EAAFC2EDA8C2E498
D7EFA1C2D788D2E79CD2E7A2D1E7A9CDE6AD122C00638052
C4EB9CC3EA9BC8ED9FC9EB9EC4E699CBEB9FD1F0A4CDE99ED3EDA3CCE49AD6ECA3CDE199
4B5F174A5E164657104E5F182938003C4806434F0DCFDE9B8D9C596A7936152600566723
5B6F2ABFD48FDFF4AFC8DF99D2E9A3CFE9A2C1DB94D4EBA3D0E69ED0E69DCFE79DCFE79D
CFE79DCDE79DCDE79DCCE89DCBE79CC8E79BC9E89CCAEA9ECBEB9FC9EB9ECAEC9FCEEEA2
CBEA9EC9E89CC4E397D3F3A7C1E094CCEB9FC7E69ACCEB9FC5E599C7E79BCEEEA2CDEDA1
C3E397C5E599C8E89CBFDF93C9E99DC9E99DC9E99DC9E99DC9E99DC8EA9DC9E99DC8EA9D
D4F4A8BDDF92CDEDA1CCECA0CCECA0D4F4A8C5E599C8E89CC4E797C6E999C8E89CD5F3AB
D3EEABC4DD9C748A4C000D005D6F35DAECB0A2B476D5E8A8CBE09BD4EAA1D0E89CD1E99D
D0EAA1CDE7A0758F48001200C5DF98D3EDA6D6EDA7C7DE98D2E9A3C9E09ADFF4AFC5DA95
DFF4AFD7ECA7C1D590DAEEA98FA55D91A860D0E79FD1E8A0C7E198CBE59CD4EEA5C8E49A
CCE89ECAE89ECAE89EC9E99EC9E99EC9E99EC8EA9ECAE89ED0E69ED1E59ED1E59ED1E59E
D1E59ED0E69ECFE69ECFE69ECDE79ECDE79ECCE89ECCE89ECCE89ECAE89ECAE89EC9E99D
C6EB9BC5EC9BC5EC9DC3EC9EC3ECA0C3ECA0C5EB9EC6EB9DC7EA9AC0E094CFEDA3C0D998
D8EBB4D7E7BAF6FFDEECF4DC7D7F71D6D6CEFFFFFAFFFEF9FEFDF9FFFFFDFDFBFCFAF8F9
FFFDFFFFFDFFFFFDFFF2EEEFFFFEFFFFFFFDFFFDFCAAAA9EFDFFE2D2E3ADCEEAA0CDECA0
CBE6A3D8EBB3D8E2B0CEDDA4CCEB9FD2EA9CE4E0A185864DBEE4ABBCEEB1C5EDA6CBEDA3
BDDD9AC8E8A9CBEAAFC1DFA992B07E577748000E00001500
C5EC9DC5EC9DC5EA9CC7E99CC8E89CCBEA9ECCE89DCBE59BBDD58BD8EEA5BFD38BBDD189
4F631BDAEEA6D3E49DA9BA739EAD6896A5628897549BAA6793A25F91A25E9DAE6ACCE09B
B9CE89DDF4AED4EBA5BED891CFE9A2D0EBA4C6E099D3EDA4CFE79DCFE79DCFE79DCDE79D
CDE79DCCE89DCCE89DCCE89DC8E79BC9E89CC9E99DCAEA9EC9E99DC6E89BC7E99CC9E99D
C3DF94CFE99FD4F0A5CBE79CCDE99ECFEBA0CFEBA0C6E599CDECA0C6E69AC6E69AC4E498
C2E296CAEA9ED3F5A8D3F5A8C9E99DC9E99DC9E99DC9E99DC8EA9DC8EA9DC8EA9DC8EA9D
C9EB9EC6E89BD2F4A7C4E699BFDF93C8E89CC1E195CAEB9CCCED9ECCED9EC8E79BBFDA93
C7E09EC9DFA18CA0650115007788517B8D53D2E4A8DFF4B3D5EAA5CDE59BCCE498C8E396
BED88FE7FFBAC9E39C849E578CA65F77914A8DA45ECEE59FD1E8A2DDF4AEC9DE99CFE49F
C6DB96C9DE99E1F5B0CDE19CB2C37D9AAB65D6EAA3D0E49DD4EAA2D4EBA3CAE49BD1EFA5
C9E99EC8EA9EC6EB9EC5EB9EC3EC9EC3EC9EC2ED9EC5EB9ECCE89ECFE69ECFE69ECFE69E
CFE69ECDE79ECDE79ECCE89ECCE89ECAE89ECAE89ECAE89ECAE89EC9E99EC9E99EC8EA9D
C6EB9BC5EC9BC5EC9DC3EC9EC3ECA0C3EC9EC5EC9DC6EB9DC3E696D0F0A4D1ECA5D6EEB0
E2F4C4EBF7D1FCFFEA727763B9BBB0F0F0E8FFFFFAFBFAF5FEFDF9FFFFFBFFFFFDFFFEFF
F1EDEEFDF8FCFFFDFFFFFDFFFFFEFFD5D1D29E9A99DDDDD3FEFFE4D0E1ADC9E49FCCEAA0
C8E2A3D0E3ACD2DBACCFDEA7C4E397CBE395E1DB9D85824BC6E7AEC1EFAFC5E9A1C5E79D
CEF5B4C9F0B7BCE3ACCFF6C1587E4D13390A00210095BC90
C6ED9EC7EE9FC3E89AC5E79ACDEDA1CAE99DC8E298CFE79DD5EBA2D3E79FDDF1A9879B53
C9DD95C7DB93E3F7AFD6EAA2CADB95CFE09AD7E8A2BED28BD1E59EC6DC94D5EBA3D9F0A8
DEF5ADD5EFA6C6E097C6E298D5F1A7D0EEA4C7E399CCE89ECCE89DCDE79DCDE79DCCE89D
CCE89DCCE89DCCE89DCAE99DC8E79BCAE99DCBEA9EC9E99DC7E79BC6E69AC6E69AC7E69A
D6F0A6D5EDA3D3EBA1C1D98FDAF4AAC7E197CAE49ACFEBA0D1EDA2CAE99DC8E89CCAEA9E
CAEA9EC8E89CC3E598C1E396C9E99DCAE99DC9E99DC9E99DC8EA9DC8EA9DC6EB9DC6EB9D
BFE496C8ED9FD0F2A5C0E295C3E397CDEDA1C7E69ACEED9FCEED9FC3DF92CAE49ACBE29C
E3F9B9CEE2A58B9E66000D004D5E28364710CCE0A3C9DD9ED1E8A2CAE49AD0EB9ED2EEA1
CAE69CC2DD96BED992E3FEB7D5EFA8BFD992809A53617B34D0E7A1C8DF99C9E09ADCF3AD
C1D691D3E8A3D1E6A1D2E6A1C7D691A4B16C97A661CFE09AD2E69FDAF0A8BAD48BCEECA2
C9E99EC6EB9EC5EB9EC2ED9EC1ED9EC1ED9EBFEE9EC2ED9EC9E99ECDE79ECDE79ECCE89E
CCE89ECCE89ECCE89ECAE89ECAE89EC9E99EC9E99EC9E99EC9E99EC8EA9EC8EA9EC8EA9D
C6EB9BC5EC9BC5EC9DC5EB9EC5EB9EC5EB9EC6EB9DC6EB9BCCEF9FC6E599C4DD99D0E5AC
E1F0C5F6FFE1FCFFEF737769F4F5EDFFFFFAFFFFFBFAF9F5FFFFFBFFFFFBFFFEFDFFFEFD
FFFEFDFFFEFFFFFAFCFAF4F6FFFDFF716B6DFFFDFFFCF9F0FEFFE8CDDDAEC6E09FCBE9A3
CBE5A8D6E8B4DBE7B9DFEDB8CFEDA3D3E99EE3DB9D817C44CEEBB1C7F1B1CBEBA0C8E89C
B5DE98B8E6A6C2F0B2B5E2A7B6E3A8A3CE96A4CF99CEF9C3
C4EB9CCAEFA1C6E89BC6E69ACFEEA2CCE89DCCE49AD8EEA5CADE96CEE29ACCE098859951
D8ECA4C8DC94CADE96CDE39AD0E69ED9EFA7D5EBA3DDF3ABD9F0A8D3EAA2C3DD94CAE49B
CAE49BC1DD93C7E399D0EEA4CFEDA3C8E69CC8E69CCAE89ECAE99DCAE99DCCE89DCAE99D
CCE89DCAE99DCAE99DCAE99DC9E89CCBEA9ECAE99DC8E79BC8E79BC9E99DCAE99DCBE79C
C4DA91CCE098D3E79FCCE299C8DE9594AC62A1B96FDEF8AEC5DF95C5E196C4E397C9E99D
D1F1A5CEEEA2C6E89BC8E89CCAE99DCAE99DCAE99DC9E99DC8EA9DC8EA9DC6EB9DC6EB9D
C4E99BC9EEA0C6E89BC1E396CFEFA3D3F2A6C6E599C9E598D6F1A2C2DD90D9F1A7D2E7A2
CBDFA086985E596A34000B004D5E289AAB74CEE2A7C4DA9AD2ECA5CDE99ECAE699CFEEA0
DBF7ADC6E19ACCE7A0C6E19ABFD992C2DC95C9E39CACC67F1E3500B6CD87C1D892D7EEA8
E2F7B2CADF9ACEE39ECDE19CD9E8A3C2CF8A8D9C57CCDD97E0F4ADC7DD95CCE69DD2F0A6
C9E99EC8EA9EC5EB9EC3EC9EC2ED9EC1ED9EBFEE9EC2ED9EC8EA9ECAE89ECCE89ECAE89E
CAE89ECAE89ECAE89EC9E99EC9E99EC9E99EC9E99EC9E99EC8EA9EC8EA9EC8EA9EC8EA9D
C8EA9DC6EB9DC6EB9EC6EB9EC6EB9EC6EB9DC6EB9DC8EB9BCCED9ECDEBA1C0D997CBDEA7
FBFFE1FCFFEC0003005F625BFFFFFAFFFFFBFDFCF8FFFEFAFFFFFBFFFFFBFFFBFAFFFEFD
FCF8F7F1EDECFFFDFDF4EEF07F797BFFFDFFFFFCFFFFFEF8FDFFE8D4E4B7CFE9AACBE8A6
D0E9B0EDFFCFF7FFD8F1FFCEE1FFB9DDF3A8E3DB9D766F38CDE9AFC6EDACCEEA9FCFEB9E
DCFFBAACD593CCF4B5D0FABBC7F0B43B642A59824AA9D29A
C3E89AC9EEA0CAEC9FC8E89CCDE99ECFE99FD2EAA0D8EEA5DDF1A9A2B66E9FB36BBDD189
BCD289DBF1A8D7EDA4CCE49AD0EAA0D2ECA2BCD88DCDE99EC3DF94CFEBA0C2DE93D4F3A7
CCEB9FC8E79BCDECA0CBEB9FBEDE92C1E195CEEEA2CFEFA3C9E99DC9E99DCAE99DC9E99D
CAE99DCAE99DCAE99DCAE99DCAE99DCBEA9ECAE69BC8E499CBE79CCEEDA1CEEA9FC9E399
AABE76A3B36C86975097A8619BAC65849850758B42A2BA70D3EDA3D8F4A9CCE89DC2E195
C8E89CC9E99DC8E89CD2F2A6CCE89BCCE89BCAE99BC9EA9BC8EB9BC8EB9BC6EB9BC6EB9B
CBF0A0C8ED9DC1E494C6E999CCED9EC7E698C7E396C9E497D0E89A9EB46995A96191A560
AEC0828D9C636A7843000D0060713DE5F8C1D7ECB3C8E1A0D3EEA7CBEA9EC4E596C9EA9B
C8E69CC6E19AD6F1AAC5E099DAF5AED7F2ABDCF6AFB9D38CC8E29B7B954ECBE29CCEE59F
B3CA84D5ECA6DEF3AECEE39ED5E9A2CDE199CCE098ABBF77D3E9A0B6CE84D9F3A9CDE99E
CAE99DC9E99DC8EA9DC6EB9DC5EC9DC5EC9DC3EC9DC5EC9DC8EA9DC9E99DCAE99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9E99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9D
C8EA9DC8EA9DC8EA9EC8EA9EC8EA9EC8EA9DC8EA9DC9EA9BC7E698CBE79DD5EBABDFF1BD
D8E4C0353D2853564DFDFDFBFFFFFDFBFBF9FDFCFAFFFFFDFFFFFDFFFEFCFFFEFBFFFEFB
FEF9F6F2EDEAA49C9AC5BCBDFAF1F2FFFCFDF0E6E7FFFEF8FEFFEBE9F8CFE4FDC3CCE9A9
CFE7B3F7FFDDFCFFDFEAF7C9DEFBB8DAF0A7DFD59A6B642ED1EAB1C4E8A8CBE59BD0E598
D1E8A4D0E9A8C7E1A4C5E1A7BBD9A387A77596BA8A9EC493
C4E99BC7E99CCEEEA2CCEB9FC9E399D5EDA3D5EBA2C1D78ECEE29A93A75FBBCF87CFE39B
E0F6ADC0D88ECDE59BCEE89EC2DE93CDEC9ECBEB9FC6E798CFEFA3D1F2A3C9E99DC5E697
CEEEA2C9EC9CCBEB9FC6E999C3E397CAED9DCFF1A4C6E89BC8EA9DC8EA9DC9E99DC9E99D
C9E99DC9E99DCAE99DCAE99DCBEA9ECBEA9EC9E59AC7E398CDE99ED1EDA2C6E297B8D086
76863F8E9B55919E58BECE87D5E59ECCDD96798D454B6118BDD58BD7F1A7D5EFA5C5E196
C9E89CC7E79BC1E195CAE99DCCE89BCDE89BCCE89BCAE99BC9EA9BC8EB9BC6EB9BC6EB9B
C5EA9AC4E999C5E898CDEE9FC5E496C5E194D8F3A6D2EA9EA4B96C899B5182934C8E9F5B
CEDCA1DAE9B29BA974000A005E6F3BBED19AD7ECB3C5DF9ECCEAA4C4E498CBEE9ECAED9D
C6E49AD3EEA7D0EBA4CCE7A0CBE69FC6E19AC8E29BD8F2ABD9F3AC92AC657D944E9DB46E
DFF6B0D4EBA5D0E5A0C3DA92CCE39BC7E197DAF2A89CB66CA5BF75DFF9AFCFEBA0C2DE93
CCE89DCAE99DCAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9D
C9E99DC9E99DCAE89EC9E99EC9E99EC9E99DC9EA9BCAE99BC5E194D8F2A9B6CC8CCEDEAD
DFEACA000400DFE0DBF4F4F6FFFFFFFBFBFBFFFEFFFFFEFFFEFCFDFFFFFDFFFEFBFFFBF8
FFFEFBAEA9A69B9391FFFDFBFFFCFDFAF1F2FFFCFDFDF8F2FFFFEDF6FFDEF1FFD1CAE8AC
C8E0AEF7FFDFFCFFE3D1DEB2CFECAAD3E9A1E0D69B6F6530E0F7BFCAEDADCEE69CD3E496
C7D78ECFE09AD6E9A7D2E8A8D3EDB08DAA72BFE2ACC0E5B1
CBEDA0C1E396CEEEA2CEEDA1C5DF95D8F0A6D0E69D98AC648B9C55C6D790DBEFA7C7DB93
CEE49BDDF5ABC6E096CDE99EC8E99AD1F4A2CFF2A2BEE18FCAED9DCAED9BCAED9DC6E997
C4E797C1E794C4E797C7ED9AD0F3A3D0F3A1C8EB9BC1E494C8EA9DC6EB9DC8EA9DC8EA9D
C8EA9DC8EA9DC9E99DC9E99DCBEA9ECBEA9EC9E59AC9E59AD0EAA0CDE79DB4CE849AB067
B3C07AD3DE99DFEAA5D6E39DCEDB95D3E39CCADB94BCD08880964DBAD288CEE89EC6E297
D1F0A4D5F4A8CBEB9FD1F0A4CDE89BCDE89BCCE89BCAE99BC9EA9BC8EB9BC6EB9BC6EB9B
C1E696C2E797C8EB9BD0F1A2C2E193CEEA9DD9F4A7A5BB709CAE62BECE83D8E8A1D6E5A2
DCE7ADD5E2AC8F9B69000A0070804FC0D29EDCF4BAD2ECABCCEBA5C0E295CDF3A0C1E794
CEEEA3CAE8A0BEDC94C9E79FCEE9A2CFEAA3C5DF98CCE69FD3EDA6D7F1AADDF4AE99B06A
8AA15BC1D892D3EAA4CEE89FD0EEA4C8E89CCBEA9EBDDC90A7C67ACBEA9ED0ECA1CCE89D
CDE79DCDE79DCDE79DCFE79DCFE79DCFE79DD0E69DCFE79DCAE99DC9E99DC9E99DC9E99D
C8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99D
CAE89ECAE89ECCE89ECAE89ECAE89ECAE99DCAE99BCAE999D5F1A4BBD58CDCF2B4D7E7B8
6D785AA7AE9EFFFFFDFFFEFFFFFEFFFEFEFFFFFFFFFFFFFFFCFAFBFFFFFDFCF8F5D9D5D2
95908DF5F0EDFFFDFAFFFDFAFEF4F3FFF5F4FFFCFBFAF5EFECEFDAE7F5D1E7FFC9C6E3A9
C7DFAFF7FFE1F7FFDFCBD8ADC9E6A4D2E8A0E3D99E706430E9FEC6CEEEAFD1E79CD6E896
E1F39DCFE68ED3EB97BBD685D0EFA1739549CCF0A8C9EEA8
D0F2A5BEE093CEEDA1D0ECA1C2DC92DAF2A8CADE96768A42C1D28BC5D68FD5E9A1D2E89F
C9DF96CEE89EC7E197CBEA9CC3E696C7ED9ABDE390CBF19EC6EC99C9EF9CBEE491CDF3A0
CBF19EC7ED9AC2E895C7ED9ACCF29FC3E996C2E593CEF19FC6EB9DC6EB9DC6EB9DC6EB9D
C8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99DCAE69BCAE69BD0EAA0C8E298A6BE7482964E
D9E6A0D3DD98DCE7A2CFDA95DBE8A2D7E7A0DEEEA7C5D9918B9F57CCE49ADDF5ABC4E095
C8E499C9E89CC0E094C6E599CDE89BCDE89BCDE89BCAE99BCAE99BC8EB9BC8EB9BC6EB9B
CAEF9FC6EB9BC8E99ACDEE9FC2DE91D0EC9FC2DA8E536A1CD4E69AD8E89DD4E19BD4E09E
D4DFA5D6E0AB8B9765000C00606E3DDDEFBBC4DCA2CCE9A7C6E59FBFE496D2F8A5C2E895
CBEBA0C8E69ED2F0A8C5E39BCCE7A0C8E39CD4EEA7C8E29BC8E29BCAE49DC2D993D4EBA5
92A96393AA64CEE59FD0EAA1CBEBA0BDDF92D5F7AAC8EA9DC9E99D446418CCE89DCBE79C
CFE79DCFE79DD0E69DD0E69DD1E59DD1E59DD3E49DD0E69DCCE89DC9E99DC9E99DC9E99D
C8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99D
CAE89ECCE89ECCE89ECCE89ECAE89ECAE99DCAE99BCAE999C9E497D8F2A9C8DC9F5B6B3C
616C4EE4EADCF7F7F7F8F7FDFFFEFFFDFCFFFFFFFFFEFEFFFCFAFBFFFFFDEBE7E6AEAAA7
FFFEFBFFFAF7FFF7F4FFF9F6FFFCFBFFFCFBFBF1F0EFEBE2D3D6C3CDDBB7D5EDB9C3E0A6
CCE3B5F7FFE3FCFFE4D7E4B9CAE7A7D2E8A0E0D39C665A26E2F7BFC6E6A7CEE398D6E892
CBDE84D8F092CBE488DAF79DC2E38C83A652C1E696C1E899
pop
P
% End of image
1 0 0 r
.03 w
.55676 .00207 Mdot
.55797 .02818 Mdot
.55151 .06299 Mdot
.57412 .09316 Mdot
.55958 .12043 Mdot
.50386 .14596 Mdot
.47438 .17149 Mdot
.53091 .23009 Mdot
.55029 .25562 Mdot
.57573 .27245 Mdot
.57452 .31887 Mdot
.60198 .33918 Mdot
.65851 .33743 Mdot
.70616 .38675 Mdot
.72473 .403 Mdot
.69243 .42157 Mdot
.72272 .44013 Mdot
.6993 .44594 Mdot
.66134 .45696 Mdot
.59067 .44594 Mdot
.5721 .45232 Mdot
.5402 .4587 Mdot
.49901 .47263 Mdot
.43562 .5527 Mdot
.30277 .67454 Mdot
.26158 .73431 Mdot
.20666 .73953 Mdot
.34396 .82772 Mdot
.3165 .87994 Mdot
.264 .89097 Mdot
.2002 .89039 Mdot
.11985 .884 Mdot
.10168 .91882 Mdot
.12025 .93448 Mdot
.13923 .94783 Mdot
.15377 .96001 Mdot
.10975 .99889 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.666667 0.34127 0.984127 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
ADCD81C1E195CDEDA1C9E99DC7E79BCDEDA1CBEB9FC2E296C9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC9E99DC9EC9CC6E999CAF09DC6E999C8E89CDCF5B1C0CF98FFFFDC
5F5A3D382B1A0D000023120B6E6158FFF9EC787763000500545D32B7C498FBFFE6F9FFF1
F8FFF8F6FAFBFBF9FEFFFDFF8274731B0C0536251BFFFDF1F9F0E9FFFFFBFBFCFFFCFFFF
FCFDFFFFFEFFFDFBFEFBF9FAFFFEFDFFFEF9F5F2EDFFFFF6BDBDB3FFFFF4FFFFF4F2F8EA
FAFFF4FBFFF6F9FFF8F8FFF1FCFFECFCFFE4A3AF89CADCACD0E3ACD8EEB0CEE4A4CDE2A1
D0E3A390A061465618D6E8AACFE2A2CDE4A0D7F0ACC7E09CCFE3A688975CD9E7A9D1DBA6
676A4FE3E5CDD3D8AFDEE7AED7E29E8999505B6B2AC3D790D2E798D3E89DCEDFA8EEFBCF
FCFFDAD3DFADDAEBB47D93538BA65FCCEAA0BCD88DDDF7AECCE19EBCCF8FACBA7DDCECAD
C8DD9CD3EDA6C4E498C1E696BDE899DAF8AECDCF8E777636D6EAA5D1EFA7C7E29BD3E29F
51460E8D824AD4E2A4D7DDA1603A0D735123C8D698CBEFA5CFEA9BCCE894C8E797C5E898
D4F2A8ABB97B6957296B552ED1D6ADFCFFDAFFFADA7C6442493C12B6B682D2E2A3CDE6A2
C9E39CD2EEA4C4E797CDF4A1CFF9A5BDE697C2E5A1C9E4ADDCECC5F5FBDF82816DF1ECD8
5B553DADAA89D2D0A9E2E3C3FFFFFAFAFDF6D9E4C2D2E5AECEE2A3C4DA9CE0F0C3E2EDCD
F7FFEAFEFFEDFBFFE1E6F3C5DCF0B3CBE9A3C3E59BC9EFA2CDF0A0C8E99AC4E397C9DE99
DBE1A3605E254D420ADADA9CCFE59DC7DF95B0AF6FACB073C5E5A4C9EFB2D6E7BAEDF9CB
DAEEB9CCE6A5C4E093C4E18FD4EFA0CEE7A5EDFDD6F7FFE9
C2E296CAEA9ECDEDA1C6E69AC4E498C9E99DCCECA0C9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC8EA9DC1E699CCF2A5B9DF92CFF5A8BEE096B9D694E7F8C4CFD6AD
4A462B1206000F010024150EFFFDF30B0500030200585D3DC7D0A5DBE8BCE9F4D4EDF9E5
FBFFFBFCFFFFFFFEFFFEF8FA75676612030038271DFFFDF1FFFDF6FFFFFBFAFBFFFCFFFF
F3F4F9FFFEFFFFFEFFFFFEFFFDF9F6FFFFFAFFFFF8FFFEF2B7B8AAF3F5E7FBFFEEF7FEEC
FBFFF3F9FFF3F8FFF2F7FFEDF9FFE5D4DEBBD2DEB6E1F1C2D0E3ACCADEA3D0E4A5D8ECAD
D8EBAB94A7677F9153D1E3A5D0E4A5CCE2A1D2EBA9CEE7A5CCE0A5AABC80C1CF92D8E0AD
686B50FFFFE7D9DBB3D1D9A0D7E49F96A65FCDE09EDEF2ADD5EA9BD0E59AC7D69FE9F6CA
FCFFDADFEBB9D0E1AAD2E8A8D4EFA8CEECA2B9D58ACAE49BDBF0ADC3D69695A36696A667
BDD291CFE9A2CEEEA2D5FAAACAF5A6B7D78CF0F2B1656424B8CC87CCEAA2D8F3ACCBDA97
60551DA2975FD6E4A6DBE1A5946E41725022D6E4A6CCF0A6CEE99AD3EC9BCCED9CC1E396
D7F7AED1E1A397865A75633B90976BD7E0B56254316C5631A89D70E3E3ADC9DC9CD0EAA3
D2E9A3C7E198D0F1A2CAF09DABD581C0E99BDFFFBEC4E0A6F1FFD8FCFFE673735BFFFFEA
FAF6D95A5734E1E2B8D3D4B4FFFFF8ECEFE6C3CEACD5E6B0D7EBACCFE3A6D9E9BCE1ECCC
FEFFEDF9FCE7FFFFE3E8F4C4BDCF93C7E09CD6F5AFB7D98FBCDF8FC6E798C6E297E4F8B3
DAE0A25D582062571FEAE8ABD2E8A0CFE59CD7D696D4D599CAEAA9C0E6A9E2F2C5EFF8CD
E5F7C3D0E8AAD6F1A4CEE998CFEA9BD1E7A6EFFFD5F8FFE6
CEEEA2CCECA0CAEA9EC7E79BC7E79BC8E89CCAEA9ECCECA0C9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC6EB9EB8E29AC1ECA5C8F3ACC4EFA8D2F9B6D3F5B9C4DAABB7C39F
41432D524C3EA79D94E1D7CE070000030200161A01D2D9B7E6F2C4DCE9BDE5F0D0F6FFEE
FBFFFBFCFFFFFFFEFFFFFAFCA99B9A190A03150400F0E4D8FFF8F1FFFFFBFAFBFFF8FBFF
FEFFFFFDFCFFFEFCFFFFFFFDFBF8F3F6F3ECFCFAEECECCBDE7E8D6FFFFEDFEFFECFCFFEC
FBFFECDAE7CDCBD9BFCDDCBDDDE9C3909D72F2FFD3F4FFD1DDEEB8CDDEA7D2E4AAD2E6A9
C5D7998FA364B9CD8EC8DC9DD0E6A6CCE2A4D1E7A9D4E9AED4E9B090A268EEFCC1D7DDAD
64624BFDF8E4FFFFDDEAF1BBC7D39191A25BE5FAB7BFD48FCDE293D7E99FD8E5B0DCE7BC
9CA578C4D09EBDCE97DCF2B2CDE8A1C8E69CD6F2A7D0EAA1C9DE9BCEE1A1B2C08392A263
D9EEADD7F1AAC3E397BEE393BBE697DCFCB1C8CA89CACA8AD8ECA7B7D58DC9E49DD4E3A0
554811AA9D66D9E7A9E6ECB0B792656C4C1DD4E4A5C2E69CC8E394D2EB9AD1F2A3BDE295
C4E5A0DCEEB2D9CEA1C7B9927B87575866358E855CFDEEC3FFF7C6DCE1A7DAEDABC3DD96
D9EEA9CAE098C5E194C9EC9CD3FAA9CDF6A8BCDF9BC0DEA2CDE1B0FBFFDF878B6AF3F2D3
E0E0BE74744E4D4E22DBDDB8FCFCF0FFFFF6F8FFDFFBFFD4D3E5A7C6D89CCCD9ADE7EECF
E3E5D0FAF9E4FFFFE1F2FAC9D5E3A8CDE2A1D3EDACD5F2AFC5E498DEFDAFD7F1A7C5D692
D7DB9ED9D49CA2975F939154DCF2AAC2D88F908C4D919155D9F7B7C6EAADD5E2B6FFFFDC
D8E6B5C3D79CDFF7AD9EB76487A04FACC37DE3F7C6E3F5CD
CAEA9EC6E69AC6E69ACBEB9FCDEDA1CAEA9EC8E89CC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC5EBA2D1FEBDBEF0B1A6D899B3E3A59ECB909BC28D94B087677858
747C67B9B7AB817A724B443A060300060800E4EDD0CFDBB5CAD6A8C9D6AAE8F3D3F9FFF1
F8FFF8F3F7F8FFFEFFFFFDFFAEA09F34251E423127FFFDF1FFFDF6FFFEFAF4F5F9FCFFFF
FEFFFFF7F7F9FFFEFFFFFFFDFFFFFAFFFFF4DBD9CA9FA18CEBEFD6F0F6DAE7F0D1F9FFE2
F6FFE1CFDFBAC5D7B1D0E2B8D2E2B57B8958E7F5C4E9F7C4EBF9C6EAF8C3EBFAC3DDEFB5
A6BA7D95AB6BD3E9A9C9DFA1D1E7A9D2E7ACDEF3BBDEF3BBCEE3ABD9ECB4859056D6D9AC
696450FFFCEAFFFFDFE6EBB5A6B270A9BA73D0E5A4C5DC96DCF3A3CFE197B2BC888A9368
9DA67BC5D19FD9EAB3CFE5A5BDD891C4E298D2EEA3C7E198CEE3A0DBEEAEC9D79A92A263
B6CB8AC7E19AC6E69AC7EE9DC1ED9EC5E79BDBE09EE1E1A18CA05BD3F1A9DBF6AFCFDE9B
5D5019A99C65CBD99BC9CF937F5A2D684819C9DC9CC9EFA4CDE899C9E291CBEB9FC3E99E
BCE19CD9EEB5FFF8CCFFFBD2E6F8C6BBCF9AEEECBBF6ECBBF7F4BDDAE3A4CEE39EC5DF96
BCD089DBEFA7D7F1A7B6D788C2E799CBF1A6BFE39DDEFCBEE9FFCAD3E3B4697047FEFFD9
D0D2AADBDEB15E623040451DE7E8D6FFFFF1FBFFDAFAFFCFCADA9BD4E4A6B7C395ADB391
89876E8B876CB8B68FE0E2B0DBE5A9D7E7A8D2E6A9B7D08FCDE99EB9D588D5EDA3D0E19D
D6D79BF5EEB7A79A639F9B5EC4D891E1F5ADACA668868449CFECACCAECB0D3DEB3DADFB6
D5E1B3D7E6AFC6DA92687E2CD5EC9AD5ECA49BB078889B6E
CAEA9EC6E69AC6E69ACBEB9FCDEDA1CAEA9EC8E89CC9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC3EBA4A7D99EC0F9C4C0F9C480B7804F814E719C6E597B569CB397
F2FDEC3134290B080105030074756373795FE5F0CEC7D6ADD7E4B6D5E2B6E8F3D3F5FFED
F3FAF3FCFFFFFFFEFFFEF8FA968887291A133A291FFCF0E4FFFDF6FDFCF8F6F7FBFCFFFF
FFFEFFFFFEFFFFFEFFECEBE7F8F5EEFFFDF0A7A99483856DD6DBBDD0D7B5D1DCB4F5FFD7
F9FFDDD5E6B9D1E4B6DDF1BED6E9B296A771D0DEA9D4E2AFE7F3C1FBFFD3FBFFD3F6FFCE
A6BA7DB8CE90D2EAACD0E8AACFE4ABD7ECB4F8FFD8F0FFD0CEE2ADCCDFA8848F57DBDEB3
1F1805F4EBDAF3EFCCBFC18F9EAA68CDE199CCE2A1D6F0A9D7EE9ED0E29897A16DA1A87E
D3DCB1939F6DD0E1AAC1D797D7F2ABCFEDA3BEDA8FD9F3AAD3E8A5D0E3A3C8D699A0B071
869B5AC1DB94CFEFA3CCF3A2C9F8A8B9DB8FD8DD9BB3B373D6EAA5C1DF97BFDA93D5E19F
8A7D46BDB079DFEDAFD3D99D6C471AAF8F60D0E3A3C6EFA3D4F0A3C8E394C5E79BC8F0A9
C8F1AFE5FEC7FFFFD7EFEAC0D2E9B3E4FDC3C6C992E1DCA4E3E4A8D2DD9BC0D78FE1FBB2
E2F1ACCDDD96D4EAA1DBF7ACCCEEA2C4E89EC0E49EBEDC9CCEE6ACC0D19D8B9765D4DCAB
D4DAAAE6EDBA79824B6A7243CFD1B9FFFFE8FFFFD8E6F4B693A45E8C9B5A6E7844737850
47442544401D514D2095945CDEE4A4DBE7A5C8D89AE0F5B4DFF9AFBED98CD0E69DE9F8B5
D6D69AD6CD96AD9C66A2995ED4E59FC6D790B4AC6EB9B47AC5DFA0BFDEA3F0F9CEE3E5BE
E9F0C6CDD7A3D4E39E6E8130CFE593BFD58AC1D69BCAE1AD
CEEEA2CCECA0CAEA9EC7E79BC7E79BC8E89CCAEA9ECCECA0C9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC3EBA5BBF1BDB4F2C33A7849619C6C9AD2A5C2F2CAC6EBCA4C654F
00090000040075766EC2C2B6FEFFEFFBFFE8C6D4B0E0F1C5DAE8B7E6F3C7F6FFE1F8FFF0
F9FFF9FCFFFFFFFEFFFBF5F76F61600B0000120100CCC0B4F9F0E9FFFFFBFEFFFFF6F9FE
FDFCFFF4F2F5FFFEFFFFFFFAFFFFF6FDFBECC8CAB4F3F6D9DBE1BDD3DBB2D7E2B7F9FFD8
F8FFD6CFE4ACC4DBA3C6DEA4C1D69BA1B57AC9D8A1D3E0ABDEE8B6EAF4C2EFFCC7E4F5BE
B8CC91D5EDAFCAE4A5CEE8ABC4DBA3D0E4B1F9FFDCF8FFDCF0FFD1EFFFCB646E39E1E2B8
1F16051C10022721016A6C3AB8C482D1E79FC9E2A0CDE7A0C6DD8DE3F5ABB0B885FBFFD7
FCFFD98A9664C7D8A198AE6EA8C37C94B2687E9A4FA7C178DEF3B0CBDE9ED5E3A6D1E1A2
8EA362D6F0A9CEEEA2B5DC8BB9E898CBF0A3E5EAA89F9F5FD1E5A0CAE8A0D0EAA36F7B39
C9BC85D5C891E7F5B7BAC084765124F5D5A6D6EBAABCE599C8E497D3EEA1CAEEA4BFE8A2
BDE7A8E2FFC9FFFFDAE9E8BCC3DEA7B5D395EAEFB5DCDA9FADB2709CAC6591AB628AA65B
CDDA94DFEAA5C9DD95C8E298CEEEA3C6EAA0CBEFA7CCECA9C9E3A4DBEFB47D8A545A642F
E5EEB7D4DDA6E0EBB1A6AE7B373B1A34381539420B5E6B266B7B308F9F587E874E898A5E
928E68ECE4BDE1DBA7747033555815A3AA66D6E2A4C9D99AC7DD94DDF5A9C8DC94D9E5A3
DDDBA0F0E5AFE4D09B675D22D5E49FE6F6AFBDB376CAC48AD6EEB0C8E5ABEDF4CAFFFFDD
EBEDC6CDD5A2E0EBA7919F50D9EC9ADBF2A4E5FBBBBCD39B
C2E296CAEA9ECDEDA1C6E69AC4E498C9E99DCCECA0C9E99DC9E99DC9E99DC9E99DC9E99D
C9E99DC9E99DC9E99DC2EBA7B9F3C140835A3D805582C398A0DAB2BFF3CFBDE5CA000B00
000700A1ABA2FEFFF8FCFFF2F4FCE5F9FFE6D0E0B9C9DAADCAD8A7E8F5C9FBFFE6F9FFF1
FBFFFBFBFFFFFCFAFFFFFDFF31232213040058473DFFF3E7FFFDF6FFFFFBFEFFFFFCFFFF
FFFEFFFDFBFEF8F7F5FFFFFAEBE9DDB1B09EB2B59AE1E5C4D7DEB5D1DAADD7E3B1F6FFD1
F3FFCCD6ECAED3EBADD0E9A8C2D89793A768D1E0A7DAE7B1D7E1ADD3DDABD4E1ACCBDAA3
BACF94D3EBADCAE4A7C8E1A7C6DDA7CADEADF9FFDDF9FFDDE6FCCBF3FFD298A26EDCDDB5
0A0000AB9D90605A3A868857CEDA9ACFE59DD3ECAAD2EDA8C9E090C4D48BBFC693E9EBC3
FFFFDCC9D5A3EAFBC4C0D696C6E19AC5E399D2EEA3D3EDA4F8FFCAD6E9A9DBE9ACD8E8A9
8EA362D5EFA8CEEEA2C4EB9ACCFBABC4E99CC5CC89979757C1D590D1EFA7455F189BA765
F2E5AEDFD29BCAD89A595F236D4B1DECCD9ED2E7A6C3ECA0C2DE91D6F1A4C7EBA3BEE7A3
BAE6A9D6F4C0FFFFDAF3F6CBCAE9AEC6E6A7D9E1A5616123989F5BCBDD93BCD88D98B469
041100CCD691EAFBB5C5DC94C5E59CC6E89ED1F5ADC1E29DC1DB9AD9EFB1D8E7AC000A00
D1DCA2E0EBAFD0DB9FD5DFAADEE3BBD2D8ACDAE4A5DCEA9DD3E593DBE99CD1DA9BE8EAB8
F0ECBFC9C192FEF5BCE5E09E53530B555811C6CF8EE1EDADCFE39BCFE59AD5E69FD9E4A2
DFDAA0EADDA8EDD9A4998F54020F00C8D58FABA164918B51BDD597D8F5BBDEE5BBFFFFDB
DEDEB8F7FACBCDD69398A556D3E591C9DE8FBBD190DDF5B9
B1CB81C4E095CDEDA2C9E99ECAE699CEED9FC8EDA0BFE497CAEA97C9EB97C6EB9BC5EB9E
C6EB9EC5EBA2C3EAA7BEEBB0487D4F4A835A6AA27B7BB18DC7F8D86994794A6B562E4636
7E8E83EAF4E9FCFFF4F9FFECFBFFE8F0FEDAD6E9BCD3E7B6D7E7B6EBF8CDF0FBDBF5FEEB
FCFFFAFDFEFFFAF8FBFFFCFF3F3432342721786B62FFFDF3FFFEF6FDFCF7FDFEFFFCFDFF
F5F1F0FFFEFBFEF9F6FFFEF9DDDAD1CED0BBFEFFE4E7F3C5D8E5AFD1E0A5D1E3A9EBFFC4
E9FCC5DAEEB9E5F9C4E2F6C1F0FFCE92A36DDDEAB4D8E5AFD2DCA7CED8A3D9E6B1D2E3AC
B1C789C3DC9BD2EDAAC9E3A2D4ECB2CFE3B2F7FFE2F8FFE3E2FAC6EBFFC9C0CB93D8D7AB
584E35D4C9B3A19F78EDF6BFCFE49FD3EDA3CCE5A1C7DE96B2C778798B41DBE8B0D8E4B2
E9F8C1CFE1A5C9DF9FD0E9A5D5F0A9C3E199CEEAA094AE65E4F9B6C9DC9AD6E6A5D0E09F
8FA461C9E09AC6E298D3F3A7BBE093D6F2A8C0C784DCDE9DE1F2AECFE6A0435A14B9C583
E1DBA1E0DAA0DEEDAC4D5617A68F5DECD7A2D5E5A6C5E69FD0ECA2CDE99FB6DA94CDF4B3
DEFFC9DDFAC4EFF6CADCE4B5CBE7ADCDEBAB929E60ADB471DFECA6D2E79CD5F4A6C2E193
4E601695A55E869A5391A8607E9C546D8D44BBDB92CEEEA5D3ECA8CCE39FC9DC9A5D6D2C
04140095A567DAE9AED0DFA6D5DFADD2DCA7DFEEA9CBDE8FC8DE8BD8EB9CCEDD9AD6E0A4
D7DCA4E4E5ACD6D696DCDF98DFE59B949C53626D29909C5ADCE9A389995294A55F4F5B19
4C4A0F71682F52470F3D3900505D18D6E19D998D53ADA46DD4E6ACCAE1ABB1B38BE0DCB6
BFC29747501B54601ED9EA9CCCE290CFE799DCF6AFC5DF9E
929D58D2E39DCEEBA8CCEAA4D1E898C3DE8FC5EFA7BEEA9DCBEA8DD8FA99B3E08BCAFDAE
B5E398BEEFADB8EEBD5D9268376133B6DAACD0F0CBCDEACE89A08C000700000C03E8F2EA
F8FFF5FCFFF3F4FCE4FCFFE4E6F2CADEEEC1D4E6B4CFE1AFD2E4B4DDECC3FBFFE8FCFFEF
F8FBF2FFFFFDFFFDFFFFF7FA2F25240C03002C231CFDF6ECFFFFF6FDFEF6F3F5F0FFFFFA
FFFEEFFFF1E4FFFCFAC8BFC0E1E0DBFCFFEFE9F9CCCCE2A1C7E494D3F09EC9E49DC6DEA4
E2F4CAF4FFE4F7FFEBFBFFEFFCFFEFBCC2A6EAF3C6D6E3ABCEDC9FDCECAED1E2AB8DA068
B3C989C8DF99DAF3A2D8F0A2C9DE9DC3D5A5F9FFEDEBFBE0C9E8ADC8E6A0CED89B9F9C69
191000747144BECB93C8E3A0CEF0A3C1E291D0E89CD0E59899A95EA2B66ED5F0ADC7E4A1
C3E294C4E393CFEEA0D4F2A8C3E199D0EEA8D5F0AB95AF68D4EBA5C4DA92DDF3AACBDF97
ABBF78CBDF9AD7ECA7CFE39ED1E29E9FAA68515616E2E7A7E4EFADCAD9964B5A17D2DE9C
DEE4A4E0E6A6D3DF9D5762208E8C51F0EEB1D1DB9CCFE2A0D1ECA7BCDB97CEECACE0FEC0
E6FFC7E7FCC4D6E3AECDDAA5D8ECB1879B5E98A869C4D591D7EDA4D8F3A6C4E393CAEB9A
D1EDA086A257D4F0A6C4E096CCE7A08DA95FA3BF75CAE49ACDE599D4EB9DCFE59AD7EDA4
20350033490BCEE3ABCDE2AAC2D699D3E8A7D4EBA3CBE59BCBE79ACBE79CCCE89ED4EEA7
D3EDA6C7DE96CDE39AD9EFA4CAE193C9DF9499AF666A7934555A1A4F5414758544B0C47F
D9DDA0EBEDAED3DC9B9DA967CBDA99E2E8ACA29561928455D4DBA8DAE3B49D9973EAE7BC
F0FDC5CEE4A3C9E09AD3EDA3BCD88DD4F3A7BEDE95D1F3A9
9AA05ADBE8A3C9E6A4C0DD9AD9EAA3DCF2A9D3FDB5B8E797BADE7EC1E382CDF8A6B4E79C
C0F8B1B9F4BA6EAA84376D4D98B98ECCE3B78295755968513943382F362F707571FEFFFB
F9FDEFFCFFEDF4FEDCF8FFDCDAEABBD2E4B0D0E3ACD1E5B0CFE0B3DDEDC6FAFFE7FEFFEF
F8F9F1FFFDFCFFFDFFFFF8FB22191A0C0401423B35FFFEF5FFFFF6FFFFF8FDFFF9FFFFF6
FFFDECFFF2E4FFFAFBA4999FFFFEFFECF5E2E5F9C8CBE9A1C5E88ECEF197C5E399C7E0A7
E6F7D5F9FFF3FAFFF9FCFFFBFFFFFAE0E3D0D2DAB1D6E3ABDCEBAACDE09EA8BA80465A1F
C5DB9AE0F8AEC5DD87BFD783DEF2ADD1E1B2ECF7E6F7FFF1C7E6ABC3E199C9D3965A5923
221C00C2C28CC5DA99CAEAA1C9EEA0BEE18FDDF6A5CFE29387974CDAEEA6CFEDA7BFE497
D7F9A3C7EA90C2E28FCDECA0C0DE98BFDA97CAE4A3B0C985D1E8A0DDF5ABC6DC91E2F7AC
8CA058CDDE9AD2E2A1E0EFAED9DFA19196567A7F3FD4DA9AD6DF9ED5E09E6A7634D1DD9B
D1DD9BD9E5A3D6E2A04D5917A2AB6ACCD594DEE4A4D9E5A5C7E09ED1F0ADC6E3A3E3FDC0
DEF3BADEF1B9EBFAC3DCEBB2D6E4A9566628B1C484CCE39DD9F3A9C8E497BDDC8CD4F5A4
C5E697C6E69AC6E49AC8E39CD8F1ADB8D18D90A75FCFE79DD0E799D0E797C6DD8FCBE196
879E5A162E00C4DBA5D2EBB2D9F2B0CEE8A1C4DE95C8E49ACFEDA3C9E99EC3E398C9EB9F
CCEEA2C8E89CD1F1A5C1E094D9F5AAC7E398C0DA90BBCC86A1A1639C9D61AEC380CAE19B
D2DD9BDBE6A2D7EDA5BED58FCCDC9BDFE5A99E915DA99B6CE4E8B6D8E0AFACA97E9F9E6E
DDEDAFBCD790E3FEB7CBE9A1D1F1A8CDEFA5CBEDA3C6EB9E
9BA35AD6E69FCCEBA7CEECACD6E3ABBBC98EBEDD97C9F2A3C5F097CEF49FD8F3ACC0E4A4
8DC88E599D6A85BE9B97C4A5C0DBB86F805E35432A283322384239E0E7E0FCFFFBFCFFF8
FCFFF1FCFFE8E7F3CDE5F5C8D1E3B1CBE0A8CBE2AACAE1ABD0E3B5E5F5D0FBFFE8FCFFEF
FFFFF8FFFCFBFFFDFFFFFCFD201615070000554E48FFFEF5FFFDF6FFFFF8FEFFFAF8F8F0
FAEEE0FFF5EBA09196EBE1EAF6F5FAFBFFF4DDF0C3CCE9A6C9EB97CEF09CC7E4A1CBE1B0
E8F7DAF9FFF6FCFFFBFDFFFAFBFDF2B5B9A2E1EABFD8E6ABCFDE9DCEE19F74864AD2E6A9
CEE4A3C4DC92C2DA84E0F8A4C8DC97DCECBDEBF4E3F4FFEDCEEBB5CBE8A6E5F2BAC2C693
1C1C00DBE0AAC3D395DAF5B0CEEEA2BDDE8DD2ED9C99B060AABF72D4E8A0D1EAA6D3EEA7
C0DD8BCCE995CCE89BD3EEA7D0EBA8CCE5A4D5EDAFCEE4A3A8BF79CDE39AD8EDA2C2D78C
B7CB83D5E9A2C6D997D2E1A0DDE3A5979C5C9FA464D3D999D3DC9BD2DD9B98A462D3DF9D
D4E3A0D5E4A1DAE6A45662206F7837D8E1A0DCE2A2CFDB9BCBE4A2CEEBA9BBD596C8E0A2
D6EBB0E2F6BBF8FFCEE9F8BFCFDEA3BBCB8DC3D696D3EAA4C8E299CBE79AC2E191CFF09F
C8E99AD5F5A9C1DF97D3EEA9CCE5A4D6ECAC9DB271CBE09DD2E69FE2F6AEC4DA8FE0F6AD
CEE5A14E66285F773D98B076CCE2A1C8E29BC9E39CCCE7A0CBE69FC5E39BC7E79ED1F1A8
C3E39AD0F0A7CCEAA2D0EBA4C7E29BD3EDA6CDE49ECDDE9ADADF9FD3DA97D2ECA3D4F0A5
CADB94CFDF98D7F1A7D0ECA1D9EFA7DDE8A68B854B9E9760D6DFA6D2DFA7EBEDBBAEB37D
F1FFC2CBE29EBFD692C9E29ED2EDA8C7E59DC3E39AC4E69C
8F9A4CD3E59BC7E8A3C1E0A5DAE5BBDDE4B8DCF1ACC4E797BBE79ABBE39CD2E1A8D8EEBF
4D8A603E8660ABE3C0BFE6C75F735A5A6650000800767E73BCC3BCEBF0EAF8FEF4FCFFF3
FCFFEAF2FEDAD2E2B5D0E2AECFE4ACCDE6ACD1EAB0C8E1AACDE3B4E7F9D3F9FFEAF9FFEC
FFFFF8FFFBF8FFFDFDFFF6F7180E0D070000797069FFFEF6FBF8F1FEFDF8FFFFFBFEFBF4
FFFDF3D0C3BDACA1A9FFFBFFFDFDFFF9FFF8E7F9D1CAE4A7CAE99DCDECA0CAE4A7CEE0B6
E3EFD7F8FFF5FEFFFDFEFFFAFEFFF2A5AB8FDEE7BAD4E2A7D6E6A5DCF0AB263A00D3E7A8
D5ECA6CAE296EEFFB2D0E694DEF1AFDFECC0FBFFF1F7FFEFCBE2B4D2EBB2C2D39FC7D0A1
060C00D4DBA8DBE8B0D0E5A4C5DF96DDFAAAC4DF8E809B4AD8EFA1C0D48CD4E7A5D2E6A1
D9EFA4DDF5A7CEE59DDBF2AEE6FCBED2E7ACCCE0A5CEE2A3B6CB88DDF3ABCCE196C9DE93
99AD65D5E9A2D8EBA9D7E7A6D3DC9BA1A7679CA262D9E2A1DBE6A4C7D391AFBB79DDE9A7
D7E6A3D6E5A2D5E19F909C5A55601E9EA766DDE3A3D9E5A5D4E9A8C9E3A2CDE5A7D3E9AB
E6FABFEAFCC2E3F2B9E4F3B8D2E1A6D7E9ABD4E9A8D4EBA5BED88FD8F2A8D1EDA0C5E494
CCEB9DC3E296C6E19CCAE3A2C8DDA2CEE1A9899D62C8DA9EC0D393D4E8A3D3E7A0B3C981
D3E8A5C1D797000D006E8446CDE4A0D1E8A2D7EEA8D2ECA5CBE59ECBE6A1C9E7A1C0DF99
C7E59FC1DF99CAE5A2D5EEACD5EEACC4DA99D4EAA9DCECABE1EAA9D5E09BCAE99DCBEC9D
CAE095CFE499CEED9FC5E697C8E396D1E19A919050A19F62D8E7A6CFE2A2FEFFCBCDD59A
ACBA7CE5F8B6DEF3B2CFE6A2CEE7A3CBE6A1CEECA6CDEDA4
A3B05EC7DC8FC0E39FDAF8C6F2F7E0E8E7CBE9F4B2D0EB9CD1FFBCB7DEA7DCDEB6C7D0B3
205E454D997F3C6F502F4D310006007A7F78BABFB9FCFFFDF3F8F4FCFFFAE8EEE0F1F9E1
EAF6D2E2F2C3CCE1A9C8E0A4CFE9AACDEBABDFFDBFDBF8BEC5DCAEE3F5CFF6FFE7F2FBE8
FFFFF6FBF7F4FFFCFDE1D7D8080000080000A0958FFFFDF6FCF5EFF7F2EEFFFEFBFFFFFA
FFFDF4C4BAB8FFFBFFF6F2FFFCFFFFF9FFFBDAEBC7D1EAB1CAE5A0CCE7A4D1E8B2D7E7C2
E5EEDBFBFEF7FFFFFDFFFFFAD7DCC8FCFFE3CBD7A7C2D196CEDE9DDCF0AB798E4BD6EBA8
D4EAA2C1D88ABBD17FBBD083738344DFEABFFCFFEFDDE6D3C7D7B2D4E7B9E0F3C6D1E0B5
7D8A5FD6E2B4CFD9A5CAD89DC2D691DDF5A9C6E391AFCF7CD1EC9DD7EBA3DAE5A3C8D391
CEDD98CFE09AC9D99AEFFEC3F9FFD3D7E8B2C4D59ED2E4AAA7BA7AC1D590D2E69EDEF3A8
849A51879D55D7ECA7CCDD99D1DC9A959E5D8F9857D7E2A0DBE6A4CBD7958F9B59DBEAA7
CDDC99D7E6A3D4E09ED0DC9AA2AD6B3A4302B1B777E9F3B4CFE2A2DCF2B2BCD091F8FFCD
EFFFC5E3F5B9CDDCA1D4E3A8D7E9AD435616D1E6A3D2E9A3CCE69DD1EBA1D0EC9FC7E698
C8E799CDEBA1D0EBA8CBE3A7DEF2BDD0E2B0546433D2E0ADE2F1B8D4E4A6CEDE9DEAFEB9
D7ECA9BFD493CFE3A47F9453203500081D00102500344B07526B276883406B86435B7835
6A84436A8443587233BED698C6DC9EE4F8BBC8DCA1C7D799D7E2A0CDDE97C3E598C5EA9A
CFE79BD1E99BCAED9BC0E693CBEA9AD2E4989D9E5A999C59D3E7A0C3DD96D7E6A3D4DE9F
9EAA6CCAD89ACDDD9FCBDE9ED9EEAD90A66566813E617F39
CADD84CFE696CAEAABF1FFE3FFFFF6FFFFEDFFFFCCCEE29AB3DFA4C3E8BDDDDBC4D3D9CD
4C857E276F61001900000F00000400FFFEFFF3F2F7FEFFFFFEFFFDF7FAF1DBE3CEC7D2B0
CFDFB2D6E9B1D4EDACCDE8A3CEEDA9C7E7A4E6FFC7F0FFD4C7DEB0E2F3CFF9FFEAF4FDEA
FFFFF6FDFAF5FFFDFBB8ACAC0A0000080000A99E98FFFDF4FFFDF8FFFDFAFFFCF9F8F3F0
A59E96FDF8F5FFFCFFFFFDFFF2F6FFF8FFFBDAEBC9CEE5AFCDE7A6D2EAACE2F6C5EEFCDB
F6FDEDFFFFFAFFFEFBF9F9EF4B5135F2FFD4D0DEA9DCEEB0D0E3A1C6DC9490A560CFE59D
D3E99EDEF5A7D4E99A4F6117CFDDA2C3CBA2FEFFEFEDF1E2E0EBCDD1E1BCEEFFDDB8CEA8
6B7D57D4E0B8D4DCADE3EAB4DFEBAB8A9F54C6E693CCEF9BC8E797D0E49CE5EAAADEDFA3
D9E2A1FEFFCAFEFFCFE4EEB9D0DCAAC8D4A4E4F0BEFBFFD3516123CADE99BFD38BDFF4A9
D4EAA1465C13D4EAA2D2E6A1E2EEAC8E995799A462D6E2A0D3DF9DD7E6A3697835BECD8A
D0DF9CD7E6A3E2EEACD7E3A1D2DD9B717C3A515A19C4CE8FD2E0A2D0E2A458682AC8D89A
D6E6A8DDEDAFD6E5AAC8DA9CD1E3A541561598AF6BCFE6A0CEE89FC8E298C7E398D2EEA1
D2EEA1CBE79DDDF6B5F5FFD3E9FBCBF3FFD87A875CDBE8BCD1DFAEC8D7A0D2E2A4CADA99
D7EAA8C8DD9ADFF4B1C5DA97CDE19C9BAF6A9AAD6BC2D794CEE4A3CAE3A1CEE7A6CCE6A7
BFD99ABCD699041C00000D00667941D8EBB3CADBA5DFEEB5D3DF9FD2E69FC9EEA0C6ED9E
CBE699CBE397C6E997C9EF9CD4F3A3D4E69A9E9F59939651D1E79ED1EDA2CBDC96E2EEAC
505A1DDDE8ACD5E3A6D0E0A2D3E5A7001100DCF5B3B3CE8B
D5EE92D9F4A3CDE8B1D3E6C8DBDAD5F9F3E7EBEEB96F7F3E5B7D4A607F5D5D60572D363B
002E3600201E527D629CB49CF4FAFAFFFDFFF9F6FFFCFBFFF5F7F2FAFEF0CED7BCDAE6BE
C8DBA3D0E6A5D3EFA5C9E99DCFF1A5C0E49CDDFFBFE1FFC7CDE4B6E3F4D0F9FFEAFAFFEF
FFFFF6FFFCF8FFFCFB8C80801C0E0B291C16C9BCB4FFF5ECFFFDF8FFFDFAEDE4E5C4BFBC
8D8A81FFFFFAF0EFF7FDFDFFF9FFFFE6F2E8F4FFE3C2D9A5CFE7A9D2EAAEEAFBCEFBFFE6
FEFFF3FFFFF6F4F1E8CBCCBAADB590F0FECDDEEDB6D5E7A9CDE09ECEE49C677D34D0E89C
CBE294CCE393CEE3966E7F39D6E3ADAEB68FFFFFEDE6E8DAD9DEC8E9F6DCF4FFECCAE3C3
596E4DD2E2BDE3E5BDCFCE9ED8DEA274853EC5E695C3E994D0F1A0BCD088DDDB9ECAC48A
3236008D955AC7CE9AD3D9A9CFD6AAD3DAAEE1EABBD9E6B1768648B8C887E8FCB4C7DC91
C4DA8FDAF0A7819850D7EBA4D3E29F909C5A8D9957D7E6A3D1E09DD9EAA68E9F5B94A561
D8E9A5D2E39FE1F0ADCCD896CDD896D9E4A2616A29ADB677D8E4A69DA96B3E4C0E697739
C8D698D5E5A6DDEDAFCBDE9ECDE0A0B8CD8A778E48D0E7A1C5DF96CEE89EC6E096CFEBA0
D5F1A4C0DC92DCF5B4F5FFD6E8F9CDF8FFE1D1DDB9D2DEB8DBE6BBD6E2B0D5E4A9E1F1B2
CEE29DD5E9A4D2E7A2D2E7A2DDF1ACC1D590CBDE9CDDF2AFD1E7A6CCE5A3D3ECABCBE3A5
E1F9BDCFE7ADD0E5AC6E834B30420E334410D7E5B2D4E1ABD5E1A3D6EAA5C9EDA3C3E99E
CDE49CCBE199C5E498CCECA0C0DB8ECEDE95A09F5CA0A15FC8DE95D8F2A8CFE099D9E4A2
727A3EE0E8AFE0E9B0C9D498000C00A0B274C8DE9ED9F2B1
D7F698B7D484CBE1B3E2EED86C6B660301000D13000D1A001D3707051E01637172000515
294C5F6D969CE9FFF6F1FFF3FCFFFFFBF5FFFFFDFFFFFFFFF8FBF4FCFFEFD8E3C1C8D8A7
D2E8A8CCE69DC6E595BFE290D1F3A6BFE399CEF3AEC1E3A7CFE4B9E1F0CFFBFFECFBFFEE
FFFFF6FDF8F4FFF8F76C5E5D221310594A43FFF9F2FFFCF4FFF7F3FFF7F5D8CFD0B1ABAB
F9F9EFFFFFFAFDFEFFFCFFFFF3FBFDF8FFF6E1F2CECFE6B0C8E0A2CADFA4E5F4C9FBFFE6
FEFFEFF7F8EAD0CFBD94977CD1DDAFD7E9AFCEE0A6C7DB9CCFE4A1DBF2AA5D7529D2EA9C
CDE492DDF2A3CBDD93B0BE80CFD9A7B1B795F9FBE6FFFFF3FBFCEEFCFFF3EAFDE9D7F1D8
5B72560008005E603BE9E6B99EA168C7D691CCED9CC8EE99CBEC9DD7E8A1C3BD817C6F3A
97965E898E58919563CCCFA2EBEDC5D8DDB4D7DEB2D9E3AF97A56AC6D695D0E49CD7ECA1
CFE59AD8EEA3AFC67E192F00A2B36F889754647330D5E6A2D5E6A2CFE39ED8ECA77C904B
D5E6A2CDDE9ACEDD9AD9E8A5DFEBA9CBD694E2EBAACED796D6DEA2727A3E9AA467485215
DEEAACCBD99BCDE0A0D2E7A4D4E9A6BAD18B97AE68D7EEA8C9E39AD6F0A7CDE79EC8E298
C7E396D1EDA3CFE7A9C2D9A3F3FFDAF6FFE1EEF9D7C2CEAAE8F3C9CAD6A6DCEBB2CADA9B
C8DC97E2F6AFC7DD95CFE59DD4E5A1D0E19DD7EAA8D0E5A2C6DB9AD8EEADCCE5A493AB6D
69814598B0765A6F37D3E8B0B4C5917888573644139CA974D8E1A8D5E5A6C2E39EC1E59F
D8EBA9D9E9A8C9E49FC9E49DD4E9A4E0EBA9969255828141869751ACC37BCEDD98D6E19F
B9C186AEB67DD5DDA4DAE5AB071500C6D89AD3E9A9CEE7A6
CFF495D2EEA3CBD7B3D5D9CA000200010600121D002B3908546133869A7EB0D1D8001C35
6D819AA9BBC7EDFFF8E4FDE8FCFFFFFFFCFFFFFDFFF7F7F5FEFFF6FAFFEAD2E1B8CEE1A9
CDE7A0CAE797D0F09BBCE089CAED9BC1E699CDF0ACC7E6ABCEE0B6E5F3D2FCFFECFDFFEF
FEFBF2FFFDF7877C7A3A2C290B00007A6B64FFF6EFFFF5EDFFFCF8FFFCFBAFA6A9EFE9E9
FFFFF6FEFFF6FEFFFFFBFFFFF9FFFFF4FFEFE2F4CCD2E7AFD5EBADC8DCA1EEFDD2FCFFE6
FFFFECFFFFECA5A58BB9BD98D4E3ACD5EAA9CDE1A4CEE4A4D9EFAE7E954FB3CB7DCAE390
CBE290D7EC9DCFE09AD7E5AADAE1B7A1A487FFFFEDFBF9ECFFFCF3FEFFF8F2FFF5BCD3BF
677D660008006E6F4DB9B68B777A41D4E39EBFDE8ECBF19CCAE99BD5E59E7F743C8C7C48
BEBB86BABC8A717344E0E3B8D7D9B2E2E7BFCBD2A8DEE8B6DAE8ADA6B675D6EAA2D1E69B
C9DF94E1F7ACC6DD954F651D7687438B9C5893A460C0D48FCEE29DCADF9ADAEFAAA8BD78
D0E49FC2D691DFF0ACD8E7A4D9E5A3C5D08E97A05FD6DC9CD7D89E5F6026D8DC9F7D8647
D9E3A4D2E1A0D1E4A2CFE49FD0E7A1C9E39C92AC65C3DD94D5ECA6CBE29CDBF2ACCCE39B
C9E59AD1EDA3CCE5A4C8DFA7E5F6CAF8FFE3E9F4D2B8C4A0E0EDC2CFDDAAD7E6ADCFDFA0
C6DA95D3E9A1E1F7AEC6DC94D0E19DD6E7A3D0E49FCADF9CD4E9A8D4EAA9AAC382768E50
7F975B879F6562773F8BA068DAEBB7CADBA70210002E3A08DAE1ABD1DFA4C8E5A5CFEDAD
C9D79CDEE9AFDCF0B3CEE4A4D1E1A3B9BE847C723D79723B94A062B3C686929E5E8D9559
D7DCA29CA46BD4DCA39FAA70000B00D8EAACBBD191DDF6B5
C6ED94BAD59073785A0301003C412ABFCDACE2F4CED6E7BBCBD4A5D2E7C879ACB06897B1
DDE6FFFCFEFFF1FFFBF1FFF6FBFFFFFFFFFFFFFFFDF9FFF5FCFFF1F8FFE5D2E4B4CDE3A5
D0ECA1C9E996CFF099C2E48DD1F4A2C9EB9FC9EAA5BBD79DD7E8BEE0E9CCFEFFEDFAFBEB
FDF9F0C7BEB90A00000B0000978581E6D5CEFFF9F0AEA199CFC4C0C5BBBAC6BDC0FFFDFD
FFFFF4FEFFF4FCFFFDFBFFFFF9FFFBF6FFEDE5F6CCD3E8AFCADEA1C6D7A0EFFCD1FBFFE3
FAFEE5EAEDD2B7B896DBE3B4D0E3A3C1DB94DCF2B2D0E8AA8FA8675F7932BFD789D5EE9A
DDF5A1BDD283869554C0CA96D4D8B5ABAB93FFFFEFFFFFF4FFFEFAFFFFFBF2FDF5D1E3D5
5F705D000700353616B3B286C8CD93DEEDA8D5F4A4CCED9CC4DF92DCE9A35B50189E8E5B
DFD9A5D7D9A77B7D4ED5D8ADFDFFD8FFFFDDE7EEC4D2DCAAD4E2A79AAA69CEE29AC3D88D
DEF4A9CFE59AC2D991C5DB93778B4698AC67B2C681D4E9A4D8EDA8CFE6A0CADF9A95AA65
94A964E1F5B0C9DA96C9D895BECA88515C1AAFB877E3E8A8C3C18698965BE9E9ADA7AB6E
DBE4A5D9E8A5E2F6B1D0E79FCCE69FD2ECA3A5BF76A2BC73CEE59FCDE49ED1E6A1D0E79F
C8E499CCEAA0CCE6A5CCE3ABE4F7C9F8FFDFEAF9D2C6D5AC647143899A64ACBB80DCEFAD
D8EDA8CBE199BAD088DAF0A8CEE29BD3E7A2D8ECA7C8DD98A3BA7689A2609BB472BFD897
C9E1A3C6DEA2D1E6ADA1B67DB1C48DD8E9B3A3B17E86935E2B320068733B5E783B698346
7A854D98A16C81905994A56E555F2AA3A371817344796D3DC5CE95CEDEA0DDE7ABE0E5AB
B8C0878A9259DCE5AC697438253500DAECAED7EDADC7E09F
B8DF90F4FFCF35351B060000818B68D7ECC1EAFFDBC5DAAFE5F1BFCBE5C2488A8976B0C4
F9FDFFF4E7F8F7FFFDE6FBECF9FFF8F8FEF2FBFFF3F3FFE9F9FFEAF1FFDBCDE4ACC8E3A0
C3DF92C8E893D2F39AC2E38CC1E090BEDC92D5F0ADE1F6BED8E4BEE6EACFFAFCE7FFFFF1
FFFEF67267631C0D0A150300E5D4CDFCEBE3CBBDB48B7E76CBC0BCC3B9B8E1D8DDFFFDFC
FFFFF4FEFFF4FAFFF9FAFFFCF9FFF8F7FFECE5F6CAD3E6AEE4F6BAD0E1ABE7F3CBFAFFE4
FEFFE8E0E3C4C1C69DD5E0A8D9EFA7BEDA8FD7F0AEC9E3A67D975886A15CCAE596D2EB97
D4EC98CDE2958F9D62DFE6BCDCDCC0B4B19EEEE8D8FFFEF4FFFCF9FFFFFFFBFFFDCDD7CE
5661510005000F1300B4BA8CDCE7ABC2D68FD4F1A1CBE898CEE499BEC784615A23ACA06C
DBD8A3E8EBB68F9160A5A87BF0F2CAFFFFDCF4FBCFD0DAA6D0DEA3899958DFF3ABD1E69B
D3E99ECAE095D6EDA5DDF4ACA2B772B9CE89D0E5A0D6EDA7D0E7A1D1EBA4CAE19BABC27C
8BA05BA8BC77DBECA8DBEAA78A96545D6826D2DB9AB8BD7D888248B2A970E5E0A6E9E9AB
DCE2A2C9D691CCE099C6DE94CFE9A0C9E59BD1EDA3678138D0E7A1BED58FD4E9A6CEE59F
CAE699CBEA9ECAE7A4CDE7AADCF3BFEBFED0E3F4C7D1E3B3BACB958EA26591A4629EB36E
D8EEA6CEE59DD7EEA6CEE59DCDE19ACDE19AD3E7A0C9DE99A4BB758BA460ADC682E3FEBB
C5E09DD4EEADD7EFB1D0E6A85E723798AC7190A2688A975F59602A3540080F2800000E00
6D7641CFD6A3EEFBC6A1AF7A88905FE6E3B679683D0F0000B1B884E5F4BBD4DDA6C9D198
DCE5ACB4BF83E2F0B35E6E309BAD6FD1E6A5C5DE9CC3DE9B
C8EBA98EA56F060200312B13D8E8BBCFEAB5CFECBCC9E5B5CCE0ADEAFFE83982796BA9B4
F4F7FFFFF8FFFCFFFFF7FFF8F9FFEFF6FFE7F8FFEAF5FFE4F5FFE1F2FFD7D8F2B5D3F1A9
CDEC9CCBEC95CFED95CFED97D4EFA2D1E8A2CBE1A1C3D49EC6CEA9FDFFE5F6F3E0FFF9EB
F9EEE82618153F2D2B897773FFFBF4F3E2DACBBDB4F0E3DBFFFDF8FFFBF9FAF4F8FFFEFF
FFFFF8FDFFF5FBFDFAFBFFFCFBFFF8F8FFECE4F3C8CEE1AAC2D39CCCDCABF3FFDBFCFFEA
EAF0D6A1A686AAB185CBD99CD3EB9FCDEA9ACFEAA7C4DDA39DB67CCBE6A3C8E394CEE793
C7DF89D6E89E95A26CE6ECC8FFFFECFFFCEEE0D8CBFFFEF4FFFEFDF2F0F3FFFFFFC2C3BE
808277050800161C00D8E4B4D3E5A7BFD58DD0EB9CD9F1A3D1E1988C9350B7B27AD2CD96
DEDFA6CDD29AA5A976A6AC7CFFFFDCFCFFD9DCE5B6DBE8B3D5E5A797A766CBDF97D8EDA2
CCE297CCE299D7EEA6C4DB93CEE59FCEE59FD7EEA8CBE59EC7E19AD0EAA3CDE7A0CDE7A0
AAC17B708540C5D994CFE09CD3E29F44500E444D0C565819A39A61C6B9826A6126535114
5F6422BDC883D2E69EE1F9AFCBE59BD3EFA4CCE89E79954B94AE67D8EDA8C7DA98D4E9A4
CBEA9CCAEB9CC9E9A0CBE8A6D0E9AFD3EAB2D4E9B1D0E5ACC9DD9ECEE5A1D5EBA3B2CA80
2B42004C661D90A965ABC57ECFE59DB0C67D8FA55D8CA35BA9C37AC8E49ACDE8A1C0DE96
DDF8B3C9E49FBFDA97D1EAA8CEE4A3C5DA99B2C6879AAA6CBDC78B8E9C617A945589A366
5F6934646B3797A570D8E6B3EEF6C53C390C705E368073475F6833102200333C05757E45
C7D296E5F3B58F9F61000D00839857BFD594D0EBA8DDFBB5
CBE9B76C7E54070400CAC7A6D8EDB5BEDE9FCCEDB4C0E3ABB5DCA7C9FCD3337E693E7A78
F8FFFFFCEEFBF8F3F7FAFDF2E0EFCECBE1B3CFE5B7CCE4B4CAE5B2CCE8AEBEDB99BFDD95
CAE999CEEB97CEEA95D2EB98CEE499D1E5A0D5E5A7DDE7B5FFFFE0FEFCE5FFFFEDFFF7EB
685B55190705513F3BB29F99FFF1EABBAAA0D8CAC1FFFDF4FFFDFAF9F3F3F2F0F5FFFFFF
FEFFFAFDFFF9FDFEFFFCFFFFFBFFFBF6FFEEE2F1CACDDDAEDCECBBD2E1B6E5F0D2FBFFED
FCFFEDCCD3B4D0D9ACCDDD9FC4DF8ECCEC99D3F0AEC8E4AA95AE75D5EFAEC7E293D0EA93
CCE490D9EAA3A6B07EDEE1C4FFFFF1FFFEF6B3ABA0FFFAF2F6F4F5FFFEFFFFFCFE070000
07000004010068704BD2E4B0D2EBA9CAE49ACEE597D8EA9E8C964F676C2AE2E1A8E5E6AD
DAE0A4E0EAAEB6BF882931007C8357FDFFD9F4FECCC8D59FDBEBADC4D59191A55DC9DE93
DCF2A7CCE299C7DD95DDF4AED4EBA5CAE49DCFE9A2CFE9A2D0EAA3CCE7A0C4DF98D2ECA5
D1E8A2DEF3AE9EB26DD3E4A0DBEAA7C9D593DDE6A5DBDD9EAFA26B4A39036A6025DBD79A
525413939E59D6EAA2C1DC8FCFEB9EC0DF93DAF8AE84A0568CA65FC8DD9AD6E9A9D0E5A0
CCEB9DC9EC9AC9EB9FCAE9A3C8E5A3C6E09FC9E2A1CDE6A2DEF5ADB9D487E0F8ACC9E497
C4DE94C2DD96BFDA97506B284C631B8AA256C4DC92CFE99FCBE59BCFEBA0D5F3A9D4F4A9
B9D78DD2F0A6CDE99FCCE69DD3EDA4CEE59DD2E9A3CCE09BDAE6A4C1D492D9F8B4CEEDAA
D8E6AB374009000B00000C00000A002B2D00A09367A39B6DDBE8B2D9EEB35F6C34041200
758546C0D391637837748B47D0E9A5E1FCB7CBE9A3BFDF96
566E4C000900C7C4A1E9EABED0E8ACC5EAA5C8EBA7C1EBABBDF4BD7FC0960C5335C1FAE9
F0FFFFFFFBFFFFF4FDFFFFF4E7F8CCC8E4A9CDE9AFCCE9AFC9E7ABCDEDAEC9E8A4CCECA1
C8E797CBE894C9E28FD3EA9ACDDE97D2E1A0D0DBA1D9DFAFFFFFE3FFFFEAF3EAD91C1004
1A0804281614DECBC7FFFAF4FFFAF3BBAAA0FFF7EEFFFDF4FFFDFAFFFDFCFFFEFFFFFEFF
FDFDFDFFFFFFFFFEFFFEFFFFFCFFFFF8FFF1E8F3D1D5E4B9C8D7ACD3E1BDEEF7E2F5FEED
DFE6D4C0C9ACD4E0B2DFEFB0D4EF9EC2E28FCDEAA8CCE7B07C955EC8E2A3D5F0A1CBE58E
D2EA96C6D791B5BE91EBEDD5FFFCF3EEE4E2968C83EBE4DCFDFDFDFFFEFFFDF1F5180507
53413D070000727C57CBE2ACC4E39FC6E599D2E79ACDD98F515711818344CED198D8DDA3
E1EBACCDD99BD3DEA4727F49868F60DBE7B7D5E2ADD8E7AED4E4A5DCEDA98DA159D0E59A
CFE59AD5EBA2D6ECA4CBE29CC9E39CCEE8A1CAE49DCFEAA3D4EFA8C8E39CC6E19AD1ECA5
D0E7A1CBE29C778B46D5E6A2D0DF9CD9E5A3D8E1A0A2A264786932B8A46FF1E2A9E7E1A3
5255129BA75FCDE297CAE598CAE699CCEB9DBFDE92C1DD937C964FCCE19ECCDC9DD4E9A4
C9EA9BC6EC99C7EC9CC9EB9FC7E79EC6E49CCAE69CD0EAA0C7E293D4EF9EC4E08CCFEC9A
C0DC91DFFDB7D2EFADD1EEACCCE69DD2EDA0D6F1A4D3EFA2CBE79AC3E294C1E293C2E394
D6F7A8D7F8A9BBDA8CD6F2A5B9D588DCF7AAD4ECA0C9DF94D2E49ADBF3A9BDE396C2E69C
C8DB99D8E6A9A4BA7C7F975BA0AF78B4BB879C9465A4A070CDDFA5D1EBACCEE2A5C9DB9D
5469265A712D233A00C2DB97C7E29DC3E199C8E89FCBEDA3
000F000D1700D3D1A8DFE4AEB8D497CCF1ABD2F4A7B3E198B4FAC42D7B51003F16E0FFF4
E2FBF7EFF2F9FFF8FFFFF3EAE5F6C2BFE099C7E8A3C9E9A6C2E2A1C6E9A5C6E7A0C8EA9E
D7F8A7CEEB99C2DB8ADBF0A3DBEBA4D3DD9E9FA76E848657827D5F887D69423628140600
1D0C05BBA8A4FFF9F6FFEFEAFFF5EED7C6BCFFFDF1FFF9F0FFFEFAFFFFFDFEFDFFECEBF1
FEFDFFFFFEFFFFFDFFFEFEFFFCFFFFF9FFF6F2FCE1E8F4D0F5FFDFE9F6D8EBF6E6EEF8ED
E5EDDEF3FDE4E7F4C9D1E3A5D8F5A1C7E993C1DF9FC9E6B08CA772CBE5A8D5F0A1CAE48D
D2EA9692A35D8E956BEBEAD5FFFEF8FFFCFBD6CBC5CAC3BBFCFCFAFCFAFDE2CFD53E2528
755D590A0000707C56BED9A2C2E6A0CBEB9FDBEDA1B4BC7370712FBDBD7FD2DA9FD5E0A4
CEDD9CD0DF9EDDEBAE9BAA71616D3BB0BE8BD5E3AED8EAB0CEE1A1D2E69F9FB469D2E79A
C2D88DD8EEA5CEE49C91A862AFC982D3EEA7C8E39CCAE59ED0EBA4C4E29AD3EEA7D1ECA5
CDE49ED6EDA7CCE09B4E5F1BE8F7B4D8E4A2CBD4935B5B1DAF9E68EED7A3D6C78E9C9456
5B5E1B9BA75FCBE095D3EE9FCAE999C6E798CDECA0C1DD93BBD28C9DB26FD2E2A3D2E7A4
C5E896C4EC96C6EC99C8EB9BC9E99DCBEA9ECBEA9ACDEA98CDEB95CCEA92CFED97C2E28D
DAF9ADC4E39DBEDC9EBCDA9ACBE79DC7E295C8E394D0ED9DCFEE9EC8E998C9EA99CFF2A0
C3E694B5D685D9FBA7CBEB98D1EE9CB1CE7CD1EC9BDFF8A7D4EB99B9D682C8F49FCCF7A5
C7E198C5DA95D7F2AFC5E2A0D5E9ACCCD79FABA875BFBF89C6DF9EBDDC98DEF7B5CBE29E
D4EDA9D3EEA7B2CD86E7FFBDBEDE95D3F5ABD8FAB0BDE295
000A00324118DCE1ABD3DDA0D3EFB2BDE0A0C3E09DC5F1B2A7F3C54F9F7C001C00E7FFF3
F1FFFFFCFFFFFFF9FFFFF5EFE9F6CBC2DEA1CCE8ADCFEDAFC5E3A3C9EAA5C7E99FC9EA9B
BDDD8AD3EE9DD3EA9CCCDD9698A4648F975E9B9D6CC3BF99A3957A1D0A001300000F0000
97827FD2BDBC9B8788B4A2A2BAA8A6CABDB7FFF6EFFFFFF6FDFAF5FFFFFDF6F8F7FEFFFF
FEFFFBFEFFFDFEFFFFFCFDFFF9FDFCFCFFF8FBFFEEF8FFE6F7FFE7F5FDE8FCFFF8F7FCF5
DFE5D9FCFFEFE9F3D1D1DFACBCD68DDBFAAEC4E0A3CAE5AEB3CC93CCE6A5BFDA8BD6EF9B
D1E7958D9E5A959C70EFEFD7FFF9EFFFF7F2FFFDF4BFB8B0FFFFFDF7F3F4BCA7AC644A4D
846D6708000065734FCCEAB4C9EEABD1EFA7CCD9917E813C959151C8C888E1F0AFCEE3A0
D0E49FD2E6A1D3E3A4C5D398727C47B6BF8AEBF4BFD5DEA5DCE6A9CFDA988F9A56B8C57F
DEEFA8CADE9694A9648CA15C899D58D1E6A1CDE29DCDE7A0D1ECA5C6E49CD5F3ABC0DE94
D1EFA7C4DF98D5ECA67E924DC5D491D9E5A3DBE4A357571BA0915AE9D49FB4A36D877B41
9B9557B8BA79D5E09BD6EAA2C9E59AD0F0A4C8EA9EC7E59BDEF5AF8B9F5ACBD797D8E9A5
C6E599C5EA9AC6EB9DC6E89BC8EA9ECCECA0C9EA9BC3E493CBEB96C2E38CCCED96D3F39E
BADB8CC9E99ED8F7B1CFEDA7D1EDA3CDE99CC8E497C6E595C9EA9BCBEC9BC8EB99C4E795
CDF09ECFF2A0C3E591C2E28FD7F4A2E0FDABBDD887CEE998CAE390D5F5A0B8E28CC5EF9B
CDE99EDEF4ACC0D995CAE3A1CFE1A3D5DFA3ABAA728D9057D1E7A6CFEDA7BDD893D5EFA8
C8E29BD0ECA2D3EEA7BFDD93C8E89FCCEEA2C1E397CFF1A5
9BB76CCAE298D3E29DD5E5A6D0E7AFF2FFDDF4FFE2E8FFEBCFFFF93E86725B7E77F7FFFF
F6F6FFFFFDFFFCFAFFFEFFFFFCFFF4FBFFECDBE9C8DAEBC1CCE3ABCFEAA7D3F2A6C1E18E
CAE892A6C26E758B4092A35FCAD39CDBE1B3FFFFE19D9378381D083211023211089B7E7A
896F70FFF8FBFFF8FFFFF5FFFFFBFFFDF6FDFFFDFFFAF9F7FFFFFBFEFFFAFEFFF8FCFFF4
F9FFEDE3F1D7E0ECD6F9FFEFFCFFF4F9FFF1F9FBEEFFFFF4FFFFF5FFFFF7FFFFFA82817C
CDCDC5FFFFF4E3E4D2F4FBDCCFDFAECEE3A8D5EAB193A86DC5DB9ACDE49CD3EB9DCDE494
D9EEA17F8E4BC9D39FF0F4CFFEFCE5FFFCEEFFFEF4CDC8C2C9C8C6979193E5D2D4D5C0BF
6E5D550402006C7D59C3E0B0CAE9AED0E6A6D7DC9C585414D2CF8CE6ECA6D1E99DC9EA9B
CAE69CC7DE98ECFCBBECF8BAD4D7A074713C77703CE8DEABDDD39EEDE3AEA6A16997985C
DFE8A78F9E5BA6BA75DAEBA7AAB374C9CF91D4DF9DC3D490DBF2AAC3E197C2E498C9F0A1
BEE497C9EEA1D1F1A6C3DD94899A56DBE7A5D4DD9E47470B7268335E4E1B5F4B19A58F5E
967E4E8B794796915A90985CD5EBAAC8E9A2CEF4ABC3E79DC1DB9295A55E767B38E1E8A5
D9F0ACBDDC98C5E4A0D1F1AEE0FFBDE0FFBDC6E7A2C6E7A0C6E89CC6E999C7E995C6E892
C8E893C8E992CAE892C9E692CCEB9DCBEA9ECBEA9ECBEC9DCCECA0C9EC9CC6E999C2E595
C8E99AC6E798CAE99BC7E698C5E194D0EC9FD6F1A4CAE598D5F0A3CAE699C3E495CDEDA1
D5EFA5CAE098CADB97DEEAAAD8DEA0D8D99F99975CA2A367CAD696D7ECA7D3EAA4D2ECA3
C9E39ACDE79DCBE59CC9E59ACFEBA1CDECA0CAE99DCAEA9E
BFDD87D6F1A0D0E49DCFE1A7D1E4B6F5FFE6F8FFF3EBFFFBD2FFFF2D6F63BFD8DCFCFEFF
FBF3FFFFFCFFFBFFFFF0F8FAFEFFFFE0E1D9F7FBEAC5D0B0CFE1B1D0E6A8C6E097A2BD6C
9CB766A1B96BA8BC75D8E6A9E2EAB9E2E4BFC3BFA430240E3114044E2A1E502D27F2D3D1
F9DFE2FFF8FFF4E4EEFFFBFFFFFCFFFAF9FFFEFFFFF3F8F4FCFFF6FAFFF1FAFFEBF8FFE7
F0FFDAD9EEC3D7E9C3EDFCDBFBFFECFCFFF1FBFDF2FFFFFAFFFEFBFEF9F6FBF6F3A49F9C
F4EFEBFFFAF4FDFAF1FAFDE8DEE8C3D4E4B3C0D39C7C9053DDF2ADC8DE95D6ECA1D3E99E
CADB94748244B4BE8AE5ECC3FFFFE8FFFFEFFDF6EEBAB5B1767573969291FEECECEFDCD8
8E8077030200627351C6E1B4B8D39EE5F7BD8B8A51635D1FE7E4A1DAE49BC0E08DC6ED9A
D7F9ADC6E49CE5FCB8FCFFCAEDF2B88F8E565C5521E4DAA7F0E4B2DFD5A2A5A06973743A
869053A4B473C8DF99C5D994E6EAAD6B6C30B5BB7BE2F1AECCE39BD1EFA5C5EA9CCDF4A5
C9F2A3C4EB9CB9DB8FDCF8AE6E823DD8E4A2D1DA9BA0A16799945DA99B6AAD966A72552B
9C7C539D82576554269C9B65CBDDA1BEDD99B5DD96CFF5AAE5FFB7A1B16880833EDCDF9C
BCD190E2FFBFCBE8A8C3E1A3EEFFCFEEFFD1BEE19FCAEDA9CBEFA9C9EBA1C9E99DCCEB9B
CDED98CDEB93CEEB91CEEC94C9E898C7E79BC7E79BC7E79BC7E99CC8EA9DC7E99CC7E99C
CBEB9FC2E296C9E89CD1F0A4CDE99EC9E59ACAE49AC6E096C5DF95C8E499D5F1A6D1EDA2
C8E299D9EFA7E3F2AFCFD897E4E6A7E4E4A6A4A265818344D8E3A1D8E9A3CEE59DB9D38A
D0EAA0C4DE94CBE59BD3EFA4CCE89DC8E79BCBEA9EC6E599
CCE5A1D1E7A7C4D59FC9D6AAD0DFBEF3FFEBF9FFF8EDFFFFB5F5E538776CEEFFFFFEFEFF
FFF9FFFDF8FCFBFFFFF2FBF6FFFFFBFFFFF8F7FBEAFCFFE8F9FFDFF0FFCC657B3A4F661E
AEC57DDDF3ABD6E6A7D1DBA6D3D9AD636442221E03332613493125F2D5CDE5C9C5FFF8F6
FFF9FBFFFBFFFFFBFFF9F7FCFEFFFFF3F8F4FBFFF8E2EDDCE7F4DAE4F3D2E4F4CDE4F7CA
DEF6C4CFE7B5CCE2B4DFF1CBF4FFE3FBFFEDFDFFF2FDFFF4FEFBF6FFFEFBC4BFBCF4EFEC
F2EDE9FFFEF8FEFBF2FFFFEFE3EDCAE7F7C68899638EA064CDE2A1D4E9A4BFD58DD5EBA3
D6E6A5A2B075CFD8A9EDF3CFFFFFECFFFEF3FFFDFBF2ECECFFFFFBFBFAF5FFFAFAD5C2BE
42342B07020032401FD1E6BBDAEEB9CAD89D525216C6C282D7D894E0EEA3D1F4A0C5F19C
B8E193C2E89DD4F5AED9F4AFDAECAEB7C58860682FBBC088DCDFA8CED39BCAD498B0BE80
98AD6CC6E19CD3F3AAD4EEA7DBE5A67A804275803EC5D692D3EAA2C9E59BC2E497C4E99B
C1E698CCEEA1C0DE94D5EFA6495D18D7E3A1D9E2A3D6DA9FE4E1AACFC3915B4617876C3F
F0CFA6FFE8BE9C8A5CA29C68DAE8ADDEF9B6CFF3ADBADE94BDD98FDEF3A8DDE49E777E3A
D9EEABD9F6B4B8D593CDEBABDEFCBCE1FFC0C7E7A6CAEAA9C9E9A6C3E49FC3E39ACAE89E
CEEA9DCBE697CCE796D0EB9ACAE99BC9E99DC9E99DC7E79BC6E69AC7E79BC9E99DCCECA0
CBEA9EC7E69ACEEDA1D0EFA3C8E499C8E499D3EDA3D5EFA5D2EEA3E2FEB3B3CF85779349
79954B8DA45C91A25C99A460D2D795D7D998A0A060B0B573E6F1ADD4E59EBBD389E2FEB3
D0ECA1C2DE93CEEA9FD5F4A8C2E195BFDE92CEEDA1CDEDA1
D4E8B7D3E4B7D4E0BADAE3C6DDE9D5F0FCF0FBFFFFEDFFFF8AC8BD71AFA4E7FFFFFEFFFF
FFFDFFFFFCF9FAFFF8FBFFF8EEEDE8FFFFF8F7F9EBEDF2DBF8FFE0AEBE91ACBF88D6EAAF
D7E9ADCADCA0D1DEA8D9E1B2F0F2CB4F4E2F120C0061564487756BFFF9F4FFFAF8FFFAFA
FFF8F9F7F1F5FFFEFFFEFFFFFBFFFDF0FCEEF6FFEFD3E4C4D1E6BDCDE3B2CDE4ACCCE5AB
CFEBB0C9E5ABC8E0ACD2E8BAE5F5D0F3FFE2FCFFEDFEFFF3FFFFF6FFFFF8CBC8C3FFFEFB
FFFEFAFFFDF9FFFFF8FEFFF0F3FDDAF9FFD87B8C56C2D49ACEE3A2E3F8B5C2D792DBF0AD
C8DA9CC5D49DE0EBC0E4EBCCFBFCEAF8F5EEFFFDFFFFFEFFFAFDF6FFFFF6FFF7F1F3E2DB
301F17070000717859CFDEB5CADBA7A4AF754D4D11E5E4A3E5EBA5B7C97DC6EC99BBE895
BFEA9BD1FAAED3F7AFC5E49ECCE5A3CFE3A48EA0648D9C61D5E3A8DAEAACD8EAACCDE2A1
C0D995C4E29CBADC92D1EFA7CAD998D9E3A4909F5CA2B671C8DF97D4F0A6CCEB9FCAEA9E
C1E195CCEB9FD4F0A6C7DE964B5C18D0DF9CD9E3A4D8DEA2D9D8A04D43106F5D2DF6DBAE
FFE3BAE6C69D644D21A09663D1D99EC8DD9CC9E8A4D1F3A9C6E49AD4EA9FDAE79F46530B
BED38EC8E39EBED996D8F5B2C5E2A0C7E5A5C9E7A7CBEBAACBE9A9C5E3A3C5E2A0CCE7A4
CDE6A2C8E29BCBE29ACFE9A0CCEB9FCCECA0CDEDA1CBEB9FC8E89CC7E79BC9E99DCBEB9F
CBEA9ECAE99DCBEA9EC7E69AC8E499D3EFA4D1EBA1BAD48A7591464D6C207E9C52CFEDA3
D2F0A6BDD78ECEE29BE5F2AD626926515614575C1A414804C7D48ECDE199E3FDB3BCD88D
D3EFA4D1EDA2C9E89CC5E498C7E69AC9E89CC9E89CC8E89C
F2FFE4EFFCE2FEFFEFFDFFF3F3FAF3F3FCFBFBFFFFF0FFFF8ECAC28FCBC1E7FCFDFFFFFF
FFFDFBFFFEF8F1F7E9FBFFF4FEFEF6FFFEF7FFFFF4FFFFEFD6DCC2ABB592DAE6BECDDDB0
CDDAACEAF6C8D9E0B6C7CBA6BCBC9A322E11070100827A67D6CCC3FFF7F5FBF1F0FFFBFB
FFFDFFFEFEFFF5F9FAF9FFFDF8FFF8F2FFEEF5FFE8CFE6BACCE5AEC9E3A4CAE59EC7E59B
C7E6A0C7E8A3C7E5A7CBE4ADD6E9BBE5F5D0F5FFE2FCFFEDFFFFF3FCFCF2DCD9D2FFFFFA
FFFEFBFEFAF7FFFFFAFAFCEEECF6D1DDEDBC8D9E68D2E4AAD8ECADCCE19ED3E8A5CEE3A2
A1B377C8D6A3DCE7BFDFE5CBFFFFF3FFFEFBFFF9FFF3F1F4FCFFF6FEFFF3FEF6EB574940
4A392F0B0000333319D8DEB8D6DEAD4A5217E9EBACE1E4A1D9E59DE0F7A9C2E998CCF7A7
C8EEA1C2E49AC0DF99CBE9A3D3ECAAC8DE9DC3D798748849CCDEA0D7E9ABCEE2A3CEE3A2
E1F8B4D9F2AED7F2ABC6E099D7EAA8D6E6A5D6EAA5AABF7A879E56CAE49BCFE99FCDE79D
D5EFA5CAE298CFE59DD4E8A1687935D1E09DCDDC9BD9E3A6E7E8AF645D27EAD8A6E7CC9D
B08F648F6E43A3885BCBBB8AD8D9A0DCEAACC8E19FC5E59CD7F5ABBAD588DBF0A5D8EDA2
62782FCAE199DFF6B0CDE6A2C5E09DCCE9A7C1DE9ECDEBADE0FCC1DEFABFDBF7BCD8F1B7
D0E8AECBE0A5CCE0A5CDE6A5C9E79FC9EB9ECBEB9FCBEB9FCAEA9EC9E99DCAE99DCAE99D
D0ECA1C6E297C9E59ACEEA9FCAE69BC2DE93B0CA8097B167B0CC82DBF9AFD2F2A7B8D88D
CDEDA2DDF9AFCDE59BC9DA93D6E19C8D94507C833F929C558B9B528FA55AAFCB7ECCEB9F
B7D68AD6F4AAC8E69CBAD88ED5F3A9D8F6ACC1DF95C2E096
F9FFF4F9FFF4FFFFFAFFFFFDF9FDFFF6FBFFFCFEFFEAFEFF88C3BF71ADA5F1FFFFFFFEFF
FCF4F2FFFEF8FBFFF1FAFFF2FFFFF8FAF5EFE8E5DCDBDCCEBFC2AFFEFFECF2FBDEE3ECCD
E6EDCCE0E7C6F0F3D4E7E8C9231F040C06006F6750FFFEEDFFFEF8FFFDFDFFFEFFFFFEFF
FEFFFFFCFFFFF9FFFFF0FBF3F7FFF6F2FFECF4FFE4CCE6B6C9E5A8C9E79FCDEC9ECBEC9B
C4E999C5EA9DC9EAA3C9E7A7CDE4AED6E9BCE6F4D1F5FFE4FEFFEFFFFFF3D4D4CCFFFFFA
F4F0EDFFFEFBF8F4F3FFFFF2D5E0B8C9DAA4899A63D9EBAFC6DB9ACBE09DD2E7A2C9DE9D
8A9C60CDDEAAE1EDC7E6EFD4FFFFF4FFFFFBFFFDFFFCFCFCF4FFEEDAE4CCC7C4B3483C30
5241371505006C644D9895725F6132B7BA81D3D896C5CC86DFEFA6CAE598B8DF90C2EB9D
CDE8A1CCE39DCBE09DD8EDAAD4E7A7C9DC9CDBEDAF4F5F21D4E4A6C6D497CEDC9EDEECAE
D5E4A3BFD08CD8E9A5CCDD99D4E7A5C6DB98D2E7A2C6DB9681974F91A75FCAE097CFE59C
D2E69ED5E9A1C6DA93D5E6A06C7D39DCEDA9D5E5A4D5E1A1C3C78C6D68319A8A57887040
7B5A2F73522791724666522079743D969E62D0E5A2C8E39CD3F1A7C4E397D0EB9EC8E092
83994EA3B970D5EBA2CFE69EC7E09CD2ECABCDE7A8C2DEA3EDFFCDF4FFD6F2FFD6E1F7C6
D2E6B5CDE1B0CFE1B1CEE3ABC9E7A1C6E89BC6E69AC7E79BC9E99DCCEB9FCBEA9ECCE89D
CBE79CC7E398D2EEA3D1EDA2ACC87D93AF64A8C278C7E398C9E79DB5D58AC4E69AD2F4A8
C2E498C4E397D1EBA1C8DC94DAE7A197A15ACFD992CCD890E2F4AACFE79BD2F1A37F9F53
79974DBDD98FD1EDA3C8E49AD4F0A6CFE9A0C6E097DCF6AD
FBFFFAF1F3EEFFFEFFFDFBFFF9FCFFF8FCFFFEFDFFCEE0EC4F87866FA8A2F1FFFFFDFAFF
FEF3F7FFFDFAFEFFF6FBFFF5FFFFF8FFFBF5FBF6F0B9B6ADF2F0E4FDFEF0F5F8E7FFFFF1
FFFFEFFEFFEBC3C2AD817F6A0700002E2613A29785FFFEEFFFFEFAEDEBECFDFDFFFEFFFF
F4F8FBF8FDFFF4FDFCF8FFFDF5FFF6F0FFEAF5FFE6CCE3B5C9E2A8CBE6A1CFEBA0CCEE9A
C6EC97C3EA97C6EB9DCBECA5CCE6A9CAE1ADD5E6BCE4EFCFF7FCE5F6F9E8D3D3C9F5F4EF
FFFEFBFBF7F6FFFEFFFDFDF1D7E2B8D8E7AC8A9C5ED4E7A5C3D893E1F7AFD2E8A0D9EEA9
8FA364CDDEA8D7E4B9E3ECCDFBFEEDF6F5F0FCFAFBFEFFFBF8FFECE6F4D3E6E8D2372E1F
311F15160200473825A4997B4F4B1CE5E6ACD1D894E6F3ABC5DB90D6F5A9CBF1A4C8EAA0
D1E09DDDE2A0D8DE9EE6ECAED8DEA2DEE4A8D9DEA451561CE1E6ACE0E3AADADEA3CFD096
AEAF73ABAB6DB3B375E3E8A8CEE19FDCF5B1C5DC96D8EDA8BBD1898DA15AD5E69FDCEDA6
CADA93DBEBA4D5E49FCCDD97788945C7D894DDEDACCBDA99EEF7B868672E6E632D64501D
5C40117E5D30513204947E4D8C804C575B20CBDB9AD5EFA8C9E79DC9E99DD0F1A2CAE797
D8EFA17E9044C6D88ED6EAA2C9DE99CDE3A2D5EDAFC1DAA0DDF4BEF3FFD8F5FFDDE1F3C9
D0E2BAD8E8C1E2F0CCDEF1C3D8F5B2CEF0A3C6E69AC4E498C9E89CCFEBA0CEEA9FCCE69C
C9E399CEE89ED2ECA2BAD48A96B0669AB46AC5E196E9FFBAC6E49AD5F5ACCBEDA1BFE497
CBF0A2D0F0A4CCE89DD5EDA1D4E69C94A159B7C37BEBF8B0C9DA93C8E096CAE99DD3F1A7
7F9B5198B269BAD189CCE39BCCE29AC8DE96CDE19AD3E7A0
FCFFFBF3F5F2FFFDFFFFFCFFFEFEFFFCFEFFF7F6FFAEBECD134B4A9DD5D2E6F9FFFFFDFF
FFFBFFFCF3F4FEFFFAFCFFF8FFFDF7FFF6F1CBC4BEE5E0DAFCF7F1FFFCF5FFFFF8FFFDF6
FEFBF2FFFFF4A29E920E0800160D00928676FFFDEDFFFDF1FFFDF8FFFFFFFFFFFFFEFFFF
F5F8FDFBFFFFFBFFFFF3FCF9F9FFFAF6FFF1F7FFEAD2E4BCCCE3ADCDE5A7D1EBA4CCEB9D
C9EF98C2EA92C4EA97CDEFA3CDEAA8C7DEA6CADBAED6E2BEE5EED3FDFFEEA9A99DFFFFFA
FEFAF7FFFEFFFEF9FDFFFFF4D5E1B3CCDC9D8FA2609CB069CEE49BCCE297CCE297CFE59C
ADC27FCDE1A6C3D3A4E5F1CDFEFFECFFFFF3FAFBF5FAFFF2F2FFDFE5F7CFD2D9BA060100
4433291100004C3726968569635B2DCFCE95E1EBA6CFE195D0EB9EC3E397C1E59DCDE8A3
9096568786468C8A4DD2D294DADA9EE6E7ADD3D49B999A612A29008382498482495D5B20
716B2FA6A0645F5719939353CFE09CC5DE9ADBF2ACCDE29DC6DA93BBCC86D1E19AD0E099
DDEAA4CCD993E2F1ACD6E5A0A2B36F97A864D2E5A3D3E3A2D0DA9BDDE1A4E4DEA490804C
917746CDAE80F4D8A9EDD5A57A6D3858571EDDE9A9C9E09AC7E59BCDF2A4BADF8FD1F2A1
CEE3968C9D4FDCECA1CCDD96D4E8A3CFE4A3CAE0A2D2EAB0C6DDA9E7FDCEF5FFDDDFF1CB
D5E5C1E8F7D6F9FFE8F7FFDFEAFFC5DBFDB0CCECA0C6E599CBE79CD0EAA0CEE89ECDE59B
D1E99FD2EAA0BED68C9BB56BA3BD73D3EDA3DBF7ACB4D086CDEBA3C4E49BC7E99DCBF0A3
C7EC9EC6E89BC9E89ACCE79ACADF9298A85FB9C67ED5E29CD0E49CD1E8A0C9E79FC7E59D
D0E79F899F57889C55B9CD86CFE09ADBEAA5CDDA9598A560
F8FBF4FFFFFBFFFDFFFBF6FCF7F7FFFCFEFFEEEDFDAABAC73E7677528D8BF1FFFFFFFCFF
FCF2FDFFFCFFFCFFFFF4F9F5FFFEFAFFFDF8A9A19EFFFEFBFFFEFBFFFDFDFFFDFDFFFBFB
FFFEFBFFFAF769625C12090223190FC4B8ACFFFBEEFFFCF0FFFEF8FFFFFBFFFEFFFFFFFF
FFFEFFFEFFFFFEFFFFFCFFFFFCFFFFFBFFF8F3FFEBF9FFE8F8FFDFCBDDABD1E6ADCFEAA5
C5E896C8F098C6EC99C4E498C9E4A1D0E5ACD1E3B3D0DCB6EDF6D9FCFFEDA9A99DFFFFFA
FFFFFDFAF8F9FFFEFFFDFFF2CEDAAADAEBA78B9F58203500D0E799D3EA9AC5DE8DD7EFA1
D1E79EB5CA89C6D7A0D6E3B5DEE8C5E2E8CEFEFFEFECF6DDF5FFDDE0F6C5D9E5C1D2D2BA
6F61541100008C72635D482D372C00E3E3A7C8D58DD4EB9BC7E494C9E79DDCF9B6BFD493
999F5FDDDC9CA5A366D0D092E4E4A8DADB9FD9DAA09CA06555561C67662D5A581F939156
EBE5A9DED89C98905266662699AA66C7DE9AD2E9A3CDE29DD1E59E92A35DCADA93D4E19B
D3E09ADDEAA4CEDD98D5E49FD0E19D52631FD0E3A1D2E2A1CFDB99D2D898E9E7AAA69B63
E3CF9CFFE8B6EFD5A4EED8A66F622D514F16DBE5A6DEF3AEC5E399C0E597CDF7A5C3E694
D3E89BDEEC9F88984DDBEDA3D6EAA3D2E7A4C8DE9ED6EBB0CBE2ACEAFFCFF7FFDFF7FFE3
F6FFE4F8FFE8F8FFEAF0FFDCF1FFCDD4F6A9CBEB9FCCEB9FCDE99ED0EAA0CEE69CD2E89F
CBE198D7EFA5DAF2A8859D53D8F2A8D0EAA0C4E095CEECA2CAE8A0C9E9A0C8EA9EC6EB9E
C5EC9DC6EB9DC9EA9BCDE89BD4EA9F94A65CBAC781DCEBA6CADE99D2E9A5C7E4A1C6E19C
D1E5A0DBEAA7CEDA98505C1AD9E4A2DDE8A6D5DE9D969C5C
FBFEF3FEFFF7FFFEFBFFFEFFFDFEFFFCFFFFFDFCFFD3E5EF478280AAE5E3F0FFFFFFFDFF
FFFAFFF6EFF7FBFFFFF6FCFAFFFDFAFFFCFAC0B8B6ECE3E4FFFDFFFFFDFFFFFDFFFFFDFF
FDF4F5FFFCFD3B31300A00006D625CF9ECE3FFFCF1FFFDF3FFFFF6FFFFFAFFFFFDFFFEFF
FFFEFFFFFDFFFFFDFFFFFEFFFBFBFDFEFFFBF8FEF0FBFFEDFBFFE4CEDDB2CFE1B1CAE2A6
CFEFA3BAE08BD4F7A7CEECA2D3ECAACADFA6CEDEAFDAE6C0F4FADEF8FBE8A7A99CEDECE7
FBFAF8FFFEFFFFFEFFFAFCEFD4E0B0DBECA6A4B56E9DB265CAE191C9E08EDDF6A3C7E08D
CFE6987A9048819454E1F2BBC6D3A7DAE4BFFEFFE6FBFFE3F4FFD6D3ECB3CBDCB2DCE0C5
756C5D100000140000745C425A4D21EAECADD0E296D5F19DC9E898C4E096C8DC9D99A76A
B0BB79D0DA95BFC88599A261CBD495E0E9AAE6EEB2D2DA9E9FA76B868C50DFE5A7E0E4A7
E6E8A9D4D695E7E8A6484F0C596825DEF1AFCBDF9AC0D48FE8F9B3ACBD77506019D8E8A1
899952A8B871D6E5A0D4E59FE3F4B0D8E9A53B4E0CD7E8A4EAF9B4D0DB97E0E2A3585417
F1E4ADD9C8949C885562511D918650E6E4ABD4DD9EC1D590D0EBA4D4F9ACBFE899C2E797
CBE093D7E59A758338B7C97FD4E59ECFE49FD3E8A7D1E7A9CFE6AEDCF3BFECFFD3F7FFDF
F7FFE4F5FFE3EEFDDEE6FBD0CFEEABC8ED9FCCECA0C8E79BC8E499CCE49ACDE39AD3E9A0
D0E69DBED48B465C13B1C97FC3DD93CCE89DD5F1A6C5E399CAE8A0CAE8A0C8EA9EC6EB9E
C5EC9DC6EB9DC9EA9BCCE89BCBE19691A25BBAC984DBEAA9CCDF9FD3E9A9CFE9AAD2EAAC
CFDF9EC1CD8BE7F2B0A0AB69C0C988D5DE9DE9EEAE919656
FCFFF4F9FCF1FFFDF6FFFEFBFCFDFFF8FBFFFDFDFFECFFFF76B1AB92CFC8EDFFFFEEEEF8
FFFBFFFFFDFFF2FAFCF8FFFEFBF7F4FFFDFBD8D0CECAC1C2F8EFF2FFFCFFFFF8FBFFF8FB
FFFAFBFFF9FA251919170C0A8C817DF8EDE7FFFCF4FFFDF4FFFFF6FFFFF8FFFEFBFFFEFF
FFFDFFFFFDFFFFFCFFFFFCFFFDFBFFFFFFFFFEFFF8FCFFF1FBFFE8D5E4BDD1E2B6CDE2AA
C6E49CCBEC9DBBD98FC9E49FDDF3B5F8FFD4F2FFD3F7FFDE50563AA9AC99D1D3C6FFFFF8
FFFFFDFAFAFCFEFDFFFBFFF1DAE6B6C6D793DEEFA9CEE39842590BDDF4A2D4ED99D3EC98
CBE491C7DF91E5FBB34355174D5C25233100C4CFA5CFDFB0CFE7A9D0EAABD4E7B9565F40
0600000E0000240A005F472F6F6436DAE0A0C9E090CBEB96D0EF9FD0E79FCCD59E959E67
D8EDA8CDE79DC6E09771884297AE6AD3E8A5C9DE9DCEE1A1D9ECACC9DC9CCBDE9CC9DC9A
D7EBA6C6DA93E2F6AED8E9A34E5A188C9858E9F5B3DBEAA7C3D28DC8D993D2E39C4B5C15
CCDD969AAB646A7B35D7E8A2BDCE8ADDEEAAE1F1B05D6E2ABFCE89DCE9A3DFE8A5505213
59541A60571E726731A59C65EAE3ACEDECB3C2CB8CE9FAB6CCE69FBFE195C6EFA0C9EB9E
CBE095D5E29A59661E92A35CD2E39DCEE39EDAEFACCBE1A1D2EAACCAE3A9D5EEB7EEFFD3
F4FFDEE6F8D0DAECC6DAF0C1BBDA96C8ED9FCBEB9FC7E69ACDE79DD0E89ECFE59CD2E69E
D3E79F7488405C7229CBE399C9E399D0ECA1CAE69BCCEAA0CCE7A0CCE7A0C9E99EC6EB9E
C5EC9DC6EB9BC8EB9BCCE89BD1E79E9BAC66C3D291DBE9ACCFDEA5CEE1A9C9E0AACFE4AB
D5E3A5EDF8B6BEC987D5E09E485110E7F0AFCCD191A1A666
FCFFF4F9FDEFFFFDF6FFFFFBF9FDFCF5FAFDFAFDFFEDFFFF91CFC2377769EEFFFFFCFFFF
F8F3F7FBF9FAF4FFF9F8FFFBFFFFFBFFFCFDFAF1F2D5CCCDEDE4E5FFFCFDFFFCFDFFFCFD
FFFCFBF0E6E5080000080000E0D5D3FFFCF8F9EEE8FFF6EFFFFFF6FFFFF8FFFEFBFFFDFD
FFFCFFFFFCFFFFFBFFFFFDFFFFFEFFFFFFFDFEFFF6F1F9E4F2FFDFD4E5BBD1E5B4CDE4AC
CAE5A2E5FFBBC0D997D9EFB1DDF0B8E9F7C6B2BD93AAB18FD4D8BFFDFFEDFFFFF4FFFFF8
F9F9F7F5F6F8FEFFFFFEFFF6C9D4A9DCEAACDFEFAEC5D992B2C77C9EB5678CA552C6DF8C
D0E996CDE597C0D68DD5EAA5D5E7A99DAC75939F6DB2C38CCEE8A1BFDA95D7EEBAC6D4B1
585745140600371F13665038948C5DDBE4A1CCE995C4E890CBEA9ACFE39EC2C08F929462
C4DF98C6ED9ECAEFA2A8CA7E8EAE65CDE8A3CBE4A2D1E7A6C2D897E1F8B4D2EBA7D8F3AC
CEEAA0D6F4AACCECA0C2DC9396A15F43470A737939E2EDABE1EEA9D8E9A3E3F7AFC4DA91
CBE198C8DE958DA35B94AA62465A15D6E7A3D2E2A16B7A379FAE69D4E49DD8E5A0B9C27F
545919808145AFAE75DCDBA2D6D59CDDE1A6D7E0A1CBDA97D0E7A1CCECA1C1E899CAEC9F
D3E7A0D9E6A146530E869751D1E59ED2E8A0D5ECA6C7E09CCFEAA7C5DFA0CAE4A7DFF8BF
E5FDC9D8EEBDCEE4B5CFE8B1C6E7A0CEF3A5C3E598C6E599D4EEA4D3E9A0D2E69ED1E29B
CFE099677831CDE199CDE39AD5EDA3D5F1A6C0DC91D5F1A6CDE7A0CCE7A0CAE89EC8EA9D
C6EB9BC6EB9BC8EB9BCAE99DD6ECA4A1B170C7D598DAE5ADD7E5B0D2E4B2CDE0B2CEE2AF
D5E5A7C5D491E8F4B2D8E4A2A5B16F7B86448E9756B5BE7D
F9FFF3F9FCF3FFFFFAFFFFFBFCFFFFFBFFFFFBFFFFE6FFFBA9EAD60E523BE5FFF5FBFFFB
FFFFF8E8EADFF7FFF3EDFBEAFFFFFBFAF4F4FFFDFDE5DFDFD8D3D0FFFEFBFFFBF8FFFDFA
F9EFEDA39997362C2A453B39EFE5E3FFF7F5FFFCFAFFFDFAFFFFF8FFFFF8FFFFFBFFFEFF
FFFDFFFFFDFFFFFDFFFFFEFFFFFFFDFCFFF6F7FFEDD8E5C7DAECC2CAE1ADC9E2A8CCE6A7
C8E0A2C4DA9CCCE0A5F9FFD4CEDCAB9BA67BDEE6C1FDFFE4FDFFE8FFFFEEFBFDF0F6F7F1
FEFFFDFEFFFFFEFFFFF4FAF0E2ECC7D4E1ACB5C48BE6F8BAC5D896C9DF9793AB5FD8F3A4
CFEA9BCDE899E8FFB6CBE199D0E3A1BCCE90DBEAB1A5B779C6DE92E7FFB9B8D198CEDEB9
4144310B01001100004C381F979363D2DF9ACAEC95C3EA8FC9E996D3E29FB2A5789E9868
C8E69ECBF8A7C1EC9DC3E99C7B9B528CA760D1E8A4D6EBA8C8DD9ADCF1AEC9E09CB8D38C
CDEDA2B9DE91C0E798D3EFA4E8EEAE48460BB4B476D2D898B7C47FDDEEA8CBE198CCE69C
D1EBA1DDF9AEC6E097C8DF97DAEFAA7F904C778645D9E8A595A55ECADC92D0E19AE4F3AE
D2DE9CD2DD9BE6EFB0939C5DA5AB6DD3DC9DE1EBACCBDA97CCE39DCEECA2C4E699C8E89D
D8E9A5D7E3A34854128E9F5BD1E59ED5EBA3CEE59DCAE49BCAE59EC8E6A0CAE7A4CFECAC
D1EDB0D0E9AFCDE6ADC9E5A8CAECA2CDF2A4BEE093C9E89CD0EAA0C9DF96D6E7A0D5E59E
B5C57EA8B972C9DD95D1E79ECCE49ACEEA9FCEEA9FCCE89DCFE6A0CDE7A0CCE89EC9E99D
C6EB9BC6EB9BC8EA9DCAE99DCFE49F9BAB6CC5D098D5DFABEAF6C8E9F8CDE6F6CFE4F7CA
E5F9BCE0F5B2CADD9BC8DB99CFE2A0DAEAA99BAB6A859453
F8FDF7FCFEF9FFFFFDFFFFFDF9FFFDF9FFFFFBFFFFD4EFE6A6EBCF004326D9F9E4DEE9D8
F9FCE9F2F7E1EEFFE3EDFFE5FEFFFAF1EDEEFFFDFDE4DFDCD7D2CEFFFAF4FFF8F2FFFAF2
FFF9F2A49B94231A15271E19FFFCFAFFFCFBFEF4F3FFFDFBFFFFFAFFFFFAFFFFFDFFFEFF
FFFEFFFFFEFFFFFEFFFFFFFFFEFFFAFAFFF2F5FFE6CADCB4CBE3AFC6E4A4C6E7A0CDEBA5
D8EDB2D3E4AED5E3B0FCFFD8828B608A906AE8EECCFFFFE7FFFFECFFFFF1FFFFF6FFFFFA
FEFFFDF4F8F7FAFEFFFCFFFAC5CEAFD3DEB3E8F6C5CBDCA6DEF0B4D9F0AC879E56CBE59B
CBE699CEE99CC0D88EC5DC94C6DB96D8EBABE5F5B7D1E4A2D6EF9ECCE79AC7E3A8D4E9C0
484D370600000F00004E3D23878554C5D58EC6EA92C7F094C9E996DBE6A49B855CA9986D
D1EBA4BCE996BAE394CCEEA2B9D38C97AC67DFEEADCEDA9AA3AD6E8F9B5BA9BA76E4F9B4
CDE99FBDDD91CFF4A4D2ECA2D0D0924C430AA6A265CFD192F1FCB8CDDE98CBE399D4F0A5
C5E498C0E094C4E298E4FEB5BACF8ADEEFAB8F9B5B9AA6646C7D36DBF0A5D1E59DC5DB92
D9EFA7C9DD98D8E8A792A160828C4DDAE4A5D5E1A1E8F7B4C9DF97C5E197CAEA9EC7E59B
D4E4A5D1DD9F66743696A665D0E49FD2E9A1CDE79DCCE89DC6E599CDECA0CEECA2C7E59D
C6E3A0CCE9A7CFE9A8C8E5A2C1E699CAEFA1C4E699D3F2A6CBE59BC5DB92DEEFA8CCDC95
8A9A53BFCF88C6D790D6ECA3D5EDA3C5E196CCEB9FCDE99ECFE69ECFE69ECCE89DC9E99D
C8EB9BC8EB9BC9E99DCCE89ECFE4A19EAE70C9D39ED7DFB0FCFFDBFBFFE3F7FFE5F4FFDE
F5FFD1D4EFAAD1EAA6D7F0ACC8E19DC9E09CC1D894CCE39F
FBFFFFFCFFFFFFFFFFFEFEFFF5FBFBF7FFFEF3FCF9D2EEE09DE2C3003F1AC5E8CACDDBC1
D4DABED6E0BEC6DDB3F4FFE6FCFFF8FFFEFFFFFEFDD2CECBF8F3EDFFFFF6FFFEF4FFFEF4
FFFEF3B5ACA3211811241B16D4CCC9F8F0EEFFFCFDFFFDFDFFFFFDFEFFFDFEFFFFFFFFFF
FFFEFFFEFFFFFEFFFFFCFFFBFBFFF4F9FFEDF7FFE3C8E0ACC8E8A7CAEFA2C5ED97CCEF9F
C8DBA3FCFFDAF8FFD6D5DCB2B3B993E3E7C4E1E4C5D6D8C0E5E7D2FCFDEDF0F2E7FFFFFA
FEFFFDFCFFFFFCFFFFF5FCF5FCFFECFCFFE3BDC9A1D8E8B98697618AA062ADC382C5DF98
C3DD94E5FFB5CBE29AD9F0A8D4E9A4D4E9A6B7CA8AB6CA85CBE491BED988E0FCBFC9E0B4
5660480B07003B2B1C64543A979763D7E99FCBF498CBF798C3E090D6DC9E7456329F865E
D5E6A2BFE494CFEEA2D1E79FE0ECAAA1A7676F6F33636126969157D8D69BA2A767919C5A
CBDC96E0F8AEBDD98CCCE098E4DEA29A8B54544B10E6E6A8D5E09CC6DA93CFE99FC5E599
D3F5A8BFE194D3F3A8CAE69CD0E5A0E6F7B3D0DC9CB2BE7C84964CE2F7AACCE498CBE59B
CBE59CD4EEA7C9E09CB9CC8A3E4D0CDAE6A6DDE9A7BBCA87D5E9A2DDF7AEBFDE92CBE69F
D3E3A5D1DCA29EAC6F92A565D0E5A0CAE199D7F1A7C8E497C9E898CCED9CCBEC9DC6E69A
C6E69BCBEBA2CCEAA2C7E79EC0E598CAEFA1C8EA9DD6F5A9CCE49AD0E49CDCEDA695A55E
7F8C46B8C881E6F7B0D3E79FDAF2A8C6E297C5E498D1EDA2CFE69ED0E69ECDE79DCAE99D
C8EB9BC8EB9BC9E99DCCE7A0D1E6A5A6B479D1DBA9D7DEB4FEFFE1FAFFE4F8FFEBF4FFE3
DAF6BBCCEDA6D8F7B1C6E59FBFDE98DFFDB7DCFAB4BDDB95
FCFFFFF8FCFBFFFFFFFEFFFFFAFFFFF9FFFFF9FFFDEDFFF4DDFFF10D4A21517C5EBCD9BA
DBEBC4CCDCADD9F0BCCEE4B6E6EFDAFFFFF6FFFFF8AAA59FFFFEF8FFFEF8FFFDF7FFFFF6
FFF8EED9D0C70A0000100200DCD0D0FFFCFDFFFDFFF9F8FDFEFFFFFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFEFFFFFCFFFBF8FFF1F7FFEAF7FFE3C8E0ACC9E8A5CCF1A3C2EA94C7E899
CCD9A3FFFFDCFFFFDC484F25F3FBD2DCE4BBC0C8A1DCE3C1E4EBCAFEFFE6FDFFE9FEFFED
F9FFEEF7FFEFFBFFF3F8FFEEFAFFEAFCFFE6D8E4C08A976C8E9F6BC5D99EDFF5B5CCE39F
D2E9A5C9E09CCEE3A2D2E6A7C9DB9FD4E6ACD5E4AD8E9E5F91A659DBF2A4BFD99CD2E4BA
7378610901000F0000614D34989465D8E7A2C3E992C5F096BFDB8EDFE3A671512AB3976F
CDDD9CCBEDA0D6F5A9BFD68ED5E4A1DFE5A58A8B4FE6E4A9EAE5ABDAD89DA1A364565F1E
D6E39EC4D890D9F1A7D4E59EE3E1A4958B505D5419E5E1A4DFDF9FD3DC99DCEDA7C8DF97
CCE89EC9E39AD3E8A3C9DD98DEEFABCEDD9CCBDB9ADDEEAAD6EAA2CEE499CCE79ACFEBA0
C3E398CBEBA0CBE69FCCE39F4C5B1A535D1ED9E2A1D6E19FD7E6A3CBE199CBE59CD1ECA5
D3E9A8D1E5A6CBDE9E90A05FD4E5A1C7D891E3F9B0C3DE91CCEB9BC7EA98C3E996C6EB9B
CBEDA0CDECA0CCE89ECAE69CC7E99CC9EEA0C2E296CFEBA0CBE198D9EDA5CFE099506019
91A25BD3E79FD2E89FCFE79DBFD98FCFEBA0D3F2A6C8E499D0E5A0D1E59ED1E59ECFE79D
CAE99BC9EA9BCAE99DCFE69ECDDB9DA7AE78D4DAAAD4DBB1FCFFE1F5FFDEF7FFE6F7FFE3
D1ECB5C3E3A2C2E29FC8E9A4CAEBA4C7E99FB7D98DD1F3A6
FEFFF6FEFFFAFEFFFFFEFFFFFCFFFFFBFFFFFBFFFDF9FFF3EEFFDCE7FFE1144E355E9679
CFEFBECCE0A3CDE3A5CBE0A7E8F9CDFBFFE6FEFFEBD7D0C6FFFDFBFFFDFFF0F0F0FFFFFD
FFFEFBBAAFAB2E19163D2525EFDBDDFFFAFFFEFEFFF9FFFFFCFFFFFFFEFFFCFAFFFBF9FF
FDFBFFFEFDFFFCFBFFFBFBFBFEFFFAF4FDEAF6FFE5E1F3C9C6DDA5C5DF9EC4E29AD9F0AC
E3E7B5C9C89CD2D8AAE8F1C2DAEBB7D6EBB3D7EFB5C8DDA4CDE0A8D3E4ADD4E3ACCFDCA7
DDEBB89AA8757D8E5AAEBE91838E6E97A083CCD6B1E3F0C2CDDEA7CFE1A3DCF1B0CCE1A0
CBDFA2DDEEB7DBE9B6DFECBEF8FFD9EFF7D0D4DAB6D0D8A996A262B3C27DD7E8B1D6E1B9
67624C1F0D00160000664A35675934D8E0A7CDEBA1BDE493CFEBA0D8DE9E684D1EA38E5F
CEE5A1C3EE9FC2E89BC7E99FCDEBA3CDE49ECFE39EE1F0ADD8E4A2D7E3A1B2C17E5F6E2B
D3E7A2D0E69ECBE29AD7EDA5D4E39E959A586C6628B7AB6FEDDCA4E8DCA2D4D295898E4E
5F6525363B004C4C10717135D4D89BD6E4A6C7E29FCAE8A2CFE59DCDE39ACBE79CCCECA0
C6EB9EBFE497C6E49AD4E9A4AFBB79616626B1B374DEE0A1ECF5B4C5D491CEE59FCDEBA3
C1E59BD3F5ABCEE59DABBA75ACB370D1D693D0DA95D0E19ACAE99BC5EC9BC2ED9BC2ED9D
C6EB9DCAE99DD1E59DD0E69DCAEA9EC5E79AD3F2A6C2DC92D7EBA3D5E69FD7E8A1899D55
CFE79DCCE89DCAE99DC9E99DC9E99DC9E99DCAE99DCDE79ECFE4A1DDECABCFD895DCE8A0
CCE395C8E593C6E393DAEEA6D8D99DB9B381AAA77AE0E3B8E4F4C7DBEEC1F6FFD8DAEABD
E7FDCEDAF5C2D6F3B9D4F2B2CAEBA4C6E999C5EB94C4EB92
FFFFF3FFFFF6FFFFFDFEFFFFFCFFFFFCFFFFFCFFFFFEFFF1FFFFDDC2DBB3A4E5CF378063
BFE8B0CDE7A0D4E9A4CFE4A3C3D89FD5E5B8F3F6D9DDD7C9FFFCFAFBF5F9FBFCFFFCFFFF
FFFEFDE5DAD84E3433492B2BE5CCCFFBEFF3F8FDFFF7FFFFF8FBFFFFFEFFFFFEFFFFFEFF
FFFDFFFFFDFFFFFDFFFFFEFFFFFFFBFEFFF4FBFFECB4C29EDEF0C0D6EBB2D7F0AFC0D294
E3E3B1A8A578B2B888EFFEC7ECFFC8C8E5A5C4E39FD1EFA9D4EEA7CDE29DD4E8A3D6E7A3
C7D8948CA05B8DA15CD7E9AFFBFFE3FCFFE8FCFFE1FAFFD7E0EFB6C8DB9BC9DC9AD2E5A3
D4E6AAC6D7A1C4D1A3FCFFDFEEF5D3F3FAD9DADFBFE0E7BE929C60929E5EBDCB96E1E9C2
2B250D1F0C00270700674836372705CCD19BC9E7A1D3F9ACCBE99FCBD69476622FB0A06C
CEE7A3C2EEA1BEE89CC4EA9FD1F3A9CCECA3C2DD96C4DB95D9EEA9CBE09BBED28D93A863
D4E9A4D1E8A2C9E09ACDE49ECCE39BD6E5A092915170612668551D55440C6D672B7E7E40
DDDEA2DADA9ECEC58E554E179E9D64D7E5A7CBECA7CAEEA6D1E8A0CEE49BC8E79BCBEDA0
CDF3A6CCF2A5CBEBA0CEE59DDCE8A6D1D69658581A6F6F31CED496E5F1B1D4E9A6C4E49B
CAF3A5B7E091D8F2A8CDDA94CDD08D6867269DA25FDEEBA5CCE89DC3EC9DBFEE9DBFEE9D
C5EC9DCCE89DD3E49DD3E49DBAD98DCFF1A4CDE99ECFE79DD8E9A2D6E69F96A760CBE198
CDE79DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCAE99DCDE79ECCE1A0DAE8AAD2D797939953
536617546F1E3552024F6019090700B0A472CDC698D3D6A7D4E6B2CBE2ACC4D29DE6F2C2
ECFED6F4FFE3F4FFDDDDF8C1CFEEABC7E99DC7EA96D1F59D
FFFFF4FFFFF8FFFFFFFEFEFFFCFEFFFCFFFFFCFFFFFEFFF4FFFFE1BDD5B1BCFDE9277053
BBE6AECAE69CD0E89ECEE59DCFE8A7CEDFABEDF1CEDCD7C3BDB6B0FFFEFFFEFFFFF6FAFB
FFFEFBFAEFE93F2621381B15E2CAC6FFF8F2FBFFFBF3FFF9F1F7F3F9FBF8FEFFFFFEFFFF
FCFBFFF9F8FEFBF9FEFEFCFFF9FAF5F5F9EBFCFFEDFBFFE4F9FFDAC8DBA3CEE2A3D7E7A8
B2B580AAAA78C4CD98E2F4BAD2ECADBFDE9AC7E6A0CCECA3C8E39CD1E8A0DEF2ABC1D28C
9CAD69A2B671B7CA88DAECB2CBD5B0D6DDBCEFFAD0F2FFCBDDEDAFDDF1ACDFF5ADC7DC97
D4E8A9697D4251632F566639FBFFDDF4FFD7FEFFDFD5E1B396A667AABD7BE3F6BFC7D3AB
69694F16090014000069503A9A916AE4EFB7C5E9A1C4EF9FC2E497CFE09A6B5E298F864F
D2EBA7C9F2A6C0E69BBDE197CCECA3D4F2AAD6F0A9DBF2ACCBE09BD2E7A2D1E6A199AE69
CCE19CD3EAA4D4EBA5CBE59ECFEBA1C8DE96BEC381A19B5D5A501561581DAAAF6FA6B16F
DEE8A9D6DFA0DAD9A09492594C5015D9E9AAC2E39EC4E8A0C9E39AD1E99FCEEDA1C6EB9D
BDE698BDE698C5E79BCAE69CC9DA96E3ECAB7D83439EA464D4DE9FD8E8A7C7E09CD0F0A7
C7F0A2BAE192D4EEA4D4E19BE3E6A3494A089A9F5CD4E19BCCE89DC5EC9DC1EE9DC1EE9D
C5EC9DCCE89DD3E49DD1E59DD6F5A9CBEDA0C2DE93C8E096F0FFBAB4C47D8A9B54D8EEA5
CDE79DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCAE99DCDE7A0D7EDADD2E1A6DDE3A5A8AF6B
CCE194C2DD8CDBF8A8D1E69BDAD89B8478446B6332D2D4A2C8D9A2CDE2A7D0DEA3D2DEAC
EFFCDEF5FFEBDFF0CEC9DEB3D0E8B4CDEAAAC5E39BCCECA0
FFFFF6FFFFFAFFFFFFFEFEFFFEFDFFFCFEFFFCFFFFFEFFF8F7FADBDCF6D392D5C3166045
BEEBB0CBEA9CC7E291D0EB9CD6EFABD6E9B1F9FED6D8D3BDFFFCF2F6F2F1F9FAFCFCFFFF
FFFBF8FFF8F22A110A301409E6D0C3FFFEEDFBFFF1F5FFF1F9FFF1FCFFF3FCFFF6FEFFFA
FDFFFCFEFEFFFFFEFFFFFEFFFFFFFDFFFFF6FAFFEBF6FFE0F9FFDAB6C48F93A5678A985A
A5AA72C6CB95DEECB1D0E6A6B9D693C5E69FD0F2A8C0E095C7E399CFE69EDCF0A9ACBD77
8C9D59C7DB96D8EBA9C8DAA0DEE9C1D2DAB5F5FFD3FBFFD3CADD9BC7DD95CAE09795AD63
92A965CAE0A0D2E7AED7E9B5768655D2E2B3D5E2B4ACBD87D0E7A3C0D995D3ECB3D1E4B7
3C43240F0A000E00007A6A51BAB88FC5D79BCAF0A5B8E594C0E798DDF3AB9B9960E0DEA5
C5DC98CCF0A6CFF1A7C8E89FC9E79FC7E29BC2DC95C5DC96C6DB96D5EAA5DCF1AC9BB26C
D1E8A2C9E39CCEE8A1CEE9A2C8E89DD6F0A7D3DE9ADEE09FDDDB9ECCCE8FD4E3A0DAEFAA
D5EAA7C8D897DCE2A6F7F8BE4E5418E2F2B3C4E39FCBEFA7CFE9A0D7EFA5D1F0A4C5EA9C
BEE799C3EC9ECCF1A4D2F0A6D5E9A4D4E09EB0BB79525D1B667534CCDF9DD7F0ACC9EBA1
BEE799CCF3A4C6E096D4E49DDFE4A15D601DA7AC69CDDD96CCE89DC6EB9DC1EE9DC1EE9D
C5EC9DCAE99DD1E59DD1E59DC5E498C3E598CDE99ED7EFA5BBCC855969229DAE67C8DE95
CDE79DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCAE99DCCE7A0C9E1A3D1E3A9697135D0D996
C8DE93D3F0A0CDEC9CC1D58DE9E7AAE7DCA6948D59767642A5B77BDDF3B3CFDB9DD6E0AE
FBFFEAE5F1DDCDDBC1CCDDB9D3E6B9D4EBB3D1EBAAD0EBA6
FFFFF8FFFFFAFFFFFFFEFEFFFEFDFFFCFEFFFBFFFFFCFFFAF8FCE1D3ECCE7FC3B4277359
BFEFB3CEEF9EC9EA91D1EF99BBD78DCDE1A6DEE3BAFFFFE3C9C3B7F0ECE9FEFFFFFAFEFF
FFFEFDFFFCF63219123C2012DFCAB5FFFFE3EFFDDAF5FFE4F6FFE2F5FFE0F3FDE4F7FEEC
FEFFF8FFFFFBFFFEFFFFFDFFFFFFFDFFFFF7FEFFF0FFFFE8EDF5CC6E7846667439C9D597
D3DDA1CFDA9ECEE1A1CFEAA5CCEEA4CBF0A3CAEFA2C4E699D5F4A8C1DB91CEE29BA2B36D
94A561CDE19CD9ECAACEE0A4CFDBADD2DAB1D2DEACCBDA9FCADE99D3E99EB2CA7C6F8A3D
D1EBA2CAE39FC7DFA1D5EDB1DAEFB6ADC28983975C7E9454D4EFA8C8E7A1C3E1A5CAE1B3
465131151700070100A5A082DAE2B3CEE6A8D0FAAEC6F6A2C8F1A2B4D086ADB377D8DEA2
CEE5A1CFEFA6CAE8A0C3E199CBE69FD0EAA3D2E9A3D8EFA9D6EDA7C8DF99D4EBA5CAE49D
B5CF88C4DF98C9E49DC7E59DC2E498CCEAA0D2E39DE2EBA8E5EEADD3E29FCCE7A0CCEEA4
BDDE97D5F0ABD2DEA0C7CF9351591DC2D092C2DD9AC5E49ECBE59CCBE399C2E195C2E497
C6EC9FCDF3A6CBF0A3C8E69CD2E9A3D5E6A2DEEDAA687734617130D2E7A4CCE7A2BFDF96
C2E89BCCF1A3C9E399DDEDA6D9E09C484D0A909753DDEDA6CCE89DC6EB9DC3EC9DC2ED9D
C6EB9DCAE99DD0E69DD0E69DC4E498CDEFA2C9E59AD1E99F96A7607F8F48B9CA83C5DB92
CDE79DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCAE99DCCE7A0CAE4A5D8EDB2656F32F2FDBB
CAE298D0EFA1C4E395D2E8A0D4D297AA9E6ACFC594B9B98597A66BA9BD7ED9E3A6D8DFAC
FEFFEAEAF1DFEBF5DCE4F2CFC7D6ABCBDDA9D5EBADBDD392
FFFFF8FFFFFAFFFFFFFEFEFFFCFEFFFBFFFFFBFFFFFCFFFBFFFFECA7C1A6074D427CCAB2
C3F5B8C0E38FD8FB9FC6E78ED1EDA2EFFFC8E2E9BFFFFFE6E6E0D4A29E9BFEFFFFF0F4F7
FFFEFFFFFCFA2209022C1203C6B59BFFFDD8D5E5B8D6EEBAD1E5B2D3E3B4D8E7C0E7F2D4
F7FFEAFEFFF6FDFEF9F7F6F4FFFFFDFFFFF8FFFFF1FFFFE8B3B792DDE5B4D1DAA1CEDA9C
DCEBAAD0E3A1CAE19BCBE9A1C9EEA1C3EA9BC3EA9BCBF0A0CBEA9EC6E096D3E79F7F904A
8A9B57C9DD98D7ECA9CFE1A3D6E2B0E4EDBECDDAA4CADA9BC7DB93859D4F7E9948DCF9A7
C1DD92BDDB93E2FFBCCCE9A7BBD594BAD592E3FCBACCE7A0B9D98ED2F3ACD2F0B4C1D9A9
6D7B581C2206030300C8CCA9D1DFACD0EDABADD889C3F39FBAE5958FAF64CDDB9DCFD99C
D9EEABCEE9A2C4DE97C7E19AD6F0A9D7EEA8CEE59FCEE59FD5ECA6C5DC96C6E099D9F3AC
5E7932CDE8A1E1FFB7BFDF96CDF2A5BDDD92D7EBA4DDEAA5BCCB88CBE09BD9FDB3B4DE92
BEE69DD3F2ACCCDC9DD3DB9F5D6327D5DFA2E1F6B5D2EBA7CBE199CFE59CD2ECA2D2F1A5
CAECA0C2E498C2E297C7E59BCFE6A0C4D893CFE09CB5C68258682790A562CEE5A1D9F7AF
C7EC9FC6E89BD6F0A6CBDC95DAE49F5F66228C9651DAEBA4CDE79DC8EA9DC5EC9DC3EC9D
C6EB9DCAE99DD0E69DCFE79DD6F6AAC5E79ACFEBA080984EBFD089DCECA5D0E19ACFE59C
CDE79DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCAE99DCCE7A0D2EFADC1D99B9DA96BC9D593
CEE89EC5E599C2E297D3E8A5EEEBB6A19467D8CCA2D4D1A4CBD8A3BBCC95CED7A0D8DBAE
FEFFE6F6F9E6FFFFEAEDF7D4CDD8ADD7E5B0D4E6A8A1B472
FFFFF6FFFFFAFFFFFFFEFFFFFCFFFFFBFFFFFBFFFFFBFFFDFEFFED98B19B00160EA7F6E1
C3F6BBBBE18CD5FA9BC2E589CCEAA0B8CB93EBF2C9FDFBE2FFFFF3DCDBD9474B4EFCFFFF
FEFCFFFCF2F31A0200190000AD9C80FFFFDACCDDA7C1DB9CCBE4A3CEE4A6D4E6B2E1F0C5
F3FCDFFEFFEFFFFFF6FFFFFAFFFFFAF3F0E9FFFFF1F6F6DC9FA17CDBE1B3D9E0AAD9E5A7
C6D793D5ECA4D4F0A5C2E497BCE392BFE997C2EC9AC9EF9CBFDE90D0EB9ED8EEA55D712A
8DA15CCFE39ED5EAA7C8DC9DCBD8A2D5DFAB8D9B605468238DA358D0E996D1ED99C4E18D
D0EFA1CFEFA3BFDF96BCDB95DBF9B1D0EEA6C2E195CAEA9ECFEFA3C7E6A0BDD99EDEF4C5
000800101700040900D1D9B2C6D9A2D9F6B3C6ED9EC9F5A087AE5D83A358CADD9DDCEAAC
CADD9BCDE29DD3E8A3DDF2ADD6EBA6ADC27D859A557B904BC9E09ACEE59FC7E19AC9E39C
506B24B8D68ED0EEA6C3E39AC6E89CD4F4A9D0E49DCAD994E0F1ADD8F2ABB9E296BDEC9E
C9F5AABCE098CADA9BD7DDA155561CDADEA3D7E5A7C2D593DEEFA9D1E29BC9DF96D1E99F
D1EBA2CAE69CCDE79ED7F1A8D3E8A3D3E7A2D9EAA6E2F1AE91A05F96A564DAEAA9C6DD97
C8E89DC7E99CD5EFA5C0D18AD9E49FB0BA7599A45FD0E19ACDE79DC9E99DC6EB9DC5EC9D
C8EA9DCAE99DCFE79DCFE79DBEDE92B9DB8EE0FCB1445C12CBDC95D3E39CCBDC95D8EEA5
CDE79DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCAE99DCAE89ECCEBA7C5DF9E93A261CDDC97
C0DA90E2FFB7C2E19BD8ECAFCAC697AB9D78E6D9B7EFEBC8F8FFDBC6D3A8AFB48BFFFFDD
FFFFE6FFFFE8FFFFE4F2F9D0E7EFBED9E4AAC5D491B6C780
FFFFF4FFFFF6FFFFFBFEFFFFFBFFFFF9FFFFF9FFFFFBFFFBFEFFEDA5C1AB145B5778C9B8
BCEFB7CCF3A2C5EA8DCAEC95CAE7A4DBEFBAF0F6D2FFFFE9FFFEF3FFFEFCD5D8DFD6DAE3
FDFCFFFFFBFF3C2424260B009D8C72FFFFD8D2E4AACDEBA5CEEAA0CCE69DCCE2A2D0E2AE
DCE8C0EAF3D6F8FCEBFFFFF4FFFFF6FEFCF0FFFFEF56563CD7D9B4D5D8ABD3DAA6E0EBAF
D0E49FD0EAA0C6E798C2E797CAF4A0C9F5A0C1EB97C3E996D2F1A1C9E495CEE49963772F
B5C982D3E8A3CAE19DD3E8A7DBE8B08F9C6493A163C9DD96D2E99BCFEB97D6F39FC8E893
C2E394D0F0A4C4E69CC6E89EC3E398CBEB9FC2E392CCED9CC5E697D0EEA6D7EFB5CCDEAE
000700000600040A00D3DEB3D6EAAFC2DD98CBEC9DC4E79583A654D4F3A7C7DE9AD4E7A7
D4E4A3D5E6A2D3E4A0CBDF9AB3C7828DA25D869B56A0B570CEE59FD0E7A1D1EBA4D4EEA7
A5C0798BA96186A45CCBE9A1A4C67A89A75DAEC27BD5E49FCFE39EC8E39CC3EDA1C3F4A5
C1EFA4C3E79FD7E7A8767A3F5B5920D6D49BDCE2A6DDE7A8DDEAA5A1AE6878884194A55E
C5D992DBEFA8D2E69FC7DB94D3E4A0CFE09CCDDC99CFDB99D5DFA0555E1F737C3DD1E09D
CBE79DC9E99DC9E399D6EAA2D0DD97DFEAA58A9751D7E8A1CFE79DCAE99DC8EA9DC8EA9D
C9E99DCAE99DCDE79DCDE79DD1F1A5CFF1A4C2DE9351691FC9DA93DDEDA6D5E69FC7DD94
CDE79DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCAE99DCAE89EC6E59FC9E7A198A963D0E19A
D3EFA4BBDD93C9E9A6CBE0A7E7E3BDC6B69CD8C9B4D8D2BCFCFFEAFBFFEAC3C3A7F1EDD4
FFFBE5FFFFEAF7F6D8EEF0CBDFE5B7A2AB74939F5FD3E29D
FFFFF1F8FCEDFCFFF6F4FCF1F9FFFBF8FFFBF8FFFBF9FFF6FCFFECD7F2DF337977A5F5EA
C0F2C1C0E69BC4E891D1F2A1C8E4A7CFE2B5E3E8C8FFFFECFFFEF8FFFDFEF8FBFFD1D5E0
FFFDFFFFF7FF3A21253A1F1897856DFFFFD7D5E9AECAE8A0C8E797CBE898CDE7A0CFE5A7
D5E5B4E2EEC8F6FCE2FFFFEDFFFFEFFAFBE9A6A68EDCDDBEDDE2BAD8DEB0D6DDA9D3DEA2
CEE39ECEEA9FCEEFA0C2E998B9E38FC4F09BC9F39DBEE48FCCEB9BD2EA9CCEE4998CA058
CBE199D4E9A4CDE6A2CFE5A4D1E1A396A467D3E29FD8ECA4D3EA9AC7E38FBEDB87D5F5A2
CEEEA2C7E99DC5E79DC8EAA0CAECA0C8EB9BC9EB97CBED99C5E194D8F2ABD3E2ABD1DAAD
040800030700000600D8E4B6C9DB9FE1F8B2C6E19293AE5DD1EC9DBED88ECDE4A0CFE4A3
D6E6A5D2E19EC7D693E1F2AE8FA05C829651DEF3AE8BA05BD8EFA9C8DF99CEE8A1CAE49D
CCE7A0CAE59EC9E49DD3F1A9CBE99F90AA6195A45FD0DD98C5D692D7F1AAC3E99EC5F1A4
C2ECA2C4E39DE2EEB056541B8B824BEDE4ADDBDAA1E4E8ABDAE19E535D184F59145C6722
1E2900646F2BDFECA7D8E5A0DAE6A4D6E2A0DCE7A5D2DB9AD7DB9E66672B514F14D6DC9C
D2E9A1C3E296C5DF95DBF1A8D1E19AE0F0A97F8F48DCF0A8D0E89ED1EDA2CAE99DC8E89C
CEEDA1CDECA0C8E499C6E297C3E598D4F6A9C4E095D9F1A7DAEBA4C7D790E3F4ADD2E89F
CBE59BC9E99DC6E89BC1E698C6E89BCFEFA3CFEEA2C9E89CD5F7AAC0DF9392A45AC8DA90
D6F2A7C2E39CDFFFC0F7FFD8FFFEE0FBEADAFFEFE5FFFDF4FCFFF6F7FFF4FBFBEFB7B1A5
534D418D8779F6F1DDFFFFE6FFFFE1C0C79BCDD7A2DBE9AE
DCE4CDE4ECD5FBFFEFF0FCE8F8FFF1F7FFF3F8FFF3F6FFECFCFFE8DFFCE83A81833B8783
C7F7CFC2E5A5D3F5A9B8D88FCBE8B2D5EAC3EAF0D4FFFFEFFFFEF8FFFEFFFBFEFFD2D6E1
FFFDFFFDF3FE37202820070385755EFFFFDCCEE2A7CAEAA1C8EA96CAEA95CCE89DCCE5A1
D1E4ACDAEABBEBF5D0F7FEDFE9EDD2C8CCB1B9BC9DCCD0ADD7DCB3E7EFC0F1F9C6E3F1B6
E5FAB5C9E59AC5E599D1F6A6C9F3A1BEE894C3EA97CDF09CC9E696D3EB9DADC378B1C67B
D6ECA3D0E79FCEE9A2C9E29ED4E4A592A160D5E6A0CFE499D3EA9AD4EF9EC8E595CBEA9C
C7E79CC5E69FC9EAA5CDEEA7CDEFA5C8E89CC6E796C8E797D3EEA1BFD48FE0EBB3D2D5AA
2828062223010D1300CDDBAAD4E6A8B7CD85CDE091687B2ADAEFA0DAF0A5C9E29ED1E8A4
D0DF9ED8E4A2B4C07E99A8658A9B57CFE39ED2E6A18FA45FC4DB95DAF1ABC3DD96CFE9A2
D0EAA3CDE7A0CEE8A1CAE59ECFEDA3B6CD85B4C17CB1BC78D5E19FD5EAA5C1E59BC3ECA0
C7EDA4D7F2AD7F874B6A632CDFD29DE6D9A4D5D0987273375A611E7D8742A5AC68909753
5E6321676E2BA5AC69CCD592CCD795E1ECAACCD594DDE3A3E3E3A7989359655A22E5E3A6
D5E9A2D8F4A9D3EDA3CEE49BBFD38BDDEEA79CAD66D1E59DCCE49AC5DF95D6F2A7CBE79C
BEDD91CFEEA2CFEEA2CCECA0D2F4A7C4E699CCE89DC9E1978FA059DCECA5BBCC85D2E89F
CCE69CCAEA9ECAEC9FC5EA9CC6E89BC8E89CC9E89CC7E69ABFE292C6E597A0B266D2E49A
C5E196D2F3ACD4F6B9F1FFD8FFFEE3F3E3D6F2E3E0FFFAF8F6FCF8EEF7F2FFFFFBFFFAF6
D3CACBBEB4B3B9B2AA969384B1B09BADB292CFD7AECEDAAC
CCD9BBDEECCBF8FFE6E4F5D3E6F7D5E4F8D5E6F7D7E2F1D0E8F3D1EDFFF472B9BF125D62
D6FFE7BEDFAAD9F7B9C8E6AAD1ECBFE0F3D3F3F8E1FFFFEFFFFDF1FFFFFBFBFFFFD0D4DD
FFFDFFFFF8FF39222A14000081705EFFFFDDCDE0A8CDEDA4CAEC98CAEC96CBEA9CCBE79D
CDE3A3D2E5ADDDEBBAE5F0C5CAD5ADA9B18AEEF4CED9E1B8DFE8BBF5FECFFEFFD4FAFFD0
F8FFCAD2ECA3BAD88EC8EA9DCAF1A0C2E996C3E996CAEB9AC8E595D4EC9E889E53D3E89D
D8EEA5C5DF96CFEDA3C8E39CD1E4A28C9C5BDEEFA9C8DE93CBE395D3EE9FCBE79AC4E298
CAE9A5C8E6A6CAE8A8CDEBABCBEAA6C8E69EC9E89CCEEA9DD2EAA0CADB97EBF2BC5C5B2F
4A4724080800070F00CBDCA8CDE2A1ECFFB8546112D4E191D9E79AC4D98ED0EBA6CEE9A4
DEEDACDAE5A3737F3DB7C683CADB97D1E5A0D6EAA58DA25D162D00E3FAB4D8EFA9C5DC96
DCF3ADC4DB95C3DA94D7F1AACEEAA0D6EDA5D0DD988D9653DEE9A7D3E4A0C3E39AC4E89E
CAEBA4BFD6929FA3685E551ED2C28EDDCD9975703875763AB6BF7CE3EEA9DFE6A2CFD491
E3E5A4CDCF8E8F9653757E3B8B9654CFDA98E0E9A8DCE1A1E0DEA3E7DCA4A5945E8D8449
CCDB96D1EBA1C3DB91D6EEA4E1F7AEBFD38B8DA159D1E79ED9EFA6C6DE94DCF4AAD3EDA3
C1DD92CDECA0CCECA0C9EB9EC2E799C4E699D4F0A5CDE59BB0C17A9EAE67DAEBA4D3E9A0
CDE79DC9E99DCAEC9FC9EEA0C8EA9DC4E498C6E599CAE99DBFE091D3F2A2B4C67AD7E99F
C2DE93CEEFA8C7E9ACD7EDBFFFFFE8E9D8CEE0D2D1FFFDFDF6FFFAF0FBF5FEFFFBFFFEFD
FFFAFFFFF4FFF7EDF8D3CED2F3F2EEFDFFF3FCFFEDECF6DB
D1E3BDE2F4CCF5FFDDD2E8B9CAE2B0CCE4B2D3E9BAD2E5B8C7D4A9EDFFF395DBE32E7883
D6FFEEBFDBB3C6E0B0D6F0C0DAF4CFEBFEE2F9FFE9FFFFEDFDFBECFFFFF6FBFFFBCDD6D5
FEFFFFFFFBFF351E26150000837260FFFFDDCDE2A9CAE9A3C9EC9ACAED99CAEB9CC9E89C
CBE4A0CEE4A4D4E6ACD9E8B1D2E0ADB0BC8CE9F5C5CCD8A8D7E5B2E6F4C1EFFDCAE9FAC3
DDF1B2D1E8A4CAE59EC5E59AC0E597C8ED9DCCEF9FC2E191CEE99AD2E99B869B50DAF0A5
CFE79DBFDB90CFEFA4CCEAA0D0E5A0899D58E1F5AECDE39ACBE397CBE59BCCE7A0CBE8A5
DBF7BAD1EDB3C7E2ABC4E0A6C7E1A4C8E2A1CDE6A2D3EDA4CBE399D3E4A0AEB37D5C592C
817D584D4F2A192600DCF1B9C1D894CADF9495A051DDE697CFDA8ED3E89DD7F9AFBBDA94
D2E2A1818C4A7B8644D5E4A1DFEEABD4E8A3C6DA95B8CD884F6620BFD690D4EBA5C2D792
D1E6A1E1F5B0D5E9A4C7DE98C4E298D8F4AAD6E5A0838C49DBE4A3D1E09DCBE69FC7E99F
C9E7A1E5F8B6818248685D27F0E0AC9F925D504E15C0C688E1EEA9D5E59ECDD893D6DD99
E7ECAADCE19FA8AF6C75803C3F4B09606F2CD0DC9AE8EEAED4CF95D6C992D9C48F7E7238
DBE6A2E3FBB1CEE69CCAE298D3EBA1CFE79DB9CF868EA45BC8DE95CDE39ACCE299D3EBA1
D1EDA2C7E69AC6E89BC3E598C1E698CDEFA2D0ECA1D4ECA2D7E8A14A5A13C5D68FC7DD94
CFE99FC7E79BC7E99CC9EEA0C9EB9EC6E69AC8E79BCEEDA1CCED9ED4F0A3A5B56CD3E39A
D4F0A6BFE099C8EAADC5DBACFFFFE5E2D4C7E0D6CDFFFFF8F8FFF8F5FFF6FAFFF2FAF9F4
FCF4FFFFF9FFFFFAFFF7F1FDFFFFFFFBFFFAF8FFF1DAE6D2
CFE6B8DEF6C4F1FFD3C8E4A7C1DE9CC6E3A1D1EBACD3E8AFCFDDAAEDFFEFA4E8F342899B
D7FFF6E1F9DFDDF2D1DBF1CDE9FFE1F5FFECFCFFEAFFFFE8FFFFE8FFFFEDFBFFF3D0DACF
FEFFFDFFFCFF29131612000073624EE6E6C0CDE2A9C5E69FC8EA9DC9EC9CCAEA9ECAE99D
CBE79DCCE69FD0E5A2D3E6A6DDEFB1BBCD919EB076899B6194A56E92A36D85976383965F
9CAE72BACE8FD9F2B0D8F6B0C6E89EC7E99DCFEFA3CAE699D1E99BCEE597A3B86DD3E99E
CCE79AC4E395CAEC9FCDEDA2D3EAA48A9E59C9DD96CFE59DD5EDA3CCE69FCFEAA7D3EDB0
F3FFD7E3FBC9D3EBBBCEE6B4D0E7B1CFE7ADCFE5A7CEE5A1D0EAA1E0F4AF979C64070400
686640BEC59CDBEDBDCBE4AAE1FCB55C7325D9E495D7DE8EE9F6A7C8DE93B6DF93D2F8AF
B0C3819EA967C9D492CFDE9BCFDE9BCEE29DDBEFAACBE09BDAF1AB5A712BC4D994EEFFBE
879B56CCDD99D9EAA6D5EAA5C3E599CAEA9FCEE29B949F5BD1DA99D2E19ED0EAA3CAE8A0
BED994DBEEAC83844A6158215E531D5E5720D2D69BD7E6A5CAE098C7DF95DAEBA4DEEBA5
CDD693D4DD9AE1ECA8D3E29DB3C7827185405E6F2B424D0B666429C9BC85E3CC98473800
CED794C5DD93CCE49AD4EEA4C6E096CEE89ECBE3994A60178BA158D7EBA3C6DA92C7DD94
D6F0A6C4E397CDEFA2C0E597CDF2A4C2E497C9E59AD5EDA3C4D58E8E9E5790A15AE4FAB1
D1EBA1C8E89CC5E79AC6EB9DC9EB9EC9E99DCAE99DCEEA9FCDEBA1C7E1986E7B35D6E39D
DBF5ACC2E39CCFF2B2CDE4B0FFFFDDECE1CBEEE7D4FFFFECCADDC1C8DDBED1DCBADEE1CC
FFFDFFFFFAFFFFFCFFF7F4FBFEFFFFFBFFFAF9FFF3E8F6DF
CDEAB4D8F5BBEEFFCACBEDA3C8E99AC8E99ACCEAA0CDE6A4DAECB2E9FFE9C3FFFF367D93
C6EDECF2FFF8F5FFF3EFFFE9F1FFECF5FFEAFBFFE5FFFFE4FEFFDFFFFFE4FBFFEACCD8C4
FEFFF6FFFEF833201C110000584932DCDDB5D1E6ABC9EAA5C8EAA0C8EA9EC9E99DC9E99D
CDE99ECEE99CD0E89CD1E79ECDE39BDCF1ACBCD18ECBE1A1D3E8ADD2E7AED4E8B3E0F5BD
B7C98FACBE82BACE8FD1EAA8D1EFA9C9E9A0CAE89ECDE99ECBE397CFE698BCD186CDE398
D2EDA0D0EFA1C2E799CAECA0D0E7A18EA3609FB46FC2D991D7F1AAD0E9A5CDE7A8CAE3AC
F4FFDCF5FFDFEEFFDAF1FFD9EEFFD3E4F6C4D5E6AFCBDFA0C4DF98CADF9A4E561D5E5D2F
707149EAF3C8CCE4B0C5E5A6C8E89F8FAA59DCE997DAE392CCD98AD6F1A4D6FFB5B3DF94
889D5AD8E3A1EEFAB8CCDB98DCEDA9C4D893E4F9B4C8DD98D9F0AA90A761566B26374B06
D7E8A4576623C9D895D4E9A4C8EDA0C2E89BCAE199A4B16CCDD896D3E29FD1EBA4CAE8A0
D1ECA7D4E7A57273390C0500625B24D7D69DDDE9ABC6DD99CAE89ED7F6AAD8F0A6CBDF97
CEDD98D9E6A1D6E7A1CCE099CFE6A0D0EAA3C9E09AD9E8A5999A5E685D255F48146A5921
B2BB78DBF1A8CAE298C8E298D1EDA2C4E095D9F3A9D3EBA172863EDBEFA7D7EBA3C7DD94
CDE79DC5E498D3F5A8C2E799C9EEA0C5E79ACAE69BD4ECA2CCDD96E5F5AE97A861C4DA91
C8E298C8E89CC9EB9EC5EA9CC6E89BC9E99DC9E89CC9E59BCCE7A0CAE19D596422DCE9A4
CBE59ECEEDA7CAEAA9D2E9B1FFFFDCF5ECCBFCF7D9FBFFDDD0E5BACEE8B8D0E2AED4DCB7
F8F7F2F7F2F9FBF9FCFFFFFBFCFFF6F5FFEDECFCE1E5F8D8
CEEDB2CFEFB0E3FFBBC7ED9ACBEF97C7EB91C7E794C8E298CDDFA1E4FFE3CFFFFF30738E
A8CBD1E4F5EFF7FFFBF5FFF4E9FFE6E4F7D7E4EECBF1F5D0EEF0C9ECF3CAE3F1CDB9C6A8
FEFFEFFFFCF058463C11000044361BF0F1C7D3E9ABCBECA5C6EAA2C7E99FC8E89DC8E89C
CCE89BCDEA98CDE897CEE796BED786D7EFA3D3EAA2DBF4B0C8E0A2C7E0A6CBE4ADC3DAA4
E5F4BDABBA8199AB71BED496D3EEABCEE9A4C9E59BCCE69CC8DE93D7ECA1B5C77DC6DB90
D0EB9ED2F1A3BDE292C8ED9FC9E39CAEC38094A964C3DA94D3ECA8CBE4A3CCE4AAC6DDA9
EFFFD9F2FFE0F7FFE4F8FFE4F9FFE1ECFCCFDBE9B6CEE2A7D3EEA7BBD58E636C33868859
70754CD1DEB2BEDCA6CFF6B3C4EA9DA1BE6CE0EF9CD9E28FE0EE9FC5E194BAED9EBFEFA3
8BA25E8C9755DAE6A4C3D28FD8E9A5DFF3AEBDD28DDCF3ADC9DE99BCD18CE2F6B1D9EDA8
D5E4A1DDE9A7737E3CD4E9A4C6EFA1C4EFA0C9E59B9BAC66D4E09ED2E39FCDE7A0CBE9A1
D1ECA7C6D997999F63A4A269DBD9A0E0E6AACBDE9ECDEBA5C5EB9EC1E899C1E195C8E298
D4EAA2D7EBA4D3E9A1CEE89FC4E29ADBFBB2BDD891D3E7A2D8DEA0BFB67D836E395C4D14
4B5411CEE49BD6EEA4C8E298DBF7ACCDE99EBED88ECCE49A9AAE66B5C67FD2E39CD4E8A0
CBE59BCAE99DC6EB9DC5EC9DC5EA9CD5F7AACCE89DCFE79DD5E69FD2E29BB5C67F62782F
AEC87EC0E094CDEFA2C6EB9DC3E598C9E99DCBEA9EC8E49ACEE9A6D2E6A7939D60D1DB9C
C5DC96CFEEA8C4E4A1CBE3A7D2D4A5AFA87EC8C79BD2DCAACCE6A9CFEEAAD4EBA3D2DFA7
FFFFEAFFFFF4FFFFF1FEFFEDEBF6D8DAEAC3D1E7B8D2EAB6
CAE7A7C3E09DD2F2A7BEDF8EC8EA93C8E992CCE997D1E99FD4E6A8F0FFE6D6FFFF4E8C99
AAD2D4E5FFFFDEFDF8EDFFFBDAF2D0D0E3B5CCD8AADAE3B4D3E4AECFE1ADCFDCAEAAB28D
F4F4DCF3EDDF726960080000372C16FFFFDCD1E3A5C6E49CC9E9A6C7E7A4C6E7A0C7E79C
C9E89ACAE999CBE896CAE795D6F1A4C5DF95CBE4A0CCE5A4CCE4A8F3FFD2F5FFD6D3E5B1
CCD9A4A5B27CA1B379C5DB9DD2ECABC7E59FC6E49CD0ECA2C5DF95DCF4A89AB067BBD188
C8E096D0EAA0BDDC90CFEEA2CCE39DD8EDA8A9BE79D3EAA4D2E9A5C7E09FD2E7AED0E7B1
D2E8BADFF1C9F0FFDCF8FFE3F5FFDBE2F1C6D7E4B6D0E1AAD2E7A4788C475C6429DDE1AF
666D41DCECBDBEDDA4C1E8A58AB065C7E897D3E694D2E190D5E698C4DF92C3EDA3C3EDA3
D7EEAA909F5CADBC79DEEFABD2E39FCBDF9AD3E7A2CCE19CD3E7A2DFF3AECADE99C5D994
D7E8A4D4E5A14A5916D1E6A1C2E79ACDF3A6CAE69C889C55DAEBA5D0E49DC9E59BCDEDA2
CAE8A0D7EEA8D1DD9DD2DB9CD8E1A2D4E2A4C8E19FC9E7A1CCEAA087A35889A058BCD089
C8D993CDDE98D5EBA3C7E198C1DF97CEEEA5CFEDA5CBE29CDDE9A9D3D498EFE9AFD6D497
DAE7A2CBE399C1DD93DBFBAFBCDE92BEE093D7F7ACD1EDA2C5DB9374853EADBC77DBECA5
D2E9A1D1EDA2B9DB8FCEF5A6C1E698CAEC9FC5E498D4EEA4C6DC93D4E8A0DFF3AB6A8037
94AE64B9D58AD0F0A4CAEA9EC2E296CAE99DD1EDA2CCE89ECCE5A3CFE3A4DBE7A9BAC686
D0E5A0CFE9A2D0EDAACBE1A1DBE2ACB2B482D6DDA9D7E6ADCEE8A9C6E3A0DEF4ACF0FFC6
F7FDE3FBFDEFF8FDE7F4FEDCEBFACFE5F9C4D1EBACC0DD9A
D9EDA6CFE39CCCE29ACDE39BCDE39BD1E79FD2E6A1CADD9DCBDDA3F4FFDDE0FFED548474
64988B98D1CAC8FFFFCAFFF0D3F0BAD5E49FCCDB9AD1E7A6BFE9A1C1E9A3DAE5ADC7BF98
96866FFFFDF3646A68000400323023FFFFE1D9E3A6D2E69FCCE6A7CAE9ADCAEAA9C8E9A4
C8E89FC9E99ECBE99FCAE8A0C5E09DD2ECADCFE7ADC5DAA2D7E9B5F7FFD4CEDCA796A36E
97A16CB1BB86CADCA2D5EBADC8E5A3BEDF98C0E49AC9EFA2CDF2A5C4E699CDE99FB2CC83
A4B871C0D18BD1E09BD7E6A1D2E39DCAE098A4BA72AEC37ED2E7A4D4EAA9D1E5A8C4D99E
C9DEA6E8FCC7F7FFD8E9FDCCF7FFDAE2F6C5D0E4B3D2E3ADE2EBAC8B904E989C61E2E9B3
67713FCCDEAAD1EEB4BFE2A283A75FC8EA9ED0EC9FC9E092D2E69EDBEFA8D2E7A4CFE4A1
D1E4A2C9DD9894A561B0C17DC9DA96D7E6A3D4E3A0D1E09DD2E39FDBECA8C8DC97DCF1AC
CFE6A0CDE7A067813ACDE7A0CCE69DD2ECA3CFE79D8CA259D5EBA2C7E197C5E496CBEC9D
C4E596C8E79BD0ECA2C9E39ACAE49DD4EDA9CDE8A3CDE29FE3E8A87A76378E8C4F868648
D9DB9CC9CF8FF2FEBCC9DD98D2E9A3C2DD96CFEAA3D1ECA5C9E09AD2E7A2D5E9A4CCE09B
D3E8A3CDE99FBFE197B8E193CFFBAEBAE697C0E99DC9EB9FD8EFA9667731929E5CDCE9A4
D1E5A0C5DF96DAFAB1C2E79AC8EFA0C4EB9CC4E699C9E99DD0ECA1CFE79DC3DB91B8CE85
859B52D3EBA1C8E096D5EFA5D3EDA3C4DE94D1EDA2C9E59BCFEAA3D8EFABC2D38F9BAA67
D2E19CDBECA8CCDD99D8E8A9D4E4A68F9E65A0B37BDDF2BACBE2ACC6DDA7F9FFD8F8FFE0
FBFEF7FEFFFFF8FFEFE9F4D2D6E8B4CAE3A2C7E59BC9EA9B
D0E097DBEBA4D4E59FCDE19CD6E9A7D2E2A3CEDE9FDEEEB0CDDCA3F7FFD8EEFFE1E6FFED
32695441857AB2FFFE9ADDCCC9ECB2CDDF93D4E5A1D1EFA9BBEFA4BFEDA5DAE4A8E8DBB1
CEB8A3FFFBF46C76770007072E2B22F4EFD2D3D99BDBEBA2CDE6A5C9E7A7C8E7A3C8EAA0
CAECA0CAEC9FC9E99EC6E49ED2EFADC1DAA0CADFA7D8EAB6D7E5B0ABB882A9B47AD2DDA3
CED9A1F1FEC6F8FFCED7F0AFC4E19ECFF0A9CFF5AABDE698C2E89BCCF1A4C5E59AC3DD94
BED28D8F9B59889150D2DB9AD8E7A2DAEEA7C0D48D8DA25D738845C6DB98DCF1B0D3E7A8
D7EDAFCDE2A7CBE0A7E3FAC2F5FFD6DAF1BBCDE4B0D3E4ADB9BA7E7C7B3B9FA066D7DFA6
6D7A45CBDEA7CAE3AACEECAEA9CA8554762CC5E399D1EDA2C9DF97C6D793DAE6A6D3DF9F
DEF1AFD1E6A1CADE997A8B477E8D4ACFDE9BDDE9A7DDE9A7CAD996D8E9A5D4E8A3C6DD97
C4DE978DA861C8E69ECAE59EC7DD95D3E7A0CFE59C8AA258D0EB9ECDE99CCBEA9AC9EA99
CCEF9DC6E997CAEC9FC9E99DC7E79ECAE8A0C9E7A1D5E5A4979356DED298EBE2A7D3CF92
4B4B0D4C52125D69277F904C9CB16CD3EAA4D5EFA8CDE7A0CCE69FCEE9A2DBF6AFCAE59E
CBE59EC9E49DD4F8AEC3EDA1BBEC9DBFF0A1C4EEA2C5E99FC4DB95B6C783687331A2AD6B
D0E19DCEE59FBFDD95C4E99CC5EB9EC1E899C1E698C6E89BCDECA0CFEBA0CAE49AC6DE94
BAD0878EA25AD5EBA2CFE59CCAE298D4ECA2CDE79DC8E499C9E49DC9E39CD6EAA396A761
BAC782D6E19DCBD795D6E5A2D6EBAAABC1818BA369CAE3AAC9E0ACD8EBBDF9FFDDFBFFEA
FCFFFFFCFFFFF8FFF1E6F4D1D4E9B1CAE59EC8E799C9EB97
CEE096C6DA92DAF0A8E0F5B0C9DE9BCCDF9DD9E9A8C9D99AD4E3A8DCF1B9D5F1C1D4FAD5
6BA0863C7A6B6CB5AE9EDECDBCE4B2C6E0A1CFE4ABCBE7ADBDEEADC3EDADD2DCA7E0D4AC
AD9883FAE9E1898A8C000404271E17F3ECCFE1E9ADD4E99CCFE99FC9E99DC8E998CAEC98
CDEF99CCEE98C9E898C6E599D2EDA8CEE7A6DBF1B3D1E5A8D3E3A58998579CA964DBE7A5
DCEAADF9FFD1F8FFCFD0E9A8BFDC99D3F2ACD3F7ADBCE295BDE295D3F5A8C1DF95C9E39A
D5EAA5A1B26E869252A7B371CDDC97D6E7A1C0D18DD0E49F55682699AC6AC1D695D7EBAC
CAE0A0D1E7A9C5DDA1F1FFCFF5FFD3E0F9C0D3ECB3D1E3A99A9F5F5B5A1A96975DDFE4AC
5F6935DFF0BACCE3ABC7E1A4CEEBA86B89417E9C52D2EEA3E0F7AFCBE09BD0E09FD1E1A0
C0D391D6EBA6DDF1ACA7B87497A663A3B26FD4E3A0C8D794EDFCB9C5D692D1E5A0DAF1AB
C3DD96516C25D8F6AEC8E39CC7DE96D1E79FCCE2998AA258CBE699CFEB9ECEED9DC8E998
D1F2A1C6E796C6E69ACCECA0C9E79FC8E39CCBE6A1CEE19F979D5DE7E7A9D7DC9CD2D898
8E99579FAE6B93A460768B46829752859C56CCE39DDFF4AFCADF9AC9DD98BED28DD2E6A1
D0E5A0BFD992D3F3AACAF0A5B4E093C6F2A5C7F0A4CEEEA5CBE29CE8F7B495A05E788341
D5E6A2D2E9A3C4E29ACEF3A6C5EB9EC3EA9BC2E799C5E79AC9E99DCFEBA0D0EAA0D2EAA0
D3E9A0889E55D2E89FC7DD94D2EAA0C7DF95CFE99FDCF6ACD3EDA6D4EBA5DAEFAA8D9E5A
818E49DEEBA6DAE7A2DFEEABD1E4A2C5DB9A8CA468C8E0A6CADEA9DFF3C0EFFFD0FAFFE5
FCFFFAFCFFFFF8FFEEE3F3CED3E8AFCBE69FCAE99BC9EB97
82984D839B517C964D829C557289453C510E526523B7C786DBEBADCDE0A8D2EDBAEBFFE6
DEFFEEDBFFFF2D6F653F7E6DB2E2BAD6FACACDE6BEC7E0B8C4ECBAC5EAB6CAD3A4A29A73
988670E0CEC4979191050001170801D0C7AAD1DD9FC2DB8ACFEC9ACCEC97CBEC95CBEE94
CBEC93C8E992C8E797CDE99FC3DC9AE4FABCF8FFD1CBDDA1D0DEA07D89479AA65EC9D690
CBDE9ED1E7A9D5EBADCEE7A6CAE5A0CAE8A0CAEA9FC6E89CD1F1A5CDECA0C1DD93C9E39A
CDE29DCDE19CCFDF9EB1C07F596825B3C47ED3E4A0E3F4B0D6E6A5C4D7959BB06F889D5C
A2B877E8FEBECCE4A6C4DE9FBCD699C5DFA2CDE7AAD1E5A6AFB5757C7E3D898D52EBF3BA
5F67345B6934000F00A6BB80C7E09EC3DE97CEEAA0829C52678138637A34D5ECA8D2E7A4
D3E8A5D4E9A4C5D994D2E6A1BCCD8973823FA2B16ED7E6A3CCDB98D6E7A3C3D792DEF3AE
96AD67B5CF88CCE7A0CDE8A1D1E8A2D0E79FCAE19993AD63CAE69BCAE99BC8E99AC9EA99
CBEC9BC5E697C2E296CCEB9FCCE89ECEE8A1CDE6A2B1C6838C9D59D3E29FDDEEAAD4E8A3
DBEFAAC2D792DDF4AEC7DE98C7DE989BB26C859A55C9DD98DDEEAACEDD9AEDF9B7D5E4A1
DFF0ACCCE39DC1DF97CBEDA3C3E99EC1EA9EC4E89ED2F0A8CEE39ECEDD9AD8E3A1939F5D
96A763D0E7A1C4E29AC8EA9EC8EDA0C7EE9FC7EC9EC7E99CC7E79BCBE79CCEE89ED2EAA0
C5DB92D8EEA550661DAAC077D8F0A6CBE399D0EAA0B1CB82C3DD96D4EBA5C0D5908EA25D
5A6924D8E5A0D7E49FC9D893CADB97B9CE8BA8BE7ED5EAAFCBE0A7D7EAB3D7E9B5EBFAD3
FBFFF4FBFFFAF6FFEAE2F2CBD0E8AECCE7A0CBEA9CC9EB97
BCD88DC6E297D5F3A9C9E79FC3DE99E4FDB9D5EAA5879756425211CBDDA1D2E6B1C9E4B9
D6FBDADBFFF33D73634E89778FC7AADFFFEEDFFBE5E7FFE9EAFFEAF0FFE6FCFFDFAFAB86
FFF7E0FFFAEFBAA7A93A2729361F17BCB193CEDC9FDDFAAACDEA96CDEB95CEEC96CCED96
C8E591C4E191CAE59ED5EFAECCE3ABE7FBC8F9FFD8D8E6B1CFDAA25C66278F9954DAE7A1
D0E5A4C5DFA0C7E1A0D3EEABD5EEAACAE59EC8E49AD0ECA2C0DA90C1DB91D3EDA4E1F8B0
CFE6A0D1E6A1DBF0ADC7DA98C8D7944E5D1ADBEAA7C3D490E4F4B3BED18FD9EEABD0E5A2
475E1AC5DB9AD4EDABCFEAA7D2EDAADBF8B5CBE8A5CCE39FE1ECA8959A58A0A66ADAE2A9
737B486A7440000A005A6C32D4E9A8DBF2ACC3DA92D4EEA4D7F1A8CBE69F47621D839E59
D3EAA6CEE39ED4E8A3D3E7A2C3D49094A561697A36C7D894D1E29ED0E19DDDF1AC829752
D3EAA4CCE69FD4EFA8CCE7A0D2ECA5CBE59ECBE59CA9C57AD4F0A5CCEB9DC5E697CBEC9D
C6E597CBEA9CC6E599CCE89DCBE59CD6EDA7CDE29F869D5993AE67CBE9A1B8D68ECFEDA5
D2F0A8C8E69ECCEAA2C5E099D0EAA3C9E09A92A6612132001521003F4A084C55148C9554
CAD996E1F5B0CAE49DCCEAA2D3F5ABC0E298C6E69DCDE8A1CFE39ECEDD9AE1EDABD7E3A1
495A16DDF2ADC6E19AC8E89DC6EB9EC7EE9FC9EEA0C9EB9EC7E79BC9E59ACAE49ACCE69C
D2EAA0C9E197DBF1A8758B42DEF6ACD0E89EC8E096E5FCB4CEE8A1DFF6B2D7ECA7D0E49F
9FB06AC4D38EDAE9A4D0DF9AD0DF9A97A864B5C886D6EAABCEE2A5D2E6ABCBDFA4DAEBBE
F0FEE7F8FFF3F5FFE7E1F4C7CFE7ADCCE7A0CCEB9DC9EA99
CCECA0D7F7ACCBEBA2C6E69DCFEEA8C2DD98BED58FDDF1ACB7C683707E40D5E6AFD0E6B7
CBE9C3E7FFF17BA89320554382C1AED6FFFFE9FFFFF0FFFFEFFFFAEDFFEAFCFFE6A7A485
FEEFD8FFF8EBA3898A2C0F11280B03B0A285CCDEA0CBEA9CCAE797C9E696CCE999D0EC9F
CDE99FC9E4A1D1EAB1E0F6C7F2FFDCF5FFE1F7FFE0D5DFBAD5DCB0717844ABB175E2EEAE
D2EBAACDEAA8CAE7A4CBE6A1CDE7A0CFE9A0D1E8A0D1E8A0D1E79EDAF0A7DDF3ABBED58D
BED58FD8EFA9D0E9A5CEE3A0D5E4A1EAF6B4697835303F00D4E4A3CFE2A0D9ECAAD1E6A1
B9D08AD6F0A9D2EDA6C7E29BC3E199C3E39AB9D990CEE89FBDCC87A1AA67555D21010900
58602DE9F1BECAD4A0DAE7AFCEDC9EC3D792D8EEA6CDE59BC4E096D5F3AB9DBC76597731
8FA662DBF0ABE1F5B0D5E9A4D4E5A1D2E39F95A66298A965CFE09CD9EDA8A6BB76768B46
D4EBA5D0E7A1BAD48DD5EFA8CBE4A0C7E29DCEE9A2B3D187D1EFA5CEEDA1C6E798CBEC9D
C7E698D4F0A3CCE89DCEE89ECAE199D6ECA4CBDF9A6A813D81A359C5EBA0C9EFA4CEF2A8
C1E59BBFE197CBEDA3D2F2A9CFEAA3CDE49ECADF9ABBCC888A9654B0BB79E0E9A87B8443
96A260C5D692D9EEA9C7E19AD4EFA8C5E099D3EEA7CEE59FD3E7A2E4F5B1CFDE9BD0DF9C
3C500BD2E7A2D5EFA8CAEA9FC2E79AC4E99BC9EB9EC9EB9ECAE99DC9E89CCAE69BCBE59B
C9E197D9F1A7BAD087A0B66D8DA55BCCE49AD0E89EC6DD95CBE59EC1DA96D0E7A1D4E9A4
C5D992798A44AEBF79CEDD98DFECA78D9C57A5B672C9D998D1E4A2D5EAA9CFE5A5CFE3AE
E0F1D1F1FFE7F5FFE2E0F6C7CDE6ACC9E7A1CBEA9EC9EA9B
CEF0A4BCE194C4E89ECFF3ABC8E9A4CAE8A2D2ECA5CDE19CE1F0ADCDD999505B21D4E5B1
C5DAB1CAE5C6DCFEE6A0CFBD31756A569695B2D8E3EDFFFFE5F7FBF4FFF7FCFFEDDAD9BD
BAAE98FFF5E7A88486310A0D1F0000B4A689DEF2B5C4E69ACCE7A0C8E19DCDE6A4DAF2B4
E1F8C0E0F6C7E4F8D3ECFFE3F7FFF3F8FFF6F6FEEFDEE5D3E8ECD1A5A986D1D4A9D4DEA9
CBE5A6C9EAA5C8E7A3C3E19BC7E19AD1E8A0D3E9A1D0E49CD2E39C98A9628FA35C697F37
738A44B2CC85A3BE7992A965A2B271778343E2EEAEE5F4B393A460E1F5B0C1D590CFE59D
C2D991738D449EBA70CBE79DCFEEA2CCECA0CBEB9FD7F3A8ECFDB6CBD893BAC4875A632A
4D5421B4BB88D8DFACD6DFA8D8E2A5EEFDBABDD18AD8F0A6C0DC92D2F2A9C9EDA5C6E59F
88A15DD2E7A2CADE99CEE29DD1E5A0D5E9A4DEF2ADACC07B8EA25DAEC27DB2C782617631
CDE29DD4EBA5E2F9B3CCE69FC9E29ECCE7A2CAE5A09EBC74B0CE84C2E296C7E899C9EA9B
C9E89AD4F0A3CBE59BD5EDA3CAE098D1E59ED2E39F718842A8CC82B9E397CDF6AAB8E195
CEF4A9C2E69CCEF0A6C4E49BC0DB94DCF6AFD8EFA9BED28DDCEDA9E2F1AEC3CF8DE0ECAA
97A361859451DAEBA7C6DB96D2E9A3CDE49ED7EEA8D0E5A0CBDF9AD8E9A5C8D99597A864
314500BFD48FCDE7A0C5E399C6E89CC4E99BC6E89BC7E99CCAE99DCAE99DCCE89DCBE79C
C6E096D2ECA2E3FBB1CDE59B677D34A6BC73D7EDA4D8EFA7D9F3ACC9E39CCDE7A0CEE59F
D3EAA27F954D9CAD67DCEBA6DCE7A2B6C17C95A25DC3D28DD4E59FD3E9A1D2ECA5C9E3A6
CFE4BBE8FCD9F3FFDFE1F7C8CCE5ABC7E4A2CAE8A0C9E99E
C7EBA1C4E89EC0E69DC6EBA5CCF0AAC8E7A3C9E29ED7EBA6CFDC97DEE9A799A166B9C38F
CBDAAFD7EBC8CDE5CBE4FFFB4C938F2E747CA7D1E7EDFFFFF5FFFFFBFFFFF7FEEEF1F1D9
B5A993FFF9ECB98F904B1E211900008F8164C8DDA2C9EAA3D1ECA9CCE2A4CFE7ABE4FBC5
F4FFDBF5FFE3F4FFECF5FFF4F1FCF4F7FFFDFBFFFDFEFFF8FEFFF0AEB196D4D4B0D5DEAF
CDE7A8C4E8A0C9E8A2CFEDA5D2ECA3CFE59CCEE29AD2E39CCFDF9851621B9CAD67D4EAA2
C4DB95D3EEA7A2BD786E8743495918677333909C5C97A665A9BA76C9DD98D5E9A2D1E79F
D5EDA33F590F8EAA5FD6F2A5CAE99BC6E796CDEE9FC2E193C9DF96D4E39ED4E0A297A067
262E007B824FB1B583DAE1ABD3DDA0C9D593E0F4ADC8E096C9E59BD1F1A8B9DD95CDEEA7
B2CB8791A661C8DC97D5E9A4D4E8A3CBDF9AD1E5A0CFE39E8CA05B748843C9DE9992A762
DBF0ABC4D994CBE09BCDE4A0CEE7A5D4EFACC3DE9B7E9C5688A65EB2D287C7E79BC8E799
CBE79ACFEB9EC9E197D9EFA6CBDF98CFE09ADBEAA7869B56CEF0A6BFE89CC5EEA2C6ECA1
C9EDA3C8ECA2C3E59BCEEEA5D6F4ACBED992C5DF98D9F3ACCFE49FD0E5A0DDF1ACC5D994
D0DF9C5C6B28D7E6A3D1E29ED7EBA6D0E49FCCE09BCFE39ED0E49FCEE29DD5E9A496AA65
102500DFF4AFC1D892D8F2A9CDEDA2C9EB9EC6E89BC7E79BC8E89CCAE99DCCE89DCAE69B
D1EBA1CBE59BCDE59BC8E0966F853C95AB62CFE59CC9DF96CFE6A0D6F0A9C5DF98CEE8A1
CFE9A0B9D0888EA25BCDDC97CED893E7EEAA939D58CCD792D5E69FCBE198CFEBA0C7E4A1
C4DCACE3F8CFF3FFDBE3F9C8CCE5AEC8E2A5CAE7A5CAE7A4
C1E29BCAEEA6C4E9A3CAEFAAB8DB97D4F3B0C4DD99D2E6A1C9D691DDE6A5E1E7AB666D39
E5EEC3DAE5C3E6F6DBE3FFF4CBFFFF246C788EBCD4EAFFFFF7FEFFFCFEFFF5FBF1FFFFED
E1D6C2FFE5D8D8AAAC75474934130A554C2FD0E5ACC9EAA5D3EDACCFE5A7CEE6AAD9F0BA
DEF4C5DCF1CAE2F4DAECFDEBF3FEF6F9FFFFFAFFFCF0F3EAFFFFF1C5C8ADA7A783D7E0B1
CFE9AAC2E69ECFEEA8CDEBA3C7E198CEE49BD1E59DD4E69CAFBF76D3E49DD7E8A2CAE098
C6DD97D9F4ADC6E19CD1EAA8CCDF9FD5E3A5D5E4A3C6D594D1E29EE4F8B3B7CB84DFF5AD
DAF2A89CB66CABC77AE0FDADBBDA8AC6E894CCED9CC7E696BED489DFF0AADCEAACCCD79D
4F57246A723F5A612E5C632D99A366D4E09ED1E29CD8EEA5D0EAA1CBE9A1C1E29BCFEEA8
C8DF9B95A964849954BDD28DCADF9AD9EEA9CEE39ED3E8A3D6EBA6C4D9948A9E599BAF6A
D1E5A0CDE19CC7DB96D3E8A5D3E9A9C3DD9CDBF6B3C2E09AC6E49C8DAB61C0DF93AECD81
C8E497D1EDA0CBE399C6DC93CDE19A94A55F859451B9CD88C8E69EC6E89ECBEDA3C5E59C
CCECA3CEEEA5BDDD94C7E59DD0EEA6C8E69EC8E69EC4E29AC7E59DCFEDA5C9E79FCBE59E
CFE39ED7E6A372813E707F3CDBEAA7CBDA97D6E7A3D0E19DC8DC97DDF2ADD4E9A4809550
465B16D5EAA5CEE29DCBE29ACAE89EC9E99DC9E99DC9E99DC9E99DC9E99DCAE99DCAE99D
CFEBA0C5DF95CCE49ACFE79DBAD087B3C980CFE39BD2E89FCFE6A0CBE59ED3EEA7C7E59D
BCDA92D7F2ABD8EEA6A6B570E0E7A4B3B876BBC07DCDD792CFDF96E2F8ADBBDA8CCDEDA4
CBE6AFDBF3C3F5FFDCE8FECDBFD6A2D2E9B3DEF7BDC2DC9F
C8E7A3C8E9A4BFE29EC8EBA994B7775270306A83429EB16FD9E5A3DDE3A5DADDA44A4C1A
63683F5E6442717B60799684C4FFFF4C929C76A8BFD8F5FFE3ECFFFCFDFFFCFFFDFDFFEF
FFF8E6C0A699CA9C9E66383A260B005A5738D0E3ACCBEAA6CEE7A3C7E09CC7E09ECFE7A9
D3EAB2D0E6B7D4E8C3DDF0D4F7FFF3F8FFF6FBFFF4F7FEECFFFFE8BBBF9CACAF84E0EAB5
D2EDAAC8EAA0CDEDA4CAE89EC8E298CFE79BD2E89DD1E69B9FB167CEE096D1E59ED5EBA3
CDE49ED1EAA6C5E09DD0E9A7D7EAAAD7E7A8D6E6A5D3E3A2D2E39FD4E8A3CAE098CFE59D
C4DC92DBF3A9A9C477B5D282DAF7A7CEEE9BC2E28FDAF7A7D9EFA4D1E59ECEDE9FD6E4A9
78824EB8C28E89915E4750195B67299CAB68DEEFA9B9CF86D1E8A0DDF7B0BBD993D6F1AC
DDF2AFBED28D94A96497AC67CCE19CCEE39EDEF3AEC4D994C4D994DEF3AED0E49FD0E49F
CADE99DDEEAAE0F1ADD0E3A1CCE0A1CBE3A5CBE4A3C4DF9CD5F0ABCFEDA5CDEBA187A65A
97B368CFEB9ECCE49AD5EBA2A7BB74D4E59FC9D895D3E7A2CEE8A1CCE7A0CFEAA3C6E19A
CDE8A1D4EFA8CBE69FD9F4ADC0DB94CEECA4CCECA3D3F3AAC6E89EBDE197D5F9AFCFEFA6
D0E7A1C6DA95A5B672768542BBC785C3CF8DDEEAA8D1E29ED7EBA6C4DB95C3DA949AB16B
506520DBEFAAD2E39FDDF1AACCE89EC9E99DC9E99DC9E99DC9E99DC9E99DCAE99DCAE99D
CEEA9FCCE89DD5EFA5D4ECA2A3B970A5BB72CADE96DAEEA6D3E9A1C9E39CCEECA4CEEEA5
C8E89FD2F0A8BED58F84934ECFD492A1A161838343C5CA87D0DD95C8DF91C9EA99C7E99D
C8E4A9DBF3BFDEF4C3DCF2C3E3F9CAD2E5B7C1D5A4DAEEBB
688241C6E3A1CDEBADCCECAD4160247D9B5F8CA468253700000B00E7EDB1DCDCA6373606
484921828665000400000900D0FFFD2F70725F94A4E3FFFFF4FFFFFCFDFFF9FDFEFCFCF0
FFFEEDA0887CEDC1C27B5353160400505334CEDFABC8E39ED0EAA0C8E595C8E595CDE99C
CEEAA0CAE5A2CCE5ACD4EABBE2F4CCE3F3CFECF7D5E9F3CEF0F7CBC5CC98BEC488C6D290
CEE8A1CDEBA1CBE99FC9E59ACAE49ACEE99CD2EA9ECDE5978BA156C9DF94C9DF97DAF1A9
D2E9A3CEE5A1CFE8A6D5EBAACADD9DC8DB9BCADD9BDBEEACD0E49FCDE29DD9EFA7C4DA92
C6DE94D7EFA5DBF3A76B8639D2EDA0CFEC9CBFDC8CBCD788D3E99ECCE099D5E8A8CEDDA2
5C6A35D0DDA8DFECB7CBD8A0D9E7A95A6B2753641E5D7129C6DA93D5EAA5C9DE9BD1E6A3
CBDE9CDDF1ACCADF9A8EA35EA3BA74BAD18BD4EBA5D7EEA8D1E8A2E1F6B1C5D994C6DA95
E7F8B4B9CA86DEEDAADEEEADE4F6BAE6FCBED1E7A9CEE7A6BCD591CCE7A0D2EEA4BFDB90
ADC97E87A358B5CD83DAF0A7859952C1D58EF9FFC4C6DA93D7ECA7D1E8A2D1E6A1C5DA95
C9DE99CEE39EC2D993CEE59FDAF4ADB2CD86CCEAA2D0F2A8C4E89EC6ECA1B4DD91C5E99F
CBE9A1DDF4AECADE99CFDE9BA3AF6DACB876D1DD9BD7E6A3CCE19CDDF4AEC4DE97CBE59E
3F5610C9DD98D5E4A1C2D38DCDE79ECAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
C4E397C4E095CFE99FD2EAA090A65DA5BB72C3D78FCEE29AD9EFA6C9E39AC8E69CC7E99D
C1E59BCCECA3C7DE98A7B37177793AAAA969B4B071E6E7A5E4F0A8CCE297C3E694C7EC9F
C5E2A2D1E8B0CDE1B0E3F6C9F7FFE1E7F7D2C7D7B2D9E9C2
687E40CBE3A5C8E1A7CBE7AD4F6C34C1DDA3CBE2AA6C7E44071200949961CFCF9B1A1700
85835D8788692F311B000700C3EFE000332C3A7478D7FFFFF1FFFFF6F9FFFAFEFFFFFFF8
FFFAEEC0AA9FFFD7D89472710700003F4927DFEDBAD0E5A4D3EE9FCDEB95CCEA94CDEE97
CFEC98CBE898CCE7A0D1EBAACBE2AAD2E6B3D7E7B6CCDAA5DEE9B1DCE6A7CED8938C9951
BED48BCEEA9FCDE99ECAE699CCE79ACBE79AD0ED9DCAE79789A457D3EEA1C7E198D6EDA5
CFE6A2CEE3A0D5EAA9C6DB9AD8EDACD6EBAAC8DD9AD6EDA9C6DB96D8EDA8D4E9A4D4EAA2
D1E8A0D9F1A7CAE298BFD78D4860167D9549E8FFB4D7EFA3D1E59DCFE39CD7EAAACFE1A5
667741CFE0AAC7D8A2E0F2B8D2E5A5DCF0ABD1E29C53641D1F2E005F6E2BE3F2B1CCDB9A
D1E1A0D3E7A2CBE09B93A86389A05ADAF1ABC9E09AD1E8A2C9E09ACBE29CDEF3AEC7DB96
D3E4A06877342D3900FCFFCAFBFFCFDFF3B8C2D69BDCF2B2D6ECABCFE8A4C9E39CD5F1A7
CAE69BC0DC91859F55C6DE9499AF67D8ECA5BBCF88E0F4ADCADF9AC9DE99D1E6A1D3E7A2
E2F6B1E7FBB6D2E6A1D5EAA5D0E7A1DEF8B1C9E49DCDEBA3C5E79DCBEFA5E4FFBFABCF85
C4E49BCDE8A1DAEFAAD9EAA6CBD7954C5715CDD997D2E39FD3E8A3CCE69FC9E49DCAE59E
D5ECA6889955DAE6A4E7F6B1CDE79ECAE99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99D
D0EFA3C7E69ACEEA9FDCF4AAA4BA71D1E59DD9EAA3CEE29AD4EAA1C9E399C8E89DC3E89B
B9DF94C4E59ED6EFABDDE9A957571B5D571B8E884CBFBE7EC5CF8AE0F6ABCCEF9FC7EE9F
D4F1AEDFF7BDEFFFD2F8FFDFF8FFE6F9FFEAF8FFE9E0EACF
5B6A31DFF0B9CFE3AE566E3A334E1B67824D677E4A61723C68723DABAF7CD2D1A1070400
7B78557271554F4E3A000600CAECD4699A852B675FAEDFE3E5FAFFF9FFFFFCFFFFFFFDF8
FFFCF3EDD9D0DDBBBC9D8581000400273816F3FFCFECFABDCEE99CC9E994C8E992C9EC92
CAEB92C9EA93C9E898CDE99FD0E9A7D3E9ABD1E5AAC5D79BD5E3A5DEEAA8D3DF97738136
A4B870CEE69CD1E99FCEE99CCDE99CC5E494CCED9CC7EA9887A859D9F8AACBE79DCFE9A0
CEE3A0D3E6A4CDDD9EA4B47582995589A25E78914D8BA46091A864CFE6A0AEC57FE1F8B2
D5EAA5CFE59DBED48CD4EAA293A961A1B76E61772EA7BB73B3C77FCADE97D2E5A5D1E5A8
6E834B9BB27A5C733BBDD599BED493D3E8A3D4E8A1B0C079747F3B707938B9BF81DBE4A5
D7E6A5D2E6A1C8DD98B1C68190A761C2DC95D0EAA3CBE59ECCE69FD8EFA9C5DA95E2F6B1
899A56B6C582C5D18F5E6A2CBAC78FD6E5AEE8FAC0CFE3A6CFE5A5D0E9A5D0EAA3C4DE95
CFEBA0D3EFA4B5CF8592AA60BFD78DCFE59CD2E8A0D2E8A0D5ECA6CFE6A0D1E8A2CCE19C
CFE39EBCD08B889C57758944647833728742C3DA94D0EAA3C0DB94C7E59DC1DF97DDFDB4
C6EAA0C6E89EC4DE97D0E49FDAE6A4576220BDC987D9EAA6DBF2ACB4CF88DDFBB3CFEAA3
CDE49E98A965E6EFAEBBC883CFE69ECAE99DCAE99DC9E99DC9E99DC8EA9DC8EA9DC8EA9D
D1F1A5C8E79BC9E59ACDE59BA4BA71E1F5ADDEEFA8D0E19ACAE095C7E398CBEDA1CBF1A4
C1EA9EC0E49CCCE5A3D9E5A7DFDEA5837A43968B53E6E2A5CED796D0E69EC9EEA0B8DE91
CEECA6E7FCC1F3FFD5F8FFE3E9F6DCF1FAE7FCFFF3E7EEDE
707A45D2DFAAC5D5A46C804F2A4212576F3F5367366E7E4D3842108E9162F1F0C4B8B48E
95927356543D252314000500B9D2B4E6FFEF0845339AD1CCE6FEFFF8FFFFF9FAFEFFFDF8
FFFCF4FFEDE6DFC3C2C6B7B2061500071F00E6EFC2FDFFCDCDE49EC7E79BC8E998C9EB97
C9EB95C9EB95CBEA9ACBEA9ECEE9A4CBE4A3CFE5A7D4E8ABD7E7A9CCDB9AD5E29D8E9B55
93A35CCFE39BD1E79CCFEA9DCEED9DC1E291CAF09DC4EB987CA151C9EC9CC6E49ACCE69D
D2E7A4DEEEADC4D09293A163CEE5A1D7F2ADC7E29DC8E19DBFD894DDF6B290A761BAD18B
C5DA95D4E9A4D1E6A1DFF3AECFE39EB6CA83DBECA8D3E49E94A55ECADB95D7ECABCEE4A6
566F365470360C2900D7F3B6D3EEABD6F0A9D0E49DD5E59EDAE19EBBBD7E5B591E929357
D3DF9FE3F7B2D2E7A2CDE49EAEC881849E57D4EEA7D0EAA3D5EFA8C4DB95D1E6A1D8E9A5
9EAD6A96A260EBF6B4C5CF92FCFFCFA8B57F8B9A638D9F63D0E4A5C7DD9CC7E09CD6F0A7
CAE69CC0DC91C6E096C7E1979BB369CDE59BE4FAB2BDD48CC9E49DC6E19ACFE9A2D3EAA4
DDF2ADCEE29D9AAB67849551D8E7A4AFBE7B7E8F4BAEC27DDDF2ADD4E9A4D4EBA5BCD790
CBF1A6D0F6ABBCDA92E6FBB6CFDE9BC5D18F9AA966BED28DC6E099DBF9B1B7D78ED0EEA6
D1E8A2B5C481515717E2EDA9CFE69ECAE99DCAE99DC9E99DC9E99DC8EA9DC8EA9DC8EA9D
C6E69AC5E498C3DF94A9C1778DA35ACDE199D0E099D1E29BD1E79CCAE699C5E79AC5EEA0
C8F2A6C8EDA7C8E2A1CFDA9EDCD9A2C3B783756833C1BB81EAF0B2C9DE99C5EB9ECAF3A5
C1DF99D6EBB0CADBAEECFAD9FBFFF1FCFFF8FEFFFAECEFE8
686F3CD5DDACDAE7B9BECFA2304618CDE3B5E3F6C992A275313A0BBBBE91D5D3AC898562
DDD9BEA9A7924745380004009AAC86D1F6CD0032168FC9BBEBFFFFF7FFFFF3F4F8FFFEFB
FFF4EFE9D6D0FFEBEADCD3CC071F07031E00CFD6ACF0F4C1CEE3AAC9E7A7CAE9A5C9EBA1
C9EB9FCAEC9FCBEBA0CBE9A3C3E09ED0E9AFDDF2BAE9FBC7E5F3BECBD8A2D9E4AA9DA96B
919E59D6E69DD0E59ACCE79AD0EF9FC1E492CAF29CC0EA968BB261C0E595C6E69BCDE79E
D2E5A3DDE9A9B6BE8297A365CAE39FCCEAA4CEECA6CEE9A4CAE5A0C5DE9A95AC6896AD69
AABF7CDFF4B1CDE09ECFDF9EC2D291E5F6B28E9D5C8A9956B7C681D2E39DD3E8A7D4ECAE
668248557238001000BCDC9DC5E4A0CBE69FC6DC94D2DF99E2E7A5DEDC9F797339949257
CEDA9AD7EBA6C5DA95C9E09AD3EDA693AD66A8C37CC2DD96CEE8A1D6EDA7D3E8A3C6D793
A8B774525E1CD0DB99E3EDB0E6EFB8DBE5B0BECB9568773C8C9E60BBD08FD2E9A5C9E39A
CDE99FD0ECA1DBF7ACC0DC91DAF4AABED88ECEE59DD4EEA5CBEBA2C6E89ECAEAA1C9E49D
D1E8A2C6DB969FB06C94A360D7E3A1DAE5A3B5C07E747F3D8D9957CFDB99D5E4A1DAF1AB
C4EA9FB8E195D1F1A8CBE29CDBEAA7DAE6A4ABBA779DB16CAAC57EBEDE95D4F4ABBBD991
D5ECA6D0DF9C9DA363B8C17ED0E69ECCE89DCAE99DC9E99DC9E99DC8EA9DC8EA9DC8EA9D
CBEB9FD2F1A5CEEA9F9AB26895AB62D1E59DD2E29BDCEDA6D5EA9FD0EB9EC3E598BCE597
C4EEA2CBF0AACFE9A8DAE5ABDCD9A4E9DDA96757248C834CE6ECAED6EBA6BBE196C3ECA0
CBE9A3D1E6ABC6D7AAECF9DBF8FEF0ECEEE9FFFFFFFEFEFE
0F1D004C5B227E8F59CADEA938501C4A622E526A36071E00465922CFDDA8DDE7B59CA377
31330E11120046462CA0A585D7E9B9C2E6B6427D5D93CDBFE7FFFFF4FFFFF9FEFAFEF7ED
FFFAEFC0ADA6FFF0F0BAB5B100100021381BD2D7AED9DDAACBE0A8C6E5AAC7E7A8C6E6A3
C6E7A2C8E7A3C8E7A4C7E3A6CAE3AAEAFFCEF5FFDAF8FFDAF2FFD1D8E6B1D7E6AB879557
93A05BDAEAA3CCE299C9E497D1F0A2C3E694CDF3A0C1E794B7DA8AD1F1A5D3EFA5D2E7A2
CDDD9CCDD99B9EA86C94A265D5F0ADC2E19BC7E4A1C4E29CD1ECA9C8E19DE0F6B5C9E09C
7A8F4ECCE19ECCDF9FD8E8A7D2E0A2B5C1818D995BB6C282D5E4A3D1E6A5C7DFA1CBE4AB
637A46637746000F00D8E9B3D1E3A9DEECAED5DE9FE5E7A8D8D298F1E8AFD3CC96898850
9EAD6CBED58FDAF1ABD2ECA5C9E39CA5BF78647E37DAF4ADCAE49DD7EEA8CADF9AD8ECA7
DFF0ACCFDE9B768240D0DF9ED6E8AAC5D99CD9EDAED2E6A7D3E7A8A0B574849B57A9C07C
D1EBA4CDE79ECAE69CC9E89CC5E498CBEA9CCCECA0CAEA9ECAECA0C6E89CCAEA9FC5E399
D0ECA2D1EBA2BED48CC2D68FD0E19BDCEBA6CAD994D7E6A1E4F3AEAAB97472813C6E843C
C7E99DC7EC9FC2E096D6EDA7C6DA95D8E8A7D8E8A9C3D897C5E09D83A05DA5C27FD5EEAC
D0E3A1C9D595E7EBAE4D5615CFE69EC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DCAE99D
C9E89CD0ECA1CAE49A8BA55B9FB76DD8EEA5CCE299D1E79CC4DC90D1EE9ECEF1A1C4EB9C
C4EA9DC5E79DCAE09FD8E3A79D9A658D8350928453D1CA94D6DC9ECBE09BC1E699CFF5A8
CBE9A3CADFA4D7E9B9D3E1BE757E69767C70EFF4EDFEFFFB
D1EFA588A65C83A35AC4E49BD1F2AB82A65E395F16C5EBA2C1E9A2C7ECA6C8E8A5CAE4A5
D9EBB1CFD9A49D9F6ED7E0ABC9E6A4BCE7AF77AD937FB4AEC4ECF4E7FFFFFBFFF6FEF9E3
FFFDE6AF9E8EFFFBFBDDD7DB000602000500CDCEA4D9DEA6D4ECAEC3E3A2C9E9A8CEEEAB
CFEDADC8E4A7CCE5ACE1F9C7F5FFDDECFFD6F7FFDDC6DAA9D8EBB4C8DC9DCFE49F8EA45B
8CA059C3D893D1E8A0CEEAA0CFEDA3C6E69ACAE99DCCE89DD0E69DDAEEA7DAE9A6C9D897
DBE9ABD4E2A5859557D0E6A6C8E7A4CBECA7BDDC99CFEAA7D2EBAAD4EAA9C2D898D5EAA9
D3E9A94156158A9E5FDCEFAFCDD89C97A164E0E5ABCFD79CD3E2A9CFE8AFCBECB5C4E0B0
67764F2F2F0D0D0000655232685A334E4115766436AE9869E8CDA0E9D7A9827E4FA7B17C
546A29BAD590DAF5B0C8E39ED3ECA8CAE39F90A965BED591CBE29ED5ECA8D1E8A4CDE29F
D5EAA7D4E9A6778A48CBE59ECFF4A7C0E798C2E79AC4E49BCBE6A1ECFFC1E6FABBACC081
899E5DD9F0ACBCD790CCECA1C8ED9DBEEA95C9F79FBEEA93C7EA98CAE99BCAE99BD0EFA1
C8E99ACEEFA0BFE091D2F3A4C9EA9BC7E698C8E799CDE99CCEEA9DCBE79ACCE89BCFEB9E
4D6A1AD3EFA2D1EBA1B2C981DDF4B0CFE5A5CDE2A7D2E7AEF5FFD495AA7293A66ED2E1A8
D4DFA5D6DEA3D4D79EA2AC6DC6E49ABFE697CFF4A6C7E99CC9E89CD3EFA4D0EAA0C7DF95
CCE49ACFE79DD0EAA086A056CDE99ECAE99DC8E89CCAEB9CC8E99AC5E695D4F6A2CBED99
B8D988C9E497D9EAA4D9E2A35C5B25A19B699D9765D4D39BD9E3A4D0E69DD1F19EC5E896
BCD996D2EAAEDBF2BC879D6E000A00D9EAC8F7FFEAF7FFEC
C1DD90D2EEA1E0FBAEC1DD90C4E095CEEDA1CCEEA2CDF2A5CBF4A6BBE498C7EBA1CDE8A1
CCDC9BE1E7A9757036BABE81CDEBA3B9E5AA91C2AC629292DDFFFFEBFFFFEFF7E8FFFFE4
FFF1D5A99783FFFAFAFFFBFF211F24030100BCB791DDE0A9CBE1A3CAE9A6C8E5A3D6F3B1
BCD697D0E8AED5E9B6DDF0C2F8FFE1F8FFE1F2FFD9C6D7AAD6E9B1CBE09FD5EBA0B0C67B
A1B570D0E3A1D1E8A2C9E39CCDE99FC9E59BD0E89ED2E69ED0DD98525B18CAD092D7DFA3
E2ECB0CFDDA293A569D8EEB0D3F2AFC9E9A6CDECA9C7E4A2CAE4A3C9E2A1D6ECACD4EAAA
D5E9AAB7CB8CB0C284D5E5A7586327AFB77CDEE3A9D7DFA6D7E4AECDE1AEC4E2B0C6E1B6
606A483C35191500007E60489C8867A5926A8F764E77572EA7855F977E55292500454F1B
8DA363C5E39DC5E09BCDE6A2C9E09CCDE4A0D3E8A59DB26FD5EAA7CFE4A1CBE09DD5EAA7
D0E5A2C2D79499AE6BCFEAA3C3EA9BC0EB99D0F7A8CFEFA4C6E19CE4F9B8F6FFCAE0EFB4
B1C183D2E4A6DBF2AEC9E79FC6EB9DBDE896BFF097C8F49DC2E191DCF7AAC4DF92CDE99C
CFEEA096B7688FB262B9DE8EC8ED9DC5EA9AC7EA9AC9EC9CC9EA9BC6E798C6E597CBE898
859C4E889F51CAE095EDFFBCD2E8A7C1D799D4E9B1CEE2ADF1FFD1E0F1BDB8C492AAB480
D9E0ACF2F7BF9A9A64AAB477D1EFA7C9EFA2D1F3A7C5E59AC1DD93CEE59DCFE59DDCF0A9
DEEFA9CCE099C5DB938DA75ED9F5ABCAEA9FC3E599CAEFA2C6EB9DB9DC8CBFE290CCEE9A
D4F1A1D9F1A5D6E5A0D4DCA0646430BFBD8CB6B483D3D69FDEEAACD2E89FB6D683D7F8A7
D4EFACC6DEA2C6DEA4536A346F8554E6FCCEEAFFD6DCF1CA
DBE4A3E0E9A8CFD595D9DF9FEFF5B5D1DC9ACAD996CCDD99CDE29DC6DB98E2F2B1D2DC9D
D9D99DE5DCA3705C279D945BC6DB98C7ECB682AD998BB4B6D9FDFFE5FCFFF3F6EBFFFEE8
FFFBE3917A6AFFFAFDFDF1FB060004110A02F0E6C3FFFFD1D3E0A8D2E8AAC9DD9EDEF2B3
F8FFCFDEEFB8D1E2AEF2FFD1E1ECC4F1FCD4DAE5BDD2DEB0D9E6B0D0DEA0DBECA5D0E097
BCC886E2EEAED6E7A3C7DC97CBE29ACBE29AD3E79FD7E7A0DBE4A14B500EEAEBAFEBECB2
D6D9A0CED69DA0AB73BED096CAE2A4C4E19FD1EEACD0EDABC0DF9CC6E3A1D1EBAAC5DB9B
C2D697CFDFA199A76AD7E2A64A5519D2DDA1D0DB9FDAE3AAD8DCA9D8E0AFBCD2A1E2F7CC
050C00211D000E00009D8C6ED2CAA3EAE3B5F1E3B6AC96677C5B3262451B675C2F919562
C9D99BD6EDA9CDE29FDAEFACD2E5A3CFE2A0D9E9A87F8F4E415110DAEAA9D1E1A0CDDD9C
C5D594D5E5A49BAB6ACCE19ECDE8A1C4E29ACDE8A1D0E7A3C7DA9AD8E6A9E7F2B8DAE3AA
939C638C975BCDDD9EC3D895CEE8A1CAE89EBCDE91C9E99DD4EBA3C8DC95D6EAA3D3E9A1
CAE49B819D53D0EEA4D0EEA4CAEA9FC7E79CC9E79DCDEBA1CDEBA1CBE99FCEEAA0D2ECA2
D1E69995A75BC8DA90CCE099C5D898CBDFA2D9ECB4D1E2ACFAFFD5F0FCCAC9D3A1ADB481
D3D5A3CFCF995F5E28E3EBAFCDE6A4C1E29BBEDC96D4EDA9E1F6B3C1D4929CAC6B899857
D2DE9ED0DF9ED9E9A895AA67BCD38FC7E29DD8F6B0BEDF98CDF1A7CEF3A6C7EC9EC5EA9C
CAEA9EC8E49ACADD9DD5E0A6656736262500919062C5C996C8D69BD6EDA7CEEFA0CBEB9F
D0E9A7C8DDA2D9EEB5041900D5E9B6DCEFC1F7FFDFE4F6CE
D1CA94D5CE98BAB07BCFC891DBD49DCAC88FB4B57BBCC286A4AC70AFB77BD6DCA0ACAC70
D4CB92BFAE78785C2A83723ECBD69AB1CE9E4C71600F35387F9FACD0E2ECFDFDF5EADBC8
E7CEBA795F52FEE9EEC1B1BC0800050A000098896CDDD5A7CDD19FE4F1BBD6E1A9DAE5AB
FEFFD1E7F1BCC7D19FDAE3B6F2F9D0EBF1CBC0C6A0CBD2A6C4CC99BAC488B9C681A1AC67
9DA365C2CA8EB9C384A9B875AABB75A9BA74B2C27BB8C37EB2B775565616969459A6A46B
A9A872AEB17C616834697640607437647D3C5D77366E8B495877346685425976345F7837
6D7F417A884B404B0F374206000A006F7D407383455C672D403A08262200000900000900
0007000F0E001C1300C5BF9BB9BF918F9662999661A89B67BDA172BDA074DFD1A4DED8A6
E0DFA6DDDDA1E2E2A6DCDCA0E5E3A8E0DEA3CDC88EB4AF75615C22E6E1A7E0DBA1E0DBA1
FBF6BCD1CC92827C42CEC98FE5E4ABDBDCA2E3E2AAEAE7B0E2DDA6DFD8A2E0D6A1D4CA95
B6AA789C925DE0D9A3ECE7AFE7E6ADE4E5ABD1D598DCDDA1DFDDA2E0DBA1C8C389F2F0B5
939458B6BA7DDFE5A7D3DC9DD9E2A3D4DE9FD5DE9FD7E0A1D6DFA0D3DC9DD4DA9CD8DD9D
E4E3A0C5C57FD3D28FDBDA9ADEDDA4EAE9B3D6D4A3DCDAAAE6E2B3F8F1C3FFFFD4C1B487
7362346856265C4816E5D8A4D7DAA1DEE8ACD0D59BE2E5ACD7D69E817C45948D579D9660
9A905BE7E0AAE5E0A9A09F67E7E8AFD8DDA3C9D196DBE9ABC3D897D9F2AECCE69FC3DA94
CEE39ED3E3A2DBE3AAE2E2B0D8CFA68B7D58827650B1AA7ED9D9A5D9E3A6CDE19AD4E59F
D8E0A4DADAA4D4D4A0282800DEDDADD2D1A5E2E0B9DEDCB5
7F714496885BA291657E6D3F8C7E4F9D9362A39D69AAA973AAAD74979C62BABD84908E55
C0B57FB39F6C664A1A85713F8D945EBFD6ACBBD9CD2E4C54233F4DDDEEF8CECAC7F2E0D2
EED2C48C7065F4DDE5EFDDE931212C0B0000857159F5E5C1ECE9C07D8053515523A6AA78
C6CA97EFF3C1C0C396A8AA82F4F8D3D3D7B2A7AB86A7AC83A6AC7CA3AB72A6AF70888E4E
74753BA3A46BA2A66B959E5F939F5D8F9C5798A35E9FA660A3A462514D0E807A40A59E68
A6A06E7472421F21006B734066783E697F3F556F2E5A773562813E5E7D3A54712F6D8645
6A7C3E53612469743889945893A3657A8C4E879B5CA0AB6F837544403203787B4C8E996E
565A3564664163613B94976C8A9D6691A56A959F63A39E66B8A2707B6333776938958554
6E4E1D734B1A694110673F0E6D451478501F8258287F5525794F1F6B41116F43144E2200
8F6334805425805123B084576F421B7448238558318C5F387D502770431A73461D7A4D23
7C4C246A3D1486562E976A416B3E176B3F187D512A92663F8959318C5C34895C336A3F15
744A20764F24815F328160338D6E4088693B8465378364367E5F31765729745326765424
AA8550694209764F189F7A46D0AA7BB38C61C9A27BDFB793CDA280B08362F9CBAAFFD3B2
E1AF8CBE8A65B8825CC19068D2AD83D7B88CB49368D7B288D1AA8171451EB68962C1916B
E0B08ABD9069A1754E987148D5B086C09F74B99A6EAE9869BAB37FBDBC84A2A168ADAB70
C7C288C0B780B8A678AB926AE0BD9FC9A489280300634223745B337F6F3EA89F669F9359
B296669775486B491C89663CB28F67D3AF8BA07C5AB5916F
C4B68FE8DAB3DFD0A991845AEEE2B8E4DCAED6D4A3EDEFBDF5FCC6D6DFA6E4EDB4D0D59B
DCD9A2F2E7B17D6936B7A978DEE1B2C1D2B0E3FDF495B2B8455F6EDAE8F5FFFEFDFFFAF3
FFF2E7EED1CBFAE3EBFFF4FF41313B0D00008B7462FFFCE1FFFFE1D0CDAABCBA93B6B48B
ECEDC1CFD0A4AFB086FFFFDDF2F3D1F1F5D4EEEFCDC3C7A2DCDFB4D2D6A4E1E6AEE8EBB2
A7A471DCD9A6E1E1ABD9DFA3D6E19FCEDB96D7E19CDCE39DD6D795686425C8C288E2DBA5
DCD6A69390633C3A119EA677CCE0A5CBE4A3D2EBAAC5DE9DDEF7B6C9DF9FCBE1A1D2E6A7
D6EAABDAECAEDEF0B2C4D698CCE0A1CADE9FD8ECADDAE2A7A2925F7563338D8C5CD3DBAC
76774FCDCBA5A19D77DAE0B2C9E1A7CCE6A5CFE2A0D9DE9EE0D39CC1B07CB4AA75B3A872
AB8F5DBD99678D6937B4905E96724095713FC49E6D926C3B76501FA6804FC19968B48C5B
AE8454B98F5F8C6232AE8356B48861B38762B68A65BB9169BC9268B48E61B48E5FBB9566
AD8758B79162B88F63C69C728357307B4F2AA17351B48664BB8E67BD9067B38760A57B51
A78057BE9C6FB7966BCCAD7FB3966AAE9364AD9265AE9364AC9164A78C5DA6895DAA8B5C
AB8A54AF8F568D6C369F7E497F5D2D6E4C1E7A572DD9B68E805A3566401BB18965EAC09A
E3B7907E512873441A693E1385643983663A65461A9D7C519D784E724B22966C447C5029
9D714A8B61398A633A8B683E97764B7C5D31886B3F776132948856827D46605B2378733B
877E476E612D756033755733A07B5E83594123000024000093754F69532452430C75642C
6A501D492A00391A0080613373542896774B7A5A31725229
D5D5AFE4E5BDA6A47D6A683FAAAB81D9DCAFD6E0AEA3B17C8CA168D3EBAFCFE7A9D1E7A7
C8D699DBE3A8908F569B99666A704400090000130B000F16304A59495966EAE8E9FFFBF6
EAD1CA785F5B28151B13030E0A0006201011846E61FFF6E1FFFDEA676149B7B295D6D3B2
CFCFA9FFFFDAE8EAC5A9AD8ADDE1C0F0F5D5E4E7CA797E5EDCE0BBD0D5ACD0D6A8FFFFD2
ACA87BDEDAABDFE1AFD8E0A7DAE6A8D4E09ED8E59FDBE59EE5E8A5797939A5A066DAD59E
EFEBBBBCBB8F494A227D8959C9E3A6CDECA8D9F2B0DDF0B0BDC98BD7E1A4E0ECAECEDE9F
CBE1A0C3DE9BBDDA97D8F5B2DAF3B1D8EDACCBD99BDADEA37E713C7B6E3AE4E4B0ECEFC0
646138867E578D845BD8D7A7DAF0B2C7E4A1D5EAA5E0EBA7D5D194E5DFA3E6E7ABD7E0A1
CFD897DEE7A6969F5EDEE7A6B7C2808C975597A2608B96549CA765D6DF9ED0D696F1F7B7
D2D797D6DB9BB6B879EAEBAFE5E5AFDCDFAAD1D49DD2D79DDCE6A7DBE7A5D3E09BCFDF98
CBDB94D7E49FD9E3A4D6DEA2ADB079989864A2A06F939160B9B882D4D39AEAEBB2BFC388
D1D99EC1CB8EE2EDB1D3E3A4D1E3A5CEE1A1CEE2A3D3E8A7D4E8A9D3E8A7D5E7A9DAEAA9
E0F0A9C5D58CDDEDA67E8D48D6E5A2CEDC9EE3EEB2CAD59BD7E0A7D4DDA4DBE3AAD8DDA3
F2F7BDE8ECB1ECF0B5D3D99DCEDA9CDFEDB0D1DFA2E2EDB1929C60D0D89DDDE2A8E7ECB2
D8DDA3ECF1B77A8247505B1FD0DEA1E2F2B4CADC9EE2F2B4D8E3A7DFE9ACCAD696DCE8A8
DEE7A8D6DA9FEEEBB6DED1A5776340381F00856A4C816A48EDDCB1EEE4B1E3E3A5D4DB98
DDECABD1E4A2D8EBA9D3E6A6CBDE9ECCDF9FDFF2B2C1D494
D6DEB9656D46232B045B633A0007006C794DCDDFAF5D763F001300C9EBAEC2E5A5D0F0AF
D3EDACC7DB9CDFEDAF939C67060C00C8D2BAE7FEF8DEFBFF536F7B000814000004FFFCFA
B8A59F0E0000FFFBFFFFF5FD2F252D080000AA968DFFFBEDFFFAEE130B00060100DAD8BF
D7D8B9ECF0CF060C00000600E3EACBD5DBBF8B9177000500CED5B6E5ECCACFD5AFFFFFDD
B1AD87DEDBB2DADDAED2DBA6D7E5A8D3E4A0D5E69FD4E49BD7E19CBCC17F909155EAE9B1
CDCD9B707346050C005E7040C5EAA7CBF0AABAD08FDBE5A866652CD6D199E5E4ABD1DB9E
CDE6A4D5F6B1BFE7A0C9F1AAB9D894D6EBAAD2DA9EDFDFA35D571DA6A169D3D8A0D3D7A4
847B52A5936D5E4B23E3DBACCCDA9DD5EFA8CAE199D0E19AE1E6A3E4E9A7BAC986DCF3AD
CEE8A1D2EDA687A25BD0EEA6C6E49C83A35A527229BDDD94C9E9A0C4E29AD1ECA5BFD992
D9F3ACD4EBA5D4EBA53F5612C9DF9FD3ECABD2EDAACAE9A3C8EA9EC1E698BFE695C9F09D
CCF3A0C2E998CFF1A5C5E39DD4EDACCBE1A3BED19994A66C2D4000D1E4A2C2D794BDD692
D1ECA7D5F3ADBEDF98C7EBA3C8EEA5C3EBA2C2EAA1C4ECA3C3EBA2BFE79EC0E69DC2E89D
C2E799C0E595CDF2A4C4E99C1A3E00CCEDA6C7E8A3CAE9A6CAE9A6C4E3A0D0EDABD1EEAB
CAE5A2C3DE99C5E09BCEECA6C6E59FD1F2ABC7E6A0BDDC9643611BDEFCB6BBD691CDE8A3
CBE6A1D0EEA8C7E59FC7E8A1D0F4ACBBE198CAF0A7BEE29ABCD792DAF4ADCCE69DCEE89F
CEE59FD2E5A3CAD5997275400D09008C835C6C603A62592E969360D3D79CE2EDA9CBE198
C4E69CCAF2A9B5DB92CEF7ABC3E99EC2EB9FC0E69BC5EEA2
6B795545542DB1BD97D8E4BC404D225B6C3FD7EDBC56733D001100CFF7B8B8E19FCAF1AE
CAEDA9CBE8A6D8EEADAAB982000600FBFFF1F0FFFFE9FFFF81A2A9000E15000205FFFDFD
0D0000382A27FFFDFDFAF8FB2C2A2D06000036251EFFFBF3F5EAE80400000B09006D6E5C
D4D8BF666D4E010C00000B009DAA8ED3E0C6636F57000600E3EDD4F3FDE2F8FFE2FEFFE4
AFAE8FF2F2D0FFFFDCF8FFD3E5F9BCCEE5A1CEE69CD3E99ED0E298DFECA6929B5AD4DCA1
DAE3AEA7B0812A370C637B49BDECA6C1EFA4D9F0ACD0D49771622B5E4A15C8BB84E3E4A8
C2DB97CDF5ACBCEFA2B7E79BCDF1A9D2E5A3D2D296A8A2688D9252CED899DDEBAEDBE2AC
72653BAF9570866640E8D1A5E2E6AB5768224C6219BDD287CBD890D1E29BCFEFA6CAECA2
CBE59EE2F8B0768C44D0E79FCCE69DD6F0A7C1DD93D1EDA3D1EBA2D0EAA1CBE29ACEE49C
D5E9A2E1F2ACC5D48F566723C6DB96D1EBA4CFEBA1C9E89CCCED9ECDF3A0C5EB96C6EC97
CAF09BD0F3A1CAE99DC4DF98CFE6A2CDE0A0C7D69BD8E6A9849350E6F6AFC3D48DB1C57D
DBF1A8CDE79DCBE79CC8E79BC3E397D0F2A5C3E598CCEEA1C6E89BB6D88BD0F0A4D0F0A4
CFEEA2C9E89CC9E79DCFEDA3BFDD9548631EAEC984D1EAA8D1EAA8CBE4A2C7E09ED7F0AC
C3DC98D2ECA5D0EAA3CDE7A0CAE49BCEEA9FC8E298CEE89E8FA75DCDE59BCAE298D1E99F
CFE79DCDE79DCDE79DCAE99DC9E99DC8EA9DC8EA9DC8EA9DCAEC9FCCF1A3C1E897C3EA99
CBF0A0C4E498CDE6A2000C00CFD8A3E1E3B2979666D0D2A08F975CD5E4A1D2E89DCAE596
CAE89EC8EAA0C9E9A0C8EA9EC9E99EC8EA9EC9E99DC8EA9D
000900718059D3DFB9C9D4ACE7F4C9CDDDB0CBDFAE5E7944001200CCF3B4B2D996C3EBA5
CEEEABC0DB98BBD08F96A46F020700FBFFF4F0FFFFBEDEDD87AAAE001014000305FFFFFF
0D05026A635D8A8985000100000100030000362825FFF3F06F666B85838661605B585C4E
E3EBD4697658000800687957586B4DD6E9CD5D6C55000A00E1EFD8F9FFEDFBFFECF1FADF
D6D8C0FFFFE6FCFFE1F1FFD5E0F9BFCBE8A5C9E79DCAE699C8E094D4E8A097A663D4E2A4
D0DFA8889867192A005E7C48C2F6AEADE093CDE4A0A8A86CB29D686F532169541FDED99F
DFF6B2B2DC92B4E99BDFFFC5B5D68FD1E09F110B00635A1F8A9752D7EEA8D5EBABB8C18A
958459AA8863653A17FBDCB0948F55E5F2ADC1D68B42590BE2F7ACD0EB9EBAE395BFE89C
CCE39BC8D99399AD66D4EAA2CFE69ECFE9A0C7E198CFE9A0CBE59CC5DC94D5EBA3D1E59E
CEDD98D3E09BE3EEAA43520DD6ECA3CBE699C9E598CCEB9BCAEB9AB7DA86DDFFACC1E490
C6E796B8D789D9F5AACBE59CC8DD98E8FBB9D9E9AACFDE9DEDFAB4162400E0F0A790A256
C0D68BD1E99BD5F0A3C5E091D2EEA1C2E191C9E89AC6E393D5F1A4D5F2A2C8E396BFDA8D
C2DE93CEEA9FC9E59BCBE59CD6F0A9CCE39D79904AD2E9A5D2E7A4CBE29ED4EBA7C4DB95
E5FCB6C7DE98CDE49ECFE69ED4ECA0CFE698CFE698CDE49693AA5CCCE395D4EB9DCFE698
D0E799CFE799CDE899CCE999CAE999CAE999C9EA99C8EB99BEE393CCF3A0C3ED99BEE892
C6ED9ACCF1A1C7E399041900DCEAAFD8DFA9B8BA88D3D8A098A26399A962CAE191D6F1A0
CCE89DCAE8A0CAE89ECAE89ECAE99DCAE99BCAE99BCAE999
1A2200151D00252A022328000C0E00575D31B4BD8E738450000E00D7F3B6CDEBABC8E5A3
D4EAAADAEDADD0DC9E929966333319B1B7ABEEFFFC658582294C4E1D3B3D687679F9FAFC
696562110E09000200000200000200040300241615FFFAFD7D787FEEEFF4F0F2EF000700
C8D4BC0B1C005D714C70865F000B00677C5D617359000800ACBAA3E0ECD4F1FBE3FCFFED
D2D5C2F9FCE7EBF6D8D7E9C1CFEAB5C6E6A5C7EBA1C9EC9CCEED9DCCE79A8AA058C1D695
E6F9C1B3C7943D5325577843BBEFA7CCFCB0D6EBA88D8B50B19A66EED09E7C6531E1DBA1
C7D796CCF0A8C6F4A9A8D68BD1EFA99FA96A655A22A1985DE5FBB3BDDF93C3E09DD7E5AA
5A491DBB9571754725A47F55C2B980E0EBA7D5EA9D94AD5CCDE496C4E093C4EFA0CAF5A6
BED58DAFC07AC2D68FD7EDA5D1E8A0C9E39ACDE79ECAE69CC8E49AE0FAB1C0D68EDAEEA7
95A45F97A45F9BA662D8E8A1D3EE9FC8E895C3E390CCED9CCDEC9CC7E897BDDE8FD0EFA1
D4F0A5C9E59ACCE69DD2E9A3D1E6A1C8DC97C4D795D3E49EC6D68DBBCC7E7C8E429EB364
E0F7A9CEE796C2DD8ED2ED9CC3E090CDEA98E0FDADC4DF8ECBE697CDE897D9F1A3D4EC9E
CBE59BDAF6ACC6E097D9F3AAC3DA92D7EDA5CAE0988A9F5AADC17CD7ECA7D2E7A2CBE29A
D8EFA7D1EBA2BED88FD3EDA3DAF1A3CDE293D2E798CCE19292A959CAE191D8F1A0CAE392
CFE897CDE897CDE897CCE997CAEA97CAEA97C9EB97C9EB97C2E392CAED9BC7ED98C5EB94
C3E692D0F1A0CFE79D5E6E2DD4DCA1AEB17A989663BBBA82A2A7678D9750D1DF90CCE290
CDE79DCCE7A0CCE89ECCE89ECCE89DCCE89BCCE999CCE997
6C73493A4117D8DBB0E1E2B8A5A4786E6F43D8DEAE636D39000C00A9BF81BFD897CFE5A4
CEE1A1DDE9A9DAE3A4929463302B1554554D1D2E28000904000A091B3738F5FFFFB3B7BA
040000030000171A11060C022C32280300000A0000D4C5CA030007F5F8FDFCFFFB7B8675
051400000B00CFE6BAC2DCAD294218000B005C7150000800ACBAA0EAF4DBE7EFD7E7ECD8
E1E1D5FFFFF4FAFFECE0F4D1D3EFBEC3E6A6C3E99EC5EA9AC6E796D2EF9FAAC47ACFE6A2
C9DEA3718852162E004F703BB8E5A0B0DA90D3E8A5ABAC70A4935DF5DEAA715D285D541B
DCE6A7CBE29EC9EAA3CBEAA4DCF1AE6D7335655C23D4D295C9E39ABCE295DDFEB9657439
1C0B0055310D7E502EEBC89EDFDAA0CEDD98C3DB8DD5F09F879E50B3CE81BEE798C7EDA0
A0B76FB8C983D5E9A2D4EAA2D0EAA1C8E49AD1EDA3C5E399C7E59BC9E59BD9F0A8A3B971
A2B36DD4E19CCED995D4E49BC7E490D1F39CC5E793C8E797CCE89BE5FFB76A843DDAF1AD
889D5CB1C685C6DB9ACADF9ECFE2A0D4E7A5D8ECA7CEE29BD3E89DDDF2A5CAE193CEE698
BED688DFFAABC6E393CDEA9AD8F5A5CAE797C2DD8EC5E091DDF5A7C1D98BD4EB9DC5DD91
D0EAA0D2EEA4C0DA91CBE59CD3EAA2CAE098CCE099CADE97869A53CFE59CD6ECA4D2E9A1
BFD990D5F1A7C4E096D4EEA4D4EB9DCEE394D1E697D1E8988AA151CAE392D5EE9DC6E190
CDE897CCE997CCE997CAEA97CAEA97C9EB97C9EB97C8EB97CBF19EBEE592C1E993CBF59F
BFE791C4EA97D4F2A8C8DD9AE3EEB4B1B680737641AAAD74A4AA6AA3AF67DAEB9BD0E596
CDE79DCCE7A0CCE89ECCE89DCCE89BCCE999CCE999CCE997
747D4E1119006D7041747647474616757746EEF2BF68733B0B1A004054156D8342CADF9C
D2E2A1CDD896D9DF9FA5A3731D1200A69E9B6B78714A635D173631000807828D91434448
0E0808332E2A12140900030026281D0E09031704087B6770403B42FCFFFFEDF3E998A48C
0009001D3304CDE6AFD6F1BA556D3900150072845C0009008E9979DBE2C3D7DCBEC7C9B4
D3CECAFFFFFBFCFFF4F1FFE4DDF7CAC6E8ABC6ECA3CAEF9FCAEC98C8E593ACC478DFF4AF
C6DC9E556C34061E005E7944DAFAB7B2D289DAEEA98D96559B995CDCD69AD9D0955A5418
D8D89AD2D898DEE9A7D2DD9BD1DA9960652599975ADDE3A3CCE89EC6EB9E96B772324108
5245198C6C46744E29F3DBADE3E9ABC8DF97DBFAACC3E2923C5106667B30BEDD91D0EEA4
8AA057D4E8A0D1E79ECDE59BCFEBA0CBEA9ECDEDA1C4E498CDEDA1CBEB9FB8D48995AD63
DEF2AAE1F2ABCFDC96D8EAA0C7E792D3F79FC8EA96CBE79CC9E09CCEE2A35F6E35D2DFAA
7E88566B7541E0EAB6E5F2BABBCB8DD7EAAACCDF9DDBF1A9CAE199D3EDA3D9F3A9CDE99E
D6F2A7BCDB8FC3E296D1F0A4C5E498C2DE93E3FDB3D7F1A7BDD58B93A960A1B56DCDE39A
BDD98FD7F5ABD0ECA2DDF7AEBBD389D8F0A6D7EDA4D7EDA495AB62AAC075D4ECA2C6E096
D0ECA1C3E296D6F5A9C9E59ACBE397D4EB9DD0E799D8EFA1869E50CDE899CCE999C7E696
CAE999C9EA99C9EA99C8EB99C8EB99C8EB99C8EB99C5EC9BCBF8A7B4E895B9ED98C3F9A1
B8EE98BBEC9AC7F1A5CCEFABC0D99FAFC28B7D8B56C9D89FC8DB9B9EB46CC1DC8DD2EF9F
CAE89ECAE8A0CAE89ECAE99DCAE99BCAE999CAE999CAEA97
CDDEA8B1BF8A55622C6E774279804CDFE6B0BEC991A2B1766D814257702E718C47C9E39C
D6EAA5D3E29FD9E2A19B9A6A2E1E0EDBCDCCFBFFFB9EB2A93D5652000806000107010005
635A5DFFFDFA6462565455474F4D410700002E171DDBC4CEE6E0E4FEFFFDF3FAEAEDF8DA
C1D2A6F3FFD0CAE4A5C9E3A2D8F0B2C5DAA1A2B484000900788059E0E4C1D1D1AF938E78
B7AFADF3EDF1FEFFF8EFFDE4DDF6CCC8E7ACC7EBA3CBF0A0D4F4A1C7E4928EA459C8DE96
E6FABBC2D79E576E3A697D48CFE3A4DDF1ACDEF2AD91A25E97A361D0D998DADF9F585619
90874CF9EFB4E0D69BA39A5F5551149B9D5ED5DB9BCEDD9ACFEBA1C8EAA092B16EC7D99F
706538B69F76664A23DACC9BCADA9BCDEFA3B2D787C4E594E2F4AACEDB9590A15B91A55E
94A860E4FAB1CAE298C9E399CAE99DCEEEA2C8EA9DC4E99BC2E799D1F3A6D0EFA3D0EAA0
738940748840D6E69FCFE499CEEE99C8EC95C8E799D3EDA6D0E2A69BA873BAC094DDDFB8
E3E3BFFBFBD7898B63969E6FEFF9C4D8E8AACDE09EC6DD97D4EFA8B5D38BC9E79FCDEBA3
BCDC93D3F5ABC4E69CC6E69DD0F0A7C5E39BDCF7B095AF688FA660D1E6A1B2C681BACF8A
98B46ABFDD93CEEAA0C4E096D8F2A8D4ECA2C9DF96C5DB90C4DA8FA0B86CABC679CBE79A
D4F3A7CAEA9ECCECA0C6E599C7E197DAF0A7D2E89FCEE69C8EA85ECFEBA0CAE99DCBEB9F
C9E99DC8EA9DC8EA9DC6EB9DC6EB9DC5EC9DC6EB9DC5EC9DC5EFA3BCEB9DC1F2A1BBEF9C
BFF09FC3F2A4BBE39C88A869CFE3AED5E3B2969F70D0DAA6E5F3B88292519AB067CCE79A
CCE89ECAE8A0CAE89ECAE99DCAE99BCAE99BCAE999CAEA97
D2F0B2BFDB9ECCE4A8D6ECAED3E5A9D8EAACD8EEAECBE6A3D4F3AFC5E69FBCE098CCEEA4
CBE9A1CFE9A0CBDF989498652D1A0CD2BEBFFFFFFAE8F5EC627772000504000005160F17
FFFBFFFAEFEDAAA498FFFFF1DAD4C80B0000462830FFF6FFFFFCFDEFF0E8FEFFEDE7F1CE
D1E2AED1E5A6B8CF89D2ECA3B9D08AE6FBBABDCC950B150064673CCFD0A8E6E2BCBAB29B
D7CBCDFFFBFFFFFFFBF9FFEFE8FDD6CFECB4C7E8A3C2E595C8E593D6F29E9AAF62C4D890
D1E4A4D2E3AC677947667441DFE4AADBE1A1B6C78396AD6788A35CD0EAA3D3E29FE0E2A3
5241095D420DBB9B68462B006A5B22CCCC8ED0DF9CE3FAB4C5DF96C7E29B94AE6DCBDDA3
857E5095845966552AEAE9B3C4E19ECEFAABCDFAA7D8FBA9C2CF87E2E7A4DBE09ECBD491
BFD089D7EDA4CEE89ECAE69BC6E69ACCF1A3C1E899C6ED9ECBF2A3B6DB8DCBEB9FD6F2A7
C5DD934B5F177A8A43D4E99ECBEB98C5E894CAE99DD5EBAAD4E1AC848960F1EECFF4EDD3
FFFEE8F8F1D7FFFFE3B2B28C868E5FD2DFA7CEDEA0DBF1B0D2EFACC9EAA5D6F7B2B9DA95
C9EDA7CAEEA8D9FDB7BADB96C0E19CD0EFABBBD6938BA462829857DAEFAED9ECACD1E6A3
C6E19A426219BCDA90D0ECA2D8F2A8CDE59BC6DC91E0F6ABD8F0A4BAD28494AF60BFDC8C
C3E495D6F9A9BEE191CBEB9FCAE49BD6EDA7D0E7A1AEC8819DB871C7E59DCBEBA2C9EBA1
C6EAA0C5EBA0C5EBA0C5EBA0C5EBA0C3ECA0C5EBA0C6EAA0CAE5A2CBE4A2D1EFA9C3E29C
CEECA6CCE7A4CCE0A575824DCDCEA4FFFFDC9B916DC3B78FDFD7A897945D979759DBE5A0
CFE6A0C9E9A0C9E99EC9E99DC9EA9BC9EA9BC9EA99C9EA99
C2E5A1CAEAA7CCE9A7C5DF9ED0E6A6CDE3A2C2DB99D0EBA6C9E8A2CCEEA4C3E599C4E69A
CBEB9FC8E497D2EDA0DAE5AD7461523D27292A29252F3C351E2E2B000A0A314345D6DFE4
FFFCFFFFFBFDC4BDB5FFFDF0939184140A0123090CFFF6F9FFFEF6F5F9E8E7F0D3D7E4B9
D0E1AADAF1ADD4EEA4D0EB9CE3FDB3C1D890CEE1A1323F07979E6BE3E4B8D6D4AB858063
DBD3D1FFFCFFFFFCF9F4F8E9EFFEDDDCF6C6D4F2B4CBE9A1D0E89CC9DE8F8CA154D8ECA4
CBE09FABC08547592576834ED2D59CDEE3A3ECFBB8869D577C9A52D6F4ACCCE19CD9E2A1
ADA76B7F6E365C471057440C9E985CEAF0B0CCE19CC5E099D5ECA4D2E9A387A05EDDECB1
736C3E9E8D62705F33D5D49ECFEAA5B5E091BFE997C8E797DEEAA2D2D391DCDE9FDEE7A6
E3F9B1BDD98FD4F2A8CBEBA0C3E599CCEEA2C0E296CCEEA2C9E99ECCEAA0CDE79EC7DE96
DBEFA8D8E7A26B7833D2E39CC5E494D2F3A2D2EDA6CBE1A3C9D5A5818761CECDB1F5EFD9
FAF3E0FFFFEAF9F8DCFDFFDEF5FED18E9C676F8346C6DC9CC4DE9DE3FFBED6F3B1D3F0AE
D0EDABC1DE9CCEE8A7D2ECABD6F0AFC1DA995C7533B9CF8EC9DE9BC3D895D9EEABC6DB96
CBE59ECFE9A2A9C37ABFD990C5DC94CFE79DD4EAA1D1E79ED0E89CCAE598ABC77A8FAE60
C2E595C5EA9AC5EA9ACFEFA3CEE59FD1E4A2CFE49F94AB65AAC47DBEDC94CDEDA4C5E79D
C6EAA0C5EBA0C5EBA2C5EBA2C5EBA2C5EAA4C5EAA4C9E8A4D0E5A2CBDE9CD4EDA9CAE3A1
D3E7A8C5D49BE3EDBB9798700A0100CEBDA3826851DFC5AAF1E2BBDDD5A4A09B61D4DB98
CFE6A0C9E9A0C9E99EC9E99EC9E99DC9EA9BC9EA9BC8EB9B
CAEAA1C9E79FCEE9A2D2EBA7CEE5A1C7DC99CDE29FDAEFACD1E6A3CBE29AD1EBA1C8E394
C6E391CEEC96CAE892D8E8A7A79787FFEEF0FCFFFDDCEBE8647275233D3E001612C8F2F0
F8FFFFFFFCFFA5A1A2FFFFFA667163161A0B0B0000B6A89BFFFFECE6F1D1D1E0B9CEE2AF
CFE7ABCAE5A0C6E69ACAEB9AC1E291D5F4A6CBE59CCBE09FD8E7AEDDE7B5D0D7ABABB18F
F9FFF1FDFFFAFFFEF8FFFFF3FBFFECEFFFDDDAF6C3CDE7AAD3E2A1DAE7A190A15AD2E9A1
C2E19DCAE8AADCEEBAAFBC87D2DDA1DCE8A6D1E09D88995593A460CEE29DD5E9A4D0E49F
D3E7A2CADE99D3E7A2D1E6A1D8EFA9C3DD96C9E49DCFE9A0D4EAA1859B5395AA67D6E1A5
766B3DBCA57B593D15ECDCABDFEBAB77934948641793AA5CD5DC96EBEEABD4DD9CCDE09E
CAEAA1BCE599C5EBA0CAEEA4C3E39ACDE8A1C8E29B2E43004F601C566522414D0B303B00
DCE5A4D5DE9D969C5CD5E29DCDE89BC5E697D4EFA8CEE6A8CFE1AF84936AD8E2C0ECF2D6
FCFFE8FEFFE8FBFFE4F8FFE0F8FFDAD1E8B2C2DC9F93AB6D3D4F11FCFFCDEDFBBEDDE8AC
DEE9AFCFDAA0DEE8ACD5DFA38C985A627032D1E09FD6E7A1C0D48CE8FEB3C2DA8ECFE59A
CCDD97E0F1ABD1E29C8B9C56DDF1AAC7DB94DCF2AACCE39BCEE89FD0ECA2C6E5998CAC60
C0E295CDF2A4BADF91D5F5A9DCEDA9C8D49253621D52631DC7DD94D4EEA4B5D486D9FAAB
C8EA9DC6EB9EBFE399C7EBA3CFF3ADCBEEAAC1E1A0C8E5A2CDE39BC9E399CAEFA2BCE098
D2E6ABD3DFAFECF4CFFDFDE30F0200937B71A47F77F4D5C3F0E8C4D0D7A3A0A86CCEDD98
D0EAA1CCEAA0C7E79CC3E398C3E599C8EA9DCBEDA0C7EC9E
CCEB9DCBEA9ECCE7A0CEE7A5CFE5A7D2E5ADDCEDB7E7F8C4F9FFD4D3E4ADCEE2A3D5ECA4
D7F2A3D3F19BBFE085C6DA95A79B85FAEAEBFBFFFD75858400040900090C3B787356948F
CFF2F4E8F7FCD4D1D8EFEBECB1B7AD0003001B1201E3DBC4FFFFE3E5F4C9D0E4B1CBE3A9
CCE6A5C7E79CC6E999C8EE99C9EC9AC5E697C5E399D4EDABD5E8B0E2F0BFE5EDC4AFB899
F8FFF4FBFFFAFFF9F6FFFDF5FEFFF1F7FFE8E2FCCFCFE6B0D6E0A3D4DB98B9C982D9F1A7
C1E59BD1F1AEC8DBA4D4E1ABCEE1A1D4E8A3D4E3A0A1AD6B97A361D6E2A0D4E8A3CCE69F
CCECA3C5E99FC3ECA0BFE89CC8ECA2C7E99FD1ECA5D3EDA4B3C98097AD64CCE19EDBE5A9
6D61319E825A725229F5E0B1C6CC8EB7CD85C6DE926D7F33A1A6639EA361E5F0AED5EAA7
C7E6A0D2F6AEC7E8A1D3F1ABC7E09C70854291A160D0DF9ED1DD9DDEE8A9DDE7A8CBD596
9DA76898A4648F9B5BD0E49FCCE89BCDEC9ECCE7A0CFE9A8CADFA797AB7AD5E4BBD7E5C1
EAF8D5EEFEDAF1FFDAF1FFD9F5FFD8CFE8AFD3EFB2C6DEA0DBEBAD374105FCFFC9CDD59A
D1D69EDBE0A6D4D99F9AA064C7CF93ABB576DBEAA5DDEEA7C5DB90D2ED9EC7E492CAE594
D3E49DD0DF9ACFDE99CDDE98738440C7DB96D1E6A1CDE49EC0DA93E3FEB7BAD68C82A056
D0F0A4C8E89CCCEEA1BEDA8FAAB976B0BB79C2CF8AD9EAA3CEE398CDE599D6F3A3B5D484
C3E495D2F4A7D1F3A7C4E39DBEDD99C2E19ECAE7A7D7F2AFDFF5AAC1DC8DCEF9A9C4ECA3
C9DCA4E4EDC0E0E7C6FCFEE90B0000CDB1AEB5898AF0CEC4E4DFBFC6D2A0B5C386E1F5B0
CCE69DC8E69CCBE99FD1F1A6D2F2A7CBEDA1C6E89CC4E99C
CBEC9BCBEB9FC8E7A3C7E3A8D0E7B9E0F4CFEFFFE4F6FFEDF6FFEBD3E3C6CFE4BBC7E0A9
BDDA97CCED9ED3F59EDEF2AB9A8B74FFFAF66D6F6A0005022F4445A6C9CBC2FAF9478C89
3A857EB0E4E0CACAD2BDA8AFB9ABA80800000A0000B7B295FAFFD8E1F4BDD0E6A8CAE5A2
C9E79FC6E798C6E995C8EE99D4F7A5D0F0A4CFEAA7CBE0A7D1E1B2FBFFDFFEFFE4959D86
F8FFFBFBFFFFFFFCFFFFFBFAFFFFF4F4FFE8E0F7CDD0E7B1D4DEA1E6EDA9ABB96ED0E799
C7E99CC6E69DD5E7A9AAB87DD1E4A2CFE49FD6E7A3BECD8A96A260D7E6A3D4E5A1CEE59F
C9E79FCBEFA5CAF0A5C9EFA4CAECA2CFEFA6CCE69FC5DC94A7BD74A7BD74CFE6A2DDE8AC
796D3DB69D7482653BBCAA7A9EA768C2D890C0D88CE0F5A8AAB16D989F5C778341A5B876
C9D998CDDD9CCDDD9CC8D796B0BF7E8D9959C8D494E2EEAEE0EFAEC8D897C4D795EAFFBD
B2CB87CEECA6CDECA6CEEEA3C8E998D1F0A0C4E095D1ECA5CBE1A3ACC188D8E9B5CCDCAD
D6E6B9DFF0C3EFFFD1F5FFD6F4FFD2CBE5A8CFECAAD4EEADCEE0A2CFDFA1AEBC7FCEDC9F
7984488691555B662AA7B375DBEAA9D6E7A3CFE59DD6EEA4C8E497C1E090D0F29EC9E898
D0EAA1BDD28DE5FAB5DDF2AD6C813CC8DD98D4EBA5CAE19BD2E9A3C9E09ADAF1A994AB63
CCE49ACEE69CD3EBA1CFE59C97A663C3D28FD9EAA4D8ECA4CAE095C9E497DAF6A9CAE99B
D8F9AAC1E195BDDD92CAE8A2D3F0ADCAE7A5D9F3B4F4FFC9DCEEA4CEE698C2EC9ABEE499
E2F6BB838C5FC6CDACFAF9E44E4037A68A89E5B8BBFFF5EFFAF5D8FCFFDAAAB77FCFDFA0
D1E8A2C7E399C7E399CCEAA0CBEBA0C3E599C3E599CAECA0
C9EC9ACBEDA0C8E7A3C5E3A7D1EBBBE8FED8F5FFECF5FFEDF6FFECC9DCBECBE1BACFEAB7
CAE8A8D0F0A5C5E896C1D693706549FFEFE7393A320005007A9292E4FFFFCCFFFF2A7B75
1D86784F9F96A4A8B18E6E7BF8DBDD1700000D0000B3B08FEAF7C2D9EFAECDE7A0CBE79C
C9EA9BC6E995C6EA93C6EC97C1E494C5E59CCEE8A9D3E7B2CFDEB5EFF8D9F8FCE5B0B4A6
F2FBFAFCFFFFFFFBFFFFFAFEEFF0E8DDEBD4D2E8C1D1E5B2E0E8ACC7CC89919D51D4EB99
D3F5A1C2E193E3F4B0909C5CD4E9A4CBE29CD3E8A3D4E5A1909F5CD6E5A2D3E4A0CFE6A0
C8E69ECAECA2C7EBA1CAEEA4C8E89FCEECA4CDE49ECBE29AD0E89EDDF5ABC8E19DD0DEA1
423807A28B61795E33B0A06FB2BC7DD6EDA5CDE89BDFF6A8D3DD98C9D28F91A25E98A867
BBC586E0E9AAF1FABBC7D091A1AA6BA4AD6EDBE5A6C9D595D7E7A6CCE19EC6DF9BCDEBA5
D5F6AFC5EBA2C6EEA5BCE295C8E998CCEC99C5E194D2ECA2D2E9A3A9BF7ED9EDAED1E3A9
CCDDA6D6E9B1E6FBC0F0FFC8E4FCBEC8E2A1C5E09DCAE5A2CDE3A3D7EBACDBEFB0CEE0A2
9EB072859858A4B475A3B674CCE19CD5ECA4C1DD92C9E89ACDEE9FC1E492CCF29FC5EA9A
C6E49AD5F0A9BAD58EBAD48D93AD66E7FEB8C1D892D5EAA5DAEFAACEE29DAEBF798C9D57
D4E49DD1E19AC3D38CF2FFBB98A965D6EAA5C9DF97BED48CDCF4AAD3EEA1C4E093CCEB9D
C1E092C9E89CD7F5ABCBE69FCBE4A0CFE8A6ECFFC2F4FFC8E5F2AAECFFB4C4E999C0E49A
D7E9AD495122919876FFFFEC887A717C605FA1777BEECBC7FFFFE8FCFFDF939F6DCEDDA2
D4E9A6D0EAA1CFE9A0CCE89EC9E79DC9E99ECBEBA0CDEFA3
C9EB9FCBEDA1C9E9A0C5E49ECFECAAE0FABDE6FFC5E1FAC1E9FFC8C2DBA1CBE4AAD5F2B2
C7E6A3BEDD97C4E69CE5FBBD7772520A0000010200939E96F0FFFFD5FEFFCEFFFF2B8C85
48C2B3318C836B737E7D5B6BFFF3FA674843291403B7B38ED8E8AACEE89ECAE797CAEA97
CBED97C8EC94C6EA92C7EA96BDDE8FD6F4AECBE3A9C3D4A7DFEAC8FCFFECFFFFF3BEC1BA
F0F8FBFCFFFFFFFAFFFFF9FFEEEFE9DBE8D4D0E6C0CFE3B0D5DDA15F651F919E4FD6EC99
C7E792C6E693CADA91A1AE69D5ECA6C6E19AD1E8A2DAEEA98A9B57D4E3A0D2E39FD3E8A3
CFEAA3C6E69DC1E399C1E399C7E59DCBE69FD7ECA7DFF5ADACC67CC8E499C2DD98E6F6B8
66602EB6A176755D319B8D5CCDD999DDF9AFD7F6A8B3CB7DDBE6A1DAE5A1D5E9A4CEE19F
AAB573595F1FA5AB6BE0E6A6909958808948E6F1AFDFEEABC5D994D4EBA5D6F1AABADA91
D0F4AAAFD58AC5EEA2D5FBAECBEC9BC6E391CDE899CEE99AD5EDA190A85CD2E89FD5EBA3
CEE39ED1E6A1D2E9A5D0E7A3C9E29ECEE9A4CBE6A1CEE9A6CDE7A6C7E1A0C4DF9CCCE5A3
D8F1AFDEF7B3BDD48ED5EFA6CAE69CCEEDA1C8E89CC4E797CCF1A1C9F09FBEE896C4EB9C
C9EDA3C8E7A1A1C07A5B7933D0EBA6C0D995CFE6A0D4E9A4C5D690BAC984697631E9F4B0
D5DE9BDAE3A0E4EBA786914CC3D792CBE59ED4EEA5DBF5ACCAE69BC5E196D2F1A5C1E094
D2F1A5BEDA8FCBE59CCBE29CD2E7A4C4D998D7E9ABD5E5A4D8E29BCCDC91BBDE8EC9EBA1
B1C085D8DEAEA1A783F8F8E0FDEFE66A4E4DD7ACB3FFDBDBFBF4E2FCFFE4A4AC839BA873
C5D898CEE59FD2E9A1CAE49BC7E399CAE89EC9E79DC0E095
CCEBA5CBEBA2C9E79DC7E69ACAE99BD0ED9DCFEC9ACAE795C8E394CDE99CD5F1A6C3E199
C3E09DCEEBA9BFDD9DC3D8A0010500151300737663F9FFF8ECFCFCE2FFFFC4FFFF1D8880
0E84784EA39E828C98B091A1FCDCE15D3E39170000ADA580CFDF9EC9E696C9E996CAEC96
C9ED95C8EC92C7EB93C8EA96CFEFA3DCFAB4C6DEA4C5D6A9E0EBCBF3F8E2EEF0E2D0D3CC
FBFFFFFCFFFFFFF7FFFFF8FCFDFEF8F3FFE9DEF2CDD0E2B0BEC389535613A3AE60D1E492
C3E38ED5F2A0DAE79F8D9A55D2ECA5C3E39ACEE9A2D5EAA58B9C58D2E39FD2E39FD4E9A4
D0EAA3C7E59DCEEEA5C4E49BD8F3ACCEE59FCFE39EBED48CCDE79DD0EFA3CAE8A2CFE1A3
767340A592676E572B9F9361D3E2A1C8E69CB1D283DCF9A9D9E6A0D7E49FB8CD88DFF6B2
D6E7A3D1E09D98A7642B3A00323E008D9C59DCEBA8C8D995E2F6B1D4E9A4D0E7A1CBE69F
D1EFA7D5F5ACCDEDA4BFDF94D0EC9FC5E292D0EB9CCBE695D2EB9A809948CAE191D2E999
CFE698CFE799CFE79DCBE29AC4DE97D8F1ADCAE5A0CBE6A3C9E3A2CFECAAC2DF9CCFECA9
C5E09BBCD790D0ECA2D0EFA3CBEB9FC8E99ACEF1A1BEE393C3EA99CCF5A6BCE596C7F0A2
C4E8A0C2E19D8EAB6890AE68BED994CDE6A2CEE39ED1E59EE8F9B3828F4A5E6925414A07
636A274D5210D7DC9958631FE2F9B3C3E199C6E49AD4F2A8B9D88CBDDC90DFFEB2CBE79C
D6F2A7C7E198E1F8B2D5EAA5D8EBA9C9D998DCECADCBD797D3DA94DAE89DD5F4A692B267
4A581BD4DBA8F7FDD7E9E9D1FFFCF1FEE2E1D0A5AEF7D3D7FFFEF1E7EFD7C1C8A7475227
CFE1A5D5EAA5D4E9A4CAE199C5DF96CBE79DD0ECA2CDEBA1
CFEAA7CBE6A1CAE69CCCE999CCEA94C9E68AC7E585C8E684CDE889D5F296D0EC97C7E396
E2FDB8CBE5A85C753C0F250000090085906E889279FBFFF6EBF3F5DAFFFF50AFA73FB1A9
C0FFFF94CBD2343D4C2D202AF8E4E51902003E2413C5B895D0E09FCAE999CBEB98C9EB95
C7EB93C7EB93C9EB95CAEC98CCEB9FB9D48FC8DDA4EAFACDC2CCA990967CC2C5B2FEFFF4
FBFFFBFCFFFFFFF8F9FFFBF9FFFFF4F9FFECE5FAD3D1E3B1B4B97F777A37C6D087D9EC9D
D1EE9ECEE99CD1DD9B849050CEE9A2C4E69CCFEDA5CDE49E90A45FD3E4A0D2E39FD4E8A3
D0E7A1CCE69FDAF5AEB7D28BDFF6B0D0E5A0C9DA968EA25B85A156B2D286D4F5AED8EEAE
7C7A47A8976B7F6A3DE7DDAADEEEADCCECA1C9EC9CC5E494DBEBA4D5E49FD0E7A1C6E49E
D0F0A7C6E69DC2E0988FAA63859F58A7BE78D5EAA5CFE39ECCE09BCDDE9AD8E9A5D5E6A2
C9DA96E1F0ADC9D895CCE09BD1E8A0CCE69CCCE79ACDE899CCE7968EAA56CCE591CDE790
CEE793CDE693D5ED9FD7F1A7C9E39CD8F1ADC4DD9CD1EBAACDE7A8C1DB9ADDF8B5D6F1AC
C5E39BE1FFB5C4E397C0DF91C7E899C5E697CBEE9EC0E595C0E597C9EFA2C6EC9FC9EDA3
C9E8A49EB877BFD897C1DA98D5ECA8CBE09DDFF3AECADB95BCCB86EAF7B1D3DE99D6E09B
DBE4A1E2E9A692995697A45FC5E099C7E99FBADC90C6E89CD4F4A9CDEBA1CAE89EC4E096
BAD48BCFE69ED1E6A161753041520E738241D9E5A5DAE3A2E5EBA5DEEAA0C7E39686A45A
ADB97BD9DDAAF7FED5535337FFFDF1FFF7F6D9AEB7FBD6DDFEF5EEFEFFF1FFFFECA7AF8A
CFDEA7CBDE9CD0E3A1D7ECA7D2E9A3C5DF98C4E096CEEAA0
D0E6A5CAE19DCBE29CD3EBA1D3EB9DCDE693CEE793D5EF98D3EA98CBE493CBE399D3EAA6
C4D99E5E723D000C00000E00CAE1B3D6ECC57F9276F6FFF3FBFFFFA7C9CB2E898268CFCB
D0FFFFE7FFFF48516038353CFFFAF6100400381E0D897B58D6E4A7CEEDA1CCECA0C8E998
C5E894C6E995CAEC98CDEC9CCAE69BD0E9A5DAEFB4CADBA7A6B189CBD2B1FFFFE8F4F9E2
F8FFF2FCFFF4FFFEF4FFFEF1FFFFEDF4FFE4E0F5CAD3E5B19DA268464807DDE49ED6E89E
C1DB919AB46D6E783C9FAA6EC8E6A0C4E89ED2F0A8C6E09996AA65D5E6A2D3E4A0D5E6A2
D3E8A3CBE29CCDE7A08FA962CCE19CD1E5A0D7E6A38B9C56CAE69BDFFFB4C1E59DBFD897
545420A7996C635123E0D9A5CDE09EBDDF93CBF0A0C1E090D6E7A0CEDF99D7F1AAC5E49E
C7EBA1BEE499CFF3A9C3E59BCBEBA2C8E69ED1EBA4CFE6A0D0E49FDBECA8D7E6A39DA967
98A36198A160787E3EA0AB69CEE3A0D3ECA8C6E097D2EDA0CBE697A8C470D7F09CCDE790
D3ED96C9E28ECDE899D4EEA4C1DB94D1EAA9CAE2A4F3FFCFF5FFD1C3DB9DD2EBAAC0D995
CDE8A1C2DE93CEEA9DCCE999C7E696CEED9DCDEE9FCEEEA2C6E69BC6E89ECEEFA8C2E19D
D2E8AA92A669CBDDA1D5E7A9C9DC9CD2E5A3D8E9A5D4E59FDDEDA6CFDF98D0DD97E1EEA8
D4E19CD2DF9AE0EBA7CFE09AC4E29AD7FBB1CBF0A3C6EB9ECBEBA0C4E298CCE89ED0EAA1
B8CF8792A860C5D994E0F1ADE2F1AE9DAC6998A462818A47D3D691D3DF95CFEB9E93B266
D8E4A4D4DBA5DEE5B9B3B697B1A595FFF8F4C89FA7FFE7EEFFFDF8F4F7ECFCFFEEFEFFE6
8F9B698F9F61ACBC7DD1E4A4CCE19EA1B87288A2598DA95F
CCDF9DCDE09ED2E5A5D5E7ABCFE2AACBDDA9CEE0AED4E6B6D3E2B7D2E3B7D2E3B7D0E1B5
5B6A3F2C3C0F2F3F12677A4CCDEABABCDDB281A382E2FBE6D6E0DF566F743F85837AC4C7
DBFFFFF4FFFF49515E3F4448F4FBF32D2C1A110000695A3BC8D59FCCE9A6CAE9A5CFEFA6
CEEEA2D3F4A5BBDA8CD0EFA1CBE79CC1DB94D2E8A7CEE0A67E8C59FCFFDAF3FBD2FCFFE1
F8FFE4FBFFE6FDF9DEFFFFE6FEFFE4EDFDD6E5FBCCD1E4AD999E64555718DFE6A3D4E5A1
CDE6A4758D4F141C00646E39CCEBA7C3E99ECFEFA6CCE69F8FA35ED7E6A3D2E19ED3E29F
DCF0ABC4D994D2E9A3748B45849954D9EAA6D2E19EACBD77CDE99EBBDD90CDF1A9C8E1A0
767642A6996C645325E3DDA9CADF9CCCEEA2CAEF9FCBEC9BD4E8A0D0E49DCAE59ED1F0AA
D0F4AABDE295C1E699D7F9ADC4E499CFEDA3CAE69CCFE9A0CAE098E0F4ADAAB9747E8B46
9AA561929D597C854299A565B3C58790A668A7C07ECCE69FCBE699ABC675CFEB97D4F09B
D0EC97C9E591C8E396CDE79EC0D9975F77399BB077E0F5BDF5FFD0D3E7ACCCE0A3D6EBAA
CEE59FCDE59BD1EC9FCAE596CFEA9BD9F4A5BCD78AD0EAA1D2ECA5CEE9A6C3DD9CD1E7A9
E2EFB77D8651E1ECB4DFEAB0CFDB9D94A362BAC986D3E29DD3E49DC9DA93E2F3ACCFE39B
C1D58EE7FBB4C9DE99CAE49DC7E99DC0E699CAEEA4D3F7ADB7D78ED7F5ADCBE69FA8C27B
89A05AB4C984D2E69FD5E6A0D9E8A3CDDC978F9C57444F0AD5DB95E6F2AACDE99C86A559
D8E7A4C7D195DDE7B5D9DFBB605845BEA5A0E0B7BDFFE8F0FFF8F6FCFFF6FAFCF1FFFFEC
AEB78C77864D6E7D4290A2648A9F5E657C38809A53CAE49B
DAEAA9CFDFA0D2E1A6D7E8B2CFDFB2C8D8B1CCDCB8CEDDBEA3B2951B2A0D000D00111F00
00080036421ACFDCB0C5D8AACCE9BB5A7F566D997632553F3E4D4AAEBFC6B8E1E7DFFFFF
EDFFFFEAF5FF4A4E5A44494CF8FFF824291513020057482BCEDCABC9E5AABEDA9DC3E29F
B8D690AECC8294B367ADC97EB2CC8293AD6495AC66899E5D708246D3E2ABD0DCAAD1DFAE
CDE1B0D6E6B9DFE0B8FAF8D2EFFAD0D0E3B5CDE6AFCADFA493995D9C9D61DCE5A4D5E5A4
CEE8A9CBE2AACDD5A698A270CDECA9C4EA9FCCECA3CEE59F92A35FC7D391D5E19FD4E09E
CDDE9A85995491A661D0E7A1B0C5806A7E399CAB6895A962D4F3A7C1E698CFF3ABD4EEAD
63632FA5986B746335DAD4A0D1E6A3C6EB9EC5EA9AC8E998D2E89FD6EAA3CCE7A0BFDD95
C7E29BD3EDA4D3EDA4D0EAA1B8D48AC9E59BC8E49ACEE89FCDE79EBED58DA5BB73ACC27A
CEE29BD6EAA3CDE19AD4E7A5C0D4978CA1668CA262CDE6A2D0EAA1B8D386C2DD8EC8E392
BFDA89E1FCADC1DB91D9F3ACD6EFAE455D21BDD29A94A672B0C18DC8D6A1E0EFB6D7E9AB
C7DB96D5EBA2DFF5AACAE294CAE191CBE294D3E9A0D5EAA5C5DA99CADEA1EAFEC3DEEDB6
C7CE9BC2C694E7EBB8ECF3BD3C4409D1DB9CDCE8A687965161722BD6EAA2C4DA91DFF7AD
CBE59CC3DD94C3DE97D0EEA6DDFFB3B6DB8ECAEEA4C7E99FCBEBA2D7F5AD9AB46DB3CA84
D2E7A2D7ECA7D2E69FCADB95D0E19BDDEEA7D9E9A2C9D68E7D8440C5D28A7E9F50C6E89B
D1E29CE0ECAED3E1ACD2DAB1FFF9E159423AB48B91FED9E1FFF5F4FFFFFAFFFFF8FFFFEF
F7FFD8DDE9B7D1DFAAD7E9AFD3E7AAC7DD9CCEE8A1E6FFB7
69793A63733567793F6576405B6D3D677A4D70825A60714D32431F051600000900384823
54633C91A077DFECC0D4E5B9C4DDB6072B072D5C3C426E578A9F9AF7FFFFF9FFFFEAF6FF
D4F0FBEDFFFF272A331B1718FAFFF600030030210E5C5135AEBB8FD2EBB4D1EAB1CDE9AC
DDF8B57B9651D6F2A8D7F1A7D2ECA2B2CC82AAC17997AE68A8BD7CD2E6A7D7E9ADC6DA9F
C9E3A6CFE4A9DDE4B1F6F9CAE9F7C4C9E0AACBE7ACD8F0B2A3AC6DD8DD9DD5DE9DD2E2A1
C6E0A1CCE3ABE2E9BD8E9768CBEAA7BEE499C6E69DD7EEA89FB06CD7E3A1E0EBA9D0DB99
AAB9769FB36EB2C782C5DC96D8EDA8788C47475613A9BD76C4E397C4E99BC3E79FBBD594
3E3E0AADA0739D8C5EDAD4A0D9EEABC3E89BC4E999C8E998CBE198D0E49DB6D18A8CA65F
D2DE9CE6EDAAD5DE9BD8E5A0D8E7A2DFF3ACCCE39BCFE9A0CEECA29EBE739FC175C3E599
C9EEA1C9EEA1CAEFA2BFE099DFF7B9CCE1A6B2C88ACDE3A2B7D18AC7E198D4F0A5D2EEA1
CDE99CCAE69BD2ECA3C8E19DAEC48484995ECDE0A8A1B27C93A170CCD8A6E2EFB9AAB97E
7585448DA15AC6DB8EDAF1A1CEE394CFE497D8ECA4D1E4A2DDECB1D5E4ADFBFFD5F7FFD1
DADDB0CACB9FC0C291F4F8C598A067D3DDA0D9E5A3DDEEA870843C95AB60CBE699C2DE93
D2F0A6D3F1A7CFEFA6C2E49AB6D88CCFF1A5C5E79DBCDC93D2EDA8BDD692A0B975C3DA96
CDE29FCBE09BCDE39BD3E7A0D5E9A1D2E69ED3E99EDAECA289944FB0C17A80A555CBF2A1
D8EEA5D2E2A1D5E7ADD4E0B2FFFFE44A3729BB9495F6D3D9FFF3F3FCFDF8FFFFFAF6F7E9
F6FDDBE6F2C4D4E2B1CBDCA6CEE2A7D1E7A7CAE39FC1DC95
3E5215465A1D4B5F2432470E1D3400354E173B5621163100142E00657F4F657C4EBAD0A2
E0F3C6E2F5C8B7C89BD4E6BCACC1A2587559406B508DB4A1EAFDF9F3F6FDFFF7FFFCFEFF
E4FFFFACD0D0636469887C7EFFFFF6403D2E0E0000615339C9D4A9C6DDA7C4DBA3D3EBAF
C8E1A0C1DA96BFD990D1EBA1DAF4AAD9F3A9D1EBA1C5DF96D4EDA9D1EAA8D8EEAECCE5A4
CDECA8CEE7A6D7E0A7E0E7B1D6E7B0C6DFA5C5E3A5CEE8A78B9654D8DF9CD5E09CCDE19C
D1EEACCDE6ACA7B0819DAA75C8E7A4BFE59ACBE9A1D1E8A27A8946DCE7A5D7E09FD9E4A2
9EAD6AC6DA95CEE39ED4EBA5D8EDA8C3D893D2E39FD5EBA3D4F3A7C2E497C9EDA5E2FBBA
4646124E4114584719ECE6B2D6EBA8BFE497C8ED9DCEEF9ECBE198CDE19AAAC57E6C833D
878C4AA1A0608B8B4B9CA15F9EA9658D9C57849A52ABC77DC0E0959EC376B0D689CCF7A8
BFEB9CB9E596C2F1A1BFE89CC5DF9ED3E7AAC3D999B6CC8B8AA35F93AE67B9D58BC9E59A
DAF6ABB4D086D6F0A9C5DE9A758B4AD5EBABCBDFA2D8E9B2DBE7B79DA97B818D5B9BAA71
A8B87992A65F879C5190A75790A757A3B86D879B5491A162D7E4ACCFDBA9D9E2B5FEFFDB
F5FAD1F4F7CC9FA575606733CAD39ADBE7A9E2F1AEC8D992D1E79C9EB66A6A8538CBE79A
C5E399C1E196C7E79ECEF0A6D0F0A5D6F6ABC1DF97D4EFA8C0D995D3EAA68AA15DD8EDAA
D2E7A4CDE29FCEE39ED1E8A0CEE69CC3DE91C6E192D1E99DD8E7A2B7CD85C3EA9BB3DE8C
D7F2A5C3D991D0E6A6D5E6B2EBECCA1504007E5B59DCB9BDFFFAF8FBFAF6FFFEFBFFFFF4
FEFFE6E6F2CACFDFB2D1E3B1D8EDB5D3EBADCFEAA7D0EEA6
CAE4A7CEEAADD6F2B5C9E7A7BBDB98C7EBA5CEF3ADBBE09AC0E5A0C0E5A2D2F5B5BFDEA3
CEEBB3CEE9B6C5DDADD3EAC052644C00110163806EF0FFFBF7FDFBFFFEFFFFFCFFEFFDFF
DDFFFF000F05313131B4A2A2FFF9F30B000012000073614BBDC498D3E8AFD9EEB3CEE4A4
CEE5A18FA660D7EEA6CAE298BDD78DD3EDA3C8E299CFEAA3CFEAA7C6E09FC7E1A2C7E4A4
C7E7A4C8E5A3D0DEA3CDD8A0CFE4ABD6F2B5CBEBAAC1DE9B919E59E6F0A9EAF7AFCFE499
C6E49CD2EDAA98A36B87955ACAE9A5C7EBA1D7F2ABC2D7923B4705CED796C2CB8AE7F0AF
DAE6A4BFD08CC8DD98D2E9A3CAE19BD4E9A4D1E5A0D0E69ECBEA9ECAEC9FC1E59DCAE3A2
7C7C489C8F627E6C3ED9D29ECEE3A0BCE194CAEF9FD2F3A2D1E59DDBECA6C1DB948CA15C
EEF0AFD5D1917A79388A8F4CC4CF8AD9E9A2CCE299D7F3A8C2E296BEE596C5EE9FCAF5A5
C3F09FC0ED9CC4F3A2CCF5A7CEE7A3CADF9CD2E9A5D9F0ACC3DD9697B26BBCD790DCFAB0
C7E59BCDEBA1C5E197DDF7B0869D57D5ECA6D2E7A4D0E2A6CAD6A6FCFFDCFBFFD8D3E4AD
C4D797D7EDA5D1E99DB0C87AAFC779C7DD9292A76297A96BC9D7A2DDE9BBE2EAC1FEFFDF
ECF7CDF7FFD7D8E4B4DBE8B3EAF9BEC4D495CBDF9AD2E89FD0E69BD1E99BBDD5898DA85B
D0EAA1C9E59BCFEAA3CCE7A0BCD88EC2DE94DAF4ADCBE29CD3E8A5000E0092A766CADF9E
D4E9A8D3E8A5D0E7A1CDE79ECCE89DCBEA9CCDEE9DD2EEA1DFF3ACC7E19ACCF7A7C2F29E
C7E698CFE99FC8E39ECBE0A7D5DAB10F000093706AB79596B5AAA6FFFFFAFFF9F6FFFFF4
FDFFE9DFEAC8CCDBB4CFE0B3CFE3AEC6DEA2C4E19ECEEDA7
C2E5A5BBDE9EBEE0A3CBEFB1CBF2B3BBE5A5B8E2A3C2EEAFC9F5B8B7E3A6CBF2B9A8CE95
83A66E8DB0785E7F4857724740513E505B53737E76BEC0BDF2E6EAFFFCFFE2F0F0E7FFFF
84BDAC3F6E5EAEAFAAF6E2E1FFF5EF1100006D4C45513824E2E8B8C6DA9BC6DB9AD3E8A5
BFD48FD9EFA7C5DB92D2EAA0C8E298D5EFA6C0DB94CBE8A5C7E4A2D0EEB0C9E7ABCDEDAE
C8EBA9CCEAAADCEBB2D4E1ABDEF6BCF1FFD3DDFFBECAE9A399A962CCD68DC6D485D4EB99
BCDD8CD2F1A5D8E7A493A261CFEDA5C5E79DD1EBA4CBDF9A4C5715E7F0AFD0D696DDE6A5
D8E4A24C5D199AAF6ACFE6A0B6CD87E0F7B1C6DB96D6EDA5C4E397C7E99CC5E9A1C6DF9E
575723605326483608E2DBA7D2E5A3C3E599C7EC9CCBEC9BCEE29ADBECA6D1EBA4B6CD87
919A57DCE19ECED591DAE5A0E4F4ADDAF0A7C7E197BFDE92CCECA0D2F7A9C9EEA0BCE394
C2E99AC4EB9CBEE596C0E295D6EEA4CCE29ACBE199C9E39AD8F2A9B8D38CC8E69EC7E59D
C4E298DAF8AECAE69CC0DC91B7CF85C7DF95D4E99EC8DB99DDEABCF9FFDBF6FFD7D9ECB5
CAE0A0CBE29CCFE99FD7F4A4D2ED9EDFF9AFC0D793B4C88B9BA976C7D2A7EDF7D2F5FFDD
F8FFDFF7FFDCBACE9BD4E9B1BED496D8EEADD6EDA7D2EAA0C2DA8EDDF5A7D6ECA15C7227
4F651DD0E69EC5DA97D8EFA9E8FFB9C3DA92C7DC97DAEFACD1E4A4445717A5B878CEE1A1
C1D695C9E09CCDE7A0CEEA9FCDEE9FCDF09EC3E994BBDE8CC6DD97D1ECA5B6E594C5F7A2
C7EA98C6E295D5F5ACC4DC9E61683C6D6246D0AFA6D1AFADAFA4A0E3E0DBFEF6F3FFFBF2
FAFFE9F4FFE3EAFAD6DBEDC3CFE6B2CCE5ABC9E6A4C6E59F
D1FAB4CDF7B5BCE5A9BAE5B0C2EDC2A2D0AB83B0938AB89E5B88716F9D814B775636603A
1D47196088534C74367A9C6A8CA18EFBFFFFFEF5F8C5AEB6C5A4AFFCF1F5E0FFFF7DC3AB
37725C91B6A59FA299FFFAF67F6763180000300403ECCBBAF0F3BEDFF3AED5E9A2D4E8A1
CFE39B7B9148D1E79CC9E197D4EEA5D0EAA3C7E29FC7E4A2C8E6A8DEFDC2DAF9C0D9FAC1
D6FABCD5F3B7E6F4BFD7E3B1D6EDB7E4FFC7CFF4B1C9EBA1CBDD93E1EE9FCCDE8AE2FCA3
C5E88EC2E28DD9E99E8A9A51CEECA2C2E49AC8E29BDCF0AB75803EE1E7A7E4E9A9D3D999
CAD694A0B16D7E934ECBE29CE2FCB5CEE59FC3DA94CDE79EC6E599D5F7AACBEFA7BED796
3A3A06A5976A7F6A3DF4EDB9D4E7A5CAECA0C5EA9AC5E494CFE099D5E49FCDE7A0C4DF98
8CA35BDCF2A9CCE49ACAE49AC6E297C8E79BCFEFA3CAEA9EC7E79BC9E89CC9E89CC8E499
CDE59BD8EEA5DBF1A8D4E99EC4D98CDBF2A4D0E69BBFDA8DCBE59BD4F0A6D7F5ABBCDC91
CBEBA0CDEBA1CAE69B769245CEE698D0E998CDE391D9EDA6CFDFB0F7FFE0F4FFD9CEE5AF
C8E2A3D3EEA7C9E89CBDDC8EC5E496C9E89CCCE7A2C7DFA3A5B785B2C198ECF7D5F8FFE4
EEFFDDF0FFDDCFEBB8D0EDB3CBE8A8CAE5A2BAD68CCCE69CCFE79BC5DC8ED4E99EDAECA2
D0E19B96A560D2E1A0C8D995C7DB96D8EEA6C5D994D0E09FD7E7A84C5C1DD2E2A4CEE0A2
D5EAA9D2E9A5CCE7A0C7E69AC3E696C2E996C4EE98C9F09DCAE59ECCEBA5B8EC99B4EA92
CAF29CBCDD8CD4F6A9CBE5A4081000786D4FA18174FFDED9FFFCF6C9C4BEFFFAF8FFFFF6
FAFEEDF9FFECF8FFE6E3F5CDD0E6B5CDE9AFCCEBA8C4E59E
6591527CA86B638F544C78436390655986652E5A431F4A39002A1937614B567F5F648D63
91B786B6DCA3C3E9AEC7E4B6E5F3E2FFFFFFFFF6FCBBA1AAB9A0A6F8FAF9D6FFFF459079
1B493CE2F7F0BCB8B7FFFAFA3A27211400005A352DFFFAE1FFFFCDDDF5ABCAE098D7EDA5
D1E79F738940CDE59BD0EB9ECAE49AC2DE94D0EEA8C8E5A5D4EDB4EEFFD4F5FFDFF2FFDD
F0FFD6EAFFCCF1FFCDD8E9B5CAE1ABCCEAAEBDE09CCCEAA2A4B66CDBE99AD6E997C6DF8B
C9E994D7F4A4CCDD9696A560D0E5A0D0EAA3CCE5A1D9EDA86D6F309D9B5EDDE3A3D4E09E
D5E9A48B9F5A97A864D7EBA4BEDC92D0F0A5DAF0A8CAE098D2EEA3C0E094BDDE97E1F7B7
323000A9986C654E22DFD3A1D0E09FCAEA9FC5E898C8E797D7EBA3D6E7A1C9E49DCAE8A0
86A057CDE79DC7E198DAF6ABCEECA2C1E195C9E99EC9E99DCCECA1C3E296D5EFA6DAF2A8
C6DA93CCDD96DDEAA5D0E09997A95DC7DC8FCDE398DCF4A8CDE59BCEE89ECBE59CCDE99F
C3DF95D2EEA3ACC67C4A6518D2ED9ECCE796C9E291D1E8A0D0E8B4F2FFDDF0FFD8CDEAB0
C4E3A0C6E89EC7E79BCEEFA0C9EA99C8E799CCE7A0D0E9A7CEE3AA93A573B2C295E8F9CD
DBF6C9DBFBCAC8E6B2C3E2A7C6E4A4DAF8B2CDE99FCAE49AD4ECA0CFE59ACBDF97D3E49D
D0DF9A8A995497A361D9E5A3D5E49FD4E59FDDECA9CAD998DBEAA94A5918ACBC7DD1E4A4
CDE2A1CBE29ECDE8A1D1F1A6CBF0A2C1E897BFEB96CAF4A2CDEFA5C0E49AC3F4A2C1F39C
C1E792D5F7A3B3D686D4F2AA000C0059562DB0907BF7D5CBE1D5C9B7B3AAFFFDF8FAF5EF
FCFFF2F9FFF1F4FFE7E2F3CFCEE4B5C5E1A6C9E8A4CFF1A5
87AD8497BE8F729B618EBA7B70995DB2DBA3ADD4A8C8ECC6B8DAB5C9EABFC8E7AEC9E7A7
CBE8A6D6F0B3D5EBBAF9FFE6EFF1E6EFE6E7AEA2A2CCC7C3EBF8EFBFE1D382BBAC60918B
F2FFFF807C8BFFF8FFA898A2040000060300ABA084F4EFC5E7FCB9D4F3A7C5E099C2DD98
D2EBA792AB67C2DE94D1F0A2C7E696CAEB9ACBEA9ED3ECABCBDBACFAFFE0FFFFEDFCFFE8
EFFFD2D8F6B6EBFFC8C5DDA3D1E9AFD4EEB1BFD998D5ECA8889C55D3E49DD9EEA3CFE59D
C2D897DFF3B6CDDEAA96A06C595E24D9E5A5C3E09DD6EBA89E915A604F19DDE6A5C7E19A
C7E79C89A35A9CA360C8D58FD5FEAFBFEA9AD1E29BDDE8A3CFE79BD1F0A4C0DF99D8EAAC
807A48AA956A654A1FA89867E2EEAEC6E49AC7EA9ACBEC9BCFE59CCCE29AC7E79ECCEBA5
D3E7A284914CD8E9A5E1F5AED0E7A1C7E399C1DF97CBEBA0C5E59CC8E89DBFDD95DDF7AE
D3EAA4CCE29AA6B77393A45EC7DB94869A53BCD089C8DC95D8E9A2DBECA5D4E59ECDDE97
D0E49CD4E8A0667C33DAF1A9C7E399CAE89ECFEDA3C6E7A2C3E7A9D7FFC1D1F9BACCF3B0
C2EAA3BFE59AC9EEA0CAED9BC5E793D6F6A3BDDA8AD5F0A3D6EEA4B0C67E8B9F5AA8BC7D
D4ECBABFD9AAC9E4AFD4F0B5C3E09DD2EEA4D0ECA1CEEA9FC4DE95D0E79FD5ECA6D1E6A1
C9DD96E5F6B08898519AAA63D5E29DD6E19DD1DE99D8E4A2D9E8A5495815BCCD89D4E8A3
CFE6A0CDE7A0CAE8A0C9E9A0C6EB9EC5EB9EC5EB9EC3EC9EC2ED9EBDE898C7F4A1CFF9A5
B9DB87D5F29ECAEA97C5E6975A7C32D8E3A9BC9E7CEEC8B3E5D8C5989785CCC5BBFFFCF6
FEFFFBF4FBF3F9FFF3E2F1D2C9DCAFCEE8ABC7E59BCDEE9D
C0E0C9BCDDC0C9ECC2B4D9A6C9ECB6BBDDAACCEBBFC6E2BADDF6CEC3DAACC5DCA6D4E9B0
DCEDB7C6D6A7F1FCDAB4B7A4877D7B746A6B4B46437D877ED9FAE9A2CEBD4D7B718CABAD
E4E7F83E2E4883708642323D03030031371DCDD2A9D2DDA5BED891CAE89ED6F1ACCEE7A5
CAE3A293AC6AC2DE94C3E294C7E993CAEC96CAE99BD2EBA9CEDBADFDFFE5FFFEF4F8F7E5
F8FFD8C6E3A1D0EDADC6E0A3C4DCA2D3E8ADCFE3A4C5DA9791A560D6EAA3C5D994CDE0A0
D4E6AC99A9785C6B40889166555320DDE3A7B9D894DAF0AFAB97626D5622DCE5A4D5F3AB
CDF2A58FA960858845EEF8B3B2E28EB9EB96E3F5ABCAD18BCEE499C5E498C1DF99E5F5B7
938B5AAF986E74572DCDBD8CCCD697C7E399D2F5A5C2E392D8EEA5D2E9A1C1E399C9E8A2
C6D5926A7332D5E19FB2C37FD8EDA8C0DA93DEFCB4C9E9A0C2E49ADDFDB4CEECA4C0DB94
C4DB95D6EBA66C803BDCF0ABCADD9B94A8638C9D59CBDC96C8D891CFDC96C5D28CE1F1AA
CCDC95DDEEA7738740CBE29ACBE69FC7E6A0CBEAA4C1E4A0B7DB9BCDF4B3CBEFAFB8DD9A
C8EBA7DCFDB8B4D48BCCEAA0CCEB9FD1EDA0D2EDA0C5DD91D8F0A2D2E99BC7DE90889D58
C3D5A3D9ECBFE9FDCADDF2B9D7EDACCAE49BCBE59BBED88EDAF4ABC3DD96CEE7A5C8DF9B
DAF1ABBED48BCAE0958FA459BFCC86DAE5A1DEE9A5C6D38EBFCE898FA05ACDE19ACEE49C
CDE7A0CCE7A0CAE8A0C9E9A0C8EAA0C6EAA0C6EAA0C3EC9EC2EF9EC4F1A0BCE694C8EB99
D2EF9FD1EC9BC9E495CBEC9DC7F0A2C5DA996F522ABC9578DFD4B8B3B59DB0AD9EFFFFF6
FFFFFDF6FBF5FBFFF4E3F2D5CFE2B5D1EBAEC5E399C6E894
F1FFFFF1FFFDF0FFF9F1FFF8F2FFF4F2FFF1F4FFEFF5FFEFF1FFE7CCDAC1E2EED677836D
666D5B343B2B888B80868580BFB3B7C7BCC07375726B7C722544353054461E3F38657A7D
262A368178890A00090B0001251D10868767C6D2A2D8EAAED9EEA9CBE199D2E5A3D2E5A5
C3D79895AB6ACAE49BD2F1A3C9EB97CAED99C8E89CCEEBA8CCE0AFFAFFE5FFFFF3E9EED8
E9FBC9C0DA99C9E3A4D9F1B5C7DFA3D4EAACD7EBACB8CD8A92A860C9DF97C8DD98D2E7A6
C4D89D6D7F4D0415001722009DA06BD2DC9FC9EAA3C8DF9BAB9A646D5622B3B979C8E29B
C1E196DCF3ABC2C381DDE7A2C0ED9CC2F3A1C5DA8FE3EFA7CBE196D9F5AAC6E49ECFDFA1
352D00A18A606D5026A2926197A162D8F4AABFE292CFF09FCBE198D3EAA2CEF0A6C5E49E
D2E39FD6E19F9DAC69D6EAA5CEE59FE1FCB5B4D28ACEEEA5CEEEA5B4D48BCCEAA2CBE69F
92A96393A863CFE09CC6D793E8FCB7BFD48F92A661B3C47EE2F3ACDCECA5D4E49DD3E39C
D1E19ADDF1A997AD64C6E097D2EEA4CAEAA1C8E89FC6E5A1E3FBC1CDE0A9EFFFCBCDE0A9
C6D9A2C4D79FD8EBB3D9EDB2C8DC9FD2E8A8DDF1B2E0F6B5BCD38FD3EAA4D0E7A1C8DA9C
99A47AD7DFBAFCFFDAF6FFCEDDEDAFCCDF9DD0E79F97B168BED891DFFAB3C9E4A1C1DC97
D8F3ACC9E59AE1FEAECAE59674853E97A661ADBC7795A66099AA64C7DB94D4EAA2D2E9A1
CDE79ECCE89ECAE89EC9E99EC8EA9EC6EB9EC6EB9EC5EB9EBEE999C7F2A2CAF1A2CBEB9F
CBE79CC6E096CDE79ECCEAA0BFE79ED7EBACBDA078F3CCADDFD6B5D0D5B7A4A68EF0F1E1
FBFCF4F8FEF4FBFFF1E2EFD1D4E5BBD6EDB5CEE9A4CEEDA1
F5FFFDEEFAF8F7FFFFF7FFFFF8FFFFE6F1E9E0EBDBDBE7D1D4DDC8232C1BD3D8D22F3334
8C8D91BCBBC0FCFCFAFBF7F6FFF9FF50464EB3BFBD6F867C000A000014090A1D19384345
FBFFFFFEFBFF0C01070A0000352815FFFFDDD1E5AAC8E39ED1E29ECBD795D5E1A3D6E2A4
D4E4A6CADF9EE3FDB4BAD98BCAEC98CAED99C6E89BCDECA9CAE2AEF7FFE4F8FFEED8E5CB
C2D4A0E7FDBCCBE1A3C1D69BD2E7ACCCE2A4B9CD8EC0D5928FA55DCFE59CDCF1ACD6EBAA
C0D499627643000A000B1B00D6DFA8D1DFA1CFF0A9CAE19DAC9B65624B17D0D595DAEFAA
C6E298CFE59DD8D9973E4803CBF8A7C3F4A2C1D78CDEEBA3C9E195D1EDA2C9E49FE0F0B2
645C2BB19A707C5F35E9D9A896A061BEDA90CFF2A2CDEE9DC5DB92D3E9A1D2F2A9C3E29C
D5E9A4D6E2A080914DD8ECA7CFE6A0C2DD96D9F7AFBCDC93C6E69DCAE8A0CDE8A1D6F0A9
7D924DD2E6A1D3E29FD4E5A1C2D691CEE39ED7EBA48A9E57DCEDA6C1D28BDFF0A9CEDF98
D2E39CBCD088C2D88FD0EAA0CEEA9FCDEBA1C3E398CFE8A6D8E1ACFFFFD6FFFFD8E2E5BA
D5DAB1DDE2BADEE5BCB9C198DFEABFC6D3A5E5F5C4F2FFD0D9ECB4E5FABFBFD597E7F5C0
606141FFFFE4FEFEDAFFFFD8CAD39CCFDD9F8599544A611B6E8841BED994CFEDA7C8E7A1
C7E79ECBEDA0B4D785C9E898D5EBA2DBECA6DFF3ACCDE19AC1D78FDCF2AAC9E098CAE49B
CCE89ECAE89EC9E99EC9E99DC8EA9EC8EA9DC8EA9EC5EC9DC4ED9EBCE596D4F6AAD2F0AA
C2D897D6ECABCDE3A3CAE7A5C2EAA4CADEA1A48860DBB795E3DEB6CFDAB2AAB18FFFFFEA
FFFFF3FEFFF4FCFFEFE2EDCFCEDFB5CADEABC3DD9EC5E29F
33392B34393200000530333C05060B4D4F4A4146306F75596C7055BEC1AECFCFCDFCFBFF
FFFDFFFFFEFFFFFFFDFFFEFBE6D9E2DCD7DEE8FCFA64827A253C349BAAA5A4A6A5DBDBDD
EFF3F4B3B5B2090200392D1DB3A487DDDCACD2F0AACCEEA2DFEBA98C90538D9357D3DBA0
DCE8AAA5B876B9D38AD6F5A7CAEB9ACBEE9CC4E99CCBEBA8C8E5AFF2FFE1F1FFE9CFE0BE
DAEDB6C2D796D1E5A8C6DA9D8FA366AEC285D3E9A98CA35F80974FCAE298C8DF99CAE09F
DDF2B7607743011400C2D3A6CFDEA3DEF3B0BEE29AD7F0AC7E6F365F4A13F8FABBD3E29F
CCE29AE4F5AFEBEBAB9EA764709B4BAADB89849E548C9D56A2BA6EBDD98ECAE5A0C9D99B
938B5AA58E645B3E14E2D2A1D1DB9C7E9A50CFF2A2BBDC8BD8EEA5D1E79FC3E39AC6E59F
C1D691DBECA896AA65869B56D9F3ACBBD68FCEECA4CEEEA5BCDA92E3FFB9CAE49DC5DC96
A8BC77CBDC98CEDD9AD6E5A2DCF2AAD1E8A0D1E79F8BA159CBDF98D4E8A1CDE19AD5E9A2
B7CB8481974FD4ECA2D6F0A6C0DC91CCEB9FC2E195D6E9A7E6E2B35747235A4B2AAA9D7D
483C225851375C564064624B4C4E36363A1FF3FDDBF7FFDDF2FFD7CDDFAFC6DAA5DEE9BE
756F57FFFDECFFF8DDFFFFDCE6E8B7D4DEA2A7B675C4D996A7C07CA6C47ECFEEA8D1F5AD
CBEFA5BFE496CEF5A2CBEE9CD0ECA1CAE199CBE29AD1E8A0D4EEA5CAE49BCEE89ED3EFA4
CCE89DCAE99DC9E99DC9EA9BC9E99DC8EB9BC8EA9DC6EB9BCFF6A5BBE293C3E29CCDE7A6
D2E5ADD3E4AE8DA16CD7F3B9D1F8B9BFD398C9AE83FCDBB2D4D3A3E3F4C0DDEABC717B56
DEE2CBFEFFEEFCFFEAE6EFD0D8E7C0CFE0B3CBE2ACCEE7AD
FFFFEDFCFEF0FFFFFFFFFEFFFFFEFFFDFDF5FBFEE3F3F7D6E5E9C8EEF0DAF8F8F6F2F0FB
FAF8FFF2F2FCFEFFFDF5F6F1E9DFE85B59647F95932B4843B0C3BFDAE0DEA2999CFFF8F9
BCBDB7060800201B085A5035D7CBA3E4E7AEC4E699C0E595C7D290C5C48BBCBF86A4AC71
9BA96BB5C886D3EDA4C9E89AC8E998CCED9CC7E79CCCEBA8C8E5ADF1FFDDEFFFE3CCE1BA
CBDFA4E0F0AFCEE0A29BAD71B7CB8EBACE8FA4BA79859C58D2E9A1E1FBB1D4EBA5CFE8A6
CBE3A7435A26000B00D3E6B8D3E7AAC8E39EC5EBA2D2EBA751470CB9A66EE4E2A5C7D290
D2E39DC2CF8AD8D898E0E9A6C6EFA0C4F3A2D5F1A6899D5589A1559AB46AAAC37FD7E5A8
574D1CCEB78D8D7046F1E1B0DFEBAB829E546C8F3FCDEC9CDDF1A9CADE97CAE8A0C9E8A2
DCF3ADCFE39EC8DD9893AA64819B54DFFAB3CBE9A1C9E9A0CEECA4C1DC95D2E9A3C8DD98
CADB977E8D4AEEFAB8BDCC89C2D890D0E79FCCE39BC5DB935D732B6D823D5E722DDAEFAA
97AC676D833BD4EBA3D9F1A7BED98CD1EDA0CEEA9DD8E9A5B6AB7E7E6747E3CEB1F1DDC5
F9E6D5FFFCEDF9ECE3FEF4EBE7E0D65A584BC7CAB7F1FADFE2EDCBD1E0B9D3E4B8CCD4AF
EFE3D3BCAA9EFFFDE8FCF6D4FFFFD6474E18AFBD7FDAEDABD0E9A5B2D08A7C9B55B4D68C
C6EB9EBCE193C8EE9BC9EC9ACBEA9ECDE99FC9E59BCAE69CD5F1A7B9D78DD0ECA1C5E498
CAE99DCAE99DC9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC8EB9BC8ED9DD1F3A7C3E09DCCE1A8
DCECBD7F8C612B3C12F0FFD8BFE2AAD0E3AC897143D5B688FFFFCDE9FFC1D0E4A9DDEDBC
CBD0B0FFFFE9FFFFE8F8FFE0F3FFD9DFF0C4D5E9B8CEE5B1
FEFFE6FFFFEDF6F6ECFFFFF8FBF8EFFFFFEFFFFFE3FEFFDDF0F6D4FFFFEAF6F9F0F3F7FA
FCFFFFFBFFFFF5FEFDFBFFFFB8B7BF050912273B3C91AAA78F9B99C1C1C1FFFBFDECDEDB
221B110A05003E391C89845EE8E7B1E0EDA8B9E18BC3EA97C1CB8CF3F2BCFFFFCFE2EDB1
C7DA98D4EBA5D4F0A5C7E698C7E696CFEB9ECBE69FD0E9A8CCE3ABF4FFDAF4FFE1CEE4B6
CFDEA3D5E4A1D9E9AA9AAC6ED5E9AACDE1A2B4CA89AFC680D3EDA4C1DD92C5DF98CAE5A2
C3DCA25B733F051A00C6DCADD6F0B1B4D48BCFF5AAD0EAA3655C21E5D49CD4D093E9EFAF
DBE8A3E7F2AED4D494E8F3AFBEE497B2DE8FDAF6ACD5EBA2D5EBA0A2BA708CA561DEECAF
201600AC956B6C5126E7D7A6CFDB9BB2D086567728C3E292D0E49CCDE19AD2EDA6CDEBA5
C3DD96C7DE98D9F0AA87A15A849F58D1ECA5BCDA92D6F4ACDAF5AEC1DC95E0F7B1D2E7A2
C9DA96C7D6939EAA68E2F1ACDDF3AAD7F1A7C7E198DFF6AE7A914B889F5B6A7F3C9FB471
8BA05D9BB06DD1E6A1D4EBA3CCE49AD0EB9ED5F0A1C6D590A297699D8666FFFCDFFFF2DD
FFFBEDFFF2EBFFFBF8FFFBFBFFF5F6A39E9BA29F96FFFFF1EDF3D9DEE8C6CDD9B3DADFC1
FFFCF384736CFFFDECFFF8DBFFFFDA59622DD8E6A9C9DE9DC6DF9BCFEAA587A55FA9C980
CDEDA2E3FFB5BEDF8EC8E998C8E89CCBEBA0CAEA9FC9E99ED1F1A6C7E79CD5F4A8CDEDA1
C9E99DC9E99DCAE99DCAE99DCAE99BCAE99BCAE99BC9EA9BC3E696D5F5AAD0E8AAD3E5B3
D9E5C1343D1E273416F5FFE4BFE1AFE1F3BF846C3EB99D6BFDFFC5F4FFC7D0EBA6D0E4A9
CED6AFFFFFE4FFFFE4FDFFE2FCFFE1E5F4CBD3E4B8C3D6A9
FCFFEAFCFFEAECEFDEEAEBDBE9EBD6FEFFEBFFFFE6FEFFE6FEFFE8F4FCE7FBFFFAF7FFFF
F2FDFFF5FFFFEAF9FFF5FFFF242D345B646B88979A9DABACC1C6C9FFFEFFFFF5F3574841
0B00000A0000B4AC88EAE9B9C7D192CBE397D1FCA3C6EC99B0BB7FEAEDB8FFFFD1E5F7B9
CDE4A0CFEBA1C5E498C5E496C7E396D2EAA0D0E5A0D4E6A8CFE0A9F8FFD6F7FFDCD3E5B3
DDEBADC6D38EDBEAA996A667CFE1A3CEE3A2DDF4B0F5FFC8D9F5ABDCF8ADCDE99FC9E4A1
DAF3B958703E000B00D8F0C0C3E1A1D0F4AABBE498D4EEA7726E316B5C23B3B174DBE0A0
D4DF9BD4DF9BDCDE9DDBE8A3C2E79AC8F1A3CCE89ED1E79FCBE198D3E9A0AFC682859356
473D0CAB946A674C21E6D8A7DBEAA9C2E096CCED9E88A555D2E39CE1F2ACBFD992D2F0AA
CFE9A2CCE69FD6F0A9C5DF9890AB64B0CB84C6E49CCAE59EC8E39CC8E29BCFE6A0CCE09B
D3E4A0D7E6A39AA664CFDE99CFE59CC2DC92CFE9A0C7E19AD3EAA6D8EEADCBE1A1697F3F
8B9F62D2E6A7CCE1A0CCE19ED6ECA4CAE097D3E99EABB7756F6939EADAB6DACBACFFFDE6
FFF9ECFFF9F4FFFBFBFDF1F5FFFBFFFCF3F6817C78B1AFA3F8F7E3F8FBE0FEFFE3FFFFE8
FFFCF6FFF4F1D0C7B8AFAB9082875ED4DEAAD7E9ABCEE5A1D9F2AEBAD590CBE6A167823B
819B52C1DC8FD6EEA0C9E495CEEEA2C4E69AC6E89CC9EB9FC8E89DCAEA9FC2E296CAEA9E
C9E99DC9E99DCAE89ECAE99DCAE99DCAE99DCAE99DCAE99BCFF0A1C0DE96CADFA6D7E6BB
DDE6CB3A3F2B7C8570F6FFE9C6E5B9D4E6B2AC9464EFD69ED0DB96D3F2A6CAE99DCAE3A2
9DA679D8DCB9D8DCB9E2EAC5FCFFE1F9FFE1F5FFDCE9FBD1
F3FAF2EBF3E6D7E0CBCAD2BAD9E2C7F7FFE7FCFFF1F9FFF2F1FBF0F8FFFAF0FFF8ECFCFB
F1FFFFF0FFFFE7FBFFCBE0F511242BD4E2E5F1F6FAEDEEF2FAFAFCFFFDFCFFFEF81F1106
1100002B1800D1C89DDBE0A8C7DE98CEF19FB9E18BCDF0A0ACBA7FDDE5B2E0F2B8DEF8B7
C0E097C8ED9FC7EA9AC9EA9BCCE79AD7EBA4DCE8A8CAD498D1DAA3F3FDC8E1EDBBD5E2AC
D7E3A3D7E49FD3E2A1899958D8EBABCEE4A3D4EDA9E3FFB5D9F5AACAE99DD1EDA3C2DD9A
DAF2B8586E3D000B00CDE5B5D4F4B1AED487CBF1A4D5EFA6A0A0605D55176E6E2EE0E7A4
CFDA98E7F2B0DFE5A5D8E4A2C5E59CCCF0A6C1DB94DAEEA7C8DC94D1E79ECCE39F586327
1E1400A58E64846C40E7D9A8DDECABC6E49ACAEB9C97B464C6D790D4E59FCBE59ECCEAA4
D3EDA6BCD68FDDF7B0CEE9A29BB66F96B16AA9C47DC9E49DD3EDA6C7DE98DBF0ABBFD38E
D2E39FDAE9A6B8C482909F5ACEE49BCFE99FD8F2A9CBE4A0D2E8A7CDE3A5D6EBB2A7BC83
B0C38CCEE1A9C8DAA0E0EFB4D7E7A8D7E8A4D0E19B737F3F565826D9D6ADDAD6B3FFFFE6
FFFDEDFFF8F0FFFDFBFFFCFFFFFCFFF8EFF2AFA7A5837C74DDD7C7FFFBE2FFFFE2FFFFEA
FFFEF8FFFEFBFBF9EA6D7156A3AE84D8E9B3C4D899D7F0ACD9F2AEC5DF98D5ECA8ABC07B
4C6019D7E7A0DDEAA2D3E599CEEDA1C4E99BC3E598D3F5A8C5E79BCEF0A4C9E99EC7E79C
CCEAA0BCDA90D6F4ACCDEBA1C6E298D0ECA2C2DE94C5E498CAEB9CCCEAA2C0D59DDDE9C5
DCE1CD6C6E61ADB3A5F5FFEBC3E2B8D2E4B0988250D5BF85DAE79FC8EB99C8EA9DCCE7A4
919A6BCCD1A9DADEB9E8F0C9FCFFDFF7FFDDEBFCD2E6F8CE
F6FFF9E5F4E1D3E4C2CEDFB5D3E4B8E0EECAECFAE3F4FFF3F5FFFAE7F8EEEFFFF8EEFFFD
EAFFFFEAFFFF98B3D04F69826F888DE9F8F5FDFBFFFFF8FDFFFDFFC3C0BB8682770C0000
462E16A08967F2EABBD7E1A4C6E69BD0FBA9CDF3A0D1EFA595A36ED3DFAFD1E6ADCFEEAB
C3E99ECCF5A6C6ED9CC1E293D3EBA1C1D08BCED496AFB279949760CED39BEEF7C0C7D195
D4DF9BD6E39D4857149FAF6ED9ECAAC6DD99CBE59ECBE99FC7E69ABCDB8FD3EFA5D0EBA8
C9E1A7708453000A00D9EFC0CDEDAAC7EDA0BFE497C7E198DCE3A0D8D7979A9F5D454E0B
A1AD6BC1CD8BCCD795CEDD9ACFEAA3C8E69ED9EEA9D9EAA4E4F5AED3E79FD2E7A4C4CF93
3D3302AD966C674F23E4D6A5CEDD9CC6E49AB7D889CAE797A0B16AAAB974D1E8A2C7E29D
C8E29BD0EAA3C4DF98C7E29BD4EFA8A0BB74829C55C7E19ACDE49EC9E09AD6EBA6DFF4AF
D2E6A1BECF8BD5E4A14A5B15ADC37AC5DF95C6E099C7E09ECEE4A6C7DCA3DDF1BED1E3B3
D2E4B4CDDDAEDAE8B7C3D09BDCE7AFC7D296E0ECAE4D571B808855DEE5BBD7DDB7FFFFE6
FFFFEFFFFFF4FCF8F5FFFAFAFFFBFDFFFCFDFFFCFAA49B944D4435FFFFEAFFFFE6F6EFDC
FFFDF9F4F5F0FBFFF0FBFFE8CFDEB3CCE1A9D5EEADC9E49DC3DE97C9E39CDAEFACCDDE9A
D9E6A197A25DB9C07AE5F2AAC6E295CCEEA1CFF1A4B9DB8ECFF1A5BCDC91C5E59AD7F7AE
CCEAA2D3F1ABC4E29CC3E19BD4EFAAD0EBA6CDE8A5D0EEA6C1E293CBE9A1E6FAC5A5B08E
3B3D2FF9FAF2FEFFF8F8FFF1CAE6BDCBDDA97F6A35BCA66AD1E196C8EB99BFE496C0DD9A
8F9B69C9CEA5D5DCB2E4ECC3F9FFDAE7F6CBD6E7BBD0E3B6
EFFFEAD8F1CACBE6AFD1EBAACFE8A6C7DFA5D6EBC4EFFFE7F2FFF1EAFFEBEDFFEDEAFFEF
E5FFF6D2F6F46C91A49CBDD0DCF9F5F5FFFBFFFCFDFFFAFDFFFBFA7F7A741311042A240E
634B2FE6CEA8E9E3AFCCDB9AC2E89DC1ED9EC3E59BC0D6968A9666E9F5C7EBFFCADAFAB7
C4EFA0C0ED9AC4EE9ACAED9DD0E69ED7E2A095965C55521B9F9E66D8D99FE6ECAEDBE6A4
D5E09BEDFAB23F4E09C3D792CFE4A1C6DF9BD1ECA5C4E298CDECA0D6F5A9CBE79DB3CC8A
DBF0B71A2C000E1D00BBCEA0BDDD9AD3F8AAC9EB9ECEE89ED6E19DDBE29FC0C9865D6824
495815677834EFFFBCD8ECA7C1D894DFF6B2DCEBAABFCB89CADA93C6D790C6DB98E6F0B4
3D3302634C226D5529EADCABD1E09FCEECA2DAFBACC4E191D8E8A196A35EC5DA95CBE4A0
CEE8A1D0EAA3CAE49DD2ECA5D3EDA6C3DD96B2C98397AE68D5ECA6C6DD97DAEFAAC0D590
C3D792D5E9A4D7E8A44D611A96AC63D4ECA2CEE59FEAFFC0F7FFD3ECFFCDF8FFDDF8FFE1
F9FFE1EBF7D1D9E4BCD5DDB4D2DAABDCE3B0A0A56F555C28909D6FCBDCB2D1DFBBFBFFE8
FCFFEFFEFFF4F9FAF2FFFFFBF5EFEFFFFDFBFFF9F4C9BFB6988C80BAAF9DF9EDD7FFFEED
FFFFFAFEFFFBECF3E3F9FFE8D5E8BACBE4AACCE9A6C1DF97CBE9A1C8E299D5EAA5DAEBA7
E0EDA8949E59656B25D0DA93D1EC9FD2F3A4C4E596CAEA9ED4F4A9D6F4AAC0DE96BEDC96
BED996D4EFACC3DD9CD9F3B2BBD596D2ECADC1DB9ECCE9A6CAEA9EC8E69EE4F8C5000700
696B5EFFFFFBF5F6F0F8FFF1C5E1B8D8E9B38E7942C0AB6CCDDD94C0E295C4E89EDCF9B9
97A371CED4A8D9E0B4E7F3C5FAFFD9E2F4C4CEE2AFC9E0AC
DCFCCACCEBB0C6E89CCEF09CCBEB98C3DF94CDE6ACE3FDCEE4FFD6E4FFDAD2F6CACAF0C7
D2FBDDAFD9CB628D94ACD3DAEBFFFDF3FFEFF9F0EBFFF2F0FBF0EC6F685E040100383218
968362F1E0B5D2D199D3E3A2CDF3AAC6F0A8CDEBABD9ECB59CA379F4FCD3F7FFD4DBFBB8
C4EFA0B8E892C3EF9ACFF2A2D8ECA5D7E0A19E9B64504B14E4E2A975793C89924FD4E199
DBE99EC5D58AA0B16AD8ECA5CEE59FCCE69FD0EEA4CEEDA1C5E599C3E296D7F3A9D8F1AF
C9DCA4667647000800D5E6B9D3F2AEC9EB9EC6E599D6EEA4D0E19BD3E09BE4F1ACC9D893
ACC07B5A6F2A3F540F8DA25DDDF0AEC5D493CBD596EBF4B3E5F2ACD8E9A2CEE19FD5DFA3
3F350480693F7B6337E5D9A7D0DF9EC6E69BCFF0A1C5E292D4E49DC1CE8992A762AEC783
CFE9A2C9E39CD2E9A3D9F0AAC0D791D8EFA9E4FBB5809751CCE39DD1E8A2D2E7A2CDE29D
EAFFBAD9EEA9C4D994CEE49C869C53D9EFA6C7DC99E7FDBFF8FFD6F8FFDDF8FFE3F9FFE6
F3FEE0EDF6D9CED4B8E3E6C7D4D6B1D8D6AF504D22999C71ADB993C9DAB6D7E6C7F4FFE7
F2FBE8FCFFF4F8F9F1FFFFFAFFFEFAFFFDFAFFFDF8FFF9F0FFFCF36052458C7C6DF8ECE0
EFECE7FAFDF6FCFFF1E7F5D4D0E4B3C9E3A6C1E09AD6F6ABCAEA9FC3E197CCE69FDBEFAA
B7C681DDE8A4959C58B9C57DCDE599C0DF91D2F1A3C3E294C8E69CC6E49CE2FDB8D7F2AF
DDF7B6C6E0A1D0EAADD1EAB0DBF4BBF4FFD6E9FFCBC1DDA0D5F5A9B9D990E2F6C37E896B
F3F5EAFFFFFBF5F6F0E9F5E1CAE7BBC8D9A26C561DA89354D2E299CDF1A7BFE29EC0DDA3
99A776D0D7ABDBE4B7E9F5C5F9FFD6E5F8C1D4ECB2D4EDB3
CBF1A4C5EC9BC3EA8FC8ED8DCAEE8EC8E98ECBEA9AD1EFA7C1DF9FC2E4A8C9EEB8C2E9BA
B8E4C0A8D5BED0FFF7DDFFFDF0FFF4F9FFEBFFFFF1F8EBE396898124170E2F2615D0C9AD
FEF5CEFFFFD1DDE5AAD6E9A9C1DF9FC4E6A9C6E1AAD3E4B7C0C19FD7D7B3D8E6B3C7E4A2
C5EEA0C4F19CC5F19CC4E797BFD38CDFE8A997965ED9D69FD6D79BD9E29FADBF75B6CB7C
CDE091708035C2D68ED5EBA3D1EBA4CAE59EC8E69CCCECA0D0F0A4C4E397D0ECA2CDE3A2
C8D9A25E6B3D040C00CFDCB0CEE9A6BADB8CCFE99FD1E99FCEE49BDCF0A8D7EBA4D2E8A0
D3EDA6B7D28BD5F0AB8CA35F4D5C1BAFB879D4D89DE0E4A7CDD893D8E8A1D9E9A8D6E0A4
2A2000BCA57B5A4216E8DCAADEEDACB3D388D0F1A2CEEB9BC9D690D2DD99AFC37E90A763
ACC37DD9F0AACCE19CCCE19CDAEFAACDE29DC6DB96B5CA854F641FD6EBA6C5DC96CCE39D
CFE6A0BAD18BC9E09AD7EEA6899D55D8ECA5C4D797CDE0A8D6E6B7E6F5CEF6FFE5F9FFED
FCFFEFFCFFEDFFFFEEFCFBE6FFFFE6AAA386A19879FFFCDEFFFFEAFBFFEDFBFFEFFCFFF1
FBFFF1FCFEF3F5F5EDF1EEE7FFFEF8F2EBE5FFFDF8FFFCF6FFF9F1D6C9C192847B867971
FFFDFAFBF8F1FFFFEFF9FFE0D0E2B0CBE5A6CAEAA1C8EA9DBDDF92CCEEA1CEECA2CBE59E
D0E5A0DAEBA5E3F0AB92A25BA0B86AC9E696C6E295D5F1A4C3DF95D3EEA7BBD490C9E2A1
C0D89ABFD79D70874F000D002D4513486030D4ECBCD0ECB2C3E599CAEAA1D8ECB9E9F4D6
EAECE1F8F7F3FFFFF8F9FFEFC4E0B0DAECB2988248CFB779D5E49FC3E7A1C7E9ADDBF7C4
8F9F72CBD4A9D4E0B2DBE9B6E7FAC2D9EFB1D1EBAAD4F1AE
C3EE95C4EF95C6ED94C6EA90C9EC92CDEE95C9EA91C2E28FC9E99EC8EBABC9EBB9D4FAD5
B8E0C66F9B8AD1FFF5E6FFFFF0FFE8E4E8CDFFFFEBFFF7EA95877E4130265F503DE0D5B9
FFFFDAF5FCC8E1F1B3D2E6A7C5DAA1D6EEBACCE6B7C4D4ADECE7CAB7AE8FD1D9AAD3E9A9
C3E99CC3EF9AC3ED97C7E899DAEEA9D4DCA0A8A970C8C78FD9DFA1DBEBA4D0EB9A627F2B
B0C674798B3FCFE59AD5EDA3C5DF98CBE9A1D6F6ABC1E195CAEB9CC4E397C6E298D3E9A8
CEDFA8657143151B00CED9AED2EBA9C6E295DBF3A9CDE39AC8E096CDE79DBBD58CCEEAA0
D1EFA7CCECA3C8E7A1C4DD99556121707437DFDDA4DEDEA2C9D38EE5F5AEC4D493D7E1A5
4438089D865C5E461AC0B482CFDF9ECDEDA2D9FCACC3E090EBF8B2C6D18DDFF3AEAAC17D
8DA25DD2E7A2D5EAA5CCE19CDEF3AECBE09BC0D590D9EEA95B702BB9CE89E0F7B1D2ECA5
BDD790E1FCB5E1FCB5C0DA9196AA62CFE09ADEEEAFD7E8B2CCDCAFE1EFCCF9FFEDFBFFF3
F5F9EBFEFFF5FFFDF1FFFDEFDAD1C0574C38FCEDD6FFFDE7FFFFF1F9FBEEF2F4E9FFFFF6
EEEEE6DCD9D2CBC6C09A958FFFFEF8FFFDF8FFF7F2FFF7F3FBF0ECFFFCF8D3C5C2615350
D0C5C3FFFDF6FCF9E6FBFFDDCDDEAAD0E9A8CCECA1BCE191C5EA9AC5EC9BCFF4A7B6D68D
D8F3ACC2D993C7DD95A4BA71789042D7F09FD4EC9ECDE599DAF2A8D3EDA6B4CD89E9FFC1
DEF6BAC5DCA40010003F5524BAD1A341582C52693F57723D8BAD63C9EBA1D3EAB6C9D6B8
F8FBF0F9F8F4EFF0E8F4FFE8CEEAB9CCDBA0866D34C6AE72D5E19FCBEBACC5E5B3BBD6A9
8F9E75D2DDB2D9E6B8D0E1ABD5E9AECAE3A1C9E49DCDEBA1
C3ED97C3ED9BC6EAA2C7E8A3C8E7A3CAE8A0CAE797C6E393C9E7A1C6E4AEC1DEC0EAFFFD
D8FAFB88AFB4D8FFFFE8FFFFE2ECD3DADBBCEDF3D9B7B9A43F31262E180D664F3FE9DBC0
D4DBAFC9DCA4CEE4A6D7EBAEF5FFCDF9FFDCF2FFE3F1FFDFFFFCE5907C61D4D3A7EAFABC
C5E59ABFE995C2EA94CFF0A1D6EAA5CED89B92955CE0E3AAEAF6B4BCD488CBEF98CAEE94
B1CA77BDD283E2F8ADD0EAA0C3DE97CAE8A0D8F8ADC3E598C0E192D8F7A9CAE49BCCE1A0
EDFCC5000800010500535C31C9DF9ED3EEA1D1E79CCBE196D9F5AAD6F5A9CAE69CD6F4AA
BEDE95CEF0A6C2E39CD5EEAAD5DFA288874E575019787339E1E8A4DAE7A1C2D291DCE6AA
6F6333A0895F7F673BA1956397A766CEEEA3B8DB8BC9E696D8E59FD7E29ECCDD99CEE3A0
A7BB7696AA65BFD38ED8ECA7CBDF9AD5E9A4DDF1ACD0E49FC5DA956B803BC4DB95D4EEA7
CCE7A0CEECA4BBD991CCE89EAABE76AABB75DBEBADDEECB7D1DDB5E3EED0FAFFF0F6FEF1
FEFFFAFFFFFAFCF7F3FFFDF6AEA198534336FFFBECFFF6E8FFFCF8FFFCFDFFFBF9FFFDFB
FBF3F1E4DAD8F1E7E5B7ADABC7BEB9FFFDF8FBF1EFFFFCFBFFFCFBF4EAE9FFFCFBF1E5E5
584547D0BFB8FFFFECFFFFE1D7E4AFCBE1A0C8E79BD3F9A6C7F19DB6E18FC8F3A4B8E193
C9EDA3D5F5ACBFDD93DFFBB0AAC372859C4C79904241570CD0E69DCBE29CE3F9B8BBD193
C3D89FD5E9B4000C00617749D6EBC2DFF4CDE0F6D0CDE7B7D0F4AACAEEA4C7DFABCEDBBD
DBDFD1FFFFFAFFFFF6FBFFECCDE8B5D4E4A6A88F56E4CC90CFDB9BC5E4A9DDFDCEE2FCD5
9AAA83E8F3C9EFFDCCD5E8B1D0E6A6C7E29BC7E69AC8E998
C1ED98BFE899C3E6A2CAE8AACCE5ABC9E2A1CAE69BCEED9DC3E79DCAEFBBDEFFEFD1F5F5
5175754E7270D8FDF5C2DDCAD9E0C1DADBB9E5EFCD767D5E0701002F200B625238DBD5B1
DAE8B5D3EBAFC5DE9DD6EAABFEFFD3EEFACAF5FFDDF9FFE3FFFEE657472EB2B089E4F1BB
CAE5A0CFF1A4C5E898C6E597C3D991E4F3B098A263CFDB9BD2E69FC8E497D6FAA3BEE28B
D2ED9ECDE398D0E79FC0DA93D9F7B1BFDE98BBDB92D0F2A6D2F3A4BFDE90CBE79DD6ECAB
B5C68F737F4F060C00D3DEB34B6422C0DA90E2EFA9D3E09ACFE79DC5E399CCEAA0C7E79C
CAEEA4C8EEA3BFE59CCEECA6D7E1A2D5D599E3E4AA5B5D1E4F561357601DDAE3A4E8E9B0
291800B29970624920E5D9A7909C5C8AA65CD1F2A3C6E393D5E79DD5E59ED9EDA8CFE49F
D5EAA5556A2580914DD8E7A4D4E3A0D1E29ED2E7A2C7E19AD2ECA589A35CCEE59FCCE29A
D6EDA5B8D48AD7F7ACC6E69AD4ECA094A861CAD99ED0E1ADD2DFB1E9F8CFF9FFE4F5FFE6
FAFFF2F8FEF0FBFDEFFEFDEBADA590645842FFF4E2FFFBEFFFFBF9FFFCFDFEF4F3FFF7F6
DAD0CFD3C8C6FFFBFBFBEFEFDED2D4FFFCFDFFFBFFFFFCFFFBF5F5FFFDFDFDF9F6FFFCFA
C4B0AF8B7770FFFCEBFDFADBDBE2B6D0DFA6D0E6A5C2E09AC9E9A0CAEBA4C7E8A1CAEBA6
CBECA7BBDC97DFFEB8BBD991D0E69ED0E19BCCDD99E0F0AF8A9C5ECCDEA2DEEFB8CBDEA7
D0E2B0677949000C0065784BD7E9BFCADCB2D6E8C0C9E1B1CBE8A8BCD89BD9ECBFD0DDC1
F4F8EAF7F8F0FFFFF4EFF4DED6E6BFCED4A49C8456DFC797D1D5A3D5E9B8F4FFE3EFFFE2
A6B193FBFFE3FCFFE1E0EDBFD3E6AECDE3A2CDE99ECAE999
C1ED9EC3EC9EC9E9A0CDE6A2D0E5A4D0E5A2CCE89BC5ED97C5F9A4B0E8ABDCFFFFA9DADE
5F8C759EC49DCDE9C0D6E8BED2DDB3E1E9C0A1AE830F1C00141D0072794DCCD4A3E0EAB5
DBEDB1C8DE9EC5DA97D4E7A5DBE9ABCFDD9FCDDD9FDCE9B48F9071F1EFD6FFFFE3E6F3C7
CCE1A9C8E3A0D1EFA5CBEA9CC2DF8FDCF7A896AE60D6EEA2CDE599D1EC9FCDE99CD5F1A6
D6F0A9C6DF9DC8E1A0D5EFB0B9D598CEECACC8E7A4D0EFA9CBEBA0C6E69AC9E79DCFEAA5
D3E8AD60723E000D00CFE1B1CEEBA9A1B8707D7F3E595919909F5A8AA45DA4C27ACCF0A6
C6EFA3BEEA9DC0EC9FC2E49AE2EDABD5DB9BDBEEACCCE09BB9C07D7472355F561FAA9A69
472B04C9AB8571552DE2D2A1DBDFA2A1B26C8AA558C0DF8FC8E396D0E89ECCE29AD1E8A2
CBE69FD5ECA8919B5CE0E4A7D0D497D6E2A2D0EBA6C7EBA3C0E49AD1F1A8879B54B6C37D
D1DE98D0E69DD3F8A8BCE392D9F8A8A6BD758FA26BCFE1AFD7E9AFD3E8A7BED58FDBF3B5
CAE1B5DDF1CCF7FFE3D4E1B6B7BE8B5A572CFFFEE4FFF7E7FCFAEEFCFEF3FFFFF6FFFFF6
ABA49EB8AEACFFF6F8FFFAFFF1E1ECBBADBAFFFAFFFFFCFFFFFEFFFFFFFBF0F3E8FFFFF3
E1D0C6645045FFF7E6C9C3AB6D6C4EE4E8C3B2BA916871446871429DA775D6E2B0B9C792
56693193AB71D7F1B4C6DEA493A16C6C744370794A717A4D151E00D1DCB2B0BB93636E46
6A754D636F47000C00374418687547596938D4E5B1D0E0AF65724774805CDFEACCDBE5CD
B3BAAA8B8D80BBBBAFFFFFF3DED8C8766B59422C17B19B84ACA2875F5E40878A6D838770
565448A8A59CF1F2E2B8BCA1616C4496A46FDDF2B197AE66
BFEE9EC3EC9ECAE99DCFE79DD3E3A2D0E5A0CAE99BC2EE97B4EF95B3F4B4D5FFFF90C8C9
78AA84C1EAAED0EAADC9DBA1D6DFB2CED6AD0009002632024D5927CCDBA4D9EBB1C9DB9D
CBDE9ECBDE9CE8F9B5D9EAA6BECD88EAF7B2D2DF99515A21ACB290F7FCE5FCFFE6E5F1CB
D1E3B3CCE1A6D0E9A5C9E59AD2F1A1D4F4A187A754CDEA9ACAE598CCE49AC4DB93CCE39F
BED796D2EAACD3ECB2CBE4AAD4F0B6C7E5A9CBE9A9C4E39FD1F1A6CAEA9EC9E79DCCE7A2
CDE5A75A713B000C00CDE4B0C3E29FE0F7B1D0CC8FE5DCA1E9F4B2CDE49E85A35BC0E49A
BDE79BC8F4A7C7F3A6BDDF95CFDA98E2EBAAC2DD96CAE59EE0E9A6ECE8ABAB9B685D4519
1B0000AC8B68745831EDDCAEE1E0A7CAD792D2EA9E97B666C5E496D1EDA2C8DE96D4EBA5
D6F4ACC2DC958E9758E4E4A8E1E1A5D8E2A3CAE8A2C1E9A0C4EDA1D0F2A899AA64949E59
DBE5A0E7F9AFA7CC7CD1FBA7C8EA96D4EEA598AD75C1D39FD1E6A3D4ED9CCBE790C6E693
D2F0B4D8F4C3F0FFD4D0E5ACC9D5955C5F28FFFCDDFFFFEAFEFFECF6FFE7F3F8E2FFFFED
B1B09EA39C92FFFCFAFFFAFFFFF9FFF6E8F7E2D6E4FEF6FFFFFEFFFEFFFAF7FEEEF7F8E6
FFFCF18C7A6E3C2E21080000120D00C6C4AD404026100F00120F000603006F6D478F9169
0A13005B6B3ADCF3BFC9DDAC0813000006003A401E555A3A0F1400040B00CCD3B4000600
000600020C004F5934515C32041000081600D4E2ADDBE7B9000500080C00FEFFEDFCFFEF
A9B09E0003008D8B7FFFF8EE0B00000E0000806C63998678140300150A00595339504B38
06000006000287847DABAC9A0E1300364117C4D39C8C9E60
C1EE9DC3EC9DCAE99BCFE79DD1E5A0D0E5A0CAE89EC2ED9DB4EE97B5F6B6B1EFE45A928F
8CC195CCF6B6C7E6A3CEE0A4E1E7BBD4D4AE0E0F0036390E757D4CD1DBA6E2EFB7CAD89B
E1EFB1CCDB9AD6E5A2D6E39EC9D691E5F0ACC7D28D5E672EC8CEACFAFFE8F7FFE1E3EFC9
D8EABACFE4ACCEE7A6C8E39CCAE69CC1DD92819D52D0EAA0D9F0A8DAEFAACEE3A0D3E8A7
D9EFB1B9D193D5EEB4E6FFC5EEFFCFF2FFD1EAFFC6F1FFCAD7F7ACCEEEA2CAE89ECAE5A0
CAE2A4576E38000B00CDE3B2CEEEABCAE19BDDD99CE6DDA2C9D492D3EAA4B8D68EC3E79D
C8F1A5BEE89CC0EA9ED1EFA7D7DD9DDDE2A2D3EAA4CBE59EB3BE7C97975B716533523D12
4F310DB1936F654C24DDCFA0D4D39ADAE6A4CEE69CABCA7CB3CF84DCF6ACD0E49FC5DA95
AFCF86EFFFC18E9957969B5BE1E6A6E2EEACC3E199CBF1A6C6ECA1CBEBA2C1D28CA3AC69
C7D08DD1E29BC6E89BCDF4A1BCDE8AC8E3968A9F64A3B67EBFD38CCAE18FE6FFA7C3E08C
C8E5A5C5E2AACFE8AFC8DC9FD7E3A151551ADDD5B1FFFFE4FCFFE1DEEFC5D3DFB9D9E1BC
919475ADAB94FFFCEFFFF5F1F3E7EBFFFAFFC9BDC7FFFCFFFFFEFFFFFFFAFEFFF4FFFFF3
FFF4ECFFF9F261544C352D220502000302008E8D79040200060200060200787556BFC09E
1C2400031200B7CD9FE2F4CA000600000500585E446D735962684E040A00292F15C7D0B3
525B3E000700F4FFDDABB7913F4B250009005C6B40CDD9B31F2308000300E3E8D2B0B8A3
8B937E0003003C3D2DFAF4E6332518170500675446AF9E8C594A350A0000A49E84F1EFDA
0702000B070634312AAEB1A0000500000700E3F0C4AEBF8B
C2EE99C5EC99CAE99BCFE79DD0E5A0CFE6A2C9E8A2C1EDA0B8F3A1B2F2B56DAB9C356E65
A7DDACBFECA7C3E49DD9ECACEDEEC47D77551A1400201D00919364D2D6A3E1E8B2CED89C
424C0F6E7A385D6A2586934EEAF5B1C5D08C8E9853D3DCA3D5DCBAF7FFE5F2FDDDEAF9D2
E8F9CCD7E9B5D2E7ACD0E9A8D5EEACCAE39F94AB67CAE19DC9DE9DCFE1A3D0DFA4D2E4A8
D6ECAED7EFB1C9E1A5F4FFD3E4FDC3E7FFC6CDECA9DBFAB4D5F5AACDEDA1CCE89ECAE5A0
CBE3A5586F39000C00CDE3B2BDDD9AD5EFA8D5D396E9E0A56B7634CFE49FC4DF98CBEDA3
CCF2A7BAE397C0E69BDAF4ADDCDE9FD1D193DEF2AD92A9634F5E1B8F9356E7E0ACD0BD92
674D28B39674806A43E8DBAEDEDFA6E4F3B0C2DC93C5E4985F7B30657F36D0E3A1E1F6B3
E1FFB6B2D185D0DF9AAFB673A7B06DDDECA9C1DF97C2E69CC5E99FCDEBA3D8E7A4CFD897
9FA867D7E8A4D8F6ACC1E698D8F8A5C0DB8CDFF5B54D6124D5E9A1D9EF9DC3DD84DAF6A2
C9E6A4C8E4AACBE3A7D2E6A7E3F0AB4C5013A49C75F5F1CCDEECBBC7DCA4D2E3ADD0DEAB
858C60BCBE99B4B2998B8376A59B99FFF6FABAB1B6F9F3F7FEFAFBF4F5EFFEFFF6FFFFF4
FFFCF8FFF6F5FFFCFADDD6D0030000070500A2A093141102140D00070000070100B0AF93
D3D8B80C1800576943CBDCBA0006000A1100131804CCD4BDD7DFC8020A00000600CAD5B7
636E50000D00CED9B9D8E6C35E6C49001000586643E3EECE6A6E57000300B0B5A1C7CFBA
E6EED9121701010300DBD6C2564B390D0000756450A4947DB2A68C3831153F3C1D797961
110E050100004C4C42EEF0E2111902000700CAD8B4C3D2A9
C3EE95C5ED97CAE999CDE79DCFE69ECDE6A2C8E8A7BFECA7B3EDA0B7F7BA498772377260
C3FAC3B9E99DC8EFA0CFE4A1FFFED33C2D0E0D0000605632B5B086E5E3B3D0D39CC1C78B
9EA76886914F89945097A25E919C5796A15CB6C17CD1DB9FDBE5C0FAFFE9FAFFE5F9FFE3
F8FFDDDBEDBDD0E4AFD4E9B1CEE3AAC8DDA294A86D9EB07684935C919F6AA1AE79A6B57E
8FA366D3EBADB2CA8EF4FFD1E3FDC0C6E3A3D6F5B2D2F1ABCFEFA4C9E99DCBE79DCDE8A3
CFE7A95B723C000D00CBE3B1C1E4A0D2ECA5C3C184A59F63A9B472D1E6A1D2ECA5C4E49B
BFE399CEF2A8CEF0A6CDE29DD8D699E3DFA29AA664556A25718140B2BA7EF2EFBCE5D8AC
5F4924E2CAA6A28E69ECE1B4E3E6AFC2D291C5DF98D8F6ACB1CD8379934AD2E5A3C0D592
C7E79CC3E294E0F4ACD2DF99AEB974C0D18BE3FFB7C4E69ACAECA2D2EDA6CEDD9AD9E3A4
9DA768CDDC9BBBD693CDEDA4BEDB89E0FBACC0D793A4B9788DA257C8DE8CD9F19BCBE491
CDE8A5CFE9ACCCE4A6D4E7A7DAE5A156571B726B3FDFDCAFD2E4A6CBE69FD5ECA8D4E7A7
AAB87DB5BD8ACBCDA6939178C3BDAFFFFBF5CFC6C7EAE4E6FFFEFDFFFFFAFEFFF5FCFCF2
FFFBFCFFFBFFFFF7FAFFFEFD0807030C0B069A979004000007000023190D0E0500635E4B
DAD9C4000500000C00CCDAC00007000810036E7466E2EBD8C9D3BB0006000E1900D9E7C4
5B6946000900E1EFCED1E0BF889778314222778669C1CEB4646857000200646857A1A692
E6EED70004000407009D997E645A3F0E00006353399C8E71D9D0B19D9A793A3B19010400
1718080F1104000200F1F5E6A0A893000600727F63E2EFD1
C5EE92C6ED94CAE999CCE89BCDE79DCAE8A2C5E9ABBFEBAEB6EFA8BCF9BD437F653E795D
B8F0B3B9EA9BD1FBA7C7DE98FFFAD25B472C1A0900A79A77DCD3AADAD6A7D2D29C6F7539
CED798E2EDA9E2EFAADAE7A2DCE9A3D8E8A1D4E19BD5E3A6DAE6BEF8FFE5F9FFE4F8FFE3
F8FFDFD5E6BAC7DAACCDDFAFCEE0AEDCECBBCCDCABD6E4B3BAC696CAD6A6DDE6B9DCE8B6
F2FFC88DA363D4EAACF0FFCCD3EBAFBFD99ACAE7A5C0DF99CAEA9FC7E69ACBE79DCFEAA5
D2EAAC5D743E000E00CBE3B1D1F4B0C9E49D818143BEB87CBDC886E8FDB8D3EDA6CAE8A0
C5E79DD2F4AACEEEA5D3E4A0EEE8ACEEE4A93E4706899A56C8DB99DCEAADDCDFAAEBE3B5
372501AB9774554521DCD3A8D8DDA7D0E0A1DDF7B0CBE99FBDD98FAAC17BAFBF80D8EBA9
C8E79BC7E698CAE095DFF1A7AFBF788CA058C8E49AC5E59AC9E79FC8E29BCFDF9EDCE6A9
C8D296566427DCF2B4CEE9A6CAE598D9F1A5D2E7A4E1F4B2CCDD9674863AD5EB99CDE496
C8E19FCCE4A8CBE1A3D0E2A4D1DB9C8B8C52686133DEDDADD4E9A6D3F2A6C4DE94CBE29A
D6E6A596A469FFFFD8FFFFE1FFFFEAFFFFF3F4EFE9E1DCD9F2EFEAFDFDF5FEFEF2FFFFF6
FFFDFFF7F0F7FFFDFFF9F7FA00000001000044403D0700003F342E4E443B51443B110900
5B58470C0F00000600D8E4CE000500000500343D2CCDD9C39BA88C0C1A00000900D0E1B7
BDCEA4001000C5D5AECEE0BAD8E9C76677570008006472598286770101000B0D00848975
CCD4BC0E1400010400DBDABB4F4927403613140700554B28958F6B91916B50552D272F0A
989E84070C00000400FCFFEFD6DFCA000600000700DCE8D0
C6ED90C8EC92CAE999CAE99BCCE89BC9E8A2C3E9B0BEEBB4BDF4B3A0DBA149856357916B
ADE4A1BCED9BCAF4A0CFE6A0D9D4AC645037100000918261EDE6BCE1DFAFE1E4AD252E00
DEE9A7D4E39ECEDF99CADE96CADE96CBE198CFE39CCFE3A4D0E1B5EFFFDBF0FFDBF7FFE2
F5FFDED6E7BDCDDEB4D4E5BBC7D6ABD9E6BBE9F6CBFCFFDCF4FFD4FEFFDCFFFFDCFEFFD8
FAFFCE4D6221D0E4A5D1E7A9C5DD9FD4EEADCBE8A5D5F3ABCBEA9EC7E69ACBE79DCFEAA5
D2EAAC5D743E000E00CBE3B1C5EAA5CBE69FA5A567E4DEA2DBE4A3B9CD88D3EAA4C7E29B
D0F0A7C8E89FC9E49DC8D794E5DBA0B2A36A4C5111D5E4A1C9DE9BD8EAACDEE5B1F8F4C7
261600D9C6A5948661F2EBBFDAE1ABD2E4A6C8E19DC8E69EC8E39CD9F0AC849455849755
DAF6ABC2E191D0E89AC0D789D3E99E99B1653D590ED3F1A7C9E49DC4DB97DAEAABDFEAAE
DCE7AD47541CD5E6AFCAE0A2C8E29BC7DE96D9EEADB1C484DDECA98E9D58061700D2E6A1
D2E8AAD3E8AFD5E9AEDBEAB1DAE3AAD6D6A26C6539D0CF9FC6DC9BCAEAA1C5E099D3EDA6
DFF2B091A163E6F0BEF7FED5FFFFE8FFFFEEFDF9EEDBD7CEC1BEB5D8D6CAEEECDFFFFFF4
FFFEFDF8F3F9FFFEFFFFFFFF0002010A0A080300000600006A5F5B382B2557484133291F
0C0900000300000500CCD8C20006000714000006005F6E4F000900000A00000B00CDE2AA
CEE3AB526631112500CAE0B1C3D8AF738762000900627056717566151509000200000400
050D00020900000600DDDDB90703001911001008000A0300302D0255582B000800000B00
010B00000700060F00D3DEC0CCD6BD0A1600000600E7F5DE
C8ED8EC9EC92C9EA99CAE99BC9EA99C8EAA0C2E9B4BEEAB9BAEDB278B27857906785BD90
C1F6B2C7F8A6B9E38FD3ECA8C4BF996B573F0F0000998C6AE0DBB1DFDFADD2D79D414B0C
D3E29FD7EBA3CEE69CCBE59BD6F0A6D1EDA2C9E59BD0EAA9CAE0AFE9FBD1E9FBD3F2FFDC
F8FFE1E4F4CDE1F1CAEAF8D4E9F5D1E2EEC8EAF4CFFCFFDFECF4CBE9F1C8EDF5CCEAF3C4
91A163B9CC8AD4E7A7BFD394DBF1B3CDE6A5C0DB98C9E79FCDECA0C8E799CBE79DCEE9A4
D0E8AA5C733D000D00CBE3B1B7DC97DEF9B259591BAEA86CDCE5A4DAEEA9C8DF99D3EEA7
C9E79FCBE9A1D0EAA39CA866A99D635D4C149E9E60D7E6A3DBF1B0BAD090DAE2AFFFFFD6
0D0000DECEACC2B592EFEBBEE8EFBBCEE0A2D1EAA6C6E49CD0E9A5C9E09CD2E0A3AEBE7D
779147D5F4A4CCE999D6F1A2C5E093CBE699D1EBA1859F55D0E79FD3E8A5D4E7A7D2E1A6
CBD8A2E2EFBA697742D7E8B1D2E8A8CEE4A3D4E8A9D6E5AAD9E4A8D5E0A44F5D20D0DFA4
D2E3ACCFE2ABD1E2ACD5E2ADCFD5A5EBEABC474016929163D1E6ADC9E7A7CDEAA8D4EDAC
C7DB9CC7D99FB9C593F6FED5FFFFE6FFFEE9FFFEEFEEEADEBBB9ACD8D6C7F1F0DEFEFCEF
FFFBF8FFFEFFFEFFFFEEF0EF787A770505030300000D050280726F988984AFA0998F8279
0600000E0F00000500303C24616F55D4E3C47989651F3006697B49869961BAD090C8DE9D
D2E9A59BB4727B9355DAF1B9CEE4B3A0B68882987195A485F2F5E4959589999C8B828771
7A8368808768A9AF8BD6D8B19F9C73322D030804003F3D0DC1C392CED5A2BECA98637440
697948778758A4B487D9E8C1D0DEBBAEBDA0738167EAF8DF
C8EB8DCCEF95C1E293CDEE9FCFF39CAED586CFF5C488B3884E7F47033900BDF1C1C2F4C1
BCEEA9C1ED9EC1EA9BD4EDACF6F2CF5E4E370E00009E9672E2E1B5D0D4A1E1ECB08A9B57
D0E69ECDE79DCAE99DC9EA9BC8EB9BC8EA9DC6EB9EC8E9A4D1EAB1CBE1B0D8EEBFEAFDD0
F8FFE1F8FFE1EFFDD9F9FFE4F8FFE1FBFFE4F1FBD8FCFFE1ECF7CFCBD6ACDEE9BECDD9A7
94A264CADB97CDE0A0D3E8A7CAE0A0D2EBA9C4DF9ACDE99FCBEA9ECDEC9ECFEBA1C5E09B
D1E9AB5F7640000C00CEE9B6CDF2ADBBD68F5C5C1EACA66AD1DA99D8ECA7D5ECA6C4DF98
C7E59DC9E79FCFE9A29BA66454450CB9A66EDEDC9FD2DE9CE0F6B5BBD191D7E1ADFFFFD8
0B01005D4F2C5F522F969366EBF4BFCCDEA0C3DC98CCEAA2CEE7A3CDE4A0D7E5A8D9E9A8
8CA45AC5E194D6F5A5C5E494C2DF8FD9F4A5CFE79B879D54455912CDE09EE5F9BAC3D79C
D9EAB4000D00000900000A00001300C3D89FE3F4BD6C7B44000900050D004E572897A375
62703F000F00000900030E000A0F00DBD9B3302804060400000B00001400CDE5B3C3DAA4
CFE3AEDDEEBA849062A6AE87FFFFE6F2F4DEF6F5E3CECCBDD7D4C5FFFFEFFCF9E6FFFFEF
FFFFF8FEFFFDF3F5F0FCFFFB72756E0809030400000700007E6F68C2B1A9AC9B91FFFCEE
0F0900070900000500000B00667651D8E9BDC8DAA8596C34D6ECACCDE49EC3DB8FD6EEA0
DAF5A6BAD588D4EEA5CFEAA5CCE6A9CAE3AADCF4C2F4FFDDFFFFECF1EFE0FFFFEFC4C9B2
C5CEB1DEE5C4D9DFBBD2D7AFD9D7B09F9C71070500737341DBE0AADCE7AFC4D69CD4E8AD
C6DA9DCBDFA2E0F3BBD1E3AFC9DAAEEAFAD3F3FFE1E7F8D8
C6E98DC5E790CFEFA3C7E99CC0E78CD6FFAEBFE7B5345E385E8D57B7E9AEC8F7C1A2CF96
CCF7B2C1E9A0B7DB95C7DCA3ECE9C85B4C350B01009D9976E1E2B8D9E2ADD9E7AA95AA65
CDE79DC9EA9BC8EB9BC6EB9BC5EC9BC3ED9BC3EC9EC5EBA2CBE8A8C9E0A8D4EBB7DBF1C0
E8FBCEE9F9D2E2F0CCF9FFE4F9FFE4FBFFE4EAF6D2EAF6CEDDEABFCDDAACD0DEADA3B27B
8F9E5DDFEEA9D9E9A8D6E9A9CADE9FCEE4A3CFE8A4CEEAA0CDE99ECAE99BCDE99FCCE7A2
CEE6A8334A14243A0CCAE5B2BCE19EDAF5AEB1B173BBB579E1EAA9C0D48FCFE6A0DBF6AF
CEECA4BFDD95D1EBA496A15F6A5B22A08D55E1DFA2DEEAA8CBE29ECDE3A3DDE7B2D0D2A3
251B00837552766A44B4B1848B945D73854792AB678BA961A8C27B859C5895A365849352
8DA35BE2FDB0B8D789BFE08FD4F5A4BBD888D1E79CBCCD869AA964BCCC8BBFD595C6DEA2
A3B880000B000612003A46182A3B0ED5E9B89FB07A36430E6F764A373E15101400424824
687349081500283309777F5A68694AE6E1C40D020035310E576544001200324720DBF0C5
C4D5A8CCDCAFA1AC82B3BB96FFFFE6F9FBE5F7F6E4DEDCCDF4F1E0D1CEBDFFFFECFFFFEF
F9FBF0FBFEF7FCFFFAF9FFF5FEFFF800020004000010070094867DAC9B91B2A295FFFDEF
D9D4C10204000A1400334223CFE0B3CADDA6B3C78CD0E5A4BAD189D4EC9EDEF7A4C0D985
C4E08BE5FFADBAD586D7F3A8B8D38ED9F3B4EAFFC9F6FFD8FBFFE4FFFFEDFFFFECC8CEB4
DCE2C6BDC6A7E9EFCDD7DBB6DDDDB7DFDDB4524F22969866D2DAA1D1DFA2DDF1B2CFE8A4
D9F3ACD7EEA6BED591CCE2A4DAEFB761754403160055673D
C7E88FCDEF9BCFEFA6BADF91C4ED8DC6F29B6F966760886589B381E1FFD2B6DFA5BCE4A6
CBF0ADC0E3A1D1EFB3D8EABAF9F5D8594D370F0800979473D8DBB0D9E3AEC9DB9D8DA760
CAE99DC8EB99C6EC99C3ED99C2ED9BC2ED9BC2ED9EC3ECA0C8E7A3C7E1A2D0E8AECEE5AF
D2E6B5D3E4BAD6E4C0F8FFE3F3FFDEF9FFE3E2F1CAD3E2B7D1E1B0D6E7B1CCDFA787995B
8F9E5BD4E39EC8D796D6E6A5D8EDACCBE1A0CDE6A2CAE69CCDE99ECBE79ACAE69CD2EDA8
CAE4A70017005B7143C7E2AFC7ECA9CAE59EA3A3657C763ADEE7A6D1E5A0D1E8A2BFDA93
CCEAA2C7E59DCBE59ED1DD9B60541AB2A169C7C789DFEEABD3EAA6D3E9A9D7E2AA515020
756943DDCFAACFC39DDAD6A9DFE6B0CFE2A2C5DF98D1EFA5C6E097D3EAA4DAE8AAE0EFAE
CDDE98CAE097D2F1A5D4F7A7CCEF9FCAE699CDE297D4E49DD3E09B637430DDF6B4C7E4A4
CDE9AFD1E8B43E4A1C0008007F9066DAEDC0DAE8B5CCD6A4E2E7BFD2D5B60303001E2104
B6BE97C5D0A6151D00070C00DBDBC3E5DFC95F5436A6A181E1E9D124341A000800A0B08C
D6E5BCC8D5AA95A078848C67E3E8CAFFFFECF5F4E2FFFFF0FDFAEBB4B1A0FFFEEBF6F5E3
FCFEF3FEFFF8F5FBF1FCFFF6F7FAEFFFFFF4E2DBD1FFFBF1FFFBF3AC9A90B3A396FFFDEF
FFFFEDEEF1DCB8C5ABD1E1BDCBDDABDBEFB2899E5DCDE29DD8EEA5D0E799CCE592DEF7A4
D2EB98CFEB97CCE798C9E497DCF7B0C2DD9ACDE7A6D2E4B0DCE0BDE0DEC5DDE0C5C0C6AA
9EA488FAFFE6F6FBDDFAFDDE666546A8A882828057989C6ACED99FD5E8A8B4CE87CEEA9F
C2DE91D1EC9DCFE99FCAE49DDEF7B6CEE3A8B0C58DD5E9B4
CAEA95C7E696CBECA5C0E597C5F28DABDA7E3D6435C1E6C4C9EFBEB6DCA1BDE1A1DFFFC0
C1DFA1C0DBA4CEE6B6CDDBB7FBF6E0392C19080100858261D1D4A9DEE8B3D9EBAD89A058
CAE99BC8EB99C6EC99C3ED99C3ED9BC2ED9BC2ED9EC3EC9ECBEBA0C7E59DCFE9A8C9E1A5
CADEA9CADDAFD2E2BBF9FFE3F6FFE0F8FFE1E2F3C7CEE0B0CCE1A9D7EFB1CCE5A38EA55F
93A25DD8E59FDBE7A5CEDE9DCFE2A0D1E6A3D3EAA4D0EAA1CCE89DCFEB9EC7E398D3EEA9
C9E3A6000D006E8456C8E3B0C4E9A6C9E49DB7B779868044BFC887D9EDA8DAF1ABC9E49D
C4E49BD7F7AEBED992D9E8A56F6329796A31F3F5B6BFCE8BC7DE9ACDE2A1B5BE87626030
7D6F48E1D2AB968861E0DCADD9E1A8D7EAA8BED891D9F7ADB8D289DAF1A9CCDB9AD3DF9F
E8F4B2B2C67FD3F1A7C8ED9FBADC8FD8F7A9D1E399D4E098DAE5A08D9E5AC9E4A1CCECAB
C4E3A8D3EBB7AFBC8E333E1432421DC4D6ACD9E7B4D4DEACD2D6B16C6C520403003B3B23
B7BD97E5EEC37F87601D22046D6A57DCD5C2574C2CD7D1AF91967F061200000A00A8B693
C9D5ADEAF5CB828A619EA681EEF3D5FFFFECFEFDEBFFFFF3FFFFF3A8A498FFFFF1FFFFF3
FFFFF6E9ECE3F9FCF3FEFFF6FFFFF6FFFFF4F4EDE3FFFDF3FFFBF3B4A298B2A197FFF4E8
FFFFEFE3E8D4DCE8D0CCDDBBC3D5A1E4F8B97F9453DAEFACD3E9A1C3D990CDE39ACDE599
D5EDA1C6DE94CCE49ACDE79ECCE5A1D9F4B1C8E2A1D5E8B0D3D8B0E4E3C4F1F4D5D0D5B7
A2A88EEBF3DBFEFFECA8AC930303006E6D4E5A5A34989E6ED6E4A9D4E9A4E4FFB5BDDC8C
D9F9A6BBDB88D6F2A5D6F2A7BAD48DCBE4A2DAF0B0CBE1A3
D0ED9DB3D286D3F3B0CCF2A5B8E77FBFEE8E567D4EC4E7C7CCF1BEC1E3A6D0EFABCAE5A2
DCF1B9E0F3C6D5E4C3D3DBC3FFFEED3323130E03007C7759CECFA5D5DEA9DCEAAC60762E
CDE89BCAEA97C9EB97C6EC99C6EB9BC5EC9BC5EB9EC6EB9DCDEE9FC7E698CDE8A1C9E2A1
CDE2A9CEE2AFD4E5B9F8FFE1F7FFE0F2FFDAE1F5C4D1E8B0C8E2A3CBE9A1C7E69AA9C475
A1B369C0CD87D9E6A1CFDE9BD6E6A5D5EAA7C6DD97C1DB91CBE79AD3EFA2C8E499CEE9A4
CAE4A7000D00607648CCE7B4BCE19ED3EEA7E1E1A3CBC5899FAA68D3E8A3D2ECA5C9E79F
D0F2A8BCDE94C9E79FBBCC884C42077F7339ECF1B1CDDE9ADDF2ADD8E8A7D0D59D4D4919
786940D0BE98A99A71E4DEAEDEE3A9D3E4A0D4EEA5CBEA9ED2ECA2D6EDA5DDECABCDD798
D2DB9CEBFAB9C7E59DBDE295C9EEA0C8E79BD0E097BBC57E56601BC7D892D3F2ACCCF1AC
B2D698C9E6AED6E3B5CDD5AC475732283A1097A66FDDE7B29496716F6D542F2C1B272611
D4D9B1D0D7ABDCE3BA989B7C0F0C00716B55524824E2DDB7BEC1A43841260007005A653D
D4DDB2CCD5A8A2A97D979E75EEF1D2EDEFD7FFFFF1FDFBEFFFFFF6B0ABA5F9F5ECFFFFF8
FFFFFAFDFFF9FEFFFAFEFFFAFFFFFA6F6C65AFA6A1B3A6A0A4918D614E48BEADA6FFFCF3
FFFFF3EAF1E1DAE7D3596C4ECDDDAED7E9AF44561CCFE1A5DCEEB2D6EAADD1E5A8D3E7AA
CCE0A3DBF1B3DAF0B2D8EEB0D0E5AAB6CE92DCF4BAC9DAA4D1D4A7E2E0B9DDDEBCC5CAAA
7E846AFCFFEDFEFFF1FAFDEA121100030300818260DDE5B6CEDDA2C5DC94D2F1A1C6E894
C9EA99C1E293C9E89ACBEA9ED1EDA3C9E59BBCD68FD0EAA3
D0ECA1C3E199D1F1B0C0E99BBCED80C2F49159814FBADDBCBEDEADCFEDAFCAE49DC6DB98
F9FFD6F4FFDCFBFFEFF9FBEDFFFDF1503E30190A007A7154CDCBA2D2D6A3D7E3A554651F
D0E799CDE897CCE997CAEA97C9EA99C8EB9BC8EA9EC9EA9BCCEC99C5E590CCE89DC9E49F
D0E5AAD1E5B0D5E6B9F5FFDBE5F7CDD5EBBCD0E7B1CDE9ACC5E49EC4E797C7ED96C8E893
7E9044BFCB83CAD7916D7C37455514809550D3EAA4D7F1A7CDE99CD0EC9FCCE89DCBE6A1
CBE5A800180053693BCDE7B7C5EAA7CBE69FD7D799DDD79B909B59C6DB96CCE69FC0DE96
CEF0A6BBDF95CDEDA4CFE39E645E22A49A5FD3D999E4F5B1CEE29DD3E2A1A0A36C4F4718
3C2A02CCB9919C8D62D7D19FD9DFA3D5E6A2CFE99FC4E395C3DD93D5EDA3DDEEAAD1DB9C
9CA065BEC88BCCE7A2CDF1A7C8EDA0D0EFA3CFDC949CA35DE3EAA6CFE09ACBECA5C1EAA4
C3EBACCCEBB2000900D5DDB48F9F78071A00758449616C32030500DAD9BD5F5C4B070500
787A526369396C7148EEF2D122200B07010061582F0A0300696A48C8CEAC070E0071784C
E3EBB8D5DDAA939B6A8D946AEBEFCEFFFFEAFFFFF1FCF9F0DED9D5FFFEFBFFFEFBFFFEFD
F0EFEDFFFFFDF0F0EEF5F5F32E2D290400000700000A00001602011E0A096E5C58FFFCF6
F9F6ED898F830006005A6C526B7A4FCDDBA8536430ECFDC9000A00031300526233DAECBC
D4E5B8C8DAAACCDEAE000C00001100708451B5C996DEEFBBE2E6B4DCDBAD0305006A704E
646A50F5FDE8FEFFF4FFFFF40102000E10002A2D0E7B8459DAECB0C5DF96D0F29EC6EA93
BDE090D5F7AACFEFA4B4D288CBE79CDBF7ACC9E399D6F1A4
CFEBA1D5F3ADC6E9A9B6DF93C8FA8BB7EA83557D49AFD1B0C8E5B5D2ECADCFE59DDBECA8
FCFFD8EDF3D7FCFFF6FFFEF9FFEEE77C695B0F00006C6145C7C29AE0E0AEE3EBAF909D58
D3E599D0E797CFE895CDE897CCE999CCE89BCCE89ECCE89BCAEB94C6E78ECEEB9BCAE69C
CFE5A5CFE4ACD2E6B5F6FFDBDDF0C3C5DBAAC3DFA5CAE9A6C8EA9DC6EE98C7F394D2F599
DFF2A3A3AF67909D57CFDE99C7D796899E59CDE49ED2ECA2D1EDA0C4E093D3EFA4CCE7A2
C9E3A60015005C7146CAE4B4C5E8A6CDE8A1E6E6A8E0DA9EA2AD6BA6BB76CFE9A2DDFBB3
BCE096DCFFB6BDDF95DBF0ABDDD99C666024CAD593CBDF9AD3E7A0C6D290D5D69D7B7140
7461377E68418C7B50E4DCABD5DB9FDFF0AAD0EB9ECAE999ADC87BCAE298C9DA94C3CE8C
898A51727A3FA9C481C6EAA2BAE093DAF9ADD5E29A979D57CDD490D7E8A2C2E39CB7E29B
C0EAAACAEBB20B1B006671465C6D43000C00647435919D5F1215002B270A383320141200
9C9F72B0B7831D23005F613C0601003B341A3F3709756F3D161500797C51050B000E1500
D4DCA1D4DCA1A8AF79989E6EE5E9C6FFFFEAEAE8DBBAB7B28A8484FFFDFFFDF7FBFFFBFF
FFFEFFEFEFF1FFFFFFF9F9F90D0B0C110B0D0800001D0D100E00002410120D0000887D7B
FDFAF5767D750010030114009FAF8ACEDBAF202D020008001A26000008000C1A00000800
6E7B5D9CAB8A00090019290426360F0010003D4F259BA87A2F33000C0C000A0D00121800
11170039402E8B8E85E2E3DDDEDED6010200080B00777F56D3E5ABCCE69DCBEF98C2E891
CBF0A2BADB94CEEEA5D7F5ADCFEBA1CCE89DC3DE91C3DE8F
CCEAA0C2E299C9E9A8C2EB9FBFF28DC3FB9A74A9716D9D739DC795CAEBB2D8ECAFCCD6A1
FFFFDFFFFFECF2F8EEFFFFFBFFFAF8C3ACA616050062573BB5AD86D6D6A2D1D799AFBA76
D4E49BD1E699D0E69BCFE79BCFE79DCFE79DCFE79DCDE89BCCEA94C8E992D0F09DCCE89D
CBE4A2CAE2A4D0E7AFF5FFD6E8FFCACCE5ACC8E4A7CBECA7C9EEA0C8F09AC1E990C5E791
CCDD96E5F0AECEDA9ADCEBAA96A6675A6D2BE0F5B0C3DA92D3EFA4B7D68AD5F3ABCFEAA7
C8E1A7000D006F8255C9DFAECAEAA9C5E39BDFE8A7D1D394D4DA9AA5B26DC8DE96C7E59B
CCF1A4BFE59AC7E79ECEE39ED8DE9E7A7A3E555B1DD9E5A3C9DD96E2F3AFD2D79D2E2800
49360C947E55BFB285DCDBA5DEE8ABCADB95BFD1877087396B83376F873BA9BD75ADB977
E1E6ACD1DB9F92A867BFDD97D9F7AFC5DC94D6E19C999E5B959F5ACEDF99CCEEA4CCF4AD
BEE7A3C1E4A4BFD29B63713C3A4E19B6CE92CEE49BDBECA6989F69706E472D280AC1BD9A
D7D9A7DDE7AB97A66D62703D8B936CD8D9B15A501DE2D9A0BDBD877D844ED7E1A59DA96B
D4E3A2DCEAACA4AF75ABB382F8FCD7F1F1D9FFFFF3D2CAC7E9E3E7FEF7FFFFFCFFFFFAFF
FFFCFFFFFBFFFFFDFF727071090708080403A79E9FFFFCFDCFBFC29C8C8F2011140E0405
DBDAD8949B94021207000700657453D6E2BA29350F000800666F50D0D9BEA2AA92000600
2C341DAEB89F67715898A589DFECCE6D7C5B0009000008006C6B3D2D2B00D1D2A8818260
15150001020072756ACFD4CD0001000301000700000807009AA674C9E2A0CCEF9FC0E595
CEF0A6BFDE9ACCEAA4C8E39CC1DB92D3EBA1D7EDA4D2E89D
CBEE9CD2F5A5BEDE95C3E99EBBEF9DB5F3A691DC9B1B662E70B37EBDEEBFD8F1CAC8CFB0
FFFFECFBFCECF8FFF5FCFFFAFFF7FEF5DEE41504004C4227989369DCDFA6D3DC9BCFDC96
D3E29DCFE09CDBEEACCBDE9CE3F7B2D0E49DD3E49DD4EB9DCBE898C8E998CBEC9DCDECA0
CAE89EC9E79FD6F4AEE7FFC1D9F6B4CFECA9C9E8A4CCEBA5C7E8A1C0E298C3E59BCFEDA7
D7E9AFCBD8A3DBE5B0D8E3AB869459809052D0E3A1CCE39DD7F2ABC4E49BC2E19DCFECAC
CFE6AE000E00616C41CDDDACC7E6A3D1F3A9C3E197D2E39DE5E1A2E0DB9BAEBB75D2EEA3
BFE697CDF3A6D3EDA6CCE19CD8EFAB8E9A5C69622BD8D399CCE29AD8F4AAC5D898676731
261100776138BBB787CDD69DCADD9DD7E6A18A8D48979D55B2C4788EA65AA4BA71D6EAA5
D1DFA1D5E3A69AAA6BA3B173DDE9A9DFEAA8D2D996B5BF7A55651EC8DE95D0EEA4C4E69A
C2E49ADAF8B2C9E09CCCE39F8AA45ADDFCACB1D37FCBE896DFEEA9DEE2A54C450FE1DAA4
E4E8ABCDE19CCCF0A6B4DC93D1F0ACDBE9AB5D5316E6D89BE3E5A4CFDB99CFE39EDAF1AB
C7E29DCAE4A3CBDEA6919D6DF2F3D1FFF9E3F3E9DFE0D5D3FFF6FCFFFCFFF7F7FFFEFCFF
FFF4FFFFFAFFFFFAFD96928F05060062655CAEB1AA8687825F595B928C9050474C040002
DDDBDE767B77000400020F006A7759C7D5B1606B49000600444A2E5E62476D7158000400
2E301AE6EAD3C8CDB6A0A890717B632F3C220007000C1200BDB795948A67797550464121
0B000008000069715CCFDACA0002000E05003E231C220B00737351D2E4B2A7C58788A865
CDE8A5D4EBA7D7ECA9CFE2A0CBDC98D5E4A1D1DD9BB7C381
BEE592CCF29FC5E599D2F3ACC5F2ADB1ECA889D6921D6F2F2B7540A1DCB0AFCDB1DEEAD6
FFFFF3F9F9EDF0F8EBFEFFFBFFF9FFFEE8F4615049291F068B885DF7FBC0DFE8A5D3E09A
4F5E1BBBCB8ACCDEA0D6E8AABFCF90D6E7A3D1E399CDE295CCE89BC8E99ACBEB9FCCECA0
C7E79BC4E498CAEA9FD4F4A9CFEFA6C8E89FC5E49EC8E7A1C9E8A4CDECA8DDFCB9F4FFD1
F4FFD4FBFFDAFCFFD6FEFFD3B9C48CC0CE91D4E7A5CCE5A1C6E49EC5E69FCBEBA8CFEDAD
C9E0A8000D006B7447DAE6B4CAE4A3BFE399C2EB9DDBF5ACE9E4A4E3D89A95A159C5E194
C3EC9DC5EC9DCCE39DCADF9AC6E3A0A8BB7B534612AA9D68D7EDA5C4E499CEE4A3DCE1A9
301B00664F26989866D8E7ACD8EEADD4E39E93904D9B9853DEEEA3D3EEA1CDE59BD1E8A2
D2E6A7D1E0A5EEF9BDD3DBA0D4D89DE4E8ADD1D799BFCA884D5E18D9F1A7BDD98ECDECA0
D5F4A8B0CC81DBF2AAD6EEA486A351B3D37EE5FFB2C2E490D5EA9DD8DF996E6627EAE2A3
DCE39FC9E197C5F4A3BAEE9BCAF3A4D1E59D4E4303CCBC7EE0E6A0D3E59BC9E399CDEBA1
C6E7A0CBEBA8C5DEA48F9F6EF0F2CDFFFFE5D7C9BEFDEFECFFFBFFFFFCFFF6F8FFFEFEFF
FFFAFFFFF6FEFFF6F574716A070B00888F7F29312270766C80817C010000030002070508
000000ACAEAB030A020005007A8769CBD7B3D9E4C2DAE4C219200174795B151800060900
02040093957D000400111600020A00353F26C1CBB2D2D6BDA8A1840A0100090700181400
4C3D20C1B79CDFE7CFD0DFC8161A0B0A0000916969522B260A0000818C647B925ECCE8AB
819756819452A6B977D5E5A4D2E1A0ACB878899354778142
C2EC9ACAF1A0C4E397CEECA4C8E8A5BFE9A7B0EBA96EB0724487516CA779CEF7D5C4DEC5
EBF7E9FEFFFAFEFFFBFFFDFEFFF8FFFFF7FF402F283C3219777449D6D9A0D8E1A0DBE8A2
909F5C8B9B5AB4C688BCCF8FEBFEBCCEE29BCDE297D9F0A2CBE79AC8E99ACAEA9ECCECA0
C9E99DC4E498C4E499C7E79CCAEAA1C7E79EC7E6A0C8E7A1C6E5A1C8E7A3DAF9B5EFFFCC
F5FFD4F9FFD8ECFAC5CCD9A1B1BF84CEDE9FD3E8A5D7F1AAC7E59DC9EAA3CEEFAACCEBA8
C3DCA2000D00677343D2E0ABD4EDABC8E89FC3E89BC8E299DDD999A39E5EADBA72DAF9AB
CCF7A7C6EFA0D1EBA4D8EDA8D0EBA8DAE8AAA69663877743CBDF98C6E49AE1F6B5CCCF98
6750266E572E999967D0DFA4CDE3A2CDDC97B1AE6B918E49D8EA9ED6F2A5CCE69CC5DE9A
DDF3B5B8CA90FCFFD1A3AC75CFD49ECED19AE7ECB2838D4E90A15DC3D991D9F3A9C7E398
CCE89DD3EDA3D9F0A8C9E0989DB56BBFDB8EC9EA9BCAE99BCDE199DEE8A34A4606E0DF9E
D6E19CC6E297C2F1A1C4F5A4C6EC9FCFE09A615519A9995ED3D895D7EBA3C8E298C3E398
CAECA2CFF0ABC4DE9F99AA74E1E6BDFFFFE3C9BDADFFFDF4FFFAFBFFFAFFFBFDFFFFFDFF
FFFAFFFFF3F6D3CAC56B695D000400000500838C77FCFFF396998E010000030000010000
2A2B254A5046000400020E00636E4CC1CBA6CAD4AFCED8B3323C19616846959C7A000600
020900858C6B0006000006003B4425B4BD9E9EA7886C7352757551040500000700A0A57C
A199754B4626515E40A6B69B0003000B0000B88C8DA97C772C1C0540421D8F9D6CD4E9AE
A9BE7D7C914C7388438EA25D8CA05B7E8F4B8D9C59AAB976
C7F2A2C9F0A1C3E197CAE49DC9E09CC9E6A4D5FDBEBAECAF94CE943F7B48B2E6BFBAE2C7
E9FFF1F8FFFDFFFFFFFFF7FFFFF0FEFFF8FF6A5B56201500454219FDFFC9C7D091D5E29D
D4E3A0D5E9A4CFE2A2AABF7E697D383F550DA5BA6FDBF3A5C9E89AC7E899C9E99DCBEB9F
CDEDA1CBEB9FC9E99EC8E89DC9E9A0C8E89FCBEAA4CDECA6C8E7A3C3E29EC7E6A2D1EEAC
CEE6ACD1E4ADDAEBB497A66BC5D596D3E3A2D3E8A3CAE69CD0F0A7C6EAA0C5E9A1CBECA7
C8E5A500120064723DCEDDA6C3D897D9F4ADD3F3A8CBE29AEDEEAC595817CEE398C9EC9C
B9E695BAE595C7E29BCDE29DC8E19FD2DEA0FDE9B75C4B17D7E8A2C5E399C6D99961642D
3D2600553E15A9A977D3E2A7CEE4A3D4E59FDDDC99989852CCE194C4E395C6E599D1ECA7
CBE3A7DBEEB7F8FFD3E0E8B7B4B788959967C1C8948E975ED3E3A4D8EDA8CCE69DCFE99F
C0DA90CCE39BC6DB96495E19ACC17ED6EDA9BED992CFEAA3CEE29BD8E39EF2F5B2959A57
D5E59EC8E79BC2EE9FC1F0A0C4E69CD3E29FA8996284733BB6BD7AD3E9A0CBE79CC0E094
CBEDA1CEF0A6C6E19EAEC287B6BE8FFCFCD8D0CAB2FFFEF3FCF4F2FFFEFFFEFEFFF8F7FF
FFFBFFF8EAE79891877273610E1700051000BDC7ACE2ECD3E7ECD8F4F6E8E7E7DBDDDDD1
E5E7D9636A585E67520007000913000007006F7A50DAE5BB3F4A20041100253207041100
0D19009AA67E929E763D482037421A717C54000700000700C9D0A4868F60051500616F3E
3331080707003E502A9BAE8E0004008D7C72BF8F8DFECDC847311A0D09005E6637CDDCA3
D5EAA9C2D993C5DA95D2E7A2D0E5A0CCE19CD2E6A1D7EBA6
BDE99AC3EC9ECAEA9FD6EDA5D4E3A0CFDE9DD5E9AAC8E6AAB5E2A7548D583E7D50B2EBCA
E4FFFBE0F4F2FFFDFFFFF3FFFFF8FFFFF7FFA89B951B1300605E38FFFFD1DBE5A8D4E3A0
CBDC98C8DC97D6EBA6CCE39DC4DA9250681EEDFFB8B9D485CBEA9CC9E99DC8E89CC8E89C
CBEB9FCEEEA2CDEDA2CBEBA0C7E79EC6E69DC9E9A0CEEEA5D0EFA9CDECA6C9E8A2C9E6A3
C8E2A5CBE3A7D1E5A88FA163C9D998D5E9A4CEE59DC7E398CEEEA3C0E598C1E79CCEF2AA
CBEAA700120063773CD9E8ADCFDFA0E0F5B0CFEBA1C0D68ED8DD9A505713D6EEA2BAE190
C1F09FCFFCABD0F0A7D5ECA6D7ECABD3D99DE0CA99624E1BD7E6A1CAE69CE0F0B1D3D39D
4128006F562EA5A573CDDCA1D6ECABCCDD97E3E4A09FA05AD6ED9FCAEB9CC9E99DD1F0AA
CCE8AEC8DEADF9FFDCE9F2C7D6DBB353552D8C92649CA471D7E6ABD1E6A3CFE69ED5EFA5
D2E9A1D6ECA4A2B36F49591ACEDEA0C9DDA0D3ECABCBE4A0CCE19CDBEAA5CFD9949AA65E
D0E69BC8EB9BC4F1A0BEEA9BC7E59DDAE4A5E8D8A461511D9AA362CBE29ACDECA0C4E498
CAEC9FC8EA9EC9E79FC7DD9D939D68C8CAA2DBD7BAFFFBEBFDF8F4FFFEFFFEFEFFFFFDFF
FFFCFAFFF7EE5C5744A6A98E00070000090053623BDBE7C3D2D9BAC9CDB4F1F3DE010300
000400E5EED1D4E2C1EEFDD6F0F9CEBCC495D6DFB0CBD7A7C9D7A6CFDFAE3B4D1B91A572
C7DBA8D7E9B7C5D6A2CAD8A5CCD8A6D8E2B0CDD5A4D3DDABCCDAA5CCDFA7BED79D9DB279
5359298E9468CBE0B5CAE0BAF9FFE5FFF9EBFFCECAFFDDD7FFFAE3D0C8A4B2B485D3DEA4
D4E9A6CCE69DCFE69ECEE59DC9E098D0E79FD5ECA4CFE69E
BBE59BC2EB9FCBEDA1D3EDA4D7E7A0D4DF9BD3DE9CD0E2A4C7EBAE90C58D4C9061559875
DCFFFFE5FFFFF1F4FFFFF9FFFFF9FFFFFAFFB7ACA83E372461613FE5E8B9E2EBB2D5E4A3
E7F8B4CEE49CCDE39BD9F0A88AA25891A95DBAD284D4EFA0CCEB9FCCECA0C9E99DC6E69A
C6E69ACAEA9ECAEA9FC8E89DCBEBA2C7E79EC4E49BC7E79ECCECA3CEEEA5CCEBA5CAE9A3
CBE8A6D6F0B1C2D898ACC180B4C883D6EAA3CBE399D0ECA1C6E89BC1E899C5EEA0CCF2A7
C1E29D000F005B7133D3E5A7E2F1B0C2D18EAAC078B2C67FB1BC7796A35DCAE99BC7F2A0
B3E492C3F2A1BFE197CAE19BD4E4A5D3D49A5E4616796532D3E09BD6F0A7D0E0A1CBCA94
2F1300695028929260D8EAAECEE7A5C5D992E0E39EA8AB64D7EFA1C3E696C2E497C3E49F
F1FFD6ECFFD4F1FFD8F0FAD7E1E6C6D7D8B8AFB38ECED6A7D0DFA6C6DB9ADFF6AEC5DD93
D9EFA7C1D58E8D9C5BCDDB9EDDEAB2CFDEA5D3E7AACDE3A2C3D893B9CD8642540AD4E99C
C8E595C6EC99C8F3A1C0E99AD0EAA3D9E2A3E4D4A05C4F1A99A565C5E099CEECA2C9E99D
CAED9DC4E699CCEAA0D4EBA7A9B87FB2BA8BEAEBCBFFFFECFFFFF6FBF7F8F3F0F9FFFDFF
FDF2ECD1C8B767654CCFD5B34C592E5F6F40000A00728255A4AF87D0D8B3A4A989000500
080F00D9E3BEC4D3AAD3E3B4E9F1C0969D6AD1D9A6DBE8B2E2F3BDD6EBB2CCE4AACBE5A8
D9F3B6D9F1B5C4D89BDBEDB1E5F3B8CED79EDDE5ACDDE6ADD2E4A8C5DE9DD5F2B0C5DE9D
CCD59EA1A976D5EDBBC1DBAEFCFFE6FFF9E6E4B3ACFFE6DBFFE8D0F0E6C2A7A676C9D49A
D0E5A2C4E096CDE79ED6F2A8D0ECA2C8E49AC7E399C3DF95
C6EAA4C6ECA3C5EB9EC3E598CFE79BD7E79EDBE29EDFEBA9D8F2B5B8E5AEADF1C019633E
A8E7D4E0FFFFEFFEFFFEFCFFF9F1FFFFFBFFFEF6F3171403050600F4F9D0CED8A3CBD99C
C8D897C0D68EDCF2AA90A85E9CB66CDEF9ACC7E293D2EF9FCAE99DCDEDA1CCECA0C7E79B
C5E599C9E99DC9E99EC6E69BCCECA1C9E99EC6E69BC4E499C5E59AC7E79CC8E89FC7E79E
BEDD99D0EDAAC9E29EDFF6B0C3D991D2E89FCFE79DC9E598C6E999C8EFA0C6EFA0C1EA9C
C1E59B0321006A8341CCDF9FCFDB9B9BA66491A25CD0E49DC8D891D3E9A0C1E696BDEA97
C0F4A1C1F09FC6EAA0D6F0A9E0ECAEE9E7AE4A3202A5915EC7D48FDBF2AADBE9ABA4A36D
583C14785C359C9C6ACEE0A4CFE8A6D6ECA4E7EDA7B3B971D0EB9CC0E595C9EEA0C4E8A2
D9F6BEE0F7CBF7FFE3CFDABCEBEFD6F1F3DBF4F7D8E7EEC5D5E2ACE6F9B9C9DF97C5DD91
CEE49B53641EAFBB7BE3EEB2CDD8A0D9E6AED8E7ACBACD8D94A96493A960D0E89AC7E492
C7E993C3EB95C6F09CC5E898D6EAA3D5DA9AA59561897E48B4C382C8E69EC9E99ECBEB9F
CAED9DC4E498CEECA2D0E9A5D1E3A7C5D19FF5F9D6FFFFEAFFFFF4FEF9F6F7F2F8FFFDFF
FFFBF14E4631FFFFE3F8FFD64B5926D0E3AB84975F1829000F1B00091200000700454C22
5E693ECFDDACDBEDB9E2F3BCB2BB84848951CED79ED9E7AAC0D497CDE6A5CBE5A4C9E6A3
B6D48ECEECA6D3EDA6C7DC97CDDC97E5F0ACD5DC99DAE3A2CDDD9CE0F9B5C8E6A0C1DA96
E0EAAD899259C6DFA8CEE8B8FAFFE1FFFCE2DEB2A5E7B7A9E1C9AD8580589EA270D0DEA1
DBF2ACC7E69AC8E499CAE99DC3E296C2E195CBEB9FD1F1A5
CAE7A4CAEBA4C3EE9FBDE896CAED9BD3EE9DD1DD93D5E09CCBDFA2C0E5AFBBF9C858A07B
7EC1AFC9FCFDE9FFFFF4FFFFFEFDFFFFFDFFFFFEFB010200010300A7AD89DFEBBBD2E1A8
D0E3A3D8EDA8869C5388A054D6F1A4C9E497CBE79ACCEB9DC6E599CCECA0CFEFA3CAEA9E
C8E89CCBEB9FCBEBA0C8E89DC5E59AC9E99ECCECA1CAEA9FC8E89DC9E99ECAEA9FCAEA9F
CCEDA6C7E6A0C4DF98CBE59CAFC77DA6BE74D4ECA0CDE99CC9EC9CCAF1A0C0E99ABAE394
D6FBAE33550B92AD68D6EBA8DBE6A49FA86785924DD9EAA4D3E9A0C8E499D1F8A7C0F09C
C9FAA8B3E291C7EBA1D2ECA5D2DA9EDDD69F775F2FA08F5BE2EFAAC0D78FCFDD9F9E9D67
361A00563D15A8A876CFE1A5CCE5A3D3E9A1D0D690A0A85FC3DE8FC4EB9AD2F9AABEE29C
C1E0A7D3EDC0F1FFE0F9FFECFFFFEFEEEFDDFFFFEAE2E8C4D9E6B1B9CC8CE3F9B0D4ECA0
CEE39852631DD5E1A3D4DDA4E2EDB3CCDA9FD1DFA295A564485C15CAE296D3F09ECDEF99
C9F097C2EA92C4EA95C7E494D7E7A0D2D493685D25BDB77DCEE19FCDEDA4C4E49BCAEA9F
CCECA0C6E69BCFEAA3C8E19FD7EBB0D6E4B3EDF5D0F6F8E0FFFCF0FFFEFAFFFCFFFFFCFB
ADA495797359ECEEC9E2EBBCD9EAB3D0E4A5C8DD9C93A76882915658652F6A7440A3AD79
D8E5B0CDDEA7CEE4A6C8DA9C8D975A949C60D8E4A4CCDC9BDCF3AFC6E19CD1EFA7C6E69D
D0F0A5C7E69ACAE69BCFE79B889A50B7C57ADEE89FD0DA93D9E8A3C3D991D6F0A7D2E8A0
B7C07FBDC589C6E0A3CFEAB5FBFFDDFFFFE1C49E8BD6AB98F0DDBD9D9C7089935ED7EBAC
C5DF98C6E599CFEEA2CEEDA1C7E79BCDEDA1CFF1A4C3E598
D4E9A8C1DF99CCF8A9AEE28DBFF198CEF6A0D1E89ACEDE97C9DB9DDAF7C1C2F3C690CDAC
438373629D9BDAFFFFE7FFFFF3FBFFFAFBFFFEFFFD6C6F660B1000636C4DD7E2B8CEDCA7
D3E5A7AFC47FAAC077D5ED9FCBE697CBE699C3DF92C9E89CCCEB9FCBEBA0CBEBA0CCECA1
CCECA0CBEB9FC8E89CC5E599C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC8EA9E
CAEFA2C5E79DD4F2A8C5DF96B1C97F839B4FD0E89CCDE99CCEF1A1C7EE9DB8E290C9F2A3
C1E79ACBF0A3C4E29ACFE6A0D9E4A28F9555C1CA87DBEAA5D4EEA4C5E79AC2EC9AC3F09D
BEED9CC0ED9CC1E59BDDF4AED8DEA2726932715B2A9B8E59D9E8A3CDE79ED6E6A7888751
987C545D441C9C9C6AD4E8ABCEE9A6D1E8A0DFE59F979F56C1DE8ECEF5A4C7EE9FC2E7A1
CAE9B0CAE4B7F7FFE6F9FFEDF1F3E5FDFEF0FFFFEDE7EDCBD6E2B0D8EBABCBE196D3EC9B
899E53D7E8A2D9E5A7D9E4A8D7E5A7CFDE9DCFDE9B95A45FCEE398D3EB9DCBEB98C5EB94
CFF59EBBE18ABCDC89D8EFA1CDD991E5E6A4615B1DDEDEA0D0E5A0CCECA3D0F0A7C2E299
D2F0A8C8E39ECDE8A5D2EAACCCE1A9D8E8BBE5EFCCFFFFEAFFFFF1FDF6F0FFFBFD897B7A
615847EBE6C9DFE1BAD0DAA8CEE0A4CCE39FDFF6B0CDE49ED3E6A4D8E6A8D7E2A8C9D79C
768648A4B978C9E29ED1E6A18D9957BEC987CDDC99D2E6A1D2E9A1CAE69CCDEDA1C6E89B
BDE090D9FAA9BCD98991AA5999AE5F849547DCE99ADAE599DFEBA3CBD892CDE199D6E7A0
8F9451DAE0A0C6DF9ED3EFB5F9FFDAFFFBD6E5C3AAE8C4AADED5AE9DA773C5DA9FCBE6A3
D0ECA2C5E196C7E69ACFEEA2CCECA0B8D88CC9EB9ED0F2A5
D7E7A8CBE4A0B8E495CFFFAFB1E98EBCED94BDDC8CD9EFA7CCDEA0CCE4B2E9FFE6DFFFF4
73AD9F46817F87B8C6DCFFFFEFFFFFF9FFFFECF4F6B7BDB9555D503A442CD2DEBACFDFB0
D4E6AA7F934ED7EDA2CDE597BCD486E1FCAFCDE79DC9E59BC7E59BC6E69BC5E59AC4E499
C5E599C7E79BCBEB9FCEEEA2C9E99DC9E99DC9E99DC9E99DC9E99DC9EA9BC9E99DC8EA9D
C7EC9EC2E79ACFEDA3CAE49AC8E096A5BB70C8E094CFEB9EC3E495CDF4A3C6F09EC8F1A2
B8DF90C7EC9FC5E59ACEE59DD1DD9B989E5EA1A865CFDE99C4E397CAF1A2BFE997C5F09E
C3EE9EBCE596DCFFB6B4CB85EEEFB5B8AD7752400EB3AC75D4E8A1C3DF95E2F2B3DADAA4
7259306C552CA6A876C8DC9FCDE8A5CBE29ADCE29C9BA35ACAE797C9F09FC1E899C4EAA1
C1E0A4D3EBBBF7FFE6F5FFE7FFFFF4FFFFF4F2F3E1EFF4D4CFDBA9CEE19FD8EFA1CBE491
9EB567D0E19ADBE7A9D0DB9FD8E9A5D1E29CCEDD989AA761C9DB91CEE69ACAEB9AC9EF9C
B4DA87E2FFB2DFF7ABC8D88F8E95519194515E5E1ED3DC99CAE49DC6E89ECBEAA4BFDD97
D1ECA9C6DEA0CAE2A8CEE2ADC2D5A7DCECC5D7E2C2DCE1CAFBF8E9FFFCF6F6E6E662504C
827765FFFFE2D3D8AFD4E1ACD8ECADC5DF98C7E197CAE298CBDF98D9EAA6CFDD9FBCCA8C
1929007287426A843BC6E0969BAC66CDDD96DAEBA5D3E9A0CCE49AC7E396D0EFA1C8E99A
CDEE9DD0EF9F9FBC6A77903FC1D888A4B766A5B666D7E397CAD48DD5DF9AE5F5ACBBC880
969954E0E7A4D6EFADBCDA9CE3F5C3EDEBC4E8CAAEE8CBADE4E1B68C9D66BDDA9AC4E59E
C5E399D5F1A6CAE69BCCEB9FCFEEA2D4F4A8C0E094CBEB9F
C7D796D5EFA8CCF5A7C4F6A1B0E68EC5F7A0D1F6A6C4DF98E3F7BCBDD0A2E7FFE1E2FFF1
C9F7ECAEE0E162949D628C98CAE1E9F3FFFFF5FFFFAAB6B6727D7700060048573AECFBD0
C8D9A29EB16FD6EAA2D0E799DBF1A6BBD389CDE49CD2ECA5CBE99FCBEBA0CBEBA0C8E89D
C5E599C5E599C9E99DCDEDA1C9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9EA99C9EA9BC8EB9B
C6EB9DC4E99BC9E89CCCE69CDBF1A8C4DA91B0C67DCCE69CC6E69AC6EB9DC1E899C6EFA0
C4EB9CD0F2A5CBEB9FCFE9A0CBDA97B6BF7E949B58D0DF9AC0E295CAF5A5BCE694CCF3A2
C7EC9EC9EEA0BFE197D5ECA6DDDCA3BAAF795E511D96955CD7EDA5BDDB91CDE0A0DEE1AA
4E370D6A542BA4A875CCE0A3CFEAA7C9E098DAE09A9CA45BD2ED9EC6ED9CBEE596CAEEA6
C6E4A4D5EDB9F7FFE2EBF3DCFFFFF4FFFFF6FCFDEDF1F6D6CDDBA6D3E8A3D8F19EC9E38C
A4BB69D1E59DD8E6A8D2E2A3D3E9A0D3E99ED2E299ABB872CBDA95CEE49CC7E79EC7EBA1
CEEFA8C3DE995C6D296069287274359BA05EA7B06DDBECA6C6E49AC5E79DCCE9A6C5DF9E
DDF2B7D5E7B3D8EABAD7E9BFD3E5BFDEEFCFD9E6CCF0F5E1FEFBECF6E9E1BCA7A2937F78
FFFEECFDF9DC787D5596A36ED2E6A7D8F2A9D1EC9FD4EFA2DCF2A9C5D690B9C885B8C985
D6EAA5C6DD95C4E0958BA75AC7DD94D4E99ECDE39ACFE79BCCE79AC7E295CEEA9DC6E393
D2EF9F6D8A3ABDD889E1FCABDAF3A2CCE393BCD1828E9E53A4AE6996A05BB3C37A9FAC64
B7BA75CED591CDE8A1CAE9A6D6EBB3CFD0A4BFA584C7AD8CD9D8AA879B60C7E6A3CDF1A9
CEEAA0D3EDA4CAE49BD2EEA4B6D288C4E096E6FFB8BEDC92
DBF0ABBCD68DBEE093C6ED9CC6F19FC3ED9BC1E699D2EFACC5DDA3C9DFB1F2FFEAEEFFF6
E9FFFFDEFFFF577F871339448DA8AFB4C7CDE6F9FFF2FFFFF4FFFF000600000700C5D5B0
C9DAA68B9E5ECCE098CFE497D6EBA0D0E69DDFF4B1C6DD99C9E79FCAEA9FCCECA1CCECA1
CBEB9FC9E99DC6E69AC5E599C9EA9BC9EA9BC9EA9BC9EA99C9EA99C9EA99C9EA99C8EB99
C8ED9DC9EEA0C8E79BC8E298D9EFA6D0E49C97AB63C9E197CDECA0C1E396BDE495CDF4A5
CCF1A3C5E79AC4E498D3EDA3CEDF9BDAE5A3A5AC69D3E29DC9EEA0C2EF9EBFE494D1F2A3
C5E498D1F0A4C4E49BD4E9A4D6D49B9A8F59615A24A0A66AC7E198CAEA9FD4EAA9D8DDA5
947F548771489A9E6BC9DFA1CEEBA8CEE59DDCE29C989E56C6E192C6EB9BC4E99BCFF1A7
D2F0AAC8E0A6F9FFDFDCE2C8D6D6CAF0EDE4FFFFF1E9EECED0DFA8DDF3AAC6E089C0DD81
94AD59D6ECA1CFDFA0D9EEADC9E598D2ED9CD6E69DC7D28ED7E3A3D6E8AACBE7AAC8E7AB
D3F1B5C7DCA3646B37CBCB95EAE9B1E1E5A8D6E6A5CDE7A0C7E79CC7E99FD2EDAAD2E7AC
F1FFCEEEFDD2F2FFDCF1FFE1F2FFE8ECFBE4EAF6E2FEFFF3FFFFF3D8C7BF957A73E4CCC2
FFF3E387856C898F69CDDBA8DFF5B5C2DE94BEDA8DCBE699BBD188A3B76F475814CFE09C
CFE39CD4ECA2C7E398D4F3A5DAF5A8CCE79AC1DC8FD3EEA1D2EDA0C6DE92D3EB9FD6EEA2
D3EB9F8DA559C7DF93CCE79AC6E192C9E495CCE798CFE59A93A05B4A57124D61197C8E44
E3E9A3E5EFA8CBE9A1CAEBA6C8DDA4E0E2B3D6BC99F9DDB8E9E9B78EA064BDDC98C9EBA1
C8E29BCAE199C6DD95D2E9A1E0F7AFC9E098CCE69DCFE9A0
CEECA2C8E499DDF5ABCFE59AD5EBA0E7FEB6C3DE99CFECACDCF7C0E9FFD6F5FFECEFFFF0
EEFFFDF0FFFFE6FEFFEBFFFF405B623651588DA6ADE9FFFFF1FFFF99AAA414251331401F
D6E6B7E2F4B66B7C366D7F35D1E29BDAEEA7DDF0B0CADF9EC8E39CC4E499C3E398C7E79C
CBEB9FCCECA0C9E99DC6E69AC9EA9BC9EA9BC9EA99C9EA99C9EA99C9EB97C9EB97C8EB99
C6EB9BCAEFA1CBE99FC9E098D1E59ED6E7A196A761CCE29AC9E59BC8E89DCDF2A5CBF0A3
C4E99CBADC90C2E296CFEBA0D1E6A1DEEDAAA5AC69B6C580CFF6A7B7E695C7EA9ACEE99C
D5EBA2C7DF95C5E39BE8FDB89E9961423701F0EFB7A6B274CEECA2CDEFA3B7D08E9CA46B
7B683D6B582E8B925ED8EEB0CCE9A6D2E9A1DCE29C949A52ABC375C6E999CCEEA1CDEDA2
D3EFA4C4D998EBF8CAC8CDAFCAC8BBCECCC0F2F3E1E7EDCBCEDDA4D9EFA4BEDB81A8C568
98B45DCDE597C9DE9BD4EDA9C3E694CCEE9ACDDE97D7E1A2DEE7B0E8F4C2DFF7C7DBF6C9
E7FED4D4E0BA787650EAE2BBDBD7A8C2C791CCE2A2CFF0A9C8EA9EC7E79CD1EAA9D6E9B2
FBFFDDFCFFE4FBFFEDF9FFF3F7FFF8F8FFFAF4FEF3FFFFF6FFF7EEF2DED5997B73E9CDC2
FFFCEF282611AEB492D4E1B3C7DD9FCBE69FDEFAAFCBE79A6D853BB1C57DE5F6B2C4D893
C8DE96D1EBA1CFEEA2C6E798C5E697C7E899CBEA9CD8F4A7D2EAA0CCE299D7EBA3C9DA93
889952BDD189D6ECA3C9E197E1FDB3CBE99FB7D78CD3EFA5D2E7A4CFE2A0D4EEA5CFE79D
E0ECA4CDDA94BADA8FC9EDA7CFE4A9DCDBABA48861EED0AAE8E2B0B7C588CDE6A2C9E49D
D4E9A4CFE39EDAEEA9708540516621E5FAB5C4D994D0E5A0
C4EB9CCDEC9ED0E097515812909350ABB171CFDFA0CCE5ABDAF8C4ECFFDFF4FFEBF9FFF6
FBFFFFFBFFFFF7FDFFF0FEFFEBFFFF607E8656737BE4FFFFEEFFFFE0F2F2000600000800
CBDBAED2E4A8D5E6A0A2B46A7D8E478C9D59728244E1F5B6D1ECA5CBEBA0C7E79CC6E69B
C8E89CCAEA9ECAEA9EC9EA9BC9EA9BC9EA99C9EA99C9EA99C9EB97C9EB97C9EB97C8EB99
C5EA9AC7E99CCFEBA1CDE49CD1E29CDBEAA5A3B26DBDD18ACCE69DCAE89ECAECA0BBE093
C9EEA1D1F3A7D6F5A9C9E59AD1E8A2CDDE9A979E5B8E9D58C8F1A2B5E493CFF0A1C9DF94
D7E7A0CCDD96D7F2ABBFD38E57521A5D521CDBDEA5D7EAAAC8EA9ECAEFA2D0EBA8D4DDA4
7C693E7360368F9662CEE4A6C8E5A2D2E8A0DEE19CA2A55E91A85AC6E798CEEEA2C8E79B
CDE899D0E49DDAE6B4BABF9FF4F2E3C6C2B7C1C0ACEAF0CCD1E0A5CFE696D2EF9290B04F
C0DF82C2DD8CD4EBA7CBE6A1C3EA97C6EC97B8CC85D7E1A5DBE1B3F7FFD8F5FFE6F4FFEC
F0FFE6C1C6AF897E68E7D7BEE3DBB7DFE5B7D3EFB4B9E19BC8EDA0C6E49ACEE4A4D0E1AD
F9FFDEFDFFEBFCFFF4FAFFFAF5FFFEF8FFFFF9FFFFFBFCF6FFF8F2FFEFE7A7857BD5B7AC
FFF2E7030200E5ECCBDDEDC0BFD79BD2EDA8C4E29884A053C6DE94C6DC94CEE29DD2E6A1
DCF1ACC3DD94C1E094CAED9DC1E696CAEF9FC9EA9BC9E598CDE59BDDF1A9CBDB947F8C47
99A661C6D592D6EAA5CEE59FBFDA95C1E09AD7FBB3BDE199CBE8A5D2EDAAC6E89EC7E59B
DAEAA3DEEFA8C7E99DC1E59DD5EBADD1D19F694923BB9872BCB27FBBC387DAEEA9D5EBA3
CBDF9AD8E9A582934FDDEEAA8C9D59738440647531D1E29E
BAEA96BDE090AFB670A49A5CFAE7ADB0A36CB7BC84C9E0A8C1E1AFDDFDD4F4FFEDF8FFF1
FEFAF9FFFBFFFFFAFFF9FBFFEDFFFFD6F9FF43636EC1DDE8EDFFFFEAFDFF718278000800
67764BCCDBA2D2E19EE0F0A7D7E7A0A1B06D5E6C31A0B276C0DB96C4E499CBEBA0CDEDA2
CAEA9EC7E79BC7E899C9EA9BC9EA9BC9EA99C9EA99C9EB97C9EB97C9EB97C9EB95C8EB97
C9EE9EC0E295CFEBA1D3EAA2D1E29ED6E5A2A3B26F869A55D5ECA6C4DF98C5E59CBEE096
CAECA0BBDD91C6E599CAE69BCCE69FCADE99A5AE6B91A05BC4EF9FB8E796D0EFA1CEE096
D9E49FD7E7A0BFD992D7EBA6666129584F18E2EAAFC6DF9DCCF1A4C1E79AC7E4A1CED99F
5B4A1E5E4D22919864D2E8AAC9E6A3CDE39BE0E39EC1C47D889F51C8E799CDECA0C8E497
CDE695D9EBA1D6E0ABB0B491FFFFEFDBD7CBB7B6A1D0D6B0D6E6A8CDE693D9F99884A741
D7F99BC4E18DDAF1ADC7E59FC5F19CC0EA96A7BC79D7E0ABDADCB5FEFFE5F7FFF1F5FFF6
F7FFF6B3B3A9C9B8B0EDDACBEEE2C8E4EBC2D5F6BFC4EEACCDF3A6C9E79DCCE2A2D0DEAD
FAFFE0FDFFEFFEFFFBF6FBFEF6FFFFF8FFFFF9FFFFFFFFFDFFFCF6FFF0E6B59185CDADA2
FFF1E6030100CED4B8BCCBA0CCE4AADBF8B596B46A547025D9F3AADBF1A9C1D590D1E5A0
DBF0ABCBE59CD9F7ADC3E598C9F2A3C5EE9FBEE395C2E195CAE199DDEEA8C5D28D6A7533
B3BE7CDCE8A8D3E3A2C9E09CCAE7A4C6EAA4C7EFA8BFE8A2C0E5A0C1E6A1C2ECA2C9EEA1
D1E79EC6DC93C5EB9ECCF2A9C6DC9EEAE8B598754FD0A982AB9967959559CBD692D6E69F
DBEAA7D4E3A28D9C5BCDDC9BD4E3A2B0BF7E213000E4F3B2
BFE695DCFBAD525E16D3D08DE3D99BD4CE929FA76BD4E7AFC9E5B2CDE8BFF0FFE7FCFFF3
FFFEFAFFFBFFFFF7FFFFFCFFECFFFFE6FFFF799BA48FB0B9DCFAFFE5FFFFE8FDF60C1D0A
000700A2AB7ED5DEA7DAE4A7CBD799D5E5A6D5E9ACCAE3A293AF65A7C67AC2E195CFEEA2
CDEBA1C7E59BC8E69ECCEAA2CAE8A0CAE8A0CCE7A0CCE7A0CDE6A2CDE6A2CDE7A0CDE6A2
D6F0B1BFD99CD1E6ABD7E9AFD1DEA6CED99F97A2664F5F20D3E8A5C1DA96D6F4AED5F4AE
B3D48F6C8C498DAC69CEEBA9C7E59DD8EFA7C8D590B0C17ACCF1A3C0E99AD0EAA0D4E59E
D6E39ED3E29DD5ECA6CBDE9CE2E2A655531AD5DFA2CFE6A2C4E99CC3E89BD5F0ADD1DAA1
7E714468592E949866D0E2A8CFE8A6CAE098DFE9A2D8E49A8AA254CBEA9CCEEAA0CAE69B
CAE596CCE49AD3E2A9A4AB82FEFCE3F0EBD7CECDB1A9AB84D6E4A9D0E69BCCE98F80A243
CDEE93C6E691D0ECA1C7E69AC9F19BC5E896A2B774DBE5B0D9DFB9FCFFEAF7FFF3F3FFF6
FBFFFDA2A19FFCECECFFF6EFFFFEEDF9FEE0EEFFE0EDFFDAD9F7B9D2EAAED1E3B1D3DFB9
FEFFECFFFFF4FEFFFDFCFFFFF9FFFFF9FFFFFCFFFFF8F7F5FFFCF6FFF9F1C8A89DB5978C
D6C8BF322E22FCFFEAE8F8D1D6EEBAB7D49490AB66C7E198D4EBA3B6CD85E9FFBCC2DD96
CCE7A0CCE89EC4E096D0EFA3C3E898BEE592CAEB9AD9F6A6C8E094C4D890CEDD98ABB873
CDD997D0DF9ED5E5A4D6EBAACCE5A3CBE8A5C9E8A5C7EAA6CCEFABC6EBA5C6F0A6BBE196
CDE99FC8E299D2F6ACBDDE97D4E6A8DBDAA4725529A07F54A497629F9F63E0E9A6D6E39E
D1DD9B97A363576323D2DE9EDBE7A7D8E4A4CAD998576625
CCDB98DDEEA8677F33CFEC9CCAE795CAE5968FA35BD0E0A1D2DFAACCD9AEF9FFE8FBFFF1
FEFFF8FFFEFDFFF3FAFFFCFFF4FFFFE9FFFFABCED27EA6A8D6FFFFDEFFFFEAFFFF3B4F46
000300686753FDF9DCE2E2BCF7FFCFC1D69DC0E3A1D2F8AFCDEC9EC8E392C9E495C9E399
CDE8A1CFEAA7CAE2A4D4ECB2C7DBA6CDE1AED7E9B9E3F0C4EAF5CBEBF6CCEBF3CCEAF2CD
E3EACBF4FAE0E6ECD0E6EBCDF7FDDBF2F9D08C9463707B43D5E5A7C7DC9BCEE7A5CBE8A8
CAE7AD000F00234216C7E5B3C0E19CD2F1A3D6ECA191A55DCCE49AC8DF97E4F8B3CDDE9A
D4E7A5CEE3A0C8E19DDAEFACD2DE9E384100F4FFBDCFE09AC9E89CC9E99ED2E5A5969E65
534B1D5C5124A39F70DCE1ABD1E1A2D4EBA5DAF2A8C5E19487A658C7E69ACCE69DD0EBA4
C7E99FC8E9A2D1E9ADC3D19EFFFFDAF5F3CDCECAA56B6940D3DAA6E3F1B4C3D99186A353
CCEE98CCF096CAED93C8E990CDE692CCE1927F934ED9EBB1D6E7BAF7FFE6F2FFEAF8FFF6
F6FDF6B2B2B0FCF6F6FFFBF8FFFCF3F8FCEDF8FFEFF7FFECE2F0CFDAE5C5D5DFC4DFE7D2
F1F7E9FCFFF8FCFFFDFBFFFEFCFFFFFEFFFFFFFEFCFFFEFAFFF8F2FFF3EBC4B0A5B8A499
F6E5DE070000FCFFEDE1F5D2D6F0C1CDE8B17E9456D6EBA8CEE49CCBE79CC5EA9CC2EB9C
C4ED9ECAECA0CEE59DCAE095CFE894D3F096C8E28BD6F29DCCE894C7E29197B263CFE79B
CFE79DCFE59DD8ECA7D4E4A3D8E7A6D1DD9DE2ECAFD2E1A0C9E29EC7E6A0C8EAA0CAECA2
CCEAA2CEE9A2CDE8A1CFE6A0D8E4A4D4D59991884FB4AB7299975C969C5CDFEBA9D4E09E
D8E2A3A1AA6B424C0DD6E0A1D5E1A1D4E3A2CFDF9E7E8E4D
E2E6A9D4E09E89A85CBCE893C4F29AD4FEA8BED688BFCC87DADFA7E5EBBBF4FFDAF6FFE6
EEFBE7F5FBEFFFFEFAFDFBFCDEEDF0EBFFFFE4FFFF406C6B588986E0FFFFDEFEFDE3F7F6
000300130F06E8DFD0FFFFE6F7FFD8DDF4C0CBF3B4ABD58DD0ECA17A9045D4EAA1D0E7A1
CAE0A0CDE2A9D1E5B2C6D7AAD4E4BDDBE9C6E6F1D1F3F9DDFBFFE6FFFFECFFFFEDFFFFEF
FFFEF2FFFFF6FDFBEFFCFAEDFEFFEBF4F7DAA3AA818D9765D3E1A6D0E3A3CBE1A0CEE8A7
CCE9AF617F4D8AA97FC8E8B7D4F5B0BEDF90C7E29594AA61A3B46DDAEBA5C8D995DDF2AD
CFE6A2C9E29ECDE6A2CEE59FD2E6A154601EB5BB7BD7E49FD1EBA1D5F1A7BFCF90E4E9B1
40390B5E552A9A9264E2E2AEE6F1B5B8CF89CFEFA3C8EB9BCDEDA1CCE89DDBF2ACBBD58E
C3E8A2C7ECA7CCE9A9C9DBA1F9FFCDFAF9CBE7E4B9B8B58AA7AB799EA9719BAD6F98B26B
CBEA9CC4E690C8EB91CFEB94D8E89DC4CF8B707E41DAEBB5B9CA9EF7FFE6F4FFEDF9FFF4
F5F6F1A4A0A1FFFDFFFFFDFFFFFFFBFAFBF5FBFFF7FAFFF2FEFFF3FCFFF1F7FBEDF5FBEF
FAFFF8FBFFFBFBFFFDFAFFFBF8FAF7FDFDFBFFFEFBFFFEF8FFFDF6FFFCF3B6A89DDCCBC1
FFF1EDFFFDF4F2F9E7F3FFE8ECFFDDB8D0A0EFFFCAC6D698D4E5A1CEE89EC4EE9CBEEE9A
C0ED9AC5EC9DCEE69CD1E399D8EB9AC6DA85A8BE6B8DA652B0CC78526F1DC2E193C1E092
C4E095C4DE95D3E7A0D3E29FE0EBA9CAD090DDDFA0E5EBABD2E6A1CCE7A0C9E79FC7E79E
C7E79EC8E69ECEE59FD3E4A0D3DE9CDFE4A4565819A2A4658C9151A3AC6BC2D18ED8E7A4
CAD694A8B371909C5ADCEBA8D5E6A2CDE19CDDF2ADC6DD97
D5DB9BC4D390CFEDA3C3EC9EBEE999C4E999CEE49998A35ED2D898E2ECB0D0E1ABD1E7B8
C9DFB9D2E2C7FEFFF1FCFFFAF2FFFFDFFDFFE2FFFF84B0AF507E7CE2FFFFE4FFFFF2FFFF
EEF2F1070200847A6EFFFFEAFEFFE3C9DFB0C3E6AED8FCBEC9DF9F7F8F51DBEDB1DCEDB6
D6E7B3F0FFD4F8FFDFF4FFDFF1FEE0F3FFE6F9FFEBFEFFEFFFFFF1FFFFF1FFFFF3FFFFF4
FFFFF8FFFFFAFFFFF8FFFFF6FFFFF1FCFEE6C8CEAAB0B98AD6E4A9D6E9A7C7DE96D3EEA7
C4E19EBEDE9DD1F3B7BCDEA1C8EAA0BFDE92E8FFB8E3F9B0C7DB93D4E8A0C1D78FD0E79F
CBE59ECAE59ED3EDA6C7DE98D9EAA686914F6B7030D9E2A1C7E197CEEAA0DBEBACCACF97
615A2C50471CB2AA7CD0D09CDAE5A9C6DD97CCEB9FC1E49486A65A829E53C6DB96DEF5AF
C7E8A3CAEEA8CAE4A3BFD195DEE7B2DDDFAED9D8A8D7D9A8545B28505D25798D50ACC583
CEE8A1C9E59ACAE598C9DD96D9E1A6969A685A6034D7DFB8CFD8B9FCFFEDFEFFF4FDFCF7
DAD1D27A6F75FFF7FEFFF8FCFFFDFFFCFBF9FEFFFBFCFFF8FEFFF6FEFFF6FEFFF8FCFFFA
FCFFFBFBFFFCFCFFFFFCFFFFFCFEFDFFFFFDFFFEFBFFFEF8FFFCF6E1D4CB7E7065DFCEC6
FFFBF8FFFEF8FBFFF3F0FFE7F2FFE4D8EEC08A9664DEE9AFD9E5A5D2E8A0C7EC9EC1EE9B
BFEC99C3EA99CDE89BD5E69FCEDF9899AA63A0B46CCFE79DBCD68DCEEAA0C3E197DCFAB0
DDF9AFD3EDA4D5EBA3C0D18B9CA9645B64214B500E515A17D2E6A1CFEAA3CEECA4CEEEA5
CDEDA4CCEAA2CEE59FD0E19DE2EDABE6EBAB717334C5C7889EA464C7D290DEEDAAD7E8A2
E3F7B0BFD38BD0E69DCFE79DD5EFA5C6E297C8E79BCBEA9E
9CA76394A561D7F7AEC4EAA1C6EEA5C2E49AD5E6A0959F58D9E09ADBE8A2C4DE97C9E7A7
C1E2ABC8E3B8F8FFE8F6FFF2F1FFFFEAFFFFD8FEFFA2CCCB234F4E8EB6B6E3FFFFF1FFFF
FCFFFF2A2522130900807967FFFFE8CDDDB8C2DFB1BDDBA9819160B7C091C5CEA3D0DBB1
CFDBB5F5FFDEFBFFEAF7FFEBFBFFF1FBFFF3FCFFF4FCFFF6FFFFF8FCFDF5FBFBF3FCF9F4
FCFBF7F7F6F4FFFDFAFFFFFAFFFFF5FFFFEFDCE1C3AAB388D6E3ABD3E6A4C8E096D6F3A3
C2E193C9E99DD5F7ADBDDF95D0F0A5C8E79BC4DE94B6CE849AB067586E23CEE69AD7F2A5
C9E89CCDECA0D3EFA4CAE199DBEAA7BAC0824D4D11C9CD90C8DF97C7E29BD6E6A7E0E5AF
888153746B40989062DDDDA9D4DFA3D3EAA4CBEA9EC9EA9B8FAE6291AB62CBDF9ACDE29F
C8E5A2C8E7A3CCE5A4ACBE80D4DDA4D2D9A3D7DBA8DAE1ADDEE8B3D6E5AED1E5AAD0E5AA
CAE0A2CFE3A6D9E9ABE4EEB9B0B08AE3DFC2F3F3D7E5E7CFD5D6C4F9F7EBFFFEF8F8EEED
C0AFB55D4952FFF3FCFFF4FCFFFBFFFFFBFCFEFFFDFCFFFBF8FBF4FDFEF6FEFFFAFEFFFB
FAFFFBF9FDFCFBFFFFFEFFFFFFFFFFFFFEFFFFFEFBFFFCF6FFFCF69B8E85604F45E1D3CA
FFFBFAF8F3EFF7FFF4F1FFEBF2FFE6D0E0B998A071D2D7A1D8E0A4D2E39FC9E99DC3EE9C
C2EE99C2E996CBE898D5E9A1C9D99891A16386985ACAE0A0D2EBA9D3EEABC1DF99BFDD97
CBE69FC2DC95D5EBA3D7EBA3A2B26B96A15C929C579CA76280964E79944D75934B7B9B52
8EAE65ACCA82CEE59FE4F5B1D4DF9DCFD4946466276C6E2FB8BE7ED9E4A2CBDA97CBDF98
C3DE91B2CF7FCCEB9BB9DA89D5F8A6CAF09DC4EA97C9EF9C
ACB97395A962BFDE98BCE19CD5F8B6CFECACD0DC9C9BA25CDFE79ACEE08EC8EA93CDF7A5
C4EFA8BEE5ACC8E4BBCCE2CBE9FFFEE8FFFFDEFFFF8FB7B75D8585C3E6E8DFFBFEF4FFFF
F9FAFEB9B3B50F0400070000EEF0DBFBFFEAF2FFE6F4FFE48E9876EFF2D3F5F8DBFEFFE9
FBFFEAFEFFF1FBFFF2FBFFF6FAFFF8FAFFF9FAFFFBFAFFFBFDFDFBFEFEFCFFFFFDFFFEFF
FFFEFFFDFBFCFFFEFFFDFBFCFDFCF8FFFFF5DCDFCA8C946FD0DCAAD2E2A3CEE499CFEB97
D3F19BC3E68CC9ED95CCF099C5E498D2EEA4D1EBA1D9F1A7C9E195536B1DCDEA98C5E592
C8E998CDEE9DCCE89BD1E99FD7E3A1D9DDA058511AACAB72D2E7A2CFEAA5D4E4A6D0D4A1
3E370B938A5F8F8759E2E2AED5E0A4C6DB96D6F2A7C3E495CFEBA0A8BF77DFEEABC6D695
CAE3A1C4DF9CD2E8A79CAC6DD8E4A6EEF8BBFDFFCCEFFDC2C0CF96D3E6AED2E5AECEE0AC
D8E6B5D7E0B3D8DDB4F2F3D3CBC5B5F6EFE7FFFEF6FEFAF1FFFEF8FFFAF8FFF8F9FFF1F6
BCA3A9624750FFF6FFFFF8FFFFFAFFFFFAFEFCFFFFF7FDFBFEFFFDFFFFFBFEFFFDFEFFFF
FEFFFFFDFEFFFBFCFFFAF9FEFBF9FEFFFDFFFFF6F7FFFCFAFFFCF673665D87766CFFF7EE
FFFAF9676664F8FFFAF5FFF4F7FFECE3EECCA1A27AE9E5B6DCDBA3D3DE9CCAE69BC8EF9E
C4F09BC1EB95C9E996D3E9A0DBEAAFB3C18C96A770C1D49CE2F7BCBFD99ACDEAA8D4F1AE
CFEDA7C1DC95D2E9A1D2E89F93A45DC3D38AD4E199D2E299CDE39BCFE9A2D4EFA8D0EEA6
C0DE96A8C37C8FA66081924E97A2608E9353D0D293D2D797D8DE9ED0DB99D8E9A5D5ECA4
8AA959AAD07BC5EB96C1E993C8F09ABBE58FC3ED97CDF9A2
DEF0A4C7DD92C8E7A1C4E7A5CDECB1C8E0A6CBD599A4A967DFEA9BCAE189C3EA8DC0F397
B4EA9CB4E7A5C0E5B9C8E6CCEDFFFFE4FFFFDAFCFE6B8E90567C7DD2F4F5EEFFFFE8F5FB
EFF0F5FFFBFF362A2C070000C7C5B9FAFFEFEEFDE6F4FFE9CFD1BCC6C1AEFEFBECFFFFF3
FFFFF6FCFDF5F3F5F0FCFFFDFAFEFDFAFEFFFAFEFFFDFEFFFEFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFCFAFFFFFEFFFFFFFBE9EBDD989E82D2DBB0D7E6ADD4EAA2C1DD89
DAF8A0C8EA8CC7EA8CCBEE94CEEA9FC8E29BC6DD95D2EAA0C7DF918CA756A7C772C8EA94
C7EB94C7EA96C6E595D2E89FD4DF9DE3E2A9655B2697945DD9ECAAC6DF9DE2F0B5DDDFAD
221B0095895F81794BD4D4A0D5DFA2CBE09BCCE89DC8E799C0DA9098AE66B9C583DAE6A6
D5EAA9C7DD9CD1E6A58E9E5DB6C584E8F7B4FBFFCAE2F5B5D7EBAEDBF0B7CEE2AFC3D4A7
DBE3BED2D5B6E3DFC6FFFEF1AAA0A1FFFBFFFFFCFFFEF5F8F4EAEBFFFAFDFFF1F3FFF7FA
AE91956F5256FFF6FBFFF9FBFFFBFDFDFCFAFBFFFFF5FEFBFCFFFDFEFFFDFDFFFEFEFFFF
FEFFFFFEFFFFFFFEFFFDFAFFFFFBFFFFFDFFFEF5F6FFFCFAF9ECE6685B52B2A499FFFCF4
8F86872C2D2FF7FFFDF1FFF4EAF8E1FEFFE8D3CDADD7CBA3E7DFB0D9DDA2CBE29AC8ED9D
C7F19DC2EC96C8E893D1E99DD1E0A5BDCB98899762D2E5ADCADFA6D9F1B3BBD594D5F2AF
CEECA6C5E099D7F1A8BDD58BA2B76CDCEEA4E3F3AAD0E298D2E8A0CEE8A1CDE8A1CBE9A1
CBE9A1CFEAA3D3EAA4D8E9A5D0DB999AA060B0B273C3C888E6ECACE1EDABC1D28ED6EDA5
91B261BFE590C9F19BD1F9A3C4EE98B5DF89BFE993BEEA93
D3E996CFE897CFEFA6CCECADC5E0A9CBDDA9E1E8B2979B5ECFDA8ED8F09AC1EE91BCF79B
B2F1A2BAF4B7E4FFE8E1FFED9EB9B41932363D5B5DB7D6D8E6FFFFD7F3F6F0FFFFF7FFFF
FEFFFFFFFCFF887D830B0102302B27FAFBF3F9FFF6FCFFF6FFFEF4A2988FC4BBB6FFFDFA
FFFDFAFCF8F7FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFFFF
FFFEFFFFFEFFFDFBFFFCF9FFFFFDFFFEFCFFFFFFFAD1D5C4D8DFBED5E3B2D6E8AAC6DE94
CFEB97C8E990C5E88CC3E58ECFEBA1C9E29ECAE199D0E89ECEE99AC6E39188AA54CDF199
C7EE95C2E68FCBEA9ACCE299DAE4A5DEDDA46155239A9460DDEDAFBDD393D0DBA3E5E4B4
756C418B7F555C5426DDDDA9DAE4A7DAF0A8BDD98CDCF8ABD1E99FC9DD96919C5AB1BB7C
D7EAAACCE1A0D1E4A299AA66869751CDDE98D7EBA4C7DE98CFE8A6D6EFB5F7FFDAF5FFDD
FFFFE8FFFAE7FEF1E8E8D8D9FFFBFFFFFBFFF5EDF8FFFCFFFFFBFFFFFBFBF7E3E2FFF8F4
A18581816561FFF1ECFFFAF4FFFAF2FBFEF5F8FFFAF5FFF9F8FEFAFAFCF9FAFCFBFCFDFF
FFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFAFDFFFCFBC7B9B683766ED9CBC2FFF4EE
716D6E676B6EF3FFFDF5FFFAF8FFF4F4F7E2C0B69DFEEECDF9EBC4E3E1AECDE0A0C9E99E
C6F09EC4EC96C7E993D1E99BD3E3A5B7C68F9CAB72CDE1A4D8EEB0BAD391DBF6B1C4DF98
C9E79DC7E59BD5F1A68AA45AC4DC92D7EDA4D0E49CC4D890CCE29ACDE49ECDE7A0CCE7A0
C9E79FC9E49DC9DE99CADB97E5F0AE909656B6B879EEF3B3D6DF9ED7E3A1D1E29E8BA25A
ADCC7EBFE08FC6E997CAED9BCEF19FCBEE9CD2F5A3C2E895
CFE88DC7E38ECBEBA0CAEAA9C8E1AAD2E2B1E1E5B34F521998A55FCDEA9AB5E790BBFBA7
B0F2ABB1EDB9E3FFF1CAECDE516B6A6C8488CBE4E8E8FFFFEBFFFFEEFFFFECFEFFF7FFFF
FFFEFFF1EAF1FFFBFF94898D040000FFFFFDFAFFF9FFFFFBFFF8F6AB9B9B807272FFFCFB
FFFCFFFFFEFFFFFEFFF6F5FAFDFEFFFDFEFFFDFEFFFDFEFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFAF8FDFDFAFFFFFDFFF3F0F9FFFFFFFEFFF5D9DEC7C9D3AED3E4AED8EDAC
C5DF96C7E396C9E996CFEE9EC7E29BD3ECA8D1E8A2CCE49ADBF3A5CDE89780A04BCDF19A
CBF19ABFE28ED4F3A5C7DD95E3EDAED9D8A0554917A6A06CD5E3A8D5E7ABDFE7B4070400
85795153461C938B5DD8D7A1CEDA9AD8EEA6D0EC9FBDDA8ADDF5ABD3E49E949F5D9CA669
CEDE9FCEE1A1D7E7A6B9CA84778841CCE196CFE79DD0EAA1CCEAA4D3EFB2F5FFDAF1FFDB
FFFFECFFFEF3FFFAFAB8A5ABFFFBFFFEFCFFFFFDFFFCFAFDFFFCF9FFFDF6FFFCF1FFFBED
A791839B8474FFFAE9FFFDECFDFCEAF7FFEDF4FFF3EEFFEEF9FFF8FCFFFBFCFFFBFEFFFD
FDFEFFFDFCFFFFFCFFFFFDFFFFFCFFFCF6FAFFFCFFFFFCFBA89D99B7AAA4FFF8EFFFFDF6
010002ADB2B6EFFDFDF4FFFDF4FFF4FFFFF1B6A998DECAB2FFF7D6EBE7BAD0DFA6C8E7A1
C7EDA0C4EB9AC8E895CFEA9B8C9F5D425213DDF0B0CADF9CCCE39DD9F3ACB8D48AD3EFA4
CFEEA2C9E89AC5E1964B671CD2ECA3CBE29ACCE39BDBF1A9D0E5A0CFE6A0CDE7A0CCE7A0
CCE7A0CDE8A1D1E6A1D5E6A2CDD896919757A5AA6AD1D696D7E09FD0DF9CD8ECA74B621C
CFE69EC6E096DBF5ABC5DF95CAE49AC7E197D0EAA0C7E197
D5F093C7E58DCFF2A2C7E8A3C8E1A8D5E5B4D0D3A460643188985AD0F1ACB2E89DB0F1AD
ABEEB88CC8A4A3CDBF6A88869CB4B6DCEFF5EEFFFFF0FFFFF0FFFFEEFFFFF4FFFFF9FFFF
FFFEFFFFFDFFFFFBFFBCB3B8070105868487E1E1E3FFFEFFFFFBFBCABABAC7B9B9FFF6F6
FFF9FDFFFDFFF7F2F6FFFEFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFB
FFFFFAFFFFFBFFFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFDC1C5B6FCFFEAF6FFDAE0F1BD
CDE2A75B7433A8C281C8E5A2C9E4A1D3EEA9D0EAA3C7DF95D1E99DCBE395ACC97988A855
D1F4A2BBDE8ED0EFA3D3EAA2CCD898E3E4AB5B542056531ED3DEA4D9E6AED7DAAB080300
3A2C0588795292875A7A7943B8C484D1E79EC8E497D0EF9FC6DE94D1E29C9DA768D8E2A5
CADA9BE0F3B1D6E7A3CADB95A6BB70D7EEA0C8E396CEEA9FCBEAA4CCEAACCBE3B1EDFBD7
FBFDE7FFFEF3FBE7E869585EFFFCFFFBFFFFFCFFFFFCFFFAFEFFF3FFFFEDFFFFE6FFFFE3
AEA083615233E9DEC0E8E3C3D5DABAE1F0CFE7FFDEF1FFECF6FFF2FBFFF6FBFFF8F8FDF6
FEFFFDF5F5F5FFFEFFFFFDFFFFFDFFFAF4F8FFFCFFFBF1F2A59B99BCB1ADFFF8EFCBC4BE
6C6B70A9B0B6F3FFFFF4FFFFF1FCF4FFFFF6CBBDB2A18C7BFFFDE3F6F1CBF2FFCDC1DDA0
CFF3ADCFF5AABDDC90CEE99C647A31A6BC73DBF1A8C6DE92D3EB9DC7E293CAE797CCE999
CBEA9ACDEC9CCAE99B92AE64A0BB74CCE5A1CDE6A2D0E7A3D3E8A3D0E5A0CEE59FD5F0A9
BFDA93CDE7A0D6EBA6D0E19DD0DB99B4BA7A9EA363D2D898D2DD9BD6E5A2DCF0AB475C17
C9D998D7E6A5CFDE9DDAE9A8D8E7A69CAB6AD5E4A3DBEAA9
CBE88BC6E48ACEF19FC7E99FCCE6A9D9EAB4DDE3B3858D5CD4E8B3BFE5ACC9FFC868AB76
4C8E685188717EA5A2EDFFFFE0F1F8F4FFFFF4FFFFF2FFFFF5FFFFF3FFFFF8FFFFFBFFFF
FCFCFCFFFEFFFCF8F9FCF6FA8681850100048B898EF8F2F6FFFAFAEDDDDDFFFBFAFFFBFB
FDF3F4FFFDFFFCF8F9F8F8FAFFFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFEFFFBFEFFFA
FFFFF8FFFFFAFFFEFFFFFDFFFFFDFFFFFCFFFFFDFFFFFEFFD8D9D1FEFFEFFCFFE6F5FFDB
CADCAC001100667D49BED79DD1EEABBDDB93CDE79ED6EDA5D0E69DCFE59CD1E99FD6F0A6
79974DE0FEB4B9D48DD1E8A4D3E1A3E0E6AAD1D0985F5E28E2EBB4C6CE9BEAE9BD150C00
0F000092805AACA17498976198A464C6DE94C4E395D0EF9FD6F1A4D2E69F939D5ED5DFA2
D6E6A7D2E5A3CADE99DEEFA8CADF94A1B86AC0DB8CCEEDA1C5E59CCEECACCDE5B1E1F1CA
F0F4DBFFFFF1EEDFDA534544FEFFFBF4FFF6F1FEEDF8FFEFF9FFEAF9FFE0FAFFD8FFFFD8
A39F72635F32EFECC1E3E4B8DDE8BDD1E4B7D9F4C7E9FFDBF5FFEAF8FFEFF9FFF1F9FFF1
FCFFF6FAFDF6FFFFFDF8F6F7FFFEFFFEF8FAFFFDFFFFFAFBBDB5B3D6CECBFAF3ED847F7B
08070CC1C8CED0E0E0F2FFFFF7FFFFFBFDF8E1D4CE655148FFF9E7FFF8DBFBFFDDC1DCA7
C6E8ABB7DA96DBF6B1C7DE9695AD61CFE799CDE899CFEA99CEEA96D6F39FD0ED99C1DE8A
C9E996CCEB9BCAE99BB7D58B89A45DD4EFACCDE6A5CCE2A1C7DC99D0E5A0C0D791DDF7B0
C8E39CCCE69FD0E5A0D0E19DDFEAA8C1CA89989D5DD9DF9FE0EBA9D7E8A4B2C782556826
F4FFC2C4CC91DFE4AAD9DEA4EAEFB52328005C6127D0D59B
C9E78FC9EA93CEF19DC2E497CAE5A0CFE3A6DAE4B09FAB7DCEE5B7BFE6BA77B188397A58
77B59EAADCD3EAFFFFF2FFFFF7FFFFF8FFFFF3FDFFEFF9FAF8FFFFF7FDFBFCFFFDFEFFFB
FFFFFBFFFFFBF7F6F4FFFEFFAEACAF0100043D3B40FFFDFFFFF6F5C4B5B2FFF5F2FFFCFA
FCF4F2FFFDFDFFFDFCFFFFFFFFFFFFFEFFFDFCFFFDFCFFFBFEFFFBFEFFFAFEFFFAFEFFF8
FFFFF8FFFFFAFFFFFFFFFEFFFFFDFFFFFDFFFFFDFFFFFEFFEAEBE3C6CAB9E1EACFDDE8C6
D2E1BA000D00506238DAF2C0C4E39FC1E195D6F0A7E2F8B0BDD18CDDEDACC8D899C7DA9A
93A969C9E2A1C0D998D3E9A9D5E5A6D7E3A5E8EEB0A7AC72747B47B3B586DCD4AD170900
9E8A6976623F908357E4E3AD9CA866D7EFA3D1F0A0BCDD8CCEEA9DD5EBA39FAB6DD6E2A4
CCDF9FCFE6A2CDE19CD5E9A1D8EDA281974CD5EDA1CDE99EC2E098CEEDAAC7E3A9CDE0B2
DDE7C5FFFFEAEBE2D3565040F1F9E2D7E7CACBDFBCD3E9C2D8EEC0D2E6B5D2E3ADDBE8B0
B8C087878C52A5AA72CBD29CD7E4AECCE1A9DBF7BDD7F3C0E1F6CBE1F2CEE2F1D2E8F6DC
FBFFEFFBFFF2FFFFF8FAF9F5FFFEFDFEFAFBF8F4F5878183514B4BFFFEFBE4DFDB030000
DCDBE0FAFFFFCDDDDD9EB1AFB5C3C3FBFFFFFFF6F58B7C79FFF8EDFFFFECF0FEDDEDFFDB
D3F4BFC4E3AAC9DEA58FA364D9F3AABBD78AD3F0A0BEDB89D2EF9BC4E48FBBDC85DDFEA7
CCEC97C2E28FD8F4A794B066AEC982C5E09DD4EEADC8E1A0D9ECAACEE29D889D58C2DC95
CAE59ED8F2ABD2E7A2CEDF9BC6D18FAEB776898E4ED7DD9DE1EDABD5E6A29EB36E93A664
C6CE93E0E3ACE6E6B0C7C791504F1976753F61602A575620
CCE999CDED9ACBEE9AC0E38FCAE99BC9E09AD3E2A7A7B987CAE6BE7AA6834E8A6E92D3BD
D8FFFFE2FFFFF1FFFFEEF7FFF7FCFFFBFFFFF5F9FCFEFFFFFEFFFDFFFFFBFFFFF8FFFFF8
F7F8F0FFFFF8FBFEF7FEFEFCFAFAFA0D0B0E2C272D7E787CFFFCFAAB9E98FEF3EFFFFDF8
FFFEFBFFFEFBFBFAF8FFFFFDFEFFFDFEFFFDFCFFFDFCFFFBFEFFFBFEFFFAFEFFFAFEFFF8
FFFFF8FFFFFAFFFFFFFFFEFFFFFDFFFFFDFFFFFEFFFFFFFBFFFFF4F0F3DEA2A88CD2DEBA
E0EFC8000900758560C8E0AEE2FFBCB1D484D0ECA1BCD18CE6F4B6D4DFA5DEE7B2F4FEC9
CCDAA598A973CEE3AAD5EBADD5E9AACBDE9CC1D08DE5EFB073774459562BC4B794170400
7C6344B19A78B3A67ADDDCA6889452C4DC90DCFDACBEE18FC7E396D3EAA299A76993A163
CDE4A0D2ECA5D2E8A0CBDF98D1E59D80954AD3EB9FCDE79DC9E79FCEEDA9C3E1A3C2DBA4
D3E2B7FEFFE1F9FADB8B8E6FE7F3CBD6E9BBC8E0AEC5E0A9C5E2A8C5E1A4CAE3A2D1E6A5
D9E8A7B1BD7D565F20DDE7AADFEDB0C9DB9DD1E7A9CCE6A9C7E0A9C7DFADCAE0B2D5E7C1
F3FFE0F2FCE3FEFFF3FEFFF5FDFCF7FFFFFDFFFEFFA4A2A3605E5FB9B8B6878684F3F1F2
FFFEFFF1F5F8EEFEFEE3F7F69DAFAFDEE8E9F2EDF1615758FFFDF8FFFFF3F1FFE7E5FFDD
EEFFE3CCE8B8CFE0B3A6B783BFD99ACEEDA9C4E49BD5F5AACDEDA1C7E696C9E996C7E794
C8E895D5F5A2BBD78A738F44C0DB94D7F2ADC0DB98D6EFADD0E3A1CDE19C667B3693AA64
7B954E849E57AABF7ADCEDA9D9E4A2B8C180A9AF6FDDE6A5D3DF9DBCD08B9AB16BC0D592
DAE4A8E1E4ADD7DAA39A9A6463632DC2C18B9895607A7742
CDE8A3CAE89EC7ED9AC1E790D1F39CCFEA99D6EBA8A8BF89BDE0B870A18443816CC3FFF5
DAFFFFE1FFFEF4FEFDF8F8F8F8F7FCFEFFFFFCFCFEFFFEFFFFFEFBF9F6EFFFFFF3F8F9EB
F8FAECFDFFF3F2F8ECFCFFFAFFFFFD5C5A5B0F0A0E040000EDE4DFA9A099FFFDF8FFFEF8
FFFEFBFFFFFBFEFEFCF8FAF7FEFFFFFCFFFDFCFFFDFCFFFBFEFFFBFEFFFAFFFFFAFFFFFA
FFFFFBFFFFFDFFFFFFFFFEFFFFFDFFFFFEFFFFFEFBFFFFF6FFFFEDF6FBDDAAB28DD1DEB3
CEDEB1000B005E6F45CBE4ADB1D689D3F9A4DDF9AECFE2A0CFD89FD9DDABCBCCA2FEFFD8
BAC198ABB68BCFE1AFCCE4AAD2EBAAC7E09CD5EFA5D5E6A2848654655C35A79473170000
E2C7A95B4321998A5FD9D8A0A3AF6DA2BD70D3F6A4C5EB98C1E094CCE69FB3C38491A162
D4EDA9CAE59ECFE69ED6ECA4D2E69E93A75FAFC37BD2EAA0D0EBA4CAE9A3C6E5A2C8E4A7
D2E9B1F6FFD3FCFFD8C3CF9DCAD9A0D6EAABD7F0AFCAE7A4C5E6A1CDEEA7D1F1A8CDE8A1
D9EEA9C5D4916E7937D6DFA0D4DD9ED7E1A2C9D897D0E3A3CAE4A3CAE7A7CCE5ACCDE4B0
E3F4CADFEDCAFCFFECFDFFF2F8FAEFF1F2EDFFFFFDC0C0C05D5D5D727272939393FFFFFF
FFFEFFEAEEEFF4FFFFF0FFFF94A8A7A6B4B5D4D5DA787379FFFEFFF0F5EFF4FFF6EEFFF1
E0FDDEC5DDB9D4DFBDB6C29CD7F1C2BDDEA9D2F1B8BFDEA2CFEFAEC1E09CCEECA2D1F0A4
CFEB9EC9E696D0EC9F648035D5EFA6C4DE97CEE7A3D3EAA6CADE99DAEEA992A762D1E8A2
A5BF787A914B667B36798A46CED997A4AD6CBEC484D2DB9AACB87695A964AAC17BDAF1AD
D1E1A2D0DB9FD0DA9E60682D474C12D5DAA0E1E4AB969960
D1EAB0C8E5A3C7EC9CC3EA91CEF193CBEC91CEE89E91AD72D5FBD46FA188074737CCFFFF
DDFFFFDEFCF2ECEFE4FFFBF4FFFEFFFFFEFFFFFEFFFFFEFBFEF7F1FDF6ECFFFFF1FCFBE9
FDFFEDEDF4E2FAFFF3FBFFF6F1F4EDE5E5E3373536090303EAE3DDA8A199FDF6F0FDF8F4
FFFFFBFBFBF9FDFFFCFCFFFFFCFFFFFCFFFFFCFFFFFCFFFDFEFFFDFEFFFBFFFFFBFFFFFD
FFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFF8FFFFEFE3E6C9F3F9D37D8657DDE9B7
DFEDBA000B00748654CCE5ABC0E796D3FBA3B1CD80D3E6A4DAE1ADDFDDB4A59F7DB0AB8D
D3D2B3E1E7C3E7F7CAC4DBA5C4E1A1C8E89FDBFCADC3DA92C0BF8F998967AA9374160000
917256947A59B1A075F0EDB6D8E4A290AB5EC0E391C8EE9BC5E599C9E49DDCEFAFCEE1A1
AAC882C5E59CD1EBA2D7EDA5CFE39CC5D68FA3B46ECFE59DCCE69DC2E098C7E8A1CEEDA7
CDEAA8DCF5B4E5F9BAD1E4A49DAD66C1D389D5EDA1C8E799BFE496C8EFA0C9EEA1BEDE93
D2E9A1D2E39FB3BE7C656B2B828747F0F5B5EEF3B3D9E6A1CBE79CCBEDA1CCE9A6C8E2A5
D7EBB8D2E3B9F8FFE3FCFFEDFEFFF4FFFFFAFFFFFDE7E9E89D9EA00405077A7B7DFAFBFD
FFFDFEFEFFFFDAEAE7EDFFFFE5FDFD000507E6EAF38A8991FEFFFFE9F2F1C9DED5C7E4D2
AAC6AFCEE2C7D2DAC2CED7BCC0D9B9C6E6C1AFCFA6C7E7B8BEDFAAC0DFA4D3F1B1BDDB95
CBE79DCDE99EC9E598C2DE9191AB61D7F1A7C8E299D0E79FDEF2ADC4D893809550CDE49E
D5EFA8D2E9A3C6DB96CEDF9BE1ECAA727B3A6B71319FA867C0CF8CD5E9A4D7F1AAB7D18A
D3EAA6DDF2AFCADD9B3F4F0EDCEBAAC8D494D7E1A2DEE8A9
D2EABAC4E0A6CAEFA2C5EC91C5EB86C6EA88C9E9967C9C5DA9D3AB98CEB640807291D0C5
CFFFF3EEFFF8CECCB5DFCFBFFFF7F5FFFAFEFFF8F9FFFCFAFFFCF6FFFDF3FFFFEFE9E8D4
CDD0BBEAF2DBF0F9E6F4FCEDFCFFF8F4F6F18F8E8C030000E7E2DEBAB5AFF9F6EFFFFFFA
FFFFFBF6F8F5F8FAF9FCFFFFFCFFFFFBFFFFFCFFFFFCFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FEFFFFFEFEFFFFFEFFFFFEFFFFFEFFFFFFFBFFFFF3FFFFE8E1E5C0D1D9A89CA76DC3D194
D7E7A9041600586C31C9E4A1CEF8A2ABD67CD1F0A2DBEBACDCE0AE635D39C2B69CFFFEE8
FFFFE8FFFFE4FBFFDFD1E8B4C7E5A5C5EA9DBDE491D0EAA0EBE9B99A8766684F31210300
A8896DA98F6EF2E1B6CCC992CDD99787A255BFE592CAF19ED4F6A9C7E29BD6E8AACADE9F
81A158CCEEA2D0ECA2CEE59DCFE09ADFEEA9A5B471CFE39CD0EAA1C7E59BCFF1A5CFF1A5
C6E69BCAE89ECEEAA0CDE3989DAC5BC0CF7CD5ED99CFEC98C6E995C8EF9EC9EEA0C5E59A
D1E8A2D8E8A7D3DC9D58591D666427C7C386DDD99AD0D793C7E492C5EB96C7E79BC1DF99
D1E9ADCFE3B2F7FFE1FCFFEAFEFFF1EFF2E9FBFDF8FEFFFFA6A7A9000104898D90F9FAFC
FBF7F8F7F7F5F5FFFFEEFFFFECFFFF000609F2FBFFFAFEFFE7EBF4747F83192F2CEBFFFD
001201D3E6D2F4F8E7C9D0BEF1FFF6AFCEBC000C00D2F1D2BDDCB3C7E4B4D1EEB6CBE8A8
CFEAA7C2DE94DCF6ACD3EEA18CA458CBE397D6EEA2CCE299DAEBA5BECF8BA1B570D8EFA9
D1EBA4CBE29CCDE29DDEEFABD1DC9A959E5D989E5ED2DB9AC5D491C7DB96D6F0A9D6F1AA
C3E197C6E49A89A55B8EA85FD2E9A1DAF0A8CDE19ACCDD97
CAE4B5BDDAA2CEF0A6CCF098C7E988CEF091DAF7A784A3677EA681BEEED8053D307FB4AA
E0FFF7ACBFABD4CFB2DECEB5D0C6BDD4CCC9DED4CAF2E9D8F6EED7F8F1D5E4E1C2A4A384
96997AA0A585AEB596D7DBC2EFF0DEFFFFF47C72710E040579726CA9A59CFFFFF8FFFFF8
FAFBF6FCFEF9FCFFFFF4F8F7FBFFFFFBFFFFFCFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFF3FEFFE6D0D9AED4E1ABB9C78CB3C385
CEDEA0011300647638D1EBA4BCE28BD2FAA1C2DE91DDEDAC8F93609C9872E6E0C0EDE7CD
EFEFD5FEFFE6EDFDD6E7FFCDDEFDC1C0E39FC3E99ED3ECA8DBDAAAC7B793655130150000
452A0CA78F6DE9DBAEE7E4ADD9E5A3AAC578D4F7A3B7DF89CAEF9FC6E69BD5EEACC9E2A0
8CAA60D0EFA3C3DD94D8EEA6DDECA9CAD696919D5DDBEAA9E5FAB7DBF5AEE1FCB5D5F3A9
C7E69ACEEA9DCFEC9CD1E898AFBE6DC4D380D2E593CFE895C4E393C4E596CAEA9FD0EBA4
CBE29CCFDF9ED8E2A3E3E7AAA8AA6B6161237B7B3BB9C07AD2E997D0ED99CEE99CC7E19A
D5EBABD1E6ADF6FFD5F9FFDDFBFFE6FCFFEFF9FFF3FEFFFDA6A8A71618174D4D4BFEFFFB
FEFFFBF8FFFBE8FDF6EBFFFF7897925F7978E6F9FDF3FFFFDEEDF08FA1A17D9893DCFAF2
EDFFFFB2C6BDF9FFFDF5FBF700050072857FF2FFFADBF0DD89A284C5E0B7BCD8A7CAE8AC
CCE9A7CAE8A0CDE99EC5E1948CA75AD2EA9CCCE498D5EBA0CEDF9B9EAF6B91A560C5DC94
CDE79ED0EAA1CDE39BCEE29DCEDA98A2AC6D8C9556E0EAABD6E5A4D3E8A3C7E19ACBE79D
D7EDA5C6DC938EA65CAFC77DCEE69AC3DB8FE1F9ADCCE496
C8E6B0C9E7ABCAE8A0CDE899D0E894D0E797CFE6A2CAE5B083A584BCE2CD4D7368000B02
B8CEC1CED7C2FFFFE3FFF7D9FFFDEDFFFEEB8D87658E8A5BE9E8B0CFD09660602A505220
DADCABA2A171B3B180847D51DDD2B2FFF1E19A81840E0000857872DBD5C9FFFFF4FFFFF4
F9FAF2FAFDF4FCFFFBF4F9F3FBFFFDFBFFFDFCFFFDFEFFFDFFFFFDFFFFFDFFFFFDFFFFF6
FFFFEBFFFFEDFDFEF9FEFFFFF7FAFFFBFFFFEEF9E9F8FFE8D4E5B8CBDFAACBDFAA93A66F
CDE0A90315005C6E30C6DD95C5E494D5F7A3CBE699D1E5A0B7C286E5EEB9D6DFB0D4E1B6
BACCA2F4FFE1F0FFE1E7FFD8F0FFDCCCEAB6C0DDA7DEF2BDD1D8A5DAD6A7A1986F150700
2E1C00726038A29769DDDCA3D5E09C8CA355C8E893C5EB94CCF3A0C6EB9DD1F3A9C6E49C
89A359D5EBA0D2E39CC6D592DEEAAAD4DEA2D1DAA1ECF5BCF8FFC9FCFFCFFBFFCCE0F0AF
DEEFA9CBDF97D0E59AD5EA9DD1E19899A9604F5F18CCDD96D8ECA5C9DF97CCE19CD4E9A4
D9EDA8C2D38FD5E4A1DCEBA8CEDA98D6E2A0899553596620A3AE62C7D286DFEAA5D7E6A3
CCDC9BCDE29DD2E8A0D0E7A3CEE3AAD5E6BCFBFFEFE1E4DB6B6A66B7B2AE7B7567BCBDAD
EFFFF3DAF9E9C3E5D7BCE0D4CCF2E7B2D6CCB8D9D0B3D3C85C7C6FB5D5C8BCDCD1EAFFFF
EAFFFFE3FAFF6779878B95A186838AF8F2F4FFFFFAFAFEF0F9FFECD0E2BCE3FDCDBEDBA1
C7E7A6CAEBA4C8E89DCBEA9E8AA65BCDE89BD2EAA0CFE39BD3E2A14C5B1A82964FE0F8AE
CAE699BEDA8DD7F2A5D6ECA4CCDC9BC4D2949EA96DC6D497D3E6A6CEE5A1C9E59BDBF1A9
DFE1A09C98585D601DD6E29AD4E99CC6DF8ED2EF9BCBEC95
C3E9ACC5EAA7C9E9A0CDE899D0E797CFE79BCDE6A4C9E6B090B28D6E9179395B4B658474
C6D9C5D8E3C5EEF0C9F7F3CEFBF7DEFFFFE5E8ECBAE4EDACC5CF86BDC97DC8D590DAE6A6
D8E2A5D5DB9FDDDEA2E7E6AEBDB48B6758413721231300055E514BC0B8ADEDE6DCF9F6ED
FFFFF8FFFFFAFCFEF9FCFFFBFCFFFDFCFFFDFEFFFDFFFFFDFFFFFDFFFFFDFFFEFDFFFFF6
FFFFE8FFFFEAFEFFFAFEFFFFF5F9FFF9FFFFDCEBD6E3F8D1C8DFA9D1E9ADD1E8B01E3200
617341000B007A8C50D6EBA6CFEB9EC3E08ECFE799D5E9A191A05DD6E6A7C6D89CCBE0A7
D3EEB7D4F2BCCCEFB7E0FFCDDFFDC7C7E4AECAE1ADC2D39FE2EBB6E2E4B28F8B5E0F0600
60522B887B51DFD7A8E5E4ACD7E29E9AAF62CEEB99C6EA93C8EE9BB8DF8EC7EC9FD3F5A9
8EA95CC9DF94D7EBA3D2E6A1D5E5A6D7E7A9D8E5ADC5D29CEFFCC6EAF7BFF0FEC3DDEDAE
C8DC97CEE29ADDF3A8CDE398D6EAA3C4D893B3C782A8BC77C6DA95D4E9A4E7FCB7C2D792
C7DC97DCF3ADC7DE98D6EDA7D9F0AAC6DD97D6F0A991A55D3F4A008A9046C8D190D6E2A2
D3E4A0D8EEA3D0EC98BFDA89C7E19ADBEFBAE2EFD33F423725241F6D6960BDB6A3CDD0B5
213C1D1F46274B6F55A7CAB2E9FFF6DDFFE889AC9430543A1D3F24A7C8ADCAE7D1EDFFF9
DFF5F2F0FFFFD9EBF9F8FFFFA2959FE3CED3FBEDEAFFFFF3FDFFE8F1FFDBE8FECFCEEAB0
C7E7A6CAEBA4C8E89FCBE99F8BA55BCFE79DD4E8A0D1E29CD0E09FDBEEAC94AA62C3DE91
D1F0A0CEEF9ED1F0A2BFD98FD9EEABA1B3758D9C61D4E3A8D4E8A9CCE5A1CDEBA1CADE96
D8D2967061287D7739D9DF99DDEDA2D3EC9BC2DF8BC8EA93
BEEDA7BFEDA4C3EC9DC6EC97C9EB94C8EB97C6EAA0C2EAABB1DFB03F6E4A103E2184AD8F
C9EBC8ABC5989CAD77DAE6B6FBFFE8F7FFE7CEE2ADD0E9A5C3DE8FC8E593C9E79DCAE8A2
D1ECA9D1EAA6D0E5A0CBDE9ED0DAA8FFFFE47D7A730B0507877D7BF7EEE9FFFDFAFCF7F3
FFFEFBFFFFFDF1F3F2FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFB
FFFFF3FFFFF6FFFDFFFFFDFFF9FCFFFBFFFAD2E2BED1E6AEE3FAB4BED58DD5EBAB647940
9AAC7C000B005A6B37CEE2A5D6F1A4C2DE8AD5EC9CD7EC9F85954C9AAA63D5E6A2D0E7A3
D2EDA8C0DF99C7EBA3D3F7AFC3E39AC0DE96DAF1A9DBEEACD7E0A79FA3705E5B2E0A0300
998D67A2966EEAE2B4DBDAA4DCE5A4A9BB71C7E293C2E490D6F9A7C3E89AC1E399C6E89E
C0E393CAED9DCDEDA1CCECA3C6E49ED2ECABBCD498667E42CCE4A8BDD798BED897CEECA6
D0F0A7CCECA0C5E898C3E495C7E59BCCE7A0C5E39BADCB838FAD6598B66EBEDC94D3F3AA
C7E79EC9E9A0C2E299BFE197BFE197C9EBA1D4F6ACBEDA90D7E99D7280354757168EA161
CCE19CC2DC92C0DD89DFFCAAD3EEA7C4DBA5DBEACD050B0073746C67675B73715AF4FAD6
CAE1B3CFEFBEDAF7CBE2FED5EAFFDEC2DEB5C5E0B7C6E1B6839D70D1E8BEC7DCB5F1FFE2
F7FFF0F8FFFAF4FDFCFEFDFF8D7A7EB89FA2FFFBF4FFFEEFFFFFE8F0F8D3E8F8C9D1E8B0
CBE5A6CEE9A4CBE69FCEE89F8EA45CD1E59ED7E6A1D2E19ED9ECAAC3DC98C0DC92CBEC9D
BEE491C9EF9CBFE292D5F5AAD6EFAD7E92538D9F63E9FBBFCEE4A4C0DB96D7F7ACCFE59D
8B864C51440FA39E64DBE0A0D6E5A0CDE398C9E495D4F3A3
BEEEA4BFEEA0C2EE99C5ED95C6ED92C5ED94C3EC9DBFECA7CEFFC82B5F2F0014007CAB81
CDF3C4ADCC9390A665CFE2AADFF2D2E4FCDCBFDBA8CAEBA6CFF4A4D1F8A5C3EC9EC5EDA4
BFE7A0C4EAA1D4F6ACC2DF9CBDD49EF7FFE4667065000100918889FFF8F8FFFCFDF8EFF0
FDF8FCFEFCFFFDFCFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFF
FFFDFDFFFDFFFFFAFFFFFCFFFEFFFFFCFFF1D2E2B1CEE49CC6DE8AC9E28ED1E8A090A668
819363000A0059683DDDEFBBC8E299C9E493C9E092CADC909EAB6347540EDBECA5CEE49B
D3EDA3D4F3A7C6E999BDE08ECBEB98D2EF9BCBE38FCADC908A9559828654A4A377110900
847852968A64CAC196E2E0ADB0B87CA7B671C5DD91C4E191DDFCAECFEFA3C0DE96BEDE95
C5EA9CC0E796BBE293C2E69CC9EAA3D7F6B3C1DF9F6F8D4FCBE7AADEFCBCCBEAA7C0E19A
C4E89EBFE697B8DF8ED6FBABCAE89ED0EAA3C1DC95C9E49DCCE7A0526D26C4E29AC3E199
D9F7AFC5E39BC9E9A0CEEEA5BDDD94DBFBB2BCDC93D6F2A8D7E99FC0CD858A985A677739
869655C3D78FD7ED9BC2D788CFE09CD6E3AEDFE3C82E2C20BBB6B0C1BBAF5C563ED1D3AC
CEDFA8C5DD9FC4DCA2D6EDB5F6FFD5D9EDB8D6E9B2CEDFA98B9A63D5E2ADD4DEACFFFFDD
FFFFE6F5F7E2FFFFF4FCF3EE8F7A77BAA19DFFF8EEFFFDEBFFFFE4FFFFDDE8F6C5C9DCA4
CEE4A4D1E8A4CEE59FD1E79F91A25ED4E3A0DAE5A3D4E0A0D3E3A4D1E6A3E0FAB1C6E295
D1F2A1C4E594CEED9FC8E299D3E6A68E9C619AA36CCBD49BCAD89BE9F9B8CCE39B5A6B27
69683087814DBEC188D6E2A4CCE19EC2DD96D2F0A6C8E89C
C2ECA0C3EC9DC6EC97C8EC94C8EC92C6ED94C5EC9BC1ECA4CAFABE194A13134110CDF8C3
BCE2A7708F4C8AA256DBF0AFC6DBBACCE3C7C4E2B0D0F3B1B1DA8BB7E290C4F0A3BFEBA0
C2EEA3C6F0A4B0D689CEF2AAE1FEC4F0FFE1819383010A07ACA6A8F4E8ECFFFBFFFFF9FE
FFF8FFFFFDFFFFFDFFF9F8FFFFFDFFFFFDFFFFFDFFFFFEFFFFFDFFFFFDFFFFFDFFFFFDFF
FFFBFFFFFBFFFFF6FFFFFCFFFFFFFDFEFFE8D6E4A7D1E492CEE686E4FD9FD3EA9AC0D495
9AAA7D0817006D7B57CEDFB2D2E8AADCF3ADCDE19CD6E5A2D4E09E5A6624CDDC99D7EBA4
C0D88ECCE89BC7E897C8EA94D1EF99CFEB94C6DD85B2C574768447B1B988CFD0A6080300
544A27ADA07DC8BF969F9B6B7B8046AAB674D7EBA3CBE397CFE99FC9E39ACAE19DD0EBA4
B0D285CAEF9FC9EB9EC9E9A0CCEBA5CAE7A5CBE8A8C0DD9D435D1E92AF6FD0EDABD0EFA9
C8E89FCCEEA1C9EE9EC2E296DBEFA8C4D08EE5F1AFE2EEACC3D28FDFEEAB91A05D9BAA67
BECF8BD3E4A0D0E49FDCF0ABD3E7A2CEE29DD2E6A1D7E6A1D4DE97DDE29FD8DBA2B6B982
7D7E444F51104B4D045C5C14666225595123685743B29E97FFF8F6FFF8F0B49E89BCB08A
D8E2A5D7EBA4DEF1AFE9F9BAF4FFC7CED99FD7E1A5E0E8AD6A7034D7DAA1E8E8B4FFFFD5
FFFBD8FEF7DDFFFFECF1E3D6927B73D1B9AFFAE9D9FFFFE6ECE9C8E5EAC1CEDAA8DBEDB3
CFE3A4D2E7A6CFE4A1D2E6A192A160D6E2A2DAE4A5D6DEA2DCE2A6444A0E9DA866D3E09A
CBDB92D5E59AD4E199DFE8A5DEDFA5534D19312700594F1E57501C4D4B125E60215D6124
AFB47CD1DAA5CADCA2C6DEA0CAEAA7D0F5AFBEE69DBAE299
CCE89ECCE89DCDE897CFE895CDE994CCE995C9E99DC6EAA4C5EBAE628751B9DEAABADBA4
CCE8AB90A761DBEE9DCDDC9BF9FFEAF7FFF1C8DDB2C5E1A4D1F1A6D5FAAAC5EBA0C1E9A0
BEE49BCDF3A8D2F7AAC3E29CCAE6ACE4FAD3728071000200FDF7F9FFFBFFFFFBFFFFFBFF
FFFBFFFFF7FFFFFCFFFBF8FFFFFCFFFFFDFFFFFDFFFFFEFFFFFEFFFFFEFDFFFDFDFFFDFF
FFFAFFFFFAFFFFF6FFFFFCFFFDFDF5FFFFE3D5E19FD0E38AD2E884C2DA78C2D788E4F6B8
C6D6A900080065734FCCDDB3CEE2ADD0E5AACBDAA1D9E4ACE0E9B2A7B0779EA96FCBDB9D
DFF4B3CCE69FC1DF95D5F4A6C7E293CAE191D5E89788984F819055E9F3C1E3E6BB070300
39300F877A5ACBC19D9F9B6E9C9F6AC8D293E1F2ACD1E59DCCE29ACFE49FD3E6A6D2E7A4
B4CE85DCF8ADD3EDA4CDE49ED3EAA6C4D998C7DB9CDBEFB2BDCF93A4B879CBE09FD2E9A5
C8DF99C2DC93DDF9AEC6DE94C9DA94DCE8A6D5E19FC9D593D7E6A3D3E29FD0DF9C879653
A6B773C5D692E1F5B0C6DA95D2E6A1C8DC97CFE39ECFE09AD1DE98D4DD9AD8E0A5DFE4AC
E3E4AAE1E1A1E3E39BEAE69F9990556E5F34412C19A08981FEE5E1FFF7EDC3AA948B8259
D7E6A5CAE49BCAE49DDFF5B4F8FFCDD7E6ABD3E1A6D1DB9F9CA469E2E7ADD9DCA7FFFFD4
FFFFDFFFFFE6FFFCE9D2C9B8A79A89BFB39DFFFEE1FCFCDAF2F9CFC0CE9DC8DDA5D3EDB0
C9E6A4CCE9A6CBE6A1CDE8A38DA460D0E5A2D4E7A7D2E0A2D4DCA1E9F1B58C9755D4E19B
DDEDA4D5E59CE0EBA6CBD1914B4A125D5524BDB083EDDFB0ECE0AEE6DFA8E7E5A8D2D397
DEE7B0D8E7B0D5EAB1BEDA9DC6E9A7D7FFB9B2DA93D8FFB9
D8E1A0D8E19ED8E29BD8E299D7E399D6E39BD3E4A0D1E3A7D3E7B20C200095A77795A36E
D8E3A7939D58D0D488DFE0A4F4F2DDFFFFF3D2D6B3C5CF9AD6E7A3D4E8A0C0D78FD5EFA8
DAF1ABB7CE86D2E89FCDE19CE0EFB8FCFFE36E70650E0C0DE2D8D9FFFBFFFFF6FCFDF2FA
FFFBFFFCF5FDFFFAFFFFFCFFFFFCFFFFFDFFFFFDFFFFFEFDFFFEFBFFFFFAFFFFF6FFFEFA
FFFBFFFFFAFFFFF9FFFFFCFFFFFCF3FFFFE1D6E19FD4E38ECFE384DDF297DFF0A9D2E1A8
8F9C700008006F7E53D2E3B7C7DAADD3E4B8D8E5B9D4DDB2D5DAB1D3D9AD9DA478C8D4A4
CADBA7DEF3BBBCD49AC8E0A4D1E5A8DCEEB0D0DEA13B490ECFDEA7E4F2C1C4CBA10E0E00
6D64459F9476C5BB98969167D8DAA8DFE7ACD8E7A6D5E6A0D5E6A2DAEBA7D9E7A9CDD999
A4B16CD0DB96D0DB97D1DA99DDE6A7DBE1A5DCE1A7DEE3A9EEF1B8ABB0769FA569A2AB6C
E7F0AFD2DD99DAE5A0C9D992D0E69EDAF4ADC2DC95D9F3ACBED992D4EFA8D2EDA6C7E29B
BBD991C0DE96B6D48CC5E39BCCECA3D5F5ACC1E198D1F1A8D1EFA5CDEBA3C9E1A3C9DEA3
CEE0A2D5E4A1D5E195D1D98ED7D9988B89583E371DCEC2B6FFFCF3FFF4E4A0977A7A8052
C9E9A8BFEAA2C4EDA9D9FFC1EDFFD6CBE9B3CAE7B1CEE7B08AA16BC7DBA6C6D8A8F8FFDF
F9FFE4F6FFE9F7FFF1FBFFF1CBD4B7A3AF89F1FFD7D2E8B9C8E3AED6F8BCD6FDBCB1DC97
BEECA4C0F0A6BEECA1C2EEA380AA62C3EBA4C8EDA8C6E6A3D4ECAED0E6A6869F5BDCFAB0
C2E296C7E698CAE49BDBEEACA6B175696E38A7A574D9D7A6E0E0ACD5D89FDCE5A6D1DB9C
D8E1A8C6D39BD6EAAFC8E0A2CBE8A6C8E7A4C5E4A0CAE7A4
E1DCA2DFDDA0DEDEA0DDDF9EDBE0A0DAE0A2D7E0A7D6E0AC9EA77A081100D1D8AED0D3A4
55551FA5A567DDDA93E8E1ABFFFDEDFFFDF4FFFCDFFFFFD2D4DA9AD5E09BE2EFAAD1E09D
CFDE9BE3F2ADD1DE98DBE6A4D7DEAAF5F6D67D766E0600008C8283FFF7F6FFFBFFFEF3F7
FFFBFFFFFBFFFBF4FCFFFBFFFFFDFFFFFDFFFFFEFBFFFFF8FFFFF6FFFFF3FFFFEFFFFFF1
FFFBF5FFFDFDFFFBFFFFFEFFFFFFF3FFFFE3DBE3A8DAE69AD4E390D5E698C6D496D6E4B1
8A976C091600000A00000B00000B001C2D03232F07060E00020600010600010600081100
000F00C5D6A9DFF3C2CDE1B0D0E0AFD3E1B0D0D9AA555E2FD4E5B1C6D6A5D4DDB2050700
6E6848A3987C9B907077724CDDDFAED6DEA5D1DD9FDBEAA7D3E29FD3DF9FDCE6A9DAE2A6
959C59CFD492E8EAABE5E7A8DCDCA0DBDAA1E4E1AAD6D39CD8D59EE3E1A8A2A067545418
DEE0A1E0E2A3D6DB99DFE8A5DEEFABC0D590D6EAA5D2E7A2D3E8A3D2E9A3C8DD98D0E7A1
CAE19BD5EFA8445B15D9F3ACCDE7A0C7E29BCDE7A0CDE8A1C7E59BCDEBA5D0E8AACEE3A8
D2E2A4D9E5A3DDE89CDDE399E6E6A6E2DCAC5C5038FDEFE2F8EAE1FFFCEDFCEED1545529
CCE4A8C1E4A2C7E6AADAF7BFF1FFD7C9DFB0CDDEB1D1E1B4909C6EDCE7BCD7DFB6F8FFDB
F9FDE2FFFFEDFBFDF0FEFFF0A6AA89ABB087E9F2C3D1DDAB273A03C8E0A4C2E0A0CEEEAB
C5E9A3C8ECA6C5E9A1C9EAA387A662CAE7A4CFE9A8CBE4A3D2E6A9CDE1A28CA561C6E298
CAE99DD2EEA3D2E9A3CDDD9CCED69D5C5C2A979062DFD8AAE5E2AFD4D39BE3E4AADADEA1
E0E3AAD6DBA3D5DFA3D9E7AAE0F3B3BBD08FE0F0B17C8C4B
B7B07AB4AF78E9E8B0D6D9A2D9DEA8D3DBA8DAE1B590986F7A805C404423BDBF9AD0CEA7
AEAC7CB4B17AECE8ABD8D0A1ECDBD1FFF5F0EFE4C8ECE8B9CFD192B2B975A1AA67AFBA78
939E5CAEB975ACB671979D5D909261E0DCBF5E534F0800008F8583C3BCB6DCD4D2C0B8B6
ACA3A6C6BDC0E6DDE0EFE6E9A6A0A0C3BEBAE3E0D7E5E3D6C5C7B2AFB199C2C5A8E6E9CC
CDCDB5EBEAD8C1BEB5BCBCB2D0D1C1C7CAAD9AA070B1BB7FC4CE8FB7C286AFB88BBEC9A1
818C642E3C0B2434002A3D002639021E300025320417200022280030360A232900313A0F
5C693D041500000B00000B00011000000900000600030B00000B00000C00010C00010500
0C07000A010032290A928C68A3A576868E557B8749849352808C4A7783437B85487C8546
5B612152571590925382844591915568662B9C975F8A854D85804877753C98965D656529
5D5F208B8D4E777C3A9799588785487D7B3E938F5287854886844789894B7F7D40727234
B8B87AB4B677A1A1635D5F20989A5B989D5DD0D293C0C686BEC784BAC485B8C087D1D49F
ADAC74989457CFC882C7BD78D2C287A8916783665492716AD8B6B4FBD9D0DABAA3654D29
CEC898C3C38FD2D0A0EDE6BCD5C8A5E0D1B0DBC8A8E2CEAD8D7654D1B899DCC1A4F7DBC3
E2C7B4FFEADEFDE0DAEDCFC5DFC0A4CCAE88E7CBA45942187F6D3FA89A69B1A772C8C38B
D6D199B8B3799C975DCCC78D958E57CCC38CB2A771BEB47FCFCC9794945EAAB074C6D18F
CED995CBD590C9CE8ECDCB92DFD3A36653289F8560E4C8A3AC936AB39D6EB09C6AAB9C65
B8AB74BAB178B0AB71B4B478DBDFA295995CA1A165767437
DBDAA4787B46676E3A97A16F7787584253296B7B566A7857192406878D71D5D8BBCCCDAB
A8A981A6A879CCCF9ADAD8AFF7EDE4E3D8D2C7C2A5EFEEBED7DD9D98A45C8D9A55C4D390
BCCB88B1BE79B0BD77B2BC7DCACD9EF7F6DA3F37340D0409E9E1DEFFFFF6FFFEF8FFFDFA
FFF7F5FFFCFDFFFCFDFCF7F4FFFEFAFFFFF6FFFFF1FFFFEDEFF2D7D5DBB9D3D9B3DFE6BD
CFD6ACD8DEBAFCFFE7FFFFEFFDFFEBFCFFE5D7DCB4D6DCAED0D8A9E1E8BFF6FBDDE6ECD0
CCD3B1AEBA88D4E3A0C6DB90D3E8A7D1E5A8D9E8ADCDD89ED4DBA5D2D9A39FA873848E59
DEECB7BED09CCADEABDAECBCD0DFB4D1DCB4A8AC874D552CC8DCA9DBF2BECFDCB0040A00
333011080100393215938F6AD6D8A9CCD39DE1EDAFC5D493CDDC99D3DF9DD7E1A2E3EDAE
CFDA98A7B26EB4BD7CD9E2A1D7DD9FE6EAADD7D89EE8E9AFE5E6ACD0D499F1F5B8E2E8AA
D1DA99C4CF8D909B599DA461A7A568C9C387E2DCA0E9E3A7DDD99CD3CF92E2DEA1BCB87B
B8B679A5A366ADAB6EA09E61A3A3655B5B1D828244A4A667A1A865A9B271A2A76FA2A570
A2A36A979558B6B26BB0A963A79B5FB4A176AF948183645F674543D4B2A98A6753624825
A29865A19F66ADA672BAAF819A8B64A4906DB39D78D2BA947A6139BB9F78BFA37ED1B492
A98E71B0947EAE9181C3A490B3926F88673EAC8D61B6996D664E1E6F5B289D8D59998C55
A69962AA9F67A3965FBEB17A766730AFA069A4935FB3A671A49E6C8E8E5893985EACB576
A3AE6A9FA865A0A165A6A169B4A6775640179A805DC8AC87957952B0986CD9C593A79861
ABA166ACA6689A99598D8F508E9353767B3B838345A4A265
CEDBA3B6C790A9C08ACEEAB99DBE9181A47C9ABC9B688569435942DAECD4D1DFC6DAE4C9
CFDAB8DCE8C0E4F1C5D2DEBAF6F9EEFFFFF6F2F9D8DEECB7D0E49FD6EEA2CEE89FCCE69D
CEE8A1D5EFA6C7DF95D7ECA9D5E3B2FEFFE8757573010004C6C5C0EAE7DEFFFFF8FFFCF8
FBF6F3FFFBF8FFFEFBFFFAF6FFFBF5FAF8EBF8F7E3F5F8DDEAF0CED9E1B8D2DBAED3E0AB
D6E5AACDDCA5FBFFDFF9FFE3FAFFE8FEFFEADAE0BEDBE1BFE8EBCED0D4BDFFFFF3DDE1D0
E1E7CB969F70DEEBA6D3E695CDE597CDE599D6EBA0D3E39ADEEAA2D6E29A96A15C5C6B26
D5E9A4D2E7A4D2E8A8D3E7AAC3D29BDFE9B5D2D8A8495321CFE6AED0E9B2C8D8A9000700
3231120702002C2709A4A27CE6E9BCD4DDA6D8E6A8DFEFAECCDD99CEDD9AD9E4A2C7D693
DBF0ABC9E39C617834CEE3A0D2E5A3C9DC9ADDEDACCADA99D9E9A8C2D291C8D897CCDF9D
D2E7A4D0E7A1C4DB95D2E7A28C9B58727E3C828E4CCFDB99E6F2B0D9E5A3E5F4B1CFDE9B
DAE9A6CDDC99D5E6A2D9EAA6CCDD9992A35F95A96490A45DADC37AC9E098D3E9A9BED496
D6EBAACEE29BD6E99AD6E799DBE6A4DBDFADE0DCC3695F5353443DFFFBEF9C8870847B50
D4E19CCFE799CFE39CDCECABD0DB9FD0D89FD4D99FE5E9AE9A9C5DDCDE9FD7D99AE2E6A9
D6DBA1DFE3B0D6DCACEAEDBEE4E1ACB9B27BC1BC84DFDDA48E8D54626629D1DA9BDDE8A6
CDD896DAE6A4D2DD9BDAE5A395A05EDCE5A4D7DD9FD7E1A4D2DFA7D9EDB2B4CA8CD5EEAC
CCE7A0CFE9A2CFE4A1D5E3A6D1D5A2656333696238B2A980DCD3A8F2ECBCFFFFCFD7DB9E
D7E19CC4D189CFE099EDFFBAD4E9A4738843D8EBA9D2E2A1
9AB274C3DFA4C9ECB4BDE5B3B7E4B9C0EECAAED9BD577D64A0BDA9F1FFF4E9FAE7F8FFEF
C8D6BCCBDCBCF5FFE4ECFFE3EDF9EFF8FFF6D4E6C0CBE3A9C4E298CAEB9AC3E598C6E89C
CDEFA5CCECA3CEECA2BFDA97D7E9B9F2FFE51D232105080DE8E9E4FBFDF2FFFFFAFFFFFA
FFFEFDFFFDFDFFFDFDFFFEFBFFFFF8FFFFF3FFFFEDFFFFE6EEF6D1D9E4B9D3DFADD4E6AC
CBE29CCEE5A1D4E8B3C5D6ACFBFFE6FCFFE8EDF4D3FFFFE6FFFFEDE9E9DDFFFFFBFFFFFA
E9ECD9ADB58CCEDA9AD5E897C9E493C5E18DCCE391D1E493DAE899DBE99ABBC97A92A353
B0C576CEE69AC8E096D3E9A1C9D998D7E3A5E2EAB1707B41C5DDA1C6E2A8D5E7B5030E00
4748281C1900605D3C8A8A649FA577DEE9B1BECE8FDDF1ACD0E49DD7E8A2DBEAA5CCDD99
CFEAA3BEDE95A1BF79BBD993CAE5A0C9E29ECAE19DD3EAA6D2E9A5D4EDA9CDE6A2CCE7A2
CDEBA5CFEEA8D2F2A9CAE8A0C7DC97D1E5A0C4D5917286411A2B00C5D994C0D48FDCF1AC
D4E9A4D3E8A3CCE19CCBE29CC8DF99CDE49EC5DC968FA65E8EA459A9BF76D6ECACC8E0A2
D4EFACC6E298CAE594CEE998CADF9ACCDAA5F9FDE22B271B3D322CFFFBF1AE9C869A9669
CFE79BC9F097C2E591CDEE9FD3EDA4D0E7A1CFE39CCBDF978B9D51DFF2A3D4EA98C9E090
CAE296D7F1A8C2DD98BCD593D4E3A2D0DB99DCE6A7D2DE9C94A463819550D3E8A3D1E8A2
CFE9A2D7F1AAC9E39CC7E19A8AA15BD0E79FD0E69ED0E5A2E6FABFECFFC890A86AC2DF9C
C7E59FD2EDA8CCE2A1CFE1A3D0D9A4BDBF9059562D635E34C6C295FFFFD0FFFFCFC4CE91
C8DE95D3EFA2CEEDA1CBEDA1BBDF977A9E58CBEAA7C6E3A3
2C49060011000013000017004F825756896846765C5C8672DFFEEEEEFFF5F7FFF6F8FFF3
CDDAC6C2D1BAF2FFEBF4FFF1F4FFFBF2FFF4C4DDB5D2F0B4D2F4A8C4EA97BBE293CFF5A8
ACD287D3F7ADCCECA3D3F0AECCDFB1F7FFEC72777A000009FCFFFFFDFFF9F7F7F5F8F8F6
FFFDFFFFFDFFFFFBFFF8F4F5FCF9F4FFFFF3FFFFEFFBFFE5E7F1CCD3E0B4C9DAA6C8DEA0
C8E49AD6F4AAC4DDA3C7DDAEF8FFE1F4FFDEFCFFE1FEFFE4F2F5E2FFFFF8F0EEF1FFFEFF
AFAFA5F1F6D8D9E2ADD1E29CD4EEA4CCE89BD0E89AD5EA9DD2E395DAE899E3F1A2D4E795
839A48D5EE9BD2EB9ADCF4A6DBF0A5D1E19ADDE6A5919D5DD0EAA9C5E1A6D9EBB9000800
797D5A04030074745294966F58602FD3E0A8D6E9A9BBD08BD2E8A0D3E9A0C3D78FDDF3AB
C5E39BD4F5AECBEAA47C9A548EA962CAE59ED8F2ABC6E099BFD992D1EBA4CEE8A1D0EBA4
CBE9A3C5E49ECCEBA5C3DE99CBDC98D5E19FE1ECAACCD896CAD59365712FE0ECAAD1E09D
DBEAA7D6E5A2CFDE9BDDEEAAD2E39FD9EAA6E2F3AFCDDC97A0AA63989F59CBD397DEE9AD
D8E8A7C9DD95D3EA98D0E797CFE09CD7E1ADFFFFE8251B125D4847FFEEEAD6B6A79D8E65
C9DF94CAF397C5EB94C4E795C6E297C5DF95DAF2A6CDE4966C8430C6E089CCE98FC3E187
C6E891D0F49DCBF19ED7F7ABD3E9A1D1E29CE0F1ADD3E7A0798E49CEE59DD2ECA3C2DE94
C5E399CEECA2CEECA2CDEBA188A65CBBDA8EC5E196D7EEA8FEFFD1FDFFD18B995ECFDFA0
D6E6A5D7E7A6CCD89AD8E0A7E3E1B1E5DCB14E401B5A4C279D8F68E1D6A9FFF9C7F0F6BA
DBF5ACCDF2A4B2DB8FC9F3A9BFEAA38BB573001B00C2E8AB
7B964F607F3B799F6256824F71A179417254608D76E7FFFBEEFFFBF2FFF8F8FFF5F1F4E9
FCFFF4FBFFF4F6FFF1F5FFF4E7F7EDF4FFF4CDE6BCBBD99BBDDF92D1F7A4C6ED9CB7DE8F
E0FFB8CAEAA1C6E49CD9F1B3F7FFDCEAF3DE03030B00000CF6FAFDF7FBFAF8FCFDFCFDFF
FFFEFFFFFDFFFFFDFFFFFEFFFFFEFCFEFFF7FEFFF1FCFFEAFBFFE3F1FFD4E5F7C3DAF2B4
CEEEA3CEF0A4C3E1A3D5F0BBCDE3B4C7D8ACFBFFDDEAF4CFFDFFEBFFFFF8F9F6FDCAC7D0
B8B6B7FFFFEFFEFFDADFECB4C8E2A3C9E6A4D2E8A7D7EAA8C9D895CDDD96E2F2A9CFE195
677E30CEE998CBE697C5DD8FCCE196CBDB92D5DF9A99A563AAC483C5E1A4B8CC97041100
9DA37F03040070704EE8EDC5AFB987909F64E6FBB8CBE59CDEF6ACCDE59BC3D990D9EFA7
D1EBA4D5F0ABC7E09CD1EAA6A7BE787F944FA9BD78D5E9A4DDF1ACD7ECA7CCE19CCFE6A0
CAE39FC2DB97CCE7A2D4EDA9E6FAB5C6D592D3E29FDDECA9D8E7A4C6D7939CAD6998AC67
CEE29DD2E6A1CBDF9AD2E7A2C9DE99C7DC97D4E9A4D1E09BC8CE869C9D57A9AD70DAE4A7
D1E29ECCE299D4F09CCAE594D6EDA7D2E0ADD3D5BD271D14846F6EFFF6F4EFCDC16C5A36
CFE59CCBF39BC8EB99C7E79BCCE7A0CCE69FD5EBA391A75CBDD482DFF9A2D0EE94CEEF94
CEF298BBE38AB4DE88C4E999D5EFA5CEE49CBCD28A8FA65E89A35AD6F2A8BFDB91D6F4AA
C5E59AC2E297C6E69BD1F1A59CBC70C5E697C4E395D0E79FE8F3BBEFF6C2949F65DAE8AA
DAEAA9D5E4A3D0DC9EEBF0B8E9E7B7E7DEB5A1936EE5D7B29789624E46184943114D5017
879854BDD790D6F4AEC6E6A3C1E4A4C5E7AB000E006A8655
CADB94C8DF9BD8F6BAB6DBA8C7F0C8C1EACCC7EAD6EEFFFBE9F8F1FCFFFBFFFEFAFAF1EC
FFFDF8FFFDF5F9F9EFFCFFF6FBFFFBF8FFF4CFDFB8D0E5AAD1EBA1D3F09EC8E799CDECA0
C6E099CCE39DC4D795F1FEC6FFFFDFFFFFF159515E080113F2F5FCFBFFFFFCFFFFFEFEFF
FAF8FFF7F5FFFBF8FFFEFBFFFFFEFFFFFFFBFEFFF4F9FFEAF0FEDBE5F6CAD6EAB9C7E0A6
C4E8A0C0E69BBDE0A0D4F1B9BCD4A0CADEABF8FFD5F0FBD0FFFFE8F2F2E8FFFDFFADA6B6
F1ECF3F6F6EEFFFFE4F4FFD5C7DEB2D6F1C4E1F7C9E3F5C5D3E1AED5E2ACD3E1A692A565
7D9450C9E39CD1EBA2D0EAA1D6EAA3DBEAA5D7E2A08D9C5B849E5DE4FFC3CDE1AC000C00
6E744E0D0E00636442D2D7AEE3EDBB5C6E328CA35FC2DE94D3EDA3C8E396D0E89CCBE198
CFDF9ECBD99BDFEBABCDD999D8E3A1FFFFC8AEB776525B1A9099589099589EA766B1BC7A
CAD696DCE8A8D6E4A6CDE09EBFD992CFEDA5D5F3ABC3E199C7E59DD9F9B0B5D58CAECE85
BFDF96D4F6ACCEF0A6C2E69CCBEFA5C9EDA3CFF3A9C5E196DDE99DBBC177949F5DD0E3A1
CDE7A0C9EC9CC8F098C5ED97C4E89ECFEAB3D1E0C33030268B807EFFF9F6FFE9DD655635
D1E4A4C4E69AC4E29CC8E3A0D4EAACD4E8ABCADA9C485817D4E8A0D0E799B9D581C3E38E
D4F8A1C6ED9AC4ED9EC6EB9EC3DD93D2E89FA4BA7189A157D7F1A8C8E49ABBD78DD0EEA4
D2F1A5C6E599C3E397CBEC9DA7C678D4F3A3CDEC9CC8E299D0DFA6D8E5B098AA70CEE4A4
CAE3A1CFE6A2D0E5A4EAF8BDFFFFD4DCDBAF848158D4CFA7E2DFB4EBEDBCDDE2AC9CA167
86844B68662DAEAF76D9DCA7E4E7B8DCDFB43A3A1681815F
DEEEA3CFE39BC9E1A3CBE8B2BDDDB4C4E5C6E0FCE5EFFFF5F9FFFAFFFFFAFFFBF8FFFCFA
FFFBF9FFF8F7FFFCFDFDFCFAFCFFFDF9FFF3CADAB3CCE2A4CDE89BCFED97C8E593D0EC9F
CBE59ED6ECACD4E3AAE5EEC1FFFFE5FFFFF4362C3406000DF4F4FCF8FBFFF9FCFFF7F7FF
FCFAFFFFFDFFFFFDFFFCF9FFFDFCFFFFFFFDFEFFF8F5FCEAE5F0D2D8E7C0D2E3B6CBE4AB
C3E79FCDF6AAC2E5A1CCEAACCCE5ABD7ECB3C5D39ED5DEB1FDFFE4FFFFF3FFFDFFC8C2CC
FAF8FDFFFFFAF9FDE4E4EECBCDE2BBE5FED4EDFFD5E5F6CAD4E1B3D4E0AEB6C38D4B5A1F
C6DA9BD2E9A5CBE29ECEE5A1C9DD98D3E4A0D8E4A490A05F93AC68B9D394D4E8B5000900
646E4B000600707851D2DEB0C9DAA3B5C98A526925A1BB74D1E8A2D9EFA7D2E39CD1E09B
D5E1A1DDE7A8D0DA9BE0E9AADFE8A7BEC786DFE8A7959E5D949D5C959E5D96A15F899452
A5AF70CCD898B4C0808D9D5C99B26ECCECA3C7E59FC5E49ECBEAA6C8E7A3C8E7A1D0F1AA
AACC82C0E598C5EA9DC2E89BD0F6A9B4DD8FC1EA9ED3F3A8D6E89CD6E29894A45DCFE69E
CDECA0C4E999BAE490C6EFA1D9FDBDD9F4C7E5F2DE2D2E269B908EFFFAF4FFF9EA645737
D0DFA8C9E6A4D1EBACCCE4A6CAE0A2D2E6A7D6E9A94B5F1AD1E59DD8EEA3CCE798C7E794
CAEB9AC3E898CCF3A4C2E79ACBE79DD6EEA486A057C2DC93D5F1A7C3E197DAF8AEC2E297
CAEA9FCCECA0D0EFA3C4E39792AE61C1DD90CCE89BCFE9A2E7FBC0E6F9C2AEC189CFE4A9
CEE4A6DEF2B5DFF1B5E9F8C1E5EDBCDBE1B3959B6DC9CFA1E0E8B5CCD79FD0DEA3D6DEA3
BFB881483B078E8451DDD7A5DAD6A6EAE6B90A0200706843
D1E794CFE698D1E8A2D1E9AFCAE2B2C8E1BAE0F5D6F5FFEFF9FFF1FAFFF2FFFFF6F8F7F2
FFFEFDFFF9FFFFFBFFFCF9FFF9FFFFEAF9E6D3E8BFC6E0A1C6E894CDF293CCF194C4E793
C9E8A2CAE5AEC6D8B0ECF9DDF9FFF0DBDDD2070400040000FFFEFFFFFEFFFFFEFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFEFFFCFBFFFFFFFFFEFFFBFDFFF3F5FDE5ECF6D4DCE9BECADFA7
CBECA5C4EA9DC6E89ECBE9A3CFE5A4CEE0A4D3DDA9D9DEB5FCFCE0FFFFEFFFFDF6D6D5D0
FFFFF8FBFFF0FCFFECE5F1CDD2E4B4D7ECB4E1F4BCE3F5BBD4E3AAD5E3A88C9A5D4E5C1E
D5E3A5CBDB9AD0E09FD8ECA7CBDF9AD5E9A4D2E6A18DA15C90A65DD1E6A5D6E9BB000900
7C8F73041700556C3ED5EEB5CCE7A4C4DE97CFE5A4B1C385808B51757D429FA366DEE3A3
D7E3A1D7E8A4CFE09CCBDC98D3E4A0D2E6A1CFE39ED3E7A2D6EBA6BBD08BD5EAA5E0F5B0
C6DB96CDE29DD6EBA6CCE19EB3C885A4B976AFC183C8DA9ED1E3A9D2E4AAD2E6A9D1E5A6
91A661647C32DBF7AAC3E292CFF0A1C7E99CB7DC8FD4F4A9D2E7A2CFE09AD4E99E8CA554
CEEE99CBEC9BC6E89ECBE8AEE9FFD8F8FFF1A4A5A0483F409D8B8BFBE2DDFFF8E6483719
D3DCAFCEE7B0C9E3A6CAE5A2D5EFA6C4DF90CFEA9993AF5BCEEA96CCE997C8E593CCEB9B
D3F4A5CAED9DC4E795CEEFA0D3F1A7CFEBA184A25ACEECA4C9E9A0C2E49ACDEFA5C4E69C
D1F3A9B9D98ED5F3A9CBE79D526C2390A75FDCF2AACDE29FF0FFCCF7FFD6A3B480D1DDAB
D7DFAEEDF3C3FFFFD6E8EEBED6DEADCDD7A599A772C7D8A1D6E8ACC8DD9CD5EAA7D0DF9E
D8D99F75723B74733AE3E7ACDDE3A7D0D89CDFE7ABB3BD80
D0E894CDE695D0E79FD0E9A8CEE2ADCBE1B3DEF0CAF4FFE3F4FFE6F4FFE8FBFFF1F8FEF2
FFFFFDFCF9FFFFFCFFFEFCFFF9FFFFEBFCEAD8EEC7C8E4A7C4E793C7EF8FC6ED90C1E792
C8E8A5CCE8B7CCDFC1EDFAE9F8FFF5EBEEE7060600030000FFFDFFFFFDFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFFFFFEFFFDFEFFF8FDFFEEF6FDDEE5F0C8D2E5AE
C7E6A0C6EB9DCAEC9FCBEA9ECEE59FD0E0A1D4DEA9D7DCB3FFFFE4FFFFECFAF8E9EBECDC
F9FEEAFCFFEDF9FFE8E6F5CED4E7B0CEE2A3C6DB9AC7DA9ACBDB9CDFEDAF9AA968586726
D9E5A5CFDE9DD1E09DD6E7A3C9DD98D5EAA5D3E8A390A45D9FAF66B6C584DDEABF041300
6A7C64000B00587444C6E4A6CFEDA5CBE79DD5EBAABCCB908B945F686D376B6C32909555
B1C07DCBDF9AD9EDA8D5EAA5D6EBA6D3EAA4CBE29CC7E19AC9E39CD2EDA6C1DB94BDD891
DEF8B1C7E19ACCE69FD4EBA59DB16CA0B06FB7C789D2E1A8D9E6B0D8E5B0D7E6ADD3E3A5
8498537B9148B9D183CBE695D1F0A0CAEB9CD0F2A5C7E59DD7EEAAC9DE99D3EA9C799541
CDEB95C7E696CEEBA8CCE2B1F8FFECF9FFF5827E7F1E1216745F5EFFF7EFFFE2CD746141
E4EAC4DEF4C5D3EAB2CEE7A5CDE79DCFEC98C8E690C0DE86CAE793D4F4A1D0EFA1C5E496
C4E498C5E697C8E99AD0F1A2CCEAA0ACCA8294B26AC6E69DC2E49AC9EBA1C6E89ECEF0A6
BEE096CDEDA4CAE8A0C5DF98566D276C813CC1D590D9ECACDDF5BBE4F8C39FAD7A929B6C
BBBE91F0EFC3E2E0B7F2F3C7DDE5B49EAB7690A268BED494C5DB9AD8F2ABC1D890D3E7A2
E4ECB08D9057575D21CDD697E8F2B3CCDB98CCDB98D0E19D
CFE895CAE594CCE69DCFEAA7CEE5ADCAE2B0D5EBBDE2F7CEE2F4CEE7F6D5FBFFECF9FFF0
FFFFFAFBF9FEFFFCFFFFFDFFF9FFFFF3FFF2E6FAD7D5EEB5C9E99DC7EB93C8EC95C8EB9B
C9E7A9D7F1C4E0F0D6F3FEF0FCFFFAE9EAE50D0A05040000FFFDFFFFFDFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFFFFFEFFFDFEFFF8FEFFEFFDFFE7EAF4CFD5E7B3
C3E49DC7EE9FCBEE9EC8E79BCCE39BD4E7A5D9E6AED7DFB0F6FAD7F8FBE0BBBDA7FEFFEC
E3EBD3D6E1C3F8FFE3D1E2B6C4D9A0D3E9A8DDF2B1DBEEAECCDF9FD2E2A393A362667635
D4E3A2D2E2A1D2E39FD2E6A1CADE97D5EBA3CCE39B889C55D9E59DDCE2A6D3D8B0101600
5C664E142304677A4CD1E9ABC8E299C8E299D5EEACD8ECAFD7E8B1D1E0A5CBD797E1F0AB
91A25E93A76295AA65A7BC77C5DA95D2E9A3D3EAA4D7EEA8D0E7A1DAF4ADDAF1ABCCE69F
C7DE98CEE59FCDE49EC7DE96A0B86EABC379C3DA96D3E9A9D0E4A9CEE2A7CFE3A6CADF9E
DCF3ADCCE498D8F3A2CEEB99C8E998BBDE8ED1F3A6C3E39AD0E6A5C4D996D7EDA2789440
CDEA96C9E696D2EDAAC1D5A4F9FFEAFDFFF3BAB5B284767688716BFFF8EAF9D9C0806B4C
F0F4D3E7F9D3D3E6B8CCE1A8C0D793D5F0A3C5E091DCF9A792AF5FB9D588CDEBA1CBE9A1
CDEDA4D1F1A6CBEBA0C7E69ACDE8A192AC65B4CF88C9E79FC6E49CD1F1A8BEDE95D0F0A7
CBEBA2D4F4ABBFDD95DEF8B17A914BA6BB76E4F8B3C3D897CEE3A8D9EEB6F7FFD0FEFFD6
ECEFC0AAAC7D6061357D8051D4DBA8BCC6917E8D52C7DC9BC9E09CD2E9A1D2EAA0D2E69F
D6DEA29B9E6570753BE2EAAFCED79ED0DEA3EDFAC2D2E1A8
CCE997C9E696CAE69CCCE9A6CCE8ABC9E5ABCBE6B1D3EBB9D0E6B7D7E9BFEFFDDAF1FBE2
FEFFF6FBFBFBFFFDFFFEFCFFFAFFFFF8FFF8F3FFE6E1F7C6D0EBA8C9E89ACBEB9FCEEDA7
C9E4ADE7FCD5F3FFEAF9FFF8FEFFFDB9B9B70F0B08040000FFFDFFFFFDFFFFFEFFFFFFFD
FFFFFDFFFFFBFFFFFDFFFFFFFFFFFFFDFDFFFAFCF9FCFFF6FEFFF1FEFFEAEAF4D1D1E3B1
C5E6A1C8EFA0C9EC9CC4E395CBE59BD7ECA7D5E5A7C9D39FFDFFDB545A386A6F51F4FDDE
D3DEBCD5E3BFD5E6BCD2E6B3D5EDAFC8E19FC1D796D2E7A6D9EEADD6E9A9899C5A5F7230
CDDD9CD2E6A1D3E7A2D3E8A3CDE39BD3EAA2C2DC9382964FD2D995EBEAB1D3D1AB040200
676953282F10647040D7E7A9DCF2AAD5ECA4CCE5A3BED698CAE2A6D2EBAAC2DC93CBE399
C8DE96D3E7A2C5DA9594A964506520304500687D38C1D691D0E5A0C6DB96CDE29DD4E9A4
C5DA95E3F8B3859A554F661EBFDC8CC3E292D0ECA2CFEAA5C7E09FCAE2A4D1E9ABCCE5A3
B2CC8598B469C9E696BFDE8ECEEFA0C4E699C8EAA0CFEEA8D6ECACD3E6A6DDF3AA88A052
C3DE8FD4EEA4DAF3B2CFE1B1F8FFE7FFFFF3FFFEF8FFFBF8B49E93E7CAB8FFE8CD755E3F
FFFFE8F9FFE8EDFCD5E5F7C5D2E6A9DEF5AFD8F0A6BED88EBED88FD3EEA7D5F0ABC6E3A0
C6E5A1CDECA6CDEDA4CFEDA5CEE59F8AA15BC4DE97D0EAA3CFEAA3D1EFA7C1DF97CAE8A0
CCEAA2CBE9A1C2DD96C6E099E2F9B3B5CC86C5DA95D2E7A4D5EBADC6DBA2CDDEA7D7E1AC
D2D9A6E1E5B3DDDFAE9DA16E040B00BEC78E8D9B5EAFC280CAE098DAF2A8CDE599D0E49C
E4EDAEC3C88E8B935AE5ECB6C9D19EF9FFD3FCFFDC929F73
CAE999C7E899C7E79CCAE9A3CAE9A6C8E6A6C6E4A4C8E4A7C8E2A5CBE2ACE0F1C4E7F2D0
FEFFEFFEFFF9FFFEFFFFFEFFFAFDFFF9FFFBF9FFEDE6F6CFD2E7AEC8E19FC9E3A2CCE5AB
C7DDAFEEFFDFF9FFF4F9FFF9FFFFFF757376080405040000FFFDFFFFFDFFFFFEFFFFFFFD
FFFFFDFFFFFBFFFFFDFFFFFFFFFFFFFEFEFFF9FBFAFBFEF7FEFFF3FDFFEBE7F1CFCEE0B0
C7E6A3C7EE9FC8EB9BC5E697CCE89BCEE59DB8CB8B9BAA71C0CC9CFCFFDDF2FDD5DFEBC3
DDECC1C4D8A7C1D5A0E1F9BFDCF6B5D6F1AED1EAA8DAF0AFC8DF9BB9CE8B9EB370BFD491
CCE09BD4E9A4D0E5A0CFE69ECDE49CD1EBA2C7E39996AC649DA25FBAB57DE9E1BD0F0800
89836D201C00666839CED69BCBD893CEE29BD7EDACC9E3A4C9E7A7D1F5AFC6EB9BCAED9B
D1EBA2D2E7A2CFE49FD2E7A2D0E49FB0C47F90A45F889C5791A560CEE29DD4E8A3DAEEA9
DBEFAAB6CA85A1B570C7DF95CFF19BC9EF98CCEF9FC9E99EC3E09DCCE9A9D6F0B1D0EAA9
DBF6B1BEDA90B0CC81D7F6AACFEFA4CBEDA3BBDC97CCE9A9CCE0A5D0E2A6C5DA97839A52
97AE66C6DD99CBE0A7D2E1B6FCFFEAFBFCECFFFDF6FFFBF4C9B1A59A7B67F8D6BA8D7456
FBF9E4FBFFEFF0FBDDEFFBD3D6E7B1C1D596C8DD9A556C26D8F1ADD8F3B0CBE5A4C0DD9B
C6E5A2C8E7A3C6E59FCDE8A1D1E6A19CB06BC9DE99D1E6A1D3EAA4CBE59ED2ECA5CCE7A0
C4DF98D5F0A9CCE7A0D2ECA590A761DAF1ABC8DD98D1E6A3D7EDADC3D89DD3E5ABDBE8B0
D4DDA8DBE2AECACF998C9159E1E6AEA8B074869252DDECA9C3D78FD9EFA4CAE095CBDC95
D2DD9BD5DB9F888F59D0D7A4DCE3B7FEFFE1F6FDDEC3CCAF
C9E99DC7E99CC6E89CC7E99FC8E9A2C7E8A1C6E69DC5E59CC9E7A1C8E1A0D8EBB4DBEABF
F7FFE5FAFEF0FFFFFDFFFEFFF9FCFFFBFFFFF9FFF1E7F5D4D5E6B9CCE0ABCCE0ABCDE1B0
CEDEBAECFAE1FAFFF7F4F8F7FFFEFF5E595F040002040002FFFDFFFFFDFFFFFEFFFFFFFD
FFFFFBFFFFFBFFFFFDFFFFFDFFFFFFFFFFFFFCFEFDFDFFF9FEFFF4FDFFECE7F0D3CEDFB3
C6E4A4C6EB9EC9EB9ECBEC9DCEEA9DC0DA909DB26D798B4DD2E1AABBC996F9FFDADAECBA
CEE2ADDCF4BAC2DA9CE7FFC0F2FFCCDBF8B5C0DB98D0E9A7D7F0ACD3EAA6B5CC88DAEFAC
D1E6A1D4EBA5CAE199C9E39ACAE49BD0ECA2D2F0A6BCD28A757A386560299088630F0500
3C311B0A01002F2B0085864C9AA15E9DAA65C6D89AD6F0B1CBEBAAC4EAA1B9E590BEE892
C9E59AD2E7A2C7DC97C4D994D9EDA8DBEFAAB6CA8591A25ED3E4A0E5F6B2C5D491CEDF9B
CCDB985B6C28B6C783CCE299CDEF99C1E990C4EA97C8EAA0C5E4A1C8E4A7CBE4AAC3DB9F
D1EAA9C8E19F48631EC7E29DB0CA89C5E2A2C8E4A9CFE8AFCDDDACDBE9B6D4E6ACACC083
A6BA7BD9EDB2CEE0AEDAE6C0FEFFECFFFFF3F0E5DFFFF6F0F8DDD2745541C19F84BCA287
E0DACAFCFFF3FCFFECFCFFE1F8FFD5D1E3A9DCEFAF4A5F1CC3D998C6DF9EC5DFA0C9E3A2
D1EEACCDECA8C4E39DC7E29BD9EDA8BECF8BD8E9A5D5E9A4D1E6A1C6DD97D8EFA9CDE7A0
CFE9A2C5DF98CFE9A24D6720C1D892D2E9A3DBF2ACCDE4A0CCE2A1C6DA9BE2F6B7CDDD9F
9FAD72767F465B6328C8CD93CED498E0E6A887904FB5C27DCBDB94D4E99ECEE499DEF0A6
D5E09C9BA3676A713BCDD3A3DEE4BEFAFFE1FEFFEFFEFFF3
C8EA9EC7EC9FC6EB9EC4E99CC4E99CC5EA9CC8EB9BC8E998CBEA9AC8E499D3E9A8CFE1AD
E7F3CFEAF2DDFEFFF8FEFFFFFDFEFFFEFFFFFAFFF6EEF8E0E5F0CEE2F1C8E2F1C8E1F1CC
E4F1D7F0F9E8FCFFFBF7F8FAFFFDFF88838A040005040004FFFDFFFFFDFFFFFEFFFFFFFD
FFFFFBFFFFFAFFFFFBFFFFFDFFFFFFFFFFFFFDFFFEFEFFFBFEFFF6FDFFEEE8F1D6D1E2B8
C9E7A9C5E99FC8EA9DCDEE9FCFEC9CC0DB8CA7BF7591A661C9DD9ED8ECB1F1FFCDD8F0B6
C7E1A4C3E09ED5F3ADCEECA4CFEEA8D3F1ABC9E7A1CFEAA5C7E29DBDD692A5BC76D2E9A3
D0E7A1D3EAA4C7E198CBE79DCDE99EC9E89CD3F2A6CEE59DADB874898A51817D57120B00
352B10483D1D544C1D9792589292525D6323859358C6DBA0CFEDADC8EEA5C5F19ACFFAA1
C9E59ADAF1ABDBF0ABD2E7A2CCE09BC0D18DAFC07CACBB78CFDE9BD1E09DD5E19FE7F6B3
BAC684788744DAE9A6D1E79ECAEC96BEE68EC7EC9ED7F8B3D6F2B7D2EBB4D3E7B4CEE2AF
CDDFABDBEEB75A6D36E5F8C1D4E6B4DCF0BFD9ECBFC8D9AFC8D4ACCFDBB3D8E5B9B7C798
B4C493D9E9BCCCD8B2CFD8BBFBFEEDFFFFF69C918DFFFAF6FFF9EF6B4E3EAD8D76C8B098
B6AEA1F6FAEBF9FEE7FAFFE1ECF8CAD5E4ABD8EBAB889D5AC8DE9DD9F2B0D7F1B0C9E3A2
C7E4A1CBE9A3CCECA3D3EEA7B1C580B9C885E0EFACD8E9A5D1E29ECFE39ECFE49FD0E7A1
DCF3AD839D5692AC6579934CD6F0A9BFD992CDE7A0CCE39DCFE6A2DBF0AFC2D79696A969
83935495A365848E51D9DFA1E4E8ABDBE0A0585D1DA6AD6AD1DE98C5D78DE9FEB3C3D88D
CDDA94717B3C6E773ECFD7A8E0E6C2FFFFECFFFFF4ECEDE5
C7EC9FC8EDA0C7EC9FC4E99CC3E89AC5EB98CAEE97CAEE96C9EB94C6E693CFE9A0C6DC9E
D7E6BBDAE5C7F3FAEAFDFFFAFFFEFFFFFEFFFEFFFBF9FFF1F8FFE9FBFFE8FBFFE8FBFFEC
FBFFF3F6FCF2FEFFFFFEFDFFFFFDFFC2BCC60500060C050DFFFDFFFFFDFFFFFEFFFFFFFB
FFFFFAFFFFFAFFFFFBFFFFFDFEFEFEFEFEFFFCFDFFFDFFFCFEFFF8FBFFF0E8F0D9D3E1BD
CFEBB0C7E8A1C6E69BCBEA9CCEEB99C9E694C3DE91C3DB91D8EFABC5DE9DC5DD9FCBE5A4
CEEBA8CCECA3C7E79BC8E89CCDEDA4D2F1ABC3E19BC3E19BCFEAA5D3EEA7B1CB84CBE29C
CBE29CCEE89FC7E399D3EFA5D0EFA3C3E397C9E99DC7E399DBECA8D0D9A0D8DBB0090600
888164877F5BB1A978E2DCA2E9E5A666672B636A34B5C38ECCE4A8C4E39FBDE58FC2EA92
CDE99ECAE19BCBE09BD0E49FBCCD899AA966A6B572DBE7A5D5E19FC3CF8D939F5D8D9957
8E9A58DEEDAAD2E19ED3E9A1CDEC9CC3E696D4F3ADEDFFCCF1FFD4EFFFD5F5FFDDFBFFE1
FAFFE0F8FFDBAEB991F2FDD5FAFFE1F9FFE1FBFFE8F8FFE5FCFFE8F7FFE3FBFFE5CED9B7
D7E2C0F7FFE2FCFFECFEFFF1FFFFF6F8F3EF120606F4E2E0FFF7F262463AC8A997B69F8D
B3AD9FFFFFF3F9FFE5EDF5D0D9E5B5D5E4A9D0E3A1D2E7A2839855B9D08CD6EFADCEE9A4
CBE69FCEECA2CBEA9EC8E4996B7C368C9B58D3E29FD2E19ECEDF9BDDEEAAC8DC97D6EBA6
8CA15CC6DD97CFE6A0C9E39CCCE69FD5EFA8C9E39CD1EBA4D3E8A3CADF9A95AA67C8DD98
CADF9CDBECA8DCE8A8DDE3A3DADC9DC0C082939355CACC8BDDE6A3DEEBA6C2D68F6E823A
424F09737E3CB5BE85D8E0B1DEE4C2FAFDE8F5F7ECFFFFFB
CBEDA3C1E399C7E99FCAECA0C0E597C7ED9ACFF59EC6EA90C5E88CCBEC95CAE797D1EAA8
CDDFABD5E3BFF7FFEAFCFFF6FFFFFFFFFEFFFFFFFFFEFFFAFEFFF4FCFFF1FCFFF1FCFFF3
FCFFF8FEFFFBF9FAFCFFFEFFFFFDFFD2CCD6040007040005FFFDFFFFFDFFFFFFFDFFFFFB
FFFFFAFFFFFAFFFFFBFFFFFDFEFEFEFFFFFFFEFFFFFEFFFFFEFFFBF9FCF1F2F9E7ECFAD9
D8F1BAC3E29EC5E39BCDEC9ECCE997C8E593C8E392DAF5A8CDE7A0CCE7A2CCE7A4CAE8A2
CAE8A0C9E99DC9EA99C8EB99CBEDA3CBECA5C1E09AC5E39DD4EFA8C6E19AB8D28BC4DE95
D4EEA5C5DF96CBE79DC6E297C8E79BCAEA9ECBEB9FC6E69BCFE9A2C6DA9DDAE7B9000600
6E6E4AD9D6ADE2DCA8C0BA7E9E985C65632A868555E4ECBDD4E2ADCCE2A2C1E090D2F29D
CBE59BD1E8A2D1E6A1CADE99AEBF7BA3B26FDEEAA8D2DD9BD3DE9CA6B16F869250929E5C
B1C07DCDDE9AD3E4A0D4E9A4D4EEA5C4DF98CFE7A9EBFFCCF9FFDFF2FDDDFEFFEAF7FBE4
FFFFECDBDDC5E2E2CAFFFFE8FFFFEDFFFFEFFFFFF3FAFBEDFEFFF0FDFFF0FEFFEFC8D0BB
D3DBC6FCFFF3F7FAEFFEFFF9FFFFFDFFFDFF080000FFEEF0FFF9F660453EC0A498B39D8F
B7B4A5EBF0DCFEFFE6EFF8CDD0DDA7D2E2A3D5E9A2CCE297869C53D3EBA1C3DD94CAE69C
DAF6ABC1E092CBEA9ACCE798657932A1B06DDAE9A6CADB97D4E5A1CEDF9BD2E6A1CCE19C
859A55D6EDA7D3EAA4CCE69FD0EAA3C3DE97D2EDA6CAE49DCEE39E8DA35B91A862C4DB93
D8EFA9D0E69ECCDB98D8E1A0DDDD9FE6E2A56D692C9E9C6190945797A16497A7681B2E00
6B7A35B8C482D5E0A6CFD8A9E1E7C5F9FCE7FFFFF6FFFEFA
C7E79ECBEBA2C9E9A0C9E9A0CEF0A3CBEE9CC2E68FBFE389C9EC90CCEF95C8E895CDE8A1
C9DEA5CFE2B4F2FFE0FAFFF0FFFFFFFFFDFFFFFFFFFFFFFDFEFFFBFEFFF8FEFFF8FEFFF8
FBFDF8FAFCF9FBFBFDFFFEFFF0EDF4655F690E08120F0A11FFFDFFFFFDFFFFFFFDFFFFFA
FFFFF8FFFFF8FFFFFAFFFFFDFDFDFDFFFFFFFEFFFFFEFFFFFEFFFDFDFFF7F8FFEFF3FFE2
DBF2BED4EEADD0EBA6CAE69BCCE999C8E591D6F1A0B7D484CCE89ECAE8A0CAE8A2C9E9A0
C9E99EC8EB9BC8EB97C8EB99C2E498CDEEA7CBEAA4CCEAA4D4EFA8C3DE97A8C279A2BC73
7B954CD5EFA6D3EFA4D4F0A5CAE99DCDEDA1C6E69AC9EB9FC8E89FD2EFAFD3E9B8000900
6D744BBEC0916C6B33837F42A6A167EBE5B1FFFFDAFFFFDDD7DEB2DEEDB2D4EA9FCAE390
CCE49AD2E9A3BBCF8ABDCE8A788744E7F3B1D3DE9CD7E2A065702E919C5ADDE9A7DEEDAA
D6E7A3DAEEA9D5EAA5CCE19CCDE4A0CAE0A0D7E8B2D2DFB4788162CACDB8F8F9EBFFFFF4
FFFFF4EFE8DEFFF6EDFFFEF4FFFDF5FFF8F5FFFDFBFFFBF8FEFEF6FFFFF6ECEEE3C9CCC3
E2E5DEFDFFFAFEFFFFFFFFFFF5F3F8FFFCFF4C4149F5E6EBFFF3F3705B589F86818E7E71
FBFAE8ECF5DAD8E2BDC9D5A5CFDEA3DBEFAAD9EEA3C9E090627A2CD1E99DD3EEA1C9E497
CBE79AC2DF8FD6F39FCCE7968FA35BD0E19DDFF3AED5E9A4D8ECA7C9DD98D8ECA7A6BA75
6A7F3AC9DE99D3EAA4CBE59ED0EAA3CBE69FD6F1AAC5DF986C823A9BB168D1EBA2D2EEA4
BEDA90CEE59DDEEFA9D9E2A1D8D699827C42675C265B541E95945E949B65819057DBEDB1
EAF8BACBD799DDE7B2E6EFC2C6CBABFFFFEDFCF9F0FFFFFA
C9E39CD4EEA7C7E29DBED992C5E39BC3E397C4E594D9FBA5C8EB91CAED93C6E693CEEA9F
CBE5A6D5ECB8F7FFDFF9FFECFEFFFBFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFD
FBFBF9FFFFFFFFFFFFFBFAFFFFFEFF010005040108030005FFFDFFFFFDFFFFFFFDFFFFFA
FFFFF8FFFFF8FFFFFAFFFFFBFEFEFEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFAFCFFF6FBFFEC
E9FDCCCBE3A5C6DF9DD6F0A7C2DD8ED5F09FC8E593DBF8A8CCE89DCAE8A0CAE8A2C9E9A0
C9E99EC8EB9BC8EB97C8EB99C1E397CEEEA5CCEAA2C8E69ED0EBA4CDE8A1C1DB92BED58D
9AB26890AA60BEDA8FB5D186DBFAACC7E899B9DA8BD4F6A9BFE39BB8DB99D0EDB7000C00
657244505825AAAE73D6D698E1DEA7D0CC9DFFFFDFFFFFE3C7C9A4EDF5C2D0E099CADF90
D0E69DD4EBA5EAFEB9879854455411CBD795CDD896E0EBA9545F1D6E7A38D7E6A3CDDE9A
C7DC97D2E9A3D1EBA4C6DF9BCBDFA0CCDDA6E7F3C5B1B896E0E3CEAEACA0FFFBF7FDF4F5
ACA2A3BEB4B3F0E4E4FFFBFBFFF9FBFFF7FDFFFBFFFFFCFFFFFCFBFFFFFAFBFAF6C7C7C5
F7F7F9F9F8FDFFFEFFFFFEFFFFFDFFFFFCFF695F67ECE1E7FFFBFBFFF2F2A89692867C72
FEFFEDE5F3D2CBDAAFCADBA5D3E6A6D2E89FCEE595CCE5925C7524CBE493D1EC9DC8E394
CBE697C7E291DEFAA6CEE99895AD63D5EAA5C7DC97CCE19CD2E7A2C6DA95DFF3AE879B56
7D924DCEE39ED4EBA5C9E39CCFE9A2C9E49DBBD99195AF66D1E79EC3D98EC5DF95D2F1A5
CEEEA2CAE69CD2E69FD8E1A0E2DDA56256228D7C4EC6B88BF2EEC1E0E3B6CEDBADD1E1B0
CDDBA6CCD9A4D5DEB1D5DDB6CED3B5FFFFEDEAE8DCFFFEF8
C6DB96CCE19CD1E8A4D6EFABD8F3AECFEDA5C7E69AC6E796C6E892C8EA94C6E693CEEDA1
CBE8A5D3ECB2EFFFD5F3FFE1FEFFF8FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FCFCFEF2F2F2F3F3F3FFFFFFFFFFFF00000200000477757AFFFDFFFFFDFFFFFFFDFFFFFA
FFFFF8FFFFF6FFFFF8FFFFFBFFFFFFFFFEFFFEFFFFFEFFFFFEFFFFFEFFFBFCFFFAFBFFEF
E6F5CAC3D79CE8FCBDC9E09AC9E195C6E19093AE5DC2DF8FCAE99DCAE8A0C9E8A2C9E8A2
C8EA9EC8EA9DC6EC99C8EB99C9E99ECBEBA2C9E79FC9E49DCBE69FCFE9A0D6EDA5DEF5AD
C8E09690A85E708A40DAF6ABC7E396C0DF91D2F1A3C7E99CD0F4ACDAFDBBBEDBA3000D00
1A2C006D7A44DEE7A8D3D99BDEDEA8EAE9BDFFFDE0CBC9B0A5A68771774BE5F1AFD4E499
CDE39BD5EAA5B1C580C7D89492A15EC5D18FDDE8A6D4DF9DD4DF9D939F5DD4E5A1C3D893
CBE59ECBE9A1C9E9A0CBE9A3DAEEB1D3E1ACD2DDB3DBE2C3FAFBEBFFFFFAB1A8ABCEC3C9
B7ACB2D5C8CFFFF5FCFFFAFFFFFAFFFFF7FFFFFAFFFFF5FEFFFAFAFFFEFBFFFEFDCDCBCE
FFFDFFFFFEFFFFFDFFFCFAFFFFFDFFF0EDF4C8C3C9726C6EF1E9E7FFFCFAF4E9E7D0CCC1
F2FCE3DEF0CAD5E8BAD7ECB3D3EAA6C8E094C9E28FD3EC99849D4ACFE897C6E192CCE79A
D5F0A1C7E291D4EF9EBDD887AAC47BD2ECA5C2DC95CEE8A1D5ECA6D0E5A0DAEFAA8CA05B
B4C984DAEFAACEE59FC6E099D1EBA4C6E19A9FBD75688239D8ECA4D6EBA0C9E598CBEC9D
C8EA9DC6E49AD2E7A2D4DD9EE2DDA6A190628F7950CCBA96E1D7B4D1D1AFD7E1BED1E1BC
C5D4ABFBFFDFFCFFE3F0F7D8FFFFECFFFFF1FFFFF4F2EEE5
DFEEA9D3E4A0E2F5B3EFFFC3DEF4B4D4EDACD0EBA6BDDB91CAEB9CCBEC9BC6E798CCECA0
C5E49EC3E0A0D4F0B6D1E3BBFCFFF4FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFFEFFFDF7F9F6FAFCF9797B78000100010103FFFEFFFFFDFFFFFFFBFFFFF8
FFFFF6FFFFF6FFFFF8FFFFFAFFFFFFFFFEFFFEFFFFFEFFFFFDFEFFFEFFFDFCFFFBFCFFF1
F2FED6D3E1ACCEE0A45B6E2CA0B66DA5BD6FB6D182D0EC9FCAE89ECAE8A0C9E8A2C9E8A2
C8EAA0C8EA9EC8EB9BC8EB9BCDEDA2C8E69ECDE8A1D3EEA7CCE69DC6DD95C9E098D1E79E
B0C67D869E54D5EDA1C9E497CBE79ACAE99BD4F3A5C4E498C2E19BC7E5A5D3ECB5000D00
42551EDCEBB2D5E1A1E2ECADD4DBA7DBE0B89FA189E3E4D2FFFFEAFBFFDC96A165A2B36C
7B8F488CA15CDFF3AE7586426C7B38DBE7A5E4EFADD5E09ED2DE9C8E9D5ADAEEA9D8EFA9
D7F5ADC4E69CBDE398CCEDA6D3E9ABD5E3AECED9AFCCD2B6FDFEF0F4F1ECFFFDFFCCC2CA
FFF8FFFFFBFFFFFBFFFFFCFFFFF5FDFFF6FFFFFBFFFFF9FFFFFAF8FFFEF8DBD6D3E9E5E6
FFFDFFFFFDFFFDFBFFFDFCFFFAF9FFFDFDFFFDFBFC14130F84817CF2EFEAFFFEFAFFFFF4
F8FFECDFF5CECAE2B2C5DEA4CAE5A0CEEA9DCFEC9AD0EC9890AB5AD3EE9FCCE49AD0E89E
D7EFA5C9E195C8E09499B467CCEAA0CCECA3CEECA4D1ECA5CDE7A0C9E09AAEC37E91A661
D0E5A0D5EAA5C7DE98C9E39CD5EFA8C8E39CA6C47C819B52C3D88DD3E89BC9E598CEEFA0
C6EB9DBBDB90D3EAA6E2ECB0DAD2A1736036B79F7DFBE3C7F9EBD1FCF8DFDDE5CDEFFDE3
EAF7DDFAFFEBFCFFEFF7FBEAFFFFF3FEFCF0FFFFF6A9A29A
C9D490D4E09EF3FFC1FBFFCDDAECB2C7DCA1D1E9ABD8F3B0CAE8A0CAEA9FC6E69ACEEEA2
C7E79EC2E19DCDEBADC4DAACFBFFF1FFFFFDFFFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFFEFF
FFFEFFF6F6F6FBFDF8FEFFFAF0F2ED000200050A06000100FFFEFFFFFDFFFFFFFBFFFFF8
FFFFF6FFFFF4FFFFF8FFFFFAFFFFFFFFFEFFFEFFFFFDFEFFFDFEFFFDFFFEFBFFFAFBFFF2
CED8B3BECA9894A16992A263C7DB94C9DF94D2EA9ECDE89BCCE89ECAE8A2C9E8A4C9E8A4
C8E9A2C8EAA0C8EA9EC9E99DD1EFA5C5E39BCAE59ED2ECA5D0E79FCFE69ED1E79ECBE198
778D44D0E69DCEE69AE3FBAFC6E194C9E598CEEA9DCFEBA0CEE7A3C2DA9CD1E6AE001000
60713BCDDFA3D5E5A4C8D698D0DDA8DDE7C2494E3AFCFFF3FCFFEDFCFFE3BCCB92DFF0AC
D6EAA5425611B9CA863D4C099CA866D6E2A0C5D08ED6E2A09CAB68859652CDE29DCAE59E
C7E99FC0E69BBEE89CC9EFA6D0E9A8CCDAA5D1DEB3DAE3C6FEFFF2FFFFFAFFFEFFFFFDFF
FFFCFFFFFCFFFCF6FAF9F4F8FEF9FFFFFDFFFFFDFFFFFDFFFFFCF4FCF3EA89817EFFFDFD
FEF7FEFFFCFFFFFDFFFFFEFFFFFFFFFEFFFDF4F6F17D8077A5A69EFFFFF6F1F2EAFAFFF3
F5FFECE0FBD2CAE6B5C0DEA2C6E59FCEEDA1CCEB9BC8E5936A8737CAE49AD4EBA3CDE49E
CDE49ED0E7A1D0E79F89A35ACEEEA5B9DD93CEF0A6C9E9A0C7E29BC8E29B92A963AFC47F
D0E5A0CDE29DCDE49ED3EAA4D1EBA4CAE59EBEDC94B9D38ABFD489D2E79ABDD98CCBEE9E
D3FAABC4E69ACDE4A0C9D299B0A87948320DC3A88DFFE8D3FFEEDCFFFFEDFCFFF3EBF8E7
F9FFF8EFF9EEF8FEF4FEFFF8FFFFF8FFFFF8DAD3CDBBB4AC
AEB873C3CC89C6D093D0DEA3E4F3BCD1E4ADC1D69DD2ECAFC8E5A2C8E89FC3E599CEF0A3
CBEDA3C8E9A2D3F3B0CAE2B0FBFFEFFEFFFBFEFFFFFEFFFFFFFDFFFFFDFFFFFDFFFFFEFF
FCFCFEFFFFFDFAFDF6FEFFF8FCFFFA040902000500000200FFFEFFFFFDFFFFFFFBFFFFF8
FFFFF6FFFFF4FFFFF8FFFFFAFFFFFFFFFEFFFEFFFFFEFFFFFEFFFFFEFFFFFBFFFCFBFFF3
F5FCDA9DA77595A068D6E4A6D0E49DD3E99EC8E094D4EEA4CCE7A0CAE8A2C9E8A5C9E8A5
C9E8A5C9E8A2C8EAA0C9E99ED0EEA4C9E59BCAE49BCAE49BCDE49CD8EFA7C9DF969FB36B
A9BD75C3D990DDF5A9BED68AD6F1A4CAE699BDDA8AD9F3A9D4E7A5DCEBB084925D091700
62713AC4D69ADDF0AED7EAAACDDEAA98A883B4BFAEE2EEE0ECF9E5F8FFE4D9ECB4C8DD9A
D5E9A4CFE39EBCCD89CDDC99D3DF9DD1DC9AECF7B5AAB674D7E6A3C8DC97DCF3ADCBE9A1
C5E99FC9F3A7C6F5A7C6F0A6CBE5A4EEFFC8A4B388FBFFE6FCFFF1F3F6EFE8E8E8F9F9FB
FFFEFFFFFEFFFDFDFDFFFFFFFFFFFFFEFFFFFCFDFFFDFDFBFFFFF3E5DECEAAA198FFFDFA
FFF9FBFFFAFFFFFEFFFFFFFFFEFFFDF0F5EEFCFFF6F3F9EBFCFFF4FAFFF2F1F7EBF8FFF3
ECFFE6DBFAD1D0EDBDCBEAAFC9E9A6C7E79CC4E596C6E597637F34C5DF98D3EAA6CCE2A1
CCE0A1D5EAA9D9EEAB8BA460C7EBA1BDE398CEF2A8CBEDA3D1EFA7D6F1AA9CB36DD7EEA8
D0E5A0CEE39ED6EDA7D2E9A3C9E39CCCE7A0CCEAA2CEE89F62772CCEE396D6F5A7C0E595
C2EB9CD0F4AACEE7A5949D644F4319A38C6CCFB09BFFE3D3FFFBEFFAF2E7FCFFF8F8FFFB
F7FFFFF9FFFFFCFFFFFEFFFFFFFFFDDAD6D3BAB2AFE4DBD6
F9FFBCC8D18E5C6428545F25C2CF9AE0F1BDC0D59DD4EDB3CCE9A7CAE9A3C3E599CBEDA0
C7E99FC4E59ECFF0ABC3DEA9FBFFEDFEFFFAFEFFFFFEFFFFFFFDFFFFFDFFFFFDFFFFFEFF
F8F8FAFFFFFDF2F5EEFEFFF8FBFFF7CBD1C7000300D1D6D2FFFEFFFFFDFFFFFFFBFFFFF8
FFFFF6FFFFF4FFFFF8FFFFFAFEFEFEFFFEFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFF4
EAF0CE4D5524DBE5B0CDDB9DDFF0ACD0E69DCFE59AC9E399CDE7A0CAE7A4CAE7A5C9E7A7
C9E8A5C9E8A4C8E9A2C9E9A0C9E79DCEEAA0D4EEA5CBE59CC9E098CCE39B99AD653F530B
D1E59DD8EEA5D2E89DD1E99DC7E295D4EFA2D4F1A1C5DD91D1E09F949F6356602C000A00
788750000C00000D00CBDFA0D3E7B2879973A1AF9EF6FFF7F7FFF3F7FFE6B9CE96D8EFAB
CBDE9CD0E49FD3E29FD8E7A4DEE9A7D1DC9AD3DE9C7B8745D9E8A5D1E5A0CBE59EC9E9A0
C4EA9FC2EEA1BAEB9CBEEA9FC9E4A1D2E5ADADBD90F8FFE5F4FBE9F8FEF4FEFFFFF8F9FB
FFFFFFFFFFFFFAFCFBFCFEFBFCFFFFFAFEFDF4F9FCFEFFFBFFFFF1D1C8B7FFFEF3F9F2EC
FFFCFFFFFDFFFBF9FCFCFEFDFDFFFAFCFFF8F0F8E9FAFFF2F6FFEEFBFFF3FAFFF3F7FFF1
F1FFEDD6F6CFBFDFAEC1E2A9CBEBA8C8EAA0C7E79BCBEB9F8EAA60CFEAA5CEE4A3D2E8A8
D2E6A9CDE1A2CEE2A389A45FC4E8A0C6EFA3C8EEA3C2E49AC8E89FC9E49D8EA861CFE6A0
D2E7A2CFE49FD4EBA5CAE19BC4DE97D4EFA8D3EEA7C7E19892A75CD6EB9EC4E395BEE393
C7F0A2C3E79DC2DB999EA77063572DAC9576987764EDCFC4FFEFE6FFFDF6FCFFFAF4FFFB
F9FFFFF2F9FFF7FAFFFEFFFFF9F7FAB4AEAEFFFDFAFFFDF8
pop
P
% End of image
1 0 0 r
.03 w
.9862 .58063 Mdot
.94419 .56672 Mdot
.90662 .56556 Mdot
.87107 .59744 Mdot
.86421 .62005 Mdot
.8436 .62005 Mdot
.8436 .67106 Mdot
.83997 .70121 Mdot
.81614 .71106 Mdot
.79473 .70874 Mdot
.77978 .72439 Mdot
.75474 .73251 Mdot
.741 .76845 Mdot
.72808 .81366 Mdot
.6998 .81714 Mdot
.67314 .86873 Mdot
.66183 .91395 Mdot
.64527 .93482 Mdot
.64365 .96902 Mdot
.63921 .98467 Mdot
.09025 .94235 Mdot
.03854 .83047 Mdot
.02966 .72845 Mdot
.08096 .61483 Mdot
.06803 .29543 Mdot
.1262 .19746 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.34127 0.666667 0.65873 0.984127 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FEFFFFFAFFF8F2FCD9DFF1B7CEE49BD0EB9A829E51CFEEA2C5E59CCDEDA2C8E998C9EA99
D3EFA5C8E2A1C9DFB0E3F5CBF8FFDDE7F9C9E4FBC3E3FFC4DFFBBEE3FFC5E1F8CAF7FFE6
FBFFF4FAFCF9F8F7FCF8F7FCF5F5F5ECF2E8E8F4DEEAF6E0FEFFFAFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFDFCFAFFFBFAFFFEFDD2CECDABA7A6FFFDFDFCF7F4
FBF8F1FFFFF8FFFFFDFCFDFFFCFFFFFEFFFFFFFEFFFFFDFFE1D5D5FCEEEBC1B2AF8F817E
E9DFDDFFFEFDFEFEFFF9FFFFF4FDFAF9FFFDFAFAFAFEFAF9FFFAFBFFFDF8686053FFFFE8
E4EDC2D2E6ABCFE8A4C3E495D5F6A5C1E490C7E897CBEB9FD1EEABCFDFA0B2AA6959520E
CFDF98D1DFA2E5D3AF8F7B60D0D7B5C6DEAEC4DE9FC7E59BCFE99FC6E298C8E6A8DEFAC9
F2FFE7F9FFEFFCFFE6C8D0A7B4BB88939D60D0DC9AD5E9A1CEE69CCEEDA1CCEEA2C6EB9D
C8EA9DCCED9CCBE896C2DF8DC9EA9BC9E99DCAE99DCCE89DCDE79DCCE89DCAE99DC8EA9D
C3E89ACAF1A2C9EEA0C7E79BD1EBA1CCE09896A15C555A18817B41E5DEA7CAC88DF0F9B8
C5DB93D3F3A7C3ED9BC0EB99C4EE9AC4E795D1EDA0D0E89CC8DE95D6EEA4C1DF9587A359
CEDF98D6E5A2DCEBB0C6D8A6D3E3BFCEDCC5E8F2E9FCFFFFFFFDFFFFFDFFC6C0C2CAC8BC
E8EED2CFDFB2D2E7ACCFEDA7CAE99DC9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99D
C9E99EC9E99ECAEA9FC9E99EC5E59CC5E59CCFEFA6DBFDB3E4FFBCD7F9ADC8DF97DAF1A9
C8E89DBFD990BEC07F585818D5E4A1C3D490F7F7B99FA464A4B974CEEEA5CDE8A1CDE7A6
CFEAB3C4DEAF9AB38B8BA37F82997D758C7259705612290F
FBFCFFFEFFF8D0DAB7D4E6ACD1E79CC8E39297B366C2E296CBEBA2CCECA1C5E697BFE091
C4DF98C7E1A4D5EBBDEBFDD5F6FFDBD5E7B7CBE2AAC6E2A5C0DD9DC3DFA4CFE7B5F4FFE0
FBFFF1FEFFFAFFFFFFFFFEFFFFFFFDF7FDF3F1FDE9F4FFECFEFFFAFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFCFBF9FFFEFDFFFBFAFFFEFDFFFEFDE7E1E1FFFEFB
FFFFF8FDFDF5FFFFFDFEFFFFF3F7FAFEFFFFFBF9FEFFFCFEDDD1D1FFFBF8FFF0ED493B38
766C6AFFFEFDF0F0F2FBFFFFF9FFFFECF5F0FFFFFFFFFEFFFFFCFDFFFCFA857D72FFFFE8
F6FED5CDE0A8D1EAA6C7E79BC8E998C9EC9ACBEC9BD0F0A4C1DE9BD0E09F91894867601C
D8E8A1D4DFA3AD9A79FFF2D9F9FFDDE3F9CAD0EAABCDE99FD0EAA0C8E49AC9E7A7DDF9C8
F5FFEAF3FFE7FCFFE4E6EEC5D9E0AC929C5FDCE9A4D7E8A1CBE399C8E79BC6E89CC2E79A
C3E598C8E998CFEC9AD0ED9BC9EA9BC9E99DCAE99DCCE89DCDE79DCCE89DCAE99DC8EA9D
C4E99BC8EFA0C5EA9CC3E598D2ECA2DCF0A8C6D38DA5AA68615C225F5821EBE9AEC7CD8D
D7EBA4C3E296BBE593C5F29FC4EE9AC2E895D3EEA1D3E99EC6DC93D2EAA0C7E59B9CBA70
495A14DDECABC1D097D3E5B5E8F8D4F3FFEAF0FAF1FAFEFDF6F4F9FFFDFFFFFEFBE5E3D6
F1F7DBF9FFDDC8DDA5C4E19ECAE89EC9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99D
CBEBA0C9E99EC9E99ECBEBA0C9E9A0C6E69DC8E89FCBEDA3CCF1A4CEF0A4C6DD95D0EAA1
C8EA9ECFEBA1C9CE8C5D5D1DD3E29FEBFAB7D1D193A0A263DDF2ADBBD991D1EFA7D0EAA9
DBF6BFF2FFDDF2FFE3F2FFE6DAEED3CEE2C9D9ECD6C3D6C0
FFFEFFFEFFF696A07BAABC80C5DC8EC7E38FC4E393D3F3A7C2E299C5E79DCFEFA3D0F0A4
CFEAA5D8F1B8E5FAD1E8F9D5F8FFE1CBDCAFC7DEA6CFECACD9F6B3D3F0ADD1EAB0E0F3C5
E2ECD1EAEEDFF4F5F0FCFCFCFDFDFBFAFFF6F9FFF4F9FFF4FEFFFAFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFBFAF8FCFBF9FFFEFDF8F4F3FFFEFDFFFDFCADA7A7F0EBE8
FFFFF8F8F8F0FFFFFDFEFFFFEEF2F5FEFFFFFBF9FEFFFDFFFFFBFBB7A9A6FFF2EF857774
504644FFFEFDFFFFFFF9FFFFF6FFFCF9FFFFFFFFFFF5F0F4FFF6FCFFFBFAD3CAC1FDFDE5
E9F1CAC7D9A5CFE8A6CCECA1B9DA8BC8EB9BC3E495C3E397CEEDA9D7EAA898904F68611B
D3E39CD8E3A7B3A07FF3DFC7FFFFE4E5FBCDCDE7AAC8E39CCFE99FCAE69CCAEAA9DDF9C6
F5FFE6EAF9DCFBFFE3D1DAADCDD49E889152D6E19DC6D790D2E9A1CEEAA0CAECA2C8EDA0
C7E99CC6E798CBEA9AD1F0A0C8EB9BC8EA9DCAE99DCCE89DCDE79DCDE79DCCE89DC9E99D
C9EEA0C8EFA0C4EB9CC2E497CAE69BD7EDA4DAEAA3D6DF9CB3B377706E35C8C68BE1E6A6
DDECA7CAE69BC8F2A0BCEC98C2EF9AC1E794D2EDA0D6EBA0C8DC94CEE69CCBEDA1B8D88F
889B59C1CF94E3F1BCCBDCB0E6F5D4F8FFEFF8FFF7FCFFFBFBFAF8F8F4F1FFFFF6DCDBC9
E2E9CAF9FFDFD2E6B5CBE7AACAE8A0C9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99D
CBEBA0C7E79CC7E79CCDEDA2CFEFA6CAEAA1C5E59CC4E49BC3E599D1F1A5CBE59BCBE79C
C3E99CD5F3A9CCD3905F6120D6E2A0BDC987E7E3A6A4A265A7BA78CBE9A3D0EEA8B6D391
E2FBC2F2FFDAF4FFE1F5FFE8DCEED4C9DBC5D2E1CEC8D7C4
C5C5C5DBDFD199A47CC4D698E1F8A8D0EC97CBEB98C3E598CDEFA5C8EAA0CDEDA1C7E79C
C2DC9BDAF1BDF6FFE3F3FFE5F9FFE3CEDFB2C9E0A8C2DF9DC8E69CC5E399C8E3A0CCE1A9
D6E2BCE0E5CEEFF1E6FDFEF9FFFFFBFBFFF9F7FFF4F9FFF6FEFFFBFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFEFDFFFEFDFFFEFDFDF9F8F7F1F1ECE7E4
FEFBF4FFFFF8FEFEFCFEFFFFF2F6F9FEFFFFFEFCFFFFFDFFFFF3F3FFF9F6C7B8B5FFFBF8
C0B6B43F3B3AABABADFBFFFFF9FFFFECF5F2FDFCFFFFFDFFFEF3FBFFF9FAF4EBE431301C
B2B997CEE0AECEE7A6D5F5ACC5E599CFF2A2CAEB9CC5E59AC2E19BD1E4A2A9A25E4D4600
C1D18AD4DFA3ECD7B8CAB49DF4F7D8DDF0C3C9E1A5C7E29BCFE99FC8E69CC8E8A7DAF8C2
F4FFE4CBDAB9DBE7BFD1DAABD5DDA47881429AA561D9E9A2D3E9A1CCE7A0CAEAA1CCF0A6
CEF0A4C8E89CC7E696CBEA9AC8EB9BC8EA9DCAE99DCCE89DCDE79DCDE79DCCE89DC9E99D
C8ED9FC6ED9EC5EC9DC5EA9CC7E69ACAE298D0E19AD8E39FDDE1A49B9A61656328E3E5A6
C4D18CCFE99FC5EF9DBAEC97C2F29CBFE693D0E89CD9E9A0D0E099CCE49ACAEFA2C8EAA0
CBDE9E727F47E1EFBCF8FFDDEEFEDAF7FFEBF9FFF3F9FFF1FFFFF4FFFFF3F8F5E2D6D6BE
C8CFAECDDCB3C9DCAEC6E2A8CAE8A0C9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99D
CAEA9FC6E69BC7E79CCCECA1CFEFA6CCECA3C9E9A0CAEA9FC5E79AD2F2A6D1EBA1C9E89C
C0E99BD2F4A8CED7947C7E3D5F6B29CBD694E8E2A6A9A568A3B372D4EFAADCFAB4D0EDAB
CBE4ABCBE1B0D9EEC5F4FFE5F8FFEDF8FFF3F9FFF4F9FFF6
6B6A68A0A392A5AE83CDDD9CD7F09DC6E48CC4E692D0F3A3C3E59BC0E298CBEBA0CCEBA5
CDE7AAE8FECFF7FFEAF8FFEDEDFBDAC9DAAED9F0B8C8E5A2C8E799C7E794D9F5AAD7EDAC
C5D2A4D1D8B7E6E9D8FDFEF6FFFFFAFCFFFAF6FFF7F0FAF1FEFFFBFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFEFCF6F5F3EEEAE9FFFDFCFCF8F7F8F4F3FFFDFDD4CFCC
DEDBD4FFFFF8F8F8F6FDFEFFFAFEFFFDFEFFFFFDFFFFFCFEFFFAFAFFFBF8AA9B98F3E5E2
CEC4C2272322757577FBFFFFF9FFFFF9FFFFFEFDFFF6F1F8FFFAFFFFFBFFFFFDF8858472
767D5CD1E3B3C1D99DC9E8A2C8E89DC5E79ACDEDA1C8E89DBFE099D9EEA9C0BB7767601A
92A25BCCD79DDDC8A9F5DFC8FAFDE0E5F7CDD1E9ADCCE7A0CEEA9DC5E498C7E7A4DCFBC2
EAFFD7CCDEB6E0EDC1D5DFABDEE6AB98A1606E7935CFDF98CFE59DC6E19AC2E19BC6E7A0
CBEDA3CBEBA0CAE99BC9EA9BC8EA9DC8EA9DC9E99DCCE89DCDE79DCDE79DCCE89DCAE99D
C4E99BC0E798C3EA9BCBF0A2CEEEA2CBE59BCEE29AD9E6A1DBE4A5B0B17759571CC1C183
D5DE9BD3EBA1BAE492C6F8A3C3F39DC0E794CDE398DAE79FD8E59FCFE59CC6EC9FC8ECA2
CCE1A099A76CAAB883F8FFDAF4FFDDF7FFE5F9FFEAFAFFE8F7F9E1FCFCE0FCFBDDDFE0BE
CAD2ABCAD9AEC9DCAFCCE7B0CAE8A2C9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99D
CAEA9FC8E89DC8E89DCAEA9FC8E89FC6E69DCAEAA1D0F0A5C3E397C9E89ACBE79CCAE99D
C0EB9BCDF2A4DAE5A1B4B9774B5715949D5CF3EAB1B0AA70ABBA79C1DC97BDDC98CAE9A6
D0E7AFCEE2B1E5F7CFF8FFE6F7FFEDF4FCEDF5FBEFFAFFF6
FCFBF7FFFFEFE3ECBFD4E5A1CFE894C5E389C1E38DCDF0A0CAEEA4C7EBA3CAECA2CAE9A5
CCE5ABDBF0C5EDFDE3EFFCE8F9FFEACADBB1D4EBB3C1DF99CAEA97C7E891D7F4A0C6DE94
DCEBB4E1E9C2EBEFD8F9FBEEFFFFFAFCFFFBF9FFFBF9FFFBFEFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFEFDF9F5F4FFFEFDFFFDFCFFFDFDE5E0DD
DAD7D0FCFCF4FDFDFBF9FAFCFCFFFFFDFEFFFFFEFFFFFCFEFFFBFBF6E8E5FFFBF8EADCD9
F7EDEB8A8685000002DDE2E5E8F1F0F2FAFCFFFEFFF7F2F9FFFAFFFFFBFFF2E8E7FFFFF1
8D9475DEEFC2CAE2A8C3E29EC6E69DBBDD90C9E99DC8E89DCFF0A9D4E9A4E6E19DCAC37D
53621DECF5BCD6C1A2FFECD6FFFFE6E9FBD1D2EAAECAE59ECBE79AC4E397C9ECA8E1FFC7
EBFFD4D5E7BDDBE9B8CDD7A2D1D99D9BA25F4F5914A6B36ED8ECA7D2EBA7C9E8A4C3E49F
C4E59EC9EB9FCBEB9FC8E99AC8EA9DC8EA9DC9E99DCCE89DCDE79DCDE79DCDE79DCAE99D
C7EC9EC2E99AC2E99AC9EEA0CCECA0CBE79CCFE59CD8E7A2E0EAABE3E7AC565117989659
E9F0ADCEE49BC5F09EBAEE99C2F49DC3EA97CDE297D8E49CDCE7A2D0E69DC2E89BC5EBA0
CCE1A0D2E0A592A16A8C9E6CDFF0C4F8FFE1D4E3BCDFE9C4DFE3BEDADCB5EEEFC5C6C99E
D7E0B3F9FFDAD1E4B6C9E4ADCAE8A2C9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99D
CBEBA0CAEA9FCAEA9FCBEBA0C7E79EC4E49BC6E69DCCECA1C8E89CC6E597CBE79CCBEB9F
C0ED9CC7EE9FDCE9A4DADF9DDEEAA8515717DED39BADA46BC8D796D6F1ACC2E19DCCEBA8
C9E1A7C6D8A8E5F6CCF9FFE6FCFFEFFEFFF4FEFFF8FFFFFA
FFFFFAF8FBE8CDD6A9C5D692D4EE97D2F194D0F29CC3E696C7EBA1C7EBA3C3E49DC7E6A3
D8F1B8E5FAD1F6FFF0F8FFF4F9FFECBFCFA8D1E8B0CBE9A1D3F49DBEE082D2F096CAE392
C9D99AD9E2B5EEF2D7FEFFF2FFFFFAFAFFFBF7FFFBF9FFFDFEFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDF1F0EEFFFEFCFFFEFDFBF7F6FFFEFDFFFEFDF5EFEFFFFEFB
F4F1EACFCFC7FFFFFDFCFDFFFCFFFFFEFFFFFFFEFFFFFDFFFFFBFBFFF4F1FFFBF8B4A6A3
B3A9A7FFFEFDE0E0E2676C6FF9FFFFF9FFFFFFFEFFFFFCFFEBDFEDFFFAFFFFFCFDFFFEF1
DBE1C5DBECC0E4FCC2D3F2AFCFEEA8C9EB9FCFEFA4CFEFA6C3E49DC1D691EAE5A1F9F2AC
4A5914D3DCA3F4DFC2E7CEBAFFFFE3E4F5CBCCE4A8C7E29BCDE99CC7E69AC7EAA6DAFCC0
F4FFDCCEE1B4CAD8A5DBE6AEDFE8A98E95525F6924889550C7DB96D1EAA6D2F1ADC7E8A3
C1E59DCAECA2CCECA1C5E599C8EA9DC8EA9DC9E99DCCE89DCDE79DCDE79DCDE79DCAE99D
C9EEA0C6ED9EC2EB9CC4EB9CC6E69AC7E398CDE39AD4E59FC4D090E1E5AA5B561C5F5B1E
D2D996C6DC93C7F2A0B1E590BFF19AC7EE9BD2E49AD7E19ADBE5A0D1E59DC0E99BC5EEA2
D9EEABDEECAFCFDEA58DA069E8FAC8F8FFDAE0F0C1CDD9A9D7DDADD2D6A3C9CB99B1B582
DBE5B1F9FFD8D0E4B3C5E0A9CAE8A2C9EA9BC9EA9BC9EA9BC9EA9BC9EA9BC9E99DC9E99D
CAEA9FC9E99ECCECA1D3F3A8D4F4ABCEEEA5C9E9A0C7E79CCEEEA2CBEA9CD0EC9FCBEC9D
BFEC9BC4EB9CD5E29DDDE2A0D6E19F60662671642D81763ED3DFA1BED996C8E7A3C9E8A5
D3EBB1C8DAA8E4F3CAF4FFDFFEFFEFFFFFF6F8F7F2F7F6F2
FCFFE9FEFFE3DAE7B1D2E69FD4ED99BFDD85D2F29FC3E397C5E49ED0EFABCCEBA8C0D99F
A2B685586843101C080005001E270C172200919F6ACDE29FD1E89A97AF5BA6BC69AFC175
333F01676D3FB3B495EFEEDCFFFFF8FFFFFDFEFEFEFFFFFFFFFFFDFFFFFDFFFFFDFFFFFB
FFFFFBFFFFFBFFFFFBFFFFFBFFFEFBFFFEFBF2EEEBFFFEFBFFFDFAFFFEFBFFFBFBFFFEFB
FFFEF8A4A19CFFFFFDFDFDFDF4F5F9FFFEFFFDFBFFFFF9FBFCF2F3FFFBFBFFFCFAE8DDD9
DFD5D3FEF9F6FFFEFD424443000102FBFFFFF4F4FCFBF8FFFFFBFFFFFBFFFBF5F5FFFCF3
F3F6E1A9B390D9EBBBCDE5ABC4DE9FCBE8A5C5E39DC5E59CC8EAA0DDF4ACD7DD95D3D490
6F7A385D6029D7C0A0C4AF94FFFFDEE5F9C8CEE8A7CDE99FD8F0A6CCE69DC0DF9BC9E7AB
CDE0B2F9FFDFFBFFDCD0DCACDBE6AED7E3A5CBD692515E189DAC67BDD08ED3E9ABCCE6A9
C6E2A5CDECA8CFEFA4C5E898C8EA9DC8EA9DC9E99ECCE89ECDE79ECDE79DCCE89BCAE99B
C4E797C6EB9BC8EFA0C8EDA0C8E89DCBE79DD1E99FD6EAA3DBEAA7D4DD9EDFDDA0525111
DCE3A0DBECA5BDDD91CFF9A7C3EA99CFF0A1D5E69FD4DF9AD7E49ECEE69CC1EA9CCAF3A7
CDE6A2D1E3A5C7DB9CD9EFB1879F6398AD72D5E9AC91A367929D61B9C3879EA86CBDC68D
E5F2BCD6E7B3EBFFCCF4FFD3C8EAA0C6EC99C6EC99C8EB9BC8EB9BC8EB9BC8EA9DC9E99D
C7E79CC6E69BCEECA4DCFAB2E4FFBCDEFCB6D1EFA9C8E69ECAE99BC9E898D0ECA2C9E79F
C2EB9FCCEEA4D6E19DDCDE9DD6DD9A7B7B3FBBAD7CCDC093A3A979D6E8B6D5EEB7C6DEAC
D1E2B8CDDBB7F2FDDDFAFFE9FCFFEBFEFFF1FBFEEDFFFFF1
D6E5AACFDFA1D2E6A1CAE097CBE395C9E495CEEA9FCEE9A2C8E2A1CCE4A8C9DEA6364818
3B47216E7758FDFFEBFAFCE6FFFEDFE1DDB77372447D804B44480D292F00353A00373B00
70703EE5E2B9B8B194918976A59890A29494FFF9FFFFF7FEFFFCFDFFFEFBFFFAF7FFFEFA
FFFEFAFDF8F4FFFEFAFFFCF7FFFEFAF9F4F0FFFEFAFFFEFAFDFAF5F5F2EDFFFEFBF6F1ED
FFFCF9FFFDFA7A7474FFFEFFFFFEFFEEECF1FFFDFFFFFDFFFEF9FDFFFCFEFFFCFDFFFAF9
EDE3E1B7AEA9FFFCF8FFF7F4D2D0D16B6C70FEFFFFFEFFFFF7F8FDF8F7FCFFFEFFFAF9F4
FEFAEFCBCAB6A8AB8EFEFFDFD3E0B2C6D9A2D2EAAEC9E6A3C7E69AC5E292D2E89DE9F6B1
56571D9E9262E2CBA2A8996EE6F3BDE0FAB9C8E89FCCE89ED7E8A1CBDC96C8E19DC8E0A4
D1DCB1FEFFE3F3FEE0E2F1D2E9FBD3D9EBB7C6DA95BCCC814E5811DDE3A5EEF1C2DEE5BB
EDFACECCE4AABCDC90CFF5A0C9E99DC9E99ECAE8A0CAE8A2CCE7A0CCE89DCAE999CAEA95
C9EB95C9EA99C9E99DC9E9A0CAE8A2CAE8A0CCE89ECFE69ECEDF98D3E09AE3EAA6727935
4E5511B7C17CD7E29DD1E09BCBDC96D9EAA4D8E7A2D4E59FC9E098CAE89ECDF3A6B9E296
CBEAA7CFECACC3E09DC9E79FD8F7ABC1E092B1CD80C9E399D3EAA2D1E6A3CEE2A3CEE2A7
D1E4ACD7EAB3DEF3BBDFF9BAC5EC9DC2EE97C2EE97C3ED99C3ED99C5EC9BC6EB9DC8EA9D
C8E89DCDEBA3D4EFAAD8F3B0D9F2B1D5EEADD2E8A8CCE69FCBE896CDEA98CDE8A5C5DFA2
C9E2A8D1E5A8D4DD9CE6E7A5DFDB9B625922F0E1BAA89A7FF0EBD7F3F6E3E0EAD2E7F3DF
E3EBE0EAF1E9F2FAEBF7FFEBFBFFEAFBFFE4EBFAD3DAE9BE
CDE199D4E8A0D1E79FE0F7AFCAE199D3EDA4E6FFBABCD591D1E7A76F8449637440162300
869169C6CCAAEEF1D4FFFFE4FFFFDCDDD8AEC8C497C0BC8C908F5976773E7777416B6B37
2B2A00AEAB82E6E0C0E2D7C3AA9C93BBA9A9C0ABB2907F87FDF3F4F6EEECFFFDFBFFFDFA
FFFDFAFFFEF8F1ECE8FFFEF8FDF8F2FFFEF8FFFEF8FFFEF8FFFFFAFCF9F4FFFFFAFFFDF9
FFF7F4FFFDFB8A8182F2ECECF8F3F7FFFDFFFFFEFFFFFEFFFAF8FDFFFEFFFFFDFFFFFDFB
FEF4F2B8ADA9D0C1BCFFFCF8F1EBEB232325FEFFFFFCFFFFFBFFFFFCFFFFF7F8FAFFFFFD
FFFDFAF1E8DFBAB5A2FFFFE6DCE2BED8E5B9CDE1ACD1EBACD4F0A5D1EE9EBCDA90B9CC8A
5C5622EDDBADE4CDA1A09462CEDC9ED0EEA8C0E097C7E399DCEBA8DCE8A8D4EAA9CBE0A7
D8E0B7FFFFE8FBFFEFF5FFEFEFFFE5D3EABCCADF9ED1E198626822AFAF73E9E4BCFFFFE1
E7EFC8C5D8A1CEEEA2C0E68FC9EA9BCAE89ECAE8A0CAE8A2CAE8A0CAE99DCAEA97CAEA95
CAEA95CAEA97CAE99DCAE8A0CAE8A2CAE8A2CAE89ECCE89DE0F6ADD3E39AC4D18BA6B16C
575E1A6F7432E2E4A3DDDF9EE0E5A5D6DF9ECEDD9ACEE29DD1EDA3D6F6ABBEE396D2F8AF
C3E6A4CBEEACC5E79DC2E595CBEF98C6E891C1E38CCFF19DCDECA0CCEAA2CCE6A5CBE5A8
CCE4A8CDE5A9CFE7A9CEEBA8C5EC9BC2EE97C2EE97C3ED99C3ED99C5EC9BC6EB9BC8EA9D
C7E99DC9E99ECCEAA2CFEAA5D0E9A5CFE8A6CDE6A4CCE69DCDEA96CAE999CCE9A9CDE6AF
D3E7B4D3E1ACD2DB9CE1E2A0E2DA9C665925FFF4D6CBBBACFFFBF6FFFEFBF4F7F0F8FFF8
F5FBFBF9FFFDFBFFF8F9FFEFF8FFE3F1FFD5E0F4BFCFE4AB
D2E4A6CBDD9FCDE2A1BDD392DAF1ADCBE4A0C4DD991B34003D5312AEC484CDDFA5CBD9A4
DAE6B6DAE3B6DFE6BCCBD1A5878A5D5557269CA06D979C669DA56AB8C084DAE4A8DDE6AD
DCE3AF63693B434520CBCAAEFFFFEFFFF7F0F5E9E9FFF7F8CFC6C7CDC7C7EDE7E7F4EFEC
FEF9F6FFFEFAFFFEFBFDF8F4FFFEFAEFEAE69A9792A7A49FF3EFECFFFEFBFAF6F3FFFBF8
FFFDFBFFFDFBF7EEEFEEE8E8FFFDFFFFFBFFFEFCFFF4F2F7F7F5F8FFFEFFFEF8FAFFF7F5
FFFCFAE4D9D5B6A7A2FFFCF8FFFDFD6260617B7B7DECF0F1FBFFFFEEF2F5FEFFFFF9F7F8
FFFDFBFFFBF4BCB5A5F9F7E0F3F8D8F6FFDAC8DCABCAE2A8D5EEAABDD98FD6F4AE334606
857F4BDFCD9DDFC799847846BAC88ACBE8A5CBEAA4D6F1AEE7F5B8E2EDB5D7ECB3C9DDAC
D4DBB9FDFFEAFBFFF3F8FFF3F0FFE8CCE1B8C9DDA0DBEAA5D0D7946A6B31D6D3AAEBEBC7
D6DFB4DEF1B9D7F6A8C7EB94C9EA99C9EA9BC9E99DC9E99EC9E99EC9E99DC9EA99C9EB97
C9EA99C9EA9BC9E99DC9E9A0C9E9A0C9E9A0C9E99ECAE99DC3DB91D6EAA2C3D48EE8F7B2
CCD793838C4B949A5A808545D4DA9AE2EBAACCD896D1E5A0D5ECA6D8F6AEBFDF96C6E7A0
C2E5A1CBF0AACBF0A3C2E895C0E68FC7EB93C9ED96C7EA96C8EA9DC9EBA1CAE9A5CAE9A6
C9E8A5C7E6A2C5E49EC3E398C8EA9DC6EB9BC6EB9BC8EB9BC8EB9BC8EB9BC8EB9BC8EB9B
C8EB9BC7EA9AC7E899C6E798C6E798C7E899C8E99AC9EA99CAEE97C6E999CBE9ABDAF5C2
DEF4C5D4E4B3D2DC9FDADC9BDFDB9E605625FFFEE3E3D5C8FFFCFAFFFFFDF9FEF7F9FFFA
F9FFF8F9FFF4F2FEE6E9F7D6E5F4C9DFF1BDD3E8ADC5DE9D
C6D7A1D9EAB3C7DAA2EAFEC3C0D696D1EAA89DB672465F1B95AC68CDE4A0D3E8A7E7F9BB
D2E0A5D3DEA47F8A52B6C189A0AA758B965EDBE9AED0DEA1D8E8A9DCECABD7EAA8CADD9D
D7E6ABA0AE790E1900333A18F0F4DBFFFFF1FFFFF4FFFDF8FFFEFBAFA9A9EFE9E9CCC6C6
FFFCFCF7F2EFFFFDFDCEC9C6D7D2CFDBD6D39D9996ADA9A6CECAC7CFCBC8B5B1AEC7C3C0
BAB5B2C4BFBCEDE7E7CAC4C6FFFEFFF3EEF2FFFEFFFFFEFFFFFEFFEEEAEBFFFDFDFFFDFB
F8EEEDFFFCFAFFF3F0CEC3BFF9F3F3C6C4C578787AF5F9FAFCFFFFFCFFFFEEEFF1FFFEFF
FFF7F5FFFAF5B1A99EC7C2AFFFFFE8FCFFE3D6E7BDD3E9B8CCE4A8D2EBAACAE4A3839355
514B17FFEBBCCAB2847F723EB0BB7FC6E3A1D3F2AFE8FFC5F3FFCBE3ECBDD7EABCD2E4BC
D6DCC0FAFDEAFBFFF6F8FFF8ECFEE8CFE3C0CEE0ACD4E2A5DCE2A474753CB3B286CCCDA5
C9D2A5D4E8ADB8D487CBED97C9EB97C9EB97C9EA99C9EA9BC9EA9BC9EA9BC9E99DC9E99D
C9E99DC9E99EC9E99EC9E99EC9E99EC9E99EC9E99DCAE99DD4F0A6DAF1ABD1E6A1D0E19D
DBEAA7AAB573535C1B3E4706B9C281D6DF9EC2CE8CE4F5B1C8DD98BCD68FCFEAA5D2F1AB
C2E6A0C2E89FC8EEA1C8EF9EC3E994C7ED96C8EE99BDE390C4E99CC5E99FC7EBA3C8ECA4
C9EDA3C8EDA0C6EB9BC7EA98CAE99DCAE99DCAE99DCAE99DCAE99BCAE99BC9EA9BC9EA9B
CBEE9CC9EC98C8EB97C4EA95C4EA93C6EC95C7ED96C9EF98C9EF9AC1E699C7E9ADE6FFD3
EAFFD9DAEDBFD8E5ADD7DDA1E2E0A7585022FFFEE4E9DCD3F9F1EFF8F6F7F7FCF6F9FFF6
F9FFEFEEFDDEDDEDC9D1E2B6CEE0ACCFE5A7CDE6A4CBE4A0
657747839563CFE1ADCCDFA86D82470C2200324B09C5DF98DBF2ACD2E9A1CCE29ABCD089
D3E49EB1C07B83924DC1D08DCBDE9ECFE3A4CFE5A4BED591C7E19ACCE89ECBE69FD2EDA8
C3DE9BCFE7ABB0C48F7E8F6374825F899378EDF5DEFEFFF3FEFDF9FBF7F8FCF8F9E0DCDD
918D8EFFFDFCAFABACBAB6B5FFFEFDFFFEFDF3EFEEF5F1F0DDD9D8D9D5D4E6E2DFFFFEFB
FFFDFDFFFDFDEAE4E6F2EEEFF7F3F4FFFEFFFFFEFFF8F6F9FFFBFFFFFEFFFFFCFCFFFCFA
FFFCFBFCF1EFF4E9E5D9CFCDFFFDFDFDFBFC3B3B3DAAAEAFFAFEFFEDF1F4FDFEFFFDFBFE
FFFDFDFFFDFAC2B9B29D9789FDFFEAFCFFEAEFFDDCF4FFDED3E7B6B5CC94E2FAC0D4E1A9
57501CE9D3A4F5DAAB7B6E3AB9C488C0DA9BC6E2A7E6FDC9FCFFDDEDF4D2E4F5D3E6F6D9
E5EDD8FEFFF4FBFFFBF6FFF9F2FFF1E8F8DDE3F2C7D0DDA8D8DFA9D9DCA7595A2EAFB287
E0E9BADCEEB2CCE69CCFEF9ACAEB94C9EB94C9EB94C9EB95C9EA99C9EA9BC9E9A0C9E8A2
C9E8A2C9E8A2C9E9A0C9E99DC9E99DC9EA9BC9EA9BC9E99DCFEDA5B9D48FDBF4B0CBE09D
C8DB99EBFAB9CEDA9AC5CF905C66274953147E8A4AD0DF9ED3E3A2D6EBA8CDE3A2C6E19E
C9EAA5BCE098C0E598C9EEA0C8EF9CC8EF9CC9F09FC5EC9DC4EA9FC5EBA2C5EBA2C6ECA1
C7EE9FC8F09AC7F298CAF198CCE89DCFE6A0CFE6A0CDE79ECDE79DCCE89DCAE99BC9EA99
C9EC98C9ED96C8EE97C7EF96C7F094C7F094C4F091C4EF95C5EF9BBFE59CC6E9B3EEFFE3
F1FFE6E2F7CEE6F4C1D8DFA9E4E2AF574F28FFFDEAF1E4DCF7EEEFFDFBFEFAFFFBF9FFF4
F0FFDCE2F5C7D3E7B4CBE0A8CBE1A3CDE6A2D0EAA1D0ECA1
4E6030485A28000E00000C00233800DAF0B2C4DD9BD5EFA8C2D991CDE599C6DC91E5FCAE
192E0094A758EBFEAFBFD489BED58DE1FCB5C7E399CFEDA3D7F7ABCFF1A4BEE093BFE195
CFF0A9D2F1AEC7E3A8B9D19D92A77C4D5F393E4D2CFBFFEDFDFEF6FFFEFFF9F5F6FFFDFE
FFFEFFFFFDFEEDE9EAFFFEFFFFFDFEFFFCFDFAF6F7FFFEFDFFFEFDFFFEFDFFFEFBF6F2EF
FFFDFDFFFEFDEDE9EAFFFEFFFDF9FAFFFDFEFFFEFFFFFDFEF2EEEFFFFEFDFFFAFAF8F3F0
FFFDFAC6BCBAC5BAB6FFFCFAF5EFEFFFFEFF616163CFD3D4FBFFFFFBFFFFFBFCFFFFFEFF
FFFBFDFFFCFDF5EBE9AEA79FFFFFF3F5FAE6FAFFEBF8FFE8D4E4BFDBEEC1C2D6A5E4EEBA
564C1BEFD9A8E7CD9CA49460D6E1A5CFE9ACC4DFAAE1F6CBFEFFE4FEFFEAF7FFEEF2FFEE
F5FBEDFEFFFAFBFFFFF6FFFCF7FFFAF8FFF3F8FFE1D6E1B6E2EAB9DCE0AE4A4D20575D2D
E2EAB7D9E9ABD3E9A1BCD786CAEB94C9EC92C9EC90C9EC92C9EB95C9E99DC9E8A4C9E7A7
C9E7A9C9E8A5C9E9A0C9E99DC9EA99C9EA99C9EA9BC9E99EC6E5A1CAE9A6CFE9A8CCE5A3
CDE3A2CFE2A0CDDD9CCCDB9AD0DC9C475313404C0C283400667436E2F2B3D5E5A6D0E4A5
D4F1AFC8E8A5C3E49DC8EAA0CBEDA1C3E89AC3E79DCAEEA6C7ECA7C6EBA6C4E9A3C3E99E
C3EA99C2ED94C4F08FC8EF94CDE79DD0E5A2D0E5A0CFE6A0CDE79ECCE89DCCE89DCAE99B
C7E897C7EA96C7ED98C8EE97C7EF97C6EE95C4EC93C1EC93C6ED9EC0E5A2C4E6B4EEFFE6
F1FFECEBFFDCF6FFD8DAE0B0DBD8AB594F2CFFFCECF6E7E4FBF0F4FFFDFFFEFFFAFAFFF0
E2F3C6D7ECB1CEE6A8CEE7A6D0E9A7CFE9A2CAE69BC9E598
CADCA8B4C790B5CA9293A86DBCD294CCE2A2C8DF9BCAE199D9F1A7CAE296DAF1A3849B4B
B3CA7AD3E997C5DB89D8EF9FCBE79AD7F7ABBDDE8FC2E595C2E595C5EA9ACAEF9FD1F6A8
BADE94C4E5A0D5F5B4C9E6ACC6E1ACBED5A753683D5C6B4C6D7065E6E6E4FFFFFDFFFFFD
F6F4F5FCFCFCFFFEFFFFFEFFFCFAFDFFFEFFFFFEFFF8F6F7F5F1F0F3EFEEFFFEFBFFFEFB
F8F4F3FCF8F9FFFEFFFFFEFFFFFEFFF4F2F3FFFEFFFFFEFFFFFEFFE8E4E3FFFDFDFFFEFB
B7AFACCAC2BFFBF1EFFFFAF8FFFBFBFFFEFD0C0C0C75797AF3F8FBF0F5F8FEFFFFF1F0F5
FDF7FBFFFCFFFFFCFDC8BEBCFFFFF6F9FBEEFCFFF3F8FFECEFF9E0F9FFE6D2E3B9E1E8BC
65582BFDE5B5D9BD8BAA9A66CDD89EDFF8BFDEF8C9E9FDD8FEFFECFEFFF1F8FFF6F3FFF4
FAFFF9FCFFFDF8FEFEFAFFFFF7FFFDFAFFF7FBFFEDE6F0CEEBF2C9D0D6A8D8DEAE909764
CAD39CD2DEA0D9EAA6D5EBA0CCE995C9EC92C9EC8EC9EC8EC9EB94C9E99DC9E7A7C9E6AC
C9E6AEC9E7ABC9E8A2C9EA9BC9EB97C9EA99C9E99DC9E9A0C8E8A5DCFCBBBDDB9BC4E19F
DEF8B7CCE2A1CCE19EDBEEACE1F1B0CFDE9DECF8B8737F3F465214606C2E8C975BDFEEB3
C2D79ED1EAB0CFE9ACC6E3A3CCE9A7C7E4A1BFDD9DC9E7A9C9E8ACC9E8ACC6E9A9C5E9A3
C5EA9CC4EC94C4ED8DC7EC8FCCE89BCDE7A0CDE7A0CDE7A0CCE7A0CCE89ECCE89ECAE89E
C9E79DC8E89CC9E99DC9E99DC9E99DC8EA9DC7E99CC7E99DC9EAA3C6E5A9C4E3B9F0FFEC
F2FFF1F1FFE6FCFFE3DADCB4D8D3AB645639FFFBEFF2DEDDF7E6ECFFFBFFFEFBF6FEFFEC
DDEFBBD1EAA6CBE4A2CEE7A5CFEAA5CBE69FC7E399C6E297
D6EAADC1D598D0E6A6C5DB9BD5EBAAC6DD99DDF4AECDE49CC8E096D4ECA08DA4568FA658
C5DC8CDFF6A6BCD383D7F09FC9E696C2E392CEEF9ED1F4A2C4E795C1E794C6EB9BBFE496
D2F7AAB9DA93CEEFAAC8E6A6CEEAB0D4EDB6CDE3B28D9D76CBD2C01C1F188A8D86F2F4EF
FFFFFDFFFFFD767676848486B5B3B6E5E3E6FFFDFEFCFAFBFFFEFDFFFBFAFFFEFBF8F4F3
FFFEFFFFFDFEF9F7F8FFFEFFEAE8E9FFFEFFFCF8F9FFFEFDFFFEFDFFFEFDFFFBF8CBC6C3
A09895FFFDFAFFFDFAFFFCFAFFFDFDF5F1F03B3B3B000100F3F9F9FBFFFFEDF1F4FFFEFF
FFFDFFFFFBFFFCF0F4BFB5B6FAF5F1FFFDF6FFFFF6FAFFF4FCFFF4F0F9E4F9FFE6FEFFDC
625328EBD3A3E4C6945F4E1A9DA66FDAF1BDF4FFE1F5FFE8F7FBEAFBFDF2F8FFFAF4FFF8
F9FFFDFAFFFEF6FCFCFBFFFFF9FEFFF4F9F5FCFFF6F9FEE8FBFFE0D8DFB5D9E1B0BDC68F
5C652CB0BA7DD5DFA0CCDD99CDE89BC9EB95C9EC8EC9EC8EC9EB94C9E99DC9E7ABC9E5B4
C9E5B4C9E6AEC9E8A2C9EA9BC9EB97C9EA99C9E9A0C9E8A5C9E9AABCDC9DCEEEAFD4F2B2
BFDC9AC4DF9CD3ECA8CDE29FCBDE9CCDDD9CD0DF9ED1DD9DE1EDAF6C7639616B2F89945C
99A776C7D9A9D3E5B3CADDA6D6EBB2D5EAB1C8DFA7CFE6B0CBE3AFCAE5AECBE7ADCBE9A9
CCECA3CBED99CBEE92CAED93CAE99BCAE89ECAE89ECAE8A0CAE8A0CAE8A0CCE7A2CCE7A2
CEE9A6CEE9A6CDE7A6CDE6A5CDE6A5CEE7A6CFE7A9CEE8A9CEE8A9CAE5B0C7DFBDF3FFF0
F5FFF4F4FFECFFFFE6DBD8B7E2D8B5746349FFFAEFEDD5D5EFDBDDFFFAFBFFF7F0FFFFE8
E6F8BED4EEA5CBE29ECAE3A1CCE5A4CBE5A4CCE7A4D0EBA6
CAE199CEE59DDEF5ADCFE69ECAE098D4EAA2CAE098CFE59CCEE49CAFC57C748C42CDE59B
D3EBA1CFE79BCCE498CFEA9BCBE896C8E895C8E895C7E995C7E897C7EA98C8EB9BC9EB9E
C8EA9EBCDC93D2F0AACCE6A5C8E0A2D8EDB4CEE3AAD4E5B8E2ECD36B72627C82746B7165
F2F5ECCED0CB000100585A596F6F6F6C6C6CBCBABBFFFEFFFFFFFDFFFFFDFDFCF8FFFEFC
FEFCFDFFFFFFFEFEFEFCFCFCFFFEFFFAF8F9FFFDFCFFFEFDFFF9F9FFFEFBFFFEFBC4BFBC
C9C4C1FFFDFAFFFBF8FFFCF9FFFDFDFFFEFF333333000100767C7C7F858583878AFFFEFF
FFFCFFFFF7FDFFFAFFD5C9CDFFFCFDFFFEFBFBFAF5FFFFFAFEFFFBF2F8ECFBFFEDFFFFE1
4A3810A3885BEBCB9C614D1B969D69D7EABCECFFDCE2F2D7E0E4D5F8FAEFE7F3E9CCD9D0
717A757278749BA19FFCFFFFECF0F3FCFDFFFEFFFDEFF3E5FEFFEACCD4ADD9E3B1DCE5AC
56602490985DE3E8B0D5E0A6CDE4A0D7F6A8BEDF86C8E98EDAFBA4C3E197CAE5B0CBE4BA
CCE5BBCAE5B2C7E4A1C3E294CBEB98CDEC9EC7E4A1C6E4A8CAE9ADC4E3A7C5E5A6C0DE9E
C8E7A4D4F1AEC5E09BCDE7A0D3EAA4C6DB96D5E6A2DDECABCCD89AC1CB8EA1AB6F67703B
2B32095F6644D9E1BAD8E3B8DFEBBDCBD7A9D7E4B6D2DFB3D5E5B8C2D3A6E2F4C4CCE1A8
CBE1A0C7E197C6E28ED4F19DCDF09EC6EB9DC9EEA0CFF1A5B5D78DCFEEA8CAE7A4C9E3A4
CDE5A9C4D9A0D0E2AE96A67572804FD0DDAFD8E5B9D4E1B3CCDDA9D9EABED3E1C7F3FFF1
F9FFFAF4F7ECFEFDE8F2EBCFA29376AA947DFFF8EFEBCFCCF4DADBFFF8F4FFF4E7EEEECC
D9E7AAD5ECA4D2E7A6C9DFA1D8EDB5D8EFB7C2DAA0CFE7AD
CDE695D6EF9EBAD284D3EB9DDAF0A5C6DC93DEF4ABCEE49CDBF1A9879C57C6DD97CEE8A1
CEE8A1CFE9A2CCE89ECAE69BCBE896CBE894CBE896C9E898C9E898C8E99AC9EA9BC9E99D
CCECA1C8E69EDBF6B1DFF8B6D7EDADD1E5A6C9DDA0CDDEAAD5E3C0E7F1D8E0EAD27A8370
7D84742E3428ECF1EAF7F9F4FFFFFDBDBDBB3533346A6967FAF9F7FFFFFBEBEAE6FFFFFD
F9F9F9FBFBFDFEFEFFFFFFFFFFFEFFFEFDFBFEFAF9FFFEFBFFFEFBFFFCF9FFFEFBB6B1AE
F0EBE8F9F4F1FFFEFBFFFBFBFFFDFFFFFCFD464646181C1B0002020003024A4F52FEFFFF
FEF9FFFFFBFFFFF6FDFBEFF371666AFFFCFDFFFEFDF9F7F8FFFEFFF8FAF7FCFFF1FFFFE4
3A26017C5F35EBCA9DA48E5FE3E6B7CEE1B4CDE3BFD2E2C8D9DDCC2A2C1F1B2817000600
071309000700000200000100030408BEBDC2EAEBEFFEFFFBFCFFF1DEE8C6DDE9B7C8D397
90985C4E531BD5D4A4DCE2B2CDE0A9C3E09DDBF8A6C7E88FCEEB993B5913001800000C00
000B00000E00CDE7A6D8F7A9BCD987C7E69A5B743A001200000E00000F000E2C005C7A3C
CAE9A6C7E6A2C2E299CBE99FCFEBA1CDE49CD3E9A1D1E29ECDDC9BDDE9ABC0CA8D777E4B
0104001618000D1000010500010600000700070E00000700000700000900000800687643
DEEDB2D5E9A4ECFEB4B9D183BEE191C8F2A0C0E798CCF1A4D5F7ADCBEAA4BFDC9AD3EDB0
9BB0783D4F1D0A1700000800020A00060C00000600000600414A1FCAD4AFCAD3C0FBFFFA
F4F8F7FFFFFBFFFFEFFFFFE65E4D33664D37B2968BB2958FFCE0DDFFFAF1F6E7D2DCD8B2
D7E3A5CBDF98617337001000000A00000A000E210095A978
D7F39CC1DD88DBF4A1C9E291CAE193DBF1A6C0D68DD4EAA2B5CA857C914EE6FDB9CBE4A0
CBE4A0CEE9A4C9E7A1CEECA2CCE798CCE894CDE897CCE999CCE89BC9E89CC9E79DC8E69E
C5E39BD2EDA8DCF7B2ECFFC1E7FCBBD4E7A7D5E8A8D5E7ADD1E1B4DCEAC6DCEAC9EDFADC
58624AC0C9B6F2F8ECFCFFFAFEFFFBF8FAF5939391050601E1E0DCF9F8F4FFFFFBFEFFFA
FEFFFFFAFBFDFDFEFFFFFFFFFFFEFFFFFFFDFCF8F7FFFEFBFFFEFBFDF8F4FCF7F3B7B2AE
FFFEFBFAF6F3FFFEFDFFFEFDF7F1F3FFFDFFC7C7C93D414207100F000302B2B8B8F3F4F6
FFFDFFFAF1F6FFFAFFFFFAFF4B3F43F9EEF2FFFDFFFBF6FAFFFDFFFFFEFFF3F6EBFFFFE8
3D26045E3E17DFBC92B0996DD3D6A9C1D3A9C9DCBC9AAA8F757A660508000007001C2C12
7582717A8577646A5E23261F0100023B383F6E6C77FBFCFFF6FEF1E5F0D2DEECB9F0FEC1
D5DDA1757843D2CDA7F7F7D5DEEDC6C2DAA6D7F1A8BDDA88D2ED9E546F2C000B00000A00
0316003E552BCCE5A4CBE79AD1EC9DD9F4AD98AE7D000B00000C000011004E672D84A063
D3F2AFC0DF99C2E297CDEDA1CCEB9FCBE79CD0EAA0CDE39BCDE19CE3F3B2D4E2A49FA774
0303000302000303000E0F001618002B2D0521230031360D171C00000700080F0058602F
D1DAA5D4DFA3CDD896DEF2AAC6E999CEF8A6C1E899BDE295C5E79DC0DF9BD2EFAFBFD89E
6A7E49000B00000900313C14717856676C4C5356391D2001010500757A5AA1A597FEFFFF
F6F7FBFAF9F7FFFAECFFF6E0BFAE94977F6774584A5D4237C0A89CEBD9C5EBDEBEE3E1B1
DFE7ABDBE7A7A0AA75131E00000800000900273511576740
CBE790D8F49FCDE693CDE695D2E99BD1E79CD1E79FB7CC878BA05DB0C783C6DD99CCE5A1
C9E49FC9E7A1C1E09AD0F0A5CCE798CDE897CEE99ACDE99CCDE99ECAE89EC9E79FC8E6A0
C5E29FE3FEBBDDF8B5E5FEBAE1F6B3CDE09ED8EBA9D2E4A6D5E8B1C0D2A2DFF0C4EFFED7
EAF8D7F9FFECF6FFECF8FEF0FCFFF6FEFFFAF3F4EEFFFFFA585753D7D6D12E2D28F5F6F1
FEFFFFFCFFFFFCFDFFFEFFFFFAF8F9FFFFFDFFFAF7FFFEFAFFFDF9FFFCF8D0CBC7CAC5C1
FFFDFAFFFFFBF5F4F2FFFEFFFFF9FDFFFDFFB2B2B43B3F400003020C1615F4FAFAFCFFFF
FFFDFFF9F0F3FFFBFFFFF7FC6F6065FAEEF2FFFCFFFFFCFFFDF6FFFFFDFFF7F8F2FFFEEA
644D2E613F1AD6B08B7A633ABCBE96E7F9D1D2E5C51F2F1200040004090090A07BE9FDD8
F3FFE9F9FFF1F2F9E7D2D4C9A39F9E120D1401000C71717BFBFFFBEFFCE0F8FFD5FBFFCD
F4FCC0B6B684BCB394EEE8D2E7EFD8DEEFCBD0E6A8CEE69CDAF2A8C4DA9A1729030D1D03
6B7B60DFF1C9D0E6A6C3DB8FD1E99DCDE3A3C7D9B30010000415002D4009D0E5ACD4EEB1
CDEAA8D2F2A9C8EA9EC7EA9AC8EB9BC2E394CBEA9CD3EDA3CCE39BCDE29DD3E3A2CBD8A3
37392103010063624DAAAB8C74764F595C311B1E009A9D6E8184556E71442E3406727848
E7EEBAD0D89FD7DFA3D5E4A1CAE69CC6E89BCFF1A5CCECA3C2E09AD1ECA9D2ECAD324A0E
000C0037491792A273C6D3A7CFDAB2D0D8B3DEE6C1A4AA863438150104003C3D35FEFDFF
FEFEFFFFFEFFFFFFF3FFFFE8FFF4D7FFFCE1FFECD7B29B898D7B656E6043878054989862
CFD597D8E0A4DBE1B18286611D2106000800586345D0DBBB
CCE796CCE796C0D88ACFE79BDCF2A9D3E9A1CBDF9AAFC280A5BA77DCF3AFBFD692D4EFA8
C4E298CAEA9FC3E598C3E598CCE999CCE999CDE99CCBEA9ECBE9A1C9E8A2C9E8A4C8E7A3
CFEEABF1FFCCDEF8B7D2EBA9CFE6A2C5DA97CFE49FC4D996C5D99AE7FCC1CADFA7D8EABA
F8FFDFF9FFE4FBFFECFBFFF1FBFFF3FEFFF6FFFFF8FFFFF8E4E3DED8D8D0E1E1D96C6D68
E2E6E7FCFFFFF9FAFCFDFFFEFAF8F9FFFFFDFFFEFBFFFEFAFFFBF8FFFEF8B0ABA7DAD5D1
FBF7F4FFFFFDEEECEDFFFEFFFFFCFFFEF7FE8A8A8C030708000300000400FBFFFFFCFFFD
FBF7F8FFFCFDFFF7FAFCECEF564649FFFAFDFCF2F3FFFBFFFEF5FFFFFBFFFCFDF8FFFFED
957B6072502DE3BD996E542F8E8E68C7D7B20009000213000005007B8259CCDEAACDE3B2
D2E6C1F4FFE8FCFFECFBFEEDFFFDFA655E6601000E050412C4CAC8F8FFEDF1FFCFBBCB8C
DAE2A7A09D70B3A48DFFFCF3FBFDF8F8FFF3D7E9B9D4E9A8C7DC97DEF2B7011000000700
5E6C53C9D9B4D9EEADD3E99EC1D78ED8ECB19BAA8D000600000800606E39D2E3ACCFE5A7
BFDA97CEEEA3C7EC9EC6ED9AC6ED9AC2E895C8EB99CCED9EC7E398C5DF96CFE49FD7E8B2
0005000F1103646851DBE1BFE0E6B8E2E9B5D8E0A7565E235C642B525923383F0B616834
D2D7A1DDE2AAD8DDA3D6E0A3DCEFADCFE6A0D1E8A4CEE5A1CDE3A2DFF5B4C2D898000E00
000D00BCD198EBFEC6D7EAB3D4E7B0D4E6B2CEE0ACD7E4B6CED4B0090B00090A05D1D2D7
F7FAFFFEFFFFEFEFE3FFFBE2FFFFE1FFFFDDFFF5DBEEDEC4E3D8B8CCC99EA6A9704B5111
636526D9DAA1D7D6AA767556030200000300484D36E3ECD1
D4EEA4BCD68CDDF4ACD2E9A1C3D893BCD18EA4B775CADD9DD5EAA7C7DE9AD8EFA9D1EDA3
BFDE90D0F3A1CDF3A0BDE08CC9EA99CAE99BC9E89CC8E89DC9E8A2C9EAA5CAEAA7C9ECAA
C5E5A4E1FFBFD1EEAEC4DE9DD0E9A7D3EDA6D4EBA5D2E9A1CFE69EC9E09CDCF2B2D5EAB1
EAFCCCEDFDD6D4E2C1E3EDD5F9FFEEF9FFF1FDFFF5F8F9F1ECECE4EDEDE5E4E4DC4F504B
898D8EFBFFFFF3F7FAFEFFFFFFFFFFFFFFFBFFFEFAFFFAF6FFFEF8FFFAF4AEA9A5DEDBD6
FFFEFDFFFFFDF8F8F8FFFEFFFFFBFFFEF4FC7A787B000102060F0C000400FBFFFDEFF4F0
FFFDFCFFFCFAFFFAFDFFFAFB554548FFFAFDFEF2F4FFFBFFFFF9FFFFF8FFFCFAFBFFFFEF
9E846B775235F8CFAF9B815EE7E7C5C9D9B50012000008003A401A949C6BD2E6A7CBE3A7
C5DAAFF6FFE5FCFFE6FFFFECFEF9F3CEC7CF393146000010010A09F1FFE8DFF1BFD7E7A8
F1F9BE9B966C8C7B6BFFF7F8FFFEFFF6FFFCE9F7D3D7E9AFCFE2A2D5E6AF162305041000
616D57D1DFBBD0E3A3D8EDA2DBEFA8D0E1AB56624E040C00171F00B7C18DCFDCA6D3E7A8
DCF5B1BDDD92BDE292CAF29CC5EF99CAF49EC6EE98BDE390C4E596D3EFA4D3EDA4C9DEA5
6D775C00040070795CCBD6AEC8D29EDBE7A9DCE9A4CEDB95B1BC788E9859949E62545C23
6A723999A1689FA46ACBD398C8D295D4E0A2D1DCA0CFDDA0D6E4A6D8E8A9C8DB9B6E8342
687E3DD1EAA8C4DD9BBBD691C3E09DD0EEA8C2E09ACDE5A9B8C09900030000010060656B
FBFFFFF8FDFFFEFFF4FFFFE8FFFFDFFFFFDCFFF7D3E1DBB7D2D0A7E1E6B0D6E19D8A964C
7A7A3A807B44AFAA828B8669322C1C030100585A45C9CDB6
C5DE9AE2FBB7CBE1A0C7DD9CABBF8093A567C5D799CFE1A3DCF1B0B9D08ADCF3ABC6E295
C6E894D1F59EC7EE93C4EB92C9EC9AC8EB9BC6E89BC3E79DC5E9A3C6EBA6CAEFACCCF0B0
C2E5A5C9ECACC5E5A4C1E09DD6F3B0D4EFA8BBD58EC6E096D4EFA2D6F0A6D8F2ABF5FFCD
D1E6AEC7D8ABD4E2BFDCE6CBFCFFEFFCFFF3FEFFF6F5F8EDFFFFF6F9FBF0FDFDF36A6B65
2D3333FBFFFFF5F9FCFEFFFFFFFFFFFDFCF8FFFEFAFEF9F3FFFEF8FFF8F2B2ADA9EAE7E2
FFFEFDFCFBF9FFFFFFFFFEFFFFFBFFF8EEF62A282B3F4042000300000501D7DDD9FCFFFB
FFFEFBF8F0EDFFFBFBFFF3F3635354FFF4F4FFF5F5FFFBFFFFF9FFFFFAFFFFFAFEFFFDF1
745842704B2EF0C7A9A38666C5C2A362704F000900000900848B5FE2EBB2C9DF97CBE59E
D4ECBAF7FFE3EEF8D3FBFEE3FFFCF4FFFBFF7F778C000010000204E5F4DFC8DCA9DAEAAB
C4CC91948F678B776CFFF8FFFAF5FFEEF2FBFBFFE8F4FFCDEBFABFD5E3AE263113020B00
5F6853E7F3CFC4D495D5E79DCDDE985C6A39020A000004002024019FA673D3DEA6CDDD9F
DAF3AFC5E498C3E996BFE993C1ED94C8F49BC2EE95BDE58FC8EB9BD0F0A4CCEAA0C8E0A6
8D9D80000700697756CEDEB1CDDFA3D4E59FCEE192D6E797D1DF92E5F2AAD6E39ED3DD9E
BFC98D8F995D8E965B353A00868650979562B3B37DD6D9A2D2DA9FD6E0A3D5E4A3CDE19C
C3DA92C9E59AD2F3A4D9FCAAC2E893C4EC94CFFAA1C4E69A68784B000400010703687176
F8FFFFDDE7E9F9FFF4D4DABECBD0A8DFE0B6DDDEB6B9BA90AAB17ECBD99BDEF3A4DDEE9E
BABB77786E39AEA57E655E420902000400009C9B87D8DAC4
D0E3A3D4E9A8C6DB9A90A56490A666C8DE9DD6ECACD0E6A5CDE4A0D6EDA5CAE49AC2DF8F
D7F7A4CDEF99B3D77FCEF49DC9EB9EC7E99FC6E59FC5E4A0C7E5A5CBE9A9CFEDAFD1F1B2
DBFBBCCCECABC8E8A5C4E39FD1EFA7B5D3897E9A4F90AC5FC7E492C4E18FDBF6A9DDF7B0
C5DB9DD6E8B6D8E4BED0D9BCFEFFEFEDF1E3FEFFF8FAFBF3FFFFF8FCFEF3F9FBF084877E
000300F8FFFFF9FFFDFCFFFFFCFEFBF3F2EEFFFFF8FFFDF7FFFEF8FFFBF5AEA9A5FCF8F5
FFFFFDFFFFFFFEFFFFFCFCFEF7F1F5FFFCFF65606468696B000202030C09E1E7E5FAFFFB
FBFAF8FFFEFBFEF4F3BFB4B2382D2BFFFCF8FEF3EFFFFBFFFFF3FFFFFAFFFFFFFDFCF6E6
422A106A4727D7AC8C7D5C3DB5AE912C3516000F00000900E2EBBECAD59BE1F5ADC6DD97
C5D9A8F9FFE4F6FFDEFFFFECFFFFF8F5F0F6C2BECD00000B0509088D9681D5E2B4DCE7AD
D6DBA3A9A47AAB9C87FBF0EAFCFFFFF7FFFAF8FFE4F2FFD0DBECB5D9E7B62C361B000400
353C2A9EA78ACCD8A6D7E5AA7F8C56000800020A00454B3F8F9571878F5EDFE9B48D9F63
89A05CC9E59BD8F9AABEE48FC0E890C1E991C3EB95CCF29FCFF0A1BFDE92BEDC94D7F0B6
293A18000800677854D9ECBED0E5AACEE5A1D1E79CD0E799D3EA9CC8DE93D4E8A0D4E8A3
CDDD9CCEDE9DDEEEAD929C5F7E7F464C491264612A9D9C64989B62CED399E1E9ADD1DD9F
DAEAA9CCE19ECCE7A0BCDC91D0F2A5C8EFA0BAE19099B8742F3914030600000200ECF5F4
F4FEFFF8FFFBF9FFEFC6D1AFD5DCB2E2E8B8D0D7A4AEB782B9C78AD2E69FC4E08BD7ED9A
E0E0A09B915E82785480765B0700000D0A00686752DBDEC3
D3DC99D4DF9B98A762C3D991C4DF98D0F0A5C4E49BCEEEA3C9E79DC6E297D8F2A8D2EDA0
C7E295C8E497CEED9DC8E89CCDEBABC7E3A8CCE4AAD0E3ACCCDAA5D3E2ABE5F4BBEBFDC1
E0F6B866813E85A35B88A65CA4C375CDEA9ACCE798D0EC98ABCC738BAC53ABC874BDD589
D0E5A299A871B8C099DFE3C8FFFFF2FFFFFAFFFFFDFEFEFCFFFFFAEDF0E7FEFFF4E1E9DA
647168E6F5EEF8FFFBF9FFFBFCFFFAF5F8EFFFFFF8FDFDF3FFFFF8FEFBF4E0DDD8FDFCF8
FFFFFDEEF0EFFEFFFFFFFFFFFFFDFF3B3235E2DDE1585659030408070B0E11151833373A
0000022B2B2B0100000905020B0600E1DAD0FFFFF3FFFCF8FFF5FFFFF9FFFEFFF8F6FAE1
3326036F522AFDD1AE61381AA9987C181800011000000900D7E4B9C8D6A1D7EAA8CCDEA0
CDD8B0FAFFE8FEFFEFFEFFF6FAFCF9F8F9FBFBFAFF010000040100797762DDDDB7DDDCAE
B2B2807373419D9C70DEE5B9CEE6B4CBE9B3CBE8AEC8E1A8CFE3B0D9E8BF4952370A0E00
1B1D0F11140371755E6F7358000500010900040B00C8D2BAD6E2BCCCDCABD4E5B1A6B981
94AA6A8CA56189A359839F52C9E696D7F4A4C1DD90CAE69BD5EFA6CAE49DD4EDABD2E7AE
687A540008005D6E4ACFE4BBD1E9B9C9E2ABC9E5AA95B3735A7935C9E8A2D2F2A9C8E89D
C1DF95CEEDA1D3EFA2D2E89DD9E39ED5D895A7A9689FA06473743A272700999965838554
A1A475EAF2C3D7E0B39AA77B6A7B4E647A4B000C000615000B0900070000A2A094E1E3D6
C8CFBFFBFFEDF1FCDAE0EBC1D8E2B0D0D9A2DBE5A9939F5DADC179C6DF8ECEEF98D2EB9A
E2E1A8BAAE84776D49332C0F0602000B0B00030A00D1DBB8
EEF1AECAD18DA2AF69CBE198CCEB9FCDF2A4BFE496C6EB9DCEF0A3CAE99DC8E298C8E096
C0D88EDFF9AFB6D086D5F3ABC7E5A5C9E5ABD3E8B0D6E4AFD9E1AEDBE4AFC6CF989CAA6D
CEE1A194AB65C8E49ACCEB9DCCEB9BCFEC9CC7E293CBE695CAEB94C7E891CDE995DBF3A7
D3E6A4BECB95A8AE88A2A48CFFFFF4F8F4F1FFFDFEF8F8F8F0F1EBFEFFF4F9FFEEF6FFEC
677564ADBEAED8E6D7E5F2E1E4ECDDF2F6E8FFFFF4FFFFF6FFFEF5FBF8F1DBD8D3F3F2EE
F9F9F7FEFFFFFBFDFCFFFFFFF8F2F4140B0EA59FA167626608060B00000516171C25282D
3C40431516183B3B39010000030000BDB9AEFFFFF1FFFCF6FFF8FFFFF4FEF4FCEDFBFFE6
544D23584014EEC29D906545A48F72060200000700000900C2D0ACEBF8CAC5D79DE5F3BE
E1E8C7FAFDECFEFFF6DADFD9FBFFFFFCFFFFF5F7F40505000401006B654BD0CAA8EDEABF
858553535820ABB47BD3E6A6C7EA9AC7EE9DC9EDA3C9E8A5CDE4AED9EABE333D1B060C00
010200080900030400010400000400000400030C00D8E3C1CCDDB3E5F9C8CBDFACC0D59C
CEE4A6C9DF9E9DB46C728A40ABC377C8E094CFE79DD2E9A1CFE6A0C3DA96C9DF9FD0E5AD
000900000800415230586D468FA67CA4BE8F62804C1F4007001700BCE19CC4E8A0CDF2A5
D3F8AAC5EA9AB8DB89CBE896D5E899D5E197C5CF88E4EBA8BEC2875B5E27626131403F13
5A5832D8D8B4636444393C1D0A1100000600182305000600030400111000C8CEAADCE7BF
D5E4BBF8FFDCF9FFD8BFCD9AD2DCA8DBE4AFD6DDA7A1AA71B5C388D9EBADD4ECAECDDFA5
DCDAAAC8BC96817754443D20040300040700162000DFEBC7
D8DD9A96A05B99A962C5DD93CDECA0CBF0A2C6EB9DC8ED9FBEDE92D9F5AAC7E197CBE399
EDFFBBCBE59BC6E096CFEDA3A3C27C6E8B48869C5CD2E4A6DDE8ACA9B377A7B174D1E09F
DCF0ABBDD78ECFEEA2CBEB9FCCEB9DCAE69BCCE69CD2ECA2C2E193CEED9FCEE89ECDE29D
D6E5AAE2EBBCC0C6A293957FFFFEF2F8F5F0FFFFFBF8F9F4FFFFF6FCFFEFE9F2D7F9FFE8
ECFCDF6C7C61CDDBC1C8D4BCD4DCC5F7FCE8FFFFF1F3F1E4FFFFF4FFFFF6D1CCC6FFFFFA
FFFFFAFFFFFBF9F8F4FDFCFAFFFDFD5D5457D7D1D37F7A7E010002000002F2F3F5FEFFFF
F3F5F4F7F9F6FFFFFBD9D8D3827F76BAB6ABFFF9EFFEF4F2FFF8FFFFF8FFF9FFF6F0FDDF
99946C695228F6CAA7966B4BD5C0A3131100081400000D00D7E4C6D6E2BCCCDCADDEEBBF
FCFFEAEFF1E4FCFFF8FCFFFDFCFFFFCBCFCEDCDED90101000A0800757253E5E3BC787A49
838852ADB77BF1FCC0C1D691C5E991C6EF91CCF099CDECA0C9E2A0D5E8B0101C00000700
6D7150D9DCBDCFD4B48489696D74523F472200080001100037481BB7CB98D2E6B1DDF2B9
D6ECAECEE5A1C5DC94C5DD93C4DC909AB2668AA25893AA62B5CC86D6EDA9D4EAAAC8DDA5
71815A0008002C3B1A6D7F595C73495872435C784555743B001000C9ECAAC7E8A3C8EAA0
C7E99DC2E595CBEC9BD2F1A1D3EC9BE2F7AACBDD93D0DF9AD2DEA0D9E2A9D3D7A59E9F73
5E5C350A07000706000403000304002F321566694C6B734AAFC282C5E093E1FFB4AACA7E
D5F7ADC8E7A1BDD796DEF2B7DBE5B3FDFFD7FFFFE2FCF6DEFCF7E4FFFCEDEEEEE4F8F7E5
FFF6D5CBBF995F54346C654904020001030032381CCBD4B7
D8DD9A98A25DC0D089D4ECA2D1F0A4C8ED9FC7EC9EC0E597CFEFA3C9E59AC2DA90DBF3A9
C4DC92CCE69C425C12446317CCED9EBFDF9393AD64566A254C5B1A8C9858C8D494D1E29E
CBE199CAE69BC4E397C6E69ACEEEA3C8E69CCBE6A1CAE39FCEE9A4CDE8A5DDF3B2C5D99C
FAFFD3FEFFDCFFFFE4DBDDC8A19F93FFFFF8FAF9F4FEFFF5C9CDBCE1EACFD3DFBBD3E2B9
D8E8C1000900000D00E9F4D2D4DABEE1E5CCFFFFEDFFFFF1FEFAEEFFFFF4B7B0A8FBF6F0
FFFEF8F6F3ECFCF9F2FAF7F2F5EFEFA1989B8F898B5F595B0804050C0A0BFFFFFDF1F3F0
FFFFFBFFFFFBFFFFFAFFFFF8B1ACA69A968DFFFEF6FFF5F4FFF9FFFFF8FFF7FFF4E4F3D2
DCDAB16E592EE1B7918B6242C0AD8F111000000600000700C0CAB2D4DDC0E0ECC8E6F1CF
FEFFF1FEFFFAFEFFFDFCFFFFF1F5F6D9DBD8DADBD30B0C000303008E906B747748353C06
ECF7BBC7D598D7E7A9CDE79EC6EA90C5EF8DCBEF95CEEE9BC4DE95D2E6A7000A00000800
747B52D1D5B0E5EBC551582FE0E9BECAD6A8657342011100000B00728653C7DCA4D4E9B0
CDE3A3C9E09CD0E79FD8F0A6D8F0A4C1D98DD7EFA589A058374E088BA25EDAF0AFC8DBA3
C3D2AB0D1B00616F4CCBDBB6D1E6BDC7DEB0C6E1AED2EFB7809E62D8F8B7C9E8A4CAEBA4
C6E69BC3E397DAFBACC9E898C0E08DC9E696D0EB9EE3FAB2D0E3A3C7D59AE7EFBCC5CB9D
6061390404001D1A000603006360416B674AD4D3B5E2E9BDD4F0A5BDE489C6EF93CBF69C
C8F39AC9F09DBDDD92D0E6A6D7E1AFFFFFDEFFFDE6F0E3DAFFF2F2FFFAFFFFFAFFFFFBFF
FFFEE6BEB490534A2B736C52050300010200D7DCC6D7DFC8
B2B9759CA762D8E9A2D3EDA3CBEB9FC3E89ACAEFA1C2E497C5E498D4F0A5D8F0A6C2D88F
A5BD737F994FB8D288CAE99BD5F7A3C5E793C3DE91C8DE96CDDE9AD9E8A7E2F1B0DCF0AB
C3DB91D6F5A7CBEC9DCBEDA0C9E9A0C4E29CCEE8A7D6EEB2CEE7AEC1DAA3D7EBB6CFDFAE
FCFFDDF5FCDAFFFFE8F6F7E589877BB1AEA5FEFEF4FFFFF1ABB49964704AB3C394D2E3AF
D8E9B3C6D4A1000900DBE4B9C2C8A4F7FADDFFFFEAF9F6E5FFFFF1FFFDF3D7CEC5DDD6CE
F8F1E9FFFCF3FFFFF4FFFEF8FFFCFDFFFCFF3F36392D2727030000010000EDECE7FFFFFA
FFFFF8F6F6EEFFFFF8F0EDE6F6F1EBBEB7B1FFFEF8FFFDFBFFF9FFF7F5F6F4FFF3F5FFE4
EAEBBF6351239C754C96704BD2BF9E737254041000051400646D5AE6EED9F1F9E1FAFFEB
FEFFF8ECEEEBFEFFFFFAFBFDFEFFFF4748430002000003000F13002930045C66318F9D60
C1D192DDF2B1C1D797D6F1AAC5EC93C5ED8DC9ED95CEED9DC5DF96D4E8A9000B00010A00
5D643ACDD4AB697047E8EFC6D6DFB4D3DFB1E0EEBD000B000214003F531ECCE1A9CCE1A6
CFE5A5CCE39FD0E79FC8E096CBE397D5EDA1CAE298CBE29AE9FFBAA7BE7A617736AFC28A
5F6B450007006B7654D1DFBBD6E8C0D3E9BBD1E9B7C5E0A9CFEBB1BCDA9CBAD795C0DF99
D7F5ADC7E59BCBEA9EC0E192C8EE9BCEF4A1C5E898B9D78DCBE4A0DEF2B3DBEAB3121C00
141A000305005D5A37CCC7A7625D3D4B4628857E61B8BD94D8F1B0B7DE8FC9F2A3C6F19F
AED987C9F0A1D4F4A9CFE5A4D6E0ABFFFFDCFFFEE2C4B8AAF1E3E2FFFAFFFFFAFFF7EBEF
EEE4CB9A906D574D32807A640C06000A0800000200E3E7D9
838A46A1AC67D2E69EC5DF95C6E69AC0E597CCF1A3CCEEA1CFEEA2BAD48AD4EAA1D0E69D
AEC47BD7EFA5BBD58BCEED9FCAEC98C6E894D2ECA2D9EEA9D5E5A7D1E1A3CDDD9EBFD491
CFE9A0D7F6A8C1E494C4E99BC4E69CCBE8A6CBE4AAD0E7B3D2E7BCCFE4BBDFEFC8F9FFE3
FCFFE4FFFFE8FDFFEAFFFFF1C8C6BABEBEB2FFFFF3FEFFEC88926FD7E7B8D0E4A965793A
AEBE80E9F7BA57622A2D3504EDF2C9D8D9B9DEDCC3FFFDEAFFFCEFF7EEE5FFFDF4C7BEB5
CDC4BBFFFEF4FEF5ECFBF4ECFFF7F8F7EEF33C33360B0203040000050200FFFFF8FDFDF3
F3F0E7FFFFF4FFFFF4FFFEF5F2EBE3CCC5BFFFFCF9FFFDFBFFFBFBFEFFFAD5EED1EEFFDD
CFD6A39B8E5A7452248B683EC6B48EDBDBB90A1700000700000400797D6EFEFFEFF2F9E9
EFF4EEFCFFFFFEFFFFF0F0F2FCFCFC010000010200090D00929872E5F1BFCEDEA0D6EBA8
D5ECA8CEE7A3D2EDAABBDB92C6EC99C3E992C8EB9BCEECA2CCE5A3D7EAB2152300081300
727A55DFE5C1DFE5C3DDE5C0D2DDB5C5D2A7D4E4B7000F00000C00213600D9EEB5D0E5AA
CDE3A3C9E09CD8EFA7D3EBA1C6DE94D0E89CD5EDA3C9E098CDE49ED3EAA4C3DA96C1D59A
616D4500070038421F9FAB85C3D4AACBDEB1D8EEBDC9E2ABC9E2A9D8F4B7E3FFBEC1DE9B
CCEAA4CBE69FC4E096CDECA0D0F7A4BEE894C3E898CFF1A5D1EFA9B4CD8CCCE0A53A4813
0008000E1400EAEAC4D0CEA8DEDAB7E7E3C098927075754F5C6C3B5B743BBDDB9FCAEAA9
E0FFBCC8E7A1C4DF98C8DB99DEE9AFEEF1C2FFFFDFD0CAB2FFFDF0FFF9F6FAF5F9FFFEFA
FFFFE5CBC2A19C9279261F0D0600000300008A8B85F7FAF3
96A05BD2DF99DDF1A9CAE49AD3F3A7C1E698C1E698CAEC9FCEEA9FCBE59BD6ECA3B2C87F
D3E9A0BDD58BDBF5ABCAE99DC6E69AC4E29ACDE6A5D2E6ABCDDEAAD3E1AEDAEBB4D7EDAF
C5E099C2E296BEE393D1F6A8CFF0A9DBF8B8C7E0A9C4DAACCDE0C0D2E2C7E0EDD3F9FFEA
FEFFEDFBFEEBF6F7E7FFFDF0E3E0D7C9C9BDFFFFEFDFE8C9B9C69AC7D8A1D1E8A494AA62
96A560AEB879DFE9AD1A2100D5DBAFCECFADE8E7CBDBD8C5FFF9ECFFFDF4FFFDF6E1D8D1
C1B8B1FFFDF4FFFDF4FFFDF8FFFCFDFFFCFFB7AEB13F3735040000040000F9F5EAFBF9EC
FFFFF3FFFFF3FAF6EAFFFEF36A635B7E776FE4DDD7FFFEF8FDFAF1FBFFF1C0DEB8D2F0BC
C9D49ADFD69B73541E7858279F9162E7EABF4E5C391B290F000500292D1CFAFEEDFCFFF6
FBFFFFF8FDFFF5F6FAFEFEFFE1DDDC030000040300020500CFD8ABC7D69DD8EEADC5DF98
C6E49CC0E097CEEDA9CDEEA9C8ECA4C3E79FC7E7A6CEEAAFCFE6B2D1E2B6283410000900
63694FB6BCA2EAEFD8F8FFE6DFEACCDBE9C8D1E1BD000A000012003D5219CFE4A9C8DEA0
D0E6A5D2E9A5D2E9A1BED68CD5EDA3D1E99FC9E098CCE39BCBE29CD0E7A1D7EEAAC5D99E
606B40192100050F0059653DD4E3B8DAEBBEC9DDAACCE3ABCAE3A9C0DA9DBCD695D9F4B1
C7E29DCBE59EC8E29BD0ECA2BCE191C7EE9BC8ED9DBFE195CEECA6D3EDACD5EAAF71824B
172500000800CDD4A8E9EBC3D5D6AEDCDDB5E4E5BDAFAF8B47452C101000A8AD8DD0DBB1
C0D19DCBDDA3E6F6B7CAD998DAE2A6CBD098E6E8B7C8CAA2FBFFE0F6FEE7C0CBBAF0F7E5
E3DEC1E5DCBFABA08C2A23130E07000400005F5E5CFEFEFE
949F5ADCECA5CAE097C0DC91D8FAADC2E799BDE294D0F2A5CBE79CCAE298C9DD9597AB63
CDE39AD1E99FC5DF95CBE79DD0EDAAC6E2A7D2E9B5EDFED2FBFFE1FBFFDFEBFBCECCE1A9
CFECA9C8EA9ECAEFA1CBF0A3B2D38ECFEBB0DDF3C2F7FFE3F7FFF1F3FFEFFBFFF4EDF4E4
FFFFF3FBFBEFFFFFF4FFFCF3DEDBD2C1C2B46C6F5A798360D8E8B7D2E6A7C7E197CEE698
D3E39C8B96549BA368A0A773060C003A3C17929276A2A08BCCC6B8E0D9CFB6ADA6BEB5B0
857A76B9AEAAFFFCF6FFFDF8FFFCFDFFFCFF756C6D362E2C070200060200383429878377
706D5E7B78697673641511050600000A0300060000FEFCEFF0F3DEDCEBCABEE0AEC9EDB0
DBEBAADCD795684B0F80632BB8AD77D6DAA8CFDEB382936F000600090E002F3420A7AD9F
EEF7F2F4FDFCFDFEFF5C5A5B040000080100040100ABAE8FD4E0B0D7EBAEC0DB96DDFDB2
C9EB9FC5E79BC8E9A2CAEBA6CAEDABC4E7A7C8E7ACCCE7B2CEE4B6C7D7B02D3818000600
3B4029636B548A927BE0EAD1D0DDC35B6A4D364727000A00000D006A7F44D9EFB1CFE5A5
CBE29ECDE49ED6EDA5D0E79FCDE59BD3EBA1C8DF97D4EBA3D4EBA5CFE6A0D5ECA8B2C488
677043050B00353D149CA77D7C895D384A1A93A571D3E8B095AD71001900000F00CEE9A6
D4EDA9CAE39FCFE6A0CEE89FC3E495CAEB9AC8E89CC7E59BCFEAA5CDE8A5C6DC9ED2E7AC
63743E000A007C8858C4CD9EDAE3B4DDE5B6D3DBAC73754E0B00000B00005550335A5A34
727848D8E1A8D9E3A4DDE6A5D7DD9DE1E5AAFCFECDD8DAB2FFFFE4FBFFED4D5A49081100
444027A59B807D72603B3326060000050100010000FEFEFF
99A660D0E19AD9EFA6C4E095C9EB9ECBF0A2C4E699CCECA0C9E399D8F0A6C6DA928A9E56
D4EAA1D8F0A6C9E399CCE7A2CDE8B1D2E9BDDFF0CEF0FEE4FBFFEDFBFFECEBF9D6DAEDBF
C8E4A7C3E49DD0F5A7C3E89BC5E4A1C7E0A7E9FCCFF2FFE2F8FFF6F9FFFBFBFFFBFCFFFA
FFFFF8FFFFF8FFFFF8FFFFF8D8D8CEDEE0D2F0F5DEFBFFE3CCDFA8D2E9A5D1EE9ECDE695
CDDC97DBE5A8D0D9A05E6633FFFFDA1D2100030600706F5A6967580C0800060000DFD8D2
E9DFDDFFFCFAFFFCFAFFFCFBFFFDFDFFFDFD847F7C57524E2F2A24040000524E435E5A4E
504D3E110E00242112565342524F3E040100D9D6C5FFFFECD4DBB9C8DEADC8F0B2C0E8A1
D1E59DE4E19A5F4805725919A8A062C1C98DDCEFB8D5EBBCCDD9B52C3314000500020C00
00070066716B0002000D0C08070000594F46E5DECCDBDCBCD6E2B2CBE1A3CAE8A2CAECA0
C2E799C5EA9DCAEBA4C2E39EC4E7A5CFF2B2C2E1A6C6E1AAD8EEBF000B00000800000700
000600000600000600061100000700000A00000900001500687D45C3D999D7EDADD0E6A5
D2E9A5C6DD97CBE29ACDE49CCFE69ED1E8A0C3DA92D6EDA5D2E9A3D2E9A3D8EFAB5F7133
000800000700060F00020E00031100000B00001200000D00000E00082000627B3AC4DD9B
D3EAA6C6DD99D6EDA7CFE69EC6DE92CEE698CDE59BCDE49CD3EAA4D1E7A6CDE3A5D3E8AD
C7DCA3001100000C00000B00021400000D00000C00010B000A03005B4E24EBE5B5C6C58D
696E2E5259155D641ED6DB98D8D89ADFDCA7F8F3CDD9D3B9D7D3C7FAFBF6616568070906
0700001C12000B0000292116060000030000121011DCDCDE
91A15AC5D991D2EAA0BFDE92C6E89BC9EEA0C6E89BD1F0A4CFE99FD2E89FE0F1AA99AA63
D1E59DC1D98FCFE99FCCE6A5DFF6C8EEFFE1F8FFF1F9FFF6FCFFF8F7FFF2E0ECD4C6D8B2
C9E5ABC2E39ECCF1A4C0E598C9E6A6CDE4B0EDFDD6F6FFEAF9FFFBFBFFFFFCFFFFFEFFFD
FFFFFBFFFFFAFFFEFBFFFFFAFEFEF6F7F9EBFDFFEBFBFFE1CEE1AAC8E29BC8E895CCE796
C9D998E4EFB7D8E2ADAAB482A9B285AFB790A4AA88868A6F868873A3A4947F7B707C786F
625A57877D7CB8AEADFFFDFBFAF6F3FBFAF6FFFFFAFBF8F304000076716BFFFDF4CFCBC0
EAE6DAF7F4E5FFFFEFFFFFEDFDFCE7919179DDDDC5F7FDDBD4E0B0C9E3A6C7F2AABEE99A
D2E79AE1E19779621F786020BEB977DBE6A4D0E6A6B7D097E8F5C7C4CFA597A17C616F4E
22341E303E2F181E1479766FCCC1BBB1A49BFEF6E3FAF9DAE8F4C6D0E8ACC5E6A1C5EB9E
C2E89BC5EA9DCCEEA4C9EAA3CBEFA9C0E19CCBEAA7D0ECAFC5DCA470825095A5789CA97E
5D68404B562E606C46606F467485597184566F8556C8DFABD3E9ABCFE5A4D3E9A8CFE6A2
C1D892D5ECA6A2B971758C44C7DE96D6EDA5CAE199D8EFA7CCE39DCCE39DBBD28EC2D496
959F6B737B4C656F3D68744277855073864F74874F6B80456D8547708948A7C07EDCF5B1
A2B9755D742E8BA25CCBE199D5EA9FDEF0A4D6EAA2CEE29BCDE29DC8DD9AC8DE9ED1E9AB
E1F9BDBAD39988A066465F25000E001932002D4509596B2FCDCE94CBC98CE6E8A7E3EAA4
CCD78BA5B0626971245A6018AEAC6FE4DCABFFF7D7E8D8C8FFFBF8FFFAFFCABFCF7C727B
9C90828B806A5D5143180F06110906080403010000040402
99AA63C9DF96DAF4AACDECA0CDEFA2C9EEA0C2E497C8E79BD9F1A7C2D68EC7D89198A962
CCE098CCE49AD7F1A7C9E3A2E2F7CEF7FFEDF9FFF6FBFFFBF8FCFDFBFFFCEBF6E5D2E3C1
CCE7B2C4E4A1CBEDA1C3E59BD7F1B4DCEFC1F5FFE4FBFFF3FBFFFDFCFFFFFEFFFFFFFFFF
FFFFFDFFFEFBFFFDFDFFFEFBFFFFFAFDFFF2FCFFEDF9FFE3D0E4AFC5E09BC7E897CFEB9E
D4E6AACDD9A7D2DEAEF0FCCCEDFACCFBFFDCFBFFDFFCFFE3FEFFE6F4FAE0FFFFEFFFFFF3
B0ADA40400000D0503F5F0EDFFFFFAFFFFF8FFFFFAFFFFFA0B08036C6964E0DBD7DFDAD4
F5F1E8FFFFF3FFFFEFFFFFE8FFFFE6CDD3B1D3D9B5D9E2B5D5E4A9CAE59EC6F2A3BCE998
D2E99BDEE0979A85447C6424AAA764D7E49ED4EDA9C2DF9DCFE1A7D2E0ABDBE9B6D5E6B9
E4FAD6F4FFEDFCFFEFFFFFF1FFF7EE8E7D73DDD0BFFFFFE4F9FFD7D3EAB2C3E3A0C7EDA4
C7EDA0C7EC9FCDEDA4CCECA1C3E696C4E795D4F5A6D1EDA2C1DB92D9EEABDFF2B2C8D79C
D5E3A88F9D62D2E1A8D2E4A8CBE1A3C6DF9EC2DC9BDEF9B6CCE5A1DAF1ADCBE29ECBE29C
E2F9B390A761C3DA92CFE69E425911597028CEE59FCBE29CCCE39DCFE6A0D3EAA4D0E3A3
D0DBA3D8E1ACDAE4AFE2EFB9D6E5ACC6DA9FC1D598D3E9A9CFE8A7D0EBA8C6E19CC5E099
CDE7A0D7F1A8B6CD855B7128A4B46BBDCB80CEDE97D7E8A2DAEEA9D2E7A4CAE0A0CEE6A8
C7E1A2CCE8ABD4EEB1CDE9ACDBF5B6CAE7A7CBE5A6C8E19FCFE499D6E99AC3D987D3EB97
D3EB95C5DB86DEED9CDFE79E433F026658299E896CA28879FFF7F6F5D7E3FFF5FFFFF6FF
FFFBF1FDF2E08B7F7161584FA29B95FDFAF5FFFFFAFAFDF4
70843CA1B96FBFDB90C4E498CBEDA0CCEEA1C7E79BCCE89DD7EDA4C3D48DADBD7699AA63
C6DA92DCF4AACEE89ECCE6A5DEF1C4F0FEE4FBFFF4F9FEF8F9FAFCFCFFFFFBFFF4F3FFE4
CFE7B3C8E7A4CDEDA4C9E8A4E8FFCAEEFED9FBFFEFFEFFFAFEFFFFFEFFFFFFFFFFFFFEFF
FFFEFDFFFEFDFFFDFDFFFEFDFEFDF9FBFDF2FBFFEEEFFFDBCFE6B2C8E5A2CCED9ECAE99D
D3E8B0EFFFD2F2FFD5D7E7B8EAFCCAC1D3A1B8CA98CFE1B1C7D6ABCDD9B3E0E9CCEAEFD9
F9FBEDCACAC085807C4D4A457D7F74FEFFF6F1F4EBFFFFFA010000858180FCF8F7FFFEFD
FCF7F3FCFAEEF7F6E4FCFFE4F0F6D2D2DBB0E8F2C0CEDCA1D4E5A1CBE79AC4F4A0BEEB9A
D3E9A0DADB99B29C62766026B7B675CFDE99C8E49AD5F5ACCCE2A1C7D99BD1E3A7E3FBC1
EBFFD6D8F1C9D3DEBEFFFDE8FFFCEF877569C4B4A5FFFBE4FCFFDFD4E8B5C1E1A2CAEFA9
CCF2A7C9EBA1CCE7A0CBE79CC0E48DD0F49ACAEC95C8E591CFEA99DDF4A6C4D98EC7D891
8C9B56778842C5D992D0E69ECAE298DDF9AED5F4A6BCD88DBDD78ED6EDA7CBE29CD0E7A1
D9F0AA96AD67D8EFA7E1F8B0B0C77F819850849B558CA35D768D47D2E9A3CBE29CC8DD9A
D1DFA2E2EDB3CDDBA0D2E1A6CFE1A3D7EBACC7DD9CD5EEACC4DF9CD3EEA9D1ECA5CFEBA1
CDE79ED5EFA6D2E9A1A3B97091A15899A75C92A25B8B9C558CA05B8BA05D8DA66499B372
BFD998DAF4B3C8E2A3C2DC9BB2CC8BD5EEACCAE3A1CDE7A0CFEB9EDBFBA8C3E58FD0F49D
CAEC95B9D781DAF09EDBE79DEBE9ACA1956368512F61452FBD9F94BFA09DFFE6EBFFECED
FFF1E5FFFDED9B8F83877E75DCD5CDFFFFF6F5F7EAFEFFF3
859B52A5BF75BEDD91C5E599C8EA9DCAEC9FC9E99DCDE99ECDE39AD4E59ECADA93A8B871
D4E59ED1E79EC2DE93D2EDA8DDEFBBE6F2CEF4F9E3FEFFF5FEFFFAFAFCF7FBFFF2F8FFE6
CCE4B0C9E8A5CCEBA5CDEAAAF5FFDCF9FFEAFEFFFAFFFFFFFFFEFFFFFEFFFFFFFFFFFEFF
FFFEFDFFFDFDFFFDFFFFFEFDFFFEFCFEFFF8FBFFF1E0EFD0CBE1B2C8E6A6CDEFA3C3E29C
BFD5A4F0FFD9F6FFDCF0FFD3C7DEA6DBF3B9D2ECADD1E9ABD1E6ADD7E9B5D5E4B9FBFFE4
FCFFECFEFFF1F2F2E8A5A69E686F5FB9C0B0FCFFF6F6F9F23C3C3C777578FFFEFFFAF8FB
FFFEFDFFFFF8FFFFEFFFFFE6D6DFB4909D68D0DEA1C9DA94D1E69BCCE999C3F2A1C3EFA0
D2E9A5D7D89EB49E6C6B5523AAAA6ED3E4A0C7E59DCFF1A5C7E198DAF1ABD2E9A3C7E29F
BEDE9FCCE9B1D1DEB3FFFFE4FFFCEC614B40BBA79CFFFEECFFFFE4D6E9BCC1E0A7C7ECA9
C9EDA7C7E79ECCE69FCDE89BCCEE97C9ED93BEE187C7E58FD5F19CC5DC8ACEE394EAFCB0
8D9F55DEF0A6DBF0A5CCE498D0EB9CD1EE9EBDDD8ACDEC9CD9F3A9CAE199DBF2AABCD38B
485F17D6EDA5D3EAA4BED58FD0E7A1CAE19BDBF2ACC0D791CBE29C879E587D944C95AA65
98A766C9D597CDDB9DD2E2A3CDE09EDAEFACC6DF9BCBE69FD3EEA7C5E399BCDA90CEEDA1
CDE99EBEDA8FCDE79DD5EDA1C8DD90D4E69AD4E8A0D5EBA2D7EEA8C8E19DB5CE8CB0CB88
748F4C8DA664CCE2A2D4EAA9D0E5A4DFF2B0D1E1A0CEE3A0C7E6A0C1E79EB5DE92C5EEA0
D2F9AACEF1A1CEE99CC3D58BDCE19FECE7ADD8CA99D7C4997E6A459D89687A67496A593F
887966C0B3A3A99D91A49A90FFFFF4F7F8EADDE2CCCED6BE
CBE399D3EDA3D7F6AAD0F2A5C8EA9DC6E89BC8E89CCAE69BCFE39BD3E49DE5F2ACB1C17A
DEEFA8CEE49BCEEA9FD1EBA4D4E6AAD8E4B4E8EDCDFCFFEAFFFFF6FBFDF2F6FEE9F9FFE4
C9E0AAC9E6A4CAE7A4CDE7AAF7FFDFFBFFEFFEFEFFFFFCFFFFFDFFFFFFFFFFFEFFFFFEFD
FFFDFDFFFDFDFFFDFFFFFEFFFFFEFCFEFFFAFAFFF2D3E3C6CAE1B3C6E4A8CDEEA7C5E6A1
D7EEC0E3F8D1E2F8CAEBFFCFC1DB9ECAE7A4C4E29ACAE89ECAE59ED3ECABB5CA92F4FFD8
FBFFE4F3FBE3FEFFF3FEFFF457604B767F6CF9FFF2FCFFFA000002838288FAF7FFFFFDFF
FAF8FBFFFFFAF8FBE8FBFFE1D7E3B38E9E60CDDE97DDF2A5D0E596CBE898C2EE9FC6F2A7
CFE4A9D8D8A6A79067644D23908F59CFE2A2CEEEA5C9EEA1C0DC91CCE79ACAE598CBEA9E
C3E99EDBFBB8DEEFBBF2F2CEFFFBE7584034C0A9A1FFF4E7FFFFEAE1F1CCCBE7B4C8EAAD
C4E4A1C4E29CD2E7A2D5EBA2C8EA96C2E68FD1F39FC7E492CFEA9BD6ED9FD7ECA19DAE67
A5B66FE0F4ACC2D68ECBE399C9E399C5E496C4E596D6F5A7C9E497D2EAA0D6EDA5A0B76F
485F17D0E79FD9F0AAD7EEA8CDE49ED6EDA7B9D08AE5FCB6DBF2ACCAE19B9EB56D8BA159
505F1C9BAA67D1E29EDDF1ACD0E5A0D1E8A0CCE69FD1EDA3C0DE94DAF9ADD8F7ABD0EFA3
CDE99ECEEA9DD6F1A4C6E194D6EEA0D2EA9CC2DC92BBD78CC7E29BCDE8A1D0EBA6D8F3B0
ABC4826E844398AB6B8E9E5DD8E7A6D4DF9DDCE5A4D1E09DCFE9A8C8EBA7CBF0ABC0E8A1
B9E198BEE499C8E89DDBF3A9D8E5A0CED391E2E0A3D0CC8FB4AF77D8D69DB3B27A918E61
7A6E5677675A83756AC9BFB5FCF9EAF4F5E3E1E7CBD8E2C0
CCE69CC9E59AC9E89CC6E89BC2E497C7E99CCEEEA2CFEBA0D4E8A0CDDE97DAE7A1BDCD86
A5B66FC4DA91D2EEA3CCE69CCFE099D2DEA0DBE3B4EDF0D1FDFCE8FFFFEFFEFFECF8FFE0
CAE2A8CEE9A6CBE6A3CAE2A8F8FFE4FCFFF6FCF9FFFFFBFFFFFDFFFFFEFFFFFEFDFFFEFB
FFFEFBFFFDFDFFFDFFFFFEFFFCFAFBF8FAF5F4FFEFDDEDD2DFF6CCC7E6ABC8ECA6CBEBAA
CBE5B8F4FFE4F2FFDDC0DDA5CAE9A6CBEDA1CCEF9DC4E793C1E38FDEFDB1D2EDAAE7FCC4
ECFBD2EAF5D5EAF2DBE8F0DBF1FDE52A361EB3BEAEFBFFFA090A0C76757DFFFCFFFAF6FF
F8F5FCFFFFFBFAFDECFEFFE3B9C792A6BA75CDE293C9DF8CD1E795CBE79ABEEA9DC8F1AD
CBDFAADCDAB1937C5C634C2AA5A476D2E4AAC1E29BC3E99CD7F6A8D6F3A3C7E696CDF09E
BFE995BBE093CEE0A6FFFFDCFFFCE65F44399F8880FFFCF1FFFFECEEFDDCE0FCCCD7F9BD
CCEAAACAE5A0D4E8A3D3E7A0C8E69CBDDF93DEFEB5C7E29BCAE39FCCE1A095A86868783A
DDEDAFCCDEA0CEE0A2DEF4B4CDE6A5CEEBA8D8F7B3BEDE95C1DB91DCF4A8C0D88E9CB46A
D8EFA7C9E098CEE59FC3DA94D4EBA5CEE59FD5ECA6C8DF99C6DD97C9E09AECFFBBC7DD95
88995391A05BA7B872ACC079B6CC84BDD58BCBE59CC7E398D3F2A6C9EA9BB2D384BDDE8F
CEED9FC9E89ACEEA9DCAE797C8E797CDEE9DCBEB9FCCECA0D2F2A9CCECA3C2E09AC5E09B
C7E09CCFE4A194A362838D4E8E9454C9CB8ACDCD8DE4E9A7CDDD9ECBE4A2C9E6A3CBECA5
CAEEA4C8ECA2CAECA0CAE69CD8EEA5C1D28BDAEAA391A15AC3D48DBED48BD3EBA1DCEBB0
DCD5B9C6B6A9C0B2A7FFFDF1FFFDECFFFFECCBD5B3D8E4BC
D4ECA0CBE699CEEA9DCEEEA2C9E99DCAEC9FCCECA1C7E399CFE69ED3E7A0CEDF99D3E4A0
465A15A2B772BED891D0E89ED6E89CD9E6A0D5E0A6D8E1B2E8F0CBFBFFE3F9FFE1F4FFD9
CDE7AAD0EDABCBE5A6C8DFA9F9FFE6FEFFF6FFF9FFFFFBFFFFFDFFFFFEFFFFFEFDFFFEFB
FFFEFBFFFEFBFFFDFDFFFEFDFFFEFFF9FBF6FBFFF6F8FFEFF5FFE4CDE8B5C3E1A3CAE6AC
D1E5C0F5FFE8F5FFE6DAF1C3C4E0A5C5E59CC5E894C9ED95D0F29CBEDD8FD0EAA9CDE4B0
C8D6B2D2DDBFD8E0C9D1D9C4CFD8C3747D6A828A7DEEF5EE0B0F1288898EECECF4FEFFFF
FEFFFDEAEEE0EFF8DBD8E5B94254188A9E56D9F09ED1E794D5E899CCE79ABDE69AC9F0AD
C6DDA5DDE0B383734F63512B939161DAE9B0CFEEAAB6DC8FCBEDA0CCEB9BC5E494CCED9C
C6ED9CD5F7ABC2D898E2E9B6D8CBA888725A9B8474FFF2E2FFFFECF6FFE8F4FFE4EEFFD9
DFF3BED6E8ACD5E5A4CADE99DDF8B3B5D38DD0EBA8CDE6A4CBE4A392A8684C6023C7DB9E
D0E4A7C8DC9FDDF3B5C4DD9CCAE4A3C8E7A4CAEBA6C8E7A1D6F0A6D0E89CC5DD938DA55B
CDE79ECFE9A0CAE49BD7F1A8C5DF98D1EDA3C5DF98CCE69DD9F3ACCDE79EBAD48BD3EDA3
D6ECA3C6DC93DAF0A7D0E69DBED68CA8C076C7DF95D2EAA0C2DC92D5EFA5D0EAA0D2ECA2
D3EBA1C6DE94CFE79DD5EDA1CAE699CFEEA0CBEA9EC6E69ACAEA9FC8E89FC8E69ED0EEA6
C3DD96EAFFBBC2D38FD2DE9CD9E29F959C599A9D5ADEE3A1D3DF9FD7EAA8C6DD99CBE6A1
CAEAA1C1E399CEEEA3C2E096C4DB93E7FDB4CBDF97899F56BCD78ADAF9ABC7EA9AC8E3A0
E0E5BDFFF9E1FFFFE9FAF8E3FDFCE8FFFFECCFD5B9D6DFC0
D5EC9ECAE193CEE698CBE79ACEEA9FCEECA2C6E69DCDEBA5CCEAA4D2EDAACFE8A6CEE4A4
C0D495A0B475A5B97AD4E7A5D8EA9EC7DA8BD4E8A1D3E8A7CCE4A8E1FDC3DFFCC2D9F8BC
C2E5A3CAEAABC6E2A8C7DDAEF9FFE8FEFFF3FDF9F8FFFDFFFFFDFFFFFEFFFFFEFFFFFFFD
FFFEFBFFFFFAFFFEFBFFFEFBFFFDFCFFFFFBFEFFF8FCFFF3F5FFE4D0DEBAC8DAAAECFBD2
F2F7E3FEFFF5F3F9EDE4EED6F0FFD9C9E1A7CBE79CC8E893CBEB98C8E39ED7EDBCE8F9D7
E9F2DDE6EDDBEBEEDBEBEEDBFAFCF1CBCCC6292B28B2B3B545494AA7ABAAFBFFFBF1FCEC
EEFBE1E9F8D1D6E8B4D9EDB0506520CCE297D0E799D2E79AD9EBA1CAE097C7E99DC4E8A0
CEEBA8CCDC9EC5C48E59521E9E9B64D8E2A5CAE39FC3E79DC4E99CCFF1A4CBE79CCFE9A0
CCE9A7CDEBABC7E6A2D0E5A2E3E4A89F936188764EFFFFDFFFFFEAF9FFEFF8FFEFF5FFE6
EEF2D1D9DFB1CCDA9DD5E9A4D2E8A0D1E79FC7DC97ADC47E94AB6789A260C9E2A0CEE9A6
CAE7A4CAE7A4C9E8A2C9E9A0C8EA9EC8EA9EC6EB9DC9EA9BC6E096D7EFA5CAE29891AB61
C5E196D5F4A8BFDE92CEEEA2C0E095D1F3A6D1F1A6C4E498C5E59ACBEB9FCDEDA1D0F0A4
C3E397C9E89AD1EDA0CBE699DCF4AAC9DF9691A25C95A45F9EAB6687944F97A260919C5A
B2BC7DE4EEAFD4DE9FD5E19FD6E7A0D0E49CC6DC93D3EBA1C6E096DAF6ACCFEDA3C6E49A
CAE89ED3EFA5CEE89FD1E8A0C2D88FD7EBA393A45D96A56094A05ED2E19EDBEFAAC4DB95
CDE8A1C8E69EE0FBB4BFD992D3E7A2CEDF99D0DF9AB6C781889E56C7E198CBE99FD3EEA9
CEE1A9D6E4B3E4F1C6F6FFDEFEFFECFDFFF0FCFEF1FFFFF6
D1E699D6ED9FD4ECA0CFEA9DC8E298C4E095CBE99FD0F0A7C8E7A1C6E49EC6E19ED2EBA9
DCF2B2C6DA9BA3B2778F9F5ED1E399DEF3A4C6DC91CAE49BDEFDB7C2E6A0C7ECA6C7EFA8
C7ECA7CCEFAFCCE7B0CBE1B3FBFFE8FEFFF1FFFDF8FFFEFFFFFEFFFFFEFFFFFEFFFFFFFD
FFFEFBFFFFFAFFFEFBFFFEFBFFFDFEFFFEFFFFFFFBFEFFF8FAFEEDDBE4C9D6E2BEF6FFE0
FDFDF1FFFEFBFFFFFDF8FBF0FBFFE8D0E2B2CEE8A1D0ED9DD1EDA0CEE8A7E2F4CCF6FFED
F8FFF5F7FDF3FEFFF0FFFFF0FFFFFAE7E5E6060407010204D2D4D3DCE3DCF9FFF4F8FFEA
CDDFB5CDE2AACCE2A2D4EBA3435910C8DE93D4EAA1C7DD94D2E39CCDE39ACCECA1C2E79A
CDEBA3D5EAA5CCD093605B219E995FDDE1A4D1E6A1C8EAA0C2E89BC9EEA1C7E398CEE59F
CEE6AAD0ECAFC4E89EC7E396D3DD94948F4F6E5E2DFFF4D1FDFFE7F7FFF2F3FAF2FAFDF2
FFFFEDFFFFE1E3EFBDD4E8A9C8D897DCEDA9C7DB963B500B819854C8E19DCFEAA5C4E49B
C9E9A0C8EAA0C6EB9EC6EB9DC6EB9DC6EB9BC6EC99C9EA99CEE89ED3E9A0D2EAA0C9E399
D4F0A5CEEDA1CFEFA3C5E79ACFF1A4BDE294B9DE90CCF1A3D9FBAEC6E89BBADC8FC4E699
D3F8A8B8DD8DCCED9EC3E294B6D086D6ECA3DDEEA8CBD893879250636C2B5D63254B5113
71773BB9C185CFD79BEBF5B6CCD994D9E9A2DAEBA4D8ECA4CBE198CAE49AC6E297C9E89C
C7E79BBBDB8FC5E498D6F5A9DFFBB0C0DC91D1EBA1C8DE95556421485412C7D894DEF3AE
C7E19AB3CE87D3EDA6C7DE98CEDF9BE5F4B1D7E3A1C0CF8C8EA25DD9F0AABFDA93C5E39D
CBE5A4D2ECAFE3FAC6F6FFDFFBFFECFBFFF3FDFEF9FFFEFF
C4DA92DAF0A8D0E89ED2ECA2CEE89EC4E093D0EFA1C2E193D1F0A4CCEB9FCBE79DC7E198
CAE19BD2E7A2C9D998AEBF7B899A53C7DC91EFFFBDC4DE97C2E19BBBDF97D0F6ADC2EAA1
C8EEA5CAEDA9CBE7ACCBE1B2FAFFE5FCFFEFFEFDF8FFFEFFFFFEFFFFFFFFFFFFFDFFFFFB
FFFFFAFFFEFBFFFEFDFFFEFFFFFDFFFFFEFFFFFDFFFEFFFFFCFFF6E8EFDFE6F0D7FCFFED
FFFFF4FFFFFAFFFFFBFCFFF6F9FFEACEE1B3CAE39FCEEA9DCEEAA0CDE7AAE4F5D1F8FFF1
F9FFFAFCFFFAFFFFF4FFFFF4FDFAF5FFFFFD1210111B1D1A272924B5BDB0E4F0DADFEFCB
D2E6B5D3E8ADC9E09C7B93498FA55CCBE198D9EFA7D3E9A1CCE299CEE89ECEF0A4BFE497
CAE8A0DFF0ACCECE92665D249B955BDEDFA3D3E7A2CAEAA1C2E89BC7EDA0C4E397CDE7A0
C6E09FCDEAA7C5EA9DCBE898DAE49BA59F616B5A2CFFFDDDFFFFEFF9FFFAF9FFFDFAFCFB
FFFEF8FFFFEFE3EFCBCADCACDCEBB2C9D99A93A666A1B675C8DF9BDFF8B4CEE9A2C3E398
C9E99EC8EA9EC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC9E99DD2EAA0CFE59CB7CF85809A50
C7E398C0DF93BBDB8FD3F5A8C9EB9ECAEC9FCAEC9FC8EA9DC6E69AC5E599CDEDA1D8F8AC
C5EA9ABCE191D0F2A5D8F8ACD0ECA1C6DE94C5D992E0F1ABD6E5A2CFDB99DEEAAACFDB9B
CCD898C8D7969AA86A879655BDCC87CEDE97D1E29BC4DA91D2EAA0CBE59BCCE89DD5F4A8
D0F0A4D4F4A8BDDC90D9F8ACAECA7FD7F3A8D7F1A7D3E9A0D0DF9CD6E5A29BAF6A1D3400
8FAA63CEE9A2D4EEA7D9F0AAD2E39FC8D794D5E19F8B9755CADB97D1E6A1D5EFA8CEE9A4
C8E5A3D2EBB1E3F9C8F3FFDDF9FFECFAFFF3FCFEFBFFFFFF
C7DC99D9F0ACBED58FC9E39AD1EDA0CDEA9ADCFCA9B9D986C3E390C9E694D8F3A4D3EE9F
C7DD92D2E89FE0F1ADD2E39F7C8D49485B19C5DA97D0E9A5D1F0AAD0F4AAC5EBA0BFE89A
C8EEA1C5E9A1C9E6A6CCE3AFF9FFE4FEFFF1FFFFFAFDFBFCFFFFFFFFFFFFFFFFFBFFFFFB
FFFFFAFFFEFBFFFEFFFFFDFFFFFCFFFFFCFFFEFDFFFEFFFFFDFFFEF4F9F2F6FFEEFCFFF1
FFFFF4FAFCF1F2F5EEFBFFF4F8FFEAD2E5B8CAE4A3CCE89ECCE7A2CBE4ABE0F4D1F7FFF4
F9FFFBF8FEFAFCFFF6FBFDF2FFFFFBFCFBF9CDCCC83E413A000200666F5CBFCCAEE0F1C7
CBE0A8D2E8A7D5ECA45F772BE6FCB3D4EAA2CFE49FC6DD97CFE69ECBEA9EC9EEA1C1E699
C7E59DD9E8A5BDB87E655821A0955DDFDDA2D1E29EC9E79FC3E99CCBF1A4C7E79BCEEAA0
C9E49FCEECA4C5EA9ACAE797D8E299A19B5F554418F0E2C5DDDFD1F3FCF7FBFFFFF8F8FF
FFF8FDFFFEF8F7FFEBF0FFDCE6F3C5D5E2AC91A067BCCE90CFE4A3D3EDA6D2EEA4C4E498
C9EA9BC8EB9BC6EB9BC6EB9DC6EB9DC6EB9EC8EAA0C9E99EC4DB93D3E79FE4FAB17D954B
EAFFBADDF9AEB9D88CCCECA0CBEB9FC9EB9ECBEB9FC9E99DC9E99DD0EFA3C7E69AB2D286
C3E898CBF0A0C1E396B6D68ACDECA0DDF7ADD0E79FCCE099D6E7A3CFE09CD9E9A8CFDF9E
CDE09ED3E6A4BDD090B7CA887E8F498A9B548FA35B95AB62D2EAA0D0EAA0C3DF94BBDA8E
CAE99DC6E69AC5E498C7E69ADBF7ACC8E499C3DD93CFE79DD5E6A2DEEFABCDE29DC0DA93
D0EEA67F9D557E9952819852DCEDA9D6E2A0D1DC9A9DA866DDECA9D9EDA8C3DA94D1ECA7
C7E4A4CBE7ADD6EEBCE3F8CFF1FFE5F9FFF2FCFEFBFCFDFF
D7EDADD3ECAA96AF6B88A25987A3568DAA58AFD0799BBC63AAC8708FAD5587A34E88A352
8DA456ABC178D0E19DD7E7A8B1C0856C7E44D4E8ADCCE4A6C5E29FC6E89EC3E89AC7EE9D
CDF3A0C6E89BCCE9A6D2E9B3F9FFE3FCFFEFFFFFFBFDFDFDFFFFFFFEFFFDFFFFFBFFFFFA
FFFFFBFFFFFDFFFDFFFFFDFFFFFCFFFDF9FFFEFCFFFEFEFFFDFEFFFCFFFDFBFFF8FBFFF4
FEFFF1F0F4E3E1E9DCF9FFF3F7FFECE0F5CAD6F0B1CDEBA5CCE9A6CEE7B0E3F6D6F7FFF6
F9FFFFF9FFFFFDFFFAFBFCF6F2F1EDFFFFFBDDDCD77A7D720C10016E785FDBEAC3C9DBA7
CFE5A5C7DE96D0E89A839B4DC9DF96CCE19CCFE4A3CEE4A3D2EEA4C6E69AC3E99CC6EC9F
CBE69FD4E09EA8A268695822AC9B65E5DFA5D0DF9CC6E49CC3E99CCBF4A6C7E99CCBEA9E
CAE69CCBEA9EC4EA97CDEA98E0EAA1A19B5F5D4C21E8DABFCFD1C4F1FBFAF9FFFFFBFDFF
FCF4FFFFFCFFF9FFFAF8FFEFE7F1CED8E1B4C8D6A375874DD7EBACCEE8A1BCD88DD5F6A5
C9EB97C8EB97C8EB99C8EB9BC8EA9EC8EAA0C9E8A2CAE8A2D7EEA6D2E69ECCE29993AB61
B8D288BDD98ED1F0A4CBEA9ED1F0A4BEDE92C7E69AD7F6AACCEB9FC5E196D3EFA4DEFDB1
D5F7AAC2E799D0F2A5D9F9ADC1DF95C5E197D6F0A7C4DB93CFE49FCEE39ED5ECA6D1E8A2
D2E9A5D7EEAACBE4A0CBE29CE2F6AFB6CA8272863E465C1381994FA1BB71BFDB90D1F0A4
BCDB8FCDECA0E3FFB4BDD98EC8E298D0EAA0D2ECA2CEE69CCFE39EC6DA95CFE6A0E2FDB6
C2E098C1DF97BCD7905168228D9E5ACFDB99F0FBB98F9A58BCC886CBDC98CCE19CCDE6A2
CAE7A7C6E2A8C9E1AFD4E9C0E8F7DAF7FFF1FCFFFBFAFEFD
849C5EA7C180B6CF8BCFEBA1D6F3A3CDEA96D3F49BBFE085D3F197C5E38BC9E591D3EB9D
C9DF97B5C886A9BB7FA4B37C48562394A473D6E8B4C8E0A6D1EEACC4E49BCBF0A0BAE08B
CAF099C2E593CCEAA2D0E8AEF0FFD8F5FEE9FEFFFAFBFDFCFEFFFFFEFFFDFFFFFBFFFFFA
FFFFFBFFFFFDFFFDFFFFFCFFFFFCFFFCF8FFFFFDFFFEFEFFFAFEFFFBFFFBF9FFF6EDF6E3
F1FADFE1EACFD3DFC9F8FFF1F7FFEAEDFFD9E0FABDCCE9A6CBE8A5CDE6AFE2F5D5F7FFF6
F8FFFFFBFFFFFCFFFBFFFFFAFFFFFBF5F4EFFAFAF2FEFFF4676C56667151E1F1C4C6DA9F
D2E9A1CEE698D1EA97869F4EC9DF96D1E6A1D1E5A6D6ECACD0EEA6C0E597BFE89ACBF1A4
CEE9A2D4E09E9F945C705B26B09B66EADFA7D6E19FC9E49DC2E89BC8F1A3C3E598C8E79B
CCE89DCAE99BC7EA96CEEB99E0EAA3908A506E5D32E5D7BCDADCCEF5FFFCF9FFFFFCFEFF
FFFAFFFFFCFFF3FCF7EFFDECEDF3D9D2D8B4C6D1A6A7B582E6FABDC6DF9BC4E095CFF19D
C9EB95C8EC95C8EB97C8EB9BC9E99EC9E8A2C9E8A5CCE7A4D1E79FDAEEA67F954CBED48B
D3EBA1CBE59BD9F5AAC5E498CFEEA2C5E498CCEB9FD0ECA1C3DF94CBE59BD4EEA4C5DF95
B6D589CCECA0C6E69AC2E195C3E197C8E49AD4EEA5CFE9A0D2E9A3CEE59FC8E29BC4DE97
C5DE9ACBE4A0CFEAA5D4EEA7CFE59DD4EAA1D0E69DCAE298DCF6ACC5DF959DB96E84A055
6D893ED9F5AAB2CE83CFEBA0D7F1A7C6E096D3EDA3CFE79DD7ECA7CEE39ECDE7A0C4E29A
BEDE95DCFCB3C3DE97CFE6A0DAEBA78793518B94536C7534EAF5B3D4E3A0D3E7A2CFE6A2
CDEAA8C7E5A7C4DFA8CCE3B5E2F3D1F5FFECFBFFF6FBFFFB
C5DFA0CBE8A6D0EBA6D0ECA1C9E696C6E48ECEEC94D2F096CBE792D0EC98D5EDA3D8EFAB
D7EBB0D1E2AEDDEDC0F6FFDAE8F4CCE5F4C9C3D4A7C7DBA6DAF4B5BBDB92C7EA98D6FAA2
C8EC92C1E38CCEEDA1CAE2A4D9EAC0DFE9D1F9FEF7FDFFFEFEFFFFFEFFFDFFFFFBFFFFFB
FFFFFBFFFFFDFFFEFFFFFDFFFFFDFFFCF8FFFFFDFFFEFFFFF8FDF7FBFFF4F8FFEEDAE7C9
DCE8C0D2E1B8CDDABCF8FFECF4FFE5F3FFDDE3FCC2C9E4A1CAE5A2CAE3AADFF3D0F7FFF3
F8FFFBFAFFFEFCFFFAFEFFFAFFFFFBFFFFFAFFFFF67377660005007D8963C0D19DDCF1B0
BFD78BD5EE9BD8F19D8CA552CAE095DCF1AEC8DC9FBED698CAEAA1C2E99AC1EC9DC8F1A3
CBE69FDAE5A39A8D566C5521A38C58E5D8A1DAE3A2CEE8A1C2E79AC4ED9FBFE496C9E99D
D3EFA2CDEC9ECBEE9AC9E694CED891676127716035D6C9A9DBE0CCEAF7EDF3FDFCF5FAFE
FFFDFFFFFEFFF8FFFAF7FFF4EDF2DEF0F3D8C6CDABD3DEB3BECF98C6DC9BE4FFB5BCDE8A
C9EB94C8EC94C9EB97C9EA9BCAE89ECAE7A4CAE7A7CDE6A5CEE39EC4D890596F2695AB62
C2DA90C6E096C6E297D3EFA4D2EEA3C7E398C6E297C6E096D0EAA0E6FEB4B7CD84536920
082200BDD78EE9FFBAC2DC93CDE79ED0EAA1CCE39BCEE59DCBE29CCFE6A0CEE8A1D5EFA8
D4EFA8CDE8A1CAE59EC5DF98CEE59DD3EBA1CDE59BCDE59BC7E197CFE99FC9E399C9E399
A1BB71092300D6F0A6D4EEA4C0DA90DCF6ACC5DF95D1E99FD1E6A1C1D892D5F0A9D2F0A8
C4E49BCEEEA5C1DC95D2E9A3D4E5A1E2EEACD2DB9A919A59808B49D6E2A0DBECA8D1E8A2
CAE8A2CAE9A6C9E5A8CDE5B1DAEFC4EEFFDFF9FFEFF9FFF3
D0EDABC5E39DC9E79DC9E89ACDEA98CEEB97C6E48ECDE995CAE596D7EEA6CDE3A3C7DAA3
D1E0B5D5E3C0E1EED2F9FFECE7F2D4C8D6B2D3E2B9D3E7B6C5DEA4CCEAA4C5E695C6EA90
CAEF92C7EA90D5F4A4CAE3A2CDDEB1D0DDC1F6FEF1FCFFFDFCFFFFFEFFFFFFFFFDFFFFFB
FFFFFBFFFFFDFFFEFFFFFEFFFFFDFFFBFAFFFEFFFFFCFFFBF5FEEDF9FFECF3FFDECEDEB1
CEDFA8CDE0A9CFDFB8F7FFE6F2FFE3F5FFDFE7FFC6C8E3A0CDE8A5CDE5ABE1F3CDF7FFEE
F9FFF8F8FFF8FCFFF8FDFFF7FFFFFABEBDB87A7A70555948474D314C5830DCEDB6C1D691
D2EA9CDBF4A0C2DC8591AA574A6015C2D794D5E9AED2EAAEC4E69CC5EE9FC5F1A2C3EC9E
C5E099DCE7A5958851654B18937946DFD099DDE3A3D4EBA5C2E79AC4EA9DC3E598D0EFA3
C5E196C6E295CDF09ED2EEA1DDE7A2756F35AB9A6EFFFFDCFAFFE4F7FFEFF8FFF6F8FFF5
FEFEF6FDFFF4F4FFF0F7FFF1FDFFEFF8F7E3FFFFE8E7F2CAEDFECAD3E9A9BCD88ED5F4A4
C9EB95C8EC94C9EB97C9EA9BCAE8A0CCE7A4CCE6A9CFE5A7CBDF9A9FB36BC8DE95CBE399
D3EBA1D6F0A6CEEA9FC6E297CAE69BC5E196D5EFA5D2ECA2C2DA90D2E89FDBEFA7BDD189
C8DC9591A75F425810667C34BDD38BD2E8A0D0E69ECBE199D4E9A4D2E9A3CAE19BCEE59F
CDE7A0CAE49DD0EAA3CFE9A0CCE69CD2EAA0CDE59BD7EFA5C1DB91D2ECA2CEE89ECDE79D
C7E197D7F1A78EA85E48621892AC62CBE59BC4DE94D7F1A7CBE09BDFF6B0C7E29BBCDC93
D3F3AABEDE95D0EEA6D0E7A1D5E6A2C4CF8DE0E9A8B1BA79889150939F5DB4C581CEE39E
C8E49ACCEAA2CEEBA8CFE9ACD5ECB8E6F8CEF3FFE1F7FFE9
C5E59CCEEEA3CCED9EC8E998CCEB9BCCE999CAE797D1EBA1CFE6A2CBDFA4C5D7A7D3E1BD
F0FCE4F9FFF4F7FFF9F8FFF9FBFFEFF9FFE8E1EFCCCCDFB2CFE6B0C8E5A2C1E293CCEE97
C6E98BC7EA8ECDED9ACCE5A1D0E4B1CEDDBCF9FFF3F1F8F1FCFFFFFBFFFFFEFFFDF5F7F4
FFFFFBFFFFFBF0EFEDFFFEFFFFFFFFFFFFFDF9FCF3FCFFF1F0FBDBD2E1B6D3E4B0D1E5A6
D4EAA2C6DD99CEE2B1CDDFB7CADEB9F5FFDFE2FAC0C4DD9BC4DD99DEF3B8C1D2A8DBE8CE
E6F1E1FAFFF7FCFFF6FEFFF60100002B2A25E0E0D6CDD1C081876B717D55BECF98D8EDA8
D6EEA0C1DA86D6F099DAF3A043590ECDE29FD5E9AECBE3A7C7E79EC5EC9DCBF7A8BBE496
C9E49DE9F4B2968952705925705623A79861DAE0A0D2E9A3C7E99DC7EC9FCAEA9EC9E59A
D0EAA0CCE89DC9EB9ECEEA9FDEE7A4534D13998B5AFFFFD6FBFFDAF7FFE3F5FFE6F5FFE6
FFFFEAFEFFE8F2FFE1F7FFE8F9FCEBFFFFF3FFFFEDE2E9C8D8E5B7DAEEB3CAE59ECBEA9C
C7E995CBED97C7E995C8E799D9F4ADBAD391D5EBAD677B3C263A0082964ED1E79EDAF2A8
C8E096C8E298CFEBA0CCE89DCBE79CD1EDA2D0EAA0C9E197D6ECA3D8EEA5D0E49CCFE099
D5E49FCDDC99D6E5A2D6E5A294A5614E5F1B4F631ECFE39ECEE29BD7EDA5879D55475D15
869C54CFE59DD4EAA2CCE39BC9E399D2ECA2D2ECA2C5DF95D1EBA1C4DE94D6EEA4C6DE94
C6DE94C8E096D4ECA2D5EDA3BDD78D587228CAE49ACAE49AD3E8A3C9E09ACDE8A1C5E59C
D6F6ADC7E79ECDEBA3CFE6A0D0E19DDEE9A7D2DB9A8F985799A261E2EEACA9BA76DBF1A9
CDE89BD3EFA2CCE89ECEE9A4C9E1A5CFE6B0F0FFD5F7FFDF
C6E999CCEF9DC8EB99C7E897CEED9FCEEA9FC9E39ACEE4A3D0E3ABDAECBCD5E3C0CFDBC3
E0EADFF2FBF8F9FFFFF9FFFFFAFFF3F9FFECE7F4D6D3E5BDD1E8B4CAE4A5C4E397CFF19B
CBEE92CAEB90CCEC97C8E49ACBE2AACDDFB7F8FFEDF1FCEEEDF3EFF2F6F7FEFFFDFEFFFB
FDFEF9FFFFFBFFFFFBFFFFFDFFFFFDFEFFFAFEFFF3FBFFEAFBFFDFD2E3ADCFE4A3CAE097
D0E998CBE399CFE4ACD6E8BECDDEBAF2FFDCEDFFCAE1F7B7E1F6B3CFE3A8D1E0B5D0DABF
E2EBDAFCFFF6BAC0B27D81735F5E59D3D2CDC4C4BAD2D6C5BEC4AA333F19B6C793C5DA99
CDE599CEE794D3EC98C6DF8C50661BCADF9CD4E8ABCEE6A8D0EEA6BFE496C5F0A1C5EEA0
CBE69FD0DB99968B53B39E69A38C58655821A2A868CBE09BC4E499D3F5A9CEEA9FCCE69C
CFE9A0CAE69CC7E99DCAE59ED6DC9C5A541A685B27DAD2A1FAFFD2EEFFCFDCEFC1D1E0B5
D9E0B6D6DFB4C9DFAECFE4BBFFFFF1FDF6EEC4C3B1EEF2D7E4F1C6D6E9B2C8E2A1CAE89E
C9EA9BCAEB9AC4E594CCEB9FD2ECA5D1E7A694A869AABF7ECBE09BD4EAA1D6EEA4CDE79D
CDE79DD0ECA1CCE89DC1DD92CEEA9FCAE69BCDE79DD2EAA0CDE39AB9CF86A1B56DCDDE98
DDECA9D4E09ED6E2A0CEDD9ACCDB98D1E29EABBC789AAE6962762F94A861B9CD86CDE19A
C1D58E798D46475B14596F27A9C379CBE79CC9E59AD1EBA1D4EEA4CEE89ED1E99FD5EDA3
DAF2A8D4ECA2D4ECA2C7DF95DEF6ACBCD68C6D873D6F873DD2E7A2D0E7A1C8E39CC2E098
D0F0A7C1E198C1DC95D3EAA4D8E9A5C1CD8BE9F2B19AA3628E9957CFDB99ACBD7980964E
D3EB9DBDD887BFDA8DD5EFA6CAE39FCCE4A6E6FEC4D9F0B8
C5EB94C8EE97C5E894C5E695CEEDA1CFEAA3C9E2A1CFE4ABC8D9ACEEFCD9FBFFEDFAFFF5
F9FFFDF9FFFFF9FFFFF1F9FCF2FAEDF9FFEDF8FFE9EDFFD9E3F9CAD2EBB1C5E39DCAE999
CBEC95CAEB92CAEA95C8E499CDE5A9D6E9BBF7FFE6F8FFEFFBFFFAF7FCF8FEFFFBFEFFFA
F2F3EDF9FAF4FEFFFAFEFFFAFFFFFBF5F8EFF8FCEBF9FFE6FBFFDCCEE0A6D7ECA7D5EE9D
CBE58ED2EA9CD7ECB4F7FFE1F2FFE3F8FFE4F3FFD5E8FCC1E1F3B5BCCB94DBE7BFE3ECD1
D4DBCB7A7D723C40329C9E93F3F2EDF1F0EBFFFFF8FEFFF4F3F8E2677252607043CCE0A5
CFE69ED6EEA0CFE895C9E2917E944BB0C580D1E5A6D4EAAACFEAA3BFE194C0E99BC8EEA1
D0EEA6CCDB98A29C62E7D6A0F3DFAA9E935B535C1BA5BA75C8E69CC5E399CEE49BDDF1A9
CDE49CC7E29BCAECA2D2EDA8E3E9AB928C52665924E6DFA9F1FFC4E3FBBDD1E9ADC9DDA2
D5E0A8D4E1A9C9E3A6D0E6B7FFFFF1E0D7D27D796DF3F7E0EFFBD7D6E8B8CBE4AACCE9A6
CAEA9FC7E79BC9E89CD3EFA4C7DE98D9EEAB879A5AD8EBA9DCF3ABCAE49AC0DA90C5E196
CBE79CC9E89CCAE99DCFEEA2C9E89CC7E398CDE79DD8F0A6D3E9A0C8DE9595A961DDEEA8
D6E5A2D0DC9CE6F5B4DFEEADD1E29ED5E9A4D4E8A3C8DD98DBF1A9D3E9A1C9DF97CEE49C
D7EBA3C8DC94C5D68FD5EBA2D0ECA1D1F0A4CBEA9EBEDA8F6C863C859F55C4DC92D1E79E
CAE097D5EBA2CBE198C9E197CCE49AE4FCB2CBE59BC9E19791A661677C37859F58CAE8A0
C8E89FCEEEA5D7F2ABCBE29CD1E29EDDE9A7E0E9A89EA766CED997D0DF9CD5E9A48EA45C
A0B769E1F8A8DCF4A6C8E094CDE79EC9E39CCCE5A3D6F1AE
C4EC93C7EF97C3E994C4E797CBEBA2CCE6A5CEE6ACDCEEBEDDECC5F7FFE8FBFFF1F3FBF0
F3FCF7F9FFFFF9FFFFF8FFFFF7FFF0FBFFEDF9FFEAF8FFE4E7F9CFD1E8B2C8E2A1CAE99D
CBEB98CAEB94C9E996C6E599CBE5A4D3EAB4E9FED3F1FFE1F4FCEDF1F6EFF9FCF3FDFFF7
FFFFF8FFFFF8FFFFFBFAFBF6FFFFFBFEFFF8FCFFF3FBFFEAF9FFDDCBDEA7D3EAA6D0E89A
D0EA93D1E99BC4D8A3F7FFE3F8FFEDF9FFECF9FFE1FBFFD8E0EDB7F0FCCAC4CCA7A2A790
797B6E0D0E065C5D55EBEBE3FFFEFBFFFFFBF5F4EFF9FCF1FEFFF3ADB79E798861D1E3AF
D5EBABCDE49CC8E092DCF4A6B6CC837D924DD2E7A6D2E7A6CAE199CAE99DC4E99CBBE194
D1EFA7DAEBA7A19F64D5C891EBDEA7A49E64A8B371708540C7E399E3FDB4C4D48DCEDE97
D6ECA4CEEAA0CCECA3CCE7A2D6DC9EA59F65564914E5DEA7D4E2A4D0E9A7CAE3A1CCE1A0
DBE7A9D8E8AACBE8A8D2EAB8F5F3E4D0C7C280796FF9FBE6F9FFE3DFF0C6D2E9B5CDE9AC
C9E8A4C6E69DCFEDA3D3EFA5C1D890D3E7A0BACB87CEE29BC5DD93C3DF94CCE89DD5F4A8
D1F0A4C5E599C7E69AD1F0A4CFEEA2CFEEA2CCE89DCBE59BCCE49AD8EEA5889C54C6DA93
E2F3AFC8D897CFDF9ED4E7A5CFE49FC1D892CEE59FDDF7B0C4DE95CEE89FD4EBA3CDE49C
CFE59CDEF4ABDFF3ABCBE198CDECA0C8E89CBFDE92D8F7ABB2CE83859F559AB067D5EBA2
D3E9A0D4EAA1CAE097D9EFA6D5EDA3BCD48ACFE99FD5EDA3D1E5A08A9E59576E2890AB64
BEDC94CFEDA5BCD790CCE39DD0E19DD7E3A1CED997879250E0ECAAD3E4A0D4E9A4CFE59D
9AAF64D7EC9FCDE297C3D98EDCF4AAD2ECA2C3DF95CBE79D
C0EB91C6F198C6EC99C4E699C6E5A1C8E2A5D5E9B6EDFED2F4FFDFFBFFECF7FFEBF4FCED
FBFFF6FBFFFAF7FFF9F9FFF8FBFFF1FBFFEDF8FFE9EEFDDCD9EBC3CAE0AFCBE5A8D2EDA8
CDEC9ECDED9ACAEA97C7E698C6E19CCAE4A7C9E1ADD7E9C1CDD9C1FBFFF4FCFFF3EDF3E5
FDFFF3FEFFF8FFFFFBF7F7F5F7F9F8F4F6F3F6FCF2FBFFF1F9FFE6D0E1B4CEE3AAC5DC98
D0E998D8F0A6CBDCAFF8FFECF9FFF6F4FCEFF6FEE6F9FFDEF5FED3CFD7AEE7ECCE444734
52524AF0EFEBFDFCF8FFFEFBFBF7F6EDECEAFFFFFBF0F3ECFDFFF5D2DBC80E1B00F8FFDF
D3E8B0C5DB9AC6DD95DEF6AACFE59C5F752DDAEFAACBE09BCEE29BD6EEA4CCEEA2B8DD90
C9E9A0D2E7A2929357B6B076E9E0A7E9E7ACC2CE8C94A964536A22BBCF88D2DC97DEE8A3
D2E79CCDE99ECCECA1C7E29BCED4969D965F534611E3DEA6CEDE9DCFEAA5CEE9A4CFE5A4
D7E5A8D1E0A5C2DEA3C9E0B2EEECDDD8CDC9C9C0B7FFFFF1FCFFEAEFFFDBDEF4C6D0EBB6
CAE8ACC8E7A4CCEAA4CEE8A1C9DF96D8ECA4C5D58CCADC92D3EDA3CEEDA1CCEB9FCCECA0
CEEEA2CDEFA2CAEA9EC4E498CAEA9ECCEB9FCBE79CCDE79DD0E89EDCF2A98FA35BD2E69F
CFE4A1D5EBAAC9E29EC8E39ED3F1ABD5F4AECBEBA2BEDE95CCECA1C5E59ACDECA0D2EEA3
C6E096C3DD93CDE599CAE598CFEEA2BFE194CCECA0C4E397BEDA8FD4EEA4C1D78E334900
788C44D0E49CE6FAB2B9CF86CEE69CE3FBB1BFD98FD8F0A6CFE09CCFE09CDBF0ABC3DD96
718F47A0BE76D8F3ACCDE49EE4F5B1C1CD8BE5F0AE899452B7C683D4E8A3B8CF89D9F0AA
BCCD8791A05BA9BA74E6FAB3D1E99FB7D187D1EDA2CEEDA1
BFEB92C6F09AC7EE9DC6E89EC5E3A3C5DEA5D7EABCF5FFDEFBFFE6FBFFEAFBFFEDFBFFEF
FBFFEFFBFFEFF3FFE9F9FFEFF8FFEAF0FAE1F5FFE8F8FFE8E9F9D5DAEDC0D4EBB3CEE8A7
CAE69CCBEA9ACAEA97CBEA9ACBE79DD1ECA9C0D99FD3E9BAC6D3B5EEF7E2FAFFEDFCFFEF
FEFFF3EFF2E7F6F7F2FFFFFFFEFFFFFCFFFFF6FAFBF9FFFAF0FCE6DDECCBD8EBBED0E5AC
C6DE94D7EEAAD4E4BDF6FFF0FBFFFFFCFFFFFEFFF4FFFFEADFE5C3E3E7C66668521E1C10
A4A09FFFFCFFFCF7FBFFFEFFFFFEFDF6F5F3FFFDFEFEFFFDFEFFFBF3FBEE5F6B55F8FFE4
CEE2B1CFE4A9D1E8A4D0E89ED0E69D7A9047D0E69ED0E49DD3E39CD1E59DCFEFA4C5EA9D
CBEBA2CBE29C969C5EC7C58AD3CE94F2F3B7DEEDAAC3D893CCE29A3B4C06D9DE9BDAE09A
CEE094CBE898CFEFA3CDE99FD8DEA08B864E665924E6E1A9D9E9A8D7F2ADD1ECA9D0E6A6
D9E6AED3E4AEC7E4AED1E7C0DEDBCCD9CBC8FFF6EFFFFFF3FEFFEDF9FFE8F0FFDEDCF6C7
CCE7B2CCEAAEC6E09FCAE49DD2E89FD5E79BA0B163DDEFA3C6E194C6E69AC4E498BEE093
C2E497CDEFA2CDEFA2C5E79AC8E89CC2E296C7E69AD6F2A7CEE89EBFD78D90A65DDFF5AD
BED994D8F5B2CDECA6CFF0A9B4D890C2E89FC8EEA3BFE89CCEF7A9BCE295BBE092C9EB9E
D1F1A5D5F4A8D4F0A3CAE699B9D98DC9EB9ED4F4A8CDECA0DCF8ADC3DB91D7EDA4DAF0A7
8CA058D4E8A0CDE199D8EEA5C3D990DCF4AAC7E197D6ECA3DEEDAACEDD9AC4D893D8EFA9
C0DB94829D56546E27617832C1D28EE6F5B2DDE9A797A361C6D793CEE39EC8E29BD0E7A3
D0DEA096A264919F61CBDB9AD0E5A0C5DF96D7F3A8CBEA9C
C0EC95C6F09CC6ED9EC6EAA2C8E6A8C5DDA9D4E6BCF0FFDBFAFFE5FBFFE8F0F9DCD8E1C4
D1DCBCD9E5C1E7F5D1F9FFE3E6F1D3DCE6CDEBF8DEF8FFEAF6FFE4E9FBD3DEF5C1CEE8AB
C8E39CCCE89BC9E898CDEC9CCBEA9ED5F3ABBCD695D6EDB7DFEDC9E3EDD2F1FADFFCFFEC
F4F8E7EFF2E7FFFFFDFCFBFFF6F6FFFCFEFFF6F9FFF9FFFFF0FAF1F4FFEDE4F4D7D9ECBF
D0E5A4D3E7AAC8D5B7D1DBD2E3E8EEFCFFFFEAECE7F8FBEA898B735F5F47828071F2EDE9
FFFDFFFFF7FFFFFBFFFDF6FDFAF6F7FFFEFFF3F1F4FEFFFFFEFFFFFBFFFB7E8979000800
CCDEB4D5EAB2D5EBABC9E098D1E79EB2C87D91A75ED5E9A1D7E49EC9DA93CFEDA3CFF1A5
CBEDA3CCE69F9DA768CACB8FE0E0A4CED496D6E7A3BFD48FF0FFBE7A87429C9D5BE1E29E
D7E898D1EE9ACEEF9ECAE69CD8DEA0615C246C5F2BD1CC95D1E1A2CBE5A4C2DF9FC8E0A4
DFEDBAE3F3C6D9F4C7DFF4D3DBD7CBDACBC8FFFDF6FFFFF3FBFFECF9FFECF5FFE6E5FED4
C9E3B3CCE9AFC8E2A3CBE59ECFE59C9AAD5EACBA6BE0F3A2C8E497CEF0A3D4F6A9CDEFA2
C6E89BC3E89AC5EA9CC5EA9CD1F3A6C7E79BC8E79BCDE99EBFD98FA1B96F8BA158BED88F
D3F2ACC6EBA5B0D891C0EAA26B974C8EBC71BEED9FC1F0A2B8E797C9F5A6CDF8A8C1EA9B
BDE292C5E898C9EA9BC5E697D6F8ABC4E699BEDE92C6E599C9E59ACFE79DE0F6ADC5D991
D4E59E98A9627B8F47DEF4ABD7EDA4C7DF95CAE49ACDE39AC7D693DDE9A7EBFCB8CFE49F
C7E19AD9F4ADC9E39C839A549EAF6BD1E09DC0CC8A8E9D5ACEE29DC6DD97D2EDA6CDE4A0
E0EBB1D1D8A2919C62909E61CADD9DDFF6B0CDE99FB5D488
C3EC9DC5EEA0C5EB9EC9EAA3CBEAA7C7E0A6D0E4B1E8F9CDE1EFCBF9FFE4F9FFE4DAE9C2
C9D9ACCEE0ACDCF0B5E9FCC4E2F3C6CBDBB4D2E2BBE4F6CEE1F6CDE3F9CBE8FFCBDEF6BC
D1E7A7D3EAA6CDE49ECCE69FC6DF9BCDE8A5A9C384C6DDA7CDDDB6ADB89A747D622A321B
0003005B5C54AAAAA856555A75747CA9A9B3B9B9C3F5F8FDF1F7F5F9FFFAF5FFF0E3F0D4
E5F5C6E9F6CAE5EED9E6EAE9E9ECF5DBDBE76D6E703E3F37939482DAD9C7FCFAEEFFFEFA
FFFCFFFFFCFFF7EFFAFFFCFFFEFAF9FFFFFBFFFFFFFBFBFDFDFEFFF1F6F2A8B0A36A775D
C9DAB0CDDFABCDE3A3C9E09AD5EDA3D3EBA1415B11CEE59DD6EAA2C8DC94D1EBA2CAE89E
C3E398CFE6A097A05FA3A868D7E0A1D9E5A3D3E7A2D1E6A1C9E098CADB957D82403E4100
D6E29AD0E298CBE198CEDF99E5E9AC5E591F948B52EBEBAFD6E6A7CDE7A6C9E3A6D7EEB8
F9FFDAF9FFE3F4FFE8F7FFEEF4EDE5EADADAFFFBF4FFFFF3FAFFEBF6FFE7F7FFE4E2F9CB
C5E0ABCCE8ABD2EDAAD2E9A1C7DC91536318E6F3A4CCDD8FCDE99CC5E79AC3E598C5E79A
C6E89BC6E89BC8EA9DCCEEA1C7E99CC9E99DC9E89CC8E499CFEBA0C9E399C9E098D5EFA6
C3E59BC7EDA4C9EEA9C1E8A5194200547E3CBCE7A2C4F2A9BFEEA0C3F09FC0EB99C3EA97
CBEE9ECAE99BCBE59CD2ECA3BDDD92D7F9ADC8E89DD5F5AACDE99FCAE49AC8E096D5EBA2
D2E89FCBDF97D9EDA5687C3482984FDDF3AAD1E79ED1E59ED7E6A1CEDD98CBDF9AC5DC96
DCF7B0C4E29AC7E29BD2ECA5CDE19C72813EDEEAA891A05DAABB77DCF1ACC8DF99D0E7A3
C9D79CE3EEB4D0DEA3ADBD7F8DA0608BA05BB9D088D8F2A8
C8EBABC5E8A4C7E99FCBEB9FCDEC9ECCE89DCCE5A1D0E5AAD1E5B4F6FFDCF3FFDBD2E8B9
CBE5A8CCEAA2C9E994CCEC97CCE7A0CCE6A5C8E5A5D2EEB1CEECAEC8E4A9D7F0B6F7FFD3
D6E7B1CFDCA7D8E5B0CEDBA6CBDCA8DFF3BE3048145971419CAC87697456303821686F5D
7A7D749D9E99D9D7D86361621816172B292A3A3839E8E8E8E9E9E9FEFFFFFEFFFFFAFCF7
FFFFF1FFFFEFFAFBF3FFFFFFE2E1E772727A5E5F61C4C5C0FFFFF6FDFDF1FFFFF4FFFFF6
FFFDF9FFFDFDFFFCFFFFFCFEFCFCF2FFFFF4F5F6F0FFFFFDFBFBFBFFFFFBE8ECDE283116
9FAC81C8D9A2D2E7A4D0EAA1CBE79DD1EFA582A15BA8C781C0E095DEFDB1C4DA91D1E79E
D0EAA0CFE39C999B5A959A58CDE29DCFE9A2D2E6A1CEE39ECDEBA3C1DF9791A5605A6425
979A63E0DEABE5E4AEDFDEA5E0DC9F6561218F904EDCE39FD6E7A1CDE4A0D1E9ADCBDFAE
F8FFE2FCFFEAF9FFECFFFFF6CABEC0FFF9FCFEF3EFFFFFF3FFFFECEFFDD9E2F6C5D2EBB1
CDE7A6C8E39CD3EBA1D1E79CD2E2995C6820C8D28BDAE79FCCE89BC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BC9E99DC9E99DC6E69BC8E69CCCEAA0CAE69CCBE79DBAD48BACC67FC9E39A
C8E69CCCECA3C4E0A3CDE8B3021D00516C3FC7E7B5C3E7AABDE59CBEE594CCF29BD4F59E
CEE595D7E49EE1E7ABD3DBA0CBE1A0C8E7A3C2E19BCCEBA5CBEBA2BDDD92D6F5A9C8E79B
CBE79ACFEA9DCCE299B2C67E95A66093A25DBCC984E9F6B1DDEAA5C7D891CFE59DDEF8AF
C3E398BBDD91C8E89DCAE89EC3DA94B5C68297A36175813FD8E4A4D3E2A1DEEEADC9DC9A
CDE19CD2E7A2D0E5A0D5EAA5CFE39C6A7E377B8C45D5E69F
C7E6ABC6E6A5C7E6A0CAE99BCDEA98CAE797CAE49BCAE3A1CAE1ABE4FAC9DFF7C7CAE3AC
C8E5A2C9EA99C7EB8BCCF090C9E994C9E89CD6F6ABBBDD93BDDE99D4F2B2EEFFCEF7FFD7
EBF6CBE2E8C2F9FDDAF0F6D21D270243532C8EA57B6379526C7C58AEBB9FF3FBE6FCFFF4
F7F8F2ECECEAFFFEFFFDF9FAEEEAE9FFFEFBC4C1BC6B67641210116C6A6FBFBEC6AFAEB4
7E7A796D69663A39373A383B848388C1C2C6E2E3E5FEFFFDF1F2EAEBEDE0F4F5E7FEFFF1
FFFCF3FFFBF7FFFCFFFFFBFBFEFFF5FEFFF4F8F9F3FFFFFDFEFCFFFFFFFDF7F9EE7B7F68
6C744BDEEDB6C7DC99CBE59BB8D78BD1F1A6B5D68F84A860B3D98CB8D88CD9EDA5D3E39C
CBE198D4E59E8E8E4EABAD6CCBE59CC9E99ECDE29DCCE19CCCEEA4CDF1A7BDD891A5B576
5B5B29938B5DE1D7A6E2D9A2D7D193575613999F57D8E49AD0E49DCCE2A1D6EDB7D1E3B9
F8FFE9FEFFF3FCF9F2FFFCFDB7A8ADFFF9FCFFFAF3FFFFEFFEFFE6E8F7CCD6EBB3CCE6A5
D1EDA3CAE598CDE597CEE396D4E19959631CD2D995DBE8A2CDE89BC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCAE89EC7E59BC9E59BC8E49ACCE7A0B7D28BC1DB94D1EDA3
CAE69BC6E49CE0FABDC5DBAA637851061C00A0B98FBFDDA7BFE49FDCFFB4CDF19ABAD783
D0E296D5DE9BD4D39BE8E8B2DCEEB0D4EFACC3DE9BD6F4AEC5E59CD0F0A5CBEB9FC1E195
C7E899CBE79ACEE89ED0E69DC4D891B1C07BA4B06E9FAC67CDDC97E9FAB3D1E99FB2CE83
CCEEA2D6FBAEBEE094CBE99FDBF2ACD8ECA78692506C7735AFB97AD2DE9EBCCB8AE1F5B0
D8EFA7C9E59AC6E096C3DD93D8EEA5D4E8A0C4D58E788841
C8E6A6C8E7A3C9E7A1C9E79DCEEAA0D0EBA4D0E9A8CEE6AACDE4B0D4EAB9CDE5B1C6DFA5
CAE8A2CAEB9AC7EA8ECDF092CCE997BAD68BD1F1A6C7E6A0CCEAAACBE7ADDEF4C5E8F8D1
FBFFE5FFFFEAF4F6E1FFFFED121A035F6D53C8DBBFCFE2C4C5D4B5E2EFD3FCFFEFFBFFF3
FFFFFAFFFFFDF9F5F6FFFEFFFFFEFDFFFEFBFBF8F3CDC9C659585606040728272F3F3E44
0300004B4746A6A4A5E3E1E4FFFFFFFEFFFFFEFFFDFCFFFAE6EADCDCE0CFE9ECDBFFFFF2
FFFFF6FFFCF9FFFDFFFFFDFFFFFFFBFFFFFBFDFBFEFFFDFFFDFAFFFDFBFFFFFFFBD7DAC9
272E0CCCD8A6DCEFAFD6EEA4D9F5A8C3E294CDEFA3D1F6A982A75A9CBA70D7E8A2D2DF9A
CBE199E7F6B1989757888A49D0EAA1CAEA9FCDE29DCADF9AC4E89ECAF0A5D1EFA7D5E8A6
9DA0695956239B965FE1DCA2D0CF8E5A5D18909751EBF8B2CEE3A0CCE4AAE2F8CADDEECE
F9FFF3FEFFFBFDF8FFFFFBFF9A9091FFFAF3FFFDEFFFFFEAF7FFDEDFF1C1C7DFA3C6E19C
D0ECA2CAE699CBE395D3E89BD8E89F55601BDAE19ED8E59FCDE89BC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCAE89EC9E79DCDE99FD2EEA4D1ECA5AFCA83D0EAA3CAE69C
CFEBA0C9E79FC0DA9BCFE8B19BB2843F592C506C3C8FB0798BB271B0D891BEE497D0F0A4
EBFFB9CCDB969FA5679CA266D0DEA0C1D492DDF2AFC6DD97CEE89FC0DC91CDECA0C6E798
CCED9EC6E597C9E59AD4F0A5DAF4ABCCE39BAFC47F99AD66B1C27CB2C37CDCF4AAD4F0A5
C0E296C5EA9DC8EA9ECDEBA1CFE6A0D4E5A1D5E19F949F5DD9E3A4DFEBABD3E2A1CFE39E
C9E59BCAE99DD7F6AACEEDA1C6E096D1E99FDDF3AA9CB269
CAEAA1CBEBA2CBE9A3CBE6A3D2ECABDEF6BAE2F9C3DFF6C2DFF3C2D0E7B3C6DDA5CAE4A5
D2EDA6CBEA9AC8E992CDEE95DAF5A6CFE99FC4E29AC7E6A2CFEDB1C6E1AEE0F5CEF9FFEA
FAFEEDF6F6ECF4F1EC6B6A65F2F5ECF9FFF6DFEEDBE5F7DFDDEBD1E4F1D7FAFFEFE6ECE0
FBFCF7FFFFFFF0EBEFFFFEFFFFFEFDFFFEFBFFFFFAFAF6F3FDFCFAFFFEFFFFFEFFE7E6EE
FFFEFFF7F5F8F0EEF1F9F9FBFBFCFEF5FAF6F9FEF7FCFFF4E3EBD6D8DDC6E6EBD5FFFFEF
FFFFF4FFFDFAFFFDFFFFFDFFFFFEFFFCFCFEFFFDFFFFFDFFFBF7FFFDFAFFFEFCFDFFFFF4
5E6247626E40CDDFA3D5EBA3CFEA9DBEDB8BCBEC9DBBDD90CDEFA3A6C278909F5AD9E6A1
D1E59ECAD994A3A262ACAE6DCFE9A0C8E89DCFE49FCEE59FC2E69CBFE59AC8E69ED4E9A6
C9D1959A9B618D8F508F91507578339EA45EAFBB73C3D48ECFE5A5D0E9B2EEFFDDEAFCE4
F9FFFBFFFEFFFFF8FFFFFAFF9C9491FFFFEFFFFFEAFEFFE3F9FFDCE9FEC6D1EBAAD4F2AA
C8E79BCCE999D0E89ADCF1A4D6E69F535E19DCE3A0D3E09BCCE89DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCFEDA3CEECA2CAE69CCAE69CBDD89197B26BCFE9A2C3DE97
C0DE94D7F5ADBEDB98D6F0B387A069BDD8A5597743BCDFA9A4CC907BA364739C588AAE68
8DAB658BA05B919E598E9957C1CC8ACAD694DAE9A6E7FBB4C3D990DDF8ABBEDA8DCAE99B
CAEB9CC5E697C3E397C6E69ACCEAA0CDEBA1C9E79FC9E39C798D468FA059D6EEA4CDE99E
C2E498CFF1A5CDEDA2C5E197CCE19CCCDD99DCE8A6A6B16F7D8748D2DE9EDDECABCEE39E
CAE89ECEF0A3C3E598C7E79BCBEA9EBCDB8FCCE89DD7F1A7
CBEB98CEED9FCCE7A2C8E2A3D5ECB8EDFFD3F7FFDFF4FFDCF3FFD8D6EAB7C9DEA3D1EAA8
D3EFA5C9E898C6E693CCE997C3DB91E2F9B3CAE5A2C5E2A2C9E4ADD2E9BDDDEDD0F8FFF2
FCFEF9FFFEFF0300076C676EFCFBFFFBFFFDF2FEF4F7FFF4C6D4BBE0EDD3FCFFF1FCFFF6
FFFFFBFFFFFFFFFDFFFFFEFFFBF7F6FDF9F6FFFEF9FFFEFBFDFCFAEFEDF0FFFEFFFFFEFF
F4F1F8FFFCFFFFFDFFFFFEFFF8FAF9FBFFF9FCFFF4F7FFE9E4EFD1D7E0C1E3ECCFFEFFEC
FFFFF3FDFCF7FDFBFFFFFCFFFFFDFFFDFAFFFFFCFFFFF8FFFFF8FFFFFBFFFBF8FFFFFFFA
73766178825DCBD9A4C3D897C7DF95DDF8A9CBE898D3F2A4D2F2A7BCD68F96A260DCE7A5
C2D38FD3DF9D9593568F9152CAE49DC4E49BCEE39ED3EAA4CAEEA4C2EB9FC8E89FD2E9A3
DAE9A6E9F4B0BCC681626C254E580FCCD88EE1F1AAD8EBA9CDE5A9CEE8B8F2FFE8F3FFF2
F9FFFFFFFDFFFFF9FFFFFAFF868477EBF0D0DBE3BED1DEB2D6EBB3CDE7A6BCDA94C1E195
C6E796CCEB9BCFEA9BD8EFA1BECE87535E1AD7E09FD3DF9DCCE89DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DC1DF95D1EFA5CEEAA0C0DC9298B36C79944DCBE59EDDF8B1
CBEBA0D2F2A7D8F6AEB6D48E96B071C2DEA35B7A41527741C6EEBAB6E1ACBDE8B0CAF2B6
C8EBA9CEECA4D5EDA1CEDE9549541067702DC7D28EC4D18BD5E69FC8DE93D2EDA0D5F2A2
C6E595C8E99AC9EB9EC7E99CC2E79AC2E69CC6EAA2CEECA4CBDF9851621B8BA359D6F2A7
CDEDA2B8DA8ED2F2A7C9E59BDBF0ABCFDE9BD1DC9A8C9554515B1CA3AF6FC8D796DAEFAA
C4E499CDF2A4BFE496C6E89BCAEC9FC8EA9DCCECA0CAEA9E
C9E78FCEEB99CAE5A0C5DCA4D6E8BEF3FFE1F8FFE8F8FFE6F9FFDFD6E8B6CBDFA2D5ECA8
D0EAA1C8E499C9E59ACBE79DD4E9A6BFD394CDE5A7CCE5ABCCE4B2D5EBC4D5E5CBF9FFF8
E0DFE42C2634C3BACDC6BFCFFDFCFFF4F8F9F9FFFAF0FDEBF1FDE5EDF9E1F6FDEDFBFFF7
F1F1EFF6F6F6FFFDFFF3EEF2FFFEFFFFFEFBF3EFECFEFAF7F9F8F6FFFEFFFAF9FFF5F4FC
FFFDFFFFFDFFFFFEFFF9FAFCF6FBF5FBFFF6FBFFEFEDF8DAE8F4D0DBE7C1E5F1CDFBFFE7
FEFFF1FEFFFAFFFFFFFDFCFFFEFBFFFEFBFFFFFCFFFFFAFFFFFBFFFFFCFFFFFDFFF9F9F7
ECF0DF3B44251C2900E0F2B8DDF2AFC7DF95BBD689D2EEA1C6E49ADAF4ADC9D593A0A968
748541D9E5A39E9A5DA0A263CEE8A1C5E79DCDE29DD0E7A1C8EEA3C5EEA2CAEAA1CFE9A0
C5DB92CDDF95E8F8ADD0DE91E1EFA2DDEDA2C9DD95C8DF9BCBE5A8CAE4B4F2FFE8F5FFF4
F9FFFFFCFAFFFFF9FFFFF8FF9A9E87EAF5CAD2E0AFCDE0A8D4EDACD2F0A8CAEA9ECEEF9E
C9EB97CDED9ACCE798CCE2979BAC655D6A25D4DD9ED6E5A2CCE89DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DDAF8AEC1DF959DB96FB2CE84C5E099CBE69FD6F0A9BBD68F
C7E79CC0E296CAEA9EBFDE92D9F4ADC8E5A2C2E4A7638852709A6CBAE5B8C6F4C6AEDAA7
BBE5A6C8EEA5C2E392CDE695E2EFA7C6D08B9CA7629CA96192A45ACCE196CBE395CFEC9C
CCEB9BCDEE9DCBEDA0C7E99CC4E89EC6EAA0C5E9A1C6E69DC7DD95CDDE97A0B86E6A863B
AECE83CBEBA0D3F1A7C5DF96CFE39ED4E3A0DDE8A698A160BFC98AACB878ADBC7BC7DE98
CAEA9FC3E89AC7EC9ED9FEB0B8DA8DBFE194D4F6A9C1E396
C9E689D0EC97CCE5A3C6DAA9D5E6C6F3FFEAF9FFF1F3FFE6F5FFDDD3E3B2CBDFA0D5ECA6
CEE59FC9E39CD2EBA9D3EBADBDCF951C2D005F743C243B050119000115000007002F3931
696870EDE6F8FFF8FFFFF6FFFFFDFFF7F9F6FBFFF4F9FFEFF1FDE5F5FFE9FCFFF3FCFFF8
FFFFFDFFFFFFFFFDFFFFFDFFFBF7F8FFFEFBFFFEFBFFFEFBFFFFFDFFFEFFFAF9FFFFFEFF
FFFDFFFBF8FFF8F7FDFEFFFFFCFFFAFBFFF3FBFFEAF9FFE3E4F4C7DAEABBE1F0C5F2FEDA
F8FFEAFCFFF6FEFFFFFDFEFFFFFDFFFFFCFFFFFCFFFFFCFFFFFDFFFFFDFFFFFEFFF9F9F7
FAFEF0C6CEB6414D27A2B281CCDEA4D0E5A4CBE09BC8E29BC9E49DC7DE9AE1EBACDBE1A3
B0BF7EA8B474736E34B8B87CCFE9A2CAECA2D0E5A0CCE39DC2E89BC2EB9DC7E99DC8E49A
DAF6ABC7E295D5EC9EC1D687D6EB9CCCE393D3EB9FC7E29BCAE8A8C7E4AEF2FFE4F5FFF1
F9FFFBFBFAFFFFFAFFFFFAFE9FA986DBEEB6C5DB9DC8E19FC8E69EC9E99DC8EB99C9EC98
C9ED96CAEC98CBE898C9E1958A9E56778641D3DD9ED7E6A5CCE89DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DB6D48ACAE89EC4E096D7F3A9C7E29BCEE9A2C7E19AD7F2AB
CBEDA3D6F8ACC7E899C4E39396B363759349D0F3B3B8DDA73E673D9BC7A3C3F1CCB7E6BA
C5F2B9C9F4ADBCE692C5E790C4D98ED8E8A1E8F8B1C6D88EAABF748FA658ADC577A8C374
C8E595CBEA9ACBEA9EC6E69AC7E79ECCECA3CEEFA8CEECA6D4EAA2E1F5ADC5DD938EAA5F
93B16788A85DCCE89ECEE59DC7D894E0ECAAABB4739CA564D4DE9FD6E2A291A16092A963
D2F0A6C3E598B4D689D0F2A5C2E296CAEC9FCEF0A3C0E295
C9E689D5EE9AD2E8A8CADBAFD7E5CBF3FEEDFBFFF4ECF5E0EEF9D7D0DDAFCCDEA2D6EBA8
CEE3A2CFE5A5DDF2B9DEF2BDA9B98A000A00A5B7855F7544536B3B8197706B7B617B857A
C9CACFFFFCFFFFF8FFFFF8FFFEF9FDFCFEF3E5EDD5E3F0D2E9F6DCECF8E2FBFFF3F0F5EE
FFFFFFFFFEFFF4EFF5FFFDFFFFFEFFFFFEFBFFFEFBF7F3F0FFFEFCFFFEFFFBFAFFFFFEFF
FEFBFFFFFEFFFEFFFFFAFFFBFBFFF6F8FFECEDFBD8E8F9CDD8EAB6D1E4ADD8EAB8E4F3C8
ECF9DBFAFFF2FBFFFBF9FBFAFFFEFFFFFEFFFFFDFEFFFEFFFAF8FBF5F5F5FFFFFDFBFEF7
FEFFF4E4ECD5616C4C6B774FC4D4A3D2E3ACE3F7BCC7DD9DD1ECA9CAE19DD3DB9FE4EAAC
C4D3925C6627524C12A3A367C8E29BCBEBA2D3E8A3CEE59FC5EA9DC7F0A2CDEDA2CAE89E
CDEDA1C4E395CEEB9BD8F3A2C5DE8BCFE897D6F3A3C5E498CDEEA9C7E6AAF1FFDDF5FFE8
F9FFF3FDFEF9FFFDFFFFFEF5A6B387D8EEADC5E09BCDEBA1C8E99AC6E997C8EE99C6EC95
C6EA93C8EA94CFEC9CD2EA9E8DA15992A35FD3DF9FD1E1A0CCE89DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DD1EFA5CFEDA3ADC97FC1DD93C1DC95E2FDB6BED891CEE9A2
C2E49AC9EB9FCDEE9DCDED9889A6526F8E40BEDE9BCBF0BA4C754B6B9975A3D2B2BAECC6
B4E7AFB9EBA6C6F6A0C3EE95D0EC9FD2EAA0BCD48AD1E99DD5EDA1CAE294AAC5766A8536
B3CE7FC4DF92D1EBA1D0EAA1CAE49DCAE39FCBE6A3CCE5A1CEE29BCFE39BD0E89ECAE69B
A8C67C537127AAC47BD0E69ED6E5A2CFDA98A5AB6B707636D5DE9FCEDA9A9FAF6E405510
99B56BDEFDB1CAE99DC5E498CAE99DD1F0A4BEDE92CCECA0
CDE78CD5EE9DC9DDA0D3E2B966725A7A8273FBFFF6D4DBC9D8E1C2D0DDB1D2E1AACFE1A5
D3E5ABC6D9A2EAFECDF3FFD869754F89956FD0E1B4D3E9B8CEE6B6C9E0B4E6F7D7F3FEED
FCFEFDFFFDFFFFF8FFFFFDFFFFFEF7FFFFECCFD9B4D4E0B8CDDABEE8F4E0FCFFF6FCFFFB
FEFEFFFFFEFFFFFDFFFFFDFFFFFEFFFFFEFBFFFEFBFFFEFBFFFFFDFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFF7F8FAF8FDF7FBFFF3F6FFE7E2F2CBCEE2AFD4E9AECEE4A6CBE0A7D4E6B4
E4F4CFF4FFE7F9FFF4FCFFF8FFFFF8FEFEF6FBFBF3FFFFF6F9F9EFFFFFF6FEFFF4FCFFF4
FCFFF1E0EAD2DAE4C936412166754ED2E2B5D0E0B1D3E6AFCFE9AACCE2A1D9E3A7E6ECB0
C9D799DBE5A8A09A609F9D62D1E8A4D2F1ABCADF9AD1E8A2CDF2A5B6DC8FD7F5ABC7E59B
C8EA9EC8EA9EC9E99DCAE999CCE997CCE995CAEA97C9EA99C5EA9DB8DC96CDEAB0D2EABA
F8FFE3FFFFECFFF9EBFFFFEAB4C58FC5E099D2EEA4C9E89CC2E392C6E995C8EE97C5EB94
C1E58ECDEF99CEED9DD2EDA08AA057CEDF9BD4E3A2D2E6A1CAE99DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCBE99FC6E49A8BA75DC8E49ACFEAA3CBE69FCDE7A0CDE8A1
C9EAA3C9EEA1D0F1A0CDED98D2EF9BA2BF6FDDFCB8B9DCA4BFE8BC628E6B5889699DD1AA
B0E5B1B6EBA7C3F8A6BFEF99BFE697C8EA9EC7E99DCEEEA2CDECA0C9E598CFEA9DCDE89B
CCE498849A4FD2E89FABBF78D5E6A2D1E1A0D0E0A1D4E4A3DCEDA7CADE96D5EDA3D0ECA1
CFEDA3C5E197BBD28A637730D7E6A3D3DE9C969C5C5E6424D3DC9DCEDA9AD5E5A4CCE19C
8EA55DACC47AD2EAA0CEE69CD4EEA4C5DF95CCE69CCCE69C
CDE492CDE39890A268BCC99E2F3920040B00EAF1E1EEF6E1E5ECCDD1DCB4D7E3B3D0DEAB
D6E4B3D2E2B5EBFBD4EDFCDB253012A4AF8DD4E5B9CBE1B0C0D9A2C8E3B0E9FED5F7FFE9
F7FDF1FFFFFDFDF9FAFFFEFBFFFFF1FFFFE4D6DFB2D7E4B6CED9BBE4EFDEFAFFF6FCFFFD
FCFBFFFFFEFFFFFDFFFFFDFFFFFEFFFFFEFDFFFEFBFFFEFBFFFFFDFFFEFFFFFEFFFFFEFF
FCFBFFFEFFFFFAFFF9FBFFF6F9FFEFF4FFE4E1F4C7CEE5ADCDE5A7CBE4A2CBE4A3CEE6AC
D9ECBEE5F6D2F1FFE6FBFFF3FEFFF4FFFFF3FFFFF1FFFFEFF6FAE3FEFFECFBFFE9FAFFE9
FBFFECEEFBE1CDD7BC74816307150091A079C8D7AED8EABAD5EEB4D7EDADDAE4A8CCD499
E5F3B6D3DB9F938C559C9A5FB4CB87B6D48EE3F7B2C9DE99C5E79BBDE295C6E298CBE79D
C8EAA0C6EAA0C8EA9EC9EA9BCAEA97CAEA95C9EB95C8EB97D1F7A4C6EB9ECCEDA8C9E2A8
E8F8C9FBFFDBFFFFE4F8FAD5CBDDA1CAE59ECDE99FCDECA0CBEC9BCAED99CAED99C8EE97
C8EB97CCEE9AC8E797CAE59899AF66D1E59ED3E4A0D1E6A1CAE99DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCCEAA0C8E69C90AC62CEEAA0D3EEA7CEE9A2D0EAA3CFEDA5
C5E69FC9EDA3C4E596C4E18FD3EF9BC8E396B4D28CDFFFC5C5EBBCB7E1BB8AB9955B9066
9DD39FC3FAB9AAE094BAED9ECBF7ACC5EFA5BCE49BC1E79CC6E89CC3E398C8E499CAE298
CFE59CCEE29ACFE09A9EAD6A96A262ECF6B7C6D093E0ECACCDDC97CFE39BD3EBA1C1DB91
C6E298CAE69CC6DD95798A44D1DD9BE3ECAB939858515717E0E9AADEEAAAD4E4A3DDF1AC
D1E59EAEC47BABBF77889E55B1C77EC3DB91E7FDB4C8E096
D3E7A095A8665F7039D4E1B59FA889C1C7ADC7CCB5FEFFECFFFFE6CED5B3E4ECC5CED9B1
C6D2AED7E5C2E8F5D9E3F0D6333D25E0EBCDE8F9CDDAF1BBCBE8A8D2EFAFE4FDC6F3FFDD
FAFFECFEFFF6FEFDF8FFFFF6FFFFEDFFFFE1D7E1AFD3E1B0D9E3C8E8F3E3F8FEF4F9FEFA
FCFBFFFFFEFFFFFCFFFFFDFFFFFDFFFFFEFDFFFEFBFFFEFBFFFFFDFFFEFFFFFEFFFFFFFF
FBFDFAFEFFF8FCFFF6FBFFF3F9FFECF4FFE0E0F3C5CEE6ACCAE4A3CCE7A2CDE8A3CCE6A5
CCE3ABD2E8B9E1F2CEECFAE0FBFFEEFDFFF1F8FBE6F9FFE3D8E2BFDAE6BED3E2B7D4E3BA
BECDA6E1F1CDD2E0BFE6F4D3C0CEAB42502C0D19005E6F4256723892AA6CD1DCA2DBE3A8
CCDA9DD5DFA2A7A069BAB87F91A663789650D3E4A0DAEEA9C5E59AD4F6AAD7F1A7CEE89F
C8E9A2C6EAA4C8EAA0C9E99DCAE999CAEA95C9EB95C8EC95C5EB96C5EB98CAECA0CFEAA7
E4F6BCDDE5B4D0D1A7686B3CD7E9ABC9E49DC6E19ACAE89ECCECA0C8EB9BC6E997C9EC98
CCED9CCBEC9BC9E898CAE598B4CC82DAF0A8CFE49FCDE49CCAE99DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCEECA2CCEAA094B066CFEBA1CFEAA3C7E29BC9E39CCAE8A0
C3E49DCFF3ABC6E599C9E497D4ECA0D9F1A75A7331CCEAAEC2E4B1CDF7C7ADDCAE295D2D
528753A1D79DB2E6A4C3F6B1B6E59FC6F4ACCAF5AEBDE79FC2E89FD5F4AED8F3ACCDE49C
D5E9A2D7E8A2C7D48FD8E3A1D9E2A35D6627E4EAAED6DFA0D8E7A2D0E69DCCE49AD0EAA0
DBF7ADCDE79ED6ECA4C5D69056611FA4AA6AA4A9697E8343DEE7A8CDD999C8DB99CCE09B
DFF3ACCBDF97D3E49D97AB63A9BD7596AC63C8DC94C9DF96
D5E4A967763DCAD8A5D9E5B7515932F6FDDBD0D5B5E5EACCEAEFD1FEFFE7F3F7DCFAFFE6
FCFFECF1FBE3FAFFF0E9F2DF767E69DCE7C9D0E1B4C7E1A4CAE8A0C3E398C4E19FD0E7B1
F9FFE6FCFFF1FFFFF8FFFFF6FEFFEEF8FFDED6E2B2CEDBAFEDFAE0F5FFF0FCFFFAFBFFFE
FEFDFFFFFEFFFFFCFFFEF9FFFFFDFFFFFEFDFFFEFBFFFFFAFFFFFDFFFEFFFFFEFFFFFFFF
FEFFF8F9FFF0FBFFF1F9FFEDF8FFEAF7FFE3E0F6C5CDE6ACCAE7A4CDEBA3CEECA2CAE8A0
C5E2A2C7E0A7CFE7B5D9EAC6FCFFF3FEFFF4FEFFEDFAFFE2D3E0B4CEDFA9C8DBA3CADFA6
DEF2BDBDD0A2D5E7BDD8E8C1F8FFE1F1FFD7FBFFDD829464BDDAA06B874A727F47CFD89F
E8F7BCCED89CA59E68939158C7DC9989A45F000C00CDDC99CFEBA1C9E79DD1E79EC3D991
C9E8A4C6EAA4C9E8A2C9E99ECAE999CAEA97C9EB95C8EC95C3E992C9EF9CC4E699C1DC95
D2E4A8D0D9A4D9DBAC4C501ED2E4A8D0E9A7D1EAA8CEE9A4C9E79FC7E79CC8E89CCAEB9C
C8E99ACBEA9CCEED9FD0ECA1C9E399DEF5ADCCE39BC9E39AC9E99DC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCAE89EC9E79D92AE64CCE89ECDE8A1C8E39CCFE9A2D4F2AA
C6E7A2CEF2AAC8E69ECFE9A2CFE39ED1E5A0394E0DBAD495C9E8ADB3DAA1DBFFD1B3E4AD
7FB17C2355204B7E46B5E7ACC4F4B6AFDC9BB6E0A0C7F0AECEF1AFC3E29EBED994D6EDA7
D5E9A4D6E5A2DBE7A5E1ECAAC9D394E2EBAC535B1F97A162CDDE98D0E69DC7DF95CFE99F
D6F2A8C1DB92CFE59DE6F5B0D3DC9BAAAF6F9A9C5D9FA464DEE7A8D1DD9DDDF0AEC3D893
C9DD96CFE39BC5D991C3D78FE5FBB2677D34586E25D5EBA2
4550253C481AD8E4B4939C6D6D7745FEFFD7FFFFDC989C778B8E71676B54FEFFF0FEFFF4
E9ECE1FCFFF6F6FCF0FBFFF3CDD5C0D0DBB9D2E6B1C1DF99D1F39FCEF29AD0F3A3D0EDAD
F1FFD9EEF8E0FEFFF8FFFFFBFFFFF4F9FEE8E2ECC9D9E5C1F9FFEFF9FFF6FCFFFBFCFFFF
FFFEFFFFFDFFFFFBFFFDF8FFFFFDFFFFFEFDFFFEFBFFFFFAFFFFFDFFFEFFFFFEFFFFFFFD
FEFFF3EEF6DEF4FEE5EEFBDFF0FFDEF7FFE1E0F8C6C8E4A9CAE8A2CAEA9FCBEB9FCAEA9E
C8E89FC8E5A2C8E4A7CBE0B5F9FFF4FCFFFDFBFFF1F9FFE4D4E6B2D2E8A8CFE9A2D5EFA6
C7E09CCFE7A9D0E7AFEAFEC9F8FFD8EEFFCED0E1ADD2E7AFD5F4B8C1DFA1081700000B00
CADCA0CBD69AA09B64BDBB82DBF0ADC4DD998E9A588E9A58CFE9A0B6D288D2E39CE4F8B1
CAE8A2C6EAA2C9E9A0CAE99DCCE89BCAEA97C9EB97C8EB97C0E693D0F5A5D0F2A8C1DE9B
CEE1A9CFD9A7F0F1C75B5E31D0DFA8E6FCBEF0FFC8DCF5B4CCE5A3CDE8A3D0EEA6CDEBA1
C8E79BCCEB9FCFEEA2CDE99EC1DD92D5EFA5C9E399CEEA9FC9EA9BC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DC6E49AC5E3998FAB61CBE79DD1ECA5D2EDA6E0FAB3E9FFBF
CAEBA6C3E7A1C7E4A1D5EBABCEDEA0D2E0A3819153DBF0AFD1EEACBBE09DBAE4A2C4F2B4
C3F2BB4C7C4A58875B90BE90C3EEB9C5ECB3D2F8BDC7E9ADC6E5A9D2EFAFCAE3A2D0E5A4
CCDF9DC6D793E1F0ADCFDE9BCEDD9CE2F1B0A6B5746F803CA9BD76DDF3AAD8F0A6C9E399
C9E39ACDE49CD1E59ED2E19CDAE3A2929757828445A3A566CFD899BAC686DAEDABDFF4AF
DCF3ABD1E99FDDF5ABDAF2A8C4DC92D0E89ECFE79DA3BB71
737D5BAEB893E5EEC38D9763959E65D5DEA5E0E7B3E2E8BC959879979886010100000100
787A777C7E7BC8CDC7F8FEF2F0F8E1CAD9B2D8F0B4BFDE90BFE485BFE786CAF198BEDE95
D8EEBFD7E3CBFBFFFAFDFEFFFEFFFDFBFFF5F6FFE8EFF9E0F9FFF1F9FFF6FCFFFBFBFFFF
FFFEFFFFFDFFFFFBFFFFFBFFFFFDFFFFFEFDFFFEFBFFFFFAFFFFFDFFFEFFFFFEFFFEFFFB
FEFFEDD7E0C1DEE9CBD6E4C3DAEAC6F1FFDDDCF4C2C5E1A6C9E8A4C7E79BC7E897C9EA99
CDEE9FCDEDA2CBE9A1C9E1B1F1FBF3FAFFFFF6FFF3F4FFE0CDE2AACAE49BC8E593CCEC97
CDEA9ACEEA9FCAE5A0D6EFAED3E9ABE9FDC0C1D397C9E1A3C6E9A9B7D69AE5F9BE66753C
394D12EFFDC288834C929057C8DD9CCCE5A1E4EFADA2AD6B556C24E4FBB3C9D992D0E19B
CAE8A0C8E9A2CAE89ECAE99DCCE89BCCE999CAE999C8EB99C0E597C4EA9FCCEDA8CAE6A9
F1FFCFE6EFC4E1E1BD2E3009D0DCACF1FFCDF8FFD3E5FABFCDE3A5CDE6A5D1ECA9C9E79F
CAE89ECDECA0C9E89CC1E094A3BF74C8E499C9E59AD3EFA4C9EA9BC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DCCEAA0C8E69C8EAA60C9E59BCEE9A2CEE9A2D9F3ACE0FEB6
CDEEA9C2E29FDCF6B7EAFEC3D9E6B0D6E1A9C3CE92CCDC9BC9E39AD7F9ACC6EFA3B9E6A1
D0FDC4BCEABC90B99900120072966AA1C18FD8F6C4C2DFA9B6CF98CEE6ACCFE3A6DBEDAF
D4E7A7E9F9B8CCDF9DD3E7A2D9EEABCDE29FBBD28EDCF3AD99AD66C6DC93C7DF95D4EEA4
D7F1A8D8EFA7D2E69FD7E49FDDE3A3D8DA9B9F9F617E8041C2CB8CD8E4A4D7EAA8BDD48E
C7E198D4F0A5B5D186C0DC91D5F1A6D6F2A7B4D085C9E59A
F2FAE3D2DBBEDFE8BDDBE5B08E9859DEE7A6D6DCA0FFFFD6D9DABBDEDFCF7C7B7968676C
95969B77787CBEC2C1FCFFF8E3EDD4CCDBB0CBE4A2D6F8A2CBF48EC1EC81CFF796C8E89C
CCE2B1CBD9C0FBFFFFFBFEFFFCFFFFFBFFFFFBFFFAF9FFF6F9FFF4F7FFF4FAFFF9FBFFFF
FEFDFFFEFCFFFFFCFFFFFCFFFFFDFFFFFEFDFFFEFBFFFFFAFFFFFDFFFEFFFFFFFFFEFFFA
FCFFE6CAD4AFD4E0BCCAD8B5CDDDB8F0FFDCE3FBC9D4F0B5CDECA8C9EB9EC7EA98C7EA96
C9EC98CAED9BCAEB9CCCE4B0F9FFFFFBFEFFF9FFFBF8FFE8D0E7AFCCE89DC6E78ECAED8F
C8E98EC1E28BDFFCACD1EBA1C5DC96C9DE99DCF0A9D9F3ACC9EEABD0F2B5CEE1A9DAE9B0
364A0F505E2379743DA3A168DAEDADD3EAA6D5DE9DE9F2B1758B438CA25AD5E29CD2E29B
CCE89EC8EA9ECAE89ECCE89DCDE89BCCE89BCAE99BC8EA9DD0F4AABCE19BBEDDA1BBD6A1
F8FFDDFEFFE3FCFCE2575839D0DBB0E7F7C6F3FFD0E1F4BDCEE3AACBE3A5CDE6A5C9E4A1
CCE7A0CFEBA1C6E599C2E1958CAB5DC5E496C9E89ACEED9FC9EA9BC8EB9BC9EA9BC9EA9B
C9EA9BC9EA9BCAE99DCAE99DD0EEA4CAE89E8EAA60C7E399CBE69FC6E19ACAE49DCBE9A1
CCEDA8C7E7A4EDFFCCF4FFD2DBE4B5D8E0AFCED79E94A360CFE696BADA85C0E794C5EFA3
AEDA9FBDE8BDC8EED55E7F6A516C49314B1E576E427A90618B9F6C8B9E6787995FBFD195
D1E4A4C7DA98BED390D6EFABBED992D5F3ABD5F4AEC3E199A9BF77A5BB7299B167CCE69C
D7F1A8CDE49CC8D993DCE9A4C8CE8EF4F6B7B8B87A5C5E1F788142ADB979D9ECAADBF2AC
BAD88ED8FAADD8F8ACCBEB9FC8E89CCBEB9FC8E79BD3F2A6
F2FDDFF2FEDAD4E2B1CFDDA095A55ED7E49CD4E09EDBE4AFD5DBB7888B76E0E1DBF5F5F7
FBFAFFFEFFFFEBEDECF5FBEF99A48495A773819B54CCED96CFF592B7E07AC8ED90D2F2A7
CCE2B3CBDBC1F9FFFFFBFFFFFBFFFFF3FAFFF9FFFFF9FFFDFBFFF6FCFFF6FEFFFAFFFFFF
FFFEFFFEFBFFFFFCFFFFFDFFFFFDFFFFFEFFFFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFFFFFA
FCFFE6CEDBB0DBEAC3D0E0B9D0E2BCF5FFE1F5FFDDF0FFD4D5F1B6D2EFADCDEBA3C9E89C
C6E599C6E599CAE69CCFE3B2F7FAFFFEFBFFF8FCFBF7FFE8D0E2AECCE69DC8E690CBED8F
C7EA8CCCED92C0E08BC6E393D5F0A3D2EA9ECFE698C6E194C8EAA0C2E39ED5E9AAC8DA9E
B3C78A0A1900242300BFC087D3E3A4C5DA95DDE8A6CBD692DCF2A9D3EBA15F7127576821
CCE89ECAE8A0CCE89ECCE89ECCE89DCAE99DC9E99EC8EAA0C6EAA4C0E3A1D3F2B7C3DEAB
F8FFDFF7FFDFFDFFE5808364D3DEB3DBECB8E1F4BDDCF1B8D4E9AECFE7A9CFE8A7CEE7A5
CCE39FD1E8A2CDE49CD1E8A08EA65CCFE99FCEE89EC5E498C8EB9BC6EB9BC8EB9BC8EB9B
C9EA9BC9EA9BCAE99DCCE89DCCE89EC7E3998CA85EC9E59BD1EDA3CCE89ECCE7A0CBE9A1
CBEDA3C7E6A0E8FFC3E3F7BCCAD7A2DCE6B1D0DB9F82914EECFFB4DAF5A4C9EA9BCDF1A9
DDFFC6E1FFD8D2F0D6D4EBD1868E69383D14000E00000D002A4B1C81A873698F56506F34
496125697B3DA0AE71D3E1A3D9EDA8C4DB93CFEEA2CCEB9DD4E8A0C3D48D9DB36ABED88E
CAE49BD8EFA7D3E7A0D4E39EDCEBA6C5CE8DB7B578B7B779B7C28099AA668999585E722D
D6F2A8BEDD91CBE99FCAE99DCAE89EC6E599D4F2A8C3E296
F2FFD2DDF0B9E1F5B6D3EAA480984CD9F1A5CBE29CD2E6A9D1E1B4F9FFE648503B9A9D92
FFFFFBF5F4F2FFFFFDA0A392E4F4C7CBE1A194AE6585A252C9E791CEEE99BDD98ED5EFB0
CCE1B6D1E4C8F4FFF7F6FFFFF7FFFFF7FFFFF2FDFFF7FFFFFBFEF5FFFFF3FFFFF6FFFFF8
FFFDFAFFFDFCFFFDFFFFFCFFFFFDFFFFFBFFFCF5FCFFFCFFFFFCFFFEF9FFFFFCFFFFFFFB
F9FFE4D4E5B8D9EABECEE0B6D3E5BDF7FFE3F7FFE1F1FFDBE8FAD0C8DBADD1E5B2DCF1B9
C6DBA2C8DDA2D8ECB1CFD9B4FFFCFFFFF8FFFFF8F9FFFFEDE0E8BFD4E3A8C7DF95C9E692
BBDC85D2F39CC8E893CFEC9ACAE596D5EE9DC9E090D7F09DCEEC96D6F39FCFE59ACBDF9A
CFE1A3D2E1A6070E00D4DCA3D4E2A4CFE09CDBEBA4D2E49ADBF3A5C2DF8DCAE797CAE699
264000C5DE9AC6E19CD5F3ADBFDD95C5E79DC7EBA3C8ECA6C2E5A1CDEDACCBE8AEC0D8A4
F8FFDCFBFFDFF9FFDB525930D4E3ACCDE1A2C9DF9FCAE4A3CFEAA7CFECA9CCE5A3C7DE9A
CDE09EDEEDACCAD694616C2A939F5DCDDC99DBEFAACCE69DCCF3A4B6E191CDF6A7C2E799
C6E89BD4F3A7BCD88DD1EBA1D5EFA5B8D28897B167CFEBA0C1DD92D6F5A9C7E79CC0E094
D1F0A2C8E497CFE99FCAE199D7ECA7D7EBA6C8DB99D2E5A3D3E6A4DDF2AFDAEEAFDAEFB4
F7FFD6F4FFD9F7FFE1EDEFC8AC9466624A1C30370D00100045895A2D7D48A4F4B9ADEFB2
C6ECB18A9962635D2BA39763E3DFA2D8E097CCE48CD7F198D8E498D4DE97D8EDA2D4EFA2
89A55ABDD78DE0F6ADC8E096C0E094DAF1A99E9A5B555112D5E9A2CBE59C99A56357621E
4F601CD3E9A1D5EAA5C9DF97E1F8B2D0E79FC2DC95CEEAA0
DAEEB1CAE0A0CAE19BD1E99F8FAA5DD4EFA2CFE9A2C5DD9FC7D9A9F9FFE3FBFFECF2F6E7
E9E9E1E8E3DFC9C1BFF2F0E1F0FECDC8DD9ACCE29A9EB46BC5DB90D1E79FD4E9A8C8DBA4
D6E7BDCDDBC1F8FFF6F8FFFDECF6F7F7FFFFF1FAFFF9FFFFFCFFF8FFFFF6FFFFF6FFFFF8
FEFDF8FDFEF9FFFEFCFEFEFEFCFAFDFFFEFFFFFDFFFCFBFFFAF8FDF7F6FBFFFDFFF5F8F1
F6FFE3CBDCB2CCDBB2C6D6AFC5D3AFD9E7C4E6F4D1F7FFE2F9FFE4EFFDD9E2EEC8D5E2B7
CFDCAEDAE8B7EFFDCAFFFFE3FFF7FAFFFAFFFFFBF7F9FBE6D2DDB3D3E7ACD2EDA6D4F5A6
D6F9A5C5EB96BFE592C1E492C9EA99CAE999CCE999C6E38FCDEA90B6D379CCE393E3F7B0
C4D496DCE9B17B8550616C349FAA6EEEFDBAB5C67FCBE294D9F4A3C4E491CDEE9DCEED9F
879C578EA1619BB06FCAE09FE4FFBACFEDA7C0DF9BD4F3AFD1F0ADC1DE9EC8E0A6DAECB8
E7F5C4DAE3B8C1C69E51592AD0E2A6CDE6A2CCEAA4CBECA5C8ECA4C7EBA3C9E8A2CCE7A2
CADF9CD6E5A4DBE5A6515B1C98A464D3E2A1D1E4A2C3DE97C2E89DC5F0A1C3EC9EC1E699
D0F0A5D0ECA2C6E097DCF3ABCEE49C8FA55D8FA65EC4DE95DBF7ADC5E399C2E297D6F6AA
C6E595CCE999D1EE9EC9E598C8E298CDE79ED2E9A3D7EDACCFE3A4D9EDB2CCDDA6D8E9B3
E3F4C0E8F6C3E8F6C5E8E7B7D6B68797784985865AB0D1A489CB9B00522140935F99DFAB
B6E2AFE0F6C5999967706730635B1DC5C57FD3DE8FD2E190DAE69CD5E59CCEE89EBDDC90
BDDC9090AA60A7B871DCF2A9C6E89BCDE79ECEC688A8A264CEEAA0B9DE91D0E69EC2D18C
E1F0ADACBD798FA05C8C9D596B7F3ACFE39ED5EAA5CDE49E
D4E6AAD6E8AAD2E6A1D5EBA28FA55AC6DC93D8EDAADAEEB3D5E2B6F6FFDEFFFFEDFFFFF3
FDF6F0FFFCFBF7EBEDFFFEF3DFE4BCD2DDA3DEEAAC919D5BDFECA7D7E3A1D2DDA1E3EDB9
D8E3BBC7D0B3F8FFEFFCFFF8FCFFFDFBFFFFFAFEFFF7FDFBF9FFFDF8FFFDF9FFFDF8FFFD
F8FFFEF7FFFEF9FFFFF8FFFFF9FFFFF5FFFCE8F1EEF8FFFDF9FFFDF8FFFDF9FFFBF9FFF6
FCFFECDAE3C4DDE4C5E0E9CAD5DCBDD1D8B9E0E7C6FEFFE4FEFFE3FEFFE3E9F3CED0DBB1
D2DDB2D4E0B2E0ECBEFBFFE3F3F8F1FBFFFFF9FFF4F5FFE8C8E2B2C5E8A6BDE69AB8E592
BBEB97B3E590CAF9A8C2F1A0CAF6A7BDE898C9F2A3BCE28FD0F09BD5F19DD5EBA2D5E8A8
D6E5ACCEDBA6BBC5934A5420202B00CCDA9CDFF0AAD8EEA3C2DD90C6E597D5F5A9C2DC93
CAD694EDF6B7D1DB9C4E5A1A879756CADD9BC6DB98CDE2A1D1E5A6CEE0A4D0DDA7E5EDBA
D9DCADDFDEB2A49F77494C1DD2E8A8C8ECA4C2EAA1BBE59BB6E297B9E59AC4ECA3CEF2AA
D2F0AAD8F1ADCEE3A03A4D0B859C58D5EEAAC4E29CD0F1AAC3E9A0D4FAB1C1E59DC7E6A0
D5F0ABC9E09CCADF9CD6E9A7CFDF9E536322859856D1E6A3C7DE9ABFD894CFEAA5C9E79F
CDEDA2C5E79BC2E498D3F5ABCDEDA4C6E59FC9E6A3C5E2A0C8E2A3D0EAABC0D89CD5EDB3
CBE3A9CFE4ACCCE1A9D3DDA9DACEA4A6976CABA978EBF8C3BDD9A8BEE3B8517D5C134021
88B490B3D9AABBD99BE8FCB5D6DE952524009E955EE2E1A9B8CF89E0FFB8B7E293CCF5A7
C1E196C9DF979FA865D2DD99D3EAA2D2E19ED4CA8FC6C285D1F5ABB8ED9DD0FAAED1F1A8
BDD48ED4E5A1DDEEAAD9EAA6CEDF9B8E9F5BDEEFABD0E19D
D5D49EDEDDA5DADA9CDDDD9D999A58DDDD9DDCDCA0E1DEABDCD4AFFFFEE6FEEADFFFF8F4
FFF6FAFFF0F7FFF3FDFFE2E0FBE6CBF8E9BEE9DBACA29561F8EBB4E3D69FECDFABFFFFD3
FFF4D1FFFEE4FFFCECFFFBF1FFFBF4FFFBF6FFF9F4FFF5F4FFFCFEFFFBFFFFFBFFFFFDFF
FFFCFFFFFBFCFFFEFDFFFEFDFFFEFBFBF8F3FFFFF8FFFEF5FDFAF1FFFDF1F7F5E9FFFFF3
FFFFEFF3F5E0F9FBE6FFFFECF7F9E1E0E3C6E3E6C7FFFFE2FFFFE0FFFFDFFFFFDDFEFFDD
FFFFDCFCFFDAFBFFD9FFFFE3F8F8ECFFFFF8FDFFEEF7FFE0CFE1AFD0E9A8CDEBA3D0F2A5
C7EC9ECAEFA2C9EBA1BAD993CAE7A4C8E3A0D0E9A7D7ECA7D4E59EB4C47D3E4A0A9AA36C
A0A374F1F2C8AFAD84C8C79B7C7C4A73763DD1D797E0EBA7DBEBA4CEE29BC8DD98D2E19E
EEECB1CAC188E8E2A8B1AC72A9A76CA6A869BDC184E6EAADDFE0A6E1E0A8CBC895E7DFB0
DED1A5E5D3ABA6906B9F9266D3DBA0CDE29FCEE7A3D0EEA8D3F1ABD0EEA8CAE5A0C6DD99
C9D897D2DC9DECF2B4595F21D8E1A2DBE7A7D6E6A5C7DA98D3E6A6CDDD9FCEDC9FD9E3A7
DBE0A6DCDDA4DEDDA5D8D59EDFDAA385824B999860E0E1A8E1E4ABF4F9BFCDD59ADAE6A8
D4E7A5D5ECA8C3D998CEE4A3CDE3A2DAEEAFC4D8998EA064D3E5A9D5E4A9D2E1A8E1F0B7
DAE9B2CDDAA4D9E6B0DAE4B0DFE2B5BEBD8F504C1C5C5626F5F0C8DBDCBCDAE6CE96B097
77A17D699B6AC8F9B7B1D990C1D691B8B9807C6641A0926BDBF1B1C2EB9FB7E195BEE499
D1EBA4DCE7A5C6C2859D995CD5DB9BE1E3A4B099658A7E44B9D892C0F1A2BDE79DC0E298
DFF6B0D2E6A1BFD08CCCDD99DCEBA899A8657B8745B7C381
B18C62B08B5FB28E5EC09C689A7741E9C490BC9669AA7F5CD5A58FFFD3C8FFCED0F2B3BE
D18C9FEAA2B8F1A7BEE29AA6C5867DB77D67B37A5D854D2C9B653FA8734BEEB892EDB896
D09A80FFE4D2E6B0A4C28D85C7928CC08B85F0BBB5FFD8D9FFD4E1FBD1E5FDD4E6FFD7E7
FFD6E6FCD4DFFED6DFFFDDE2A0797CC19B9AEFC9C6A17C76926D64DDB9ADDAB6AAE6C8BE
DBCCC5D8D1C9DCD6CAE8E2D2E0DEC9C8C7ABC0C1A1C7C9A49A9C75868B62A9AF83D6DDB1
D6DCB0CCD3A9D3DAB0D7D4B5ECD9CBF2D7CEF6E0CBFFF5D5E2D5A9C9C089A9A568A09F5F
C6C489BDBB8298925EB1A978DCCFA2CEC093A49367BAAC7B9A915A847D46B8AE7DA4976D
93805F9D88697B6445967F5F64512928170081743F91884F9B955BACAA6FA09F66AAA36C
A18754BF9D6DBA9A67AC915CBCA36D8C763D5A450E6F5A2378612BD0B683CDB182D0B185
D7B48CEBC39FA27755A57F5AD2B887B8A76FA0945A9B9257A89F64B5AC71B9AF74B8A970
CCB57FE0C590AC8E5A6A4C18B69B66D1BA84CFBC84E1CD98D9C593AB9566D5BD8FE4C79B
D8B78CF6D1A7F2CBA2DFB58DE8BE9671471F9E774EE6C197C8A57BE6C59AD5B68AAD9768
C2B883DEDDA5C6C58DAEAD75AAA971DBD8A3B2AF7A615B29DDD7A5D0C897DED6A5D4CC9B
DBD3A2BFB584E4D9ABD7D5A4DDE8B0AFB883898055735C3AE3C3AAE6CAB4EBDFC5BAC4A2
8EB4855289501A561896CA8CD0ECB9D3D5AE9A82686851317D844EB5CC88E8FFBDD5E8A6
B9BF81DDD79DE7D09CA9925EAA9D66D4C38DC1966BA48252CFD99CD4EFAAD4E9A8D6E6A5
CFE39ED0E49FDAEBA7D1E09DD6E2A0DBE6A4C2CB8A929858
8F70448D6E40937543937340795A249A79468F6A3E865E3BCC9D89F0BEB5ECB4B7D597A2
C28292DF9CAED0889CB06C77A96D65A9725DB37D61743F1D7E4A23946338D4A37ACE9E76
A97B59F8C9ADB98B739A6C55AC7F68A97C65D8AC93F1C6B6FFD7DEFCD3E1FED4E2FFDAE3
FFD7DFF8D1D6F8D0D1FDD7D4C19A93BF9A91DDB7AA977363A07B69FAD7C3F6D2BCFFE6D6
EFDED7F6ECEAEFE6DFF7F1E3FAF5DFE4E3C5DCDCB8D8DBB0B6B98A949B68B2BA87DEE6B3
D3DBAACFD8A9DEE7BADADCB7DACAB3D4BEA9D5C2A4EBDCB5C6BA889D945D6E682C5F591F
9B94608E83556B5E34A0906CC5B190AA9373775E3FA18B6670633753481B948661897958
836D55735B43644A33876D52B098744532081101007266329A905B78723E595623695F2C
77602E664816583D08886F397F69307661287562286552183C2700907B44917A48967A4B
B9986DBE9B73855F3A755228B89E6D9481496D5E2560541A6F652A867C4195894F9B8A52
8E753FAE905C71511E6A4A17987A46AB925C97824BA4905B9F8D5B6651229B8556A58D5F
94774BB9986DAF8C629C774D9F7A50603B117B582E917045BFA0749D82558870428A7546
8F834F98915B88814B7F7842716A34867F4B594F1E544A19BAAE7EA39669B3A679938659
9B8C6175663BA7986F918B5BA0AE7079844842390E6A4F32A17B6699755FE5D1B0AAAB7F
7D9C634577380D480E4177434D6D46A8B39585765F5D4A2C504A1A9DA166969E6393995D
6E6932AC9C68B5996AD4B586A59460B59E6CCD9870CB9C72DCD59EC9D195E3E1A8DCDCA0
D7E1A2D6E7A3D3E29FD1DD9BE0EBA9C1CA89FCFFC2B2B777
CDDFA1D2E5A5DAEDABC4D591B4C37E737F3DC9D397D7DEABC5C5A1FFFFE8FFFDF1FFFBF6
FFEDEDE8D4D5DDC4C7B7A39CE6DAC0BAB58FEAE6B9A6A471D9D99DD7D99ADCDE9DE3E8A8
EAEFB5FFFFCFE0E7B3D1D8A4DCE5AEDAE3AADAE4A8DBE1B1FFFFECFFFFF4FFFFF4FFFFF1
FFFFEFF7F6E1F4F2DBF8F8DCFFFFE4E8E9C7DADAB6C9CBA4D8D9B1F1F3CBECEDC5FFFFE0
FFFAEEFFFDFAFDF6ECFFFFEDFFFFE6EDEFCAE6E9BCE2E9B5D8E1A8CAD599D0DEA1D9E7AC
CEDDA4CCDBA4D2E0ADCDDDACF9FFDDEDFDD0D8E8B7E0F4B9CBE1A0CEE5A1CAE19DD0E6A6
DBEEB7D2E2B3C8D5AAD7DFBAE0E4C3DDDEBED6D5B6E2E2C0646941C5CAA2AFB090737256
8A846C655D489A9077635A3DA79F7AC1BD90706E3D8285505D622C656E39D9E3AFE5EEB9
D6D9A0EFEFB3D1D394D5DA9ADCE3A0DBE4A1D3DE99D5E09BD5DF9AB3BC79989E5EA7AB6E
B6B57C908D56BBB883E2E1A9DBE1A3D2DE9CCCDD99CEE39ED5ECA6D5ECA6CFE49FC9DA96
DBE4A3C7CC8CCFD1926D6F30E0E5A5B5BE7DE2EEACCFE2A0D8F1AFBBD594D2EBAAD9EDAE
D0E2A4DFEDB0DAE5A9D2DCA0B7C185A4AE72CDD89CCBDB9DDEF0B2C1D596CFE8A7C5DA99
E2ECADD7DC9CD5D99CE5E9ACD4D89DCACD948E915ADCDFAAD8DAA8CBCD9CDFE1B2C7C89C
C5C39AA9A77ED1CFA8B4B685CAD591FEFFC4FFFFD4786545B1957DEFD4B6FFF7CAE7E8AE
D0E7A3BBE09D78A36E446F44000D00A7BBA0B5BEA3BDBA99C5B68BA18F5D7C754197925B
E6DFABBEB27E9D8859B19D6BAAA36D917F4D814D2667330C8F7B496C602C886E3D89743F
AAAB6F616D2B4752109DA866B3BC7B9EA4644146066D7232
C0E9A3C4EEA6CCF4ABBDE396CBF0A33A5C12CDEAA8D4EDB4D2E4BAF8FFE6F7FFEBF7FEEE
EAEDE2ECEEE3EFEFE5FFFFEF9EAD86081C008FA46B869C5CCFE9A0D4EEA4D1EDA0C5E196
D0EEA6B7D690CDECA8C7E8A3C0E298CBF0A2C2E797CDECA8F5FFDFF4FFE4F4FFE2F8FFE4
F0FFDBE0F1C7D9EABEDDEEC1F1FFD3E6F8C6D4E6B4D9EBB7D5E7B3CCDEAAE0F2BEF1FDD5
FDFFEDFFFFF4F7F6E4FFFFE8FFFFDFDAE2B3D1DAA3D3DFA1CBDA95E0F1AADBEFA8CDE29D
D1E6A3D1E7A7CDE2A7CEE7ADCDE9AFC6E3A9BFDD9FCAEAA7BEDF98CFF0A9CEEDA9CEEAAD
C9E4B1DCF1C6F8FFE4F5FFE4F8FFE6FEFFEAECF0D78E9176FFFFE6ECEFD2030300AAA794
726B5B0C0300423723554B309D9571E3DEB4D9D8A89698660B1200000900CFDBABCFDDAA
CEE0A2CEE3A0D3EAA6D3EAA4CBE59CCCE89ECEEDA1CBEA9EC5E498D1F0A4CCE89E819B54
516824536825D1E6A5C9DE9DD0E5A0CEE8A1CBE9A1C7E99FC3E79DC3E79DC8EAA0CEECA4
D2E9A3CFE39ED7E8A49CAD69D2E6A1DFF6B0CBE69FC3E59BBCE89DC3F3A7BAE69BBFE99F
CBF1A8C2E69EC7E6A0CEEDA783A15BCCEBA5D4F5AEBDE39AC2EAA1C1EDA2BFEDA2CAF3A7
C8DE95D5E29ADCE9A3D5E29DCCD896D8E6A88B965CD5E2AADBE5B1E0ECBAFEFFDAFEFFDD
F9FFDAF0F8D3FEFFE1EAF3C6DCE7A5CED591DAD9A1EEE6B82F2200E5D8ACE7E2ABD4D89B
CBDA97D7F0AECCEBB2BEDFB061835E1B3A1ACBE6C7D1DFBCE3DAB1ECDCAB8A87545A5D26
757841D7D7A1E1DBA7DEDBA6D7DFA4E1DCA5B78D6380532AD0C08D887C486B4F1F6E5421
636126CDD695DFE8A7DBE1A1DAE0A0D4DA9AE2E8A8E2E8A8
CEF2ACC2E69ECAECA2C5E79BCBE99FCDE8A1617737D5E8B1D9E6BADDE7C5EFF5DBFDFFED
EEEFDFE9E7D8FFFFEFFFFFE8E1F1C4D5EAB1CEE4A4CEE8A1D1EC9FD0EB9ACBE896CAE797
CCEB9DCBEBA0CAEA9FC9EB9FC9EC9CC9EC98CAEE96CCEB9BE5F9BEE7F5C4E9F7C6EBF9C6
E5F3BED9E8B1D4E3AAD6E5AAE5F4B9DBEAAFD4E3AAD2E1A8CEDDA6CFDEA7E1EFBAF7FFD8
F8FFE6EDF2DCE7EDD1EAF4CFE6F4C3D7E9ADCEE29DCDE398CFE897CDE995CCE997CAE999
CAE99DC9E99EC9E8A2CAE7A4D1EAA9D0E6A6CDE4A0CDE29DCFE49FD1E6A3D1E3A7D2E0AD
CCD4ADF5FADCF8F7E2FFFFEFFFFEF1FFFCF0FFFAED9C8F7FFFFDEFEFE3D554463BFFF4EC
FFF9F4FFF1E9644C40836D58695437A79571A19269DED1A5E5DDAF837F524340177E8657
93AB6DCEEFA8C1E59DC7EBA1C6EC9FC2EB9DD0F9AABFE899C3ED9BC3EC9DC3EC9DC3EC9E
C5EB9EC6EAA0C6EAA2CAE8A0D1E5A0D3E49ED0E69ECDE79ECAE89ECAE89ECDE79ED0E69E
D2E39DD3E09B98A35FD1DC98D4E39ED2E39DD0E69ECCE89EC5EB9EC5EE9FCFF4A6BFE194
CBEA9ED5F1A6BFD98FD1EBA17C944AD6F0A6D2F1A5C3E397C5E79ABEE596CEF7A8C3E898
D4F09CCAE08ED7EC9DC9DE918A9E5691A661C6D999CEE2A7D3E4AEE7F9C9F9FFDDF9FFE1
F9FFE4F9FFE6F5FFE4EDF9D3DDE6AFCFD895DBE59EDCE39D8289454C5212979C62DAE1AB
DAE3AACBDB9CD3EAA6CCEBA8B5D89E739D6D3D6948688A69DAE5BACCD39DD0E3AB8EA86B
637D4073884DE0EFB4D0E2A6CDEAAAC9D89DBAA674947C4CD7DBA0DBE3A7C7BE87A0935C
A5A368959A5AA5AA6ADEE4A4D5DB9BDCE5A4DFEAA8D9E4A2
C2E39EC9EAA3CDEDA2CDECA0D0EAA0D8EFA78A9D5D96A56CD5E1B3D8E0B9D7DCBEF8FAE2
EDEFD7EBEDD5FFFFE8FFFFE1DFF1BDD2EBAACAE59ECBE79CCFEC9ACEEB97CDEA96CBEB98
C4E395C7E69ACAEA9FCDEDA1CCEF9DC9ED96C5E991C4E48FCDE49ECBDFA0CDE2A1D3E8A5
D3E8A5CFE49FCEE49CD2E8A0D7EDA5D1E6A1CFE4A1D1E6A5CEE2A5CDE1A6DBEEB6EDFFCD
EFFFD8DFEFCAD4E5BBD4E6B4D3E8ADCBE4A0CBE699CFEC98CAEB94C9EC92C8EC94C8EC95
C6EC97C6EB9BC5EC9DC8EA9ECEE9A2CFE69ECFE59DCFE59DD1E59ED5E5A4D6E3ABD7E0B3
FFFFE4FFFFEAFFFFF3FFFDF4FFFBF5FFFBF4EBD8D1E3D2CAFFFCF38277718B7D7AFFF6F3
FFFAF6FFF9F4B39D9036210C8473559F8F6B6F6238EEE6B8E0DCAFD9D8ACAAAB830A1300
011900B9D894D6F5B1C9EAA3C4E69CC0E598CDF2A5C2E99AC6EB9DC5EC9BC5EC9DC5EC9D
C6EB9EC6EB9EC8EAA0CAE8A0D0E69ED1E59ECFE69ECCE89EC9E99EC9E99ECCE89ECDE79E
D3E7A0D2E19C97A45FD0DF9AD8E9A3D5EBA3D1EBA2CBEA9EC7EA9AC3E996CAEB9AC6E595
CEE99AD1E99BCAE193D7EEA05C7325BED688D0EB9CD0EF9FCFF09FBEE491CAF19EC3E692
C3DD86E0F49FC4D785DEF3A498AD62CADE97D7EAAAD6E8ACCADBA5DFF1C1F4FFD8F8FFE1
F8FFE6F8FFE8F0FFE2E5F3CFCEDDA6DDECA7CDDE90D3E593D1E292637028454F13DAE3AC
D4DDA4DDE9A9D3E89DC4E093CEF3ADBDE9AE0D3D1526532CBBD9A7D2EEB3BDE1A3C0E7A8
D1F5B54967297F9356D2E6A9C8E6A6D0E4A59787549B8A56C7D597D5EBAAD4DA9EDDDDA1
D6D8999DA262656A2AD6DC9CD7E09FDBE6A4BFCB89D4E3A0
C6E59FCBEBA2C7E69ACCEB9DCAE598D4ECA2CCE09B9DAD6F83905BB9C297CCD4ADFFFFE3
D0D6B4B8BE9AD9E0B7ECF8C8D8F0B4CDEBA5C7E69AC9E898CBEB96CAEA95CAEA95CBEC9B
CDEDA2CBEBA2C8E7A1C6E59FC6E69BC8E99ACBEC9BCDEE9DCAEC9FC6E89CC4E699C6E999
C7EA9AC6E997C7EA96C9EC98C7EA98C5E898C7E99DCBEDA3C8E9A4C4E4A1CBEBAAD9F7BB
DDF8C3D1E9B5C7E0A7C5E2A2C6E49EC4E498C7E995CDF199C8EC92C6ED90C5EE92C5ED94
C3EE95C3ED97C3ED99C5EC9BC6EB9BC8EB9BC9EA9BCAE99DCBE69FCCE5A4CDE2AACFDEB3
FCFFE8E8EDD9FFFFF6FFFFFAFFFEF8FFFDF6796F66FFFFF4F7FDF3778179EFF6EFF6FBF4
FFFFF8FBFBEFFAF9E5CACAAE7C7E591117006A723FBFCC96DCEDB7CADEABCFE5B6E0F4C3
54632C121D00D1DCA0CFDD9FE2F1B0D3E4A0D5E6A0D3E79FD3E49DD1E59DD1E59DD1E59D
D1E59DD1E59DD1E59ED0E69ECDE79ECAE89EC8EA9EC5EB9EC2ED9EC2ED9EC3EC9EC6EB9E
C8E69CC7E3998DA75EC7E399CEECA2CBEDA1C6EC9FC2E99AC6EC99C6E894C4E491CFEC9A
CEE796C9E090D3E899CDE293889D4EC9E090CEE796CDEA98CCEE9ABDE38EC9F19BC9EB95
D9ED98DDEA98748131738031CAD68CDAE7A1D7E3A3D3DEA4DEE8B4EDF9C9FDFFDBFCFFDF
FCFFE4FCFFE6F9FFE5EDFCD3D0E8AAD4F0A5D5ED9FCFE497E9F9B2C4D18C79834696A063
CBD797D4E59FCEE69AD0EFA1CBF1A8CBF5B5A1CD98679360497238B8E2A3C4F2B1BEEBAA
C0E3A395AA6F373F06858851D4E2A5DDE0A7DEC394AC9664E0F0B1C2E19BCCE19EDCE8A6
E1E7A7D5DA9A909555BBC181CCD795E0ECAACADB97D7EBA6
CEEDA7C6E69DC7E69ACEEB9BCBE697C1D98BE6FAB2D3E3A2DEEDB4B5C18F5A6638939E73
A9B587CBD9A8DDEBB6D0E4A9D1ECA9C9E9A0C7E899C9EA99C9EB97C7E995C7E897C9E99E
CDEAA7CDEAAACCE8ADCCE8ADCCE8ABCCE9A7CDEBA5CCECA3CEF4A9C7F1A5C5EEA0C3EE9C
C5EF9BC4F099C4EF96C3EF96C2EC96C1ED96C5EF9DC6F1A1C3ECA0BCE69CBFE7A1C6EEA8
CDEDACC7E7A6C6E5A1C9EAA3CBEDA1C7EA9AC4EA95C6EC95C5ED94C5ED94C3EE94C3EE95
C3EE95C2EE97C3ED99C3ED99C2EC98C4EE9AC7EE9BC6EB9BC5E79DC5E3A3C9E1ADCDDFB9
F9FFECFBFFF4FEFFFAF6F7F2FAF7F29D9A93FFFFF4F4F4EAE3EAE376817DF9FFFFEDF3EF
FEFFFAEFF3E5BBBEA9EFF4D4CAD1A8545E2C77844E253700485D25728955879F6FCAE0AF
CFDCA7959E67313A01DCE6AAB6C284EAF6B6CCDB98DAE9A4D4E49DD3E49DD3E49DD3E49D
D3E49DD1E59DD1E59ED0E69ECCE89EC8EA9EC3EC9EC1ED9EBFEE9EBEEF9EC1ED9EC2ED9E
C2E79AC6E89C8FAF64C8EA9EC9EEA1C1EA9CBFEB9CC0EB9BC7ED9ACCEE9AC6E391D2ED9C
CCE594CAE191D6EB9CB2C576CDE293DEF5A5C9E291C5E290CBED99C4EA95CAF29CC9EB95
C7DE8CD0E191869749D7E79CCEDF98D5E6A0D4E4A3D3E5A7C8D9A2CEDFABD1E1B0CCDDB0
CADBAFCCDEB6CEDEB7C9DFAEC7E8A1BDE292D2F0A8C3D998BCCB90EEF9BFCCD699515C1A
78853FDFF1A7BAD087D4EFA8C1E09CBBDE9CC1E5A7C3EBAC76A2632556147FB06EC5EFAD
C7E3A6D1DFA4C6C08CA197625B5C234B420B916C3F533705B9C887CCECA3DBF0ABCDDC99
C9D492E6EFAED8E1A07A8543B7C381D0E19DD3E8A3CCE39D
C8EAA0C2E297D3F2A4CCE999D8F4A0BFD887CCE297DAEEA7CBDD9FC6D89E92A36CCADBA4
CDE1A6D3E9ABCDE3A2C4DD99C9E9A0C6E89CC7E99CCAED9DC9EA99C6E798C7E59DCBE8A6
BFD89FCBE3B1DDF3C5E9FED3EBFDD3DFF2C5CEE2B1BDD8A1BFE3A5BCE7A2BDE6A0BDE99E
C0EB9CC2EF9EC3EF9AC1EF97C3EF98C2F098C4F099C4F19EC1EC9CBCE899BFE99FC3EDA3
C6EAA0C5EA9DC9EB9FCBF0A2CCF1A3C8ED9FC4E999C3E898C5EC99C5EC99C5EC99C5EC99
C5EC99C3ED99C5EC9BC3ED99C0EC97C3EF98C6F09CC4ED9EC5E9A1C8E8A9D1EBBBDAEEC9
F7FFEEF9FFF6EAEFE9FEFFFDFFFFFB8E8E86FFFEF2FFFFF6FFFFFD716F72FFFBFFFFFDFD
FFF8F6FFFDF4CFC4B2FDF4D7AEA67FA6A273D6D4A17C7F48626935121C007D895BCDDAAC
DBEFBABDD49C31490FD6EEB2CDE6A5C9E2A0D1ECA5C7E399CAE99DCAE99DCAE99DC9E99D
C9E99DC8EA9DC8EA9EC8EA9EC9E99DC8EA9DC5EC9DC2ED9DBFEE9DBEEF9DC1EE9DC2ED9D
C5EC9DCFF1A49BBB6FD0F2A5CAF1A2BFEA9ABFEE9DC5F2A1C3E898D0F1A0C8E595CDE899
CDE597D3EA9CD2E79A93A85BD4E99CD5EC9EC5E091C8E797D1F2A1CAF09DC7EE9BC0E796
C8EA9EE0FFB583A55BC0E298D2F3ACC6E7A0B5D993CDF0ACCAEDABCBEFAFC9EDAFC3EAAB
C1E7AAC2EAAEC6ECB1C6EDAAC1EB99C8EFA0C5E3A7D9F1C1CFDEB5CEDAACD4DEA2848E49
49550BAAB76FE5F4B3C3D599D3E7ACD5EBABD4EEA5D4F2A8CEF3B087B171234D0DCDF0B0
CFE3A8DCE1A9E1D3A2E1CF9D9E955E988751A87C4F785221777C3C94AA62CBD692D8E19E
DBE7A5CDDC99DEEDAA596A26B1C580CCE19CCAE19BCEE8A1
C7E99DC6E89BD3F4A3BADA87D7F59FD2EE9AC6DF8ED3E9A0D2E7A4DAEFAEBFD595D6EFAE
D2EBA7D3EFA5C5E496CDEE9FC8E89DC6E89EC8EA9DCBEB9FC9E99DC8E69ECDEAA8D7F0B7
D3E9BBDFF0CCEEFDE0F8FFECF9FFECEFFCE2E1EED0D5E6C2CBE8B8CBEEB8CCEFB5C7EBAD
C4E9A4C5EBA2C5EC9DC4EB9AC4EC96C4EC96C5ED97C5ED97C5EC9BC5EC9DC7EDA0C9F0A1
C8ED9DC7ED9AC6EC99C5EA9AC5EA9CC5EA9DC6EB9EC7EBA1C6EAA0C6EAA0C6EAA0C6EB9E
C6EB9EC6EB9DC6EB9DC5EC9BC2E996C3ED97C8EF9CC8ED9FCBEAA6D3EFB4E4FACCF3FFE1
F9FFF3F3F8F1FEFFFDD9D9D7464541FFFFF8FFFFF4FFFFF6ADA7A9352E35FEF4FCFFFBFF
FFF3F2FFF5ECBBAC99B5A78ADDD1A9827A499D9763A7A66EE4E7B2D5DCA95D6536D4E0B2
CEE5B1C7E2ABB3CF95000F004E6829DFFCB9CBE9A3CCECA3C9E99EC8EA9DC8EA9DC6EB9D
C6EB9DC5EC9DC5EB9EC6EB9ECAE99DCCE89DC9E99DC6EB9DC3EC9DC2ED9DC3EC9DC6EB9D
C9E99DD1F0A49DB96ED3EFA4CBEB9FC0E597C2EB9CC7F0A1C1E396CDEDA1CAE69BC8E298
D0E89ED8EEA5C2D68E879B53CDE199CEE49BCEE89ECDECA0C8EA9DC3E89AC3EC9DC8EEA3
C1E4A0C0E0A1C4E4A3CEF1AFCBEEACB2D591DDFFBCB2D792BFE49FBFE7A0C2EAA3C3EDA5
C3EDA5C1ECA4BFEAA2BEE89CCBF2A3CBEFA7BBD9A3F2FFE1F5FFE4C8D7B0DFEBB9C8D095
D9DE9C585A192B2C00898C53D3DBA0D6E2A2D6E89CBBD387CEEEABC4EBAC052E00001700
809A5BD7E2A8E6E3ACE2DBA4DFE0A4E7DEA5BD976693723D7A7F3D4A5B14BEC380E7ECA9
E1F0ABC8DD98D0E5A06D823D99B06AD5ECA6C5DF98D7F1AA
CCEEA1C7EA9ACBED99BCDC87CEEC96D6F29DD4ED9AD5ED9FCEE59DD4EBA5D0E9A5C3E199
C4E397CBEC9BBBDF88D0F39FC9EB9FC9E9A0C8E89FC9E9A0CAE8A0CFE9A8DDF4BCECFFD2
F6FFE4F7FFEBF9FFF2FAFFF7FBFFF7FCFFF4FCFFF2FAFFEFF0FFE3F0FFE0ECFFD9DCF4C4
CFE8B1CBE5A6CCE7A2CBE79DC9E598CBE896CDEA98CCE997CCE997CEEB9BCFEB9ECDEC9C
C9EC98C7ED96C7EA96C4E795C4E69AC6E89EC9EAA5CBEBA8C8E8A5C8E8A5C8E8A5C8E9A4
C9E8A2C9E9A0C9E9A0C9E99DC8E998CBED99CDEC9CCCE89DCFE5A4DBECB6F2FED6FEFFE8
F5F5E9FFFEFBFFFDFFB5ACAFB5ABAAFFFDF8FFF6ECFFFAF1EEEAEB706E73FFFDFFF4EEF0
FFFCFAFFFDF3DDD2BECCC3A4DBD7AAECEBB5D4D59C90965A545C23DDE7B2000B005E6E3F
CEE0AECEE2ADC9DEA696AB722E4207CAE0A0B7CD8CD4EEA7CDE79ECCE89ECCE89DCAE99D
C9E99DC8EA9DC8EA9ECAE89ED1E59DD4E49DD1E59DCFE79DCCE89DCAE99DCCE89DCDE79D
CFE39BD3E49D9BAB64D1E29BCFE59CC8E298C8E79BC9E99DC7E79ECAEAA1CEE9A2C7E19A
D2E9A3D0E5A0A6BA758A9E59D5EAA5D0E7A1D3EEA7CAEAA1BEE298C1E79CC5EEA2CCEFAB
D7EEB8D2E2B384946394A672BFD29BE3F8BFD2E8AACBE4A3C9E2A0C8E39CCBE79DCDEC9E
CEED9FCBEA9AC8E895C6E599CAE4A5C5E0A9C5E2ACF0FFDCECFFDBCAE3BBE2F2CDD0D6B0
DCD7ADFFFFD163541B695E1E56510DD1D48DD8E39EDDF2AFBBD898CEF5B6C6F3B0ACDB97
527D38BEE19FD2EBAAD0E9A7D7F8B1CCDF9D9A8B5276662BC5D28D82964EABAE6BCCCF8C
C6DA93CAE59EC6E19A95B06986A059C9E39CCAE49DC9E39C
C9EB9EC2E595C9EA99D6F8A4CAEA95C2DF8BD0EB9AC9E495CCE69CCAE69CD4F2A8BCDC91
CDEE9FD9FCAAB9DF88C9EF98CDEDA1CBE99FC9E79DC8E69CCBE69FD4EDABE9FEC6F8FFDD
F9FFE8FBFFF1FCFFFAFFFFFFFFFEFFFFFEFFFFFEFFFFFFFBFBFFF6F8FFF1F7FFEBE3F3CF
D1E2B6CCDEAACFE3A8D1E6A5CEE39ED1E79ED4E8A0D3E89DD2E79CD2E79CD0E49CCCE496
C6E691C7EB93CAEC98CAEA9EC9E9A0CAE9A5CBEAA7CAE8A8C9E8A5C9E8A4C9E8A2C9E8A2
C9E8A2C9E8A2C8E9A4C8EAA0CCED9CCFEE9ECFEBA0CCE39FCCDDA6DAE5BAF3F8D8FFFFED
FFFFF6FFF9F8FFF8F9B0A4A6FFF7F7FFFCF8F6ECE3FFFDF6E6E2E367656AFFFEFFFFFEFF
FCF9F4FDF7EBF3E8D2E3DDBBD1D9A6DBE9ACD8E2A3DAE5A3D9E5A76A783D7B8C55102100
1523006D7947D0DCAACDDAA5AFBD881C2D007B8F52CFE5A5CDE6A2CCE7A0CCE89ECAE99D
C9E99DC8EA9DC8EA9DCAE99DD3E49DD6E39DD3E49DD0E69DCDE79DCDE79DCFE79DD0E69D
D6E69FD4E19B98A35ED1DE98D6E7A0D3E9A0D1EBA1CCEAA0CFF1A7C8E9A2D0EEA8CAE39F
D4E9A8C4D79791A16292A063D5E5A7C9DD9ECFE8A7CDEAA8CBEBAAD0F3AFC8EDAAC1DFA3
D4E6B6CBD6ACCAD2A9C3CBA2FEFFDCEEF7CAF6FFD0FBFFD3D8EAAED2E9A5CDE79ECBE79A
CBE896CAE793CAE892CBE79AC8E2A5E8FFCAEFFFD2F1FFD4EBFFD2C6E0B0C8DAB4E0EAC5
E0E1B9DED8A8DED59A625B175F5810A19D56E2E1A1D5DDA1D1EBAAC2E9A6BBE8A5C2F3B1
74A86696C987C5F1B2BEE8A8B0DF9BD1EFAFBBB47D90874CD3E7A0CCE49A807C3CE1DC9C
D9E8A3D1EBA4C5DF98CDE7A0B1CB84C9E39CDCF6AFC7E19A
CBEB9FC5E599C5E697CBEC9DCFF0A1CAE99BC9E89ACBEA9CCAE99DCDECA0CCECA0C8E89C
C6E69AC9EA9BC9EC9CCAEB9ACCE89BCCE89BCCE999CCE999CDE899CDE79ECFE5A7D0E2B0
FBFFE4F5FDE8FFFFFAFFFDFFFFF9FFFFFBFFFFF8FFFFF9FFFCFFFFF7FFFEF6FFF4F7FFEC
F2FFDEE4F5C8D4E6B2CCDFA7D4E6ACCFE1A5DDECB1CEDEA0DFEDB0CBD99BCCD898DCEDA6
CCE894C8E992D8F7A9B9D78FC7E1A2CEE8ABD1EBACC8E3A0BCDA90DAFBACBFE08FCEF19F
CAEFA2C9EFA6B5DC99CFF7B1C8EF9EC0E693CAEBA4C3DCA2D2E3B7DFE8CBFFFFF1FFFFF6
FFFCF9FFFCFBABA19FFFF8F6FFFCFAFFF9F3FFFEF8FFFBF88A81841E181AFFFBFCFFFFFB
FFFFF8FFFFF1AE9E87D4CEAAC4E0A5BDE39ACEE89ED6E89ED1E29BCBDC98C4D998D1E0A5
DBE0AA5153212C2E003E44189AA378617144637746CBE4ADC8E6A8CAEBA6C7EC9FC3EA9B
C5EC9BC8F2A0C5EF9DC1E698CCE89DCFE79DCCE89DCAE99DC9E99DC9E99DCAE99DCDE79D
D3E79FD5E59E97A45ED6E69FCFE59CCAE49AC5E599C4E99BC6EFA1C5EBA0C5E49EC8DE9D
D3E3A5DCE5AC777E48A2A975DAE2AFCBD7A5D4E6B2C8DFA9D1E9B5CDE8B1CEE9B4C5DDA9
CCE0AFCFDEB3C1CCA4C5CCAAF8FBDCF6F9DAFFFFE3FBFFDED1E3B1CBE4AAC8E9A4C8ECA2
C7EC9EC3EA99C5EA9AC9EEA1C4E9A3D8FBB7F2FFCBF7FFCDECFEC2DCEBB0D0E1AACDE1A6
CBE3A5D0E9A8C4D996DCEBA656581762581BE7D09AE8DDA5D0E7A1BBE39ACEF3B0C6EFB3
7AAF775089547BB481B4E6B3C3EDBBC5DBAAD7CC9FD2C895D6EDA9859C56A2965AEEDBA1
D0D293E0EFACCEDF9BCADE9991A560CEE59FCEE8A1CFEAA3
CCECA0C9E99DD0F0A4C7E79BCAEA9EC0E094CCECA0D1F1A5C7E79BC3E397C4E498C9E99D
CBEB9FC9E99DC8E89CCBEA9ECCE89BCCE999CDE897CCE995CDE897CDE89BCFE5A4D0E3AC
F9FFE3F1F9E2FFFFF8FFFAFEFDF5FFFFFAFFFFF9FFFFFAFFF6F6FFF6FDFFF9FFFDF9FFF4
F6FFE7E3F1CDD6E5BAD2E2B3C6D6A7CAD7A9DBE7B7D7E3B3D3DDA9CDD7A2ACB57C596825
B7CE7CBDD984D6F0A6DBF4B2D4E9B0D2E7AFC7DCA3D4EAAAD8F2A8C6E391D5F5A0B7D983
C1E696CBF1A8C7EEADB8E09AC9F3A1BFE693CAEBA6D2EDB6F3FFDFF1F9E2FCFCF2FEF9F5
FEF6F4B3A9A8BDB3B1F6EFE9FFFEF8FFFDF9FFFDFAFFFDFD0C0105887F82FFFEFDF8F7F3
ECEEE3FFFCECFFE9D4B5AD88D2F6B6BEEFA0DCFBADCBE091C7D98FC9DD9595AC668D9D5E
E0E3AAD4D19ECCCB9D5A5C347C845D9CA880778A5D284310C8E5ABC6E9A5C3E99EBEE596
BBE593BFE997C3ED9BC7EE9FCAE99DCAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D2E69EC3D48D91A15AD5E69FCFE79DCAE69BCAEC9FC5EC9DBDEA99BFEA9BCAEAA1D2E9A5
DBE6AADBE0A8737543A2A473D9DFB1D9E2B5D6E6B7CBDEB0D1E4B6D0E6B7E2F8C9F3FFDA
F7FFDAEDFED2AFB994929779FFFFEAFFFFECFFFFEAFCFFE4D6E9BCCCE7B0C6E9A7C5EDA4
C5EEA2C3EC9EC2EB9DC4ED9FBEEA9FC6EEA5D4EFAAD9ECAAD9E5A5D5E1A1D1E1A0CDE6A2
C1E59DCFF7AEC9EFA6CBE6A1939C5D6A5F27A18351F1DEA6D0E49CCAF0A3CAEDA9BDE5A9
B2E7B16FA97939724583B88CB8E3B6D6EBC0B2A67E8A804FCAE3A194AB65BBAC71DBC68D
EBF0B0C1D28ECFE39EDFF3AECDE29D485F19CDE7A0C7E29B
BEDD91C9E89CC1E094D6F5A9C8E79BD8F7ABC3E296C0DF93CEEDA1C6E599C5E498CDECA0
D0EFA3C9E89CC5E498C8E79BCAE99DCAE99BCCE997CAEA97CCE997CCE89BCCE7A2CDE4AC
F7FFDFF5FFE8FCFFF6FFFFFDFBF9FEFFFBFFFFF9FFFFFCFFFEFEFFFBFFFFF6FCFAF8FFF3
FBFFEFFBFFE8FAFFE5FAFFE2FBFFE3F4FEDBF7FFDCFCFFDFBCC59A9EA876C3CD98B0BF7E
91A657ADC472BCD089C6D89ACDDBA6FBFFD6E5F3BED2E4AAE0F3B1C6DC93D3EC9BD5F09F
CDEC9EBFDF96D9F8B5C2E39EC2E895C8ED9DCFEEAAD1EAB3F8FFE4FCFFEDFFFFF6FFFEFA
B3ABA9E8E0DEFFFDFAFFFAF7FEF9F5FFFBF8F1EDEAAFABAA574E51C5BCBFFFFDFCFFFFFB
FFFFF6FFFCEDFDE2CFE2D5B2B9D799BAE699C4DF92DDF0A1DBEDA3C6DC93D1EBA4D8EBA9
878D51201F00505221767C50A8B087636F473243173C5422C4E0A6C5E5A2CBEDA3CCF1A3
C9EE9EC4E999C5EA9CCBEDA0CAE99DCAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
CFE39BA7B8718D9D56D3E49DCDE59BCAE69BCEF0A3C3EA99C7F2A0C2EC9AC6E69ACBE29A
D3DF9FDDE2A88E915CD3D5A3DDE3B3F0F9CAE1F1C2DDF1C0E0F4C3DBF1C0E6FAC9F7FFDA
F5FFD9F9FFDDDAE4C1D7DBC0C9C8B3F0EFDADCDEC6EDF7D5E2F3C7D2EDB6C6E9A7C3EBA2
C6EFA3C4ED9FC4EA9DC2EB9DC2EEA3C0E89FC2E19BC7DE9ACEDE9DD2E2A1D1E6A3CCEAA4
C5EBA2B7E197D1F9B0B5D38DE4EEAFD2CC926A501D897840D4E69CCCF1A3C9EEA8B5DFA0
D1FFCCA1D7A537683B528155BFEDBECBE5B6B2A97E8B8150E2F8B7C4D994796F3265591D
6F803CD9F9B0BDDD94C5E59CD1EFA7BDDB937E9952D0EBA4
D3EFA4D3F2A6CCE89DC7E69AC3DF94CCEB9FCDE99ECBEA9ECBE79CC9E89CCBE79CCAE99D
CCE89DC9E89CCBE79CCAE99DCAE99DCAE99DCAE999CAEA97CAEA97CAE99BCCE7A0CCE6A9
F3FFDBEDFEDEF9FFF3FCFFFAFBFDFCFFFEFFFFFBFFFFFCFFFBFAFFF8F9FEFBFDFCFEFFFA
FEFFF4FEFFEFFCFFEFFCFFEDF8FFE9FCFFEDF1FADFEAF3D487916C808B60D2DCA8DCEAAC
87994DAEC170D2E19CDDEBAEE6F0BEFBFFD7C4CDA0929C6AA7B278E2F1B0CADB94C8DD92
D8F0A4D1EBA2C8E29BD2EEA4C2E392D2F3A4CDEAA8C4DBA7F9FFE4FEFFEDFDFDF3F2EFEA
AEA9A6FEF6F4FFFDFBF3EEEAFFFEFBFFFFFDFFFFFD312F30DCD8D9FDF9FAFCF8F7F8F7F3
FFFFF6FFFCEFE9CAB8D5C2A1E4FCC0B8DE93DBF1A6CDDE90CEE096DDF3AAB5D089D0E7A3
AFB879AFB076989C69444A1A9BA479A7B4894E5F323C501DCEE7ADC9E6A6C9E8A2CEEEA3
CCECA0C6E69AC6E69BCCEAA0CCE89DCAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
CFE39B8FA05990A059D1E29BCCE49AC7E398CEF0A3BFE695BEEA95C0EA94CDEE9FD5ECA4
D5E19FCED49872753EB3B583E8EFBCFEFFD8F8FFD9F8FFDAF7FFDAF5FFDAEDFFD2F4FFD9
F8FFDCF8FFDED9E3C1DADEC3999883DAD9C4D2D4BCE1EBC9F2FFD7DDF6BFCAEAA9C3E9A0
C6ECA1C6EC9FC6EB9EC4EA9DC6F0A6C3EDA3C8E7A1CDE6A2D4E7A5D5E8A6D0E7A3C7E6A0
B9E198D3FDB3BDE59CC8E7A1D9E8A7BDBB80937E49594A11D8E89FC3E397CAF2A9B9E8A4
BBEDB0C6F6C28AB486477143BDECB8C8E8B6DDD6AAC9BF8EC6D999D8EDA8ADA96A6D6929
455610C2E098D5F0A9C2DD96C4DB95CEE39E445813D8E9A5
C8E298C6E297E4FEB4BFDB90D9F3A9BBD78CDAF4AAD3EFA4C5DF95CEEA9FD0EAA0C6E297
C5DF95CDE99ED3EDA3CFEBA0CCE89ECCE89ECAE99BCAEA97CAEA97CAE999CAE89ECCE6A7
D1E9B9D2E6C3F0FFE8F8FFF5F7FEF7FCFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFD
F8F9F3F2F3EBF8F9F1FFFFF8D2D5CEB7BAB19EA496FCFFEDFCFFE6D5E1B9CFDBABD0DEA1
DCEA9F99A75A97A260B2BB82D2D8AAC4C9A1D2D4ADFCFFD8DEE4B4656E35BDC989D2E19C
CFE099C9DE93D6EAA2CDE599D1EE9ECFEBA0C9E1A3CFE1B1FBFFE4F7FCE8D6D6CEC4C0BD
FFFDFDF7F2EFFFFEFBFFFEFBFFFFFDFFFFFD5C5C5EB3B3B5F6F4F5FFFEFFFCFBF9FFFDFA
FDF6EEFFFBEFE0BBAB9B8263A6B87EC1E198CFE197DBE99CD6E89ECDE59BD6F4ACC6E099
D8E3A1C0C686E2EAB19AA26F959E71DDEABE89996C051700EBFFC7DAF2B4CBE4A0C5DF98
C5DF96C7E19ACBE4A0CFE9A2CCE89ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D2E69E869750A1B16AD2E39CCFE79DC6E297CDEFA2BFE695C0EA94C2EA94CCEB9DD4EAA1
D7E3A1D5DB9F7A7D46B8BC89E3EBBADFEBBBEBFBCCE3F4C7DCEFC1E2F5C7E5F6CAEFFFD4
E3F2C7E5F1CBDBE2C1B5B79FD6D5C0DCDBC6E6E8D0EDF7D5F8FFDCE3FCC3CBEBA8C3E79D
C5EA9DC7EC9EC9E99EC8EA9EC0EAA0C3EBA2CBECA5D2EBA7D4E9A6D1E6A3CAE39FC3E29C
C9F1A8ACD68CD1F9B0D7F6B0C6D594D1D195665720655B20D9E59DC6E295C2EEA1C3F5AC
ABDC9BC9F2BAD1F1C0668758001500729761949164837948DEECAED4E8A3C9CE8BD8D997
676C2A828B4AB6BC7CEAF0B0D4D697E3E3A5E6E4A7A09E61
D5EFA5CBE59BBCD68CCAE49ACCE69CD6F0A6C8E298C5DF95D0EAA0D7F1A7D6F0A6CDE79D
C9E399CEE89ED0EAA0CCE69DCDE7A0CDE79ECCE89BCCE999CCE997CCE997CCE89DCCE6A5
C7DEAACCE1BAEFFFE4F8FFF3F9FFF6FCFFFAFDFFFAFFFFFDFFFEFFFDF7F9F8F2F2FFFCFC
FFFEFBFFFEFDFFFCFDF3F1F4808082D8DAD9F0F5EEFCFFF3F1FBE0DBE7BFD7E8B4D8E8AA
CAD88DE8F4A8DBE6A45E652F464C208F916CECEDCDFFFFE1E8EAC2CCCFA04E551FE2ECAD
DCE9A4D5E59CC8D88DDEF3A6D3EB9DCAE199D4E8ADE0EDC1EEF7D8C4C7B6C4C4BCE4E0DD
FDF7F7FFFDFDFFFDFAF8F4F3FFFFFD00010055565AFEFFFFFEFFFFEDEDEDFFFFFDFFFEFB
FFF9F2FFFAEFD0A497A58669C5D098A1BC75D3E098D6E296D5E79DD6EEA4B3D38AD7F5AD
DCECA5ECF7B3D1DB9E88935B9DA979DAE7B96A7749627241F8FFD3EDFFC4DEF3B0D3E8A3
D4E9A4D9ECAAD5E8A8CCE19ECDE79ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D5E9A18B9C55BBCB84D4E59ED5EDA3C8E499CCEEA1C3EA99C8F29EC5EC99C4E395C8DE96
D7E3A3E6EEB3959863CED2A00C1400000B0089986DCADBAFD6E8BED4E5BBCDDEB4CCDBB2
C5D4ABD3DFB9E9F0D1E3E6CBDFDEC9D2D1BCFEFFE6F6FFDDF6FFDAE0F9BFCBECA7C3E79D
C5EA9DC8EA9DCAE89EC9E99EC1E79EC4EAA1CAE9A3CEE7A3CEE3A0CDE29FCCE5A1CCEAA4
C8ECA4BFE59CBADE96CCE7A2E4F3B2EFF0B45D5019564C11D9E09AD1EC9FB6E595C6FAAF
BCE9A4BCE0A3D4EBB789A5725F9058113A0269683A5E5325C8D397D1E5A0DBE6A1E7EEAA
E5E7A68E8E50575719D5D597E3E1A4E4E2A5E1DDA0969255
869E54758D434C641A869E548AA258C9E197C2DA90DCF4AACCE49AC2DA90C2DA90CEE69C
D4ECA2CEE69CCAE298CDE49CD0E5A2D0E5A0D0E69DCFE799CFE897CDE897CDE89BCDE6A2
D0E5ADD6E7BDF8FFE8F9FFEFFBFFF3FEFFF8FBFEF7FFFFFAFBF6F2D1C9C6A39B989A928F
B3ABA9D5CCCFEBE4EBF5EFF9FFFDFFFFFEFFFEFFFFFAFFF4FBFFEAD4E3B8C5D8A1D1E6A3
E1F3A7CEDE93CFDB9BCCD59EE8EFC3FFFFE1FFFFE6FFFFE4F8F9D9D4D6AFE3E9B9808950
BECA88DEEEA5CDDD92CFE293CEE398D1E4A2E8F7C0DDE8BECCD2B6AFB2A1DBDBD3FFFEFB
FFFEFDFAF6F5FFFEFDFCFBF9828282333436FCFDFFFCFFFFFCFFFFF5F7F6FFFFFDFAF6F3
FBF0EAFFF9EFD3A598BA977BE4EBB5A5BC7687934BA8B367CEDE95D2EAA0CBEDA3C7E79E
C1D78CDFEFA6D0DF9EB5C388A3B17CCAD8A75E6C3BB3C18EE8F7C0E7F6BBDAE8AACAD998
CBDA99DAE6A6DBE6AACEDE9FCFE69ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D2E69E92A35CD0E099D2E39CD8F0A6C7E398C8EA9DC8ED9FBEE594C5EA9CCFEBA1D3E6A4
DCE7ABD5DCA6585A2B6B6E43757C530008008B9A73C6D6B1CCDCB8C9D9B5DDEBC8F3FFDB
F8FFDCE7F2CADADFBFF9FCE1B4B49CC3C3ABFFFFE6F7FFDAE6F8C6D5EFB2C8E7A1C7E99D
CAEC9FCAEA9ECBE79DCAE69CC9E8A2C9E8A2CCE5A1CEE3A0D1E1A0D3E3A2D3E8A5D3ECA8
D2F1ABC5E69FDDFBB5B2C985C7D192DCDCA05E531BA49A5FDEE19ED2E89DB8E997C2F9A8
C3EDA5C4E1A1CCDBA493A772B6E8AB05310037390A625A2BD9E2A9DEF1AFC9DD95D9E9A2
CDD693BDC383878D4D3A43027E8947D0DB99D7E3A1DBEAA7
D1E99FC4DC92DEF6ACCAE298CBE3998BA3598FA75D8EA65CAAC27892AA6098B066C0D88E
D7EFA5CDE59BC8E096D6ECA4D1E4A2D3E3A2D3E49DD3E599D1E697D0E797D0E69BD0E5A0
CDDEA7D3E3B6F7FFE2FCFFEDFAFEEFFFFFF6FFFFF7FFFFF6DED7CDEDE4DBFFF8F1FFFDF8
FFFCFBFFF8FCFFF7FFFFFBFFFFFCFFF5F4FCFEFFFFF6FEEFF8FFE7D7E8BBCBE0A5CEE59F
C9E092D1E69BD7E7A6DAE7AFCDD9ABECF4CFECF1D3FFFFEAE7EACFFBFEDFD8DFB6BAC291
949F63879651B7C77CD3E599D4E59FDFEFB1F0FCCCD5DDB8CACEB7CFD0C2F8F5F0FFFEFD
FAF6F5FFFEFDFFFFFD878785000000FCFDFFFCFFFFF7FBFEF3F7F8FCFFFFE6E6E4FFFEFB
FFFCF6B49990C6968AC19C81D4D9A3D6EBA6D7E19A9AA25791A158C5DF95CDEFA5C6E89C
D5ED9FD2E79ACBDF9AD9E9AB92A16A97A57242501FE4F0BED3E0AACFDAA0B5C18396A061
97A162BBC387D5DDA2D8E4A6CFE6A0CAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
CCE09894A55EDAEAA3CEDF98D7EFA5C5E196C3E598C9EEA0C3E89BCBEDA3CFE8A6CDDFA1
D5DEA9CBCE9F3A3D123C3E17D8DEBA030D00919F7ED1E0BFDAE9CAD0DDBFE4EFD1F9FFE2
F0FCD4FCFFDDFDFFE1F9FCDDD0D0B69E9E82F8FEDCFBFFDDD6EBB3CCE6A7C6E69DC9EB9F
CEEEA2CCEB9FCBE59CC9E39CCDE6A2CEE5A1CFE2A0D1E1A0D4E3A2D5E4A3D3E3A2CEE3A0
D0E9A5C4DD99CBE29EE1F1B0E2E8AA99975C7F743CC8BF84E4E6A5C4DA91C4F5A3BFF6A2
B4DD8FD8F1ADD9E3A7889962B9E9AB8AB67B202100665E30818A53778C4BD3EDA4CCE299
E2EFAAD0DB99CCD79574803E52611EC6DA95DBF0ABCDE49E
CFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCDE59B8FA75D556D23768E44
96AE6498B066BFD78DDCF2AAD0DEA0DBE5A6D7E49ECFDD92D5E696DCED9DC0D08596A562
6D7A42CEDAACFEFFE4FBFEE9FFFFF3FFFFF6F9F4EEDCD5CDE9E1D4FAF2E5FFFEF3FFFDF4
FFF9F5FFFAFBFFFBFFFFFBFFFFFBFFFFFDFFFDFFFCF8FFF0F8FFE4CFE3B0CEE7A5CCE89D
CCE798CAE598CDE6A2D3E8ADD0E2B0D0DFB6E5EECFFBFFE9FEFFECF1F7DDEBF5D3D5E0B6
CBD9A49CAC6D91A25C8A9B55CCDA9C97A16DE2EBC0E2E7C7E5E8D5E5E5DBFFFEFBFFFEFD
F9F5F4FFFEFDF8F7F3797977717171FDFEFFFEFFFFF9FAFEFCFFFFFCFFFFF3F3F1FFFEFB
E0D5CFC3A89FE6B6AAD0AB90D7DCA6D1E6A1D7E19ABDC57A54641BBAD48AD2F4AAC0E598
D1EC9BD2E999CBE199D3E6A68F9E6772804B000B00E7F1BDCBD5A0E4EDB4929A5E727B3C
777F437A80448B9056DCE6A9D0E5A0CAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D2E69E90A15AD2E29BD8E9A2C9E197CDE99EC5E79AC8EDA0C8ECA4CAE9A6C3DB9FDEEFB8
D8E0B170724A1D1F00868A699097786B7658A4B195E0EED4E3EFD7E9F5DDF3FBE4FCFFE8
E5F1C9E7F4C8EDF5CEF0F6D2E4E7C8C4C8A7EEF6CFE7F4C6CDE5ABCAE7A4C8EAA0C8EA9D
C9E99DCCE89DCFE69ED0E5A0D1E1A0D1E09FB4C08099A364B5BE7FDAE4A5DDE9A9CDDC9B
CADA99D4E4A3CBDA99DBE5A6DFE0A4A49F659F945CE5DCA3DADC9DCEE49CC3F5A0C2F8A0
C8EF9ED1E79EC7CD8DA0AE71C3EFB0A1C88F26270050471EBBC590637C3B89A75DCFE99F
D5E49FD3DE9CE1ECAABBC7856B7A37A9BD78D3E8A3C7DE98
CFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCAE298CEE69CC2DA90D2EAA0
D7EFA5C3DB91B0C87E8FA55D838F51424C0F39440079853B93A1527C8A3B93A156D5E29D
D1DCA2777E528A8D6EB9B8A4D8D4C8C3BCB4A89F9AFFFDF6FBF3E6FFFEEEFFFFF1FFFEF3
FFFAF5FFFAF9FFFBFFFFFBFFFFFAFFFFFEFFFDFFFAF8FFECF8FFE1CDE4ACCDE8A3CAE99B
C9EA9BC7E899CBE9A1CDEAA8CBE4ABCFE2B5E3F3CFF9FFEAF5FEE9F9FFEDF7FFE8D2E0BD
D5E4B9CEDFA9C5D799A5B5769DAA748F986BF2F8D4FFFFEAFFFFF3FFFFF8FFFEFDFFFCFD
FFFEFDF7F3F2D5D4D0585753FFFFFDFEFFFFFFFEFFFEFFFFEEEFF1FBFDFCFFFFFDD8D4D1
B0A59FFFF9EFECBEB1C19E82DEE5AFCFE6A0DAE69ECBD68AABBB72EBFFB9BDDF95CBF0A3
CDEA98CEE796C9E197D8EDAC90A268596732000900D2DCA8E5EEB9DBE3AA8B9155A1A769
DCE2A6CCD29695985FA0AA6DD0E69ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D1E59D94A55ED4E49DDBECA5CFE79DD1EDA2C7E99CC6EAA0D0F0ADB7D396E5FAC2D1DFAC
61683E60623B87886696997A2B3115788267DBE8CEF8FFEDF9FFEDEEF8E0F3F8E2FCFFE8
CADAADDFF0BCC0CBA0D3DBB2FFFFDFB8C099CCD7ACD9EBB7CCE6A7C9E8A2C6EB9EC6EB9D
C9E99DCCE89ECFE6A0D1E5A0D7E1A2F0F9BA414A0B8F9557797F412A33008F9859869051
7D8949E6F2B2D7E0A1DDE3A5DBDB9F938E54AA9F67DBD59BE2E8AAD0E79FBCEC98B5EA90
C2E68FD7EC9DDFE4A1C8D295BFE5A8C0E3AD6E6A44140B00C6D4A1DFFCBCCDECA6809C52
C0CF8CC4CD8CDEE7A6DCE5A4ABB67455601EDAE6A4E3EFAD
CDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCAE49ADCF6ACD3EDA3CAE49A
CBE59BD3EDA3D7F1A7C2D890A8B47697A1648B9652909D559AA859A7B566BFCD80D7E49F
DEE7AEB0B78B7F8061ABA895D4CDC3C8BFBAE4D9D7FDF2EEFFFFF1FFFFEFFFFFF1FFFFF3
FFFAF3FFFBFAFFFBFFFFFBFFFFFBFFFFFEFFFDFFF7F8FFEAF7FFDFCDE5A9CBE99FC9EA99
C6EB9BC5EC9BC8EDA0CAEBA4C6E4A6CCE4B0E2F7CEF7FFEAF3FFEAF9FFF3F9FFF1DBE7CF
E4F2D1EEFFD5E3F5C1BACB95D3DCAFCAD0AAFFFFE6F7FAE7FFFFF6F7F6F2FDFBFCFFFEFF
FFFFFDF5F4F2706F6BBFBEBAFFFFFBFFFFFDE2E0E3FFFFFFFFFFFFFFFFFFFFFFFD95918E
C6BDB6FFF3E8CB9F92DBBC9FDCE7AFC0DB94DBE8A0D6E296E4F6ACC3DB91C1E198CCEEA2
C5E592D3F09EC6E096C7DD9C9BAD7399A772495523CDD7A3CDD69FDDE5AA979D5F949A5A
D7DD9FE2E8ACA5AA70858F52D0E69ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
C9DD9594A55ECEDE97D5E69FCDE59BCFEBA0C5E79AC1E59BC7E7A6CCE8AED7EBB68C9A69
030A00F4F6D15455359A9D7E3E4428535D42ECF9DDF2FFE6F0FDE3FBFFECFCFFEAEEF8D6
D6E7B3CADEA3F1FFCCC9D5A5D4E0B2B1BD8FCCDDA9C4D99ECAE7A4C8EA9EC6EB9BC6EB9B
C9E99DCAE89ECFE6A0D3E3A2DCE5A6CCD093585C1FE7EDAFC4CA8C5A63244952133D4607
3B4405B1BA7BD8DC9FCFD094DADA9EB0AB719E985EE3E3A7D9E5A7CBE69FC2ED9BC0EE94
C6E98FD4EA97D9DF97C2CB8CD7F6BAC7E2AFA9A07F332906A6B888C0E2A5BEDF9AD1EBA4
899452EBEDAEDADC9DE0E0A2E8E6A97F7B3EACA66AACA66A
CDE79DCCE89DCDE79DCCE89DCDE79DCCE89DCDE79DCCE89DCBE59BCBE79CC7E197C6E297
C6E096C6E297D1EBA1D7EEA6DAEAACDBE9ABDAE9A6D6E89ED3E695D3E695D4E798D5E49F
DFEAB0CED5A9E5E8C9ECE9D8FFF9F1FFFCFAFAEEEEFFFCFAFFFFF6FFFFF3FFFEF1FFFBF0
FFFCF6FFFDFBFFFCFFFFFDFFFFFCFFFFFFFDFDFFF5F8FFE9F7FFDDCCE6A9CBE99FC8EB99
C5EC9BC4ED9EC8EFA0C7EBA1C5E4A0CAE6ABE2F8CAF7FFE6F8FFEFF9FFF4F5FFF2F1FCEC
F6FFECF2FFE3E7F5D1D9E5BDE1E9C4E6EBCDFFFFECF4F6E8FFFFFAFDFBFCFCFAFDFFFEFF
F6F4F592918D010000FEFDF8FFFFFAFFFEFBFFFEFFEEEAEBFAF8F9CFCDCEA09F9DFFFEFB
FFFEF6FFFBEFFFE3D3B09778D0E2A8BADA91DBEDA3D7E598DAECA25F772DDAF8B0C6E69B
C0E28ED1F19ED3EFA5D0E9A792A56DAEBC87323E0C6F7945DAE1ABDAE2A7A7AD6FA7AD6D
B6BC7C919759969C60D8E4A4CFE69ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
CBDF979EAF68CDDD96CFE099CBE399CCE89DC7E99CC4E69CC6E4A4C0D9A0596B374F5B2B
D6DBB2D5D7B0989977D7DBBA9FA685000700E6F4D3F9FFE6F9FFE4FCFFE6E3E8CAC7CFA8
C5D99E91A7666A7C4293A26BB7C59084955FCDE2A7CEE8A7C9E9A0C6EB9DC5EC99C5EC99
C8EB9BCAE89ECFE6A2D3E3A2D9E2A39A9E614F5517D9E2A3D2DC9DC7D192D5DFA0C7D192
9FA869777D3F616528A6A76BD9DA9E98985C858549E1E7ABCDDFA1C6E3A0C6F09EC9F49B
CBEC91D0E78FCED68BB7C07FC7DFA5D4E4B7A3947737290C667E4ED3F9BEC6E6A5CDE6A2
7C8B48D1DC9AD7E09FC8CE8EE2E7A7D1D193928E51686226
CCE89DCAE99DCCE89DCAE99DCCE89DCAE99DCCE89DCAE99DCEEA9FC5E498CFEBA0D6F5A9
D6F2A7C6E599BFDB90C6E298CFE5A5C5DB9AC5DC96D0E89CD3EC99CAE390CAE392D3E9A1
D1E3A9D2DDB2FEFFE6FFFFF1FFFFF8FFFDFDFAF1F4FFFDFFFDFEF9FAFDF6FAFBF5FEFDF8
FFFFFAFFFEFBFFFDFFFFFCFEFFFDFEFFFFFDFDFFF5F8FFE9F7FFDFCCE5ACCAE9A3C6EB9D
C5EC9DC5EE9FC7EE9DC6EB9DC5E59CCCE6A5E0F4C1F3FFDEF9FFEFF5FDF0F6FDF6FBFFFB
FBFFF8FAFFF3F4FEE6FAFFE8E8EED4F4F8E1FFFFF1F7F8F0FFFFFDFFFFFFFCFBFFFBFAFF
FFFEFF01000066635CFCF9F2FFFCF5F9F4F0F1EBEBFFFDFFA59FA1797576FFFEFDFFFFFB
F8F4EBFFF3E6C2A391A89574CBE3A7C7EDA2D4EA9FD5E698CCDE945F752CCCE7A0C8E69C
D7F8A7BFE08FC3E197D2EDAA83985FCDDEAA778351D4DEAACDD59CCDD5999CA56487904D
8B94516B74338D9657DBEAA9CFE69ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D8ECA4B5C67FD7E7A0D2E39CCEE69CCDE99ECDEFA2CBEDA3C8E7A4D7F1B4000E0096A36E
E0E6B8979A6FE3E8BFC4CBA2D6E1B9000800DFEEC5F9FFDFE1EDC5CED6AFDBE0B8D9E2B3
D7ECAB8CA35BC6DB9AEBFDBFC3D599CFE3A6D6EFAEC1E09AC6EB9DC3ED99C3ED97C3ED97
C6EB9BCAE89ECFE6A2D3E3A4959E5F565C1E99A263E7F3B3C9D897DFEFAED5E5A4C5D493
D5E1A1CFD99A4C5516505618474D0F333C00B4BD7EC3D193CFE9AAC5E5A2C4E99BC6EA92
C5E789D1EA8FDBE99AD4DF9B51622BD5DCB3DCC6AE66583E28451790BB83CDEBADC6E19E
C3E19B81A158CFEDA5D7F2ABD3EDA6D6EBA6D0E19D98A764
CAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCAE99DCFEEA2C6E599C9E89CC0DF93
C3E296D0EFA3CEEDA1D5F3A9C9E6A4D4F1AED0F0A7C2E394C4E690D4F49FD2F29FC3DF95
C4D99EE4F4C7ECF7D9FDFFF2F6F7F1F6F2F3FFFCFFFBF6FCFEFFFFFBFFFFFDFFFEFFFFFD
FFFFFDFFFEFDFFFAFCFFFCFDFFFDFEFFFFFBFDFFF5F6FFEAF7FFE1CCE5AECAE9A6C6EAA0
C5EB9EC6ED9EC7ED9AC7EA98C7E698CEE7A3DBEEB6E5F4CBECF6DEFCFFF8FEFFFFFEFFFF
F9FBFAFEFFFBFEFFF6FEFFF3FFFFEFFFFFEFFFFFF6F2F3EEFCFCFEFDFCFFFCFBFFFDFCFF
858384656460ECE9E2FFFFF6FFFEF8FFFBF5F8F0EE908788E7DCE0FFFCFFFBF7F6F4F3EF
FEFEF4FFFEEFB29784AA9D7AC6E4A6D0FCAFC4DF92D0E394D5E79DBDD38A97B16ACBE69F
C7E899BBDE8EC9E9A0D9F3B28A9F66D7E8B4727E4C76804CDCE5ACE1E9AD9DA6656D7633
A4AD6AC9D490DAE5A3CEDD9ACFE69ECAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
D1E59DBECF88DCECA5D4E59ED0E89ECAE69BCCEEA1CAECA0CDECA84B6423000C00D2DFA7
D4DBA7848856DBE1B1EAF2C35C683A657546F3FFD4F0FFCFEBF9C8D5DFADD5DBAB97A069
4A6018C7E295CDE49CCEE39ECFE4A3D1E7A6CAE5A0C3E599C5EC9BC2EE97C2EE95C3ED97
C6EB9BC9E99ECDE6A4D1E4A4949E614F591ACCD898DFEFAEC0D592DCF1AECADF9CD2E5A3
CFDF9EDFEEADC7D192E7F1B2A1AD6D556423B8C887DAF0AFCBEEAEC3E8A5C8E89CC9EA93
C6E588CFEA8DDCEF9DDCE9A48B9560ABA983BDA28D85765F44653A25561EBDDB9FD2EBAA
CEEDA77A9C528CAE64C5E79DBBDB92BDDB93D3EDA6BBD58E
C9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DC9E99DCCECA0C6E69AD0F0A4C1E195
C1E195CEEEA2C2E296C3E599C6E9A5BEE39DC1E79CCBF2A1CDF59DC5EB94C5E894CBEBA0
DBF5B8BBD1A2F8FFE8FBFFF3FBFFFAFFFFFFEEEBF2FFFEFFFBFFFFF9FFFFFBFFFFFEFFFF
FFFFFFFDFBFEFEF9FDFFFDFFFFFCFFFFFFFDFBFFF7F6FFECF7FFE3CAE5B2CAE8AAC8E9A2
C6EAA0C6EB9DC7EA98C7E995CAE795D0E89ED4E6AAD8E3B8E9EED7FFFFF8FFFEFFFFFDFF
F2EFF6FFFEFFFEFDFBF8F8F0FBFDF0FBFFF0FAFDF6FEFFFDFEFFFFFEFEFFFFFEFFFEFDFF
7A7879ADACA7FFFFF6FBF7ECF1EAE2AFA6A1E8DEDCFFFCFBFFFBFDFAF1F4FFFEFDFFFFFB
FBFDF2FFFCECDDC7B2A29A75C1E5A5C6F7A8BFDE90D0E596D8EAA0E9FDB58BA25CCBE69F
CDEE9FD3F6A6C7E79EB9D3928CA168DAEBB79BA9762E3804E6EFB6C6D093899450818C47
CDD893DAE7A1DFECA7D5E6A0CFE79DCAE99DC9E99DC8EA9DC6EB9DC8EA9DC9E99DCCE89D
ADC179ADBE77D2E29BD2E39CD1E99FC6E297C9EB9EC5E79BCBE9A1637C38394C0CD5E3A6
D7DFA6989D67D8DFA9C9D29D2A3701D0E1AAD9EAB3C4D69CCBDAA1E1ECB2C5CD94909C5C
D2EA9CCDEA96D2ED9EC3DB91C8DF99D8F2ABC4E298DDFFB2C3ED99C1EF95C1EF95C2EE97
C5EC9BC9E99ECDE6A4D1E4A4E1EFB1D3DF9FCADD9BD7EEAACAE5A0B5D08BDBF6B1C6DF9B
D5EAA7C8DB99D9E8A7CDDD9CBED18FC6DB98C7DE9ACEEDAAC2EAABBFE8A6CEECA2D4F09C
CBEA8CCAE78AD0E693CEDE97DAE1AEA39A79B99A888C7B6752774C002500C9E5ABDBEBAD
D5E8A6D8EDA89FB46FB0C580CDE49EE1F8B2D2E9A3D4EBA5
CAE99DC9E99DCAE99DC9E99DCAE99DCAE99DCAE99DCAE99DCEEDA1C1DF95D1EFA5CEECA2
CFEBA1D1EDA3C2DE94CFEDA3CAECA0CBF0A3CAEFA2C4E99BC1E696C3E996C9EC9ACAEC9F
BFDD9DD3EBBBF3FFE6F8FFF6F6FCF8FCFFFFFEFFFFF6F7FBFBFFFFF9FDFFFAFDFFFEFFFF
FEFEFFFAF8FBFDFBFEFFFEFFFFFDFFFFFFFDFDFFF7F8FFECF9FFE4CFE2B4CEE6ACCCE6A5
CAE8A2C8E89DC8E797CAE793CDE994D0E89ACFE2A2CDDBAAE7F0D5FAFDF4FAF9FEFFFDFF
F8F5FEFFFEFFFFFEFFFFFFFAFFFFF6FDFEF6FAFBF6FFFFFFFCFBFFF7F6FCFFFEFFFFFDFF
6D6C6AFBFAF5FFFFF8F6F2E9BFBAB4F9F2ECF7EFECFFFCFDFFFCFFFFFDFFF8F6F7FFFFFA
F7F8EAFFFEEBE3CFB49E976BC9E6A4BEE99AC9EC9CD6F1A2CBE198CADE97B3BF7FD4E4A3
C3DF92D3F4A5CBE9A1CCE5A3B2C78CD1E2ABCAD8A3394610CBD99ED8E6A8C0CF8CA9B972
D5E79DD0E59AD5E9A1C8E096CCE89DC9E99DC8EA9DC8EA9DC8EA9DC9E99DCCE89DCDE79D
8CA0589AAB64C8D992CFE39BD4EEA4C8E799CCEF9FC6E89CCCE2A16577394B5B1DCAD99E
D6E4A993A166C7D59AE0EDB5415017DEEDB2BDCC91E5F5B7CEDEA0D3E1A3899759B0C47F
C7E494C6E894D3EFA2C8E298D2E9A1CAE49BCCEB9FBEE191C3ED99C2EE97C2EE97C5EC99
CAE99BCFE69ED6E2A2DAE0A4D5D49BDBDCA2E5EFB2C3D696CFE8A4DAF8B2BDDC96D2F0A8
C4DE97D6EDA7D0E5A0CADF9AD4EDA9D6F1ACC9E8A2C0E59FC1EEA9BEE9A2CCECA0D5EE9B
CDE78ECEE68ED7EA99D9E6A0D7E0A99A926BCEAE99AE9C84698D61002E00D0F1BACADFA4
CFDF9ED9E8A3CFDE99798845BBCC88C0D48FD2E7A2CEE59F
CCE89BCAE99BCCE89BCAE99BCCE89DCCE89DCCE89ECCE89ECFE9A0D2ECA5CDE49ECFE6A0
CFE4A1CCE19ED4E7A5D2E89FD5ED99C4DD89D8F2A9BFDA97DFF9B8CCEAA4C9E89AC1E293
CCEAA4CBE3AFF5FFECF5FFF8F8FFFFF9FFFFFBFFFAFCFFFAFDFFFEF5F5F7FFFFFFFFFFFD
FAFAF8FFFFFDFFFFFDF5F3F4FEFCFDFFFFFDFFFFF7FFFFF1CDD2B4979E75A6AE7BDEECB1
D5E9AAD8F1ADC4DF90D4F09BC9E68CBFDB86D8EFA7CDE0A9E1F0CFF2FDEFF6FAFDB0B0B8
8384896D6D6DCECEC6F9F6EDFFFCF7FFFEFBFEFAF9FFFCFBFDF9FAB1ADAE403C3D010000
BEBDBBFFFFFBF9F8F4D6D5D1F6F5F1FFFFFBF2F3EEFFFFFFFDFDFFFCFFFFF1F5F4FEFFF6
FFFEE9DED3B5B4A179B9AD79DBE6A2D3EFA2C3E898C9F0A1C6E49CD5E5A6827F4A89874E
D4E59EC9E495C6DE94CFE69ECEE3A298AC6DC9DB9F112300D9EBADCFE4A3CEE5A1CAE49B
CBE79CCDEC9EC8E797CBEC9BC8ED9FC0E597C4E699CDEDA1CCEAA0CBE79DD1E8A0D0E69E
95A9617F934BCCE297D8F3A6C8E799D0F3A1C1E895CCECA1D2DCA7606638DBE7B7D0E1AD
CCE3ABA9C288CEE7AD9AB276304208C8D69BD8E3A9D7E2A6D3E3A59AAE6FA4BD7CCBEAA6
C6EAA0C6EAA0C9E9A0CCE7A0CFE69ECFE69ECCE89DC9EA9BBEE594D5FCA9BBE18EC8E497
D5E59E7678375E5218654F1D63461A765B305044126E7138D5E8A8D5F0ABBDDF95D0F2A6
CAEA9FCAE69CCDE79ED3EFA5CEEEA5C2E69CBEE69DC1EFA4C2F5A6B7E897CAEF9FCAE594
D6E797D0DC90DEE69DD0DB975262239FA26DB597739C8563CCE6B679AA736A9963CEF6BA
D4EBA7DEEEA7BBCB84A9B671889752D4E59FD4EAA2D4EEA5
CCE89BCCE89BCCE89BCCE89BCCE89DCCE89DCDE79ECDE79EC9E09AD1E8A2D1E6A3DBF0AD
D1E4A4D4E4A5D1E1A2CFE099DDF19AC1D880D8EEA6D1E7A7B6CC8EDBF4B2CBE79CD7F6A8
C7E59DC9E2ABF4FFE9F1FFF2F8FFFFF9FFFFFAFFF5FCFFF6FEFFFAFEFDFBFEFDFBFFFFFB
FFFFFAF8F7F2FDFCFAFFFFFDFCFAFBF9F5F4FFFFF87C7A6BAFAF959EA079A1A475CDD49E
D2E1A8B4C988E0F6ABC4DD89D7F198E0FCA7CBE59BC5DAA1E9FAD8F8FFF4FBFFFF33363D
3334383434322D2D21C9C7BBF6F1EDAAA1A28F8989A8A2A2807A7A342E2E3D3938868281
FFFFFDF5F4F2F0F0EEF3F3F1F6F8F5FEFFFDFCFFFDE9EDEEF4F8FFF9FFFFF9FFFFF2F5EA
FFFFEAEADDBBAC996EAEA16ADBDE9BCDE295C6ED9CC4F1A0C5E69FDFEFB1978D5CADA16D
DEEBA5D2EA9CD6ECA1DBF1A8CEE39E889D5ADBEFB0607435CCE2A2D2EBA9D6EFADC9E79F
C7E79BCAED9DC4EA97C4EA97C1E897CDF4A5CEF0A3C5E599C5E196D9F1A7C5DB93D1E59D
85995192A65EE2FAB0C3DF94BFDE92D9FBAEC4EB9CC9E4A1E3E8BF767352DAE2BBCFE0B4
B9D4A1D6F5BCC0DFA45A763B728649E9F7BAE2ECB0C8D295AEBE7FB7CD8CC0DF9CC8ECA6
C3EBA4C5EBA2C9E8A2CCE7A0CFE69ECFE79DCCE89BC9EA9BC6EB9BC6E999D5F4A6CEE49B
93985671672CBAA16BB59063C09670A9835E917C4D1B18009DAB6DC7E29BCBEDA1C5EA9C
C2E296D1F0A4D3EFA4C2E195C1E397CDF3A8C9F5AAB7E899BDF39FB8EA95D7FDAAB4CF80
E0ECA2EBF1ABC6C986E7F0AD475C17B6C083E0C59AAC956CCCE3AFAEDDA65D925CB3E3A7
BBDA96CDE199E4F5AE899952A0AD68E6F5B0B6CC84D2E9A1
CAE99BCAE99BCAE99DCAE99DCAE99DCAE99DCCE89ECCE89EDAF4ADCDE7A0C3DA96D3E8A5
C3D895D2E5A3CFE2A2D7EBA498AE5C95AB59C4DA92E3FAB6DCF3AFBDD790DDF9ACBCD88B
CFEAA3D1E8B0F0FFDFEFFEE9F9FFFAFBFFFBFBFFF8FCFFF8F8FAF7FFFFFDFFFFFDF4F3EF
FFFFFAFFFFFAFAF6F5FFFBFAF8F4F5E0DCDBABA8A1E4E5D5F6F9DED7DEB5B0B887BAC58D
B6C58CDDF1B2D8EEA5BED784DFF9A2BDD683C0D78FDEF3BBE5F4D3ECF7E7FBFFFF383B40
A6A7ABFFFFFDF8F8EE7A786C3F3A365D5855B6B1AEFFFAF7FFFEFBFFFBF8FFFEFDF8F4F3
FBFAF8A6A5A3B4B4B2FFFFFDFEFFFFEDEFEEF9FBFAFCFFFFFCFFFFFBFFFFFBFFFFF4F7EC
FFFFEAD0C6A3AE9D71958851DEE19ECFE499C9F09FC4EF9FC4E89EDDF0B0938D59968F59
CDDA94D1E99BCFE59AC1D78FCEE29D95A866CADC9E314506CDE3A3CEE7A5C9E2A0C6E49C
CBEBA0C8EB9BC4EA97C9EF9CBDE495CCF2A5CEF0A3C6E599CBE59BDEF6AAC4DA91DBEFA7
80914AC1D58ED0E5A0D6F0A9C5E09DC1E09CCBECA7AFC68E363717B0AC93FEFFE6E8F8D3
9EB88BAECA97E5FFCA91AA7075894CCDDB9ECAD495A7B270869753CBE29AD3F1A9CCEEA4
C5EBA2C5EBA2C9E8A2CCE7A0CDE79ECFE79DCCE89BCAE99BC4E797C0E192D2EEA3D7E8A2
B0B27190844ADCC28FF2D0A2F4CDA6F6D5ACCFBD8D66642B93A261D2EDA6C1E397C4E99B
CCECA0C8E799C7E398CAE69BC9E99EC5EA9DC2EB9FC1F0A0C1F5A2B9EB96C1E696D2EA9E
E3F0A8D6DC96DEE19EAFB8758BA25CD6E0A3CEB386988157CFE6B0C5F5BB3B7038CCFEC1
C5EAA4D5F1A7CDE49CCBDF988D9C57CBDA95E6F7B3D9EDA8
CAE99BCAE99BCAE99DCAE99DCAE99DCAE99DCCE89ECCE89EBBD58ED8F2ABCAE39F8BA25E
3A510D5168244E63224156134E641B596F26CBE199BDD48CD1E99FCBE59BD3EEA1D4EEA4
C6DF9BC7DCA3D6E9BCD7E6C7F6FFECF6FCF0FBFEF7F9FBF6F7FCF8FEFFFDFEFFFDF8F9F4
FFFFFAFFFEFAFFFBFBFFF9FADCD3D6736D6DFFFFF8FFFFF1F5FBDFE4EFC5C4D29FCEE0A6
80915A889A5EDAEEA7D5EC9EC1D886E2FBAAD7ECA7C4D7A0EBF9D8EDF5E6E2E7E386878B
F6F6F8AEADAB5C5950F2EEE3FFFEFAFEF9F6FDF8F5FFFAF7F7F3F0FFFBF8FFFEFDFFFEFD
D2D1CFEDECEAF9F9F7FFFFFDFEFFFFFEFFFFFDFFFEFEFFFFF8F8FFF7FAFFF1F5F4FEFFF6
FFFFEAE9DEBEEEDDB2A49762D1D392D8EAA0C3E898C2ED9DC8ECA2D5EAA995945E69642C
DBEBA4CFE799D3E99ED8EEA6C7DB964F622292A466627436DAEEAFD6ECACC0D997C9E49D
D5F3A9C6E999C4E795CDF3A0C5EC9DC2E79AC3E598CBEA9ED4EFA2CBE196D1E69BCBE095
9CAD66DAEBA7C8DB9BC9DD9ED9F1B7C2DEA4D2EDB6000B0064644CFFFFEDFEFFECE1EFCE
F4FFE3CEE8B9C3DEA95B73397E9054C7D597D3DE9C9BA6628C9C55CEE499C8E497C3E397
C5EBA0C5EBA0C9E9A0CAE89ECDE79DCDE79DCDE89BCCE89BD5F4A6C6E599C9E098DCE8A6
CFCD90796A336E522277552873522761461954471363642AC7D693CEE89FDBFBAFC5E79A
D3F2A4C6E295C6E096D3EDA3D0EEA4C1E196BDE398C8F3A4A9DA88CFFFABC9EC9CC5DD91
CBD890D7DE98E7ECA9505B17CFE6A0E1EDAF9C84566A5329CDE1ACBCE9AE275A21B5E7A8
D0FBB4C1E79CB6D48CE3FDB6D2E6A1D6E5A2CCDB98C9D895
C9E99DC9E99DC9E99DC9E99DCAE89ECAE89ECAE89ECAE89ED8F3AC87A25B8BA65FD1EBA4
DAF3AFD6EFABC4DB97DBF1B0D6ECACB9CF8E6D843CA1B96DD1EA99CAE392CEE69AC9E098
D1E8A4D1E5A8D0E1ADD4E1B6FEFFE8FEFFF1FFFFFBFEFFFFFCFFFFF2F8F4FEFFFDFFFFFB
FAF7F2FCF4F1FFFCFDFFFCFDD6CBCFC7C1C1F7F7EFECF0DF79846666774B647843000D00
3F501A75844BD1E1A0CEE29ACEE396C8DE93DCEFADC5D6A2E1EFCEFBFFF3F4F6F1707072
FFFEFFA6A2A1C6C1BB9D9990DED9D3C8C3BFAEABA6AEABA6B5B2ADACA9A4BBBAB6EBEAE6
C5C4C2FFFFFDFFFFFFF0F0F0FFFFFFFBFBFDEAEAECFFFEFFFBF9FFFFFEFFFCFFFFFFFFF6
F4EFD9DACFAF9C8B6060531FACAC6CD7E8A1BEE393C3F09FC8EEA1CEE7A3BBBE8577763D
D2E29BCEE597C4DA8FD5EBA3D8ECA770834390A26465773BB1C588DDF3B3D4EDABCEE9A2
D1EFA5C4E797C7EA98C6EB9BCDF2A5C2E79AC4E699CAE99DD3EEA1BAD183E2F7AAA1B369
C4D48DCFDF9EDCEBB0D8E9B3CBDDADDBF0C5102500A2B192F2F3E1FFFCEDFBFFEA818E72
F6FFE3D2E9BDBED6A4ABC0888EA064D1E09FD6E39E75803B95A55AD2E79ACFE897C6E595
C6EB9DC6EB9EC8EA9ECAE99DCDE79DCDE89BCDE89BCDE89B87A358A8C278D3E7A2DEE7A8
DED7A0BEAA78BA9B6DA28154B09566AC9B679A915AE1E5A8D2E39FD4EEA5B9D88CC1E195
C9E89AD3EFA2D4EFA2CCE79ACBE59BCFEEA2CDEDA2C0E699C6F5A4CEFBA8D7FAAAC7DF93
E9F6AED8DF99ABB26E929F5AC7E19AD8E4A6B39B6B796236C5DAA2BCEAAC518346447838
B0E49AB5E599D0F8AFC6E59FCBE09D485714E7F3B1D6E19F
C9E99DC9E99DC9E99DC9E99DCAE89ECAE89ECAE89ECAE89EC3DE97A1BC75C5E099CBE69F
BFDA95CCE7A2CAE5A0C9E3A2C2D9A3DCF4BACFE9A28CA5548DA75098B15DA6BE72DEF3AE
D3E8A7D8EAACCCDBA0CEDBA6FBFFDBF5F7E2FBFAF6F6F5FAFAFFFFF7FDF9FCFFFDFFFFFB
FDF8F4FFFCFAFFFBFDCFC3C5E1D5D9FFFCFDFFFFF8888F7D394628BDD3A5C5E0A9D8F1B7
899A64061500DFEFB1D9EAA6CEDF98D4E8A1CBDD9FDEEFBBDFEAC8EDF4E2282923C7C6C4
FEFAFBE8E2E2FFFDFAFFFEF8F5F0EAFFFEF8FFFFFAFAF7F2FFFFFAFFFCF7F0EFEBFFFFFB
FBFAF8FAF9F7F7F7F7FFFFFFFFFFFFFFFFFFFBFAFFFFFEFFFBF8FFFFFEFFFEFFFDFFFFF4
FFFFEAE5DCBB64522A998C589A9A5CD2E29BC6EB9DC9F6A5C1EA9CC6E49CDFE7ABB2B679
84944DDDF3A8DEF4ABCFE59DD0E3A1A8BB7BAFC18366783C405417C1D797E3F9B8CAE59E
C2E096C5E599D2F5A5C1E696C6EB9ECBEDA3CEEEA3C8E799D2ED9ECAE193EAFCB08EA056
E2F1ACD2E0A2CEDBA5CCD9ABD2E1BA556445B4C4AAF5FFEBFFFFF1F0EFDDFFFFED7F8A6C
EAFAD5CDDFB5CADEAD5B7038A2B478D8E7A6CAD69454611B8C9C53CEE094DDF2A5CFEA9B
C8EA9DC6EB9DC8EA9DCAE99DCCE89BCDE89BCDE89BCDE89B546C22CEE29BD3DF9F666A2F
645A256F592A6E4F2364451954400D62571FE6E4A9D2DB9AD8E9A3BAD189CFEBA0DCFBAF
CBE79AC5E093C4DC90CBE397D3EBA1D2ECA2CFEBA1C9EB9ECAF5A3ABD684B3D485CFE59A
D7E39B8F9652959C59D2DE9CCAE39FCAD89AE8D0A0BEA879D1E6ADC4F0B19ECE90205714
4C883EC2FCB0B0DF97CAEFA9CCE2A1DBEAA9505B19AEB474
C8EA9EC8EA9EC8EA9EC8EA9EC9E99EC9E99ECAE89ECAE89EE3FEB7A6C17ACEECA4CBE9A1
D2F0A8CFEFA6CCECA3C1DF9FCFE9BAC7DFADC6E19CCAE692C0DD83354F00637B2F9EB370
C5D799DAEAACD4E0A2DBE4ABFFFFDAFFFFE5FFFEFDFFFDFFF8FEFEF9FFFDFCFFFDFAFBF6
FFFEFAFFFCFAEFE0E3AC9DA0FFF4F8F9F0F1F9F9F1050C00A4B595CEE8B9D7F8BFB7D599
ADBE8A33400B67753A94A463CEDF9BDBEBAAD7E6ABD2E0AFCAD4B1D8E0C9404237EAE9E5
D4D0CFFFFDFDE6DEDBFFFAF4FFFEF8FFFDF4F8F5EEFFFFF8FFFFFAFFFFFAFEFDF9FFFFFB
FFFFFDFFFEFFFFFEFFF5F3F6F4F2F7FFFEFFFFFEFFECEAEFFFFDFFF9F7F8F7FAF3F8FCEB
F5F5DBAEA886695A31AEA16DAAA86BBECB85CDEFA2C8F3A3BDE899C7E79ED9E8A7D7E09F
99AB61D7EDA2B5C981CADE97E2F2B1D7E7A8CEDEA0A3B579000D0098AE6ED4EAA9C9E49F
C4E29AC3E397D3F6A6C6E999C3E59BCAEAA1CBE99FCCE89BD4EC9ED6ED9DB5C87993A35A
C9D691DCE7ABCCD6A4D5E0B6A1AA8D060F00D9E4D4FCFFF4EFF0DEFFFFEAFFFFE89BA583
D0DFB6C2D3A6F1FFD15C6F37C4D69AE1F1B2DAE9A88E9D5A98A762B2C17CCBDC96CAE097
C9E99DC6EB9DC8EA9DC9EA9BCAE99BCCE89BCDE89BCFE79B677D34DCEBA6B5BE7F3F3E05
7A6E3CA68F63A6865FBA9F747B7038646426B9BE7EDAE5A1CFE09ADEF4ABC5DF95BCD68C
C9E399A6BE749BB369BCD289D5EBA2CFE79DCBE399D1F0A4C6ED9CD6FDACD8F7ABDAEEA6
C6D18C979E5AC4CD8AD4E3A0D9F4AFCDDB9DDCC494B7A172D8ECB1C6F0B0C0EEAD76AD69
2B6D23AEF0A6C4F9B1BDE6A2CEE8A7CFDFA097A061A3A868
C6EB9EC6EB9EC8EA9EC8EA9EC9E99ECAE89ECAE89ECCE89EBFDA93839E57C1DF97C0DE96
D1F1A8C2E49AB9DB919FBF808EAB7FC8E3B6D4F1AFC3E390C0DE84DBF7A0DBF2AAA7B97B
69783D8F9D6097A162ABB377E1E4B5DDDCC0F6F0F0FFFDFFFCFFFFF5FEF9F1F6F2FFFFFB
FFFDFADBD0CEC9BABDEFE0E3FFF6FBFFFCFD35322B9FA694F7FFE8C7E3B3C6E7AECBE9AD
D5E6B2AFB9854B58202937000616008B9B5CDFEEB5CBD9A8D5DFBAD3D9BF323426CBCBC3
8D8885F3EEEBFFFCFBFFFDFAFFFEF8FFFCF3FFFFF8FFFFF8F1F0EBFFFEF9FFFFFBF8F7F3
FCFBF9FFFDFEFEFCFFFFFEFFFFFEFFFBF9FEF9F7FCFFFDFFFAF4F6FFFFFAFAFEF0EEF3DD
C3C6A99B9772DED1A5BBAD7CBCB77DA1AC68C5E498C0E99ABFEA9BCFF1A5C4D893DCE9A4
44590ED2E89DD4E8A0DBEFAACBDB9AD0E0A2D9E8ADD0DFA4000C008B9F62C3D999D3ECA8
D7F2ABC0DF93CAEB9CC8E99ACDEDA4C4E29AC0DC92CFE99FCFE698C8DD8E61732790A057
D4E09EDDE8AED7E0B1737B563841267F8674FBFFF8FAFFF2FCFFE5F6FCD8E4ECC59BA67C
D2DFB1D5E6B2C1D29C6E8247A8BA7EB5C789D5E5A7D6E6A7ACBA7C95A365B7C385D3E6A4
CAE89EC8EA9DC9EA9BC9EA9BC9EA9BCAE99BCCE89BCFE79DD6E7A1C8D4929FA3687B763F
C4B687F1DCB1F1D5AEE2CB9FE6E4A9959E5B8C9753DCE9A4CFE099CADE96D9EFA6D4ECA2
B4CC829BB3698AA05899AF66C0D68DDBF1A8D8ECA4C4DE94C7EC9EBADF8FD4F0A5C8DC94
DDE8A3929B58636C2BD2E39FC4E29CD8E8A7AC9563685221C8DC9FCBF4B0B4E19EC0F7B3
2B7129A1E79FBFF8B3C0EDAAC5E2A2DCECAED1D799BEC081
C0E49ABEE298D1F3A9C8E89FCFEDA5C6E49CCAE59ECEE8A1CFE9A0769248E0FEB4BFDD93
C9E99ED7F9ADC3E89B8AAE6E97B78EC3E2B8B8D899CEEFA0CEEF98CCE995CBE29ED9EBB1
D4E3AC7B864E565F2091965CE8E9BDD6D2B9FFFCFDFAF4FEFEFFFFF7FDF9FEFFFDFDFCF8
FFFDFABAAFAD8C7D80FFFAFDFFF9FEEEE5E647443DFCFFF1F5FFE6CCE6B7C2E1A8C9E7AB
CCDDA7DFE9B58390586E7C3F243400283800B2C188CBD9A69CA77F5F66473B3E2BCCCCC0
A9A4A0FFFEFBFFFCFDF8F0EEFFFFFAFFFFF8FFFFFAFFFFFAFFFFFAFFFFFAFFFFFBFFFFFB
FFFFFDFFFEFCFCFAFBFFFEFFFFFDFFFCF7FBFAF5F9FFFEFFFFFEFAFDFBEFF9FFECD9E2C7
616745E1DFB8E5DAADB5A776DFD99F9CA562C4E095C3EA9BC2EB9CC6EB9ED3EAA2D7E8A2
64792ED6EBA0CCDD96D7E8A4D4E4A5D6E6A8B1C085D3E2A9000C00697D40D0E6A6CCE5A3
D5F0A9C8E79BB8D98ACFEFA3CDE8A1CEE8A1C8E299D5EDA3C9DF94B0C57894A65CAFBF78
DDE9A7D5E0A6D2DBAC000700666F54F3FAE8FCFFF6FCFFEFFCFFDFCEDBA6CEDBA69FAC76
D1DEA6D1E0A7D1E3A79BAF7033470A5A6E319CAE747A8C5294A36CBAC48F9BA370D6E3AB
C5DF98CFEFA3C1E195CDEFA2D2F4A7B5D589D9F5AAC7DD94CFDE99D8E1A0C0BF86605923
7F7142A38E63AD966D7867399EA363677730B8C881DEEEA7CAD994CDDE98E2F6AFA8BC75
6D833BCFE59DD4E9A4889E5693A760B3C780C8D993D8EEA5CDEDA1C6E89BD2ECA2D1E59D
DEE9A5868F4C4C5715C8DC97D0EFA9C2D593AD9765796331BFD193C3EBA5C3EEA7B9EEA8
3C823C97DE9AB5F0AEC8F4B5C6E2A5DCEEB2D4DCA0999D60
D2F6ACD2F4AAC3E39AC6E49CC0DE96D9F4ADC8E29BC1DB94CCE39B8AA45BC7E399C7E59B
C6E69BBADF92C0E699C8EFAC24491DD5FACFCFF5B8C6EAA0C2E595CFEEA2C5DB9BC7D8A2
D2E0ADD6E0ACDAE2A9B0B57FBAB891FFFFEAFCF2F3FFFCFFF8F8FAEEF0EDFFFFFDFFFDFA
FFFDFAA29896FFF5F8FFF9FCCABEC2898081B1AEA7F6FAE9F9FFE8C9DFB1CDE8B1D5EFB2
D5E6AFCDDAA2F5FFC8D4E4A6D7E7A85F6F31000E002B3904687348656F4CEFF3DC8D8E80
E5E2DBFEF8F8FAF1F4FFFCFFFFFEFBFFFFFAFFFFFAFFFFFAFFFFFBFFFFFBFFFFFBFFFFFB
FFFEFCFFFFFDFDFBFCFEFCFDFFFEFFFFFDFEFBF6FAFFFAF7FCF8ECFFFFECFBFFE8798763
949F75CED1A4B0A577ADA06CEBE2A9A7AC6AD6EEA4C8ED9FC4ED9EC5EA9CCDE79ED2E69E
BACE86D8ECA4D9EAA4D0E19DC4D495D0E0A299A86FDAE9B0000B007A8C50D0E4A7C3DC9A
C9E49DD1EFA5C7E79BCDECA0C9E39CE4FBB7CDE49ED4EAA2D9EDA5667A32D0E19AD8E7A2
CDDC9BDBE9AE6B7745808B61C2CBACECF6DDE5ECDAD8E3C5DAEBB5E1F4B4D3E3A2899857
D4E3A2E1F1B0CADA99D3E8A7637939DAF2B460753C61743D455320697243ABB1857E8856
D4EAA9D9F7ADB4D489C9EB9EBCDE91DAFAAEBBD78CDDF3ABD9E8A5D3D99BDAD89FA59E68
AA9C6DAD9C70958258A197649CA866AAC077CEE29AC9DA94D3E29DDCEBA8D2E19E8A9B57
B8CB89D9EEABCDE29FD3E8A3CCE09B98A963D7E6A3C2D38DCAE99DC8E89CC7DF95D6E7A0
CCD7939FAA66485412DAEEA9C9E8A2CCDF9DB29C6A9A8452D4E4A3CBF1A8C7F1A7BAEEA6
B0F3B0539859A9E1A4BDE9ACCBE9ADBCCE92DEE8ABC3C98B
B9DA93C1E29BCEEDA7CAE8A2CEE8A1C8DF99D4EBA5D9F0AAD8EEA6BFD68EC8E49ACEECA2
D2F2A6CCF1A3C6ED9EC3ECA6002700A0CB9DD7FFC6B8E19DB7DB95D5F4B1D7EFB5D5E7B5
DFECBEC5CEA1E2E8BAD8DBB0E9E6C75A5542FFFAF9FFF8FDFFFEFFF8F8F6FFFFFDFCF8F5
B5ADAAFFFCFAFFFBFCFFFAFB7D7477120C0CEDEAE3FFFFF1FCFFE8D2E1B6CBDDA9CADEA3
D6E5AAD1E1A3BACA8CE1F1B2CDDD9ED6E8AA7C8E52000B00536130B1BC94363A1FFFFFEF
FFFFF8FFFDFDF7EDF5FFFCFFFFFFFDFFFFFBFFFFFBFFFFFBFFFFFDFFFFFDFFFFFDFFFFFD
F7F6F4FFFFFDFFFEFDFFFEFDFFFCFBFFFEFDFFFDFFFFFEF8FFFFEAFFFFE4E9F8D155663A
D4E4B3DBE2AF9F9766A79A65E2D99EA0A261D9EFA6C8E89CC6ED9EC5EA9CCBE79CD3E9A0
D2E69EBFD38BC3D48EE0F0AFD4E2A4C2D0939BA870CCDBA2000E00819357E3F7BACEE7A5
C7E29DD3F1A7CDEDA1C2E096D5ECA6CDE29FBCD18ED3E7A2CADE99B5C982D0E49FDAEAA9
DCECAE606F36000A00EBF8CAFBFFDFCDDBB7D3DEBEE3F2C9C9DF9EC9E195D2E79C5A6C22
D5E59ECCDD96D4E59FD5EAA5CAE3A1C3DD9EC8E1A7D1E8B2E0F0BF6C754AE4E9C1929A6B
D3E5A7AEC982E6FFBCC5E79BB5DA8DD1F3A7D6F4AAC7DE96CAD694ECF2B4D8D69DD0C993
DCD2A1FBEFBFFFFCCFE9E8B2CEE29DDAF4AAD6ECA3D4E59FE0ECAAD8E2A3D6E0A19CAB6A
D7E7A8BCD190CFE5A4D1E8A4D0E5A294A561E0ECACDDEEAACFE9A0D0ECA1D3E9A1CDDC97
DCE7A596A15F778343D6EBA8C4E59EDFF4B1B8A46FBEA974D9EAA6BFE399C5EB9EC2F1A9
AAE8A94D8C5372A56DC3ECB4D1EEB4EAFEC3D6E4A6CCD697
F1FFCADDFCB6C3E19BCBE6A1DBF2ACCBE09BCDE29DCBDF9ABFD38CB5CB83D1EBA2CFEBA1
C5E599C5EA9CC7EE9FC3EEA67FAE77538351B6E5AEC4F0B5BCE2A7C9E8AFE8FFCCEBFCCF
FAFFDCF6FED7FFFFE1FFFFE4F7F2DEEAE4D6C2B9B4FFFBFCFCF6F8FFFDFDFCF6F69D9895
E0DBD7FFF7F4FFF9FAFFFDFD544E50D0CCCBFFFFF8F1F2E2FFFFE8D1D9B0DDE7B5DAE8AD
C9D99ADBEBAAE3F3B2C6D997CCDF9DCADF9ECBDD9FB7C98F8E9F6BA4B185DFE6C5F9FCE7
FFFFF6F2EEEFFFF8FFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFEFDFEFAF7F9F5F2FCF8F5FCF7F4F3EFE4ECEBCDFCFFD997A979C3DAA4
CEE3AADBE6AEB1AC75998E56DFD59A9B9B5BD3E49DC8E79BC6EB9DC4E99BCAE69BD3EBA1
CFE39B6D8139D3E4A0DDEDACD4E2A4E3F1B6839058D1DEA602110036480ECFE3A6CBE1A0
C7E09CCCE89ED3F1A7CDE99FD4E9A4C9D998EDFDBC95A86698AB69C9DC9AD6E9A9C6D89A
2739002B3F04E2F5BDE5F8C1DFF1BDD1E3B1D5E7B7C0D59DD4F0A6D2EF9DC1DA89A6BB6C
9BAD61C9DB8FD7ECA1D1E99FC9E49DD2F1ADC3E1A1D9F2B8B9CB979AA6783E431A343A0C
6A793ED6EDA9C0DE98CDEFA5D1F7ACBDE295D3F3A8C4DB93D9E5A35A5F1F747237A59E67
A8A16D8D8755605A2873783EA7C178BCDB8FD1E8A0D8E9A5929C5D656D319AA266909A5E
5B6A2F32460753692957702E041900C3D394657133B7C685C7DE96D5EFA5D6EAA3CFDE99
D7E2A0909B59B9C887C9E09CC5E9A1DBF0AD927E49B6A16AD3E29DBEE093C7EC9EC1ECA4
B6ECB22E6432053400CCF1BDBAD59EC4D99EC3D597D6E6A5
E1FEBBDDFAB7C0DB96D2EBA7D0E5A2D4E7A5D7E8A4D1E29EE5F6B094A861C4DC92C9E59A
CBEB9FC3E89AC2E998C1EDA2C1F5B51950174E804BC3F1C0C4EBBCB6D7A8E7FFD2F7FFDF
F3FFD9FEFFE6FFFFECFCFAEBFFFEF4FFFEF6FFFEF689807BAAA0A1FFF8F9DDD3D4C9C1BF
FFFEFAF1EEE9FFFEFD0A0907E5E3E4FFFEFCFFFCF5FFFFF1F6F6DCD9D9B39EA071BBC086
E3F2AFC9DD95CCE099D0E69EDFF4AFCFE6A2D3E8A7CFE3A6D1E2ABCCD9ABFCFFE3FDFFEB
F1F3E8FFFEFFFFFCFFF4EEFAFFFEFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFFFD
FFFEFDF9F5F2F8F4F1FFFFFAFFFEFAFFFEFAFFFEF8F0EDDCBBBD9676804BE7FFC3BFDC9C
D3EDACD4E4A5AFAF73B8AE73EAE0A3A3A262C0D089D1EBA1C9EB9EC6E89BC8E499CEE69C
D0E49C70813AC5D491DFEEADD4E2A5CCDA9F9FAC74C8D59F67763F1A2C00CDE1A4CBE1A1
CFE8A4C5E197CFEDA3D1EBA2C8DC97C0CF8E8A985A99A96AC5D597E6F8BCD4E6AC5C7035
73874CCADFA4A6BC7EDCF2B4C5DE9DCEE7A6D0E9A7CDE8A3C7EA9AD3F4A3CFEA9BDCF3A5
8FA25398AA5ECEE396D5EDA1D4F4A8BEE096CEF2ACCAE9A6D4E9AED0DFA8959C69464D1A
6573386D8142CAE5A2C4E59EC6ECA3CDF3A8BEE096D2ECA591A05D898E4EC8C68BE8E3AB
DAD7A0D0CF99EEF1BA889659B4D288C9E99DC6DD95D1E09D9BA36766693072753E5F672E
69763EC4D89DD2EAAECDE5A70418006476389AA5698A9958C5DC94D3EBA1CADE97DBE8A3
A1AC6AB7C182D5E3A5CBE4A2C5EAA4C6DD99634F1A9F8A53D5E59ECFF2A2D0F3A1BAE299
BCE8B3A9D7A95178496D8D5CD8F3BEDCF4BACCE2A2DBF1B0
C4E19ECFEAA7CCE5A182995598AB69819150D6E5A2CCDB98CEDD988DA15ACFE59CCBE59B
CBEA9ECFF4A6CAF1A0B4E395A8E19A4985471F5523B0DFB5C4ECC7BADCB7DFFAD1F5FFE1
F8FFE3FEFFECEBEBE1FFFBF8FFFDFDFFFDFBF2EBE1D8CFC6E3D5D5F3E4E7E1D5D7E7DFDD
FFFEFAFFFFFAE1E1DF4B4D4AFBFDFCFFFFFDFFFFF8F3F0E1FFFCE4DBD5B16F683C98975F
929F59D8EFA1C8DE93D3EBA1C6DD95D2E9A3C3DA96D6ECACCFE3A8C4D4A3DCE8C0FCFFEA
F6F9EEFFFFFFEAE7F2FFFCFFFFFEFFFEFFFFFEFFFFFEFFFFFFFEFFFFFFFFFFFEFFFFFFFD
FCF8F7FCF8F5FFFFFAFFFFF8F7F2ECFBF7EEFFFBF2E9E7D28E9464AAB87ABDD895DDFCB6
C5E39DC7DB96BDBF80A79F61E7DB9F9F995B95A05BD2EAA0C8E89CC6E89BCCE89DCEE69C
D8ECA44F601AE3F2AFD2E1A0CAD89BDDEBB088955FC8D59FC9D8A1495B21E0F2B8D0E6A6
D7F0ACC7E29BCBE99FCAE49BD1E29EA7B373556123E0EEB1DFEEB5BFD099697C4431460D
CDE2A9CEE6A8DAF3B2BFDA95D5F1A7CCEB9DC2E191C9EA99BDE292C3E898D5F1A4C1D78C
C9DB8F839549B9CE81CEE99AC7EA9AC8EFA0BBE194CAEEA4E7FFBED8E8AA8C9459A3A870
CFDAA0071B00CCE6A5CAEBA6B0D891C9F1A8CDEEA7CEE9A2AEBD7A666C2CC7C78BD7D59A
E8E7AEEDF0B7CAD39A7184449EBE75D9FBAFD3EAA4D6E5A49A9F652D2D00353501A7AB78
DFECB6D8EBB3CEE6ACC9E3A6000D0067793DCBD69CADBB7DDEF4ACC8E096D6E7A1C5D18F
959F60D2DC9DD2E2A3CFE8A6C2E7A1CFE6A27D6A32AF9A61D9E6A0CAEB9ACDF09CC4E8A0
CCF2C1B1D6AD84A57A3C592B8AA270D2EAB0CDE7A8BDD895
D0EBA8C5E09DD1EAA89CB170D6E6A5869554A2AE6C54601E7A8944A1B26CDFF3ABD2ECA2
B5D486C0E393CEF3A3C9F8A8BBF8AAB2F0AD76AE7D74A681A1C9AEC2E5C7D0ECC6DBF0C9
F9FFE6F6FEE9FFFFFDFFFDFFEDE6EEFFFAFCFFFFF3FFFEF1FFFAFAFFFAFDEFE0E3FFFCFB
F2EFEA84857F0A0C09EBF0ECFBFFFEFDFDFBF6F3ECFFFFF1FFFAE44D401EB4A77DE2DDA5
C4D189829949D7EEA0D4ECA0CEE59DC7E19AD2EBA7CFE5A4D3E9ABDBEEB7E5F2C7F4FDE0
FEFFF4FBFBFDFFFCFFF9F7FFFEFEFFFCFFFFFEFEFFFEFFFFFFFEFFFFFFFFFFFEFFFFFFFD
FCF8F7FFFEFBFFFEFAE6E1DBB9B5ACCBC7BCE0D9CFC5C3AACFD6A2E0F1ABC9E79DC8EA9E
CFEFA4C6DC94AEB06F968E4FE1D698999152636D28D1E79EC7E69AC8E89CD1EDA2D0E89E
C8DC9452631DCEDD9AD9E7A9DEE9ADCDD89E9BA570BDCA94707F4855672DD1E3A9C5DB9B
CDE6A4CBE69FCFEDA3CFE9A0B1C07DB4BE7FE3EFB199A76C62713A4D5E2850622EA1B580
D7EFB5B7D192CFECA9D9F7ADC5E494C5E790D1F498C4E88EC8EF9ED1F7ACBDDB91D4EBA3
D7E8A1CDDF9598AF61D3F0A0C9EF9CB8E28ECEF8A4C8EF9EB0CC81DEF2ABCED794BEC486
D7E2A875874D597334DAFAB7C6EEA7B9E399C7EBA3CFEAA5D3E29FA1A7678B8B4F69692D
4A4B113F470B92A063BDD392C2E49AD1F3A7BDD48ED4E3A2ABAE75383701383605E2E6B4
D4E1ACB6C992DCF5BCC8E4A9647C40334509CBD69C95A365CEE49CC9DF96B1C27CB2BE7C
BEC889D4DEA1D3E3A4CBE4A2C0E8A1D8F1ADA39058BEAA6FD8E59DBEDF8EC6E894CDEEA7
C2E2B3C8E6C26D8760132D00273F0DCEE7ADD6F3B3CFEEAA
D3EBADC4DA9C94A869CCDC9ED9E5A7D7E1A2DCE6A7D1E09DCBDF9ADCF3ABBDD78ED4F3A7
D2F2A6CFEFA3C1E195BCE597BBF1A3B1EDA7B6EFB80C401A57846FB8E0C8C7EBBFC8E5B5
EDFFDCFBFFEFFEFFFFFDFAFFFFFDFFFBF6FAFFFFF4F3EFE3FFFBFBF5E6E9FFFCFBFAF5F2
FBFAF6080A05FCFFFDF8FCFBFEFFFFFDFDFBFFFFF8EEEBDCFFFFE6605B35928C5CE4E5AB
E0F0A9C2D98B4860148FA75DCEE89EC2DC93DCF6AFC5DE9ACCE4A6C9DEA6E3F2C7FBFFE8
F4FAECF3F4F6FFFDFFFCFAFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFD
FFFDFCFFFDFAF1ECE9BEBBB4B2B0A4F5F3E6FFFFF1E2E5C6DDE8AECEE29AC5E498C3E598
CEEEA2DBEFA8C5C484D7CD90E6E2A39A9C5B4D5613D9EAA3CAE49AC9E89CD0EFA3C8E499
D8EEA54B5C16D1E09DD0DF9EDDE9ABD3DEA498A36BCED9A1000A0068773ED9E8AFD3E5A9
CCE0A1CEE4A3D1E7A6CEE3A05A6928BECD8CD2E2A1021500000C00CFE5A7D3EBAFC8E2A5
D1EEAEC4E19FCDECA6C2E296C7E995CCEF95CDF092C9ED93C9F0A1BCE098CCEAA4D1E8A2
CDE19CD9EAA48A9E56CDE59BD0EFA1C6E999C5E898CAEA9ED9F3AACDE19ADEE9A5788243
C9D69E6B7E465A7437BDDB9BCCEFABCDF1ABC6E19ED4E7A5D3DC9BE3E5A6E6E1A7D1CC92
E1E0A7F1F7BBCFDA9ECBE1A0CCECA1C7E99DCAE19BDAE8AA9DA26853531D575725D7DBA8
DDE7B2CFE1A7CFE7ABD0EAABCFE7A95F7336D0DFA4D2E2A490A560D2E8A0556922BFCE8B
D4E09EDBE7A5D5E5A4CDE6A2C5EAA4CBE1A095804BAA935DDAE7A2CAED9DC8EB99C2E69E
CBE9B7627E55153005607A4D2E4614708C52BCDA9AD2F3AE
637840A4B57F858F5AD1D8A272773FD3D89EDFE9AAD0E49FCCE7A0C8EA9EC3EC9EC3EC9E
C6EB9ECAE89ECDE79ECAE8A0C2EAA3B9EBA4B6EDA95F98654A7F6F9ED2BCBCF0B2BDEBA3
D7F5C3EDFDE2FCFFFBFEFFFFF4F5FAFBFFFFFBFFFBF8FDF7FFF9F9FFF9FAFEFAF7FFFFFB
81837E656A66FCFFFFFEFFFFF8F8FAFFFEFFFFFEF7FCFDEBF9FFDD939F6FDCEBB0D2E5A3
CEE3A0D2E7A28299538CA35BD3EDA4CBE59CBAD68CD5F0ABC7E1A2CEE5AFE5F7CFF1FFE3
F3FEF0FBFFFFFCFFFFFAFAFFFCF6F8FFFDFAFEF7F1FFFAF4FFFDF6FFF8F3FFF7F6FFFCFD
FFFCFFD5CFD1CBC7C8E8E7E2F5F7EAFEFFEFFCFFEAE9F5CDD3E5A7CDE59BC7E59BCBEBA0
D2EEA4D4E09ECCC287B6AC71D2DE9CA3B87346510FCFDA96DAEEA7CBE79DC7EC9EC9EB9E
D0E89E40540CCCDD97DDEEAADDECABC5D395A9B478D1DCA2000A008A955DCAD49FDAE4AF
D2DCA8D3DDA9B0BA864E5B25CBDD9F3148040620007D994ED8F5A5D2F1A1C2E394CAEC9F
C8EA9EC8EA9EC8EAA0C9E99EC9EA9BCAE999CAEA95CAEA97C0E097D9F8B4C1DC99D0E6A5
D9ECACDBEBAC859554ACBC7BCCDC9BD8EBA9C7DA9AD3E6A6DAEAACCBDB9DD3E1A6C8D79E
D3E6AF5F763E657E44C7E1A4D5EDAFD1E5A6DDE9AB292D00B7B175F1E7ACD7CB9185793F
4E480EBFBF83D4DA9EDDECABD6F0A6C3E294CDE49CD3E6A4CAD599666F36313900AFB77C
D1DB9CD9E8A5D1E59ED7EDA5C4DB953B520ECDE3A3CDE3A392A86789A05AB8CE86C8DC94
CEE096E2F4AAD0E69DC7E29BC6EAA4D7E9AD7E6338AE9165D5E0A4C4E8A0C3EC9EC0E89F
C4E8AAA8C99264824E9FBD8B5D794892AF79749455CEEEAB
000E0059663A5E6539E8EBBE585727040700E1ECB0C7DC9BC9E8A2C3ECA0C1ED9EC1ED9E
C5EB9ECAE89ED0E69ED0E5A0BFDE98D7FFB8B3E69BBAEFB74E836F7CB29AB5EEA9BFF09F
CAECAFC7DBB6F0F6ECFEFEFFFEFFFFF4F9F5F7FFFCF9FFFDFFFFFDFFFEFDFFFFFBFEFFFB
CDD2CE868C88FEFFFFF0EFF4FDFBFFFEFAFBFFFFF8FAFDEAA2AC89C6DAA5C6E09FC5E39D
CDE3A2D0E5A4D5ECA8D4EBA5445C12D1EBA1D2ECA3CEE7A3DAF2B4D7EEBADAEAC3F9FFEC
FBFFF6F5F9F8FCFFFFFEFDFFFEF6F4DACFC9FFFBF2FFFDF3FCEFE6FFFCF4FFFCFAFFFBFC
FAEFF5EAE4E8F0ECEDFBFCF7FDFFF3FBFFEDF9FFE4E3F4C7CEE4A3CBE59BC9E79DCEECA2
D2ECA5CED997C1B27BA39860D1E8A4B3D28C5A6624D9E2A1CFE09ACBE79DC1E899CAF1A2
CBE59B5E722AD0E19BCEDF99D1E09DDCEBAA7F8B4DD5E0A4000900848D56E1E8B4DBE2AF
D4DAAACFD5A7303308D6E0AE0013005C7635BCD790D2F1A5C0E28EC1E58ECAEE97C1E792
C6EB9BC6EB9DC8EA9EC8EA9EC9E99DCAE99BCCE999CCE999D2F0A6C0DE98C9E2A0D2E8A8
C4D89BFBFFD1ADBA84CCD6A2D0D8A5E0E8B5F0F9C4F7FFCCE3F0B8D8E5ADD8E7ACC2D49A
C0D79F082100B4CD93D3EBAFD3E7AAD2E0A3CFD599615F24EADDA6402F0068571F6C5D26
5A5118504E15E2E6ABC4D090C9DF96E6FFB6C2D993D4E9A8D7E6ABB4C189000A00A2AC70
DCE7A5CDDA94D7E99FCEE398D8EEA6556E2ACAE4A3D2ECABCDE6A5CAE19DDAF0A8D4EAA1
C5DA8DC3DA8CC8DE95D3EEA7C6E9A5DBEAB191734DCFAF88DAE5ADC8EBA7BAE299CFF7AE
CFEFACB9D79993AE77E4FFCC4E6537A2BA8A475E26D4ECB0
0007007883634C5131C8C9A7686842070A009EA874D1E5A8C9E8A5C5EBA2C2ECA0C2ED9E
C6EB9DCAE99BD0E69BD1E69BCAE49AD0F0A5C7EFA8BEEBB28CBB9B2352305A8A4CD2FCB2
BDDA97DDEDBEFFFFF6F9F4F8C1C1B976786BB3B8B18489859D9C9AE1DDDCEFEEEA61635E
000200FBFFFDE1E2E4FFFFFFFFFEFFFFFCFDF6F3EEE7EAD797A17EE7FBC8C1DB9CC9E7A1
C5DB9AD4E9A8DBF0ABC7DE96C1D98FB9D187CDE49CC5DC98C3D79AC9DBA7E5F1CBF9FFE9
FEFFF4FFFFFDFFFDFFFEF9FFFFFDFBC5BCB5D7CDC4FFFDF4FFFBF2FCF1EBFFFCFAFFF8F9
CEC3C9F0EAEEFFFEFFFFFFFAFEFFF3FAFFEBEEF9D7E0F2C2CBE4A2CBE79CC9E99ECBEBA0
CFEAA3CDD997BFB27BA0975ED0E9A5CCEBA5818D4BE3ECABCADB95CEEAA0BDE495CAEFA1
D0EAA0BDD189AFC37CCFE39CD9EAA6DAEAA992A062DEECAF030E00838E56C0C994E0E8B5
E4ECBBDCE4B3202600666F40B1C38FC0D89ECDE5A7D2EDAAD1EFA5C9E99DC9EC9CD6F9A9
C6EB9DC6EB9EC8EA9EC8EA9EC9E99DC9EA9BCAE999CAEA97CDEC9CC9E89CDBF5AED5EBAB
CCDFA8FBFFDAC1CCA4BCC49FD6DCBAD2D8B4EDF5CCF4FDCEE6F3BDE3F1B6C5D5969CAF6F
DFF7BB566F35D7F0B6D2EAAEC8DC9FCEDC9F92985C5E5E225E531B887942D5C68FE1D49D
E2DBA49D9E65DEE6ABDEECAECFE4A1B5CA87E0F4B5D7E9AFE4F2BDE4F1BC323C07939E66
BCC88AD6E5A2DBECA6C1D78FCEE5A1637C3A7A9455C1DB9ED7F0AFC9E2A0C9E09AD0E69D
DDF2A7D8EEA3CAE097CFEAA3C4E4A1D8E7AE93754FB0906AD4DDA8DBFBBABBE09ABDE199
CAE3A1D0E2A48E9C67CEDBADAEB98F171F0099A074919767
000A000C1500676B54DEE1C69A9B7C010500677343D1E4ACC9E7A7C5EBA2C2ECA0C3EC9D
C6EB9BCAE999D0E799D3E697D5EA9BBDD589C9E8A4BFE2A8CBF1C8001300173E05C7EAA6
D3EDA3D4E1A9C6C6BA342E303B38298E8D7986887D4849445D5958413D3C6D6C68999B96
F0F5EFEBF0ECFEFFFFFFFFFFFFFEFFF5F1F2DEDBD6B5B8A7FCFFE4BDCF9FD5EFB0CAE7A4
CEE4A3D6EBA8B8CE86E4FAB1DBF3A78EA65A99B167D9EEA9D7E9ABCDDBA8FCFFE1FDFFE8
F8F8ECFFFEFBF8EEF6FFFBFF786E6DE2D9D2D6CBC5EFE5DCFFFDF4FFF8F2FFFCFADBD1D2
C3BABFF5EFF3FFFEFFFDFEF8FDFFF0EDF7DCD8E6C2D9EBB9CEE7A5CAE99DC5E79BC5E79B
CBE9A1D1E09DCCC189B2A970CCE5A1D5F6AFA7B673DDE6A5D4E59FD2ECA3C1E698C4E99B
C5DF95E5F9B18DA15ACADE97D6E7A3C6D79397A665B4C284D1DFA2616C326A753DD9E3AE
2E3603000800848C5BDAE3B4C8D8ABDAEBBED6EAB7CBE2AACBE5A6BFDC99B9D892C6E89E
C8EAA0C6EB9EC8EA9EC8EA9DC9EA9BC9EA99C9EB97CAEA95C8E992CDEA96C8E298C8DE9E
DCEEBCBCCBA4E6EFD2F5FDE6FEFFEDF6FAE3FEFFE6F9FFD8F1FDCBDEECAFA4B3708CA05B
C3D99B647E41BBD598CAE2A4DEF2B3DCECAD70793A4D4D11F7F1B7E0D59DE3D69FD0C790
5350196B7038CED99FD7E9ADD4E6A8D7E9ABD4E6ACCFDDA8BCC898D5E1B11620008B9862
7D8B50DEEEAFD1E5A0CFE49FDCF5B3A2BC7B324E1399B57AC0DA9BC0D998DCF5B1D3EAA2
CEE49BBFD58CA2B971CDE8A3CBEBAA98A56F63421F886641282F0091AF6FCCF0AACFF0A9
D3E8A3D9E7A9919E66CFDBABE7F2CA171F00D9DFB9ABB289
00040023291B6C705FD4D6C1888B700006006D784DC7DBA6CAE7A7C6EAA4C3EC9EC5EC9D
C8EB99CAEA97D0E797D3E695E0EF9ED0E095C6DB9ADAF6BC9FBD89163604082600678346
C9E090D2DE9E6B695A1E161487816BF9F5DCFFFBEFECE7E3E0DBD8C8C2C2F0EFEBF7FAF3
FCFFFBF7FCF8F6F8F7F1F1F3FCF7FDFEF8FAABA8A3F0F3E2FCFFE6CFE0B3C1DAA0D1EBAA
C2DB97E4FBB5C8DF97D2EAA0BFD78BADC57952681FAEC37ED9E9ABC8D5A0E1E7C1FFFFE5
FFFFF3FFFCFAFFF6FDFFFAFF938988EEE5DEABA29BBCB3ACFFFDF6FFFDF8EEE4E3B2A7AB
EAE1E6FFFDFFFFFFFDFCFFF6FCFFEFE5F0D2C8D7B0D1E5B0CCE7A2CAEA9EC4E99CC2E79A
C9E9A0D2E39FCEC58CB1AB71C9E49FCFF0A9BFCE8BBEC786D9E8A3CCE69DC9EEA0C2E799
C9E399CDE19995A961CADE97D5E9A4D2E6A190A05F92A263D8E8AA8F9D6234410976834D
2A34006E78449BA571D3DCAFD7E1BEDEE9C7C9D7B3BCCDA3CFE5B4DCF5BCCFEDAFC8E8A5
C8E9A4C8EAA0C6EB9EC6EB9DC8EB9BC8EB99C8EB97C9EB94D2F496B8D67CD8F3A6D0E6A6
C7D9A9909E7DF5FCEAFCFFF6FEFFF8FEFFF4FEFFEDF3FAD8EFF8C9C8D69996A560B4C881
D5EBAB60783ADFF7B9BFD897D0E5A4D3E3A2A9B273A8A96DD4CF95C9C087D9D29BB3B079
A2A56EBDC890D2E4AAC5D99E97A66D6C7B446775428B97677580556D784D2733039CA974
92A168D6E8AACBE29EC9E29ECBE5A4ADCA8A0521001E3A0099B57A758F508CA563677E3A
61772F6278302A41005C773466864533400A5937144723014A4C1B556F32CBEAA7C6E59F
C3DB91DBF1A98BA163D0E7B1C2DCAF253E1697B18A8FA984
2B31250003002E3221DFE2CD6C70550B1200616E42CCE1A9CAE7A7C8E9A4C6EB9EC6EB9B
C9EA99CCE997CFE897D3E695CFDB89D0DB8FE1EFB1A2B57D8AA369C7E2AB536E3B879F65
9EB366798543787A642B271E2F290F908B6E7F776C88807D807876948F8CB4B3AEADAEA8
D6D8D3C6CBC5FEFFFFFFFFFFFFFDFFDBD5D7E8E4E1FEFFF1FCFFE8D0E1B5DEF7BEC5E2A2
D1ECA7BFD990D2ECA2C7E295D8F3A4C9E495ABC37771873FCDDD9EF5FFCCE5EAC2FFFFE6
FFFFEFFBF0EAFEEFF2AE9FA2FFFBFAFBF2EDEAE1DCEAE1DAE8DFD8C3BAB5C6BCBBFFFCFF
FFFDFFFFFDFFFEFDFBFAFDF2FCFFEDE5F3D0C9DAAED4E9B1C5E39DC8EA9DC7EC9FC4E99C
C9EBA1CDE19CC4BB82A19C62CBE6A1CAEBA4C8D7949FA867D3E29DC7DE96CEF0A3C9EB9E
D2ECA2D0E49C7C9048D0E49CDCF0A9D5E9A4CDE09EAFC2809AAA6B85955786955A526128
6E7B4366733DCBD8A2D9E5B7FCFFE6F8FFEBFBFFECF9FFE8F7FFE3D8EEC0C0DBA8CBE8AE
C8E8A7C8E9A2C6EB9EC6EB9BC8EB99C8EB99C8EB99C9EB95C7E98BD7F59BC4DF90DFF5B5
253707DAE8C7D5DECBF9FFF3F7FAF3FAFDF2E9EED8DAE1C0DCE5B6B6C1878B9A55A5B670
001000617A39CCE5A4D1EAA8CDE4A0D8EBA9DCE6A7D4D89BE0DEA35E5921A09D66E3E3AD
D1D8A2BFCE97D1E6ADC4D9A049582179834FDAE3B4DCE8BACDD8ADCCD7ACDBE9B8899762
B9CB8FBACF8ED8F1ADCFEAA5CCE9A7D3F1B19BB97D7C995F8AA66C4D692C637B3D5E7735
8EA35EB9CE89849B5799B2706A884AA5AF7B7C5836916A494544149AB276C3E09ED3F1A9
E2FAAEC0D88CC9E4A1AECD92C8EDBA8AB3874A775080AE89
292E1A0004000F14000006000007000009005E703ED8F0B6CCE6A5C9E8A2C8EA9EC9E99D
CAE99BCCE999CFE799D3E697DEE99AD5DD92D7E3A55E6D348CA166DCF4BA59713F536A32
D7EDA57D8D4F8B9273E3E4D2B7B69A2A260D0901000700000600000B0603030000020300
090C05000200656766FAF8F9FFFDFFE5DFE1FBF6F3FFFFF4F0F9DEF5FFDEEDFFD1CAE6A9
C1E09AE3FFB7B5D488BFDE90D9F8A8C3E292CDE99CCDE49C8C9F5FC8D7A0DFE6BAF7FBDA
FFFFECFFFEF3FFFCF8D0C5C3FFFDFBFFFBF8FFFEF8FFF9F3F3ECE6FDF5F2F9F0F1FFFCFF
FFF9FDFFFEFFF9FAF5F7FDEFFBFFEAE9F8D1D1E3B3D2EAAEC6E19ACAEA9EC7EC9FC4E99C
C9EBA1CFE49FC6C086A2A065C8E6A0CBEFA7D2E19E9FA565D3E09BCCE29ACAEA9ECBEDA0
C9E399D7EDA44F651CC9DF96D1E79FC0D590ECFFBECADF9CD1E4A4DDEFB13B4D0F55672B
89985DCDDCA3D2E1A8D7E2B7FEFFEDFFFFF6FDFFF5F4FDECECFAE1EBFCDCD9F0C6BCD7A4
C9E7ABC8E9A4C6EB9EC6EB9BC6EC99C6EC99C8EB99C9EB97CCEA90C7E38CD9F1A5596F2E
445624D0DFB8FBFFECF1FAE5FCFFF3FCFFEFE5EBD1DBE3BECBD4A5ACB77F8B9757647531
000E00D9F2B0C2DB99D9F2AEBED591D0E49FE1EDABD8DEA09A9B5F54531A9FA067E5EAB2
C4D199E9FEC5DAF6BC4B642B1F2C00A5AC79C8D09FDEE7BA5E6A3C071400495A26D6EAAF
D4EAA9C5DF98D9F5ABC6E49ABEDC96C0DF9CD8F6B8C7E4AAD5F1B7C2DEA3D6EEB2D1EAA9
D0E5A2D6EBA6C6DB98C9E2A1DAF6BBD9E1AE845D3C6C432307050063773CD4EDACC9E39C
C5DA8DD1E89A8CAA648EB274B9E8B2B9F1C248865D78BC95
BAC1A07077558A926D939E746A77498EA06CDCF1B6C0D998CCE7A4CAE8A0CAE89ECAE99D
CCE89DCDE79DCDE89BD0E69BD8E498D5DF98929E5EACBB80CDE1A6CDE4ACC6DEAA49642D
BED89BE9FEC6B0BF988E9778DBDFC4BCBBA7C6BFB7B6AEACFFF9F7FFFEFBF7F4EFFFFFFA
D1D4CD9497900000005E5C5DFFFBFFFCF6F8E3DEDBF9F6EDFEFFECF9FFE4F1FFD8CEEAAF
CEEFA8B2D487D1F4A4D2F5A5BADD8BC9EA99CDEC9ECEEA9FAAC17D93A56BD3DFAFDBE3BC
D0D3B6D4D1BEC3BDB1F4EDE5FBF6F2FFFEFBFBF3F0FAF2EFFFFDFAFFFDFBFFFCFFFEF8FC
FCF7FDFFFEFFFEFFFAFBFFF2FAFFE7E7F8CCD0E5ADC7E09FC9E49DCBEA9EC7E99DC1E699
CAECA2D8ECA7D6D096B7B57AC4E29CD1F5ADDCEBA8B0B676D8E5A0D7EBA4C5E498CBEB9F
CEE89ECDE39A657B32D2E89FD0E69ED4EAA2C5DA95CDE29FC7DC99DCF1B0B1C685A8BC7D
D8ECADD3E7AAD2E6A9CEDBAFFFFFF3F9F8F6FFFFFDFCFFFAF7FFF4F8FFF1F5FFE8DFF6CA
C9E6ACC8E9A4C8EA9DC6EC99C8EB99C8EB99C8EB9BC9EA99CAE793D5F09FCAE2986D8342
D0E3ACCFE1B1CAD9B2D8E3C1CED9B9D1DABBD9E0BEDDE5BCB5BE8FA9B37EAAB57B606E30
677C3BCCE5A3C6DF9BD7F0ACCDE49ECEE39ED6E5A2D3DC9B7D81469A9B61D2D59ED6DEA5
DBEAB3C9E1A7BBDAA1355117A8B27DB5BA848E95629BA372939F6D818F5ABCD095C6DC9C
C9E39CDCF8ADC1E092C9E99DD5F5AAC6E59FC2E0A0CCEAAEC7E2ABC9E2A9C5DDA1D5EBAB
CBE09DC6DB98DDF2B1C9DF9FD5EEB4C7CE9B350C00572C0CDDD9AAD7E9AFCCE2A2D3E8A3
DBE79BD3DF93B1C77F54723492BD87B2E8B711542970B892
DEE6B3BCC692AAB781CEDDA2C9DD9ED5EBAAC7E09CCDE8A1C7E198D0EAA1CCE69DCDE79E
D0EAA1CCE69DCFE9A2DBF2AACCDD9764732E82934FCDE1A2D5ECB4C3DCA5C8E5AD92B07A
C4E4B5C7E4B6CCE7B4D1E3B9FBFFECF9FBEECECBC64B4643FFFDFBFFFDFBF4F1ECDDDED6
C4C7BEE1E4DDD3D3D1020001FDF7FBFFFCFF9F9697FFFFF6EFF4E0D5E3C2C8DDB2CFEAB3
CFF0ABC5EA9CC5EA9AC6EB9BC2E895C5EB98CAED9DC5E599CEECA4C2DB9A52652ED4E4B5
CED8B3D7DDC1F3F5DFFFFFF1FFFFFAFFFEFBFFFEFBFFFEFBFFFEFBFFFEFBFFFDFFFFFDFF
FDFBFFFFFFFFFCFFF6FBFFEFF9FFE4E7F9C9CCE1A6CEE7A3D1EBA2BEDA8FCDEDA2CBEDA1
C1E198DCF0ABE5DFA5949257D3F1ABC3E79FD7E6A3919757D7E49FCBDF98E1FDB2BEDD91
D7F2A5C4DC904B6319D2EAA0CCE39BD1E8A0D1E8A0CCE39DCCE39FD0E7A3D3EAA6D1E7A6
CDE3A2CCE2A2D0E6A6D6E6B9FEFFF3FFFDFFFFFFFFFEFFFFF8FEFAF9FFF6F6FFECE1F7D0
CAE5AED2F1ADC8E89CC2E591CCEE9AC8E998C2E296D1EFA5D3EDA4C5DC96C8DF9BC9DF9E
D9EDB0C7DBA0CBDEA7D9EAB6D5E3B2C9D7A6D7E3B3C4CD9EB6BF90DBE3B2656D3C727F49
DBEFB0D6EFADB8D38EDDF6B2CEE59FC6DB96DFEEAB4C571550561AECF0B5D0D39CE0E9B0
D0E1AAD8F1B700120059763C89945A959A60D1D9A0CED7A0DFECB4D6E8ACBED493CDE99F
C8E799CCEE9AC8EA96C3E591CAEB9CB8D88DD0EFABC9E5A8C5E0A9C6DFA8D2EAAECBE1A1
D3E8A7C7DA98DDF0B0596D30000E001B1F009F7356E0B394E7E1B1CDDFA3BCD291E3F4AE
E3E39BE0DC95D9DE9C59672A88A36EBBE2B54D815A457E5B
D5DE9FA7B270BECD8ACEE29BD5EFA5CEEA9DCCE89BCCE89BD0EB9ED8F0A6D3EAA2CAE199
CAE19BAFC8846B8641334C0894AB67B9CE89DCF3ADD2EBA9BED79ED0EDB5DBFDC14D723C
8AAE88CCF1C8CDF1B4C4E1A9F5FFEDE8EFE77473710B050519110F645C597E7B74686860
DFE0D831342B605F5BF8F4F3FFFDFFECE3E6E4DBDCFFFFF8FFFFF1D5E2C6D0E2BCC5E0AB
BADA97C3E89BCBF0A2C8ED9DBDE292BAE08DC3E898CFF1A4CEEEA3C7E4A17D975896AA75
86976AA8B790DBE5C3F9FEE7FFFFF8FFFEFDFFFEFDFFFEFBFFFEFBFFFEFDFFFDFFFFFEFF
FCFBFFFEFFFFF9FFF5F7FFE9F7FFE2E2F6C1CDE6A5D2ECA3D4EAA1D0E89EC6E298D5F3A9
90AE665D6E2A999057ABA66CBAD892C2E69ED1E09DA0A66695A25DD0E49DCAE69BC2E195
D0EB9EC5DD916C843AD2EAA0CEE59DD0E79FCFE69ECDE79ECCE69FCCE7A2CDE6A2CBE6A1
CEE9A4D7F2AFE6FFBEF5FFD7FCFFF2FDFBFFFFFEFFFEFFFFFBFFFFF9FFFBF6FFF0E1F5D0
CBE4ADC8E6A0C3E294C4E692CCEC99C8E797C3E197CBE6A1C5DE9DB6CC8E4C6224D8EEAE
C7DC9BD0E5A4E1F6B5C3D897F3FFC7F8FFCCF1FEC6889560C8D09F9BA3741C2300CDD9A9
BED297C9E2A0DBF6B3CFEAA5C9E29ED0E5A0BCCB88495314979D5FE5E9AED5DAA0D4DDA4
94A86D35511650743798B67A7A86488B9151E1E9ADD9E5A7DBEBADC9DF9EC7E399D1F0A2
C6E892C4E890CBEF97C9ED96C9EA99DCFAB0CAE7A4CEE8ABC9E0AAD2E9B3DAEFB4C4D899
6D80401929000818009EB07496AE74BDC18F926747BB8D6CDDD7A7DAEAACD9EFAECEDF99
D0D08ADED791E8E9A7879154C5DAA2C9E9B85C865E1C4B27
D9E19894A056D5E59ACCE393DBF8A6C5E592CFEF9CCBEB98D5ED9FBDD388E1F5AD859954
94A966B1C786C4DE9DDEFBB9C7E1A0D3EEA9C7E399D1EFA9C8E6A8B2D498C3EAAB517C46
537C5CB0DAB6BCE9A4BCE3A03E52392E3732A1A19FFEF8F8C1B7B6E3D9D7DDD8D2B1B1A7
A0A297A0A39AA7A6A2A4A09FCBC2C5E6DBDFFCF3F4F3F0EBFFFFF3F0FDE3F3FFE0D6F0C0
D1EEAED0F0A7C6E89CC5E79ACEF1A1CCF1A1C5EB98C6EB9BC7E99CD0F0A7DBF8B5C2DC9F
BBD29CD2E6B5E6F9CBF9FFE6FFFFF6FFFFFDFFFFFDFFFEFDFFFEFDFFFEFFFFFDFFFFFEFF
FEFEFFFEFFFDF7FFF2EDF9E1E6F8CED5ECB4CBE59ED3EB9FCBDC95DCEDA6E2F9B1B6D087
59732C5C6826594E169C975DD2F0AAD8FCB4CEDD9AAFB5755D6824D1E29CC3DF94D3F2A6
C9E598C5E09398B366CAE598CFE99FCDE79DCBE59CCFEBA1D0ECA2CDEBA3CCE7A0C7E59D
C7E59DD0EEA8DDFBB5EAFFCBFDFFF0FDFBFEFFFEFFFEFFFFFCFFFFF9FFFDF7FFF2E0F4D1
CDE6AFC8E39ECBE898CDED98CBE896CCE89BD0EBA4CEE6A8D5EAB281935FD7EAB3C2D69B
CFE5A5C4DB97C8DF99DBF1A9E0F4AFFBFFCAD6E4A776834BB3BB8A6F764A3C4119DBE4B9
D1E6ADDCF6B5C7E1A0D0EBA8CBE4A0CFE4A1A9B8775C6627BAC082E2E6ABCDD298404910
30420896AF75D6F8BBC8E6A6B0BC7A989F5BD9E4A2D3E29FD0E49FC5DF96D1F0A2C6E995
CEF59CC5EC91C7EB91C6E891C7E696CBE79DC4DD9BC6DEA2D3E7B2D5E7B397A96F607032
566524CEDD9CC9D799D8EAACD2EAAEE7E9B89469478A5C3AD7D19FB8C8898AA15DCADE97
E7F1AAE5ECA6D0DB96889B59D4ECB0D2F0BAA4C89C4A7049
E1E9A0919B52DBEDA1C8E190CEEE9BC1E490CCEE9ACDED9AD5ED9FCBE095C9DA93C9DA94
CADD9BCEE4A3CCE6A5C2E19ECCEBA7CDECA6BADA8FC6E69BD8F7B3C6E9A7BDE5A7507C49
5C8968BEEEC6BDF0A3A9D48C000C005B655DFFFFFBFFFDFBFFFAF9F6ECEAD8D3CD9A9A90
AFB1A694968B7A797494908FE7DEE1FFF9FFFBF2F5FFFEFBFDFFF2FBFFEFF7FFE8C3D9AB
C4D99ECFE6A2CDE7A0CCE89ED4F0A5CDEC9EC5E697CBEC9DC3E495B7D78BCFEFA6C3E09D
CDE7A8D3ECB2DBF2BAF7FFE0FEFFF4FFFEFFFFFEFFFFFFFDFFFEFFFFFEFFFFFEFFFFFEFF
FEFFFFFCFFFDF7FFF2E4F2D8D6E9BCCAE2A6C6E298CDE597DFECA4DDE8A394A55F647A32
374C07A2AD6B776A33A59F65C2DD98C1E59DD2E19EDBE1A196A15DD1E29CD3EFA4CDECA0
C8E497C6E194BDD88BB9D487CFE99FCCE89DC8E49ACDEBA1CDEBA1CDEBA1CDEBA1C9E9A0
C5E59CC3E59BC5E59CCAE3AAFCFFEFFEFEFCFFFEFFFEFFFFFAFFFFF9FFFFF8FFF4E2F3D1
CDE4AECCE7A0D6F1A0D2EE99C6E190D1EBA1D8EEADC3D89F9EB07E9EB080DEF0BECDE0A9
D7ECB3D5EBADDCF2B2C7DD9CE3F8B7F9FFCCE8F7BC707D478C9664878E62161B00656E41
6A7F47849E5FBBD596CFE9A8D3ECAAC7DE9ADEEDAC4C56176F7537D6DA9DEEF2B7000A00
6A793ED6EEB2AFCF90CAE7A5DFECA7A6AD67C6D18DD9EAA4CBE199C9E59ACFF09FBEE48D
C8F097C5EE92BFE68BC7E993DFFBB0BDD692DBF1B3CCDFA7CFE0ACC2D39D2F3E05758346
C8D494CBD795E8F4B4D0E0A1D0E5AAC6C896A07552855934C0BA8695A86689A058DAF4AA
C8DC94C4D8909FB66E92AD66CDECA8C8EAADBDE2AE4C7243
D4D999939C5BD6E7A1CDE79DC2E296C8ED9DC8EB9BCBEA9ACAE296D0E298596922E2F1AC
CBDC98CDE4A0E1FCB7C2E19BBEE396C9EEA1D2F2A7C0E094CBED99CEF3A5C1E9AB74A06F
3A6A42AFE4B0C5FAA885B1641A340DC4CCBDFCF9F2FFFCFBFFF9F9FFF8F6FFFEF8FFFFF6
F3F5E8FFFFF6F1F0EBFBF6F3FAF1F4FFF9FFFFF6FAFFFEFBE7E9DECCD5C2F7FFEAC9D9B2
D9E6B1DCE6AAD4E0A2CCDB9ACCE099CDE39ACFE79BD4EFA2D7F3A6C9E89AC1E094D1ECA5
D0EBA8CEE8A7D6F0B1EBFED0FCFFF4FFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FEFFFFFCFFFDF8FFF1E2F1D4CDE0B2C8E1A0CBE79ACEE595D5DC96C8CB88354000A6B570
A9BA76D7DD9DA998629D925ACBE4A0BEDF98DBEAA7E1E7A7CCD79391A25CD1EDA2C0DF93
CCE89BC8E396CDE99CA2BE71CCE89BCEEA9DC9E59ACBEA9EC7E69AC9E99DCCECA0CCEEA2
CAECA0C6EB9EC6E89CC8E4A9FBFFECFFFFFAFEFFFFFBFFFFF7FCFFF9FFFFF8FFF3E4F5D1
CEE3ABCBE59ED2EB98CDE692CAE392D7EEA6C7DB9C95A871718152EDFDD0D7E8BBF8FFDC
D9EDBCBDD1A0E0F4C3C7DBA8E2F4C2F9FFD8E3F1C0D9E5B5B2BB8CAAB283C2C89A747E4C
677C44405C1F688447D8F2B3B7D08FDDF3B2CBDA99939D5E6A6E31DCDDA1CBCC90757D41
354306CEE4A6D1EFAFD3EDACCBD8939CA65FB1BE79E7F8B2CBE59ECAE89EC7EA9AC8F09A
BDE58DCCF49BD2F8A1C5E697C7E29DCCE2A4DBECB8D5E3B2CEDCAB020F0078834BCAD497
646F2D808B49838F4D7A8A49CFE5A7C5C8938B613BBF936CDEDBA4D9EEA9D8F2A8A5C478
DCFCB3C2E49A88AD60A7CD80B8E193C3EDA5D4FCBE6D965C
ABAE79929A61CFDFA1D7F0AEC2E39CCFF5AAC5EA9DC6E599CAE298A5B66F99A660DDEAA4
D6E7A1C2D993CBE9A1D6F8ACD2F7A7BCE191CAECA0C6E796CAEE8CBFE389B3DB9F8BB689
598A5BB8EEB0B4EA94BFEC9B000F00050D00CBC4BCFFFBFAFFFBFBFAF0EEFFFEF8F9F6ED
FFFFF4FFFFF6FFFFF8FFFEFBFFFCFFFFFBFFFBF0F419131306060000070077856BD8E6C2
7477489C9B65D4D59CEDF3B7DDE6A5D0DD98CFE099C9DE93BED688D3EE9FC6E194DBF5AB
CAE49BC8E39CC9E49FC7DBA8FCFFF3FFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFEFFFF
FDFEFFFBFFFBF8FFF3E4F3D4CDE1B0CDE8A5D2F1A1CFE694E4E7A2B1B06F4E5311D1DC98
D6E2A0DCDE9FAD9964A59861D2E9A5CDECA6E1EDABC9CF8FD3DE9A5A6B25C7E398CEEDA1
CFEB9ECCE79ACEEA9D92AE61CBE79ACCEB9DCAE99DC8E89CC9E99DC8EA9DC8EA9DC6EB9D
C7EC9FC9EEA1CAEFA2D0ECAFF7FFE4FAFDF2FCFFFBFBFFFFF5FDFFF8FFFDF7FFF2E5F6D2
D4E9B0CDE49CCAE38FCEE690D7EE9ED9EDA6B1C387798A56D1E1B2F5FFD9F8FFDDE3F3CC
F7FFE3DAEBC7CCDDBBC4D5B3E5F4D3EDFDD8F1FFD9CDD8AED9E2B5A0A676999D6BC2CC97
CADFA6C8E4A9000F00698548CBE5A6CFE5A5DEECAED3DC9D444509E1E1A5E0E0A4A9AF71
859355CADE9FDAF7B5CAE3A1CCD994A2AC6797A45FC3D792C9E49FCDEDA4C4E99CC8F2A0
CCF6A0BDE58FC0E595C3E398D0E9A8E0F3BC535E3300080000080057612CCCD59CD6DEA2
ABB473DFE8A5D4DF9DE1F1B04359198F945C774D27BF956DCBCA91D3EAA28DA95CD4F4A8
B6D58F91B26D81A357CDF2A4C3E898C4EA9DC0E5A05A7E3E
848259949A6ED0DEADD6EFB6C4E6A9C9EEABC9EDA7C5E49ED1E6A184934EE0EBA6C6D18C
E9FAB3D8EFA7BDDB91C0E393B9DF88C4EA93D0F0A5CBEB98D2F786D2F790BDE2AC507951
B7EAB1BBF3AABDF39BB5E291D7F0B9CCD3B4170D032F1D1B372928180E0C0600003F3C33
79796DF8FAEFFFFDF6FFFEFBF3EAEDA99EA4291E246F6969A6A69E07100078866DC8D3B1
938E6463572757501C78733CA0A064D8DD9BEEF8B3CFDC94D1E397DDF4A4D1E89AD3EB9D
C7DF93CEE89ED6F0A7D9ECB5FCFFF3FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFFFF
FEFFFFFBFFFBF9FFF4E4F5D5CAE1ADCEE9A4D1F19EC5DD8991924C817C3CB6B676DEE5A2
DBE4A3E1E1A39B86516558218DA460C0DF99D9E5A3D5DA9AE9F4B0899A54C5E196D5F4A8
CDE99CCFEB9EC9E5988CA85BC9E89ACAE99BCCEB9DC7E899CCECA0C9EB9EC6E89BC3E89A
C3E89AC3EA9BC5EC9DC9E7A7E4F2CFF0F4E3FCFFFAFBFFFFF6FFFEF8FFFDF5FFF0E3F5CF
D5EAAFD0E89ECDE591D4EC96D7EC9DC2D38FA7B67DA0AE7DC8D8A7EDFDD0EAFBD1F8FFE4
F6FFEBD8E7D2D8E9D7F4FFF3F3FFF0F6FFEFECF9DFEFF9D6E5EEC39BA26FA6AB73DEE7AE
D4E9B0C7E3A96A884C000F0097B172CAE0A0D1DFA1D4DD9E6B6C30B8B87ADCDC9EDADEA1
818D4D99AC6CB4CF8CDDF6B2E2EEACC4CF8B9DAC6B94A966CCE7A4C9EAA3C7EDA2C0EB9C
BAE593C4EE9CD3F8ABCBE8A5BED39A8D9D6E8A926D7D85608C9367D2DBA69CA46B72783A
D6DD9ABEC8838C9753CFDE9BD8EEADE2E7AD9F754DA0764CE3E3A7DFF7AD3A5707C9E59A
DCEEB08797598C9D59D3E89DC6DD8FD0E89CD9F2AE8CA764
6B734494A070D1E5B0CDE9AFC4E6A9BCE19ECEEEABCBE6A1C7DB96C1D08BD4DF9ADCE9A3
C5D991CBE59BD6F6AAC1E895C3EE92D0F89FC2E498C6E798C7EB87BEE386CBF0BD558055
BDF1B3B0E99CC0F69ECDFAA7B7D693DEECBBF5F1D4F0E8D3FCFAE1D7D7BDFCFFE4CCD0B7
90957F0004000101000300001A1512726C6CFFFCFDFFFFFA67695BE9F3DBE3F2D3D6E0BB
A69D749F8E60B0A4749A955E5C5C206E7434B8C37ED2DF97D9E9A0CCDE92D2E49AD1E399
D6E7A0D3E49ECADE99D1DFACFEFFF1FFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFBFFFF
FBFFFFF9FFFBF8FFF4E4F5D5C9DDACCDE3A3CCE79AB9CC7D5D601B7D7E3CD8DF9CD0DB97
DDE8A6D8D99DD8C48F64551E8E9A5CDDF2AFD4DE9FD1DA99D8E7A4B2C880B1CB82C7E398
CAE69BD2EEA1C7E2958CA85BCCE89BC9E89ACCED9EC6E999C3E89AC2E99AC3EA9BC3EC9D
C6ED9EC6ED9EC5EA9CC7E4A1D7E4B8E8ECD3FCFFF2FCFFFAFBFFFCFBFFF8F4FFE5E3F4C7
CEE2A3D0E69BD1E898D7EC9FC6DA939EAE6DA3B277D8EAB0D5E9AECCE1A8CDE1B0F2FFDE
F3FFE8F7FFF3F1FEF4F6FFFAF3FEF6F9FFF8FAFFF0F4FDE0E8F0C9E3EBBA8B935ADAE6A8
C4DD9BCFEEAACCEBA88CAA6A132D002D4106CEDBA3E1E6AE75733A9F995FE8E2A6E3E3A5
D5DE9D9EB16FD9F4B1BBD993D1E5A0DBECA8C6D9978DA460D8F3B0BFDE98CBF0A3C4EB9C
C7F0A1C9EFA2BCE096C9E6A4D4E7B0121F00848A667A7E59949C69959F63D7E1A2DEE7A6
D9E49F88934EE5F2AC8CA059C6E19CD9E1A5C5A074AD875ADFE0A4C6DD958DA95ED1EBA2
DBE6AA6F743C97A061DBE8A3D4E59ECBE199CAE4A37A9757
AAC784CAE7A4CBECA5CEEFA8C3E79FC1E399CEE9A2D2E8A0ABBA75C2CF89CEDB95CFDF98
D2E89FCAE99DC2E99AC3EF9ABBEA8EC8F49BC2EB9FC1E6A1C8EDAAC4EAADBFE9B9517F4E
B6EDACB6EEA3BCF39FC8FAA3BFE695C8E69CDAEDADCEDE9DCDE39AD0E89ECFE4A3D0E3AB
D7E7BA677250898E787C807193958AD6D8CDFEFEF27F826F636C4FD0DCB6C7D7A8E0EAB8
A79F71998B5CF3EDBBDDDEA59BA568536221495D18A2B66FCFDE99D9E6A1E0E9A8DCE2A4
D5D99ED9DCA3E7ECB4F5F8CDFFFEEAF4F4ECFFFFFAFAFFFBF9FFFFF8FFFFF1FCFFF3FFFF
F5FFFFF1FFF7F7FFF4CCDBBEDAE7BCDDEAB5D1DCA06E7937798440B3C27DCFE49FCFE6A0
CFE2A0DBE1A3BEB17C655420A89E69D5D49BDEE7A8D3E4A0C8E29BCEEAA0889F57D6ECA3
CFE99FCFE99FCFE79D88A056CCE49ACDE99ECBEB9FC7EC9ECAF3A4BFEC9BB7E695BEEB9A
C7F2A2CDF4A5CCEEA1CCE69FCED7A0FFFFDCF8F6E1FFFFF4F6F6EAEFF2DDF5FFD5DAEAAC
DDEEA7D8EDA2CEE19FD0E2A6B1C389485A1EDBEFAAC8E096CEED9DC7E79BCEEDA9D7F3B9
DDF4CAF5FFECF0FDECF9FFFAF8FFF8FBFFFAFCFFF4F7FCE6E9F0CFD7E0B5929A67A3B374
C8E591C5E98FC6E999CEEFAA6F8B503446146B7246DAD7ACA395687D6B39CFC089E1DB9D
D1D895697E39C6E7A0C0E59FC7E6A0D3F1ABC3DE99C6E19AAFC980C6E297D7F6A8BFE08F
C9EC9CC5EA9CC0E298D1EEACD3E6AE344010C5CAA1939667D6E0A1D0E097E1F1A8CCDC93
CFE1979BB065D2E89D85A156C4E69ACEDD9ABD9F6DAB895BD0D195DEF5B177924DD9EEAB
D0D89C87884F8F975CCEDC9FD6ECAED3F1B5BCE2A98FB782
C1E698C5EC9DC2E799C8ED9FC8EA9DC1E094D8F0A6A5B9718F9F58C1CE88DEEBA5D6E7A0
CAE49AC5E599C0E99AC3F09BC4F097C2EE97C4EA9FC6EAAAC4E6B3BDE1B1C9F0C16F9B68
85B77AC1F6B0BBF0A2ADDC8BCBF29FCAEC98C2DB8AD5EE9ACBED8FDAFD9FCAE795C2DC95
D6E9B2DEEDC4D7E2C4EDF5DEEAEEDDFEFFF1E2E7D1040D00FBFFE1CDDDAEECFDC7C0CB93
A49E6C9F9564DDDCA6C8D095D0E0A1CFE4A19AB16B8A9F5A778844818C4AA2A86AD0D197
E5E4ACE4E3ADEDEDB9FFFFD8FFFFEAFFFFF4FCF9F2FFFFFBE3E7E8F9FFFFDFE9EBF7FFFF
E9F5F5F8FFFDF6FFF1F7FFE8CCD2B0C9CFA3A7A978777C42C9D897CBE29AC7E59DCCECA3
D0E7A3D8E2A3C7BD887F6B396C5826E9E0A9D8E0A4D0E5A2D7F5ADC9E79F93A961C8DC95
CEE69CCEE69CD4EAA192A85FD6ECA3D2ECA2C8E79BC4E99BBAE595BFEE9DC6F7A5C5F4A3
BEE999BADF91C0E094CDE39BD0D99AA7A676ACA88BD1CEBBFFFFEFF1F4D5D2DCA7CFDE99
D1E495BED386D6E8AA879A6295A773CDE1A6CBE198CFEB97C7EB93C6EC95CBEDA1CCEAAC
D0E7B9F5FFEAF0FDECFBFFFAFCFFFDF6F8F3FEFFF8FEFFF1F0F6DAD0D8B3D6DFB2879759
D7F39FC7EA90D0F3A3C0E19CD0EBB4BFD0A3838A61E9E3BFB4A27C6A5329A79361EDE2AA
757B3D425714BBDF99CBF5ADC2E7A1D3F4ADCAE8A0CEEAA09DB56BCAE296CEE99AD3F2A2
CFF0A1C9EB9EC7E79ED2EDAAC4D89D323F0AD8DBAE989C69D4E19CD5E698C7D98DD0E598
DAEFA488A0548BA65985A559CDF3A6D0E49FBCA06EB79766EAEEB3B3C988DAF3B1C2D796
E3E9AD9FA0668E965BCBDAA1CFE8AFBEDFA8C5F0BB679763
CFF1A4C3E89AC4E699CBEDA0CEEEA2C9E59ADEF6AC8B9F578F9F58C6D68FE2F2ABD3E79F
C7E197C7E79BC2EB9CC2EC9AC6EC97BDE08ECAE89ED0EDABC5E0A9BDD9A6C8E8B7719663
567E49A1CD92CCF6B6BEE6A0C5E59CCDE59BD2E297D6E99ACDEA96C1E38DD2EEA3D1EAA8
C3D8A0D3E4B8D1DCBCDFE9CED9E1CADDE5CD737C61000900F3FFD5C0D09FCADDA6DCE9B1
969461A59F6BE6E6B0DCE6AADBEEAEDAF1ADBED891CBE29A596D265763216770318A8E53
9C9F66999C659CA169ABAC80EEE6D1E6D9D0FFFCF6FFF8F5FFF9FBFFFDFFFFFDFFF0EFF5
FFFEFFFEFEFCFBFBF1F1F0DCF7F6D8EBE9C358552AB6B984FCFFCADBF5ACC6E69DC9E9A0
CAE19DDAE4A5CCC28D7462304F3D0BE3DAA3D9E1A5C2D995D7F5ADC5E39B8DA35BD5E9A2
CFE59CCCE49AD4E8A08A9E56CEE29AD4EAA1CAE49AC7E79BC7EE9FC3EE9EBFEC9BBDEA99
C1EA9BCBEDA0D6F2A7DFF3ABE9F2B19EA16AAEAE8AA1A187F4F6DEF7FDD9CFDAA0DBEBA4
CBDE8DE0F5A6DAEDAB4F6326889B63C2D898D5EDA1C9E591C5E793CAED9DC9E8A4C9E5AB
CADFB6F3FFE8F4FFF1FBFFFBFEFFFFF3F3F1FDFEF8FFFFF3FBFFE8E5EBC9ECF3CA919E69
C7DC9BD5F0A9C7E6A3B7D599CEE9B4E3F6C8C7CFA66B6742887A57715D38A8966EA1996A
2F34006A7E41DBFEBCBDE59FC4E8A2CDECA6CAE59EC6E09789A157D2EA9EC1DC8DD8F5A5
C8E99AC6E89BC9E9A0D8F3B0CADEA36C7944A6AC7EB3BA86BBC785C8D88FE0F2A8C8DD92
D4E8A0A6BE748EA85EAECE83C6EC9FC9DD988A6E3CD1B180DBDFA28DA460D1EAA8D8EDAC
CED7987F83489EA66BD4E3A8D0E9AFBADBA2C6EFB7679660
C6E89BC5E79ACDEDA1CCECA0CAE99DCEE89EC1D98F8A9E56B6C780D1E29BD5E9A1CBE198
CBE79CCEF0A3C6ED9EC2E799D2F1A3CBE397D7EDA5D4E9A6CEE2A5D6EBB3D6ECBB6B8757
1D3D0E608152B5D5A4C3E0AAD1E6ABD6E6A5D9E39ECDD991D0E89ECEECA2D6F1AEC9E1A5
C4D8A3E3F4C8DFEDC9B7C2A2A1AA8D636C4D75805EDFEBC5E5F5C8E7F8C4CBDEA7D1DEA6
8E8E589C9B63CCD197D7E5A7D7ECA9C9E39CBFDB91E2FCB3DFF5ADDAE9A4C8D391B1BA7B
A3A96D99A1658D975B8588595B5138E8D7CDFFF6EFFFF9F6FFFAFDFFF3F8FFF9FFFFFAFF
FFFAFFFFF9F9FFFCF6FFF8E9FFFBE19F9979625A33EBEBB9EDFCBBD7F1A8CCECA3C8EAA0
C2DB97DEEAAACBC48E5B4917604E1CB6AF78E0EAADC0D793CCEAA2C8E69E7A9048E4F5AF
D1E79ED0E69DD0E19A6C7C35B0C079D1E29BCFE79DCAE99DC4E699C3EA9BC3EC9DC6EFA0
CCF1A3CCECA0C5DF95BED28AA9B56DBFC587DBE1B3878B68ACB290E7F0C5D6E4A7D6E89E
D1E794D4EB997F954DC0D695DFF5B5D7EEAAD1E99BDAF5A4C8E799CAE9A3C7E3A6D6EEBC
DAEBC7F5FFECF8FFF5FCFFFDFFFFFFFFFFFFFEFDF9FFFFF6FFFFEDFCFFE5BCC09DCED6AD
D6E3B7D7E9B9D7EFBDC4DFACCCE6B6CBDEB0C6D1A7848661776C4C7465466E5F3E726A45
0C1200DAEDB6A8C889CBF3ADD3F4AFB4D48BE1FCB596AE64ACC279C7DD92D9F1A3C5E292
CEEFA0CFF1A4C5E59CCDEAA7BED49695A46D0109006F7843BAC688899853E3F2ADCADB95
C3D792D0E7A1D3EDA6C7E79ECDF3A8DDF1ACAD915F7F5F2EEEF2B5CCE5A1C5E09BD3E8A5
D4DE9F5F6527B5BF82CFE1A3CFE9ACCBEDB0B7E0A67AA76E
C4E499CBEBA0D0EEA4C7E399CAE49BCEE59D93A96191A55ED1E59ED3E7A0CDE39BC9E39A
CFEDA3CCEEA2C4E99CC9E99ED4EAA2D0DF9ADAE7A1CAD590CFDA98E4EFB3D0DDA856673A
001200253A1960755480916DD4E1B3E0E9B2D2D493DAE19ED0E2A4BBD397D5EDB3C5D9A4
D7E9B961714400080005110000070087926AFBFFDDC7D4A8D0E0AFD8E9B3D9EAB389965E
5D6228A3A96BCFDB9BCDE19CCCE69FD5F3A9CAE89EC8E499C9E197D2E69FD6E5A0D2DE9C
D2DE9CD7E3A3D3E3A4D0D9A45A4F33AD9A8BFFFAEFFFF9F3FFF7F7FFEEF2FFF7FFFFF5FD
FFEFF5FFF9FAF5E2DCFFFCEDDACEB85A5132FFFBD7FBFDCCD7E7A8CAE69CCEF0A6D1F3A9
C5E09BDBEAA9D1CC956E5E2B6A5A27948D56E1EBAED0E7A3C9E79FD0EEA690A45DD5E6A0
D0E49CD6EAA2D0E099515E1895A25CD2E29BD5E9A1CBE59BC4E397CBEDA0CCF1A3C7E99C
C2E296C9E59AD5EBA2DEF0A65B691CC5D28AE4EFB79EA778869166D9E7B4DBEBAACBE093
CAE08DD2EA96E2F8ADC7DE98D6EDA9C2DC93CDE899BAD787CCE7A2CBE5A8C9E0ACECFED6
F1FEE4FBFFF4FAFCF7FFFFFFFEFBFFFFFEFFFEFAFBFFFFFAFFFFF3DDDFC9A8A88EFEFFE6
F8FBE6FBFFECE2F1D2F4FFE3F2FFDDECFFD4E8F8CB0006000E0900948870574B356A6548
040800586A38C4E4A5CBF0ABCEEDA9CBE9A1D1EBA4B5CD83A0B46CDAEFA4D5ED9FC9E495
C1E293C9EB9EC5E79DCEEDA9D6EEB0D7EBB00E1B00616B36D3DEA25967297A884AE2F2B3
DDF0AED6EBA8E1FAB6B5D48EB5DD94D3E8A5BA9E6C765625D3D79AD0E9A5829D58CBE29C
E5F1AF818B4CC6D594C4D797C8E2A1D4F4B5BDE5A67BA768
CAEA9FCCEAA0CBE79DC3DD94D7EEA6C3D9918FA35CAEC27BCBE199CFE69ECDE79ED0ECA2
D1EFA5C6E69BC1E397D1ECA5D2E1A0D3DC9DE6EDA9DAE098DFE29BD5DA98A7AE78404B20
2A37192F3E278493806C7862484F2D484B1C9D9D61E3E7AAD9E6B1CDDFAFD5E6B979895C
0009005F6C40697449A5B085D9E2B5D9E2B5EDF9C9D6E2B0DEECB7C1D099D4E3AC283600
545E21C2CD8BE6F7B3D7EEA6BEDC92C8E89CCBEB9FCCEB9FD1EBA1CEE49BD5E6A0DDEEA8
DAEBA5CDE19CCCE19CDBE9AE827C58695940FFF8E4FFEDDFFFF8F1FFEFEBFFF6F5FFF7F8
C8AEAD523B355543374D3E2B61573CD2CCACF9F7D0E9F0BDD9E9AAC3DF95C4E69CD2F6AC
C7E59FCDDD9CD1CE97998C587D6D3A9D965FD5E1A3D7EEAAC5E39BD4EFA8C8DC95D0DF9A
CFE099D7E8A1D7E49E4C5712909B56D9E49FD8E8A1CCE098D2ECA2CDECA0C6E69AC0DF93
C7E398D3EBA1D6E7A0CEE0948EA14FD8EB9AD0E09FCBDAA193A26BD3E5ABD5E9A4D1E699
D5ED9993AB5789A153CBE399C5DF96D9F5AAC3E090DCF8ADCDE5A9D4EAB9D3E5BBF8FFE8
FBFFF1FCFFF8FCFCFCFFFEFFFFFBFFFFFCFFFFF9FDFFFEFDF6F2E9ABA99AD5D4C0FFFFF1
FFFEFBFFFFFBF9FFF1EAFEDBF2FFDCF2FFD8C1D5A2D7E4B9434327625B48564D3C9E9985
1B2100CCDEAED7F5B7C5E9A1BDDC96E0FBB4C1D890E0F6AE93A45DBDD287C6DC91D3EE9F
CAE99BCAEC9FCBEDA3C2E19BCBE5A4C6DC9E6A79423E4B15222D00EAF5BBA5B076B1BF84
D4E4A6CDE1A2BAD392D8F7B3C9F1AAD1E6A3A48856D1B180D1D598C8E29B77924BCDE7A0
A3B470B2C17ED7E8A4D0E5A2C6E19EC1E19ED4FBB88DB674
CCEAA0C9E59BCCE69DCAE098DCF0A991A55EABBF78CDE39BC6DD95CFEBA1CDEBA1CBE99F
CCECA1C8E89DC6E49AD2E9A3DAE5A9CDD196DFE29FDDE197D6D98CA6A962868B5172794F
9BA58C424E40B6C1B9D6E0D5ADB29B9CA179A2A36A4D5017B5BC92939D7A67714C404821
FEFFDDF4FDD0D5DDAEDCE4B3D0D8A5E9F2BDCAD39CD9E2ABD4DDA6DAE3ACB7C28A576228
909C5AD4E59FCAE199CEEA9FC8E89CCAEC9FC9EB9EC9EA9BD1EDA0CBE397CADE96CFE39B
CCE299C5DC94C6E298D6EBAAD7DAABADA882675E3D76684DB6A68FCBB6A5462F215F473B
B59F92F4E3D3FFFEE8FFFFE4FCF9D6F3F5CDE8EFC3D0DDA7D7EAA8CAE49BBEE298CAEEA4
C7E59FC9D998CCC992A39763978A569C975FD2DEA0D2E9A5C5E099CFE9A2C5D690CFDC97
D2E39CD3E39CD8E39E525C17989F5BDAE49FD5E09BD2E29BCDE39ACAE49ACAE69BD2EEA3
DBF3A9C8DC9492A25B5B6B20D1E890DDF7A0C2D88DD4E9A48FA364C9DE9DC9DF97CFE59A
A4BB69A4BB69CDE695D2EA9CDAF5A8C0DC8FD0EC9FC5E09BCFE3B0ECFCD7E9F6D8FBFFED
FAFDF2FFFFFBFFFDFFFFF8FFFFFAFFFFF7FFFFFBFFFDF7F9DDD5D2BAB6ADFCF8ECFFFDF7
FDF3FEFFFDFFFCFFF6E9FAD8C0DBA6CFEDB1D1EAB0D8EABA676C4C040200373123979481
3A41209FB181D0EDABC3E599C6E49CC6E19AD8EFA7C5DB93CEDF985D6F25D5EA9FCDE89B
C8E79BC3E598CEF0A6C4E59ED6F3B1D2EAACD9EDB097A66D737D48606A35828C57E4F1BB
D9E8AFCADEA3D3EBADC7E6A3CBF3ADC4D998937946A38553DDE3A3D2EDA6B4D28A8DA95F
849851C9DA94D8ECA5D9F0AACDE8A1BBDA94D4F9B3B5DD96
CCEAA0C8E49AD6EDA5D0E49DD0E19B51621CB9CD86D5EBA3CDE99FD5F3A9CAEA9FBFDF94
C8E89DD2F0A6D0EAA1CEE19FCCD59EA0A36C9EA15E9FA3579497485A5E146D7337B5BC92
97A08B0D1810414D4B69746E9FA895D2DAB5DBDFAC838651747855707358030600D2D6B3
F6FBD3BFC597979B69989D67686D35A8AD73D9DFA3949A5E9BA0669A9F676E763D505A1E
91A25CDBF1A8C6E096C9E89CC5E79ACBF0A2CDF0A0C7E899C6E295D3EB9FD4EAA1CCE299
CDE59BD4F0A5CEEEA2C5E099D6E6A8CAD39E9195638D8C60504B25655D39AD9F82B0A287
FDF2D6FFFADBFAF7D4FFFFDDFBFFD7E0EEBBDEF1BAC3D89DCDE29FD6F0A7CAECA2C4E89E
C8E6A0D4E4A3C9C890918551A194607F7A42D9E5A7D4EBA7CDE7A0CBE29C889752BCC783
DBEBA4CDDD96D3DE9956601B9DA25FD8DD9AD1DB96DCE9A3D2E39CD3E9A0CFE99FCDE79D
CDE39ABFD08997A45E6B7B30C9E38ACEED90CAE692D4ECA08CA35DD5EAA7D4E9A4D3E9A1
899F549FB668DBF2A4C3DB8DC7E295D9F5AAC2DE94D2EAACD2E2BBFBFFEAFBFFEDFCFFF3
F3F4EEFFFEFFFFFCFFFFF8FFFFF6FFFFFBFFFFFBFFF2E9EEC6BDBEF5EDEAFAF6EDFFFEFB
FFF9FFF9F1FEF7FDF1F7FFE4CEEAB0CBEAA7C7E4A2C9DEA66D75500A0A00302D1C6B6A55
020900889A66D3F1A9C5E898D1EFA5CEE8A1BFD68EDEF2ABD5E69F465710CBE095D2EA9E
D3EFA4C5E599CBEDA1C2E49ACDECA8C9E3A2CEE2A3D2E1A69FA975000800A0A875CEDBA6
D4E2ADCBDEA6C8E0A4C8E6A6BCE49EDAEFAE9F8554C2A472D1D797D2EDA6BFDD93CAE89E
CEE59DD7EDA5C9E098C5DF96D4F0A6CCECA3BCE096D1F7AC
CAE8A0CDE8A1CDE29DD5E9A4E2F1AE3C4B08CFE09CD3EAA4CAE8A0C5E79DCBEFA5BCDE94
D7F5ADC6E099BFD38ED8E6A879834E5D642E9BA25F8F954BA0A4578D9349BCC488D6E1B6
000B0005150B1C2C2B3C4D47000700354320A1AB79656C3935341528240B413D20FFFFE1
A2A0795C5B2DA4A77293975C7E82454C5111505515555A1A75793C9FA368A9AA71D0D89C
D7EBA4CBE699CFEEA0C9EA9BCAEF9FB8DD8DCEF0A3C5E498CCE69CD2E89FCFE499CBE196
D8F3A6D0EFA1B1D686D1F3A6CCE89ECFE6A0D1E4A2D3E3A5D6E1A7D8DFABDBDDACDBDDAE
DCDFB0D8DEAED2DCAAD3E4AED6EEB4C8E4A7BFDF9ECAE9A5CAE19BDDF7AEBBDD93D0F4AA
C5E39DD1E1A0E2E1A9AA9E6AA29561534E16E4EEB1CADF9CC8DF99D9EEA9919C5898A15E
D9E9A2D4E59ED8E59F828C47A3A865D5DA97CDD490DEE9A4D0E099DCF0A8C1D98FD6EEA4
D0E49CD4E49D98A35ED5E59ACDEA90CBED8FC7E58DDAF7A58CA45ACDE29DD1E6A5B3C686
ADC17CD1E79FD7EDA2CEE69AD1EBA1C8E39CCEE9A6F3FFD4F9FFE8FCFFF1FBFFF1FDFEF6
FFFFFBFFFDFFFFFCFFFFFBFFFFFAFFFDF1FDFDF1FBA89DA5CCC3C6EFE6E7FFFEFAFFFDFD
F9EDF9FFFCFFDAE1CFBFD1A9D3F0B0CBEBA2BFDD95CFE5A7A5AE8311120085836C6D6D51
000700D5E9AEC4E596C2E591C8E79BD7F2ABC6DD95CDE19AD8E9A2D7E8A183974FD3EBA1
C7E398C1E195D6F8ACBCDE94C5E49ED8F3B0C4DA99B9C88D49531F040C00ADB584D0DAA6
D5E2ADCFE0A9CEE6AAC5E3A3BFE7A1CCE1A0A68C5BC8AA78D8E1A0CEECA4C2E297CDEDA2
CDE79DCFE79DCDE79DCCE89DCAE99DC9E99EC8EA9EC6EB9E
CAEAA1CDE8A1DAEFAAC7D894CDDC99707F3CD5E6A2D0E7A1BFDF96C3E79DC9EFA4C3E79D
CBE9A1D4E9A4E4F0AEDDE7AA37410C939E66C6D18FD5DF98E3EBA0E3EDA6CED99FC2D1A6
0008004E645721383092A99F647A653E543025370534400E0403003E371DB1AC8EE4E0BB
6F6C419A9A68D9DAA1E3E7AAB7BC7A9499569FA462A1A664B5BA7AD1D296C9CA90E1E7A9
CCE098C7E396D2F1A3C9EC9CC7EC9CC9EEA0D3F3A7D1EDA2C7DD94CCE098CCE098D6ECA1
CCE79AC1E293C9F09FC6F09EC6EC99C8EB99C9EA9BCCE89DCFE6A0D0E5A2D1E4A4D3E3A4
CCDEA0D7EBACD0E6A6C2DC9BC4E5A0CAEFA9C9F1A8CEF2A8C2D993D4EBA3BFDF96CFF1A7
CCE7A2D5E5A4DBDAA29E925EBBAE7A6E6730CBD397D8E8A7D3E8A3CEDF9B838A478A914E
D9EAA3C3D78FE0F0A997A25D959C58D9DE9BE7EEAAD4DF9AD4E49DD0E49CDAF0A7C7DF95
CEE29AB1C27BB5C07BD1E196D0EE96D4F79BC1E48ABCD98589A359D3E8A5C9DBA18D9E67
D2E4AAD8EAACCADE99C7DD95D6EDA7CDE6A5D1E8B0F7FFDFF9FFEDFAFDF4FBFCF6FDFEF9
FFFEFDFFFDFFFFFBFFFFF9FFFFF5FFFFFAFFFFF7FF9E949CF3EAEFFFFDFFFBF5F5FFF9F9
FFFDFFF5F5EDE1EBD0C1D7A6CEEBA8E0FFB4CAE69CD0E5A4333D0B4547229C997A3E3E1C
3D4715B9CF8ED4F6A2CFF59EC9E99DC5E39BD4EEA5D2E8A0D2E39C809049C9DA93C1D78E
CEE89ED6F5A9BADA8FCBEBA0DBF9B1C5E09BCFE6A28C9C5E1E2600101600525A296E7844
DBE8B3DAEBB4C5DDA1D3F1B1C4ECA6D5EAA9B59B6AC7A977D7E09FC7E59DC4E499CEEEA3
CAE99DCCE89DCCE89DCAE99DCAE99DC9E99DC9E99DC8EA9D
C1E399D2F0A8CFE6A0CCDD99D8E4A2303C00DBEFAAC7E19AC9EBA1C9F2A6C8F1A5C7EBA1
BAD58ECADB97BDC383878B5075824AD9EBB1CBD99BEBF8B3D0DB97C2CE8EE4F3BC6A7D50
000C00EEFFF481A0903A5947BFDDC1F0FFE6BAD6A5D3E5B3A5A782363010433F1A716F46
888757DADDA8D2D89CDAE0A0DBE5A0C9D38CD9E09CD4DB97DBE29EE9EEACD7DC9CDEE7A4
D3E99ECAE797CFEEA0C3E495C1E396D5F7ABB4D288A9C37AACC079D4E59FD6E7A1D2E69E
C8E396BFE091D6FDAABEEA95C2EE97C2EE95C3EE95C6EC97C8EB99C9EA9BCAE99DCAE99D
D6F4AACDEDA2BEE096BFE399CDF3A6CAF3A5BCE798BDE295D4EBA3DAF0A8CCEAA2C8E89F
C9E49FD2E1A0D2CF98958854C8BB87847D4693995DDAE9A8DEEFABCBD7958B8D4C939856
D4E8A0C9E197D9EAA38B9852909A55E4EBA7D9E09C97A25DDAEAA3D0E69DD8F0A6CDE59B
92A85F8B9F57CDDA94E6F8AEBDDD88CDF49BD1F49ACCEC97B5CF85DCF0B1CADAA997A478
D0DDAFD5E3B0D1E0A5D4E7A7D7EBAEC5DAA2CADFB4F5FFE8F9FFF4FDFFFAFFFFFDFFFFFD
FFFEFFFFFDFFFFFBFFFFFAFFFFFBFFE8DDE5C5BBC3FFFCFFFFF7FAFFFDFFFFFDFFFCF9F4
FFFFF3FEFFEABFD0A6D5EEB5BCDB95B7D78BCEEAA0000D005E653172714598946E1D1E00
78834BD6EDA7CAEE97B9E188BBE090D7F7ACDAF6ACD4EAA290A15A5C6C25BFD089DBEFA7
D8F0A6C7E398D5F5AAC3E398BAD88EC8E29BDBF2ACDFEFB05B642F444A1A555D2C9BA571
15220090A16AD0E8ACCBE9A9C2EAA4D1E6A5B69F6DBDA16FDEE9A7CAEAA1C9EB9FC3E599
C9E99DCAE99DCAE99DC9E99DC9E99DC9E99DC9EA9BC9EA9B
BDE398D3F5ABC2D993DDEEAADBE7A50B1700D8ECA7C7E19AC6EAA0C0EA9EC4EEA2CEF2A8
D4EEA7E5F1AF9896595F5E25D8E5ADBCD095DFEFB1C5D396D7E2A6D9E6AED2E3AF5A6F44
BDD6B6EDFFEFB3D5BA587D5E92B692BCDFB5CDEFBDD2EAB8C7CEA2AFAD84C4C599E4E8B6
E0E7B1DBE5A9D7E3A3D7E6A1D9E9A2D2E299DBEBA2D1DE96D2DF97DEE9A4D3DD98D6E39D
D1E99DC8E595D2F1A3CCECA0C8E89DCBE99F617B323248008F9E5BCDDA95E3F0ABC9DA94
D1E99FCCED9ECCF3A2BCE893C2EE95C2EE95C2EE95C3EE95C3ED97C5ED97C5EC99C5EC99
BEE393CFF4A4D2F7A9C9EEA0C3EA9BBDE495C0E798D1F1A5C8DC95CDE19ACDE8A1CCEAA2
D3ECA8DEEAAADAD59E9E8E5BCBBB88988F585C6025D2DE9EDCEBA8D1DA999F9E5EA4A665
CBE198CDE99EC6DC9390A15AAAB570C8D28D9CA6618D9A544D5E1792A85F88A2584D671D
CEE69CCBE198E1F2ABBFD58ADAFBAAC0E892BBDF88CAEA97D4EEA7C9DCA4AAB68E8D9677
D3DDBBD7E2BAD4E0AED6E5AED8E9B3D0E1B5D8E8CBF6FFF1FCFFFBFEFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFBFEFFFBFEFFFBFF5A5154E7DEE1FFFDFFFDF7F9EEEAEBFBF7F8F9F9EF
F5FEDFEAFCCCDBF2BAB6D494EAFFC3BCDC935B722CD6E4A65558230C0800120E00898957
D5E1A3C6E096D3F9A4BFEA91CCF3A2BBE093BDDB91C5DC94D7EBA3CDDD9640510ADCF0A8
D1E99FC1DB91C7E59BDBF9AFD3EFA5CFE99FD1E79FBFCF8ED2DBA4EFF3C18C9360D3DDA8
8A9761000C006F8547C4E3A0C4ECA6C7DC9BA58E5AA28654D7E2A0CBEBA2D1F3A7BFE497
C8EA9EC9E99DC9E99DC9E99DC9E99DC9E99DCAE99BCAE99B
C6EEA5C4E8A0CEE7A3DAEAA9CEDA9A465212D4E7A5CBE6A1CCF2A9BDE99EC1EDA2BCE098
CEE3A0C8CE90574E1559521BCED99DD7EBAED2E4AAA2AF79788250000900000C00000E00
ECFFE2E2FFDFC8EEC7A4CDA34D764A688F60C3E9B8B9D7A3D6E4AFE5EEB7DDE8AED4E2A5
D0E0A2C5D896D7ECA7D1E8A0CFE79DCDE79DD1EC9FC9E195C9DF94D3E99ED2E79CD3E99E
D3EB9FC7E396CBE79CC6E599CBE99FD7F2AB7E934E67783496A061919A59DBE6A4D6E5A0
D3E9A0CEED9FC4E999BFE995C5EC99C5ED97C5ED97C3ED97C3ED97C3ED97C3ED97C3ED97
BBE28FCEF4A1CBEE9EBEDF90C8E79BD6F5A9CEEAA0C2D9918F9E599FAE69A4BE77C3DE97
D0E7A3D9E3A4D5CE98988855CFBD8BADA26C4A4B11D2DB9CD8E3A1D6DC9CA39D5F9B9B5B
DDF5ABCCECA0D3EDA3D1E79EC9D992ACB7729BA661DDEDA6DAEEA6ACC47A759146BBD78C
CAE49ACDE59BCDE199DAF2A8C3E599C4EB9CD7FAA8D3F4A5B9D29096A876B4BFA1EAEFDB
FDFFEEECF2D8D2DAB1C9D5A7DEEBBFF3FFDEF8FFF4F9FFFDFAFEFDFCFDFFFDFDFFFDFDFD
FFFDFEFFFCFBFFFAFBFFF9FAD8CFD0A39A9BFFFCFDFBF5F5FFFDFDFFFEFDFDF9FAFEFFF3
D4E6B4CFEAA7CAE9A5C8E9A4C7E8A3CAE7A596AA6D2F3801817F4C0B0300726B37EBEAB2
D7E3A3D3EDA3B4DB8AC7F49FBBE696D2F9AAC6E69BCEE89FD2E69FD8E9A3E6F5B080914B
8AA0587E984FBCD88DD9F5AAC2DC92DEF6AABDD189EAF9B6D1D9A0C9CE98A5AC76D8E1AA
AAB57D41531793A96BC5E2A0C9F1ABCDE2A1A8915D9E8250CBD694C1E198CEF2A8C7EC9F
C8EA9EC8EA9EC8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99D
CBF5ABB6DC93DAF5B0CCDF9DDEEAAA222E00DCEFADC9E49FC0E69DBAE69BC6F2A7C2E69E
DEF1AFCED29593864FE5DAA2CFDB9DD2E6A9A1B0795B67376C744BFCFFDFF9FFE3F5FFE3
D4F0C7D4F8CAB8E2B0B9E5B2689260022C0083A97AD4F4C2D4ECAEC4D795CBE09DCCE39F
D7F1AACCEAA2B8D88DD0F2A6C5E79AC8EA9DCBEE9EC8EB9BCAE999CCEB9BCEEB9BCDEA9A
CFEA9DCBE699CBE59BC3DF95CBE59ED3EAA6BBCB8ADCE8A8BDC3875D6325C7CD8FE4F0AE
CDE19AC6E297C9EE9EC4EB9AC8EB9BC8EB9BC8EB9BC6EC99C5EC99C3ED99C3ED99C3ED99
D0F7A4C3E696BEDD8FD2EEA3DFF7ADC1D58E9DAE6A98A462C0C986C4D18CA1B872D4EEA7
D7ECA9DEE8A9E2DBA5AA9866CEBA88B0A36E4E4D14DDE3A5D8E1A0E0E2A3A3995C969555
CEE89EB1D688C5E498CAE2989DAE67A0B069B3C07ACFE099BFD58CD0EAA0DBF7ACCEEDA1
D3EFA4C6E096D7EDA4C9E39ACDF1A9BFE59CBCE191C4E498D7F0AFE4F5C8F8FFEBFFFFF8
FFFFF8FCFFEEEDF2D2E2EAC3EAF4D1FBFFECF9FFFBF7FFFFFBFFFFFCFDFFFDFDFFFFFFFF
FFFEFDFFFEFBFFFAF7FBF3F0AFA7A4FFFEFAE4DFDBFFFEFBF9F5F2FCFBF9FBF9FAF8FFEB
CFE8A7CBEE9ABADF91D0F4ACBCDC9BBDD99ECDDEA8616533777141574B19918650D9D79C
D0DC9AC6E097DAFFB5B9E897C7F6A5BEE999D2F4A8C9E59BD3E9A1BFD08AD8E7A2D8E9A3
CDE39BCDE49C506A20C4DE94CEE69ACBE196E2F4AAC2D18CCAD297939860D8E0A7DAE4A8
939E6432420495AB6BCDEAA7C0E8A1DBF0AFCBB480CEB280E1ECAAC4E49BC4E89EC4EA9F
C6EB9EC8EA9EC8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99D
C6F2A7BAE299D3EEA9CCDF9DD4E0A0010D00DDF0AEC7E29DC8EEA5C6F2A7C5F1A6C2E69E
C5D896959559A2915BF9ECB5E4EEAFC6DA9B384611DBE6BBD9E0BEFEFFE6FBFFE6E8F9D5
C3DEB1AED39FCDF9BECCF9BE99C48C39642F779D6EBDDFACC5E29FCEEA9FD7F6AAC0E094
C2E498D8FEB1BCE597C9F4A5BFEA9BC0ED9CBFEA98C4EF9DC6ED9AC1E993C4EA95C5E894
C1DE8ECCE79AD5EFA5D5EFA6D3EAA4A3B8759CAA6CC8D295DCDFA685864CBBBF82C5D08E
D0E19BC7E197CDF0A0C7EC9ECCE89ECDE79ECCE89ECAE99DC8EA9DC6EB9BC6EB9BC6EB9B
C5E898C5E498CFE99FDBEFA8C4D390969F5E929659BABB7FE0E5A5D5E09C809550CDE49E
C5D896C9D293CFC590907E4CD1BD8BA5956157551CE3E7AAD6DC9CE5E5A7A5995DA8A767
D5F1A6CBF4A5D2F2A6C9E399ACC078D6E7A0DBEBA4C6DA92E6FEB4C0DC91C1E094DAF9AD
A9C87CD6F2A7DDF5ABCAE59EC5E8A4C8EDA8CAEFA2CDEDA4CDE5A9EBFAD3FBFFF1F4F4F2
F6F4F5FDFDF5FFFFEAFFFFE3F6FFE0F4FDEAF7FFFFF6FAFFFCFFFFFEFFFFFFFFFFFFFFFF
FFFEFDFFFBF8EFEAE6E1DCD6F1ECE6FFFCF6FFFEF8FFFFFAFFFEFBFCFBF7FFFFFDFBFFEC
C6E49ACFF89ABCE692C9EFA6D5F7BBCEE6B4D5E2B6D2D3A9998E616E5E2DA29560DAD699
E7F2B0CFEAA3B8E298BFEFA3BCED9CBAE796BCE193D6F5A9D0E69EDDEEA8DAE9A4C4D58F
C9DD96D1E8A04F691FD3EDA3D1E99DD9EFA4C3D589C4D18B858B4FEEF3B9D5DDA2CCD699
758044758546DBF1B0C1DE9BB9E19AD9EEABC8B17DDFC592E8F4B2CBEDA3BDE197C2E89D
C6EB9EC6EB9EC8EA9EC8EA9EC9E99EC9E99ECAE89ECAE89E
CBECA5CFEDA7D0E7A3D6E6A595A46361722ECDE4A0CCEAA2C4EA9FC4EEA2BCE599CAECA2
BACE896F7434A89E63E0D79CD0D99AD8E8AA000800B3B792DADDC0D9DFC3D4E4C0D1E8BC
C8E9B0C8EFACC2EBA5C0E9A5C9F1B5C5EBB8395F36C5E9BBC3E3A2D3F1A7C5E599CDEFA2
C5EC9BC5EF9DBAE595C1ED9EC6F2A5C3EFA2BBE79AC4EF9FC5EF9DBEE892C5ED94C8EE97
D2EF9FD0EAA0C9E399C8E299CEE8A193A865A7B778E1EDAFE0E8ACD2D89CBCC284919C5A
DAE9A6D6ECA4CCE89DCDEBA1CDE7A0CDE7A0CDE7A0CCE89ECCE89ECAE99DCAE99DCAE99B
CFEBA0D1EBA1AEC47B8A9B559EAD6AD1DC9AE2EBACD9E2A1D8E39FD5E29D7D8947EDFEBA
E5FAB7E1F0AFDAD7A090834FE1CD9BA08F5B635822E7E5AACCD594DDE3A3A09A5CB8BA79
BEDA8FCCF3A4C3E598CDE99ED0E89ED6EAA2C0D48CDBF1A8C8E096C7E398D1F0A4C1E094
D5F4A8D2F1A5BCD68CD0ECA2C7E8A3CAEBA6CBEBA2D0EEA8C2D79FE7F5D1FCFFF4FEFFFD
FFFFFFFBFCF7FFFFF1FFFFECFEFFEDF9FFF3FBFFFFFBFFFFFCFFFFFBFFFFFCFDFFFFFFFF
FFFDFCF2EDEAD9D1CEC3BCB6FFFBF3FFFEF6FCF8EDFFFDF1FEFEF4FAFCF1FEFFF6F0FEDB
CBEA9EC2E98CCDF09EC8EAA0C1DFA1D1EAB3C6D6A5A0A678665F319C8B5D9F8B59AFA069
8C8C4EAABB77D0F4ACB7E698C3F09FC3EE9ECBF0A2C7E69AC9E39AD2E8A0CBDF98D4E8A1
D0E69ED7EEA6425911D0E79FC8DE95CCE0988A9B54889550DCE4A9DAE2A9CFD99D091500
A6B476D6E9A9C3DC9ACDECA8C3EBA4CADF9E9D8352BB9C6DCED496CBE4A0C5E099D1F1A8
C6EB9EC6EB9EC6EB9EC8EA9DC9E99DCAE99DCCE89DCCE89D
9CA564B3BC7BDEE9A7CDD99797A864D7EDA5C1DC95CCEEA2C3E99CC4EA9DCAEC9FCDECA0
C8DE95B3C07A9398557A7C3BD1DC9ADFE7AE717044403B1BA8A489D2D9BAC2D9ADC9EDB0
B6E192D6FFABC1E790C0E094CEECAECFEEC21C43248CB190C4E2AEC7E4A4BCDB95D7F9AC
BFE290C1E794D2F9A8C2E89BC4EAA1C5EAA5CBF0ADBADF99C7EC9FC6EC97CEF598C5E98F
CFEE9EC9E89CC6E599CAE89ECCEAA0839E57D4EEA7CEE59FCFE2A0E0F0AFBDCC89AFBB79
CCD896D8E4A2CFDE9BD4E8A3D7F2ABBBD98FC9E59BDDF7AECAE098C6DC93DBECA5CEDF98
D6E7A08A9E5671853DA9BF76D8F0A6CEE89EC3DF94D2EEA3CFE9A0D0E19B858547FFFFC8
F1FFC7BFDA95E0E8AD9F9A63D7C794A48E5C684C1CEFE0A9D3E29FC5DC96A4AD6AD0DB97
CCE89DC8EB9BC9EA9BCAE99BCCE89BCDE89BCDE89BCDE89BCDE89BCCE89BCCE89BCAE99B
CAE99BCAE99BCAE99BCAE99BCDE99CCCE89DCFE9A0CCE5A4CFE3B0E5F5D0F9FFEFFBFFF8
F2F9F2FCFFFDF3F8F2FDFFF9FEFFF8FCFFF8FEFFFDFCFFFFF0F6F2FBFFFDFCFFFDF6F6F4
FFFEFDFFFDFBC0B6B5FFFAF8FFFCF6FFFEF3FFFFF1FFFFECFFFFEBFEFFEAFCFFE8F9FFDD
CDE6A4D6F1A4C4DA91D0E69ED1E8A2D0EBA6BEDB99586E30595D2A66582B56360D836134
654E1A7A7637CEE69ACAF09DC4EB98D6FBABC1E494BADA8ED2EEA4D2ECA3C2D993D4EBA5
CDE49EACC37F98AD6ADAEDABBBCE8CB3C48062712EAFBD7FDCE6B15F6935738048687A3C
C7DC99D3ECA8CFEAA5C1E29DCCF4AEC5D79BAB8A619F7851BFB884828C4FCFDB9BD7EBA6
CEEEA3C4EB9CC7EC9EBEE191D0F1A2C6E295CCE79AD4ECA0
B9B97B6B6D2EA0A666D2DE9C81954EC4DE95DFFDB3BFE195CEF3A5C3E89AC0E192CAE699
D6EEA2CEE096B0BD75949F5A808B47CFD49AF0E9BFB8AD8D5E593C7F8563D3EEBBC2EBA7
CDFDA7ABD87BCCEF95DBF6A7D2EAACC1DCAF2A4F30001400456438D6F2B8D4F3B0C2E299
CBEC9BD6F8A4AACB7AD3F3A7C7E6A2CAE8A8CBE9ABD4F2B2C7E79EC3E493C1E488CEEF94
C8E595CFE99FD6F2A7C6E297D3F1A7ABC97FC6E49ACEEAA0C6E099DAF1ABCBE09B8DA15C
6E7D3CD0DC9CD4DE9FD1E29ECDE8A1C4E298D0ECA2C4DB93DFF3ACD1E29C9EAE67E3F0AA
A0B069C6D790DBF1A6CEE99CC0DF91C6E999CBF0A0C8ED9DCCECA1D0E49D636124DEDEA0
EDFFC2D8F7B1CCDC9EA6A76EE5D8A4A98F5E614112FCEBB5C9DD98D3F1A980914BDAEBA4
CCE89DC9EA9BC9EA9BC9EA9BCAE99BCAE99BCCE89BCCE89BCCE89BCCE89BCCE89BCCE89B
CAE99BCAE99BC9EA9BCAE999CEE998CDE899D1E8A0CEE4A6CFE3B0E4F6D0F8FFECF8FFF4
F8FFF9FBFFFDF6FAFBFCFEFDFEFFFFF7F8F3FFFFFBFCFFF8FBFFFBF1F8F1EDF2ECFFFFFB
C7C4BFC7C2BEFFF9F4FFFDF4FFFEF1FFFDEAF8F6DFEEF1D4E5EFCCE1F0C7E0F1C5E0F4C1
C6DC9CD2E7A2CFE09AD8E9A2CFE79BCCEB9FD5F7ADAFCA8798A16AB3A87BCFAD88E9C19D
BE9F73A69B63C9DA93C6E798C2E394BDDE8FD0F0A4D7F6AAC1DF95C6E298D2ECA3C4DE97
AEC57F6F8441C5D896C3D696E9F9BA7F8F50DAE8AAD9E7ACA0AD78000A0044561CCFE4A3
D4EBA7BCD790E3FFB9BCE09AB1D895ECFBC2B3906AE7BB985D5121757A40A0A467CCD896
C5E399BDE294D3F5A8CFF0A1D0EC9FCDE899CBE196869B4E
DDE3A3C9D291A3AF6DC4D591CEE49CD1EBA2B4D288D3F5A9C9EB9EC8EA9DCAEB9CD0EC9F
D4ECA0D1E79CCBDD93C5D58C515E18515719DBD5A5D0C79EE8E4BF01080059743DBEE5A2
B7E493D6FFAAC2DF8DC4DC9291A769314B1BD2F6D04E744F8CAB7F84A06DC7E3A8C7E4A1
BEDA8FC3E090EDFFB9D0EAA0D7F0ACD2EBAAC6DEA0BFD897C6E19AD6F2A5D3F49DCBE792
D4E99CCFE099BBCF87E6FCB3C9E09887A158DAF4ABC3DF95CBE59ECDE7A0D4EEA78EA55F
3F5612D2E7A4D1E4A2CBE09BCEE9A2D1EDA3E3FDB4C4DB93B7CD85A4B8718C9D56CFE099
C7DB93D3E9A0D5EDA3CCE69CCDECA0D6F6AACEF1A1BCDF8FD5F3A9C8DC95828747DFE4A4
CCDF9DD5EEAAC4DA9AA0AA6EE0CE9CB599696D5624DDD49BD0E19DC7E19A9FB36CD0E49C
CAE99DC8EB9BC8EB9BC8EB9BC9EA9BC9EA9BCAE99BCAE99BCAE99BCAE99BCAE99BCAE99B
CAE99BCAE99BCAE99BCAE999CDEA98CCE999CFE9A0CCE4A6CDE4B0E4F6D0F8FFECF8FFF4
F9FFFAFBFFFDFAFEFFFEFFFFFFFFFFFDFCF8FFFFFBFFFFFAF0F3ECFEFFFAFFFFF8FDFDF3
B6B6AAFFFFF1F3F2E0FFFFEAFEFFE6F5FCDBE8F2CDDAE9BED1E4B6CBE3B1CAE5B0CEE7AE
CBE4A3CFE6A0D1E8A0D0EAA0C4E596BFE194CEF0A6DEF8B7D6DFAADFD6ABF4DAB7F9DBB9
A8926B928E5ED6E8AAD5F2AFCBE9A1C4E29AD3F1A7CCEAA0C4E096D7F1A8D1EBA293AA62
4C621AD0E5A0E0F3B1CFDFA0DBE9AC95A368C4CF95D5E2AA2C3B04C6D7A0D9EBAFDBF2AE
D3EDA6C7E59BC3E39AC1E59DCEF6B0D2E4AACCAA84D5A986A89E6D9AA267DEE4A6A9B573
DCF6AFC7E59DC1DF97C3DF95CDE59BD0E59ADEEFA896A65D
D6E5A2E0F1ADC2D691DAEFAAD3EDA4D2EEA4CBE99FCAEA9FC6E69ACCECA0D0F1A2CEED9F
CAE699C9E497D0E89CD7EDA285954C5F682577753CDDD5A4D5D3A37C84532A43098EB370
C9F1A8BEE396C9E39ACEE19F7F9157BAD19BBCDDAE93B88C84A379829F7178955F91AE6E
D9F3AAD0E89CCBE093C8DA90C5D692C9D99ADDEDAFCCDF9FDDF2ADCDE59BD5F09FCCE594
CFDF96EDF8B3DEEBA5C1D18AE5F9B2798F47D3EAA2CDE79ED3EEA7C0DB94CFEDA5B6D48C
7E9954DAF5B0CEE9A4CAE49DC0DA93CDE79EBCD68DB4CE85A3BA729FB66EC7DF95D2EAA0
DBF3A9C8E298C3DD93CCE89DCBEA9EC0E094C3E397D1F0A4C1DD93D1E79FB6C17FD6DF9E
DAE6A6CDE29FA0BD7B9BA96CC6B07FAE8F60675723DDDEA2CCDB9899AE69C8DE96C9E098
CAE99DC8EB9BC8EB9BC8EB9BC9EA9BC9EA9BC9EA9BCAE99BCAE99BCAE99BCAE99BCAE99B
CAE99BCAE99BCAE99BCAE999CBEB98CAE999CCEAA0CBE5A6CDE4B0E4F6D0F8FFECF9FFF4
FAFFF9F6FBF7FEFFFFFFFFFFFFFDFEFFFEFBFFFEFBFEFBF6FFFFFAFFFFF8F0EDE49E9F91
EFF1DCD8DCC3F5FCDBD9E3BEECF9CDE3F5C3DAEEB9CFE8AFC9E5AAC6E5A9C8E7ABCBE9AB
D5EEACD0E7A1CBE99FC6E89BC2EC9ABCE596B8DA90D2E8A8D9E0ADE8E0B9D9C6A6786547
6F6444FEFFD7EEFECFC3DCA3D1EBACCFEAA7C7E29DBCD790D5EFA8C7DE96A9C1778FA55C
A7BD74DFF3ACCADB97DEEEAF1422008F9C64E6F0BB9BA8721D2F00E1F5B8D6EBAAB9D08A
C1DD92D3F2A6C7E99DCCF2A9BFE8A2C0D298B5936DB68B68A9A170949E62CED89995A461
BCD18ED4EDA9D4EBA7CBE09BD4E8A1CEDF98DEEBA5A9B670
C3DD96C6E19AC9E39CE0FBB4BCD88EC3E197E1FFB5BAD88ED1F0A4C9E99DC3E495C4E596
CBEA9CCEED9FCBEA9CC9E497D6EBA0CBD78FB7B676656026A09D66D4DCA3627A3E5F7F40
C4E7A7D4F2B2D6EAADCAD79F8C996184975FD3F2B7BBE0AA000E00BBDAB1D5F2C2C5E1A7
425817A6BA72D9E9A0D8E49CEDF7B2D6DF9ED1DB9CD6E2A2DBECA8C7DD95C8E094D3E89D
D5E09BDDE4A0CCD691B1BC774D5C17D4E8A1CBE199D8F2A9D0EBA4C4E29AC9E9A0D0F0A7
C8E9A2C2E39CC9EAA3CBE9A1D2E9A3CDE39B94AB63A0BA71C7E399C8E49AD5F3A9D1EFA5
C1DF95CBE99FD2F0A6CFEDA3C9E79DC7E59BC9E79DCBE79DD1EBA28BA159C7DB96E0ECAA
CFD899D1E09FC8E7A4687A3CBAA4736A4B1C959058D9E3A4EBFAB75C702BD8EFA7CBE79D
C9E99DC6EB9DC6EB9DC6EB9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99DC9E99D
CAE99DCAE99DCAE99DCAE99BCAEC98C9EA99CBEBA0C9E6A6CCE4B0E4F6D0F8FFECF9FFF4
FCFFFAF7F9F6FFFFFFFFFEFFFDF9FAFFFEFBFFFEFBFEF6F3F7EFEDB4ADA7ADA99EFAF9E7
FFFFE8D6E0BBDBEBBCDDF2BAD1EBACCDEAA7CAE9A3C7E8A1C5E9A3C4E9A3C6EBA6CAEAA7
D0E6A5CEE59FC9EB9FBFEA9AC5F5A1CBF8A7C5E49ED3E5ABDDE0B3E7E1BF786E53AAA28B
D9D7C0FEFFE8EEFCDBEFFFD9CDE4AEC5DDA1CDE5A7CDE3A2CEE59F91A75E97AD62C9DE93
D1E69BC4D58ED4E5A1DBE9AB525D23BCC691C7D19F697641BDD194C8E19DC8E29BD8F4A9
D0EFA1C8E998C3E598C6ECA1C5EEA8DDF1B6A5855EBA926EB5AF7DAEB97DD2DE9ED5E4A1
A9B978C3D694E0F0AFD5E6A2CBDA97CFDC97DCE7A3929D59
C7E99FDFFFB7BFE197C7E79ED7F5ABC6E49AC3E197CCEAA0CAE99DCAE99DC8E99AC8E99A
C8EB9BC8EB9BC7EA9AC9E89AD6ECA1E8F5ADD8D9955C581879773AD5DB9F5F7439506D33
BEDCA6CDE5B3C3D0A2EDF5C6828A5789985FD0EDABBEE2A520451ABDE1BDC3E4B7DAF7C1
899F6199AA6698A35ED7DF96CDD38DE3E8A5DDE4A1DCE7A5C3D28FD7EBA6D2E9A3DAEEA7
D0DA95D7DE9AD5DC9889944F93A25DD6E7A1BFD58DC6E097C4DF98D3F1A9CBEBA2C6E69D
D5F6AF97B871C8E9A2CBE9A1D5EBA3A9BD76ACC27ABFD990CBE99FD0F0A5C2E498C0E598
C9EEA1C7EC9FC4E69AC6E69BD0EEA4D8F4AACEEAA0BFD990CEE59D8DA45CCDE49EC4D591
E7EDAFD6E0A1C2DF9D6B7D3F9E8A585F4514DFE0A6D7E6A5C6D2908C9D59D1E8A0CDEBA1
C8EA9DC6EB9DC6EB9DC6EB9DC6EB9DC8EA9DC8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99D
CAE99DCAE99DCCE89DCAE99BC9EC98C8EB99CAECA0C9E6A6CCE4B0E4F6D0F8FFECFBFFF4
FEFFFAF8F8F6FFFEFFFFFDFEFFFDFFFFFDFBFFFDFBFFFAF9FFF7F9CAC0BFFFFEF4FFFFED
F1F8D7C9D9ACC9DEA5C4E19EC7E79CC7EA9AC6EB9BC7EC9CC8EDA0C8ECA2C9EAA3CBE8A5
CBDB9AD1E5A0C8EDA0BFEE9DBCF09DC9F5A6E1FCB9EDF7C2F4F0CAC2BB9F746F5BFCFAEB
F4FBEBEEF7E6FBFFF1F0FDE1E1F4C7D6EBB3E5FAC1C2D697AFC48199AF66C5DA8FD4E99C
E6F8ACC6D790DBEAA7D4E2A449541CDAE4B299A2756B7946C2D898C0DC92D3EFA4C5E496
C5E793CDF09EC2E797C8F1A3C1ECA5CFE3A89D7D569C7651EBE5B3B8C689D8E7A6D9EAA6
D1E1A0849453A6B574D5E4A1DCE8A6DAE7A2D9E4A0939E5A
C4EDA1B8E195B9DF94C7EBA1C9E99ECAE89ED6F4AACFEBA1C4E095CBEA9ED1F2A3CEF1A1
C3E898BEE594C3EA99CEF1A1C2DD90C6D68DE4E7A2A29E5E585717D7DDA1ABBE865E7848
EAFFDBD9EDCAF6FDDCE6E7C59B9E718A955DCDE8A1CAEFAC4F7A4F8AB693C7EDC4B3D3A2
CBE4ABC4D7979EAB66969E55E0E69EDAE098DEE59FD7E29EE9FAB6C9DE9B8AA361435815
5C69245F6A25909B56BECE87D6E7A1D2E69FE5FCB4C5DF96C5E099D6F1AACDEBA3C0DE96
CAE8A285A35DCDE8A3CBE59E869A5394A55ECAE097DBF5ABC1DF95C5E79BCEF4A7C6EFA1
C7F0A2C3E99CC4E89ECBEDA3C7E59DBFDA93C9E09AD9F0AAD5ECA487A158DAF4ADD5E9A4
D8DEA0CED798D7EBAC7583466B5E2A9D8D59DEE4A8D6E6A5556421E9FDB8BCD68DD0F0A5
C8EA9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DC9E99D
CAE99DCCE89DCDE79DCCE89BC9EC98C6EC99CAECA0C8E6A6CCE4B0E4F6D0F9FFECFCFFF4
FFFFFAFAF9F7FFFDFFFFFBFDFFFCFFFFFCFBE5DBDAE0D6D59B8E95FFF9FDF2EDE7FFFFED
F4FEDBE3F5C3DEF8B7B6D68BC8EB97C9ED96CAEE97CCEE9ACDEC9ED0EAA1D1E8A2D2E5A3
D3DD9ED5E4A1C4E69AC6F5A5B8E998BFE89CF7FFCDFEFFD1FFFDDF5E513EA9A79AFCFFF8
EFF9F0F9FFFBEEF1EAFBFFF0F9FFE3EAFCCCCBDEA7899B61AFC280C9DD96E3F5A9C6D98A
CADB8DDCECA3CCD994BFCB8D46501BD6DFB0383F155F6D3CDCF5B3BAD98BCDEC9CD3F5A1
C2E490D4F7A3CDF2A2B7E092C0EBA4DCF1B6B0936BA6835DE2DFACA6B678C3D792CCE09B
D4E4A384945395A564B1C27ECBDA97B0BF7A9AA762ACB973
C2EEA1BEE89CCEF7ABCAF0A5BFE195C8E89DD5F1A7C1DD93D1EDA2CAE99DC5E697C7EA9A
CAEF9FC8F2A0C2ED9BBFE695C0DC92EDFCB7CCCF8C969253676528D6D9A0CADAA9C4DBB1
EEFFE4F7FFEDFDFFEAFFFFE8C4C49ECDD6A1BDD48CD0F5B0BAE9BB17492480AD84C9EFBE
CBE9B3D1E9ABD0E19DD7E39B4D550C5E661BD9E59BCCD993CFE39E475E1A8EA867D1EAA8
D1E59EC0D18AE2F6AECEE29AD3E9A1C9E098C5DF96D7F3A9D2ECA5CBE59ECDE7A0CDE7A0
CEE5A193A865D3E8A5CBDF9A4C5B16D4E59ED4E8A0CCE49AD5F3A9BEE396C7F0A2BDE899
C0EB9CC3EC9EC5EBA0C8EAA0CDEBA3D2ECA5D2E7A4CDE29DC2DC9396B067CCE39DCADE99
E5EFB0DBE4A5D1DB9F8A925756511A9F9D64DCE4A88C9B5A4D5E1ACBE09BCCE69DCDEBA1
C8EA9DC6EB9DC6EB9DC6EB9DC6EB9DC5EC9DC6EB9DC6EB9DC8EA9DC8EA9DC9E99DCAE99D
CCE89DCDE79DCFE79DCDE89BC9EC98C5EC99C8EDA0C8E6A6CCE4B0E4F6D0F9FFECFCFFF4
FDFEF8FFFCFBFFFDFFFFFAFDFFFBFFF0E6E5ACA2A19D9394FFFBFFFFFBFFFFFFFAF7FAE7
FBFFE3C3D7A4BFDA97D4F3A5C9E994C9EA91CBE993CFE895D1E69BD3E29DD5E1A1D7DFA3
E2E3A7D5DFA0BCDA92D0FBACC2ECA0C5E4A0FFFFD3FFFFDC614F39B5A598FEFBF4F9FFFB
F8FFFFF2FBF8FFFEFFFDFAF1FCFFE6DCEDC08B9C685B6D33CDE0A0D1E59EC9DB91D9EC9D
CDDE90E2F2A7D0DD9897A365D5DFAAD2DBAC030A006B7948C0DB96DBFCABC7E995C7E995
C5E992CCEF9BBADF8FD2FBAFC4EFA8BED3989F835C704D27D6D4A193A666DBF0ABCCE29A
C3D792E5F9B4C4D8934B5F1A54651F4859134C5D16D8E9A2
B5DF93D8FFB6C6EFA3B6DA90D1F3A7CEEEA3BFDB91D4F0A6CCE89DCAE99DC9EA9BC6EB9B
C5EC9BC3ED9BC2ED9BC5EC9DC3E199DDEDACCED3937D7B405E5B24D7D9A8DEEDC4637656
F3FFEDF8FFF3FBF9ECFFFFECCAC7A6DBE3B0B5CC86CEF3AEB7EBBA10471F467A4CCCF8C7
C1E6B0C5E3A7D3E9A8CFE39CD0E095BECF81697A2C8CA1565B722ACBE6A1C5E2A0D0EFAC
D3EEA7CAE69BCBE79CCDE99EC9E59BCCEAA0D2EEA4CAE69CCCE69FD1E8A2D9EEA9CFE39E
849352DFEBABCDD79856611FD2DF9ACEDE97DDF1A9CEE69CC0DE94CCEEA2C5EB9EC4ED9F
C2ECA0BEE79BC7EDA4CFF0A9CBE6A1C5DE9ACBE09FCFE4A1D4EEA78EA85FC3D893DBECA8
D7E6A5CED798D2CF9865622B73783EEEF8BBC7CF93939D5ED1E5A0D3EAA4CFE9A0C6E298
C9E99EBCDE92CBEDA1C8EDA0C8EDA0CBF0A3BBE093C7EC9FC4E69AC0E095CFEDA3C7E399
DBF2AAD0E69E5C702998B066CEF19DBEE592CBF0A3BEDC9CC8DFABECFCD7F9FFEAFCFFF2
FFFFFAF5F1F0FFFDFFFFFCFFFFF5F9FFFAF9BEB4B3FFFCFDFFFBFFFAF4FEFFFFFDFEFFF3
EDFBDADFF3C2CAE3A2C5DF95CFEA99D0E995CFE2918F9D50C6CD89E3E5A6DDDBA2A6A16A
9D965FE4E8ABC7DE98C1E399CDEEA9D6EBB0F5F4C83E2F1280695BFFF0EAFFFCFCFCFFFF
F7FFFFFCFFFFFFFCFFFFF6EFFCFFE4A9B98CB6C491BFCE95E3F3B4D4E59FD0E298D4E69A
D5E59AD6E69D94A35E919F61D6E3AB95A16F838C5FB2C08DCAE8A0C9EC9AC8EB97C6EA93
C3E790C4E793C5EA9CC5EEA2BCE7A2C8DDA4BA9E779C7854D5D59FD6E9A9849B55CFE69E
D3EAA2CBE199CCE29ACFE59DCDE39BD3E9A1D6EDA5CFE69E
CAF0A5BEE499C3E79DCDEFA5CAEA9FC9E79DCEEAA0CCE89ECCE89DCAE99DC9EA9BC6EB9B
C5EC9BC3ED9BC2ED9BC5EC9DCAE8A2DBEEAEE9EDB24946116B6738D3D4AAF0FEDA526547
F1FFEDF4FFEEFFFFF1FFFDE9E2DFBCD4DCA9D9F0ACBFE7A1B8EDB7001A001F5524A7D7A5
C7EFBAD0F1B8B9D696D4EDA9CDE398C1D88AD7EE9ED3EB9DC7E197D5F3ADC8E7A4BFDF9C
CAECA2C5E79AC8EA9DCBEDA0C7E99DC8E89DCBEBA0CDE99FD6F0A9C8DD98D1E29E8A9654
626B2CD9DFA1747539D9DE9EDCE7A3E3F3ACC4D890D9F1A7D7F3A9BDDD92D1F6A9C0E699
C8EEA3C5EBA0C6EAA2DEFDB7F4FFCCEAFFBFD2E7A6CFE6A2BBD68FC9E39AE2F3AFC3D28F
D5E4A3E4EAACF1E1AE5245118F9D60BCD190EAF2B6E1E7A9CFE39EB6D089DFF9B0CBE59C
CCEAA0D1F1A6CCECA1C7E99DCBEDA1B5DA8DD3F8ABD2F7AAD7F9ADD6F6ABC8E49AD3EDA4
556B23223600D9E8A3BFD58CBADD89C4EB98D3F5A9DAF7B7C5DCA8E3F1CDFCFFECFFFFF4
F4F1ECFFFDFDFFFCFFE9E0E3FCF3F64B4341FFFDFBFBF5F7FAF4FFFFFDFFFEFFFFFCFFF6
F9FFE8CFE0B3CCE0A5DEF4ACCEE396CBDC8C95A155666E255151114540065F5520655925
61582197975BE0F0AFD8EEADD3E9ABCDD7A5938A695F4A37FFF5F0FFF9FAFFFDFFFAFBFF
FCFFFFF0F0EEFFFCFAFFFEF1DCE3C19CAC7DC5D3A0E7F6BDDAEAACC6D793E3F4ADD6E89E
CBDD9392A35C4B5A15D4E4A3CEDCA1172400C6D2A0D7E8B1C7E59DC3E996C6E995C7EA96
C9EC98CAED9BCAECA0C7EDA4CCF5B3D7EAB3896B4794704CE9E9B3CEE3A295AC64D3EDA3
D5ECA4CDE49ECEE59FD1E8A2CDE4A0CAE39FCBE4A0C7E09C
CAE8A0C3E199CBE9A1D1ECA5C8E49ACCE89ED2EEA4C8E49ACAE99DC9E99DC8EB9BC6EB9B
C5EC9BC5EC9BC3ED9BC6EB9DC3E199C0D393E1E4AD58542599946CD8D8B68B967676866B
E3F5DDE2EED6F1F3DDFFFBDECFD0A8F2FCC8D7F1B0BEE7A3BDF0B591CA933D723E88B884
B8E3AEBBE2ABC9EBAEC8E8A5D1EFA5CCE89BCBE898D1EE9EC7E398C9E79FD0EDABCCECA9
C5EBA0C0E99AC5EC9DCAF1A2C7EC9FC2E79AC7E79CCEECA2C7DE98D9EDA8D3E29F9EA967
95995CBABB7F6B692EE8EAABD1DC97C2D48ADAEEA6C6DC93C5DF96D1EDA3B5D58CD3F3AA
BFDE98C9E8A2CBEAA6DCF9B6F1FFCADEF7B6C8DE9ED0E6A587A25B9DB76ECADB97DCEBA8
E0EFAEC7C88CA58A5B7C6836A6B87AD0EDAACCD699949A5CDDEEAACFE6A0CBE29ACEE89F
C8E49AC1DF95C3E197C4E499CAECA0D0F2A6C1E397B7D98DB6D68BCEECA2CBE59C9CB26A
A7B87283924DD6E19DE2F3AC91B15ECEF4A1BADA8FCBE5A6D4E8B5E2EECAF3F8E1FFFFF4
C8C3BFA89FA0A2999EB7AEB1D2C9CCCAC5C2FFFEFBFDF9FAF7F5FFFEFEFFFCFFFFF9FFF3
FBFFECCFDBB3CEDCA7C3D3949AA76294A0585259138C8F4CA19F62AFA871B2A875A49A67
9E985E58581CA5AD71D7E2A8D5DDAAD5D6AE93876DAC988DFFF6F5FFF9FDFFFAFFF8F6F9
FFFFFBFAF7EEFFFDF1BAB49CAAB289D9EAB6D5E6AFCEE0A6BBCD8FDAEDABD1E5A08B9F58
50641CC5D992CADB972639003D4D0E9AA96EC1D097D0E4A7C9E9A0C6EB9BC7EA98C8EB99
CAEB9ACAED9DC9EBA1C5E8A4C1E8A7C9DAA4AF916DC6A27ED4D49EC9DE9DB8CF87C7E197
CCE5A1CAE3A1CFE8A7D6EFAED4ECAECDE5A7CCE4A8CFE9AC
A2B671D7EBA6DAEFAAC4D994CEE59DD2ECA3C7E399CAE89EC9E99DC8EA9DC8EB9BC6EB9B
C6EB9BC6EB9BC6EB9BC8EA9DD6F4AAD2E7A4BBC08A716D40C2BC9AEAE9CB636E50667659
D4E7C7CDDBB8DCE0BDD8D9B1BCBF90FCFFD1C1DE9EC6EFABB7E8A7CCFFC2C4F5BD25541E
4F7A45CDF5C0C9EFB6C4E8A8C0E19AD7F7ABB5D484D1F0A0C6E295C2DE94DDF6B4CCE9A6
C8EDA0C6ED9EC4EB9CC7EE9FCAEFA2C5E79BC4E499CEECA2D1EBA4C5D994B4C3809CA765
E7EBAE6F7034C9C98DD7DC9CD3E09AE6FBB0D7EBA3CFE59CD4EAA2CFE69ED2ECA5C8E29B
CDE6A2E1FAB6EFFFC7E7FFBFD3ECABCAE3A2D1EAA9DAF3B1526C25839A52D0E49FDAE9A6
D0DA9BDCD79D6445177E6837AEC082D4F3AFD8E6A8828B4CCFDB99CDE19CCDE39BCBE59C
CBE59CDFFBB1CBE79DD7F5ABB7D78CC9EB9FC7E99DD1F1A6D2F2A7CCE89E91A860748841
DAE7A2D8E39FDFE8A587944EC7E492CBEE9CC5E399DDF5B7C8DAA8E1EBC8FFFFECC4C2B6
FFFDFAFCF3F4FFFCFFFFFCFFF8F2F4FAF6F3FFFBF8FFFFFDFEFEFFF8FBFFFCFFFFFCFFF6
F4FCE4DCE6C1B6C08E7E894F97A05FD5DE9BD0D793F3F8B6D6D79BD2D198D5D29BD9D8A0
DBDCA07B7F429EA168E8EBB675734A504A2AB8AB9AFFFBF4FFF8FBFDF0F7FCF3F8FFFEFD
FFFCF3EDECD8ADA98E797B56E7F3C1D3E5ABD7E9AFD3E5A9CCDEA0CADD9D9CAF6DAABD7B
CDE19C92A661253800879C59C3D694D6EBA8E0F3B3D4EBA7CBEBA2C8ED9FCAED9DC8EB9B
C9E99DCDEDA2D4F3AFD6F9B7D9FDBFF1FFCCCEAD8AAE8864DEDDA7D6EBA893AB61E3FDB4
CDE3A3D5EAB1DEF3BAE5FAC2E4F8C3D7EBB8D1E7B6DAF0BF
777D3DB3BC7BD3DE9CD1E09DD5E9A2D0E79FC6E298CEECA2C8EA9DC6EB9DC6EB9BC6EB9B
C8EB9BC9EA9BC9EA9BCAE99BC9E696C8DE95969B63A9A67BE7E0C38E8C733F4A2C677854
D0E5BACBDDABCBD49DA8AD73CFD99CDEF0B2C6E6A5C5EEAABFEAA3BAE7A2C5EEB2719A62
001400C6EEBCB7DEA9C3E9AEBCE19CCDEFA3D8F9AACDEA9AD9F4A7C7DD94D2E5A3C1D693
CAE89ECDEDA1C6E69AC5E599CEEEA3CAEA9FC4E298CDEBA1DBF5AECDE29D748541D8E4A2
BBC5869DA365C5C98CE5EEADCEDF98D0E69BC1D58DCDE199DBEFA8D7EBA4D8ECA7C9DD98
DBEEACE2F5B5F8FFCDE8FEBEC0D89ACBE3A5D7F1B2B8D1908BA05BAAC078DFF4AFCCDB98
DEDFA3DBCC9568491B745E2D98A669B6D390D2E7A6A1AD6DEAF3B2DBE6A4D5EBA3D6F0A7
BFD690DAF1ABBCD68FD4EFA8CFEDA5C0E097D7F7AEC1E198CEECA4B2CC859DB26D9CAD69
CBD694E8EEAED2D797343F00CAE594D5F6A5C3DF95BCD294D8E8B7EBF2D0F5F7E1BEBAAF
FFFDFAFFFCFDFFF7FCF5EFF1FFFEFFFFFFFBFFFFFBF9FAF5FEFFFFFAFCFBFBFDF8FFFFF3
FFFFEAD6DCB87A805269703ACFD79BDDE6A5D5E09CCCD994D4E09EE3F2B1D9E7A9D3E2A1
CDDC999DA768898C53DEDAAB827A56625741E7DFD4FFF8F6FFFDFFF3EEF5FFFDFFFFFEFA
F3F0DFF0F1D290966AB4BE89CEDEA0CEE3A2D7EBACD0E4A5E1F5B6DAEEAF394D0EDDF1B2
D4E8A9708544485D1AD0E7A1CCE19CCFE69ED6ECA3C4DE95C5E59CC6EAA0C9EB9FC8E89D
C9E79DD1EFA7E2FFBDEFFFD0EEFFD4FCFFD8FFE1C1ECC4A1F2F1BBCDE09E9DB569C9E098
D4E7B0EBFBCEF6FFDAF7FFDDF2FFDBE0F0CBD5E5C1DFEECD
7A7639727033AEB071E7F0AFD8E7A2C8DE96D1EDA3CCECA1C6EB9DC6EB9DC6EB9BC8EB9B
C9EA9BCAE99BCCE89BCDE899D9F6A2C9E09262672DA09D74D1CAAE6D6B54000700ECFED6
CDE4ACDDF2B1AAB570B6C077D7E49EC6DB96CEF1AFC1EAA4CFF5AAD0F4AAB8DC9CC9EFB6
89AF7C173D0EC4EAB9CBF2BBCFF3B3B9DD95CFF0A1C1DC8DC8DF91E7F9AFAEBA78BFCE8B
BFD58DD0EAA0CCE69CC3DF94D1EDA3D1EDA3C7E399CDE99F9BB66F163000B4C984ABBF7A
596827E6F2B2E1EBACCFDE9BDEF4ABBED68AE5FBB2DFF3ABC9DA94C4D38EB0BC7ACCD896
D7E3A5CCDA9CD8E8AAD6E8AAC9DFA1D7F1B2C2DEA17C9655D9ECAAC7DB94CCE69FCEDF9B
EBE2A97A632F85693A9C8A58B9C387D4EAA9D2EBA994A765C7CC8CCBD090D7EBA4C2DC93
E7FCB7BFD48FE9FFBAB6D089D0EBA4C7E59DBFDD95CCEAA2CCE7A0D6F0A98DA15CB2BE7C
CED796CFD494E1E1A3515814DCF4A6BBDA8ADAF4ABD9EFB1D1DFAEF1F8D6F4F3DED2CBC1
F8EEECFFFCFDFFFCFFF9F3F5F6F2F3FFFFFBE6E7E2FEFFFAFCFDF8FFFFFAF9FBF0FFFFEF
FFFFE8AAAC875A5D309FA370DFE7ACD7E3A3DFF0ACC6DC94CDE79EC4E298C1E399D2F2A9
D5F1A7AEBF7B5659226D663AA19275D7CAB9FFFEF8F6F7F9EFF4FAFCFFFFFFFEFFFFFCF3
FFFFE6C7CCA3D0DEA3D8ECA7D8EEA6D6ECA4C8DD9AC3D8978EA263869A5DCFE3A675894E
102400879D5FD5EBAAD5ECA6D0E89ECEE69ACCE594CCE999C6E69DC8E9A2C9E8A2C6E49C
C2E09AC7E4A1D7F1B2E0FEC2D8F9C2DBE7B7FFE0C0FFD7B4DFDCA7CADE99D9F1A54B621C
C3D0A2EEF8D5FCFFE6FCFFE8FBFFEAF1FBE2E6EFDAF0F9E6
AFA3696E6429868245CED393D8E39FCDE19AD2EEA4C8EA9EC5EC9DC5EC9DC6EB9BC8EB9B
CAE99BCCE89BCFE79BCFE897BDDA80D3EA98646A2EC9C69DE7E0C4B9B49E162100DEF1C3
CCE5A3BED688A4B35ED8E68FCADC8AD2EA9EC4ECA6C0E9A3BFDE90CFEA9DC3E09DD1F0B5
C4E4B3002300527648CAF1BCC6EAACC2E6A0C2E195DDF5A7C6D88CD6E2989FA663CBD491
A6B66FD0E19AD4E8A0C6DC93D2E9A1D5ECA4C9E39ACDE99F87A25BE6FFBABBD58E96AD67
9EB571CDE29FDAEDABC5DA95CAE49AD2EDA0CAE095CEDF98909F5A65702C818A495F6525
D9E1A5D7E1A4CFDDA0CFE1A3DDF3B5D8F2B5AFCD8F86A05FD3E3A2D9EAA4CBE9A1C5D994
B7A670573706B69B6CBAAD79C9CA91C4D495CCEBA78FA8645757196E6C2FBACE87779148
455A15475C17C0D791C0DA93D8F3ACD8F6AEB4D28ADCFAB2D5F0A9879E58CDDE9ADEEAA8
D9DF9FEFF1B2A09E614C510EC7DE90C5E494C8E299C4D89BD3DFAFDBE1BF75735ED1CAC0
FFFAF8FFFCFDFFFCFFFFFEFFFFFEFFF8F9F4FEFFFBF5F8EFFAFCF1FFFFF4FFFDEEFEFDE8
F1F0D270704C939468D4D8A5CCD69AD1E1A0D2ECA5D1F1A6D4FDAEB8E796B9ED9AC0F19F
B8DF90DDF4AEE3E6AFD7CEA5FFEFD7FFFCEFFFFFFBF8FFFFF0FDFFF7FFFFE5E5E7FFFFF4
F8F7D88D9661D0E79FC4E18FD1E99BBFD58AD3EAA2E8FFBB849A5AD6ECAE62773E6E834A
D8EDB4C3DB9DD9F2B0C2DC95CAE598D7F2A1CBE792D1EE9ACAEAA1CAEAA7CCEBA7CCEAA4
CCE7A4CBE5A4CBE3A7C8E4AAC8E6B2DFE8BBB0896A744927DAD7A0DDF1AAD1E89A495E19
A2AD85E2E6CDFCFFEAF9FCE9FFFFF3FFFFF4F8F9F1FFFFFA
DCD6989490516C6C2C999E5CD6DF9CDCEBA8CCE09BCFE6A0CCE7A0CAE89ECAE89ECAE99D
CCE89DCCE89DCDE79DCFE799DAF09BCFDD8E585B22EFECC3A49F822524087B8562E4F6C4
D2E9A3798F3DCADA81D1E286D1E58ED8F3A2BEE69DC1E9A0D0ED9BC8E190E3FAB4A0BC82
7EA2763159340013006E996CBADEA1DCFCB3CFEC9CCEE796AEC479566720A7B26EE8F3AF
8E9F59C8DC94D7EDA5C8DE96D1E79FD4EBA3CBE29AD0E79F8EA861C5DF98D2EDA6A3BE77
C7E59DD4F2AABCDA92D2EEA4D4EEA4C5DD93D7EBA3B5C67F90A15BB0BC7AA2A26458581C
D0DA9BE5F3B5D2E2A3C5D99AD4EDACBBD5949FB374B2C585D5E4A1CFE39CC6E298DCEBA8
9C8B53785A28C1AB79D1C690D0CD96E4F0B2C3E19BC4DF98E3E9A9CFD492DAF1A9C3E296
D3EFA4C8E298637D34B2CC85C1DB94C6E099DBF6B1BED992CBE59E93AA62CBE199D4E59F
DDE8A6C9CF8F98995D99A261CFEA9DCAEB9CCDE6A2EBFCC5FBFFDAFFFFE66D6A59FFFEF6
FFFEFBF8F4F3FFFEFFFEFFFFF4F9F5FCFFFDFCFFFBF9FAF4FFFEF4FDF3E7FFFFEFF9F4E0
C0BFA34B4C2AE7EDC1DCE6B2D0DEA3E2F7B4BED992C4E699C9F2A3B9E897C9FFABB8EC99
CFF8A9C2DE94D8E2A6E3E0B3FFFFE3FFFFEDFCFFF8F2FEFAF4FFFFF7FFFFFEFFFAE0E2CD
989D75C5D398D8F2A8CAE793D0E996D1E697D6EAA3475A1ACFE1A76A7B455E703CD0E5AD
CDE5A9CEE9A6C0DC92CEEA9DC7E494D5F29EC6E38FCDE99CCAE7A5CCE8AED1EDB3DDF4BC
E7F8C4E7F5C4D8ECBBCCE4B2CAE5B2D2D8AAD1AB87835933ECE7AFD0DF9AD1E69BD1E1A0
919C71DAE1C2F7FDE3F1F6E2FEFFF3FFFFFAF9F8F6FFFEFF
D6E89CD6E69D94A15966712C8C9252CDD194EBEFB4DEE1A8D5DAA0E3EBB0D5E1A3CEE19F
D4EBA5D0EBA4CEECA2CBE399DAE299616220959360D9D7AE71714F777B5AC1C9A2DEEAB8
4F5E1D9AAA5FD5E48FD4E98EC5DD85DBFCA5C5EC9BC4EB9AC3E591D5F0A1D0E69D809C61
CDF9D53971584F8B72386E4ABEE2A5D1EC9FD2EB97C6E38F8DAF65CBECA7D4E9A4CFE39C
8BA95FC5E59AC8E69ED7F2ABC8E29BCBE29CD4E9A4D0E5A0879C57DFF6B0C8E29984A357
D0F2A5BFE697B7E18FCFF4A6C8E299D5E9A2D3E29F889955849E57E5F5B49C935A61581F
C8DB99CCEAA4D2E9A5CDE6A2C8E9A2D3EDA64A4C0DE1E1A1CEDE97CFE59CE4F5AECED794
9D93566A5921E3D49D948951A19F66DAE3A4D4E9A4C7E198D6EDA5CDE79DCBEB9FC0E693
BBE18ACFF39CCAE99B46601790A763D9EEABC9DE9DD1E8A400110088A459C8E499D9F3A9
DBF2ACC8DB999BAB6DC5DA99BCDE94D4F8B0CFE7ABE4F1C5FFFFE6D5CFBFFFFEF6FFFEFA
FFFFFBFBFFFDF8FFFDF5FFFDF7FFFDF8FFFDFBFFFFFFFEFBFFF7F3FFF8F1FFF6EDFFF5E7
5E5D489DA485EAF9D0D0E2B0CEE4A6D0E7A3CEE89FCDE99ECCEB9FCBEDA1C4E8A0BDE197
C4E797D8F4A9CADF9CCFDCA6FAFFD8FEFFE4F1F9E2FBFFF1F8FFF0FBFFF1FCFFECD6DDBC
BBC799D2E4AADBF2AEC0D88CD9EF9CD2E393A1AD6BD2DDA56A71450007008F9C70D6E9B2
CFEAA5CAEB9CC8EC94C8EC92C9EB95C9E898CCE69FCDE5A7CCE0ADD4E9BEDEF7D0F2FFE2
FFFFEAFFFFEAE8F5D7CDE4BAD8EABAD8D8A4A987599B7544E5DD9FD1DA97D7E2A04F5D1F
9BAD71C1D49DD2E1B6E4F2D1F5FEEBF7FDF3FEFFFFFDFEFF
D2EB9AB7CE80E0F2A8BFCA854F54146664299A935D9C925F81774469632F4F4E169FA569
D7E3A3BFD38ECBE29AD2E39DD1D090685F269B9767E2E0B7727351A0A682DFE6BD939B6C
5B6328C8D28DDFEC9DD2E490D4EC96BADB84C5E896D2F5A3D5F2A2BAD284D1E59D9CB87D
ADDBB7447E663F7E69B0E7C78BAF728DA55997AE5C9BB66591B670BDE29DCAE49DC9E197
708E44C3E39AD2EDA6C6E099C5DA97DFEFAEB1C07D6C7836D9E5A3C9D895D6EAA393AB61
C8E79BCEF1A1D6FDACC1E494D3EDA4CFE09C7B8A4790A45FCAE9A3CADF9C9D925A544911
DBF2AECFF3ABCCE7A0C4E29ABCE297D0EAA1575113EEE6A7DAEBA4CAE598CFE099DAE19E
A4A363645B20DFD69D726C3296965AD4DD9EC9DA96C7E198C1E196C5E79ACFF4A6CCF3A0
D4FCA3BDE189C3E090BDD58B7F8F4EDEECAEC3D193ABBB7A8FA55DC8E096C8E396BBD78C
C3DA94D6EBAAA5B77BDFF3B6D7F6B2BFDD9DBFD19FFFFFE1FBF4E2A4958EFFFAFAFDF1F3
FFFFFDFCFFFDF8FFFDF7FFFDF8FFFDFBFFFFFFFFFFFFFBFDFFF7F3FFEDE7967E746D6151
898B73FAFFE3F7FFDDEEFFD0EBFFC3D3EDA6C5DD93CBE397D2EAA0CEE89FCDE8A3D1EFA7
C5E496C5E292D9F3AADDF3B3C9DBA7D1E0B5DEEAC6CCD5B6F5FEDFFCFFE4FCFFE1879468
B6C793CDE1A4C9DF9ED9F1A7D2E895C0D1818D9959DFE7B4444921717751CDD8ADCFE2AB
C9E49DCDF19ACCF396C5EC8FC6EA93CDECA0CFE7A9CBDFACDEEEC7E4F5D3E8FFE3F6FFEE
FFFCF4FFFAF1E4F0D8CAE0BAC7D7A6E7E6AEAA8B55B090578C8747939C5BB6C0838C9A5C
C6DB96D2EBA9D6EAB5EEFFD8F9FFEDF8FFF7FCFFFFFCFFFF
D3E599DFEFA4E1EDA5CDD490C0C082A19C62554C159588549D905CDED19CA89D67756F35
5756166B6E2BC8CD8AD5D895EDE7AB605720A7A07286835A353513E0E4C3D9DDB8B3B68B
8C8F5A717636BBC37AD3DF93DFF2A3D3EE9FC3E296C7E69ACCE194E2F2A7D3E29F819860
C1E7C04E7F6143785CC8F7D3BCDAA4AEC581BFD489C3D98ED2F0AAD6F3B0D7EEA6DDF1A9
B2C67FDAEBA5DEEDAAD9E4A2DDE3A3E2E7A79D9F60727234EAEAACCED091E4EBA88C9753
D0DF9ACCE098CAE298CFE99FD1E79EA2B66FB1C27CD0E79FCFF1A7BBD28CB1AB6F686226
BFD690B9DD93C2E09AD1EFA7CAF0A5D6F1AA575316DAD496CCE49AD0F0A4CDE49CD4E19C
999E5E615F24E4DFA56F6D34ABAF74E1EBACCDE09ED8F3ACC5E59AC3E598CBF0A2C2E593
C2E28DC9E591DFF4A7DCE9A4B0B67AA7AA719A9E63ACB274D6E19DDBEBA4D7E99FD1E59D
D8E7A2E1EDAD9DA56AC8D198D5E7ABDBECB5F0F5CCF5EED2FFFAEF644A4B91767DFFEFF7
FFF9FFFFFCFFFFFEFFFFFFFFFFFEFFFFFDFFFFFAFFFFF8FDFFF7EF8D70605644309D967C
DBE1BFF0FFD4CFE6B2EBFFC8CAE39FD2ECA2D5EDA1CCE395C5DB90C8E096CDE79ED0ECA2
D1EE9ECFEC9ACAE49AC8DF9BCFE3A8DAEBB7DAE7BBCEDBB0EFFCD1D8E7BCAABA8BD0E2AE
C9DEA3BAD391CFEAA3CBE699CDE6929AAF60849352EAF4BF3C4319D5DDB4F1FED0C7DAA2
C7E399C6E995C6ED92C6ED94C6E999C7E4A1CCE3ADD1E4B7EBFAD9EEFEE3EFFFECF8FFF2
FFFDF4FFF8ECE4F2D8CFE8BED6EAB5D5D89F876E36644A0FF0EFAEC7D391E5F5B7D0E2A4
D2E9A3CDE4A0C4D9A1E3F5CBF9FFECF1FCEEF5FAF6FAFEFF
D0E69BCEE398CEDF98DBE8A2DCE5A2D5DA9A97975BBCBA7FE7E2A8EFE9AFD3CD93D6D094
A7A3635F5E1B7D7C39A7A665938D51615A24A29E6FB4B28B565735A4A887C9CAA8EDEFC7
E7E7B5828349A5A766D2D993CBDB92D8EEA5D1ECA5CBE59CCEDA92D4DE97BAC688869B63
CBECBF5D865E143E18BBE1B8C9E7B5C7DFA5D6EBAAD2E6A1D9EEA9C9E09ABDD38BCCE098
CFE09AD3E09BD4DF9DD9E2A1DBE0A0D1D394979759A8A86ADBD99CDFDFA1E3E8A697A05D
DBE8A3D2E39DC7DD95E0F6ADD2E89F8DA35AD8ECA4D2ECA2C2E497D4EEA5C4C3834A4609
DCF3ADD4F6ACCBE9A3CFEEA8C2E69ED0E9A55E591FDED89CCCE29AD0EEA4D4E8A1D8E3A1
A0A064554F15BFB67F958C55AFAD74D9DDA2D1DB9EE0F0AFDAEFAACCE39BD5ECA4C1DC8F
D4F19FC8E593CFE499CAD996E2EAAE52571D4F5519AFB879D8E5A0D1E399D2E79CD1E69B
D4E59FB8C786A9B377CED79ECCDBA4DBE7B5FFFFDFFFF9E3FFFAF3E9CFD23F242DD4BAC5
FFF9FFFFFBFFFFFDFFFFFEFFFFFDFFFFFBFFFFF9FFFFF9FDFFFAEC5E4D339B9275DEE0BB
C8D5A9C7DEA8CAE6A9CBEAA6CFEFA4CCEB9BCAE594CBE695D3EE9FD7F2A3CEEA9FC2DE91
C3E08ECEE998D1E99DD1E8A0D2E7A6C8DA9EC6D59ED3E1ACCFE0AACADDA6879A62CFE5A7
C3DC9AD4EFA8DAF8AEC3E294D4F09C88A0528A9D5BCBD8A2454E21CCD7ACC6D4A1CCE0A5
D0ECA2C0E190C0E48DCCEF9DCCEBA5C6DFA5D2E5B8E8F7D6F0FEE5F3FFEEF4FFF3FBFFF4
FFFDF4FFFDEDEDFEDEE0FCCCDBF3B9EFF8B96C591F6F5B20D8DA99D7E7A6BCD093CDE5A7
D3EAA4D3EAA4C9DEA5E4F5C9F9FFEAF9FFF4FBFFFBFCFFFF
D1F6A8C8EA9DC7E79BD2F2A6B8D48ACBE59CD7EEA8CEE29DC9DA96D7E49FD9E4A0D0DA95
DDE49EDCE49BB2B870939651514F12D4D39DECEBBBEEF0C8B9BD9A353B19010500D1D3AC
DAD9ABEBEBB794955BDEE4A4D8E4A2BBCF8ADAF5B2CFE4A1F0F5B27D7F3E8F9D62CBE2AA
B9D5A2A0C08E000F00B2D2A1C4E4B5CCE8B7D3EAB2D2E4A6D0E19BDAEBA4C9E197D7F1A7
98AF67C4DA92D5E9A2CFE09AD4E39EDBE6A29AA5619AA561DBE4A3D5E09EC6D592AEC27D
C8DD98D3EDA6DAF5AEC6E097CDE398B2C77CCBE196BED98CD7FAAAD4EEA4D4D593676626
BED28DD0EEA6C8E39EC9E7A1C0E19CD0E6A5645F28E5DCA5E4EFADCBDC96D5DB9BE9E4AA
D5C68F735D2B8C71429C8454A08C5AC0B07C958C553E39002D2D005B5B1DBDBD7DE5F0AB
B8D988D3FDA9CEEEA2CBE6A1CADE9FD8E8AADFEFB0D1E4A2CCE69CCBEA9CCBEC9DCBEC9D
C9E79D88A25BC9DD9EDAEEB3CCE3ABE4F8C7FBFFE2FFFFECF8EFE6FFFAFDFFF7FFB4A7B0
FFFBFFFFFEFFFEFFFFFEFFFFFEFFFFFFFEFFFFFDFFFFFDFBFFFFEA827F5CCCD3A9CFE1B1
C1DEA4CCF1AEC3EDA3C1EC9DCDF7A3C1E993C1E58ECCEE98CBED99BEE18FC0E595D1F4A4
C6E1909EB766B8CF81DEF3A8CEE29AD3E49EE9F9B8DBEBAADBEEAE677C3BAFC682DDF7B0
C8E39CC9E79DC6E599CBEA9CCBEA9AA9C37999AE6D94A36A535F2FD7E0B1A9B681DBEDB1
D5ECA6CCE89BC7E698C8E69CCEE8ABD9ECBEEBF9D8FBFFEFFAFFF3F9FFF8F9FFF8FEFFF6
FFFDF2FCFAE5EAFFD8E5FFCEF4FFCFFBFFC57C7133847639656B2B9CAE70A6BF85BCD89B
C0D78FD9EFA7D7EBB0DFF0C3EFFCDEF5FFEFFBFFFAF8FEFA
ADD688D3FCADBDE698B4DD8FD4FDAFCFF5A8C6EB9EC8EA9DD4F4A9D1EDA2DBF3A9C5DA8F
CADC90DDEBA0D1DD93E7F3ABD8E3A1CAD59BD7E5B0E3F3C4ECFDD1D7E7C0728158667348
DCE5B6E1EAB5788148DFEDAFE0F5B4C5E09DCCF0AAC3E19B89924FC8D190D0E8AECDEEB5
CEF0B3AACD8D001B0097BA80C3EDBFC1EABEC6E8B6C2DEA4C1D78FD7EFA1C4E99BC5EB9E
85A157CBE29AD6EDA5D0E69EDAEEA7DBECA693A45E7D8E48D7E6A3D9EAA6BCD18CBDD490
C8E19DCCE7A4CFECA9C6E099CDDE9795A55AD7EEA0CFEA9BCAEB9CC7DF93E0E3A0D5D493
808F4AC4DB95CAE39FCEE9A6CCE9A7D5E7AB615A26DDD6A0DAE6A6CCE09BD7E0A1DBD99E
F8EBB6CFB9889F8757755D2D735D2E4E3C0A625622B0A770E2DBA4B1AB71948E52D4DB98
D4F7A7BEEB9AB9DF94E0FFB9C3DC9BCBE1A1CEE3A2CBE59EC5E498CBEE9CC7ED9AD0F5A5
C1E39675934BD2EBAAC5DDA1CEE9B2EEFFD6F2FFDEF6FEE7FCFCF2F4EEEEFFFCFFD3CCD3
FFFEFFFFFFFFFCFFFDFCFFFDFCFFFFFEFFFFFFFEFFFFFFFAFFFFE88A8C65CFDBADD5EAB2
D8F6B6CCF1ABB3DC8EC9F3A1B6DE88C8EE99D2F29FC9E996C9E696D1F0A2CFF0A1C5E496
495F1454661C8D9D54CEDE95DCECA3CEDE95C9D990C6D88E8FA35BC5DB92E0F6ADB7D187
D1EBA2E6FFB8B3D187C6E49ACDECA0C9E39AC5D99AD9E6AE59632F4A521F071000BFCD90
CADE99D6EDA5D1EBA2C1DA99CDDFADF0FCD8FEFFEDFAFDF2FEFFFBFCFFFDFEFFFBFDFDF3
F6EEE1E5E5CBD5E7BDD1EEB4D0E9A7CBD893B1A96A908649E0E6A8BFD195C8E4AA99B779
93AA62C7DD95D1E3A7CDDDAED5E3C2E6F2DEF9FFF6F1F8F1
94B66C9ABF72CDF1A7C8EEA1C7F2A3B2DD8DBDEA99BAE794B4DF8FBEE594CEF1A1D1F0A0
D9F1A3D5EA9DC7D98DCFE39BC8E7A1CFF4AFBCE3A4C3EBAFC7F0B8CDF4BFBCE1AE20400E
C6E3ADC4E0A690AC6FC4E4A1C0E8A1C9F7AEBDF1A6C1EFA49BB26AC6DD99C7F1B2C0F4B4
BDF0A5CBFAAAB8E394164501A1DDAA9AD9AEC3FBCCC2F2B8C8EEA3C7F19DBEF8A4B5EB9D
89A960D0E5A0C5DB93CADE97D4E8A1C5D99297AB6496AA63D6E7A1B5C984BED38ECCE39F
DAF3B1CEE8A7C7E1A0C9DF9ED8E39E818B44CEE096CBE397BDD98CD2E89DE3E6A3E7E6A5
828946E7F3B1DFF2B0CEE3A2CAE0A0D2DDA3615726E5DFABC5DB9ACDEEA7D7EEAACAD89A
E6E9B0F8F3BCD8CE9B6A602DA09867D7D49FEEEDB5DDE1A6C8CC91D0D49785864AB9C583
BEE094C7F0A2D3F4ADC4DF9CD5EBABCDE1A2CDE0A0D8EFA9D3EFA4D0EF9FBFE08FC4E594
95B369748F4AD3E9ABCCE1A8D2EAB6D3E9BBF2FFDEFBFFECFFFFF4FFFFFA726E6DE3DFE0
FFFFFDFFFFFBFFFFFAFEFFF8FEFFFAFFFFFBFFFFFFFFFFF8E8E0CBA59F7DF1F4C9CCD9A3
B7CD8DCFEAA3CCEB9FCDEA9AD3EB9DD8EEA3D6E69DCDDD96D7E49FDBEAA5BFD08A98A762
9BA662C8D18EBEC78496A05B78823B515D135B671B9EAC5FC1D284E8FAAEC4D68CD5EBA2
C5DB93C3DA94D2EBA7DBF4B0BED891E6FDB9D7E7A9CDD8A0949865D6D8A66D7039747C40
CFDB9BD5E4A1D6E6A7D4E3ACE4ECC3FBFFE4FFFFF3FFFAF6FEFCFDFFFDFFFFFEFBFFF6EF
EFE6D5D8D7B8C7D9A9C7E1A4D1E8A4E3EEAAA59F617F753AECEDB4D2DFA9CAE5AED4F2B6
869D57C4D891D8E7ACCFDFB0D4E2C1E6F2DCF9FFF6F9FFFA
CEDD9C98A867D1E4A2C6DD97D6F4AAC2E497C2E797CAF1A0C5EC9BD7FCACC7E899C5E093
CEE499D2E49ADDEAA4D3E29DD8F1ADB4D390DBFBBCC3E2A6C0E1A8CEECB6B6D19E69804C
000A00D5E6B0D2E4AAC8DEA0CEEBA8C1E59DC6F0A4C2E498929F5AD7E3A3C0E1A8C2EAAC
BFE197C4E393D4EFA092B26F4D7E51508863B2E2BAC0E6B3D2EDA8BCD88BC8F6ABC1ECA5
879C59E5EEADD5DE9DD2DB98DCE5A2DBE4A1D1DA97DAE5A1DBE6A2505B179FAB69D3DF9F
CDDB9DD0DEA1D3E1A6959F63CFCF91EAEBA9D6E39DCEE49BDDF3AAC7D891EAEBA9D5D191
3D3C00C9CE8ED8E4A4CFDFA0D8E6A9DBE0A8605326E2DCAAD4EAA9C9E8A2CFE5A4DCE8AA
D2D39AD6D19AEFE5B48F8554D2CA99E5DFABD5D29DE7E6AED9DAA0EFEEB558561B8F9555
D4E9A4D2ECA5D4E7A5CAD698DCE4ABE7ECB2D3D99DD7E09FD0DD95D5E59AD1E495DCEEA4
8F9E59919D5FD6DEA5DAE1AED4DDAEF5FDD4F7FCDCFFFFECFFFBEF7F7671FFF9F7FFF7F5
FFFBF8FFFCF6FFFDF4FFFDF3FFFDF4FFFCF6FFFCFAFFFCF4B8A596BBA78EFFFFDCE3E1B1
D7DFA3E1ECA8C9D68ED8E49CDCE39FD3D594DFDDA2E2DDA3A39E665651175C5A1F99995D
D8D79EE1E2A8E5E6AADEE09FD9DC99DBE199DBE398D3DE92D8E498CFDB8FE0EDA5CADA93
E4F5B1CADD9BD7EAAAC4D899D3E8A7CBDE9ED4DFA3D9DEA6AEAE7AD5D29F94915A74733A
E4E8ABD2DA9ED8DFA9F6FCCEFFFFE1FFFEEAFFFAF1FFFBFBFFFCFFFFFCFFFFFBFAFFFBF0
F6EBD5DDDDB9D0DEABD2E8AAD2E5A3D6DF9C9E985C9B905AE2DCAAD9E0ADC7DEAACBE7AD
8DA25FCADB97DAE9B0D3E0B4D0DEBDDDE9D3F6FFF3F9FFFA
D9C7959A8A57A39862A09B61D1D392C4CE898B9850CADC92BACF849CB1668B9B5298A35E
B6BD7AAEB07188884CA5A066BFB881BEB781A7A16D98925E999363A79F71B0A3792B1900
755D37AF966EB29970A08B5CA19660C0BC7F93985699955590773E8C723FA39C709E9C6C
C6BE80C8BB77F0DE9CD9D099A6B08E40523A99A38AE8EAC5D6CA96E9DFA4D8DDA5D6DBA5
DBD19CCCBC88DACB94E9DDA3EBDFA3DED497E9DFA1A9A1625951135D5517B8B276EDE7AD
E2D9A2E1D7A2F5EBB89A8E5AE5D5A1EDE4ABD4DA9CD8E7A4D2E19ED9E4A0DFDE9EFAF2B4
AAA065E7E1A5CDD395E7F3B5F2FABFDADAA4675A2DC1B786DEE6AACBD797EAEEB3CEC991
EBDBA8FFEBBAFFE4B98E7348A89064F5DFB0E3CE9FEBD9A7E2D19DC8B78367531E63541B
D8D497E5E5A7C3BD83E9DCA7F3DEAFAB9564AB95634F3C046F6122AAA15EEEE7A3EAE2A1
A3995EEADAA7EBD6ABE0CDA5E6D7B0E7D8B7FFFDE3DCC9B8A38C84FFF8F4FFEEEEFFF5F6
FFE9E7FFF5F1FFF2E9FFE2D9FFF6EFFFF2EBFFF6F3BF9D9B724B46E9C3B6FFF7DFFFEBC4
EFE2AEF8EFB4D6CE8FEFE5A7F0DFA9FFE9B8FFE8BDF9DCB4C2A57BD0B58AD8C090D0BC8A
EEE2B2FCF6C4DED9A2E4E2A9E6E4A7D2D391E5E8A3DAE098E0E89FE0E7A1D6DF9CD2DD9B
E1EBAED4DFA3E1ECB2CCDA9FCEDEA0DBE9ABD6DEA3D7D89FB9B37FDFD5A08076418D864F
E3DEA6DAD9A1D8D6A5FFFFDAFFFFE3FFF6E2FFFBF3FFFAF8FFF5F7FFFBFBFFF0EBFFFAEB
FDF2D6D7D5ACE0EBB3CDDD9EDCE8A8D8DD9DA49B645B4B1AE6D7ACF0EBC1C4D4A7C8DFAB
97A96BC6D496DEECB7D0DDB2CDD8BAE6EFDCF0FBEDE5EFE6
A7865DB0916564491AA6925FA89B64A19D5E999A58ABB26EC9D38E939E599CA562C2C888
A6A76DB2B179AEA8749C9261B2A475AC9B6DAE9E6DBCAE7DBEB081AA976CB19A716B4D29
BC9979876343B08C6AC0A37BB59F6EB6AA70A09B5BB1A867B1945CBA9A6996855A908357
9C8750BAA0657154185F4E1A4C4B2C38402801030007020089784C928050736C40817A50
9B865B674F1F7860306C57228E7B438E7E438F814453480A6F63278C80445B4F1563541B
5747138472407B69377D683963481D6856287979458D985E525C1F595F217777395D5419
66551D5D5117717538A1AD6D3B40067E7D47A99F6E5B54204951157F8B4BA8AC6F67622A
857844604C1A7D65378B7345654E22806E3EA59562776A356558236D5E27877640605118
63591C6056195A4611634C1A74552769471A866635644612654D11806C2D77632498854A
634C18674C1F8F6F497352318A6D4D886F51563B26E5C9BBB4978F977875FFE3E2CAA4A3
AB827E9D706AE7BBB2AF837ACEA2999B7069AB847F764E4C805657B8918CFFE3CFDAC3A1
5446155E5419867C3F897D43BCA8768D7549BEA07CC1A07F81603D5C3E1880653AA48F62
6E5F34796E41554D1C534D1959541C615F228585457A7D3A585D1A4E5311777D3DBFC587
D0D59B9AA269969D67B4BD86B5C08496A063969A5FA3A0697A703BAC9F6B51410EA29561
B7AD78C8C08F999264EDE5BEFFFFE1CFC0A9A59283A49288DBD0CAE4D7CFBCA597FBE5CE
B5AD86969866838D519DA969939C5D8D8E54857B4A402D031400000E00000E1500031500
000B00000A00000B00000B00030D00111A09121A0F000A01
F1D1ABFFEEC6856D41756331EADFA9D4CF95ECECACDAE19EDDE6A3D3DE9CCCD699DDE5AC
DCE0ADD7D9AAE4E3B7CFCEA2E5E6BAD7DAABD4D8A6E1E5B2C7CB98CDCD9BE6E2B542360E
E9D9B7736341E5D5B1F4E8BED8D7A1D6DFA0D3E49DD3E098E4E3A2F1EDB0E3E6B19EA26F
E0DDA6DFD99F9691579499638C9E7490AA85304922000A00B2BB8C9BA17377825ABFC39E
DBCEA4564114A492649A8A57D6CB93CFC68B8E884AA29E5E989454D5D191959152A19B5F
A89F66CDC28CA19460B49F72755433A78C6EBDBA8FD1D9A88F9662979A63C5C98EA29D63
6A551E9D8C54BAC080D5E4A39FA76BB6B77E908B54575A2194AB679FBD75CFE6A295A463
B5BB7FA09F67AAA77063622A85854F9A9F65DCE4A9AAB477909A5D8E9758BDC3838A8C4B
7B7A3A615B1D70612A695522856B3A9E8252A38755876E366B571AA99A59C1B173BAAB70
937F4DA38C62D4BA97AE9173B89D80A68E749C8671EBD5C7EEDAD1FDE6E0FFF1EDFFF6F1
FCD7CFFFF3E9FFD9CEFFDFD2EEC6BAFFE0D5D5B3AA82635ED7BDBEF8E5DFFFFEE8E2E0BA
9398629EA768BAC382D5DB9DCCCB95DCD5A7CABE98C3B592968863AA9E769C9567DAD4A4
A1996BB2A77A9E96679B95639A9762A8A76EC5C68AAAAE718A8E519FA567B8BE80ADB377
878C52757A427E834D9EA66D7A8447444E0F84884B58531B655A245E4E1B3E2C00695928
AEA272C1B688958E62D6CEA7BDB39084775788785E84755ED8D3BFD9D3BDAB957DE9D5B2
8C8A596A72374A56166E7A3A53581E99976464582E210D006A4B2E37200130300A596638
5C69343B4715404B21616A4B727A657B83747F867E757C75
E3D1ABDACBA2C1B488655D2CE3E0A9E0E1A7E2E8A8CBD694D0DC9CE5F1B3E3EEB49AA470
B3BC8FA0A77EC8CCA9DEE4C0A0A883C7D2AAE0EDC1C7D4A6EAF6C6D5DEAF91946973714B
F1EBCB5E5538E5DFBFE8E9C1DFE9B5DCF0B1D3F1A7C3E294CCE098D0DD98D0DEA1808B53
EEF5C1D5DCA8D1DBA6D3E5B1CCEAB8B8DDAACBF1BE527442738E61D3E9C2DEF1D3D2DBBC
BEBA94BDB587DFD9A9D9D6A3EBECB3D1D799E4EDAADCE7A2CEDB95DEE9A4DCE6A1DEE5A2
E5EAAAE5E6AAE2E1A8CBBE9169472EEECFBBE1DEBDE4ECC3DAE0B2CFD3A1DDE6ADDFE0A6
594510FFEFB7D8E3A1D8ECA7CCD898D7DD9FDFE3A8707C3C7A954EA1C176DBF5AEC7D796
E1EBACD6DCA0D5D89FA1A66CB1BB7FDAE8AADCEFAFCEE3A0C9DC9AD3E7A2D6E7A1E7F7B0
E3EEA9CBD28EE0E0A2D8D298ECDFA8FCEDB6E7D89FAB9F635E5615E3E09DE5E4A3D6D497
99935F60572CA0926F322105B09F85E4D4BBF5E8D5F6EDDEFFF9EEFFFDF4FCEFE7FDEAE3
FFF7ECFFEDE0FFF6E8FFF6E6FFF7E8B195877A6256FFEEE7FCF2F1FFFFF8EFF7DFC2D1A6
D4ECB0D7F2ABBAD48BDEF5AFCEDDA4CBD5A3767B52CACFA7E2E7BEDDE5B6D1DEA8DFE8B1
D5D3A2E5DFAFE1DDADE4E2AFDADAA4DADDA6E7ECB2CCD498E7EFB4D4DCA0CFD79BCFD79B
D6DBA1E6EBB1D6DBA1D7DFA4DBE7A7D1DD9BD9DFA1EAE8AD9F945C998955A694645C4B1D
524518AAA274D7D3A6ECE8BBF5F0C6D4CDA1DFD6ABEDE8C0C8CEA8D7D9B4DACBA4F2E4B5
D9DFA1C9DA94D2E39FDBEAA9DBE2ACD7D4A7766C48140000A28067987A60E3E1BBDDE8BD
E4F0C2C6D1A6D3DDBAF5FEE3F7FEEEF6FCF2FBFFFBF7FEF7
DDE6BB98A174D5DFADD6E3AD8E9C61D0E0A2D0E0A1DBEEAECFE1A3CCDEA2D1E2AC182800
000A00000700081300000500000500081100CED9B9C9D5B16E7951000700030400FFFFE4
FFFFEA7A725DDED8C2EAEBCCFCFFDCE8FDC4C8E9A4CBF0A3CDECA0CCE49A97A663A1AA71
CED6A7D5E0B6CFE0B6C8DFB1BCDBA2D0F4B6C4ECB0557D484F744BD3F0D2CADBC8F0FAE2
FEFFE1F3FBCCD0DCAAC5D49DCDE1A4CDE6A2C4E298C4E498D7F8A9BBDC8DCEED9FC6E096
CDE49EBACD8BE1F1B0C4C492684937FFF3EAF6F6DEF1FCDAFEFFDFE4EDC0C9DAA4D4DDA4
A2925ED9CD93D1E5A0C9E79DD0E49FDAE9A6D7E7A6DBEFAADFF5AD8B9F5898A560D6DC9C
D7D79BE7E2A8D9D49C918F568F9358D4DCA0C9D799D8E8A7DCEDA9E2F1ACBAC782D7E8A1
C8E396CAE699D7EDA5D2E39FD3DD9ED2DB9CD8E1A089944FCBDB92CDDF95E3F7B0C7DA9A
C8D7A0D3DFB1FFFFE1FFFFE6FAF8DFFFFFECF9FCEBFBFFF4DFE9DEEBF5ECFCFFF8FFFFF6
FFFDF1FFFCEDFFFAECFFF6E5A695855B4E3EDDD5C8FFFFF6FBFFFFF3FFF9EFFFEACFEFBE
C1E8A5C4EFA0BEE798BDE396CAE8A8435E27D2E8B9C4DAACCCE4B2D7F2BBABCB8CCCE6A5
D8E3A7DCDFA8D6DBA3DAE2A9D4DDA4CED99FD7E5AAD7E5A8C9D79CD4E2A5DFEDAFD7E3A5
D4DE9FD9E4A2DAE3A2D7E3A1DAEBA7CADB95DDE8A6D5D798ECE6ACF4E9B3665827E6D9AC
E1DAAE848154DDDFB08F915F5A5D2883864DE3E4A8D4DA9ECFE2AAD7E6AFE9E4ADD9D598
D6EBA0C5E194D3EDA3C5DA99D9E3AECBCEA37C77570F00006F4A377B5B44EFEBC6BCC79C
CED9AFC5CFAAD5DEC1ECF4DFF2F8ECFBFFFAFCFFFDFCFFFD
DFF4C973895A566C3BD3E8B06D80489FB1758C9C5EA8B87AB3C186D8E5AF131C00DAE2BB
9FA48492967F8B8E7BA7A99BD6D9CE666C5E7E86717881667D8465BABFA1F0EED5FFF8E5
CEC2B6A89B92F2EADDF1F0DBFCFFE3DFF5C4BBDB9AC3E99EC3EA9BD2F1A3A5B26DD9DEA4
D5DBB5D7E2C4D4E9CAC7E2B9E5FFC4BEDF9AB3DC98C2EDB53C6844BBDCC7F2FFF3FCFFF3
FCFFE4E1EEC2586837B0C58DDFFBBEB9DA95DCFFB7C6EFA0C1EB99C4EB98C8ED9DD0F3A3
DFFBB1CEE8A1D3EAA4C6CA989C7E73FFF6F4FFFFF1F7FFECFBFFE4EBF8CDD1EAB3CDDFA5
A39862F5EFB3CAE49BB5DB8ED9F5ABC8E299CBE79DC1DD93D2E89FCFDF98939C599FA462
ADAB6EA19C6263612677763DBAC084DAE6A6DBEEACC7DC97C3D991CDE39AD1E59DD2EA9E
C4EA97CCF3A0C6E69ACFE9A0D2E7A2CDE19CDBECA6677D34DFF7ABD4F0A3C0DE94D2EFAD
DFF8BFC1D7A8F7FFE3F4FEE3FFFFEDF3F4E6FCFFF8F8FFFBF5FFFFF5FFFFEEF9F3FEFFFA
FFFDF5FFFCF1D2BEB33B281A7A6A5DB4A89CFFFEF4F8F9F1FBFFFFE6F3EAF4FFECDCFAC8
B8DD97BDE795D2F9A6C8ED9FCBE8A688A168CEE1B3CDE3B4CBE3AFBEDA9FDBFBB8D5F3AD
D4E7A5D6E2A2CDDB9DD3E3A4DCEEB0D0E4A7C9DDA0D4EAACD2E8AAD6EAABCDE2A1C1D590
D6E7A1D0E097E3F0A8C6D88EC2DA90DBF2AADBEAA5D6DD9AD3D196D7D099C1B786C4BD8F
9A976C111200C9D09D929D65939F5FA8B36ECFDA8ED5E698CBEBA2C9E49DD5D893DBE197
CEEB97C7EF97C8EB9BCDE6A4CAD8A5F3F9D36766480D00007E5949BB9B86FFFFD9FCFFDD
FCFFE1FCFFE6FCFFECF8FFEFFCFFFAFCFFFDF9FDFCEEF2F1
F2FFDFA6BD8F243A0BD0E2AEDBE9B4D2DBA49CA169A5A56F9C9A69655E32605632857A5E
F1E2CFFFFBEEBDACA5B0A2A1A9A5A4949492696B60ADAFA1EAECD7C5C4B0DCD6C6ADA399
AE9F9CEADADAFFFCF8FFFFF3FAFFE6E2F7CCC9E8ADC2EAA3B9E495D0F1A2DAE49DE1E2A9
FFFFE3E7F3DDF2FFF3F0FFE5D0E9A8D3EFA4C7F0A4C9F7B91B4827D2F4E4F9FFFDF7F7ED
FEFFE6FFFFDDD1DAADB1BF8CBED398C7E29FBEDE95C1E396C6E999D1F4A2C4E393C1DD90
CEE49BCCE099C0CF8CA3A272C0A29AFFEFF3FBFFF5F2FFEDE7F6D7E3F5CDCFEDB9CFE7AD
E6E1AA8E8C4FC3E599C9F8A7C7EC9ECBEDA0BFE697D0F7A8C3E294D7EFA3CFE099D5E09C
C4CB88D5DB9BBBC485A8B474ACBF7DADC682C5E59CC5E79BCFF4A7CFF1A4D5F5A9BDE090
C7EE9BC7ED9ABFDE92CAE199D4E8A1D5E6A0CDDC973D5109C7DD92C0DA90CDE8A1C0DA99
C7DEA8D8EBBEF2FFDFFEFFECFFFCF1FFFCF8EBE7E6EBECEEF9FFFFF2FAFDFCFFFFF9F5F6
887A799C84828A6D69FFEFEAFFF7F3FFF9F4FDEEEBFFF9F9FFFAFFFFFDFBFFFFEAD6DDB1
D4E4A3D0E596D1E493D4E499DBE4A5999E685E5D318C8D63C1C593CED79EC6D592CFE099
CDE199D7EDA4CDE49CD2EBA7F4FFCCEBFFC6C7E4A4CCE9A9CBE8A6C0DD9ACBE6A1DFF9B0
D3EA9C62772899AC5AB9D07EAECB7B99B56A869A52E8F5B0A2A66997965E817D4DE1DEB1
E0E1B7000800D7E4AFB6C88C8EA25BA4BA68D2E68DD3ED92CAF49EC4EA97CEDB8BDEEB99
C4ED8FC3F596BDE795CFEEAAC9DBABD5DFBC5D6146190E00856153C5A590D7D5AFAAB78C
C5CFADE5EED3E8F0DBE6ECE0FEFFFBFEFFFFFCFDFFFEFFFF
E7FBCAC7DBAA29390AD0DEADD2DCAAE6EDB9CED19AE1E0AADDDAA740390F8C7E61C3B4A1
FFFBF1FFF4F0FFF9F8FFFAFAFFFDFFF7F7F9FFFFFDFEFFFAE6E5E0C0BBB7D8D0CEF3E7EB
ECDDE4FFFAFFF3E9EAFFFFF6F9FFE9DDEFC7C9E6AEC8EDAAC3EBA2CDEDA2D6E19DBDC08B
FFFFEAFBFFF6F4FFFBF0FFEBEEFFC8BFD98FC5EBA0BCE8AB12411FE4FFFAEEFFF6F9FFF3
FCFFE6FDFFDCDFE8BDA7B381CEDDA6DCF0B1C9E29ED3F1A7C6E69AC4E797D0F1A0C3E292
D1EC9FDCF1A6DFEFA8929560C3AE9DFFF8F4FCFFF6F5FFF3F6FFECE9FCDCC1DEB0D0E9B2
DDE3A76E7734AFD582BCEA92BCE28FCDF0A0C7EDA0BFE598D3F4A5C1DC8DCDE398E3F5AB
D6E69FD8E8A1C8D7949EB26DD0EAA3ABC98190B067A4C67AC3E89BC7E99DC2E296CFEFA3
C4E69AC8E89DD3EDA6CFE49FCFE09AD7E6A1CEDE974F5F16D0E59ADEF4ABC8DD9AD5E9AE
D6E6B7D0DCB6F9FFE5FFFEECFFFCF6FFF4F5FFFBFFFFFDFFF9F7FCFBFAFFFFFDFFD9CFD0
5646466B5653D1B8B3FFF5F0FFF8F4FFFAF6FFFCF8FFFDF8FFFDF4FFFDEBFFFFDDD4D9A3
D9E59DD9E798DBE899D8E29DDBDEA9DDDAB1BBB497857E61908C69B3B286D9DEA8A2AC6F
B9C988C8DD9AB9CE8BB8D18FF2FFCAF2FFCCCAE9A5C9EAA3C7E8A1CFEFA6CBE99FC6E295
CEE698738839CADD8CD0E596CEEA9FCCEAA0DCF3ABB7CB84818C4A91995D989D65D4DBA7
DBE3B20A1600D9E7B2D6E8ACCBDF98D8ED9ED3E790D3ED94C3EE95C1E993D5EB98CCE28D
C3EC90C1F094C3ED9BCBECA7D2E9B3D0DFB66974520403006450387E6D5199A07776875B
7E8E6ABBCAABD4E1C7DEE7D2FCFFF3FCFFF4F4F7ECFEFFF4
8B9558D9E2A9A8B07F00070098A071D6DFAAD1DB9EDAE4A5A5AE75414719FFFFE8F9F7EB
FFFEFDFFFDFFFFFEFBFFFBF8FAFAFAFCFDFFFFFEFFFFFEFFFFFDFFFFFAFFFFFAFFFFFAFF
FFF7FFFFFCFFF7F6F4FEFFF4F9FFEADCEEC6CAE2AECEECB0D2F1B5C1DDA0C6DA9FB1BC91
FCFFF3F9FDFCFBFFFFF2FCF1EFFFD3C5DD9FC7EAA8C4F0B50D3D157DB18DB7E7BFC7F2C5
D6F6C7F4FFDCD7E9B9B1BF8C8C9661D1DFA4CFE2A2D8F2ABCCEEA2C0E99AC4EF9DC4EE9A
C5EB96C4E491DEF5A598A462DFDBB5F7F1D9FCFFECFBFFF3F5FFF0F1FFEBF4FFE8C9E1AF
CFE4A36C853496B95DC5EA8DC3E58FD5F4A8C8E5A3C9E6A4D1EBA1C9E493DAF3A2C4DD8C
D2E99BD3EA9CC6DC93A0B66DCCE39BDAF1A9BAD18B95AC66889D58809550C9DD98CBE09F
C6DBA0D1E6ABCCE0A3DAEDADD1E29ED6E69FD3E39A728035D9E69EC9D691D6E1A5DDE5B2
D0D7AEE4E7CAFFFFECFFFDF1FFFBF8FFF7F9FFF9FBFFFAFBFFF3F3CDC2C0948985726761
D7CAC2EDE3D9FFFCF0FFFFF1FFFEEFFFFFF1FAFEEFD9E1C9D3E0B5CEE0A6CDE19CCFE696
D1E993CFE793CFE39BD1E0A7E9F3D0F1F6E2FFFFF8FFFFFAF5F5EBFEFFEDF8FBDED5D9B4
FFFFDCE6ECBEA9B37FD7E6ADD9EFAFCAE5A0CBEA9EC5E697C4E795C7E897CDEA9AD4EC9E
C8DD92DEEEA78D985493A25FD8EEADC5E09DD7F1AABFD990D2E89FD3E9A0C8DC97D2E5A3
D3E5A9718349303F08D2DFA7D0DB9FE4EEAF5F692473833AA9C578BFE091D4EFA0CFEA9B
C5E695C8EB9BCDEDA2CAE8A2D1EBACD1E8B05B6F3C000A00DEE7BCF0FBD1D6E7BBDFF6C8
DEF7CDD2EDC2CCE3B99EB086A0AF867E8B60EBF4C9E6EDC1
B9BC85DBDDACECECC86465453E4221777E55CDD7A3D1DEA6596631B4C098FCFFF3FCFFFF
FEFFFFF4F5FAF9F9F7FBFCF7FEFFFDFBFDFCF8F7FCFFFDFFFFFBFFFAF3FFFAF2FFFFFAFF
FFFCFFFFFEFFF8FAF5FBFFF0F5FFE4DDEFC5D5ECB8D0E7AFC8DFA7D7EEB6E1F3BF8E9D76
FBFFF3FEFFFDEFF0F2FCFFF8D7E5C2D5ECB8C4E5ACBEE7AF6FA071528B5EAEEDB8A8E3AB
DCFFD1F0FFD8BCD39DDDEBB6616A33CFD89FBECC8ED4EBA5C5E59ABDE495C3EE9CC8F3A1
C7ED9AC1E090D3EA9C879655D7DDB1EAEBCCF0F4DDFEFFF1FBFFF4F8FFF1F7FFE8D2E8B9
D7F1B09EBD6D7C9D44CBE991DAF7A5BED88FDBF3B5C0D698C9E197D7F09FBCD584D3EE9D
D7EFA1BBD387D8F0A4A8C076D7EDA4CBE199DDF1ACDCEDA993A2616F7E3DA2B17092A264
A5B67FCBDEA7D0E4A9D6E8AACCE09BD3E49ECEDE9578853D939E5A767E42868A57AEB186
C5C4A5DFDDC6F5EFDFEDE5DAF3E4E1FFEFEDFFEFEEDECCCAA3908C806E6A94857EBDB0A8
FBF1E8FFFCF0FFFFF3FEFFF0F7FEECFBFFF1F1FDE9CFE0C0CFE8B1CDEBA3CFEC9ACDEB93
CEEB91CDE994CDE49CCBDEA7EBF8DAF9FFF4F5FBF7F7FBFCFEFFFBF9FDEFDADEC7E4E7C8
FEFEDCF5F6CEBCC495CEDBA5C4D899C1DB92D2F1A1D1F39DD3F7A0D0F29CCDEA98CEE499
CEDF99DBE5A6DAE0A498A168C3D79CD7EFB1B5CE8DDFFAB3D1EDA3BDD98EDAF4AAC9E39C
D1E7A67B8F52000B00D9E6AECED79EB9C186C7CD8F96A15FB5CB83C3DF94D0ECA1CEEA9F
C9E59BCAE69CCCE89ECAE59EB8D38ED0EAA96C8647000E009DB67FCDE5B1D1E9B7D5EDBB
CCE7B2D2EBB4D7EEB6C9DCA4D0DFA6B9C48A717B3FD5DDA1
928F70B7B59CFAF6EAFBF8F1AFAFA75D604F33391D232D0A626C4AFCFFEDECEEEBFEFEFF
FFFDFFFFFDFFFFFEFFFFFFFBFFFFF8FFFFF8FEFBF6FFFEFDFFFDFFFFFCFFFFFCFFFFFCFF
FAF4F6FFFFFAFFFFF3FEFFECEFFBD7DDEDC0DCEEBCC7DAA2D2E4AACFDEA7CEDAACF6FDDB
D9DCC7E8E9D9FFFFF3ECF1DDFBFFEAF5FFE3D8F8C9C2EAB6BAECB9457F4C76B481B9F4BE
BBE4ACD5F2B8CCE1A8C4D398D3DDA08F9859DAE6A4D2E69FC6E297D3F3A7CFF4A6C4E69A
C9E49DDFF4AFD7E5A75B622EFFFFE2FFFFECFFFFECE3EBD3D3DDC4E2F1D2EBFDD5C2D8A7
C2DBA1E6FFBEA5C0798DA75E8AA45B8BA25CCBE1A0DAEFACD1E79FCDE39ACDE39ADAF2A8
CEE49CD0E69EC3D991A4BA72CCE29AD6EBA6C5D994CDE09EDBEBAAD0E09FC4D493DCEFAF
8EA265CBE1A3D6ECACD1E6A3CCE19CD5E9A4D5E6A29AA966858F525C632D5B5E31777954
7E7D617775606E685A5C544983766E6D5E5765544D7E6F68B2A09CDFD0CBFFF0EDFFFBF8
FFFCF8FFFEF8FFFFF8FCFEF3FBFEF3FBFFF6F3FEEED3E1C8C6DDAFCAE6A9CEE9A2C9E696
C9E590CEEA96D1E99FCEE2A7E2F1CAF4FFE7FBFFF4FAFFF5F9FFEEFCFFEAFEFFE1F0F7CD
93996DBCC493C0CA95D8EAAED1E8A4CAE69BCEF09CBEE28BC0E28CC3E390C2DD8ECFE39B
DDECABDCE4A9CED19C9A9E6BE4F2BFE4F9C1D6EBB2C2DB9ACCE5A3D7F1AACFE9A2D3ECA8
CBE1A093A7682C3E02DEEDB2CFDA9ECED89B727D3B65722DC4DB93C7E399CDE99ECFEBA0
CCE89DCAE69BCAE69BCCE89EE5FFB9C6E19C506B280011007F995CD1EAB0D4EDB3B9CE93
D4E4A5D7E3A1D6E19FD4DF9DE2E8A8E7EDAD696D30F6FABD
272115B4ADA7FFF7FFFFFBFFFFFCFFFFFEFFF5F7ECFEFFF1EEF2E1FCFFF8FEFFFFFAF9FF
FDFBFFFFFDFFFBFAF8FAFAF0F6F4E5FFFFEDFFFFF0FDF9EDFFFAF0FFFEF6FFFEF6FCF5EB
FFFFF3E9E8D6D6D8C0EFF6D5FCFFDDFBFFDAF9FFD6CCDEA4CCDA9DFDFFCFF9FED6F7FBDA
FFFFE4CBCCADFFFFE4FFFFE6EEF6DFF7FFEDD3EECBB9DEB2B5E6AFD2FFD0104B1BBAF0BE
BFE6ADC0DC9FDCF2B4DCECADDFEAA8939D58E0ECA4CCDC93D7EDA2C9E497BFDB91CDE8A3
CCE0A1D2DFA7D4D8A67C7C56B4B6A0F1F4E3FEFFECDEE7CACDDBB7EDFED2F7FFDCD4EAB9
C9E0ACB9D09AD8EFB7C2D79ED5EBAD748946001500C7DD95D1E6A1C3D893D1E6A1D8EDA8
C8DD9AE4F9B6B6CB88899E59D7ECA7CFE49FD4E7A5DAEDABC5D896E0F3B1D6E9A7C8DD98
94AD69CEE9A2D2ECA5C9E09ACDE49ED4E9A6D9ECACC8D79CD4DEAACAD2A3DDE1BCFBFCDD
FFFFEAFFFDEEFFFEF4FFFAF1FFFCF0FFFBEDFFFDF1FFFCF3FFFAF4FFF5F2FFFBFBFFFBFD
FFFCFDFFF9FAFFFEFDFFFFFBFEFFFAFCFFF8F7FFF2D9E7D0D1E7C1D5F0BBD5EFB0C9E59B
C7E291CEEA96D4ECA0CFE5A5F0FFD2F1FFDBFBFFEAFBFFEAEFF9D7FAFFDDF1FDCBBECB95
A6B179C9D79CD0E2A4D9F0ACCDE99EC5E494CCEF9BC1E58EC7E995CEEB9BC7DF95D9E9A8
DBE6AACDD19E6F6C3FA3A47AFCFFDDDAE9BED6E8B8C7DBA6D2E7AEC0D89AD1EAA9BFD897
CDE3A3D5EBAB000D00D7E9ABDDEDAECFDE9DE4F1ACCFE09AD1E8A2CAE59EC9E59BCDE99F
CEEA9FCBE79CCCE89DD0ECA1B8D489D5F1A7DAF6ACCAE59ED1ECA9CFEAA7CCE6A5D0E9A5
D4E99ECFE293D0E095CADA91D4E19CDDE9A7C2CC8FF2FCC0
201615948B90FFFAFFFDF3FFF8F0FFF1EDFCFFFFFFF9FCF5FEFFF8EBEDEAFFFEFFFFFDFF
FFFDFFFFFEFFFFFFF4FFFFECFFFFE6FFFFE4FFFFE4FFFFE6FFFFE6FFFCE1FFFFE4FFFFE4
FFFFE3EFF0CEDFE3BED8DFB5ACB58687956294A36C93A166D9E3A6FFFFD1FFFFDBE5E5C3
D3D1A8D7D6A68F9160F9FED6FEFFEFF7FFF5E1F7E2D2F1CFC0EBB5A3D69B88BD8F002800
5E844BC6E4A4CCE5A4C9DC9AD5E29CDEEAA08B974BBAC87BD3E697D3E89DCDE39BD9ECAC
C8D29DD4D7AAE4E0BAA29D80D5D6C8FCFFF4FCFFECE5F1CDCBDBACD3E5B1D1E5B0C8DCAB
D6E8BED5E7BFC3D5AFE1F2C8CFE1ADBCCE90DCF1A6B2C77C91A4628FA163788A4CC0D294
C9DC9CD4E7A7D8EBAB8DA05ED0E3A1CCDF9DD0E5A0DDF2ADCBE09BD0E5A0A4B974869E54
ACC87BCCEB9BC9E598C3DF94CDE7A0CBE1A1CFE2AADAEAB9DAE5BBE9F0CEFEFFE6FFFFED
FFFCEDFFFDF2FFFEF8FFFEF4FFFFEFFFF8E6FCF3E4FFF9EFFFFCF8FFFBFBFFF9FDFCF1F9
FFFBFFFFFAFFFFFDFFFFFEFFFEFFFAFCFFFAFAFFF7E7F4E0F1FFE7EEFFDBE2FEC4D0EDAA
C9E598CBE896CEE99ACDE49ECFE3A8CFE1AFC6D5AAD3E2B7E2EFC1B7C68F8F9F619EAE6D
D8ECA7DBF0ABD2ECA3CDE99CC7E897BEE18DCAEE97CBEE9ACEEF9ED1EDA2CADF9AD8E6A9
D4DBA8CBCCA0908A66EEE9C9FDFFE2F3FCDDE4F0CCD3E2B9D8E9BCD8ECB75F743CD2E7AC
D5EDAF607635000E00C6DB98D7EBA6CCE099C5D690DCF0A9D1EAA6C9E4A1C5E09BC8E39C
CBE79DCAE69BCBE79CCEEA9DD9F5A8C7E396C3DF92D4F0A5C4E095C7E399CAE59ECFEEA0
C1E88FC1EA8ED1F7A0CEF4A1CAECA2C5E4A1D8F4BAB7D29B
5F55536E6367F9EEFFFFF9FFFFF9FFFCF4FFFFFEFFFFFFFBFFFFFAFEFFFDFBFAFFFFFEFF
FFFEFFF0F0E8D3D2BDB3B4929EA07986886086875D9A9B7195966C818256909165B6B98A
999C6D858C59868E5BB7C18CD4E1ABD4E3AADDECB3D7E5AAC5CF92676C34ABAC84D2D3AB
DDDDA7D4D697DEE2A5E0E3B4F0F3E0FBFFFADDEDE0E1FADDC7E8B9DAFFCDABD6A95D865A
335822C5E4A8C9E3A4D5ECA8C8D992DAEA9FC5D3848FA14F8EA1508B9D5194A55FD4E0A2
D8DFABE7E5BCE7E1BFA49E86FFFFF3F9FFF2F3FDE2DEEDC4D1E3AFCADDA5CCE0ABEFFFD4
DDEECAEFFEDFDEEDD0D7E5C4E8F8CBE1F0B5CCDE94CCDE92D2E2A1A1B37797A96DD4E6A8
D9EBADD3E6A6C9DC9C91A462CCDF9DE3F7B2CADF9ACAE199D1E8A0AAC47B8CA65CB5D282
C1E38CCCEF95C7E995C8E799D2EDA8C9E1A5C7DBA8DBECC2EBF6D6FBFFEBFFFFF1FEFEF2
FFFCF3FFFEFAFFFDFAFFFAF2FFFFF1FFFFEDFFFFF3FFFEF6FFF8F6FDF4F9FFF6FFFFFBFF
FFFBFFFFFBFFFFFDFFFFFEFFFBFCF6FCFFF6FCFFF3F9FFEFF5FFEAEBFFDADBF6C1CFECAA
CBE79CCAE795CCE798CFE79DCCE2A1D8ECB1DAEBB7C9DAA6ADBC8599A96BAFC07CD8ECA4
C9E195BEDB8BC4E491C9EB97D4F8A1C3E992C5EB94C5E894C1E092C9E39CD1E3A5DAE4B0
D6D9AED9D5B2FFF7DCFFFFE8FFFFEDF4F9E3FCFFECD2DDBF6F7D5A4C5D3396A8783B5018
071F008AA361D5EFA8D7EEA6C8DF97CBE399E3F9B0C6DD97CFE8A7CCE6A7CAE4A3CBE6A3
CDE8A3CEE9A2CCE89EC8E499CDE99CC6E393CAE797D8F5A5BFDB8ECCE89BD2EEA1CDEC9C
C8EF94C1EC90C7F19BC4EFA0BDE8A3C9F5BABEE8B6B5DEB2
756C5B827970FFFCFFFCF4FFFFF6FFFEF8FFFFFEFCF8FAEFEDEFE2FFFFF6EAE9E7FFFFFD
FFFEF7FFFFEFDFDFBB999C6D9DA47189905C89905A9AA2699AA2678D95599AA465B9C384
959F60A1AD6DA7B675C7D798D9EBADCBDFA0C8DC9FC7D99DDBE9ACA5B076858D5AD6DDA7
E2E9A5D1D990D8DF99BEC38DE5E9D2FCFFF8F5FFF6F7FFF3E1F7D1C2DDB0D6F2C9A0BF93
577947E2FFCEBAD99ED1EEACC7E19ACCE395D8EE9CC2D883788B394B5E0D526219C4CE8F
D4D9A3CBCA9ED1CBA7B8B497FAFFEDF0FCE8F7FFE6EDFED4E5F7C5D0E2AEC3D5A5EDFED4
EDFCDDF9FFECF9FFECFBFFE8FBFFDDDBE8B2CBDA95D8E9A2B3C382819153ADBD7FC3D394
CBDB9CDFEFAEC6D69598A965CEE29BD2E69ED6ECA3CCE49A92AD606A8639ABC878CCEC97
CAEF90CCF192CCF098C9EA9BCFECA9D2EBB4D3E5BBE2F1D2F6FFEAFCFFF4FCFDF5FBFAF5
FFFEFBFFFDFDFFFBFCFFFCF8FEFCF0FFFEF1FFFDF7FFFDFAFFFBFFFFFBFFFFFAFFFFFBFF
FFFBFFFDF6FEFFFBFFFFFFFBF9FBEEF8FFEBFCFFEAF9FFE6E8FCD7D6EDC1CAE3ACCBE5A4
CEE89ECCE798CFE897D4ECA0D0E7A1D4EAA9D6EAAFA6B98170824892A466CCDF9DCDE39A
DBF8A6C9EB94CDF199BFE68DCBF299C1E790C7ED98CCED9ECDE99FD7EDADDAE9B2D0D7AB
CDCAA9E5DEC4FEF1E0D2C6B8C9C5BAF7F7EBFDFFF1FCFFED192109E8F3D3EEFFD5ADC18E
758D4FC9E29ECFE9A0C2DC92E1FBB1BCD68CC7E197D2EBA7D6EEB4DEF5BFE2F9C1E1F9BD
E1F9BBE0F9B7D7F0ACCAE49BC7E197CAE598CDE89BD3EEA1C5E091D3EE9FD3EE9FC9E495
D8EF9DCDE695C4E096BDE09EB7DEA7C7F5C7B7EBC7A1D6B8
968F735A5340F1E9E6FFFCFFFFF7FFFFFDFFFFFFF8FFFFF3FFFFF1F4F6E9FFFFFAFFFFFB
F1EEE5FFFFECFCFCD6B1B582D4DDA6D9E4A8D9E5A7D3DF9FCFDE99D4E49DD5E59CCFE195
C4D98CDBF0A3CEE49BCEE59DD6EDA7CAE3A1CDE6A5D2EAACC7DBA0E0F2B8CCDC9D879651
9FAD5EB7C474CCD68FBEC68D898E6EE2E5D4F8FBF0F3F9EBF4FEE3E3EFCBDBEAC16C8156
304F23365A2CC5E7B4C6E8ACD4F5B0CBEA9EC2DF8DD8F19DC2DA84E3F6A4C8D88DADBA75
81894EBCC08DE2E1B59EA07BE6F1D3F3FFE7F8FFE6DCECC5CEDFB3CFE0B4D0E1B7F9FFE4
F9FFEAFBFFECF6FFE5E4EFCFE3EEC4D3E0AB919F615E6D2AB5C584C4D495D6E6A5DBEBAA
D3E29FCDDC99DBEAA56C7D3790A15AA4B96E82984D90A85AD0EB9CC3E090D6F6A3CCEE97
C8ED8EC6EE8ECAEE96C0E094C4E1A1D7EFBFE0F4D1ECFAE3F9FFF6FCFFFBFCFEFBFFFEFF
FFFDFFFFFAFCFEF5F8FFFEFBFFFFFAFFFFFAFFFFFDFFFAFEFFFAFFFFFCFFFFFBFFFFFCFF
FFFBFFFDF8FCFFFEFAFFFFF4F6FBE4EBF5D3E6F2CADAEBBFE7FACDCFE7B5C5DCA4CEE7A6
D3EDA4CEE698CBE395D2EA9ED3EAA4CBE1A1A6BA7F96A971BECF98DFF1B7DCEEB2D2E9A5
C6E693C0E48CCFF69DBDE48BCAF099C3E994CAED9BC8E89DCCE5A3D3E6AEC3CFA1AFB390
BAB49CFFF8E8C9B8AEC2B3AED8CECCFFFEFBFFFFFAF5F7EC4A4E3FFBFFECECFAD6D1E5B4
CEE6AAD0EBA4C2DE93D1EE9EC3DF92D2F1A5C7E399CAE4A3E0F7C3F1FFD8F5FFDAF5FFD6
F5FFD4F3FFCFE3FCBBCFE8A4D3EDA6CEE89FC9E399CEE89ECAE598CEE99CCCE79ACFE799
CFE290CDE391D3EDA4D2F2B3C3EBB7B0E0B8B5EECE478369
A09C795B553BFFFCF2FFFAFAFFFCFFFFFEFFFFFFF6FFFFF1FFFFF1FCFFF2FFFFFDFFFFFF
F0EFEAFFFFF1BDBE9E9DA373DBE8B0CADD9DCCDF9DDCF0ABCFE59CCDE597D8F1A0C9E591
C4E18DCFEC98CEEB9BC8E799CDEBA1CDEDA4C8E7A3C7E5A5CBE6AFC9E3A6CBE699D3ED96
4961097E913FE7F6B1CED99FACB387D4D8B7EAE9D5FFFFF1FFFFF1FFFFE8E1E2BA515D2F
47633D355B348AB184BCE3AEC9F0B1D1F7AEBBDE8ECAEA95D0EC97D0E894D9EC9BCBDB90
B7C3816D773A949D64919B69D4E3BAE8F8D3F9FFE4DCEAC7DAE8C7D5E3C2C4D1B3FBFFEA
FBFFEAFCFFE8F9FFE1D9E4BCCFDBADD4E1AC7F8C54B3C184CFE09CCEE29BC8D993DEEFA9
D0E099DAEAA3D3E39C48580F607228C4D98CD7EEA0CCE594D1EC9BC9E694CCEC99CCEE98
C5EA8DCBF093CCEE9AC7E79ECDE9AFE0F7CDF4FFEBF8FFF4F9FFFBFCFFFFFEFFFFFFFDFF
FFFDFFFFFDFFFFFDFFFFFEFFFDFDFFF9F9FBFFFEFFFEFBFFFFFCFFFDFAFFFFFCFFFFFDFF
FFFDFFF9F8F3FFFFF1FBFFE7E3EDC8DBE8BAD1E2ABCDE1A6D6EBB2CAE2A8CFE5A5D5ECA8
C9E098D2E89FD7EDA4CDE29DD8ECADBED2979BAC78D2E2B3E6F6C7F1FFD2ECFCCDD1E6AD
D2F1A5B2D67FD9FDA6C9EC98C1E492C7EA9AD1F1A6C7E59FECFFC6D7E7B6C8D0A9A8A88C
D4CDBBFFFCF3907E7AD9C7C7DCD0D2FFFCFFFFFEFFFAF9F7464741FCFFF1F2FFE1D3E6B9
CFE7ABCCE7A0CCE999C8E895C4E393C5E599D3F1A9E2FEC1EAFFD1E1F3CBE6F8CEE4F7C9
DFF3C2E2F6C1E0F5BCC4DA9CD5EBABCDE4A0C1D892D5ECA6CAE199CFE69ECDE49CCEE698
D1EB92C3E086C8E998CFF7AEB4E2A49ED2A17FB9932E6B4A
A19D7AADA98EFFFEF4FFFDFDFFFDFFF7F5F6EBECE4FEFFF3F6FAEBFEFFF8EEEFF1F5F4FA
FFFFFF9C9C94D5D7C1D5DBB5CFDEA7DAEEAFD0E5A4C1D894D6F0A7C6E295D3F0A0C7E794
CFF19DC9EC98C8EB97CBEE9ECBEDA0CBEDA3CAEBA4C8E8A7D0EEB8B1D192CEF09AD0F293
CCEA90C6DF8E859856B9C78C859058B6BC8CD7D6B7F6F1DDFDF3E7FFFEECFDF5CE808356
AEC8A5002403BFE8BE90BA88C3EFB4B4DF9AC7F0A4D7FAA8C4E48FD1EA96D4EA98CBDE8F
EBFBB2D2E39CD1E5A0CFE1A3D0E2B0DFF0C4F3FFDDE7F5D4DAE7CDD1DBC3EFF8E3FCFFED
F6FFE4FCFFE6FCFFE1D3DEB3CCD8A8B1BE89B2C18ADFEFB1CEE29BE7FCB1DBF0A5C7D98F
C9D990C6D68D4C591199A65EBFCF86E3F5ABCFE499C7DF93D3EEA1CEEA9DCCEB9DC5E695
CBED97CDEF9BCCEAA0C8E5A5CFE7B5E0F4D1F1FFEBF8FFFAFBFFFFFCFFFFFEFEFFFFFEFF
FFFDFFFFFDFFFFFDFFFFFDFFFFFEFFFEFEFFFFFDFFFCFAFFFFFDFFFFFDFFF5F2F9FFFEFF
FFFFFAF9FCEBF6FCE0F1FCD4DDEBB8D1E3A7D3E8A5CEE59FC4D998DCF1B0CEE3A0C9DE9B
E7FBB6E5F8B6CCDEA0D3E5A99FB07A97A778AFBE93DCEBC4F3FFDBF9FFE4E4EFCDCFE0B3
CAE5A0E0FFB0BFE091C9E99DDCFCB1BAD890CEE9A6CBE3A7EFFFCDA9B68B999E7EFFFFEB
FFFEF3FFF3F0E3D0D2C2B2B5FFFBFFFFFAFFF4EDF48886898C8C8AE4EADEF9FFEACCDFB2
C9E1A5C8E49AC9E996CDED98CEEF9ED2F2A7DEFDB9ECFFCDD4EABCD0E2BCD4E6BED3E5BB
C8DBADC9DDAAD3E8B0D4E9AEC5DB9DD6ECACDCF2B1C3DA968198548FA662CCE39FD2ECA3
C1E092DAFCAFC5EDA6A8D6969FD4A0407D53478A6B96DCC2
CFCBB2EBE8D5F9F4F1FFFDFFFFFDFFFFFEFFFEFFFBFAFFF6FCFFF8F6FBF7F3F6FFFEFDFF
FCFBFFEAE9EF64655DD4DAC0CEDEAFCEE2A7CCE1A6CFE7A9D8F3B0C8E69EADCD82DAFCAF
D5F7AAC1E696C4E999C9EEA0C1E699C3E89BCBEFA5C3E6A2C4E5ACD5F8B8CAF198C0E585
BCDE87C6E295D5EEAD8094579AA966BFC98CD2D5A8E7E4C5F2E9D8FFFEEAFCF0C887885C
C6DEBC557858496F4A9EC89AB4E1AAB8E4A5CBF4AEB5DB8ECAE999CCE796D5EC9ACCE290
D6EB9CD2EB9ACAE596CBE59ED3E6AEE5F5C8FBFFE1E6F1D3BCC6AEA6AE99DEE5D3F9FEEA
F7FDE3FEFFE4F7FFDAD2DEB0DFEDBAA0AF78DAECB2D9EEADD1E99FB6CE80CEE597D5EA9F
DCEEA40818007C89438D9A54DBE8A2DAE9A4CCE099D2E7A2D4EBA5C8E39CCCEAA2CCEAA2
CEEAA0CDE8A1CBE5A6CDE4AED5EAC1E6F6DBF2FFEEF7FFF9FBFFFFFCFFFFFEFEFFFFFEFF
FFFDFFFFFEFFFFFEFFFFFEFFFFFEFFE0E0EAFEFEFFFEFEFFF8F7FCF2F2F2FFFFFBFFFFF6
FEFFEEFEFFE6DBE8BDD0E1ADCEE2A3C4DB95D2EDA0D0E89AD8ECA4E2F3ADCFE09CD5E5A6
FBFFCFEEFDC6A2B07F758256D1DDB7CAD5B3F8FFE5FAFFE9FCFFECFBFFEDE3EBD4D7E5C2
C5DAA1CDE6A2D0E9A7C7E09EC2DB9AD5EDB1D3E8B0D6E8B6D4E3B8D2DCBAFFFFEAFFFFEF
F6EDE6FFFBFAFFEFF2FFF9FFFFF4FBFFF8FD878087030004828282FCFFF8F9FFECC9DBB1
CFE7A9CCE89DC9E994C9E994C5E695C2E299C4E2A2CBE6AFD7EDBFD5E7BFDCEEC4F2FFD8
EEFFD1DBEFBAC8DDA5C7DCA1CFE5A7CAE0A0667C3C061C00000E001A3000889E5DD7F1B4
C8E6B4C4E9BDBEEBC284B796518F76014A3721756839938A
C1BEABFFFFF3FFFEFFF6F3FCF4F2FDF6F7FBB0B5AE7D857872786C989F98FCFFFFDDDFEC
EEF0FD76767E0C0E09282D177A865E7787565E703ED5E9B4B3CA92D2EEB1DFFDBDB4D491
C1E29DBADB94CAEEA4D0F4AAC2E49ACBEDA1D4F6ACBEDF9AC9E8ACC7E7A6BDE08CC9ED93
DFFFAFC9E79FCBE5A6D3ECABCFE59ADBEBA2D5DFA3DDE0B3F0ECCFFFFFE4EFE8BE84855B
ACC09DAFCEAC0010004F764977A46D84B073B9E2A0CFF4AED4F2A8C6DE92D3E89BDEF3A4
C0D988C0DB8AD0F29CCDECA0CADDA6E5F2C7FBFFE1DBE5C3C0C9AEB3B8A2A5AA96FEFFEF
FDFFEBFEFFE8F5FFDCD3E0B4DFEDBA96A86CDCF1B0C4DB93D6F1A4D1EC9DC8E092E1F7AC
94A55E84944DDDEAA599A563D4E0A0CAD698CEDEA0D8EAAECCE1A6C4DCA0CEE7ADCDE7AA
CCE4A8CDE2A9CEE2AFD6E8BEE5F4D5F1FEEAF8FFF7FBFFFDFCFFFFFCFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFEFFF2F3F8FEFFFFF9FBFAF2F3EEFFFFF6FFFFF1BCC2A8
7C83628B966C4D5E2A7D9154C3DA968BA75C88A555CAE596CDDF95CEDB96DEEAAACAD59D
ADB687A1AC82CED5B4E3ECCFF3F8E1ECF4DFFEFFF1F9FFEEFEFFF3F9FFF0F5FCECE9F1D9
D6E6B9CDE0A8C8D9A3D5E8B1E4F6C2C9DBA97D8D60B8C49EA5AF8DE7EDD3FFFFEFFFFEF2
FFFDF8FFF5F5FFF8FDF6E7EE82777B7D7479918A91E9E4EAFFFFFFFAFFF8EDF9E1CEE0B6
CCE4A6C9E59AC8E893CDEE97CEEFA0CCEBA5CCEAAED1ECB7CAE0B1D0E3B5DCF0BFF7FFD8
E6FAC5C1D69E9FB479A3B97BC3D999A6BC7C5B71305E7433A5BB7AB1C787B8CE8EBFD89E
CCE9B9B6D9AFCEF7CF9BCAA8366E5135766085CFBE60B1A0
626053BDBDB3FFFEFFFEFDFFF9FAFF8387862D36258F9B839BA58DDCE7D6F2F8F4FBFFFF
FBFFFFF2F6F7E4EADEEEF3DC5E6544D9E3BE3C48229FAE85E1F2C6D8EEBFCAE2B05B7641
6B874D5775394A682835541136540E7C9A52C9E59BD7F2ABD5EFAEC6E09FCDE99FCBE99F
BBD993CDEAA7CAE7A4C6E49CD4EFA0D5EE9DCEE29AD2E2A3E8F2C0FFFFDCF1F4C9A7AE84
819069C7DEB4D2EFC1325724264F1787B07495BB7EB2D595C8E2A1D6EBA8D0E19BD8ECA4
D3EB9FCEEB9BD7FAA6CCECA3D1E3B3E8F2CFF4FED9C1C9A4D1D7B3D4DAB85B5F44F8FCE5
FFFFEFFEFFEFFCFFECD6E2BEC4D4A392A766D1E99BD0EC98C2E28FCDEC9C94AF62465E14
BED28BE1F0AFCFDB9DA7B175E9F2BDD2DCA8D6E2B2D7E4B6CADBAED3E6B9D4EBBFC7DCB1
D4E5BBD4E3BADBE7C3E7F2D4F5FEE9FBFFF4FBFFFAFCFFFFFCFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFDFFFFFDFFFFFDF8F8F6FFFFFBE6E7E1FFFFF4FCFFEEFFFFEA757C5B979F76
C7D3A3C9D7A2D1E5A8D8EEADAEC982C7E79CE3FFB7688439495A13303B0058612899A172
E3E9C7F8FDE6FFFFF3FEFFF6F1F2ECF7FAF3FFFFFAFAFDF4FFFFF6F6F9EEFEFFF6E5EAD6
D7DEBCE1ECC2D6DEB5C4CFA757623A555F3AB5BF9DD2DBBEFEFFECF9FCE9FFFFF3FFFBF2
F8F0EDFFFCFDFFFBFF81767A524849B9B0B1FCF6FAFFFEFFFCFDFFFAFFF9F9FFEDD4E7BA
CDE6A5CAE699C8E992CCED96CDEC9ECAE7A4CBE6B1D0E8B6C3D7A2CFE2ABD6E9B1DCF0B5
A2B6798B9F6091A665BBD08DD9EEABC2D794D7ECA9E7FCB9BFD491B2C786CCE1A0D1E7A6
D1EBA4C9E79FC4E39FD7FAB8B2D89BB7E0A8CCF8C3CCFBC7
7A7B6D686A5FF7F7F7E0E1E38489855A625397A486F9FFDFDCEBC2C7D5B2F9FFEFF6FFF3
F7FFF4FBFFF4EEF7DCF5FCDBDEE3C5DFE2C7C6CAAFDCE5C8EDF8D8D8E7C6D7E8C4576C43
5970425F77456A834A677F436E8746A1B872CDE49CD0E69DC8DC95D8EBA9D2E6A9D0E5AA
C5DDA1CBE8A6C6E49EC7E79BC5E592C8E893CDEA96CEE99AD5ECA8E5F6BFE3F0C4C9D5AD
869264D6E6B5D1E8B49AB882001100567C41A0C389B0CD9398AD74D4E3A8DBE9ABC4D392
D9EFA7CAE99DBADF8FC8E9A4E8F8D1FCFFE6EDF5D0AAB187CAD0A2DDE3B76B6F4CFFFFEA
FFFFF3F8FBF0FCFFF4DAE7CBCCDEAEABC27CCBE88ECFEE90C7E993DFFFB16C883E829953
EBFEBCD5E3A6C5D098A2AA77D5DCB0D4DBB2EFF7D2ECF8D4DDEBCAE7F6D7E5F8DAE0F0D3
E8F2D7E6EFD4EAF2DAF5FDE8FEFFF4FCFFF8FEFFFBFCFEFDFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFDFFFFFBFFFFFBFFFFFAFFFFF8F0F2E5FFFFF1DFE3CCF3F8DA9BA17B6B7445B7C48E
DDECB1D8EBABC8DF9BDAF5AEDBF9B1C7E99FC0E49CA2C0789EAD6A8F975B919465B0B491
FFFFEDFFFFF8FAF8F9FEFDFFFFFDFFFFFEFFFCFCFEFFFFFDFFFFFAF9FAF2FFFFF6EAEDDC
E2E4CCE7EACDC6C9ACABAE91A6AA8FCACEB3DEE2CBD3D6C1FFFFEFFFFFF3F9F6EDFFFFF8
FFFEFBFFFBFCFFFCFF342B2EB5ADAAFCF7F4FFFEFFFBF9FCFBFCFEF2F9F1F5FFE9C7DAAD
D3ECABCDEA9AC8E992C7E891C3E296BFDC9CC2DDAACAE2B2D9EEB5D6EAABCEE3A2CCE19E
8DA25F9DB26DBDD38BE2F8B0D2E8A0C1D78FCBE199D3E9A1C4D994D6EBA8BBD08DD2E9A3
CCE89BD2F1A1B7D686EBFFBCEFFFC3E9FFBFC0DD9ABCDB97
85887346493835362E0D1007939A8AFBFFE8F0FFCFE0F4B7DCF0B1D7EBB0ECFDD0E3F3CE
DDEBCAD3E2BBEAF8C7F5FED1F7F7DB9E9B88F5F4E0EFF1DCFFFFEFF3FBE4EFF9E0E2F1D4
E3F4D0DEF0C6D8EABACFE2ABCDDFA3D2E2A1D6E7A1D7E79EC5D0842A3300687240D9E6BA
CFE1AF8DA5678FAE62C3E591C8EB99C5EB94CCF398CAF194C6EA92C6E69DC6E0B3CFE1BB
E1E9B65A6227D5E7ADCAE2A8C5E4A973945B6A8852CEE6B292A36F919B67E2EBB4CED99F
D4E7A7D2EDA6C1E699E6FFC7F4FFE5F6F9E6CDD3B1A7AD7DD4DCA3E7ECB4D0D3A6EFF2D5
FFFFF6F9FBF8F6FBF7D6E1D0DBEEC0AEC87ECBEC84C2E67CC4E891C4E69AC4E29CCFE8A6
BCD093DBEAB3DAE4B2878E64D0D4B1D8DDBDFEFFE8FCFFECF6FFEAF7FFF2F1FFEEF8FFF4
FBFFF2F9FBEDF8FAEDFDFFF5FFFFF8FEFFFAFDFDFBFEFEFCFFFFFFFFFFFFFEFFFFFEFFFD
FEFFFDFEFFFBFEFFFBFFFFF6F5F8E7FFFFECFFFFE7BABE9D747B51D5DDAAC5D096DCEAAC
CEDF9BD1E79FC3DD94BDDB93C6E59FC6E9A5C5EAA7CBE9A9CED99DD8DCA9DFDFB9D6D6BE
FFFFF6F8F6F9F9F3FFFFFCFFFFFAFFFCF8FFF5F2F9FDFBFCF5F4EFFFFFF6FFFFF4FFFFF3
FFFFEFCAC5B2F0EDDAFFFCE9FFFFEBFFFFEFF5F6E4FFFFF1F8F9EBFFFFF6FFFFF8B9B6B1
878380716B6B736D6FB8B2B2FFFEF8FCF7F1FFFEFDFFFFFFF1F3F2FBFFFAF9FFEDCBDEB1
CCE5A3CAE797CBE993CDEA96CFEBA1D6F0B3E5FCCEF4FFDBE4FABAD1E79FC3D990CBE196
95AB60C3DA8CD9F0A2D3EA9CCDE496E2F9ABD2E89DC9DF94D5EBA2D1E79F667B36C7E09C
C0E19AD1F6B0C8EDA7D2F7B1B6DA94C6E6A3D1F1AECEEEAB
FFFFEA7D806BC2C6B8FCFFF4E6EED7C6D5AECCDEA4D4EAA2D0E89ED7EEA8C3D69ED1E3B3
D9E9BCD6E6B5D6E5AAD0DAA5FFFFE6C3BDADD6D0C2EDEBDCFFFFF3EAEEDDFCFFF1F4FFE8
F8FFE7E3F3CED0DFB4D1E2AEDBE9AED1E09FCFDC97DDE99FC8CF82B0B572262B025F6644
CBDBAC899F61C9E89A88AC55CBF19EBEE690C1ED8CC5F28DC8F191C4EB9CC0E0B1D3E9C3
D9E0AADEE2A5505E20DDF3B5BDD99EC5E4AB001000667C4BD7E5B44B5322D7DEABE1EAB3
C5D799D0EBA6C4E89EDAF9BDFBFFEFDFE1D3989C7B9DA471DEE4A6D2D89AE2E6B44D5130
FFFFF8FEFFFFFBFFFFC8D3C5CADDB088A457CBEC81CFF584CCF099BEE096D9F8B4CDE7A6
D3E7ACD7E5B0E0E9BCAFB68DFFFFE4F5F9DEFEFFECFBFFF0FBFFF4F8FFF6F1FDF3F9FFF8
FEFFF8FFFFF6FDFEF6FFFFF8FFFFFBFDFEF9FDFDFBFFFFFDFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFBFEFFFBFEFFFAFEFFF6FFFFECDEE1C6D1D5B44F542C98A06FD2DBA2E0ECAED3E29D
CFE099D6ECA1DAF4ABCCEAA2CAEBA6C5EAA7BDE1A1D1EFB1D5E0A8DEE0AFFFFFE1F9F6E3
FFFEFBF6F0FAFFFAFFFAF2FFFFFAFFFDF6FFFFFDFFFFFEFFF6F5F1FFFFF6F3F3E7FFFFF3
5C5648CFC7BAFFFFF1FFFDEFFFFFF1FEFBECFFFFF3FBF9ECFFFCF3FFFFF6706D68312E29
8D8988C3BFBEF3EDEFFFFEFBFFFCF6FFFFF6A7A3A2494949FEFFFFFBFFF8E7F3DBD9ECBF
CFE8A6CCE997CBE993C9E692C8E49ACEE8ABE0F7CBF2FFD9E3F9B8D5EBA0CEE597D4EB9B
90A757C7DE8CDEF5A3C5DC8AD4EB9BCCE393C9E092DAF1A3D6ECA3CBE1984E631ECEE9A4
C8EDAAC7F1AFB9E2A0BEE7A5C6EBA8C5EAA7CDEDAAC3E3A0
pop
P
% End of image
1 0 0 r
.03 w
.99835 .01949 Mdot
.96242 .01021 Mdot
.9503 .04095 Mdot
.91235 .04965 Mdot
.85866 .04733 Mdot
.81748 .0914 Mdot
.81304 .11634 Mdot
.82232 .15113 Mdot
.81869 .22246 Mdot
.81223 .24044 Mdot
.72785 .2213 Mdot
.66528 .2155 Mdot
.61199 .19695 Mdot
.57404 .19115 Mdot
.5591 .16273 Mdot
.54255 .18709 Mdot
.5159 .17665 Mdot
.51186 .23058 Mdot
.49006 .24856 Mdot
.47957 .27581 Mdot
.46665 .38136 Mdot
.4614 .44167 Mdot
.4073 .43471 Mdot
.44283 .48284 Mdot
.46988 .52344 Mdot
.46907 .55011 Mdot
.42466 .5304 Mdot
.39438 .52402 Mdot
.35159 .50256 Mdot
.331 .53562 Mdot
.29829 .56519 Mdot
.28457 .60115 Mdot
.24177 .59941 Mdot
.22118 .57505 Mdot
.20019 .58491 Mdot
.18 .56693 Mdot
.13237 .58723 Mdot
.08271 .60173 Mdot
.05041 .59071 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.65873 0.666667 0.97619 0.984127 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
57515365645F343827839271536B3B3E5D22AAD18EC0E9A3C1ECA7BBE5A3BDE7A8B8E1A5
C5EEB2BAE3A7C9F3B4C8EFB0C9E2A8CDE5A7CEE6A8C8E5A2D0EEA8CCECA1C7E99DCAEC9F
BFE292D1F4A4C2E195D2EEA3CAE49DCBE29CCBE09DD2E9A5CBE69FC6E19AD2ECA5CEE39E
D5E9A4D3E29F8F9A58DCE5A4D5DB9BE4EAAABFC887E4EDACDCE7A5C2CE8C929E5CC6DA93
CDE79EC9E99DC8EA9DC6EB9DC5EC9DC6EB9DC9E99DCCE89DD4EAA143540DDEEEA7D3E39C
D0E49CDAF2A8BDDC90CCE89DCEE49CD0E19BDAEBA5D0E19B5B6C267C8D479CAD678E9F59
788943A9BA74CFE09ABBCC8687985273843E99AA64C7DC97CEE7A3CBE9A1CCE997CDEA96
C9E497C9E2A0798D5C000A00667850CCE0AFCCE5A3CCE79ACBE894CDEA98CAE8A0CFEAA5
CCE5A1DCF1ACCDDE98CCDB96798640B7C780C3D48DDCF2A9CBE79CCFEEA2C7E79ECDEBA3
90A6657F9252D5E0A4D5E5A4CEE99CCAEC98C8E799D4F3A5C0DC919CB86DDBF5ACBDD78E
CEEAA0C2E195CDECA0CAED9BC0E391C1E790C4EC94CAF29AD1F7A2C0E693C2E394CFF0A1
D4F0A6BFDB91CEE7A3CEE7A3CDE6A2CCE69FC2DD96CFEEA2CBEA9ED0F3A3BEE18FCDF2A2
C0E69DC9F1A8C4EFA0BAE794C0ED9AC8F3A1C7EC9EC3E39ACEE4A6D5E8B0A2B07B3E4F19
A0B57CC4E1A1D3F4ADDEFFBAE1F3BFF1FED2F1FBD6FCFFE6FEFFEF8084768C8D88FFFFFB
FAFBF6FFFFF6FEFFF1FEFFEDFCFFEDFCFFEFF8FFF3ECF9DFD2E5AEC8E39ED3F1B3CCEBB0
C4DEAEF2FFD8FEFFDCD6E2B2D0E9B0D7E9ADE6DBA3767034DCFAB0C7F2A3CAE8A2CFE9A2
CDEBA1CDE79ED9E8A5D4DEA1919B5F85995ECAECAFBFE9AA
35302A030100010900E3F4D0B7D1A2BDE0A8CDF5B9B7E3A6C7F3B6C5F1B6BBE6AECAF5BD
CDF9BCB8E4A5BEEBA8BCE5A3CCE6A9DAEFB4C8E0A2C0DA9BD5F2B0C5E4A0BFE099D4F8AE
CDEFA5BFE197CBEBA2CCEAA2D2ECA5C7DE9AE4FBB7CDE4A0CAE59EDDF8B1BCD38DD8EDA8
D5E9A4CCDB98606C2A4A55134F5817959E5DEDF8B6D1DD9BC7D39161702D899A56D3E9A1
CDE79EC9E99DC8EA9DC6EB9DC5EC9DC6EB9DC9E99DCCE89DCFE79DDCF0A8405009D7E7A0
CBDF97C7DF95DCFBAFC9E59ACEE49CD5E9A2869A53435710E1F5AED8ECA5BFD38CD8ECA5
C9DD96CFE39CD4E8A1D2E69FCDE19ACBDF98CFE39CD4E9A4CBE4A0C8E69ECCE997CFEC98
D0EB9ED2EBA9899F6E00140065774FCCE2B1D0E9A7D0EB9ECDEA96CDEA98C8E69ECBE6A3
CFE6A2CBE09BD5E6A2DAE9A48C995492A25BE2F3ACC0D68DCEEA9FC4E298C7E79ED5F3AD
BBD19098AB6B9DA86CD0E0A1D4EEA4C2E193BFDE92CBE79DCEEAA0B1CB84BBD58ED9F3AC
D4EEA7CBE79DCFEEA2CFF0A1C8EB97C6EC95C5EC93C3EA91BCE28DC3E696E3FFB5AAC97D
D4F0A6DDF7B0CEE5A1CAE09FD4EAA9CBE29EE1FBB4C1DD93BDDC90D1F2A3BEE191C2E799
CCF0A8B9DF96BDE899CAF5A5BFEA98B8E290C6EB9ED4F2ACCDE3A5C8D9A2899A647A8B55
BED69AD0EDABCAEEA6CBECA7D1E6AECCD9ABFBFFDCFCFFE11A2308FCFFF1FEFFF8F8FBF4
FEFFF8FEFFF3FCFFECFBFFE7FCFFE8FBFFECF4FDECE6F3D9D1E4ADC2DB99C9E7A9C9E8AF
C9E3B3F1FFD7FEFFDCC8D4A6C2DBA2D3E5A9F7ECB6C7C185C2E098C6F0A4C4E29CD6F0A9
C8E69CB8D289E0ECAA90995A9CA66ADCF0B3628447507A3A
6F6B527C7C6067714E000C005B7B4C5A815285B0826C9A6C79A67DB3E0B7BFEABDBAE6B3
B7E4A9BCEEA9CFFFB6B5E398C7E1A2C7DAA2D1E6ADE2FAC0A2BE8494B378CAECAFC0E4A6
C6E8ABCBEEAEC6E9A7C4E4A1D7F4B1C5E09BCCE5A1BFD992CFE9A2BCD38DE1F8B2C5DA95
CFE39EC6D7934C5B18E1EDABD7E3A1ADB9778B9A578E9F5BC1D28EC7DB96CBE09BD0E79F
CCE89ECAE99DC9E99DC6EB9DC5EC9DC5EC9DC8EA9DCAE99DCBE399D7EBA3C1D18A8FA059
CCE098D7EFA5C2DE93CEEA9F8DA45C8BA159C5DB93D7EDA5C6DC94C8DE96E2F8B0C3D991
D8EEA6D2E8A0CDE39BD0E69ED7EDA5DAF0A8D5EBA3CEE59FD0E9A5CEE9A2CDEA98C9E692
C6E295C3DE9B7F9765000C0061764DCCE4B2D1ECA9D0EC9FCCE995CCE997C9E49DC9E4A1
D1E8A4C6DA95D8E9A59BAA65D9E6A1899651ABBC75D5EBA2D4F0A6C8E69CCBEBA2CAE8A2
D2EBA9C0D4957D8B50D7E7A9CAE39FCCE7A0DBF6AFD2EBA7C2DB9997AD6D6F8545CFE5A4
C9DF9EC6E099C5E197C6E597C8EA96CAEE97CBEF95C7EB93D2F5A1C1E494D0EFA3D1EDA3
D7EEAACBE09FC8DA9CD1E3A5C8DA9CCCDEA0D6EBAACFE6A2D1EDA3C3E296DBFEAEB9DB8E
C9EAA3BDE199CCF2A7D7FFB1C8F2A0C6ED9ECDEFA5C6E19ECBE1A36D7E4704150093A66F
D3EDB0D0F1ACBAE397C6EAA2D7EFB3B8C993C9DAA496A473B8C49CEBF6D8F3FCE9FBFFF6
F6FFEEF0FAE2E7F3CFE4F1C6EBF7CFF3FFDEF5FFE9F1FEE0E7FAC3CBE4A2CEECAEDEFDC4
E7FFCFF8FFDDFFFFDDD3DCAFD5ECB4CCDBA0E0D59FABA569CAE8A0D4FDB1CBE9A3C1DB94
D1EDA3D6F0A7CCD896A4AD6EAAB477CBDFA082A563A3CD8B
C9C2A6757455DEE9C1B2C89A91B3815B86517DAD79598B5A59885A2C592E517C4F6F9969
B4E1A8C3F4B3B6EBA3C3F1A9D5EFB2C3D49DD3E6AF4C632F9DB885A8C6944A6A3983A573
B3D8A4CDF2BC6E91576E9053A9C988CBEAA6B4D28AE9FFBDC9E09ADAEFAABFD48FD5E9A4
CADE997D8E4ADDEEAAC8D995CEDF9BD4E8A3C0D590E3FAB4C1D892DCF6AFC5E099D0ECA2
CCE89ECAE99DC9E99DC6EB9DC5EC9DC5EC9DC6EB9DC9E99DD1E99FD3E79FD0E19ABDCE87
9BAF67334B014E6A1F5E7A2FD2ECA3CFE9A0B3CD84D6F0A7BAD48BDCF6ADC7E198CEE89F
C8E299CBE59CCDE79ECCE69DC9E39AC9E39ACAE49BCDE7A0CBE4A0CAE59ECDEA98CCE995
D2EEA1D2EDAA9EB6840016005F764CCCE4B2CFEAA7CCE89BC9E692CEEB99CDE8A1CEE7A5
CADF9CDCEFAD576623C0CC8AD3DE9AD8E5A0C3D48D50661DC3DF95C9E79DD0F0A7BCDA94
CEE7A5E0F4B5909E63CFDEA3D3E9ABCAE2A4C7DFA3CADFA4D4E9B0CFE2AB94A770D2E5AD
D7EBB0E0F6B6D3ECA8CEEAA0CCEB9BC8EA94CBED96C5E991BFE08FD5F5A9BFDB91C6E099
D1E6A5C7D99BBDCC9194A16938450D425116BDCF91D5EAA9C8E29BC9E59BBFDF93DCFCB1
D3F1ABCBEAA4C2E299BDDF93C0E295C5E599C9E49DCDE3A2D6E8AE73814C0E1C00DBECB5
D0EAABBEDF98B5DE90CEF4A790A9689EB27597AC6BE1F5B6D1E4ADCDDEB4F8FFECF8FFEF
F5FFEAE5F4D3D1E3B3CADDA6D4E7B0E7F8CBF6FFE6F8FFE6F4FFCFC9E2A0C8E6AAE9FFCF
F4FFDCF4FFD9F3FAD1DEE7BAD2E9B3CFDEA5E6DBA5574E15D6F1AAB2DB8FCFEDA7CEE8A1
C9E59BCFE79D8F9A56DEE7A6D8E2A3BFD493CFF2AECEF9B2
DCCCBF9A9380D6DBBBD9EFC0C1E5A7C9F7AFABDF94B3E79C9BCD864D7A3986AF752F5722
6B9661A6D59F8BBE86AAD59DD3EAB4697742899A6694A779DFF8CEB8D4ACB3D3AC779974
B7DCB3D0F5C9668C5B668C5397BB7BB5D9938EB066B8D68CD1E8A2D0E49FDCF0ABC7DB96
CADE9990A45FC4D893D3E7A2D5EAA5CDE49ED1EBA4C7E29BC0DE96C2E299D1F1A8CBEBA0
CCE89ECCE89DC9E99DC6EB9DC5EC9DC5EC9DC6EB9DC9E99DD5EDA3C1D58DCEDF98E9FAB3
A8BC74899F5686A056ADC97ED2EEA3C5E196D2EEA3D7F3A8D3EFA4CAE69BCFEBA0C6E297
D0ECA1CCE89DCAE69BCBE79CCFEBA0D0ECA1CDE99ECAE69CCCE5A1CBE59ECEEB99CAE793
D1EDA0CFEAA7A9C18F00120062794FCDE5B3CEE9A6C9E598C9E692D2EF9DD3EDA6D0E9A7
D1E6A3D1E4A26C7B38E9F5B3CAD591D6E39EBECF89869C5485A1579BB96FC6E69DCCEBA5
D0E9A7D9EDAE97A56A9AA76FC8DAA6D3E7B4C9DDACCCDDB0CEDFB3ECFBD0E3F2C7F0FFD3
B3C392D3E6AFCCE1A6CBE4A2CFEBA1C8E799CFEF9CCAEC98C4E395D3F1A7C6E099CEE5A1
D6E8AAE3F2B9A6B07B9EA87396A06B88925D8A9960CEE0A2D5ECA8D5EFA8D6F4AAB8D48A
BED591D6EDA9D0E7A1CDE79EDFF9AFD1E8A0C3D895DFEFB1C4CE997E86532E3603D6E3AD
ACC284CCEAA4C6EC9FAACF817B9651B4CB87DAF2A8C7DF95C9DF9ED2E6B1D4E8C3F5FFEA
F5FFE8E9FED3D4E9AEC9E09CCDE3A2DAEFB7E7F9D3EFFFDBF8FFD3CAE3A1C8E6AAF1FFD6
F4FFDCE4F5CBE7EEC5EFF8CBE0F7C1D1E0A7E7DAA560571EDFFAB3B3DC90D0EBA6D4EBA7
CAE49AC6DE949BA661DCE3A0D9E4A2D9EEABC9EDA5B3DE96
EBD8C7968A72DADEB9D0E2AED4F7B3B6E595C2F6A3CAFEACBBE99ED2FBB5BDE3A6CDF3BA
B2D9A415400B44753E305823000D00020F00000D004D60331C3410304B2C3C5A3E74967B
93B899B5DDBABBE2B6C3EBB7BFE5A8C0E5A0C7EDA0CFEFA39FB66E2F430053672295A964
9DB16CC6DA95DDF2ADD2E9A3CEE59FC4DF98D4F2AAC4E49BD1F3A9C5E99FD0F6ABC0E296
CCE89ECCE89DC9E99DC6EB9DC5EC9DC5EC9DC6EB9DC9E99DC8E298E3F7AFDDEEA7C9DA93
D4E59ED1E79ED1EBA1CAE69BC8E79BC6E69AC5E498B1D185D7F6AAC1E195C6E599CCECA0
CAE99DC8E89CC7E69AC7E79BC9E89CC8E89CC8E79BC6E49AD1ECA7CFE9A2CEEB99C3E08C
C6E295BED996A0B886000C0061784ECDE5B3CEE9A6CBE79ACCE995D3F09ECCE69FC2D897
DBF0AD7C8C4BD0DF9CD2DE9CD9E4A0DFECA7DAEBA5CBE199DBF7ADB2D287C7E6A0C9E8A2
C1DA99CFE3A4E2F0B5F4FFCCB4C599E5F7D1F4FFDFEEFEDAD0DEBDDDEBCAFBFFE6F5FFDD
96A27CC8D8ABC4D6A2C9DEA3D3ECAACAE69CD3EFA2CAE99BD4F3A7D0EBA4CBE29EE6FBBA
D3E2A9808D57FFFFD4D7DFACE6ECBCC3CB98C1CE989FAE7370844594AD697F9A5399B36C
90A05FD7E6A5DEEFABC1D28CCEDF98D8E9A3CFDB9BD4DCA1F5F7C57274432628009BA46F
849658CAE5A0D7F9ACBBE092CFEDA3C3DD93CAE692D3F09CC7E197DDF7B8B6CD9FD9F2CB
EBFFDADEF6C2D2EDA8CDE99CCEE89ECFE8A7D4EABCD8EDC2F5FFCED1E7A6CEEAAFECFFD1
EEFFD7D9EAC0E1E8BFF4FDD2F0FFD1D7E6ADE8DBA6BFB67DDDF8B1D6FFB3CAE5A2CBE29E
CFE99FD2E89DAEB974CFD692D4DF9BCDE29DBBDF95CCF8AB
BAA47DA6996DD2D5A0D6E8AAC6E7A0BDE99EBEEEA4B5E49EBDE5A6BADDA3D6F7C2C2E3AC
C7EAB0C8F0B1BBEAA4C7F0ACD9EDB2D6E0AC222F01E4F6CECBE3C34A644B001A051E412D
000E00264E3382AA85CCF6C6C5EEB2C8F1ABCDF6A8BCDE91CDE49CD5E6A2DAEBA7D6E7A3
CDE19CE2F6B1D1E6A1CAE19BC9E49DD0EEA6C9E9A0C7EBA1B9DF94C1EA9EBFE99DC8EEA1
CCE89ECDE79DC9E99DC6EB9DC5EC9DC5EC9DC6EB9DC9E99DC5DF95D0E69DC5D68FD4E59E
D9EAA3D7EDA4B7CF85D9F5AAC1E195D6F8ABD5F5A9D5F7AAC9E99DC9EB9EC2E296CFF1A4
C9E99DCDEFA2D1F1A5CEF0A3C9E99DC5E79ACAEA9ECFEFA4CAE5A0CAE49DCFEA99C8E490
D4F0A3D0EBA8BED9A6001400577046C6E1AECDE8A5CDE99CCFEB97CDE897B5CF889DB372
4A5D1BD9E9A8E3F2B1D1DD9BD4DF9BDCE9A4D0E19BC9DF97C7E3998CAC61C7E6A0D3F2AC
D4EEADCAE0A0DEEDB2EFFDCAD1DFBCE5F3D9F0FDE3F6FFEAFBFFEDFBFFEDFCFFEDF6FFE7
C8D3B3F8FFE2DFEFC2D6E8B4DBF1B3C9E2A0CEEAA0C2DE93C8E49ABFDA93DEF4B3DBEDAF
4B5822F7FFCDFBFFD1FFFFD6F0F3C6E8EEBED4DEAAD3E0A8CFE1A5D1E7A6D0EAA3C9DE99
566021989E60CED796DCE7A3DBE6A2CFD897A1A5686869305C5828080400413F0FDBDDAB
CFDDA0D5ECA8C6E69AC9EC9CC2E195CFEC9CC7E58BCFF193D2EF9BC7E59DD5F0BDD0EBBE
CDE7B8C9E5ABC8E799CBEC95CDEA98CAE59ECBE3B1D1E7B8D6EAAFCBE1A0C7E3A8CEEBB3
CEE5B7CBDCB2D4DBB2DBE4B9D1E8B2ECFBC2FFFFCCD7CE95C6E19AC5EEA2C6E19ED9F0AC
C9E3999AB16388944CDAE19DEDF7B2CCE099C6EB9EBCE899
FFF8CBEFE7B6B1B47D97A568CBE6A3CBECA7C0E5A2CDF0B0C7E6ABD1ECB5B6D19AD1EDB3
C2E1A5C2E7A2C0EBA3C1E9A2CEE3A8CEDCAB98A47C818F6E98A792889989D5EADB8EA595
667F6A6B8A6B2A4D254D7541527E41A5D291B4E39DCFFAB5D1F0B4C6DFA5C9E3A6C2DF9D
D9F4B1C0DB96C9E59BD2EEA3CAE69BD0ECA1CCE89EC9E79DCDEFA5CAEEA6C2E89FC7E99F
CDE79DCFE79BCCE89BCAE99DC9E99DC9E99ECAE8A0CCE7A0D4EBA5CFE39EDDECA9C6D592
D3E49ED7EBA4D5EBA3C8E49ACDEFA2C0E597C0E597C5E79AC2E498CFEFA3D1EFA5BDDC90
D0EFA3CBEA9EC6E69AC7E79BCCECA0CCEF9FC8EB9BC3E598C9E8A2C8E69ECDED9AC5E28E
D1EDA0CCE6A5C0D8A8000C0050653EC2D8A9CBE4A3D0E89CD0E996C7E08FA1B8727C934F
AABF7CD9EDA8C2D38FDFF0AAD1E09BCEDE97D6EAA2CEE49BCDE79E8AA55ECDEBA5C2DC9B
D2EAACD4E7AFE9F7C2FBFFDAECFCD5EAFAD6ECFBDAE0EDCFF4FEE5E0E8D1EDF5E0FEFFEF
D2DAC2FCFFE8D4E0BAC5D5A6D1E4ACC8E19FD7F3A9CFE99FCDE29DDFEFB0D0DFA495A26D
D6DFB2FFFFDFFEFFDFFFFFE3FFFFE1D8DDB5D7DEB2C8D4A2DEF0B6CEE4A3C1DC97D8EFA9
D3DD9E858B4B88914EBEC984B5C07B9AA360989E5E8F9356C6C690383804898B59DDE4AE
D2E0A5D1E7A7C6E19CCFEFA6C9E99ECBEC9DC7EA90C2E589CBED96BEDF90CAE8AAC1DEA6
C9E6AEC7E5A5C9E89ACCEC97CAEA97C5E498C9E2A8D2E9B1CADF9ED5ECA8CFEDADC2E1A5
C3DEA7D2E6B3DAE3B4CFDBA9CCE4AAFAFFCEFFFFCC7F743CCCE7A0C4EAA1D0E9A5CCE09B
D6ECA3657A2F9CA860DDE7A2C5D28CCCE299D8FDB0C1EC9D
FFFFDFFFFFDDF7FFD3F9FFD376854EC5D79DDEF0B2D1E3A5DBEBADD5E7A9C4D899D0E9A8
CBE8A8BCDC99C6EBA8CCEFAFC8E3ACCBDEB1D8E5C7FCFFF1F5F6EEDDD9D6CAC5BF636051
DCDFC2C9D4ACC9E0ACD4F6BA89B57A62955C19521F447C4D87B78DBAE7BCB1DFAEBFEFB5
BEECABC5F0A8C7EE9FC3E591D6F29ECDE492D0E296D9EAA3D7EBA6CBE09FADC5878DA362
8DA25794A7585E7024D5EA9FD0E19BDEEEADC4D496D9E9ABD9E7ACC4CF95DCE7ADD6E4A7
D6E4A6DDEDAEC6D997D4EEA7C6EB9EC3EC9EC5EB9EC6EB9EC9E9A0CCE89ECFE6A0CFE69E
CFE69ECFE69ECDE79DCCE89DCAE99BC9EA99C8EB99C6EB9BBFE59ACFF5A8C7ED98CAED99
BFDE92D4ECAED4E7BA000900707E5BCCDBB0CEE0A4D0E49CD9EE9F889F4FDCF2AACAE19D
CDE7A0CDE79ECDE79DCDE89BCFE79BD0E799D0E69BD0E69BCEE49BD2E7A24F6324ACC085
CDDEAAD8E5B7DFEAC0FBFFDAABC087C3DB9FD2E7AED9EBB9D3E0B5D7E1BEFAFEE5FDFFEB
EBEEDBF7FCE6FCFFE8FBFFDFBED19ACFE8A4CFEC9CCCE393CBD28FC8C791545627E6E8C3
F4F8DFFFFFF1FFFFF6FCFEF3FFFFF3FFFFECFFFFE3D3DCB1C6D7A0C7DD9DD5F0A9CCE89E
CEE29BDAEBA4D0E2988C9E548FA15595A75BCEE096D9EAA3D6E7A1627231D6E6A8C8DAA0
E8FBC3F1FFD0D5ECB6C1DDA2C9E9A6C8EDA0C8EE9BC9EF98CAEE97C9EC98C9EA9BC8E89D
CAE8A2CAE8A2CCE89ECCE89DCCE89BCCE89BCAE89ECCE89ECFE69ECDE79EC8EAA0C6EAA2
C9E8A4CDE6A4D4E2A4D3E3A4C6E19ED1E1A0E3D69F554B10DBF2AEC1E29BD2E7A4D2DE9C
D8E8A16A7A33B5C57EDFF0AAC1D78FC1DD93D9FBAFBFE598
FBFFE3F1FDD7EBF8CDFAFFD8A9B381A2AD75ABB579CBD596C3CF8DD4E3A0E1F1B0C3D895
DFF8B6D4F1AFEDFFCDC7E5A9E7FFCEDCF3C7DCEBCEFCFFF3FFFDFAF0E6E5FAEDE7C6B9A8
BAB492D8DBACE2F1B6C0DD9DBDE6AAA4D9A357926629633D13452291C19BA7DCAEBCF3BC
B7EFB0AFE49EBBEB9FCCF5A6B6D585D7EEA0E4F4ABDCE9A4D8E4A6DBE6AC95A26C6D7D3F
96A65F8D9E5069792EB4C47DC4D390D4E3A2C0CE91B4C287D0DFA4F7FFCBC1D397CFE1A3
CDE2A1C2D995DBF2AECAE8A0C5EB9EC2ED9EC3EC9EC6EB9EC9E9A0CCE89ECFE6A0CFE69E
D0E69ECFE69ECDE79DCCE89DCAE99BC9EA99C6EC99C5EC9BC1EB9FC2ED9EC7EF99C8EB97
C8E79BD0E8AAB2C399000B00576041D7E2BADFEDB2DEEFA8BED38492A959D1E79FCEE8A1
CCE7A0CAE99DCAE99DCAE99BCCE999CDE897CDE899CFE79BD8EEA5CBDF9A7A8A4C99A871
D3DFAFE8F3C9E3EBC6F7FFD69DB470CFEBA0D2E9A3C6DA9DCBD9A6C3CBA4FFFFE8FFFFEF
DCDCD0FFFFF4FBFFECFBFFE8D8E8BBDFF5B7C6E298D6EAA2EFEEB6786C4297916FF9F5DC
FFFFF4FFFFFDFAFBFDFEFEFFFFFEFAF3F3E7FDFFE7DFE7C2D9E7B6DEF3B8CFE9A8C4E29C
D2E9A3B7CD85E5FBB2CCE299C8DE93D9EFA4DBF3A5CFE79BA4BC726C833DD3E9A8CFE7A9
E6FDC5F5FFD8BBD1A2CEE6B2C5E8A8C4EAA1C4EA9DC4EB98C5EB94C8EC94CAEC96CAEC98
CAE99DCAE89ECCE7A2CCE7A0CCE89ECAE99BCAEA97CAEA97CDE89BCAE99DC6EB9DC5EC9D
C8EA9ECAE89ED1E59ED1E59ED2F0A8DCF0ABEBDFA552480DCEE5A1C4E59EE0F3B1D6E2A0
B2BD79B7C47EC9D893C8DC95D8F2A9CBE99FCCEEA2BFE497
F9FFDFEFFED3D7E7BACCDAA7D7E6AFC9D79CAEBC7EA3B26F97A86498A963D5E9A4C7DC99
C8DD9CF3FFC9DFF7BBF4FFD3F0FFD4F2FFDDEEFFDDFBFFEFFFFFF6FFFBF2FFFEF1FFFAE2
FFFFDCCFD6A294A668A5C280D9FFC2C2F1BBADE1B3AEDEB67BA276365B2F0E3A0972A56D
9AD497A9E4A4BFF8B4B5E8A5C7F0AED2F2B1F7FFCFFBFFCFD7E2AADAE1ABBEC58FAFB97D
D3E4A0D1E59DCCE299B7CD859AAF6A859C567D944E68813DBED994BBD993C8E89FD5F5AC
C7E99DD2F7A9C1E698C0E798C3EC9DC3EC9DC5EC9DC6EB9DC8EA9EC9E99DCAE89ECAE99D
CCE89DCAE99DCAE99DC9E99DC8EB9BC6EB9BC6EB9BC5EC9DC9F2A6BAE395C9EF9AC8EA96
CFEBA0CEE4A695A67C000B0070795ADEE9C1BDCC91B2C37C90A556AEC575CFE69ED2EDA6
CAE8A0C9E99DC9E99DCAE99BCAE999CCE999CDE899CFE79BCAE097D0E49FD0E0A29CAB74
C9D5A5DAE5BAE0E8C1FBFFD87A9149CAE797CFE69ED4E8A9DFEDBCE2EAC5ECF0D9FFFFF4
D3D0CBFFFFFBF9FAF4FAFFF1F7FFE6F1FFD8C7DBA8E5F3C0E5E0B8D0C3A3FFFDE6FFFFEF
F4F3EEF5F5F7FFFEFFF9F8FD8C8A8B818179848573747B5C76825AB6CA99C9E2ABC5DEA4
CDE1A4E2F4B6C9DE9DCEE3A2E5FAB7C7DC97C6DC9481974F5D722DC7DE9AD0E6A6D1E6AB
CBE0A8DBEFBCF7FFDAF4FFD8CAEAABC7EBA5C5EA9DC4E999C6E995C7EB94CAEC96CBED99
C9E99DC9E99ECAE8A2CAE8A0CAE89EC9E99DC9EA99CAE999CAE99BC9E99DC5EC9DC2ED9D
C5EB9EC9E99ED0E69ECFE69ECCEEA4C3DA94DAD1965D571BD5F0ABC4EAA1D6EDA9C2D18E
75823DD5E29CD8E8A1CADE96E1FBB1C4E397C7E99DC9EEA1
D3E3B4EFFFD0E5F7C3BCCF97CFE3A6D9EEADD0E5A0BDD38BC6DC94AEC47C8FA35EB3C684
CEE1A1D3E5A7E4F3BAE1F5BAD5EEB4F2FFD8F5FFE3F5FFE6F9FFEEFFFFF1FFFFECEAEBCB
ECF2C4D0DBA18699579EB9769DC080B5DCA3CBF6C8C6EDC0C9E5B49CB78260854F34632C
1F591E7CB97EB5F4BBB1ECB4B8EAB5C0E8B4D5F1C0E5F7C5EBF5C3E1E5B3D1D3A1A3A872
D5E3A8CDDFA1DCF1B0C7DD9CCAE19DD4EEA7D0ECA2B4D387799A4BCFF2A2C8EE9BAED882
C6F09AC4F099C8F69EC1ED98C3ED9BC5EC9BC5EC9DC6EB9BC6EB9DC8EB9BC8EA9DC8EA9D
C8EA9DC6EB9DC6EB9DC6EB9DC6EB9BC6EB9BC5EC9BC5EC9DCCF2A7BDE396C8EB97CAEC98
CCE69CD1E7A9A7B68D000700667151C4D0A8A1B07599AD6592A959CEE796CDE79ECCEAA2
C8EAA0C8EA9EC8EA9DC9EA9BC9EA9BCAE999CCE999CDE89BD6EEA4CFE49FDAECAE9AA970
DBE7B5EFFBCDE6EEC5E8F6C38CA458CEEB97C7DF95C9DD9ED0DEADEEF5D4FFFFEFFEFEF6
DDD9DAFFFDFFFBF9FEFCFEFBFCFFF6F9FFEFD6E5C8F3FADBE7E0C6D2C3B0F7EEDFFFFEF6
FFFFFDF8F7FCFFFEFFDAD7DE1F1A1E76726F2D2B1F0003002A33144A5A356A7F54D2E8B9
D9EBB9C0D19BD4E7AFCCE0A5D1E5A8CCE0A1D0E5A4364B0A394E0DDBEFB0CBDFA4D9EEB5
CADCA8C1D5A4F8FFDCE7FDCCCDEBAFCCECA9CBEDA3CAED9DC9EC98C9EB95C9EB95C8EA96
C9E99DC9E99EC9E8A2C9E9A0C9E9A0C9E99DC9EA99C9EA99CAE99BC8EA9DC2ED9DC1EE9D
C3EC9EC8EA9ECFE69ECDE79EC1E59BD0EAA3F3EDB1656124B9D791B7DF96E2FBB7D9EAA6
98A560CCD993D5E59ED7EBA3D0EAA0BDDC90CFF1A5CAEFA2
D0E3ACCFE2AACEE3A8D0E8AAC8E19FCCE7A0D1EDA3D7F3A8E8FFB9B6D087D0E5A090A361
D1DFA1BDC88CDBE4ADCDDAA2D2EAACF2FFD4F4FFDCF3FFDFF9FFEAFBFFEAF5FFDDDAE5BB
CAD7A1E6F6B7D9EFA7D2ECA585A46193B277D3F3C1B8D4A3C4D69CC7D99BCFEDB1C3EFB2
9FD69D54955D094D1A70B284AAE3B8D0FED7BFE2BAB8CEA7FCFFDDFFFFDAFFFCCF939264
C4CBA1CAD5AAD3E1B0CBDCA6C6DA9DDAF1ADCDE99EC0DF8F89AB55799D43CFF699D5FFA0
C3EF8EAEDC7AC9F697C0EB8FC6EC97C8EB99C8EB9BC6EC99C6EB9BC5EC99C5EC9BC3ED9B
C3ED9BC3ED9BC3ED9BC3ED9BC5EC9DC5EC9DC6EB9DC6EB9EC7EBA1C8EA9EC6E894D0F09D
CAE298D9EDB0D0DFB6000700253010A5B189BFD195C7DD94C3DE8DD6F3A1C2E096C6E69D
C6EAA0C6EB9EC6EB9DC8EB9BC8EB9BC9EA9BCCE89BCDE89BD2EAA0D1E6A1CDE0A0A9B87F
E9F6C1F8FFD4EBF6CBD2E1AA8DA655C7E58DDAF2A6E3F7B8EBF8CAF4FBDCFFFFF3A6A5A3
F5F0F7FFFCFFFEFAFFFFFDFFFEFFFFFCFFFFF1F8F1FBFCF4FFF9F1C7B6AFFFFCF8FAF5F2
F5F3F6FFFEFFFDFCFF89868D736E74FFFDFFF4EFEBFFFFF4FEFFEFBCC9AF809171647853
26370D37471ADAEABB6777466576406A7B4443551B5B6D33CFE1A7D4E5AED4E5AFCADCAA
D2E2B5D3E4B8F8FFDEF7FFDDCBE4ADCAE7A7CBEAA4CCECA0CBEC9BCAEC98C8EA96C7E897
C9E99DC9E99EC9E8A2C8EAA0C8EAA0C8EA9DC8EB9BC8EB99C9EA9BC6EB9DC1EE9DBFEE9D
C2ED9EC6EB9ECDE79ECDE79EC3E99ECEE9A2DEDA9D575518C9E8A2D5FDB4B2CB874C5D19
D6E39ED5E59ED2E39CCFE59CC6E096CDECA0CEEEA2C4E699
DCF0B3C4DA9ABDD694DBF6B1C6E69DCDEFA3C7E99CC5E79AB8D88CD1F0A4D6EDA5CCDF9D
D8E4A68E9359E4E4AED9E1A8C3D999C5E2A2C4DFA8C8DFB1D1E6BDCFE1BBC7DAADC7DBA8
D9EFB1BCD38DCFE79DCBE59B99B26E6D8748CEE7B0D2E5AEE3EFAFD1E09DC7E29FB9E1A2
BFF5B9A5E4AD3377464D906487C1999AC9A5CCEFCEDBF3D1D3DEBCD1D5B2FFFFDDA4A57D
AAAF87DCE4BBE2EEC0DFEDB8C7D99DD0E5A0CDE599D9F4A3CCEA9446670EBADB82C7EA90
C1E58ED4F7A3C1E492CBEC9BCAE999CAE999CAE999C9EA99C6EC99C5EC99C3ED99C2EE99
C2ED9BC2ED9BC2ED9BC3ED9BC5EC9DC6EB9DC8EA9DC8EA9EC5E59CCEEEA3C5E592D5F09F
CCE49AD4E6AAD5E1B9000700313C1CB6C59CD9EDB0DAF2A8D6F3A1CDED9AC0E095CAECA2
C6EAA0C5EB9EC6EB9DC6EB9DC8EB9BC9EA9BCAE99BCCE89DC5DF96D7EEA8D1E6A5B8CA8E
EAF9C2F3FFCDF0FCCECCDBA2CBE493D4F099C8E094CFE3A4DEEBBFFEFFE8ACAEA1DBD9DA
FFFCFFFFFBFFFFFCFFFFFCFFF9F7FFFEFEFFFCFFFFFFFEFFFFF5F8BEAEAFA59B9CFFFDFF
FFFEFFF7F6FBF6F5FAFEFCFF666167FFFDFFFFFDFDFEFBF6F6F8EBFBFFF1F8FFEFC5D5B8
CDDDB894A37847572A2030012636051B2C00E0F1BBCADBA5DBECB8C9D9A8D5E5B8CDDCB1
DDECC5C9D7B4EDF8D8E9F7D3C9DDACC8E2A5CAE5A2CCE89ECBEA9CCBEB98CAEC98C9EA99
C9E99DC8EA9EC8EAA0C8E9A2C8EAA0C8EA9DC8EB9BC8EB9BC9E99DC8EA9DC2ED9DC1EE9D
C3EC9EC8EA9ECFE69ECDE79EC6EAA0CCE7A0DCD69A635F22C3E19BC9F1A8DEF7B3D8E9A5
8F9E59D3E39CDBECA5CAE097CDE79DD7F6AAC0E094C9EB9E
C3DA96D6EDA7DCF7B0D8F8ADBADF91BEE594C1EB99C7F19FCEF5A4C2E296C8E299E3F3B2
D5DFA2CDCE959D9A659B9E65D8EDAAC8E5A2C9E5A8CBE8B0CEE9B6CEE9B6CDE8B3D5F1B6
D1EFA9C3DF94D2ED9EC9E195C9DF97A9BC7CE2F4BAD8E6ABD1DC98D5E59ED9F4ADC7EFA9
A8DB99C4FEC1AFEEB797D2A243784C305D367C9E7DC0D8B8B1C0A3D3DCBFFFFFE6FFFFE1
9AA273E0E9B4D2DBA2CFDB9DD6E5A0D9E9A0D0E394C6DB8CC7DC8DE2F7AC9AAE67768947
B9CB91D5E6B0C4D1A3DFEDB8D1E5A0D0E799CDE899CCE999C9EB97C6EC97C3ED97C2EE97
C2EE99C2EE99C3ED9BC5EC9BC8EA9DC9E99ECAE89ECCE7A0C7E59FD1EDA3C8E392D2EB9A
D2E89FB6C88C96A27A0006005B6646D9E8BFCFE5A7C7E197C6E693CBED99C5EA9DCBEFA5
C5EBA0C5EB9EC5EC9DC6EB9DC8EA9DC9E99DCAE99DCCE89DD7F1A8D0E7A1C6DB989FB173
EAF9C0FBFFD4E7F3C19EAD72D0E998CCE893C5DC94D9EBB1F5FFD9F5FBE17C7E73FFFFFD
FFFDFFFFFCFFFFFCFFFFFDFFFEFBFFFDFCFFFFFEFFFFFDFFFFF9FFFFFAFF8F8586DAD6D5
FAFAF8FEFFFDFEFEFCF4F3F1373334E5DFE1FFFCFDFBF6F3FFFFFAF8FEF2F3FEEDF8FFEC
F8FFE0D7E7BACCDCAFC7D7A8E5F5C4C5D5A4D1E2AED6E6B5E1EEC0FBFFDDE6F2CECDD8B8
D9E3C8C9D3BBFCFFF1FBFFEAD4E5B9D1E6AECFE5A7CCE5A1CBE79ACAE999CBED99CCED9C
C8EB9BC8EA9EC8EAA0C6EAA2C8EAA0C8EA9EC8EA9DC9EA9BCAE99DC9E99DC5EC9DC3EC9D
C6EB9ECAE89ED1E59ED0E69ECDEDA4D0E7A1E0D69B7C7338D6EFABB9DD95BFD491D8E7A4
4E5D18CEDD98D5E6A0D1E79FD4EBA3CEEAA0C3E296CEEEA2
CFE79DCFE99FC5E196BFE292CFF6A5C8F49FBFEC97C3F09BBFE997CAEC9FD6F0A7CDDE9A
D7E0A1E0E1A79D9861595A20D0E49FC9E79FD1F0ACC6E4A6BFDEA2CAECAFC8EBABC2E29F
C2E498D0F1A2CCE999D1E99BC6DA92A9B875B2BE80CDD99BD7E6A1DAF0A7B5D389CAF2A9
C3F2AABAEDA8BEF2B2BBECB4C3EDBB7FA377082400000A0044543998A88E5A6851A4B298
909C76FBFFDCFBFFD8DDEEB7DEF0B2C8DC97D5E9A1D4E99ED6EAA2CDDE98CDDB9DDCE7AD
A8B07FA3A87F8C906BD6DCB0D6E2A2D3E59BD1E69BCFE799CCE999C9EB97C6EC97C5ED97
C5EC99C5EC99C6EB9BC9E99DCAE89ECDE7A0CFE6A0CFE6A2CEE7A3D0EAA1CBE493CCE393
D6EAA299A86D505B33000600444F2FDAE9C0CAE0A2CEEA9FC7E794D3F6A2C7EC9FC4EAA1
C5EBA0C6EB9EC6EB9EC6EB9DC8EA9DC9E99DCAE99DCCE89DC6E097C7E19ADDF2AF8B9F60
C8DA9ED8E7B0C9D7A286985ACFE799CEE796CFE4A1C6D7A1EDF9D39BA38BFFFFF4FCFBF6
FBFAF8FFFFFDFFFDFEFAF8F9FFFEFFFDFDFDF8F8F8FFFEFFFFFBFFFDF1F3FFFEFAB9B9B1
FDFFF3F5F9EBFEFFF4E6E8DDF3F0EB6B6663A79E9FFFFDFDFFFFFAF1F4E9FBFFF3F0FFE2
F7FFDED4E6B4D8E8B7D1E2AEC9DAA6D9EAB6D4E4B3ECFCCDECF9CEFBFFE3F7FFE4DBE5CD
F1F8E8E9EFE3EDF2EBFBFFF3E4F2CEDFF1BDD7EBB0D0E6A5CBE59BC8E797CAEC98CCEF9D
C8EB9BC8EA9EC6EAA0C6EAA2C8EAA0C8EAA0C8EA9DCAE99DCDE79DCDE79DC8EA9DC6EB9D
C9E99ECDE79ED4E39ED3E49E8AA55ECFE09CF1E2A973672DD0E5A2D0EFA9D3E3A2D5DFA0
859451E1F2ACC0D48FD5EBA3D0E79FC4E096D5F3A9C3E397
CDE89BCCE89BCAE99BC8EB99C5EC99C2EE99C1EE99C1EE99BEE896CAEFA1CFEBA1CCE09B
D3DD9ED0D197A7A26B6E6F35C7DB94CEEDA1C6E69DCEEFAACCEFABBADF9AC1E6A0CAF0A5
C4E99BCCEF9FC2E191CAE294D9EEA3C2CF89ABB674BECA88D1E79FD3F1A7BFE195C3EA9B
CCF7A7BCE798BFE89CCEF2ACBEDA9DDFF6C037491F13240200110098B09AC7DFCFDBF6E7
F0FFFAE7FEECF1FFF1D4EFCECDEABED1EDBAC9E7ABC3E09ECAE39FD5ECA6D3E7A2D9E8A7
D3DDA1919862777948BEC38DD2DC9DD1DE99DDEDA6D1E69BD7EFA3C4DF90CCEC99CDEF9B
D2F3A2C0DF8FD4F0A3CFE99FD4EBA3CADF9ADEF1AFCFE2A0D2E9A5C2DC93D3EC9BADC474
8EA25A92A166838E660006000D1800D6E7BDD1E7A9C4E095CFF19DC3E994C9EFA2C4EAA1
C5E99FD1F3A7C0E296CFEFA4C6E69BC4E298D6F4AAC7E399CBE59CD3EDA6D4E9A68A9F5E
CFE1A3DDEFB3B9CB9198AA6CCAE298CEE69CC9DDA0DEEEBFDDE8C68D957EFEFFF3EFF1E4
FFFFF3FDFFEFFFFFEFFFFFEFFFFFEFFCFFEEF8FAECFDFDF1FFF9F3FFFEF6FFFFF2B6B9A4
FCFFEAF8FFE7FCFFECF7FCE8EFEFE37C77716C6462FFFCF9FFFFF8FBFFF1FBFFEFF8FFE6
F8FFD8C5DA9FD4E8ADDDF0B8C8DBA3CEE1AADDEEBAF9FFDAF9FFE1F9FFE6FBFFEDF9FFF1
F8FDF6F9FDFCFBFFFFFCFFFBF9FFE6F9FFDAC6D9A1CEE4A4CDE79EC4E393CAEC98C6E997
CCEF9FC1E699D0F2A8C8E9A2CCEBA5CBEBA2CEEEA3C1DD92BFD38BEDFFB9C1DD92C5E498
CCE69DD9EDA699A25F96A15D51662185914FAD9A6265521ACDDC9BD1EAA6D0DA9BE2EBAC
8F9B5BD6E7A3D6E9A7CADF9ACFE6A0C9E49DCDEBA3C8E69C
CDE899CCE999CAE999C8EB99C5ED97C2EE97C1EE99C1EE99C3ED9BC6EB9DC8E49ACFE49F
E2EEAEDEE4A8A8A76E64682BD6EAA2D8F4A9C6E49AC7E99DCCF0A6C3E99EC6EC9FC4EA9D
C1E698CFF2A2CAE999CFEA9BDDF2A7C4D48BA9B46FAEBD78ABC67FCBEDA3C6EB9EC5EC9B
CDF39EC7EB94CAE793CDE597D8E9A3CEDC9FD3E1B0AABA959BAF94607B6A57776C6C8F89
89ABAAD8FCFAE6FFFFD2F9E6B1DABCB9E4B9AED9A4D6FEC2C3E8A5C6E7A2C8E69ECAE49D
D5E8A6DBEAA9D2DEA0D0DA9D9DA96B98A76697A663A0B16BCADE96D9EFA4D2EA9CC0DB8C
C1D98BDCF4A6D2E89FCAE097B1C5808D9E5A808E50B7C788A5BC7887A1588EA756B5CC7C
D0E49CCAD99EA8B38B0912003C4727CCDDB3CEE4A6D0ECA1D4F6A2C4EA95C1E79AC4EAA1
D6F8AEB5D38BDBF9AFCDEBA1C2DE94D1EDA3B7D389DCF6ADC9E39ACEE59DD8EFA9A2B774
D7ECABDDF2B1CDDFA1CDE2A197AD65C8DD9AD8E9B3CEDDB2F2FDDFD0DAC2D4DCC7FEFFED
ECF2D6E9F0CFE6EEC9E3EBC4E1E9C2E5EDC8F1FBD9FEFFEAFFFFEDFEFDE9DBDFC4B7C19E
E0EFC6DDECC3E6F2CEF8FFE4FFFFF1FEFBF2040000EFEAE6FFFFF6E3E5D7EBF5DCE4F4CD
E8FDC5D3ECABBBD493D5EBADC9DFA1D0E4A9E8FAC6D2E2B3F2FFDAF5FFE2FAFFECFBFFF4
FCFFFDFCFFFFFCFFFFFCFFFFF6FFE5F9FFDDCADCA8D4EAACD2ECA5C9E89ACAEB9AC4E795
C6EB9BC2E79ACFF1A7BFDE98B7D690DBF9B3C6E49CD9F0A8E7F8B1C4D58EC7E197DAF6AB
CEE59D56672169702DDAE19EC7DB96D8E1A0EBD49E6A551E96A262859A57959E5F9B9F62
B6C284E2F5B5DDF2B1CFE4A1CDE4A0C7E09CCFEAA5C7E59D
CCE999CCE999CAE999C8EB99C5EC99C3ED99C3ED9BC3ED9BCBF2A3CBEDA0C6E49ACAE199
D6E7A3CEDA9A9CA566616C2AC4DA91D4F0A3C8E79BC6E69ACBEDA0C6ED9EC9F0A1C2E99A
C5EA9AD1F4A4C8E99AC6E295D5EBA0CEE398C3D38AC8DC958AA963C5E9A1CFF4A7C4E999
C9EB95CDEB93D3EB95CEE08ED4DE95F0F9BAFEFFD3ADB9938B9F86C8E3D46B8C851A4241
315E637BACB08EC2BEC3F9ECB2ECD4D2FFE8B2ECBCAAE4AAB9F0AFC0F3AEB9E99FC4EEA2
CEF3A6CEEEA3C8E69CD8F2ABCADE9FA7B97D6E80427083439DB16CC5D992CEE398E0F5A8
D3E599DCEEA2C8D992D8E9A296A7639DAC6994A264B4C485D4EBA7D3EDA4C1DA89CFE696
DEF2AAD6E5AA9DA880000600606B4BD7E6BDD3E9ABCBE79CC7E995C5EB96C7EDA0CAEEA6
BBD68FE7FEB8C9E09AB6CD87DCF3ADE1F8B2C8DF97CAE199D1E8A0CFE69ED2E9A39CB36D
BDD490D1E8A4D0E5A2DCF1AE9BAE6CD7E9ABD1DFAEBFCBA5EAF4D9EFF9E199A38BC1CAAD
D3DEB6D8E4B4DAE7AFD7E5AAD4E3A8D5E4ADD7E5B2D7E2B7FEFFE2E0E6C49BA67BA3B382
CCDFA8E5F9C4CADBAED6E1BFF6F9E4F0EEE2746F6B73706BB2B2A6E9EEDACFDABCCEDFB3
CAE2A6CCE7A4E0FBB8BDD694D4EDACD2E8AAC6DBA3DCEEBCE9FACEEFFFDBF7FFEAF9FFF3
FBFFFBFBFFFFF9FEFFF8FEFAF7FFE8F9FFDFCBDDABD2EAAECDE8A3C9E99DCAED9BC4EA97
D7FCACB9DE91C6E7A0D6F5B1CAE7A4CBE6A1CFE9A2CBE199D0E099D4E49DD0E89E859F55
849A526E7D38B3B876DDE4A1D7E8A4D7DD9DF7E0AA6F58229BA5668CA15EAFB5779CA065
DCE7ABEBFDC1E5F9BADAEEAFCEE4A4C8E19FD1ECA9CAE5A0
CCE999CAE999CAE999C9EA99C8EB9BC6EB9BC5EC9BC6EB9DBFE496C8EA9ECCEAA0CCE89E
D2E9A3D6EAA5CBDC98B5C9849AB268C5E093CFEB9ECCEB9DC8E99AC3E696CAEF9FC6EB9B
C4E999D0F2A5C6E69ABEDD91CCE69CD6EEA2D6ECA1DAF2A885A35DC5E69FD1F3A7C4E596
C5E592CCE894D6EC99D5E396D6DD99BCC286E6ECBEE0E7C5CFDEC7F1FFFADBF9F1DBFFF9
8DBCB21C5244114A37407C634584652C6D4581C09189CA949DDDA1B2EEB0B9F1B0C2F7B3
C2F0AFBBE5A3BCE5A3BBDFA1C6E5AAD3EFB5C9E2A8D5EDAFB6CC8B889C5760712B7C8C43
D4E49BDFEFA6CFDF98D3E29D8FA05CC4D493CFE2A2D1E6A5C3DC98D8F4AAD2ED9CC7E08F
CAE097CFE1A578845C040D00354020E4F3CADBF1B3C1DD92C0E28EC7EA96D0F5A8C4E39D
CFE6A0C5D994D9EDA8D1E5A0CADE99CDE19CAAC0784C621AD5EBA3D3EAA2C7DE98859C56
95AC66CDE49CCFE69EC7DE989AAD6DE3F2B9E5F2C6FBFFE4FBFFECFBFFEDC0CAAF8E9C78
93A372798B4D63773072873C98AE65A5BA757A8E514556206D7949B4C090CBDDA3DFF5B5
C9E2A0CFE7A9CADEA9F3FFDBFEFFEDFFFFF6F7F3F0FEFBF6070900C7CCB6DEE9C7C7DAAC
CAE4A7BFDE9BC8E5A3CBE8A6C1DB9ADCF6B7BFD79DCFE3AEDBEFBEE5F6CCF0FFDEF9FFED
F9FFF4FBFFF8FAFFFAF8FFF5FBFFECF8FFE2CDDEB1CEE6ACC2DD9AC5E599CAED9BC8EE9B
B7DC8CD0F2A6CDECA6BFDC99D2EDAAC8E19FB2C98591A560909F5A86975098B268CFEBA0
DEF5ADD6E7A1D3DA97DFE8A5D1E5A0CFD897F2DBA5756029D1DD9DCBE29EE5EEAFC6CC90
E2EFB7E4F6BCE8FCC1E6FABDD5EBADCFE5A5D2EBAACCE6A5
CAE99BCAE99BCAE99BCAE99BC9E99DC9E99DC9E99DC9E99EC2E297CAEAA1CCECA3C9E79F
C8E69CD1EDA3D9F5ABDCF8AE93AD64C4DE94D1EC9FCEEA9DC8E797C6E595CEEF9EC9EA9B
C2E296CEEEA3CCECA3C6E69DCBE99FCFEEA2CAE699C2DE918DA45EC6DD97CEE9A2C9E59B
C9E89CC7E398CFE69ED1E4A2E4EFB5D6DEADDBDFBADFE3C8C3CCB7F7FFF6EEFFF7D7F2DF
B4DDB3DAFFD6B0E2ADABE2AB002100205B25427E4A4685504886530017000021003A7147
79AB8585B38FD4FFDDBEE8C0C3EDBBC4EDB5B3D69CC4E3A8C4DE9FCAE09FC7D894E6F5B0
4D5A144C59131E2E003C4D078FA35EE0F7B3CFE8A6C2DD9AD3F1ABC2E096CEE998CFE897
D5EBA2C2D498192500000700000700DDECC3D8ECAFCAE49AD2F29FC2E490CBF0A3C2E09A
DCEDA9D9E5A3D3DF9DE4F0AECFDE9B4655129BAC688A9E59D0E49FD1E6A1CAE19996AD65
8CA65DCFE99FD2ECA2CBE29A9AAD6DD6E3ADE8F3C9FBFFE6E8F2DAEFFBE3F9FFEAEDFDD6
C4D9A0CFE6A0D1EC9BCBE793C7E291CBE59BCCE5A3CAE0A2D7E9AFDCEEB2C6DD99C0DC92
C2E096CBE9A3C7E0A7D9EBC3FAFFEEFEFFFAFFFEFFF1F0EE7173686B735CD2E0BCD4E8B7
CCE9B15F7E42001300D3F1B3C6E2A5C9E5A8CCE6A9C9E2A8CBE2ACD6EAB9E4F7CAF1FFDC
F8FFE8F9FFECF9FFEFF9FFEFF6FFE7F2FFDED6E9BCD5EEB5C0DD9AC6E69BC8EB9BC7ED9A
C0E595D6F8ACC6E59FD3EEABC7E09EE1F6B5647735C5D692D4E8A1D4ECA2BFDE92CFEFA3
B9D58BDEF4ACD7E29ECBD893D4EBA5D9E5A3E3D0985E4D15D7E7A6D0EBA6E1EDADD4DEA2
D5E4ADD4E7B0E7FAC3EDFFC8DFF4BBD6EBB0CEE6AACCE4A6
CAE99DCAE99DCAE99DCAE99DCCE89DCCE89ECCE89ECCE7A0D3EEA7CEECA4C7E79EC2E49A
C1E397BFE497BDE295BDDF93B0CC82D0EAA1CDE79DCAE596CFEA99CEEB99D2EF9FC5E496
CCEAA0CEEEA5CCEBA5C6E59FC4E69CCAEC9FC9EC9CC3E2948FA059C7D48FD0E49FD0E9A5
D0EDAAC5E2A2C9E5AAD0E7B3C5D6AAE6F0CBF2F6DBFFFFECC7CCB8E8EFDFF9FFF4F8FFEF
F2FFDDF1FFD8EAFFD6DEFFCFC2EAB8B1DFAEBBEDBCB3E7B7B4E9BBC1F9CC3B734690C59B
31633D3B6B450230096C9B71ADE1B0BEF1B9C7F4BDCDF4BBCBEAAEDAF2B4D6E9A7CCDB98
DCE9A4DAE7A1D0E099CADE97C9E09AC5E09BC2E39ECEEFAAC7E8A1BCDC91D3F09ECDE897
DBF3A9DAEEB1121E000E1900232E0ED9E8BFCBDFA2CFE99FDCF9A7C0E08DCAECA0DBF6B1
D6E2A0D4DA9ACED796D0D998384301DAE6A4CFDE9B94A561D0E19DCEE29DDAF0A8C2DA90
96B066C7E396CAE699D5EFA5859554ABB882EEF9CFFBFFE6FBFFEDF9FFEDE4F3D4E3F5CB
D4ECB0CDE99EC6E48EC4E58CCDED98D5F4A6D2F0AACBE5A4CAE09FC5DC96C8E396D6F5A5
DDFEADCAEAA1CEEAB0EAFFD8F9FFF3F0F5F1FFFEFFFEFEFFFAFDF4272F183A4922CDE3B4
BFDBA8587944001000618047D5F4B9CDEBAFC6E4A6D1EDB0C9E2A8D0E8AEDAEEB9E1F5C4
E5F6CAE5F6CCE5F3CFE5F3D0E6F3D5E7F6D5E4F6CCE8FFCACAE7A5CBEDA1C4E999C2E895
D3F8AAD0F2A6C2E19BCFEAA7CCE2A1849757D6E5A4D8E9A5D2E8A0C8E499C8EA9DCCF1A3
C7E79CCCE69DD8E9A3DAEBA5BFDA93D3E7A2DCD09661551BD0E5A2C2E19BCADD9BD8E6A9
CADBA5CDDFABE1F3BFE6F9C2E6FBC3E1F6BDCBE3A9CCE4A8
C9E99ECAE89ECAE89ECCE89ECDE79ECDE7A0CFE6A0CFE6A0CFE9A2CAE59EC5E59CC7EBA1
CBF1A4CAF3A5C5F2A1C5EEA0B8D68ED2ECA5CDE59BCDE597D2EB9ACEE998D1EC9DCAE598
D4F0A6CBE9A3C7E6A2C4E5A0C0E49AC7EDA0CDF7A5D1F0A0949E55D2D590D9E4A2D2E6A7
CFEBB0C8E9B4D3F4C7DCFAD4DDF4D7DEEED4FCFFF1F1F4E3FFFFF1FAF7E6FFFFEFCFC9B9
CEC7B7E2DCCCFDFBECF2F7E3E8F6DFE7FBE0DBF8D9D3F5D0BAE1B5B8E4B1BBEBB1C7F8B7
A6D893C0F0A6D2FFB361954B09440A35713D91C891BFEEB7C0E3A9BEDA9DD7ECABD7E6A3
DDEAA5C8D58FD6E7A1E4FAB2C4DF98C0E19ACBF3ACC4ECA5C1E59DD4F4A9D6F6A3C1DE8C
C7DF95D0E4A71925003A452595A080D7E6BDCADEA1CDE59BD1EC9BCAEA97BDDD92CCE5A1
DAE5A3999B5C828747A0A565DDE3A5E3ECADD0DC9A43520FD3E4A0CFE39EDBF1A9CCE49A
8FA95FC6E295C7E396CEE89EC7D796B0BB83DEE9BEE9F4D2FAFFECF8FFEDC0D1B1D2E8BA
C8E2A3C8E799CDEE97CEF197C9EB95C2E296C2E29FC8E6A6D3EDA6CFEA9DCCE997D0F29C
C1E490B7D98DC7E3A9ECFFDBF2FDEFFCFFFFFEFDFFF7F6FCFEFFFAE0E9D4E8F8D15B7343
C2DFB3D7F8CBC1E2B30F2F008BAC75C8E7ACCEECAEBEDB9BCDE7A8CFE9A8D1E9ABD0E8AC
D0E5ACCDE2AACEE1AACEDFB2D3E2C1D9EAC8E6FBD0EDFFD1CAE9A6CCEEA2C3E898C2E996
C1E698BBDD91D0EEA8AFC886405415E8F8B9D3DF9FCFE09CCBE59CC6E89BC9F2A3BBE696
C9EFA2C4E499CFE59DC4DB93C9EBA1DAF1ABF3EAAF8D874BD8F3AEC6ECA3CBE29ED3E5A7
CEE1AACDE1AED5E9B6D3E7B2EAFEC9F0FFCDD2E7AFD7ECB3
CAE99DCAE99DCCE89DCCE89DCDE79ECDE7A0CDE7A0CDE7A0CAE59EC8E69EC9E9A0C9EB9F
C3E89BBDE495BDE697C5EB9EA6C17ACAE19BCFE69ED3EB9FCFEA9BC5E091CDE899CFEB9E
CAE69CC2E098C9E7A1D0EFA9CBEBA2C8EA9EC7E99CC5DF959BA25FDBDCA0E0E8AFCFDDAA
CBE1B3D1EBC6E9FFE6F0FFF3F2FFF6F0FEF1FBFFF6FEFFF4F5F6E8FFFFEFFFFDEAFFFFEF
F9EFE5C5B8B2DDD4CDF8F4EBEEEEE2FCFFF3F8FFEFDFF2D6C7DFBBDBF8CAAFD099CCF0B0
CCF2A9B9E293BFE995C7F6A88AC68A3777434A845287BB8ABCE8B7C3E8B5D7F4BEC1D99F
CCE0A1DDF0AEC8DD98C8DF99CDE8A1D8F9B2C1E6A0C4E9A3C9E9A0CFEBA1BDD88BD3EBA1
E1F4B2CFDCA6252D0669704FDEE5C3D2DDB2D9E8AFD1E5A0C8E094DDF8ABA3C1798FA962
909D58929C5798A25DC9D490DBE6A2CDD997E2EFAA727F3AD4E19CD2E29BCFE499B6CC81
7D984BD4F3A5D3F4A5C4E397D3E6A49FAD72C2D09FEDFACFDFEAC8EDFBD8C7D6AFD5E7B5
D5EBABC9E399C5E18DCBE894CCEB9BC7E79CC9E8A5D1EEACCAE49DD5EDA3C8E394CCEB9B
C0E190D5F5ACCFE8AECFE4B9E7F5DCFBFFF6F9FEF8FCFFFAFAFFF3F9FFECE7F9D1A0B288
D4E5C3D9E9CCE6FAD75F78503652226B8852C6E4A8D6F4B4CAE7A5CCE7A4CDE6A4CEE4A3
CDE1A2CEE2A3D2E4A8D5E6AFCBDBAED0E1B5E6F8C8ECFFCBC5DF9EC9E7A1C7E59BCAEA9F
C5E59ADCFAB0A5C0798BA25E99AE6DC3D696D0E09FD7EBA6C9E39ACCEEA1C3EE9EC0ED9C
C5EEA0C9EB9FCFE69ED6EDA5C8EDA0C3DD94E1DB9F928C50C7E59DC5EBA0D2E9A3CEE1A1
D5E8B0D0E4B1CBDFACC3D7A4ECFECEF8FFDADBECBFE3F4C7
D4ED9CD1EC9BC5E091CBE898CAE99BC4E397CDEDA2C8E89DC8EA9EC4E69ACBEBA0D3F3A8
C7E59BCAE69BD6F2A7C6E09689A05CD8EFABD1E8A2C9E39ACEEA9FC2E195D0F0A4C6E69A
C7E79BD1F1A5C4E096CBE59CD0E5A0CBDF9AAFC07C505E20DAE3AED9E0B4DAE2B9E9F3D1
E3EDD4E9F5E1F9FFF8F3FDF5F7FFFBF8FFFCFBFFFBFBFFFAFBFFF4F7FFF1F5FFEBF7FFEB
F5FDE5FEFFECF3F8E1D5DAC4D8DBC88E917EFEFFEFF4F9E5F5FDE5DFEACCE7F5D2DBECC2
E6FAC9CDE6AFC9E2A8C2E6A9BCEFB7B7F3C09AD5A95F9973386D4F4D7E618BB796C1E5BF
CDEDBCB4D096CEE7A6CEE8A1D2ECA5D4EFA8C2DF9CCFEDA7D4EBA3D2E69ED0E19DDBE6AA
DAE2AFCDD0A55A5A3609060071714BDDE0B3D8E1AACFDB9DCDDD9C9AAF6AA4BD7BD0EAA3
CAE594D1EA96CBE491CDE695D5EDA1D6ECA1C5D78D94A159E1EBA2DAE599C4D08499AC5D
C8E094C3E397D2F8ABC0E69BD5F3ADAAC07F73874ACADCA2D8E7B0D7E4AECED9A1E1EAB1
D0DC9EE7F3B1CBDA95D6E7A1D7EDA5CCE39DD8F1AFCBE4A2CBE09FDDF0AECBDF9ACBE09B
DAF1ABC6DD99D2E8A8CDE2A9D9EBB9F4FFD9F6FFDFF7FFE3EBFCD8F5FFE3F0FFDD7F8D6A
756E5ECBBDB2FFFAE7D7DBC02D3D18001600314E148DAB6DD5F2B0C6E19ED1E8A4C2D796
D4E6A8D7E7A9D1E0A5DAEAACD0DF9ED4E3A2D0DEA0B2C083A4B37889985D95A4698FA163
85985692A762A8BE76BFD58CCDE49CD2E9A3CEE7A3CAE49DCDE79EC9E99DC3EC9DC2ED9D
C5EC9DCAE99DD0E69DD0E69DC7E99CCAE298E7DDA0625A1CCEE59DCAECA0D2E69FCEDD9A
D0E4A7C9E1A7CBDFAAD6E8B8E7F6CDF6FFDEFBFFE8FBFFE9
BBD282DBF4A3C9E193D7F3A6CBEA9CCFF1A4C4E699C9EEA0CAEFA2C3E598C7E79CCDECA0
C2DC92C4DA91D4E8A0D0E49C889D58CEE59FC9E39CCAE69CD0EFA3C2E497CBF0A0C1E696
C5E898C1E293D0EAA0DEF4ACCCDD99E4F0B0ACB4789BA46BC9D2A5DDE8C0EEF8D5F0F9DA
FEFFECEAEFDBFEFFF3FEFFF6FCFFF8F9FFF6F8FFF3F5FFF1F5FFEFF5FFEFF4FFEDF4FFEA
EEFFDDF7FFE3F8FFE4E5F0D0D5DBC1939780E7E9D4FFFFEDFBFAE6FBFDE7FFFFE8FDFFE3
FAFFDEDAEBBECFE3B2C4E0ADBEE8B6B9EDBDB3EAC0A0D8B17BB493568D6E47785A497552
53784FA0C08FD6F1BAC9E3A6C5DF9EC6E19EC4E39FD4F2ACCBE399C9DD95E0EEB0CDD7A2
D7DDAFA9AB8445431D1B17005C5B2F87895770783F7E8A4CA0AE70A7BA7AC8DE9ED5F0AB
D2F1A3CCED9CCEEF9EC4E395C8E499CDE49CB1C27CBAC782DAE19EC9CE8CBAC080B8C482
D1E6A3CCEBA7C9F1ABBCE59FC0E19ABCDA94B9D28EB9D08CC6D695DAE9A8D6E0A1CFD899
DBE4A5CCD596DDE7A8D4E3A2C3D392DEF3B0B7CE8ACEE5A1D6E9A9CADA9BD3E3A4A6B977
97AA68869957CBE09FD6EBAAB9CF8FF3FFCDDAF1B9E5FCC6EFFFD6E0F7C9E0F7CBA8B693
2E2514837268FFFFEDD3D5BD84926F0920001E3A0984A36A7D9B5FCEE8A9D5EBABDFEFB0
DAE6A8C4CC90DDE3A7D1DA99DCE89ED5E398C0CB87A0AA6DA6AF78969F6A9BA46F99A46C
A7B577BACB87CEE29AD5EBA0CDE79DC8E49ACDEBA3D6F4ACCCE89ECAE99DC5EC9DC3EC9D
C6EB9DCAE99DD1E59DD0E69DD0F0A4CDE39AE2D89A594F11C6DC93C6E69AD6E7A0D6E5A0
D2E9A5CCE6A5C9E2A8CCE3ADD9EABEE9F7D4FAFFE9FCFFED
D9EFA7D0E79FBDD48CCAE69CB9D78DCFF1A4D6F8ABBADF8FC3E89AC5E898CDEDA1CFEBA0
D1EBA1E1F7AEDFF3ABC9DD959DB368CDE597C5E091C9E898D0F29EC2E591C9EF9CC5EB98
D2F5A5C4E498CEEAA0CFE6A0BCCF8FB6C487A0A970C6D199ECF8C8DFECBEE7F4C8FBFFDD
E5F0C8939D78A5AC8ADCE3C2EAF4D2EAF5D3EAF5D5E5F4D3E2F3D1DDF1CED9EFCBD7EDC6
E7FCD1D8EBBEECFDD3DBEAC3D6E0BEB9BFA3C0C4ABD9DDC4FDFFE7FFFFE6FEFFE4E5EFCA
E4F3C8DDEFBFE2F6C3DDF8C5D9FACDDAFFD4C3EFBEB0E1AACBFEC5D5FFD076A672002500
001F00001D00011B00BAD5A8B3D19D87A96C7DA55F72984DC4E397ADC47CA1B47486955C
A3AD7B949B6F3033083C3F1092966399A166889253A2B16EC5D692D3E8A5E1F7B6C4DC9E
C6E0A3C9E5A8CDE9ACE2FFBFD8F2B3DDF3B594A36AD1D9A6D6D9AAB8B98FBCBE96E1EABF
E7F8CBE1FCC9CFF2BAC2E9AAD2F6B0C8E89FC6E19A657F386E823D92A35FA5B16F9BA664
A1AC6A8D9856DAE6A4C6D793E2F6B1C9E09AD7F1AAD3ECA8D2E7A4B9CC8A91A462839855
879C5999AE698499568A9F5ED6ECACC8DEA0D1E6ADBED59DCDE3B2D3E9BABCD2A4D5E7BD
CCD7B5485333EFFDDCD2E3C1819773455F383F5B33244115ADC99995AD7B83965F97A268
969A5DE9E8A8CDC584F1ECA8939D54A2B26BADB979ADB87CDAE4AFD5DFABCDD7A2CFDAA2
CFDD9FD1E29ED2E89FD3EB9FD0ECA1CCEAA0CAEAA1CAEAA1CCE89EC9E99DC5EC9DC3EC9D
C5EC9DC9E99DD0E69DD0E69DCBEB9FCEE49BEBE1A3686021D3EBA1CDEDA1D4E8A0D2E39C
CBE99FC9EBA1C9E8A5C7E3A6CBE2ACD7EABDEAFAD5F8FFE4
CFE3A6D4EAAADCF2B1D8F3AECDEBA3BDDF93D1F4A4C5EB98C4EA97CEF19FD3F2A2C4E093
CDE59BDCF2AAB3C47E788C44C1D88AD4EF9EC8E490C8E893CCEE98C1E58EC9EF9ACCF29F
C4E797C7E79BCBE69FC7E09CDCF0B19AA96EC6D199DFECB6D9EAB480915B25360044531C
586730CEDBA5E0EDB797A46ECEDBA5D1DFAAD1E2AECFE1AFCDE1B0CEE4B5CEE5B7CEE6B6
CFE7B3C6DDA7D4E8B5CBDCAFD5E1B9DBE5C0B2B9979BA281FBFFDFFEFFE3EDF8D0D0DDB2
DAECBCECFFCBF5FFD4F4FFD6EFFFDAF0FFDDE4FFCDC2EBA7ADDB92B3E399BAE7A2B8E1A5
4C70405B7953223D1C637E5B92B386BEE5AEB3E09DC7F2AAC0E49AD1EFA7CBE6A3D0E5AA
C4D7A0CAD8A536400C5E6730CDD79BDCE8A8CCD994CDDE98D4E8A3D1E8A4D6EFAECAE1A9
C2D8AAD1E8BCC6DEACF4FFD6EBFFC9DFF2BA869260D5DCB2D8D9B9B0AF93D2D0BBFBFFE6
F9FFE8EFFFE0DDFDCCC2E8ADC0E49EC5E79DE4FFBABED992D4EBA5CCE09BBCCD899BAA67
3B47056776334F5E1B4D611C4A611B001000C7E29BC0DB947D944E5A6F2AC3D893CDE29D
DEF3AECCE19CD1E6A190A562D0E6A5CBE1A1D4E9AED7ECB3C8DCA7C3D7A4E4F7C9C7DAAC
CBDFAE91A476C5D7ADF7FFE3ABBC9A34492A9BB2956883621D3B15CDEABECDE8B5354A11
657131525510605C135C5A108D9750AEBD78CDDB9DD4E1A9FEFFD4F7FFCFD7E4AFDAE7AF
D8E8A9CFE49FCAE298C8E497CBEA9ECBEDA0C7E99DC2E498CAE89EC9E99DC5EC9DC3EC9D
C5EC9DC9E99DD0E69DCFE79DC7E99CCBE399EEE6A771692AD9F3A9CFF1A4D2E89FCDE39A
C3E696C2EC9AC8EDA0C8E9A4C6E4A4C8E4AAD1E9B7D9EFC0
DBEDBBE6FAC5C6DBA3C9E3A6D2EFACC1E397BBDE8ECFF5A0C7EB94C6EA93CFEF9CC4E191
CDE59BD0E69EA1B26E7F904AD5EC9ED6F29ECCE894CBEB96CBED97C3E790C7ED98CCF29F
C4E999CDEFA2CFEDA5C3DE9BD0E6A87F935892A16A94A36CA3B77C83975A879B5CDFF2B0
CCDD99DFF0AAB9CA83718339D5E79DDAEBA4D6EAA3CCE19EC6DC9CC9E1A5D0E9AFD1EDB2
BFDC9CD0EAABD1E9ADD2E7AECFE0ACD7E4B6C9D4A9B6C196BCC49BF0FBD0E4F1C3D4E4B3
D9EDB8E1F9BFE5FFC2DEF6BCE2F5BEDCEFB7D4EDA9CFEFA3CDF59FCAF49EC9F2A3C9F1AA
7C9D669CBB8FD7F3CD3959340F340997C392BAECB1AEE19FBCE7A0CAEFA9C7EAA8D3F1B3
D0E9AFD4E9B0253700283800A0B16DD4E59ED8E9A2D0E49CD6EBA8C7DD9DC6DEA2DAF0BF
E1F5D2E7FADAD6EBC0EAFFCBDFF7B9A4B87B8F9C67D7DCB4DBD9C0B2AFA0EEEAE1FCFCF0
FBFFEFEFFFE1E6FFD2BEE2A4C3E8A2C3E99CBDDF93CAE89ED8F4AAD1E8A0DBF1A9CEE29B
E2F3ADC1D58ECBDF98D6EDA5C1DB92C8E69CD3F1A7D7F5ABC6E097D0E79FDBF2AAD8EFA7
C2D991D2E9A1BDD48CD9F0AA92A764586D2CADC184C0D499D6E9B1DCEFB8C2D4A2E2F3BF
D4E5AE5C69336D7448F1F5D0DEE1C4A7AF98D5E2CEC2DAC44364479CC59DBFEBB8C7F1B2
B8D992D2EB9ADFEE99C7D482CDDD94D8E8A7E1F0B5D2E1AAFCFFD6F4FFD1CBD9A4CCDEA4
C9DE9DD0E7A1D4EFA2CEED9DC4E797BEE596C4EA9DCCF2A5C9E99EC8EA9DC3EC9DC2ED9D
C5EC9DC9E99DD0E69DCFE79DCCEEA1CAE298E6DE9F615C1CCAE69BC1E899CFE79DD3EB9F
C1E993BFED93C3ED99C5EC9DC5E99FC5E6A1C5E3A5C5E1A6
F8FFE1EDFFD5C3D9A8E2FBC2BAD795CEEEA5CAED9BBFE58ECDF199BDDF88CFEC98D3EE9F
DBF1A8D1E5A0B8C786D1E1A0D0E69DCCE79ACEE99CCFEEA0CCED9EC8EB9BC8EB9BC5EA9A
C4E99BC1E399D1F0AAD3F0ADCBE3A5CFE4A9B1C48CCBDFA4C5DB9BDCF3AFD3E8A3BFD58D
D3E79FD6E89ED6E89CB5C879AEC172C4D98CD6ED9FD6EEA2CFE69EC9E39CC6E19CC0DE98
CDEBA3D4F2AAC5E09BD1EAA8D0E4A7CBDCA5E0EEB9E3F0BB707C4ACDDBA8D4E5AFD4E7AF
CBE3A7C6E0A1C7E4A2C9E2A1D9E9AADDECA9CFE59CBBD685BADC86CBEF98CEF4A1C5EA9D
CDECA99EBB8382A06EC9EABDB2D7AB669163184A195C8F57C8F9B8B4E19EC2EAABB1D899
CBEAAFCDEBAF728A4C6B814092A860CAE097D8EEA5D4EAA2E1F7B6D6EBB0CAE1ABE4F6CC
F7FFECF0FFE3F7FFDDD3E8ADC8DF996F833CA2AD71D2D8AAE1DFC6C2BBB1FFFEFAFCFCF4
FBFFEFE9FED7E4FFCAC0E5A0BDE69AD1FAACBDE295D1F3A7C6E49AC4E096D2E9A1C9E098
CFE59DD2E8A0D2E9A1E3FDB4C9E79DB8D88DC9E99EC0E095DFFBB0AFC97FD9F3A9C6E096
D3EBA1C7DF95E3FAB2B9D088D0E5A0CBE09DA0B475879B5EDDF1B6EFFFC9E9FAC3CEDDA6
CDDBA08F98610A0900E8E2C0F4EDD3E8E5D29DA494D4E9D6C0E4C873A57F91CB98A2DE9E
BCF0A5CBF7A2C3E48BD8F29BD9EDA6CBDD9FCEDFA8BECF9BF7FFD4F9FFD8D7E8B4D3E7AC
CDE3A2CDE7A0CCEB9DCAED9BC5EC9BC2EB9CC2ED9EC4ED9FC8EA9EC8EA9DC3EC9DC2ED9D
C5EC9DC9E99DD0E69DCFE79DC9EB9EC7E197E6E1A1666222CCEB9FC0E99ACBE59BCFEA9B
C7EF97C0EF93BEEA91C0EA96C5EC9DC8EDA0C9EAA3C9E8A4
F4FFE5F3FFE0D6EBC0C8E0ACC5E1A4C9E9A0D3F6A4C5E992D6F99FC4E78DD4F19DCFE799
D2E69EC5D594A1AF71BFCD90CCE0A3C7DFA1D0E9A8CDEAA8C8E7A3CBECA5C9EAA3C6E89E
D0F4ACC6E7A0D1F0ACDEFBB8C2DC9BD6EEB0BDD395D4EAAACAE49DCBE59BCCE49ACDE39B
F2FFC0C6DA95CCE09BD4E8A3697D3895A962C2D890D5EDA3D7EFA5D3EEA1CEEA9DC7E696
D2F3A2CBEC9BC0DF91C5E197D3EAA4CCE1A0D3E3A5C6D59A728148D4E3A8CEE2A5D4EAAA
CDE7A6C8E5A2CCEBA5D5F1A7D8EA9EC4D585C7DC8FE2FAAEDFFEB2C3E398B9D98DC8E99A
C9E598B7D38857752FB8D897AFD29CABD2A55E8B64001D008ABD8484B677C3F1B3C6F2B7
C6ECB1C0E4A7BDDB9DD0EDAACCE69FD5ECA4D0E7A1C0D695C6DBA0D7EBB8E2F4CAF1FFDE
F9FFECE3F1D0EFFFCDD2E8A0A3BB678CA24DBAC87DE2EAB1E4E3C4CFC9B9FFFEF8FFFFF4
F4FDE2E3F6C8D3F2AEC9EE9EBBE495C8F1A2C1E899C5EA9CBEDE92CDECA0D2EEA3D2ECA2
CAE49ABBD58BCEEA9FBAD98DDAF9ADC8E89CD4F6A9C7E99CC5E496D6F2A5C4E093C4E093
CCE79AC9E497CFE79DDCF3ABC3D991E7FCB7C9DC9A485B1B9DAF71FBFFCFFBFFCFD1E0A5
DBE6AC9DA16E403B11DFD2B2E0D0B9FFFEEC80816FC1D3BDC1E9C7346D42054A13B3FBB9
B9FCAFA8E391BDED97C2E895CEE7A3C3D79CDDF0B9D2E4B2F9FFDAF8FFDAD5E7B3CADFA4
D4EDABCAE69CC0E192C0E693C6F09EC9F4A4C1ED9EBAE596C8EA9EC8EA9DC3EC9DC2ED9D
C5EC9DC9E99DD0E69DD0E69DC5E79AC6E096ECE7A7706C2CD6F5A9C3EE9ECAE69BCCE999
C8F098C2EF94C0EC93C1EB95C5EC9BC9EEA0CBEDA1CBEBA0
F5FFEAF0FFE35D724B000E00CFEBB0CDECA6BBDE8CD1F59DC6E98FC7E88FD6F39FC3DB8D
D2E69FD8E7A69BA66A919E68D3E3B4CBDEB0D1E7B6CAE2AEC1DCA5CBE9ADCDEBADCAEAA9
C0E09DC9EAA5D6F5B1F1FFCCE7FFC1CAE5A2D9F4B1C7E29DCEE99CD3EEA1D0E79FCDE4A0
C1D598CCDFA7DFF0BCC7D8A47F905CA7B882CCDEA2D3E8A7CCE39BCAE598CEE998CEEB97
BEE08AC7EB94D9FBA7C3E090CDE89BCCE29AB3C7828F9F5E8D9D5EDEF1B1C6DB98CDE6A2
D0EBA6CBEBA2C5E79DC3E294D0E795D7ED9AD5EDA1CAE69CC5E39DC9E8A2CDEBA1CEEB9B
D1EA96C9E38CD5EE9A89A359B1CF91C5E7B5B9DFBA8CB9927EB07B4B8145679860A8D7A0
B3DCA4D0F6BDC7E9ADC3E1A1D3EEABC3DC98D1E7A6D1E6ABCEE0AEEAFBD1F8FFE6EFFDE3
FBFFEDD6E1BFC6D89ED4EB9D789136CEE688D2E492FFFFCAE0E0BCD0CBB8FFFDF4FFFFF3
E4EDD0DAECBABEDD91CAF099CEF8A6BEE798CAF1A2C0E597C8EA9DD7F7ABC4E397CAE69B
CBE79CD6F2A7CEEDA1C8E79BC6E69AC7E79BC4E699C8EB9BC9EA99CEED9DCBE898C9E696
DDF8ABC3DE91D9F1A7C5DD93D7EDA5BFD58DD6EAA5CFE2A0BCCC8D708041A1B172D1E0A5
CDDEA8FCFFD88E8F676B6241F7E9CFDBD1B89A9C84F7FFEAD4FAD39AD2A167AB723D8344
93D58EBBF5ABC2F2A8C9EEA8CAE7A7CBE3A9F7FFD6EFFFD0F7FFDAF4FFD7D2E6B1CBE3A7
CBE6A1CCEB9FCBEE9EC6ED9AC0EA98BFEA9AC2EE9FC7F2A3C8EA9EC8EA9DC3EC9DC2ED9D
C5EC9DCAE99DD1E59DD0E69DCFEFA3CAE298E5E0A0646020C8E89CBBE696C9E89CD5F1A4
C5EB94C6EE96C8F09AC9EF9CCAED9DC9E99DC7E69AC6E599
607055263919000D00000E00CBE7ACD4F3ADCCEF9DBEE28AD9FCA2C2E38ACCE894D3EA9C
D5E6A0D2E0A28F985F97A071DCE7C7F6FFEAF7FFEAF1FFE2F4FFE3EEFFD9F2FFDAC7E4AC
C9E7A9C9E8A5C9E8A4C9E8A2C9E9A0CAE8A0CAE8A0CAE99DCFEC9CD2EDA0D1E8A4CFE4AB
DEEFC2F4FFDFF9FFEAFBFFEDF4FEE5D7E4C6D1E0B9CFE1AFC9DD9ED8EFA7C2DB8AD1EF99
C3E58ED3F79FCAEC95C1E18CE5FFAFBAD085566A224B5F18D6EAA5CBDF9ACDE29DCEE89F
D0EEA4CEEEA3C4E69AC6E999CDEA9AD1EE9ECFEDA3CBECA5C8E8A5C9EAA5CCEAA0CFEA9B
D1E890D0E58AD8EB92BCCF7DB8CF89CDE9AFC8E5B7C7ECC1B6E6B25A8F570015001F4F1B
C2ECBAB9E0ABCCEFB7CBEAAFBAD699DEF6BACCE1A8E6F8C6F9FFE1F6FFE5F9FFEFE2EBDA
CFD8C3D8E3C1CEE0A6CFE6988EA74CDCF496DAEC9AD1DB9CABAD88DCD9C6FFFFF6FCFDEF
E3ECCFD0E2B0C6E297C6EA93C2E998C5EE9FC9F0A1C5EA9CC6E89BC8E89CC9E99DC7E69A
C4E397CBEA9ECFEEA2CAE99DC3E397C4E498CCECA0D2F3A4C5E494D3F3A0D2EF9FC6E393
CAE598CDE89BCAE298C8E096D4EAA2CFE59DCBDF9AC7DB96D2E2A1A2B271819150D3E9AB
C3E1AFEDFFE0F7FFE3717B58E0E1BFD2D3B1ADB590F2FFDCD7F8C9C8F7C3B4EBB24D844A
85B67EC3ECB4D0EEBAC3DEA7C6DFA5D4EDB3EBFFCAF5FFD8F5FFDAEBFFCED6EDB5C7E1A2
CDE8A1C7E899C7EA98C0E892BBE591C5F0A0CAF6A7C2ED9EC2E498D0F2A5BEE798C4ED9E
D6FBADCCE89DD3E49DD1E59DCEEDA1C3D990EAE2A3605C1CC4E498C5F2A1CCECA0C4E093
CBEA9AC3E493C7E899CEED9FC9E89CC9E59BCEE89FCCE69D
000F000012000015001F3A05B8D497CAEAA1C7EA9AD4F8A1BEE089C9EA93C6E190DCF2A7
CADB97AEB97D989F69D6DDB3CFD7C0F0FBEDF8FFF3F6FFEEF4FFE9EDFFDCF1FFDCD3EEBB
CAE6ACC9E7A7C9E8A4C9E9A0C9E99EC9E99DC9EA9BC9EA9BCAE699C9E39CCFE4A9DCEDC0
E9F8D7F2FEEAF7FEF6F9FFFBFBFFFDF9FFF69AA38E8B9976E3F3C2C3D798E0F6ADC3DE8D
C6E892C2E68ECBED97C8E893CDE897DAF1A391A65BD3E89DCADE96CEE29BD8EEA6D4EEA5
C8E79BC2E296C6E89BD5F7ABC6E89EC8E9A2C6EAA4C5EAA4C4EAA1C7E99FC9E89CCDE695
DBEF9AD7E691D7E492CAD78898A962C5DA99C1DAA0BBDCA3BCEBB4B7ECB476A672457440
3B653598BE8D9FC18ECDEBB7D5EEB7C5DCA6D1E3B3DBEAC1EEF9D9EFF7E0FCFFF6E4EADE
D1D8C6D2DDBDD0E1ADD3E9A1A9C16DC9E18BC8DA8EDBE6AC868A69F0EFDDFFFEF8FFFFF4
DEE7CCDCEDC0CEE9A6C9EA9BC8ED9FC8EFA0BEE395CAEFA1C7E99CD5F5A9CBEB9FCBEA9E
D2F1A5CDECA0C8E79BC8E79BCDECA0CDECA0C2E195B5D486C9E898CEEB99C9E696C9E696
D1EC9FCFEA9DD0E89ED8F0A6C5DB93E1F7AFD5E9A4E2F6B1C2D691C9DA969AAB67ACC284
CAE9BDEDFFE8F2FFE624341097A17CE2EAC1879267E1F2C5C9E5B4B8DDA9BDE8B38DB986
477141BFE4B8C7E5BFC5E0B5C9E6AEC8E6A8C8E4AAC6E1AAC6E1ACCAE3ACD0EAADD5EFAE
C5E399CEED9FD4F7A3D0F6A1C8EF9CC1EA9BBFEA9BC1E79CD1F1A6C2E296C5EC9DD1F8A9
AFD184C3DD93DEEEA7CDDD96CFEBA0D9EDA5DBD394545010C8E89CC7F4A3C6E89BD1EDA2
D4EEA4CDE79DDBF5ACC8E299CDE49CB9D088889F595F762E
CEE3B8D9EFC1C8E0AEC8E4AADEFBB9D0F0A7B8DB8BCAED99C4E692D4F19FDEF6AAC5D992
E1F0AF99A367B1B680C9CEA6CDD1C2FBFFFBFBFFF8F8FFF2F8FFEDF8FFE6F7FFE1C3D9A8
CCE5ACCAE7A7CAE8A2CAE89EC9EA9BC9EA99C8EB97C9EA9BCEE9A2CDE5A7DCF0BDF4FFDF
F9FFF1FBFFFBFAFFFFFCFEFFFCFEFFFCFFFFFCFFFACAD3BEA2AE8AF3FFD2C4D69AE0F7B1
D3F4A5C5E894CCEE9AD3F0A0CAE596B9CF8495AA5FCCDE94D7E8A1E0F4ACD9EFA6C7E197
C8E499D5F5A9CFF1A4B7DB93C7EBAEC3E9AEC1EAA6C2ECA2C5EF9DC8EE99CBEB96D1E898
CDDD92E4EEA9D0D7949EA562939E59CBDD93DBF4A3E2FFB6BAE7A4CDFFC2C6F3BCBBE6B1
92B98A0010008AAA7BCAE6B6CAE0B2C1D4A7D5E4BBFCFFE4F7FCE5FFFFF3FFFFF8F5F6F0
FEFFF4FBFFEAF2FFD6D5E9AECCE39DCFE69ED7E9ABFCFFD8B0B499828276F1EEE9FFFFF8
E2EAD5D1E1BCC4DDA6CCEBA8CDEDA4CCEEA2CDEFA3CAEA9FC6E69BC0DE94C1DF95C6E298
C6E298CAE69CCCE89ECAE69CCCE89ED2EEA4D4F0A6D3EFA4D2EF9FC9E493BFDA8BC6E192
D3EB9FCCE49AC6DD95D2E9A1D2E7A2C1D691C4D994D1E6A1DFF5ADCDE19ACFE39CBACE91
CEE2BDF5FFEDF4FFE68694736E7853CFDAB0889466CCDCADDBF1C0C9E5B4C2E3B4CBF2C5
90BA9276A27ED0FCDBC2ECC4BEE4A9C4E7A5C9E8ACCBE8AEC9E6ACC7E3A8C6E3A3C5E39D
D1EDA2CCEB9BC1E38DBFE38CC7EA98C5EA9CC3E99ECCF0A6BCDA90D7F7ABC3E89AC1E698
D4F3A7E6FCB3CBD691DFECA6CFE99FD2E39CF1E7A99D9858D3F3A7B6E392C8EA9DC8E298
BED38ED6EAA5BDD18C4F631E576C27ACC17CD8EDAAD3E8A3
CFE6B0D2E9B1C5DEA4C8E5A5C3E09DC4E49BBEE093CEEFA0D6F5A5BEDA8DD8F0A6CDE19C
D0DC9E8D955CBDC08BF1F3CBDCDFCCFAFFF6FCFFF4EDF6E1F5FFE4F9FFE4F8FFDDCFE3B0
CDE5A9CCE7A4CCE7A0CAE99DC9EA9BC9EA99C8EB97C9E99DCDE7A8D5E9B8E5F5CEF7FFE8
FBFFF4FAFFFBF8FBFFFDFDFFFEFEFFF4F4FCE8EAE9FCFFF6E4ECD59AA583D0DDB2C8DBA4
BFDD97CDEE9FCBEA9CC9E598CBE39982984FC6D790D5E69FD1E29BC4D890C0D68DD4EEA4
D4F0A5BEDD91C3E397CDF1ABCAEDB5C2E9B2BFE8A6C1EB9FC5EF99C8EF96CEEB97D3EA9C
D6E2A0D7DDA1BABD8672783CB4BF7BD3E697D8F297AACD73C6F0A4BAE7A4BBE4A8C8EFB8
A8C99AD4F3C7445F343D542ABACCA4D8E7C0D9E3C0E3E8CAFBFDE8FFFFF3F3EEE8FFFFF8
FAFEEDFBFFE8F1FFD8B6CA95D0E8AAD1E9ABD7EAB3F3FFD5FEFFE8CACDBCFFFFF6FEFFF4
DDE6D1D3E4C2CAE2B2BEDA9FC4E19EBCDA90CFEDA3C0DE94DAF6ACC5E197D6F2A8D2ECA3
CEE89FD6F0A7D7EEA6CCE39BC5DC94C8DF97CEE59DCFE79DC5DD8FD9F2A1DDF5A7C5DD91
9CB46A778E46778E4693AA645A6F2A9DB26DD3E8A3BACF8AD9EFA7C4DA91D5EBA28F9E63
D7DDBBFFFFEBEDF1D8FEFFE60C1600000900F6FFD9D0DBB1DBE7BFF7FFE1E3FCD5B8DAB5
C1EDC9396F4BA3E0BEAAE5B9C4F2B4CAEFAAC7EAA8C6E6A7C7E7A8CCEAAACEEBA8CCEAA2
C9E598CDEA98C8E992CEEE99D8F9A8D0F0A4C4E69CCCEBA5CEEAA0C7E69AD2F4A7C9EB9E
BCD88DD5E9A1DAE49FD4DE99C7DD94D6E69FDDD294888343C4E498C1EE9DD8F8ACC4DB93
DDEEAAD8E7A6B4C483B3C382C3D694D1E6A1D1E6A3CFE6A0
CFE8A6C8E19FCFEAA5D0EEA8D2F0A8CCECA1CFEFA4CAEA9EC3E197CAE49BCCE19CDEEEAF
8C965AE4ECB3D9DCA7EAEBC1FFFFE5F5F9E2FEFFE9DAE1C2DBE3BEC4CFA5D7E5B2DCEEB4
D0E4A5CFE6A0CCE89DCAE99BC9EA99C9EA99C8EB97C9E9A0DCF2C1EEFEDAF8FFE8F9FFED
FBFFF3FCFFF8FEFFFDFFFFFFFFFFFFFFFFFFFFFFFBF1F2EAFFFFF4FCFFEDDFE4CDE2F0CC
CDE7AAD0F0A7BFDD95C2DD96DAF1A99BB169BECF898A9954D4E39EDEEFA9D0E49DD4EBA3
D4EEA5CCEAA0D3F3A8C2E39EC8EAAEC1E4AABFE4A1C2E89DC3EA97C4E793C9E598D2E69F
939E6279804CB7BB88D4DCA3E3F2AFC0D787E0FFA1CDF292BFE791C5EB9EC0E5A0CBEDB0
DAF8C4C4DEB1273E140C1E000A18005C6643989E7C8B8B6FA3A18CA49E90BBB2ABF0EADE
D0D7B8D9E8BFD5E9B8ADC48ED5EEB4D3ECB2C7DBA6D0E0B3C3CDAAE3EACB4B5039F3FCE1
F5FFE4F7FFE3E2F9CBD7F2BBD7F2AFCFE9A2CCE69FC8E29BD3EDA6D0EAA3CCE69FC1D892
C7DE98CDE49ED2E7A2D4E9A4DAEFAADAEFAAC9DD98B2C67F71883A7D9444869D4F9CB267
C3D990DAF0A8D5EAA5CDE29FDAF1ADB9D08C7087418EA55FC7DE96D7EFA5D3EBA1D2DEA0
B6AC89C5B39DFFFBE2B4B397575C3E000700E8EED2F8FEE2FDFFE8F9FEE7F7FFECD3F0D2
BAE9C744845F37885D9FEEB7B6EDA9BFE99FBCE49DBCE19CC4E4A3CDECA9CEECA6C8E79B
C7E492CEEA95D0EE98CEEC96C9E696C1DD92C1DF99CEE9A4DAF4ABC1DD92C5E599C3E397
D2ECA2CFE099B5BA777E8541556921DEEBA5E1D3965B5314BFDE92C2EF9EC3E397D6EDA5
D1E29EC2D18E8C9D59D5E9A4DBF0ABCCE39BC7E19AC9E39A
CEE99CC5E093D3EFA2C7E69ACAE99DBCDC91C8E89DBEDE95D4EFAAD8F1ADCDE2A1B0C082
4C551CD4D9A3DCDFAAEFF1C2FFFFDDFFFFE1FFFFDDD4DBB1D6DEAFDCE6B2D9E7ACC7D798
D1E5A0CFE79DCDE89BCCE89BCAE999C9EA99C8EB99CAE7A4EAFCD6F8FFEFF9FFEFFBFFEF
F6FDEBFBFFEEFEFFF2FAFBEDFFFFF4FAFAEEF6F6ECFFFFF8F8F8F0F4F5EFCECFC9D6DFCA
D4EBB7CFECAAC7E29FCFE8A6D4E9A6D2E5A391A05F586724B1C07DD5E6A0CFE39CCBE29A
C0DA91BEDA90D9F7ADD0F0A7CCEBA8C8E8A5CBECA7CEF2A8CEF0A6C7E79ECAE3A1D4E6A8
4A551DDAE1ADE3EAB4CED99DDFF3AED0EB9CAED278D0F79AC7EC8FD1F59DC6E69AC2E19D
C8E1A8CFE5B60E2000000D000711000E14001B1C0068674B4F49335A51406C5F56ABA491
DFE6BCD4E6ACCFE4A9C5DFA0D0EDADD3F0B0C4DCA0D5E8B1DEECB9D4E0B2394217DEE9BE
F9FFDCF5FFDAD5F0BBCCE8ADC1D796DEF3AECFE49FDAF1ABB5CA85D5ECA6CEE39EDDF2AD
889D58A6BA75C2D691D1E29ED2E39FC9DA96B0BF7C94A55FA4B66CC7DC8FDAEFA4D0E69D
C9DF97C9DE99CCE19ED5EAA7C6DD99D7EEAAAFC68290AA63ADC77EC6E096CEE99CD3E2A1
D6C99F9D886B9C93769FA2856C795D000800FBFFF3EEF0E3FFFEF6FDF4EDFDFBEFF8FFF3
DAFEE285C19B4A9E6D52A66AB4EEA4C6F2A3CAF4AAC7EFA6C9EDA7CDEEA7CBE99FC4E093
D4F09CCBE792CFE992CFE894CBE395D4ECA2D7F0AECBE4A2C4DB93DFF9AFC5E498C4E397
DBF3A9B6C67F989B588A8F4C4A5B14B7C27DE8D89C7D7335D7F3A8B8E393B6D68ADBF3A9
D2E39DD6E7A1AEBF79D9EFA7C4DB93C7E197D6F2A7C6E599
D3EF9ACCE893D2EF9BC7E794CBEA9CC9E99DD7F7AED5F4AEC4DF9CBBD493E0F4B7DBEAAF
818A533B400A2D30006565336567358B8F5CA1A57299A16899A166D9E3A4D7E3A1D6E69F
D1E59DD0E69BCFE799CCE999CAE99BC9EA9BC8EB9BCAE6A9E2F2D7F0FBEDFBFFF3F4FDE8
E6EED6DDE4C5DDE0C1E0E1C1FFFFE4FCFCE2FFFFEDFDFBEFFEFAF7F7F5F8FFFDFF949992
B2C79CCFEBAED7F1B2D0E8AABBCF90DAEDADC6D496DBE7A7D8E4A28A9956586925ACC17C
E7FEB8C7E29BC7E59DC6E599CEEB99CFEF9CDBF9AFE5FFBFDEFABFD0E9B2CEE2AFD5E6B2
B6C1898792567C8846D3E49EC8E298C3E397C3EC9EC5EF9BCDF191C6E685C7E58FCBE79C
CEE4A6D4E6B428370C131D002028031216000403009C977AE1D6C0FFF2E1BFAFA08B8467
DDE7AAD3EA9CCBE697CEEA9DA5C478C8E69CC5E197D7EEA6CDE19ACADB95D4E3A0B3C480
C5DA97D0E9A7D7F4B2C0DD9BC0D592DBEEACC7DA98A8BD7A7588468499568699578EA15F
D6E9A7CBDE9CA6B675748342627130839251B9C585DAE7A2C3D58BD3E599D8EAA0D2E69E
D4E8A1D1E5A0D0E5A2DAEFAEE8FEBDC9DF9ECFE8A4C4DE97D9F3AAC7E398CCE89BD6EAA3
E9E8B2D8D4A7D4DCB3F5FFE492AF912F4B35DDECE5FEFFFFF3E2ECFFF6FFFFF7FDFCF1ED
E6F5E0C2ECC8AEF2BF135E1DA9E295BFEE9DC8F4A5C0EA9EBCE299C6E89ED2F1A5D8F5A5
CFEB97CBE58EDCF49ED8F09CBFD688CEE49BDEF3B2C4D998CBE199D7EFA5B7D388D2EEA3
849A51909D57DADB99EBEEABD3E39CA7B16CCFBC817B7032D5F1A6C5F0A0D2F2A6CDE59B
DAEEA68D9E5790A65DC9E197D6F0A6C7E698C9EA9BC7EA9A
D0EC98CDEA96C9E692CAEA95CBEA9ACEEFA0C6E69ABFDF96CCE9A6D8F2B1C2D898E0F4B7
F5FFC7F2FDC1D6E0A3D7E1A4D3DD9EE0ECAAD6E2A2CEDA985D6A2554631E45550E98A962
D1E59DD1E69BD0E69BCFE79BCFE79BCDE89BCDE89BCFE4ABECF7E6F3F9F5FBFFF6FBFFEC
ECF8D4D3E0B4CFD8ABD9E0B4FEFFDDFFFFE6FFFFEEFFFFF6FFFBFAFFFDFFF0EDF4DCDFD8
D0DEBAE9FBC7CEDFABCADBA7DBE7B5D7E1AFDEE6B7D1D9AACFD7A8E4ECBBCEDAAAD0DEAB
B5C69299AB77C5D9A4D5EBADCCE299D4EB9DE5FCB8F3FFCDE8FFCBD4E7B9CBDDADD0E1AD
D0DFA4D7E6A58FA059889D52CBE699D5F5AAC6ECA3C1E899C5E789CFEF8ECDED98C5E399
D8F0B4C0D29E788152202500575932919270777A5F373A25D2D6C5EAF1E1FEFFF3A2A98A
B2BA7ECCDA8DD1EA99D4EF9E8CA456D4E99CD8E89DD3E599D0E799CEEB9BC9E8988EAD5F
CAE49ACFE69ED3E8A5D3E6A6DDE8ACD6E0A4CFDD9F9AAB67BBD189C7DE96E3FAB2C5DF96
C9E09AD5ECA8D6EBAACADD9DCADA99D4E5A1D7E8A2D0E19AD5EA9DD2E99BCDE39AD0E69E
D5EAA7CDE3A3CFE4A9E1F6BBF2FFCED6EBB2CBE3A5C6DF9E92AB67CCE69DC8E499D1E79F
D5DFA2D6DFA8CDE1B0E9FFDC739175557061F0FFFCFEFEFFFFF8FFFFEFFEFFF0F9FFFAFA
EAEEDFC8E1C3AFDEB280B98255894988B773BAE4A2CDF2AFCCEBA8CBE6A1CCE49ACAE193
D2EA96CBE38DCDE58F92AA5641580A60762DBACD8BD6E9A7D5E9A2CEE49B506A20A4C075
ADC57BDBECA5DBE29ED6DD99D7E6A1CAD390F7E8AF6B6126C5DA97C7E6A0D4EDABCCE1A0
D5E8A88B9E5ED3E8A5CBE29CCEE89FC7E398CAE99BC9EA99
C8E49AD2EEA3C5E194C7E794CEEE9BC7E792CBED99CAEB9CC5E59AC8E69EC9E7A1CBE9A3
CEE9A2CEEA9FD0EB9ED0EB9CCAE596D5F2A2CCE89BCDE79DCCE69DCAE199CCE39DBBD08D
8DA05E6C803B42530F303F00525F195360189EAB63E0E8B5F1F2ECFAFBFFFBFFF6F2FFE0
DBF2BCCCE4A6CDE2A7D4E4B3FAFFE2FFFFF1FFFFFBFAF5F9FFFDFFFFFEFDFFFFF6E9EAD8
B9BD9CF7F9D4FFFFE1FAFBDCFFFFE8FFFFECFFFDEEFFFFF3FFFFF4FFFFF4FFFFF6FDFDF1
FAFAEEFFFFF3DFE1D39B9F86FEFFDCCCD6A2E5F1BFF9FFD4E4F4C3D6E7B3C8DBA4D2E6AB
E0F4B5BBD08BD2E8A0B4CA7F6B833791AC5FDBF5ABC8E595C4E28AD1F39DC6ECA3CAF1B2
C6E5ACD3E7B25156200804002D2600969576D4E1D079938A1C433EC0EDE6DFFFFFABCDB4
73744AD6D39CDDEDAC899F57919B52E0E098F2E8A3D9D993CDE99EC5F6A5B3EE9EBBEFA4
8BAA66B7C587D0D499E6E0ACE0D9ABD6D2A3A0A56BC7D691CBE493C6E691CDF19ABFE592
C8EA9ECEEDA7CAE7A5CAE4A3D1EAA6CFE9A0C9E696CEEB99CDED9ACAE999C6E599C6E49E
CBE7AAD7F0B9E2FACAEAFFD2E9FED3EFFFD7E3F7C6C3D8A0A0B678D4EBA7CFE69ECFE69E
D0E5A0D1E5A8C8DCA9EFFFDE83957F000500F9FFFFFDFEFFFFFDFFF7EEF3FFFDFBFFFEF8
EEF2E3E0ECD6E8FCE1DCFBDC0730102854319CBE99E9FFD8C9DBA9CDDBA0D5E09CD9E79C
D5E896CBE38BCCE98F728E37C6E190839B4F96AA658FA05C93A45E99AD66ACC47AC1DD92
CEEA9FCEE89ED0E49DD4E59FDAE9A6878F53A19E67807D4AD6DDA9EBF5C3E7F0C1C7D3A3
B5C596E0F2C0E5F6C2CBDFA4CBDFA0D3E8A3CFE79DD1E99D
C5DF9ED1ECA9C4E298C8E799CEEE99C6E790CAEC96CBED99CCECA0CAEAA1C7E6A0C6E59F
C6E69DC6E69BC6E798C5E697C4E498CDEDA2C6E69DCAEAA1CBE9A3C9E49FD0E9A7C8DE9D
D1E6A5CBDB9CC6D496E7F1B2E9F2B3CFD597B5BB7BCFD2A7EFEEECF8F9FEF9FFF3F6FFE0
E0FDBDCFEEA8CBE6A3CCE3ADFBFFE8F7FAEFFFFEFFFFFDFFFFFEFFFFFFF8FFFFEFA9AC8F
A2A381E4E4C0FFFFE2FCFBDFFFFFEAFFFDEEFDFAF3FFFEFBF7F3F4FCF8F9FFFEFFFFFEFF
FBFAF8FFFFFBFFFFFBEFEFE3AFB297A2A685E8EECAFEFFDFDDE8BED3E0B2DEEFBBCDE0A8
CCE0A5E0F6B6CFE6A2C5DC96E0F6AE40560DD2E79CCDE496CDE597C6E69AB6DF99CAF4B4
C4E8ABBBD399323500140D0043370D8E8E6CDAEDD9B2D8CB49817842847ACFFFFFDFFFF5
484524F6E9BDC6D1975A6B275B611BD7D08AE6D794E7E29EC8E69CAADF91BCFAADC2FAB1
9EBE7D8F9A5E343300D5CB9861552D635C30686D33BCCD86CFEB97C0E48AC2EA91CFF9A5
C4EA9FCAEAA7C9E7A9C8E4A7CCE9A6C9E99EC5E894C9ED95C7EB94C6E997C5E79BC9EAA5
D2F0B4DDF9C6ECFFD5F3FFE0F5FFE1F5FFDFF7FFDCD8ECB7C2D699BACF8CD0E69ED5EDA3
C6E097CEE8A7DBEFBCF8FFE476826E0D140DF0F4F5F8F9FDFFFEFFFCFCFCFFFFFAFFFFF6
FEFFF3FEFFF1ECF3E1A2B09F9DBDAE527766506C5645583CD7E3BBE3EBB8D5DE9FD9E59D
D5E897D8F09AB7D37C95B35DC9E495D8F0A6D2E7A2CBDF9AC7DB94C5DB93C5DF95CBE79C
CAEA9EC7E79BCAE69CD0E79FD0DF9EE5EDB1C7CA935959270B0A0053562B7D8259CCD4AD
DAE8C5F2FFDEEBF9D5D2E1B6D0E0AFD3E4AECEE0A4CEE0A2
C8E4A7D4F1B1C7E59FC9E89CCDED9AC5E590CBEB98CCEB9BCFEDA3CBE8A5C8E5A5C8E4A7
CAE6A9CCE8ABCCE9A9CAE6A9C9E4AFCEE9B6C7E2ADD1EAB3D0EAADC7E09FD0E9A7CFE6A2
D4E9A6D2E2A1D8E6A9D9E4AABEC7929FA673B9BC8DFFFFE1F8F7F2FBFDFAF9FFECF1FFD6
DFFCBAD0F0A7CCE6A5CBE2AEFBFFE8F5F8EDFDFBFEFFFDFFFBF7F6FFFFF4E3E7CEA7AF8A
B2BB8ED4DDAEE3ECBFEAF2CBFDFFE3FEFFEAF7FCE6FEFFF1FEFFF4FCFFF6FCFFF4FCFFF4
FAFFF1FCFFF1F6FDEBE1E6D0CFD1BBD4D6BEE9EDD4FEFFE8FAFFE4F4FFDDEDFBD7C6D7AD
C9DAADD3E5B3D5E8B1D1E5A8CADC9EB2C583899A56B8CC85D5EBA3D7F3A9BCE297C3EBA2
D3F7B1DEF4B33131000D02003428009E9E7ACCE2BEA7D0B080B9992B6D518FD0B8D6FFE7
747150A29368D4D9A1BBCA8978833EC5CB83D6D68EDCE49BC9E39AD4FCB3BFEDA5BCE5A1
D8F2B3C0D092A4AC71A2A56EA19F6FB6B684C2CC8FDAEEA6D2EF9DCDF19AC3E996C4E99C
C4E4A3C8E4AACBE4ADCBE4ABC8E5A3C7E79CC5EB96C7EE95CAED99C8EB9BC8EA9EC9EAA5
CDEBADD4F1B9DDF5C3E1F9C9E4FACBD5EBBAE6FAC5CFE4ABCCE0A1839853BDD38AC7DF95
D2ECA3C1DB9ACBDFACF8FFE48C98846A7169FCFFFFFDFEFFFCFBFFFFFFFFFFFFFBFCFDF5
F7FBEDFEFFF3FAFEEFBBC6B8DDF2E995AFA66279699CAE968E9E79CADAA9D2E1A6CEDF99
D0E598BFD686A2BB6AC1DC8DD1E99DDAF1A9C4DB97D5ECA8DBF0ABD5ECA4CEEA9FCBEA9E
C8EA9DC6E89BCAE99DD3EAA2D8E7A4D3DD9EE8EDB3484B16A2A674B9BF8FEDF5C6E8F3CB
F8FFEBF8FFF1F1FDE7E3F0D6E8F2D7EAF5D5E6F1CFE7F3CF
DCF8BEE0FCBFCAE7A4C8E69CCEED9DC7E794CBEB98C9E89ACAE8A2CBE5A8CDE6AFD4EAB9
DDF3C4E2F8CAE3F9CBE1F6CDE0F3D7E2F4DADAEDCFE3F8D1DEF1C3CBE0A8D0E4A7CFE4A3
D4E7A5CBDB9CD7E5AAD3DDA9E2E9BDABB18BECF0CFFFFFEAFFFFF4FCFFF3F0FEDBDFF6C2
D1EEABCAEAA1CCE6A5CDE4B0E9F6D8ECF0E2FCFAFBFCF8F9FCF9F2F7F8E6ABB291D8E3B8
D1E2ABD2E6A9CCDFA7D3E5B1E8F9CCEAFBD1E1F1CDE4F3D2E9F8DBE0EFD2DEEED1E4F5D5
E7F8D6E6F7D5E0F1CDDBE9C8F4F8E1FFFFEEB6B7A5B9BEAAFEFFEFFBFFEFF1FBE3E7F4D8
EAF9D8E3F3CEE8F9CFDBEBBCD7E8B2E2F1B8CCDC9E89995BBFCD90D8EDACCAEC9FBBE291
C5E697D7EDA53E3D072A1F00433711A09E77D1E7B8C6F1BCC3FDCA9DDEB34A8B69689375
BEBF9D61542ABCBC88DAE4A5D1DE98B3C37891A156D7EC9FDAF1A9C5E09BCEEBA9C6E0A1
D5E9ACD0E2A4CEE1A1BECC8FCED79EDEE7AEE1F2AECAE298BBDA8ACCED9EC6E89CC5E4A1
CCE5AECDE3B4D2E8BAD2E8B7C7E3A6C5E79DC7EF99C7EF96C9EF9CCAEC9FC8EA9EC6E7A0
C6E4A4C7E5A9CBE4ABCBE4ADCFE6B0C6DDA5D5EAAFD1E7A7D6EBAA778C47C7DD94D1E99F
CDE79EC8E1A0D7EBB8F8FFE37C8874545B53FBFCFEFAFBFFFCFBFFFAFAFAFFFFFBFFFFFA
F4F6EBF6F9EEFEFFF6FCFFFAD1DAD7E0ECEA5E6E63586A54A1B79396AE7E9DB67C96AF6D
95AC6488A054A7BD72CFE59CDCF3ABC0DA93C1DC99D1ECA7CAE49DCAE49BC8E79BC9E99D
C7EC9EC6EB9DCAE99DCEE89EC9DA94D2DE9CEDF5B96E7339D4DBA5D0DAA5E4F1BCF3FFD7
F8FFEBF5FFF1F3FEEEF4FFEFFBFFF4FCFFF4FCFFF4FCFFF4
F1FFD8ECFFCFCCE9A9C6E49ECFEEA0CAE999CEEB9BC9E59BC7E1A0CCE3ADD7EABDE4F5D1
F0FFE3F6FFEBF7FFECF4FFEFF7FFFFF7FFFFF1FDF3F8FFF1F1FFDFD8E9BCD7E8B1D3E3A5
C8D899D7E5A8D0DDA7D5E1B1D8E0BB9CA286EAEDD8EDF2DEFEFFEFF5FFE2E3F4C7D3EBB1
C8E6A0C6E69DCBE5A6CEE4B3D0DDC1D7DDCFFFFFFBFEFDF9FFFFF49599809BA67EDDEEB8
CEE7A5CBE9A1CAE7A4CBE8A6CAE6A9C3DFA5C4DFAAD2ECBCC7E1B1CAE4B4CCE6B6CAE5B2
C6E1ACC7E2ADDBF6BFF7FFDDF9FFE5FDFEF0A9AA9CA8AC9EF8FBF0F9FFF6F0F8EDF9FFF6
F9FFF3F6FFECF9FFEAF4FFDFF7FFDBBBC799F0FCCA8A9460E8F0BFDAE7AFC8E497C2E48D
CBEC95CBDD9355541E55481EA49671979668BDD395CCF5AFA7E09BBAFABD609D734F7B58
D7DFBA5E572D9C9664DADEA3E8F7B2C0DB8C9CBD6C91B263C5DC94CADA99D8E3A7DEE9AF
D6E6A8DBF1B1C3DE9BDFFAB5D5EAA9C9DE9BD1E8A0CFEBA0D0EFA3CBEBA2C8E5A5D5ECB8
E5F5CEE0F0CCE7F7D3E3F5CBCBE7ADC5E69FC7F19BC3EE94C3E898C6E89CC7E99FC7E8A1
C9E8A4CAE9A6CDE7A8CEE8A9CCE5A4CDE6A5CDE3A2D7EEAAD7ECA7899F57D7EDA4DAF2A8
CEE89FCBE4A3D1E5B2F8FFE37D89752A3129FCFEFDFCFDFFFFFEFFFAF8FBFCFBF9FFFFFA
FFFFFAFDFEF6FDFFF7FFFFFBC5C0C4FFFEFF7F867F243523ABC6A5B9DAADA3C68E7A9D5D
87A55FA1B872D3E7A0CDE19AD8EDA8CFE8A4DDFCB8C7E6A2CAE59ECCE89ECBEBA0C7EC9F
C6ED9EC5EC9DC7E79BC7E398D7EBA3D7E6A1C3CE8C697334CED99DE8F6BBD4E6AAF4FFD4
E4F3D4E3F0DCF0FBEAF9FFF6FBFFFAFAFFFBFCFEFDFEFFFF
F1FFDCF0FFD7CDE9ACC6E3A0CEEDA1CAE99BCFEB9ECBE59ECCE4A8D6EAB9E4F4D0F1FDE5
F9FFF4F9FFF8FBFFFBF9FFFFF9FFFFF9FFFFF7FFFFFBFFFAFBFFEDE8F4D0E2EFC1D6E3AE
D2DFA7FCFFD3E0ECBAEDF8CDB6C09EAFB89DEAF1DFF4FCE7E8F1D2E0EFC4D7ECB4CFEAA7
CAE89EC9E9A0CAE7A7CCE2B1E8F5D7DDE4D4FFFFF8FFFFF6FFFFED39401FCCDAA9C9DFA1
C9E79DC0E595C4E699C9EEA1CBECA5C2E5A1C2E2A1C4E4A5CCEBAFCFEEB2C9E9AAC6E6A5
C7E7A6C1E19EC5E6A1DDF6BCFCFFE2E6E8D3D1D4C3E5E9DBFAFFF6FAFFFAFBFFFDF5FEF9
F5FFF7F1FBF0F9FFF4FBFFEFE6EFD2F1FBD8BBC39CBAC198BABC95BFC796D3EAA2CEEB97
D7F39EDAECA2A19E697D70466E6137A6A473C6DB96CFF8A9BFF6A5A9E59F87C08D537E53
C9DBB3909368837B4CD8D39CD4E19CD5F4A6DAFFB36F994791A860A5AF70E3E4ABCDD097
CBDB9DC7E09EE1FFBAB0D288CEECA2CDE99ECAE99BC0E192C7E79CC1DE9CC9E0AAC2D2AB
FBFFEAF7FFE8FBFFECF3FFDFD1E9B5C3E7A1C6F29BBEEB90C3E89AC6E7A0C7E8A1C8E9A2
CAEAA1CAEAA1CDE8A1CCE7A0CBE59ECEE89FC7DE96CFE69EC9DF978EA45BCEE49BCEE59D
D7EEA8C8E1A0C2D4A2F1FFDC8E978421261FFEFFFFFFFEFFFFFEFFFFFEFFFFFEFCFFFEFA
FFFFFBFFFFFBFDFFFAFFFBFA9F8B94FCEBF3F1F0ECBBCCBA3D5F3EBEE9BBD0FDC6AAD495
C6E6A3D1EAA6DCEDA9D5E6A2CADF9ACFEAA5CEEFA8BEE29ACCECA3CEECA2C9EB9FC2E89B
BFE899C4EB9CC8EA9DCAE69BD1E79ED4E59EE5F2AD535F1DD9E8A5C4D795C4DA99C3DB9F
CEE1B4D2E1C0EAF7DBF9FFEFFCFFF6FAFCF7FFFEFFFDFCFF
ECFFD8EAFFD3CCEAAEC6E3A1CCEAA0C9E598D0EAA0D0E9A5D9EEB6E4F5C9F1FEE2FBFFF4
FBFFFDFBFFFFFBFEFFFCFEFFF7FBFFFBFFFFF6FBFFFCFFFDFCFFF4F4FCE4EFF9D6DDE5BC
DBE4B7FDFFD9EFFACFFCFFDDDBE7C3FBFFE6EDF7DCCAD5B5D5E2B6D2E5ADCFE8A6CCEAA0
CAEA9EC9E99EC9E6A6CBE1B0F9FFE6F7FFEAFFFFF3FFFFF1F4F8DD556036E8F9C2C6DF9B
CEEFA0BEE690BFE592C7EE9DCDF2A5CDF3A8C9EDA5BEE29AC2E6A0C6EAA4BEE29AC3E79D
D5F9AFD0F5A8C2E497C8E39EBFCB9DB5B998D8DCC1F7FCE6F7FEEEFBFFF8FBFFFDF4FDFC
F1FAF9F9FFFFFBFFFBF3FBEEFCFFF1FCFFECE1E7CBDADDBE5F5A3C93946AE0F2B4CFE9A0
C4DC92CEDD98E5E2ADA4976A57491CE3E0ABD4E8A1B8DD8FD1FFB3B2E79FB9EBB084B07F
96B788D7E8BB7D7648726634C6CC8CCFE99FBCEC98B7E695C8E2998A9455D3D299EAEDB4
D4E6A8BAD794CDEDA4CFF1A4BBDE8ED2F5A1C9EF9CB8DD8DCCECA3D6F2B5F8FFDDF8FFE7
FFFFF3FEFFF5FEFFF4F9FFECD0E8B8C2E5A1C7F59DBCEA90C6EC9FC9EAA3C9EAA3C8EAA0
C8E89DC6E69AC7E398C6E295D3EEA1CDE89BD2EA9ECFE79BCEE49993A960CDE39ACFE69E
CBE29ED1E9ABD9EBBBF8FFE3767F6C000400F4F6F5FCFBFFFBF9FEFFFEFFFFFEFFF8F7F5
F6F6F4FCFCFAFFFFFDFFFCFD8F717BEBCDD5FFFEF8D7E8D538603D3E7242B0E7AEC6F8B9
CDF4B1CAE5A2C6D695D4E3A0CDE29DC8E49AC0E699CCF5A7C5E79BC9E99EC5EA9DBFE598
BEE798C6ED9ECBEE9ECDE99CD0E69BD3E59BC8D89153631CCEE29AE4FAB1D1EDA3D1ECA7
C8E1A0CDE0A8E7F7C6F9FFDFFBFFE9FEFFF3FFFFFAFFFEFF
DCF7CAE2FECDCCE9AFC7E6A3CBE79DC5E196D0EAA1D4EDABE3F5C1EDFDD6FBFFEDFBFFF8
FCFFFFF9FCFFFCFBFFFCFEFFFBFEFFFBFFFFF9FDFCFCFFFAFEFFF6FEFFF1FEFFECE7EECF
EFF6D4F4FCD7F8FFDBC3D0A59DAC81E1F2C6DBECC2D1E3B3CEE2A7CEE5A1CCE69CC8E799
C5E898C5E79BC7E5A5CBE3AFF6FFE0FCFFEAFAFDE8FFFFEAF1F9D4B2C08DD2E4A6CBE59B
C7EA98C4EC96CCF29DC9EF9CBBE090BCE193C7EC9FCAEFA2C4E69CD1F3A7CAECA0C3E598
CBEE9EC7EA9AC5E695D8F2A88D9B60ADB584E0E9BEE4EECBE6EFD4EAF3E0E1EBE0F9FFFD
F9FFFFF7FFFFF7FDF9FBFFFBFCFFF6EFF6E6E4E9D5F0EFDACEC7ABAFAB86CEDAA8CCE1A6
D8EEB0D1DFA2EAE7B27B6F3D736735E1DEA7D4E4A3D1F0AAD6FFBAC4F3AFBFE8AC749F69
659561C3E3B4BEBB90564819C0BE83DAEBA5B7E292C9F8A7CDE99FC1CD8D040800CFD79B
D9EFAECBE9A3CCE7A0C8E799C5EB96CCF49CC0E892C7EC9CD1F2ADB9D29BF8FFE3FEFFEF
FFFFFBFAF6F5FFFFFAF9FFEFCEE3B8C0E3A1C8F69EBDEB91C5EB9EC9EAA3C9EBA1CAECA0
CBEB9FCBEC9DCDEA9ACDEA9AD1EC9BC1DC8BD6EEA0CAE294D4EA9F91A75CCCE299D4EAA2
D1E7A6CDE2A7CFE0B3F7FFE4848D7A2D3029FFFFFFFFFEFFFDFBFFFFFEFFFFFEFFFFFFFD
FFFFFDFFFFFDF8F8F8FFF8FAAF8A92F2CED2FFFBF2F7FFEF95BF99001D0098D59AB3EBAA
B9E2A0CDEAA7DEEFABCCDB96D5EBA2C7E698C6F09EC2ED9BC2E799CAECA0CBF0A3C6EC9F
C6ED9EC9F0A1C9EB9EC7E396D6ECA1D8EAA0D2E299697B31CADF94D0EB9EBEDD8FCFF0A1
D2EDA0D1E99FE6FBBAF6FFD1F3FFD7FBFFE9FFFFF4F9F8F3
C7E3B3C7E3B0CAE8ACCCEBA7CBE79DC9E59AD6F0A7E6FFBDF6FFD4F8FFE1FBFFEDF7FFF2
F6FAF9FCFFFFFEFEFFFBFEFFFCFFF8F7FFEDF8FFEFFCFFF3FEFFF3FBFFF0F9FCEBFEFFEE
F9FEE7FEFFE6F2FCD7828F61BCCE9AD8EDB2C4DA9AD6EDA9CFE6A0CDE79DCCE999C9EB97
C8EB99C8EA9DC9E8A5CCE5AEECFBD2FCFFE4FEFFE6F6FCDA626E40DEF0B6C2D792D6F2A5
C9EA99C6EC99C8EB99C8EB9BC8EA9DC8EA9DC9E99EC9E99EC8E89DC4E499D2F0A6CCEB9F
BEDA8DD7F3A6C7E494CCE49652641AB8C782DAE8ABC7D5A0D2DFB4D5E3C2DBE7CFF8FFF4
F3FFF5F6FFF9F9FFFBFBFFFBFCFFFAFCFFF6FEFFF4FFFFEDFFFCE1A6A07EDEE8C3D3E5BD
CADDB0D4E2B1A09F695F561F9A8F57E3E0A9D4E1ABD8F1BAEDFFD8C4EAB1CCEEB2BFE8AE
427F46C3F3C1D8DBB06E5D31928952E6ECACC6E89BC0E99AC8E69CC8DD9AE1F1B24D6020
C5E29FD2F0A8C8DE96D1E99DC4E891C7F298B9E189BFE496D7F6B3C8DEADFBFFE8FAFCEF
FFFAFEFBF4FBFFFEFFFEFFF4CBDDB7BFDFA0BCE893BEEC92C4EA9DC8E9A2C7E99FC6E89C
C8E89CC9EA9BCBE898C8E595CAE596C9E495D4ECA0CDE599D0E69D95AB62CDE39BD1E6A1
C6DC9CDBF0B8CEDFB3F7FFE6DAE3D25C5F58FEFEFFFAF7FEFFFCFFFFFAFEFFFEFFF7F5F6
FFFEFFFFFEFFF8F8FAFFFBFDA98086C39B9BFFF9EDF0FFE6B4DEB600240074B478B8F3B1
BDEAA7C6E7A2DCF1ACCDDE97C8E092CEEE9BB9E48BC7F39CC7EC9EBEE094C8EDA0C0E699
CBF1A4C1E698CEEEA2C8E298CFE59ACEE096D3E39878883DDDF4A6C9E495D3F4A3C5E992
CDEB93C9E590CBE397D6EAABE9F7C6F6FFDEFCFFECFAFCEF
D1EDBACBE8B0C7E5A7C8E6A0CAE99DCCE89BCEE89FD0E9A7DDF1BCEEFFD5F9FFEAFBFFF3
FBFFFAFBFFFFFCFFFFF1F6EFE6F1D3E1F0C9E9F4D2F9FFE7FCFFEDFEFFF1FFFFF3FFFFF3
FEFFEFE5EED1BBC7A197A776C8DC9FD3EDA4C4DF90CFEA99CDE899CCE999C9EB97C8EB97
C6EC99C8EA9DC9E8A4CCE5ABF3FFD4EDF8CEDEE6BFF4FDD292A06BD7ECABD4ECA2C3E090
C9EA9BC8EB9BC9EA9BC9E99DC9E99DCAE89ECAE89ECCE89ECCE89EC8E49AC8E299D2ECA2
D5EDA3D6EEA4C5DD91BDD4868AA04DCDE08EDDEFA3CADE99D2E4AAD4E6B6D3E3BEE6F6D9
E7F6E1EAF7E6EFFBEDF5FFF2F8FFF3F8FEF2FBFFF1FFFFEEFFFFE3CFC9A9868C70DDEDD0
D6E9C9BCCBA2D8D8A4746E348C834AEAE7B2D8E1B4DCEEC6F1FFE3E5FFD4C6DFA8C6ECB3
10541BB3EFBBDAE7BB9A8F62736733C1C183BDD48CD2F2A7D6F1AAC8E39EC7E09E96B370
93B46D9CBA72DAEBA4D7E99DC8E893C6ED94D0F6A1C4E699BCD999C5DBACFBFFECFBFCF4
FFFCFFFFF8FFFFFDFFF9FBF0D0E0BBD1EDB0D2FCA8BFEC91C5EA9CC8EAA0C7E99DC7E99C
C8E89CC9E99DCBE79ACAE699D0EB9ECAE49AC8E096D7EFA5C5DB933F550D92A860D4E9A6
DCF1B6CEE0AECEDDB6FBFFEA888E800E100BFFFFFFFFFDFFFFFCFFFEF9FDFFFEFFFFFBFC
FFFEFFFFFEFFFDFBFEFFFBFDC0999AC6A19BFFFDEDF8FFECC6ECC5A0D6A47CB980B2ECAF
C0EEAEBDE09CD0EAA3D1E99FCBE695D2F49DC9F498BFEA90D2F5A5C6E69BC0E296C5E79B
BEE396C6E89CCFEBA1D4ECA2CEDF98EEFEB5C7D48C708035CEE396BAD584C6E894CCF099
C9EA8FC9E78FCAE598D3E9A8E2F2C1F2FEDAFEFFEDFEFFF3
CBE8AECBE9ABCAE7A4C8E69ECBEA9CCEED9FCEEAA0CBE4A2CFE7ADE2F5C7F2FFDEF9FFEC
F9FFF1F9FFF3F4FCEDE6F3D9D3E5B3D1E6ABDCEEBCEFFED5FCFFE6FBFFEBFEFFEFFEFFF1
FEFFEDCAD3B68F9C71B5C891D1E8A2CDE897C7E689CAE98CCCE995CAE999C8EB97C6EC97
C6EC99C6EB9BC9E8A2CCE6A5CEDFA9C6D2A0D1DAABD9E6B1A3B579C6DD97D7F2A5C9E898
CAE99DC9E99DCAE99DCAE89ECAE89ECCE7A0CCE7A0CDE7A0DBF2ACC3DA94D6EBA6D9EFA7
C9DD96CBDF98C6DA9374893CC4DB83D8F196D7EF99CBE493D0E79FD1EAA9CDE4AECEE4B5
C8DDB6D3E4C4E8F6DCF9FFEDFBFFEFFBFFF1FCFFF1FFFFECFCF3D4CBC5A5899179F7FFEF
E1F5DACFDFBAD6DAA7A19C62544E149B9865C0C6A2ECFBDEF5FFEDDEF1D1DFEFC2BDDBA9
0F541EADF0BBC9E5B5DBDDAE9A935F8A854BBEC987D3E9A1B9D38CD7F6B0D0F1ACD1F5AF
B8DC94A8C67CA8B86F8A984DB5D17DB5D781D4F5A4D6F4AAC9E3A6D4E7BAFBFFEDF7F8F2
FFFCFFFFF9FFFFFDFFF2F2E8D0DEBAC8E2A5C9EF9CB7DF86C6EC99C8EA9DC7E99CC7E99C
C8E89DC9E99ECCE7A0CDE8A1CDE7A0D3ECA8BFD692D9F0ACE8FDB8859A55C5DA95D5E9AA
C5D8A1EBFCCFF9FFE4FBFFED60665A050704FFFEFFF4F1F8FFFDFFFFFAFEFFFEFFFFFEFD
FFFCFBFFFDFEF7F5F8FFFBFBBA9B98BB9D93FFFDEDFBFFECBCDEBBCCFBCF356B39669D64
C6F3B8BDE4A3C4E39FD2F0A6C3E292BDDF88C9F294BFE68BBFDE8EDBF7ACC5E498CFEFA3
D5F5AAD5F3A9B8CF87CCE099D3E09BCDD893C9D48F929F57DAEFA2D5F0A1C4E692CFF29E
CCEE9ACCEB9DCBE69FCBE3A7D2E3B6DEECCBF0F9E6FCFFF4
C0DF9CCAE9A5D1EFA7CCEB9FC6E595C8E797CCE89DCCE7A2CFE9ACD9F0BCE3F5CBE3F5CF
E3F4D0E4F5D1E2F2CEDBEEC0CEE7A6CCE7A0D3EBADE1F4BDE8F7CCE9F3D0E8F1D4ECF2D8
E4EACEB1BB989BA87AC9DDA0D1E99FC8E690CAEC8DC9EB8CCAEA95C9EA99C8EB99C6EC99
C5EC99C6EB9BC9E99ECCE7A2D5E7A9D6E5AADAE5ADB7C58AA7BA78CCE39BC6E295CAEB9A
CAE99DCAE89ECAE89ECAE89ECCE7A0CCE7A0CDE7A0CDE7A0C7DE98D9EEA9DAEEA9C3D792
C6D7939EAE6D8A9A59B7CB83D7EF99D0EA8FCEE891CBE793CBE697CFEBA1D0EBA8CAE4A7
C8E1AACCE2B3DAECC2E8F8D3E7F5D4DEE9CBDDE7CCE9EED0FFFFDDD7D3B08C967BECFFE5
DCF3D6D3E5BFA4AB7852511948410B9C9869F9FEDEF0FAE2E9F6E2F9FFEDDEE4C2DFF6CC
215F3077BB88BCE3B4E0F2C0D9DCA768662D77793AD4DF9DD1E6A3CDEBA5C2E7A1B5DD94
D6FAB0DBF7ADACBE749DAD62657A2BD3EB9DD4EFA2B8D28BCCE4A8D4E5B9F0FAE1FFFFF8
FCF7FDFFF7FFFFFDFFFFFFF4DBE7C3CDE2A7C9EA99CCF398C9EC98C7EA98C7EA9AC8EA9D
C9E9A0C8E7A1CDE8A5D2ECABC4DC9EDBF3B5CFE5A7D1E7A7BBD08FB1C685DCF1AEC5D99C
DBEDBBECFDD3F8FFE7EFF8E5747972414141F7F5FAFFFDFFFFFDFFFDF9FAFFFEFDFFFEFD
FDF9F8FCF8F7FCFAFBFFFCFBC6AFA9E7D1C6FFFFEFF2FAE3CAE4C7C4ECC96A996F72A473
B9E8B2C9F2B6C0E4A4CDF1A9CEF1A1C1E58ED1F59BCEF197CCE796D6F1A4CAE49AC2DE93
BBD78DD0EAA1D4E8A3D8E7A4E1EAA9E2E9A6EFF6B38B9651C8DA90D6EEA0C7E696CCEF9D
CDEE9FCDEDA2CBE8A5C7E0A6C8DBAED4E4C0EAF6DEF9FFF3
C6E49CCCEAA0CFEEA0CBEA9AC8E895C7E794C7E698C6E49CC9E6A4CEE7ADCFE8B1CDE4B0
CBE2AECDE4ACCFE7ABCEE8A7CAEA9FC7E79BC8E6A0CEE7A6D3E6AED3E3B2D4DFB4D5E0B6
939E7396A272C5D49DCFE4A3CBE59BCAE793CBEE92C9EC92C9EA99C8EA9DC6EB9DC5EC9B
C5EC99C6EC99C9E99DCCE89DD9EDA8D8E9A58D99598F9E5BBBD189D9F3A9CAE99BC5E896
C9E99DC9E99DC9E99DC9E99DCAE89ECAE89ECCE89ECDE79ECCE39DD6EDA7BED39099AE6B
869957D1E4A4BDCD8EDAEEA9D2EA9CC5E290CAE795CDEC9CC5E494C8E799CFEEA2CCEAA0
D1EEABCCE6A7C8E1A7CCE3ADCFE1B1CFDFB2D6E5BAE6EEC5DED9B3B2B08AF6FFE0F1FFE3
E9FFDCF4FFDD6C7644353404BAB3857E79514A4D2EDCE4CCF6FFEAFCFFEDFFFFECD5DFC4
A1CFAA002400649A68C3ECB4CADFA6B9C186848448585A1BDCE8A8C2DB97C3E49FC1E59D
C4E49BD9F5AAD1E89AD2E79ADEEEA576874061752EDBF0ADDCEFB7C3D4A8FBFFECF6F9EE
FEFCFFFFFCFFFFFCFEFFFFF4D2DCB9D1E5AAC1DE8EC5E88ECAEE96C7EB94C7EA98C9EB9E
C9E8A2C7E6A3CFE8AED7F0B7F5FFD6D3EAB4CCE0ABD5EAB190A469C8DC9DDAEFAED4E8AD
CCDDB0F8FFE4F6FFE9D1DAC96C716BE6E6E8FFFDFFF9F4FBFFFAFFFDF7F9FFFBFBFFFEFB
FFFBF8FFFEFDFFFEFFFFFEFBC4B5B0FFFCF3FFFFF3F3FAEAF2FFF0EEFFF1C0E5C66E9872
699467BAE6B3BDE9ACB9E29ECFF5AACEF3A3D1F39DC8E591D3EA9ABCD287DBF1A8DBF3A9
C8DE96CBDF9ABFCE8D687233515518D2D397D0D293646B28DDEAA4C7DC91D2EEA1BCDD8E
C6E89CC9EBA1CAE9A6C8E4A9CAE2B0D8EDC4F2FFE1F8FFEA
CFEEA0C8E797C6E693CBEB96D0F09BD0F09DCEED9FCEECA2C5E29FC8E5A5CAE6A9CAE7A7
C9E6A3C8E69EC9E89AC8E998C7EC9CC5EA9CC6E69BC8E6A0CCE5A3D0E4A7D3E2A9D4E1A9
505D2592A166DCEEB0D0E5A2CBE59CCDEC9EC9EB97C7EA98C9E99EC8EAA0C6EB9EC5EC9D
C5EC9BC6EC99C9EA99CCE999CCE196C9DB9155651E9CAC65D2E89FC8E396D7F8A9CBEE9E
C6EB9BC6EB9BC8EA9DC8EA9DC9E99DCAE99DCAE99DCCE89ECEE89FD5ECA6CFE6A0405512
DEF3B2D1E4A4D7E9ABC8DD9CCEE7A3C8E69ECFEDA5D0F0A5C5E697C3E694CAEB9ACBEC9B
C8E998C7E69AC7E59BCDE8A3D5EBABD3E7ACCBDEA7C8D2A056522C95966ECFE1B1CEECB6
C3E4ADB4D19B6571410E0F006E6943EFE9C75155343B4223FEFFEAFCFEE9FFFDF3EFF0E2
B6D4B853885E50915BA3DFA3CCF3B4CCDEA09A985D655F23606628CADD9BD5F2AFDDFCB6
C1DC95CFE99FCCE999CBE395CBD892D1DA979EAA68BECE8FCFE0A9D1E0B5F8FFE7FCFFF4
FFFEFFFFFDFFFEFAF9F2F3E5D6DDBBDDEEB7CFE79BC9E78FCCEF95C7EB91C6E995CAEC9F
C9E8A4C6E4A6D0E8B4DBF3C3F5FFDDBED4A6C4D7A9CFE3B083965FD4E8ADCBDFA0C8DBA3
D2E3B7F4FFE4F4FDE8E8F0E3777976FFFEFFF7F4FBFFFDFFFFFCFFFFFDFFFFFCFCFFFEFB
FCF8F5FFFDFAFFFFFDE3DFDCD6CFC9FFFEF6FCF9F2FEFFF8F8FFF9F4FFF8C3DECB81A589
2C5533A6D3A8D1FFCABCEAAABFE8A2C7EC9FC7E696C9E291DCF1A4E1F3A7B9CE835D7129
4C5D1753621F98A263D1D799E9E8AF98965DE5E3A856581997A25ECFE099CDE79DD4F3A7
C6E89BC6EB9EC9EAA3C8E7A4C9E5AAD4ECB8E5FBCCF2FFDC
CEEB97C8E591C7E891CBEC95C5E68FBBDB86BFE08FD0F0A4C7E6A0C9E8A4CCEBA5CEEEA3
CDEE9FCAEC95C9EC8EC9EE91C7EE9DC5EEA2C7EBA1CAEAA1CFEBA1D3EAA2D3E7A0D2E39D
566721BDCE88D4E8A1D1E8A2CCE69FCDEBA5C5E49ECAEBA4C8E9A4C8E9A2C6EAA0C5EB9E
C5EC9BC6EC99C9EB97CCE997D3E899BED1829CAC61D6E89CD7EEA0BDD88BCFF0A1C5EA9A
C5EC9BC5EC99C6EB9BC6EB9BC8EB9BC8EB9BC9EA9BCAE99DCEEDA1C3DF9598B26BD5ECA8
C9DF9EC5DA99C1D596DBF1B3CCE5ABCCE9AFCDEBADCAEBA6C8EAA0C5EA9AC7EA96C7EB93
C6EA92CAEC95CBEB96CCE999CEE89EC3DA92A1B673828F57D6D4ABDCDEB6D9EEB3BDE19B
CCF1ABDAFAB9818E602F310C9F987BE7E2C4DEE0B9535933DCE2C0FFFFECEFE0DDFFF6F5
D8E9D6BFEBC75EA7707FCB8AB9F2ADCCEBA8E3E3A79A905548480CACB677CEE3A0C2DC95
CBE29AD6F1A4CAF09DD3F4A3DAE5A1E6EAADCAD394AEB97DAAB982E0F0C3ECF9DBF8FFF0
F9F9F7F7F5F6FFFEFBF6F7E9F0F7D5C3D29BC8DE93D7F39CCDF094C6EB8EC6EA93CAEC9F
C9E8A5C5E2A8D1E9B9DFF6CAF0FFDEF5FFE3F7FFDFF5FFDAAABC8AD0E3ABCBDFA2D2E5AD
CADAB3F8FFEAFBFFF17B8378797B7AFAF9FEFBF8FFFFFDFFFFFDFFFFFDFDFFFDFAFFFEFA
FAF7F2FEFAF7FAF6F3B9B8B4FFFFFBFEFFFAF7F7F5FEFFFDF3F7F6F6FFFDECFFF7EBFFF8
6F977D7EAD89A5D6A7B9EAB2C3EDADC9EDA7CCE89EDAF0A5CFE195CBDB9097A75E91A25B
D7E6A1DAE6A4C6CF90E9EDB2D2CF98D7D29A908B53545418E2EBAAAAB974A8BF77CFEEA2
CAED9BC7ED98C6EB9BC6E89BC6E69DC9E7A1CFE9A8D2ECAD
CBE491CCE894D4F09CCDE995ADC67590A85A9DB76DC2DC93CDE7A0CDE7A0CDE99FCDE99C
C8E895C5E68FC5E789C6EA90C6EB9DC6ECA1C7EC9FC9EA9BCCE999CDE597C9E092C5DA8D
82964EEFFFBCC4DA92D4EBA5CCE7A0C9E79FC2E297CFF1A7C8E9A2C8E9A4C8E9A2C8EAA0
C9E99DCAE99BCCE997CFE895ADC571768C39CDE390DBF39FC2DB88D5F2A0CAEB9AC2E797
C5EB9EC5EB9EC5EC9DC6EB9BC6EC99C8EB99C9EA9BCAE99DC7E399D2EBA7819757C7DBA0
DBECB6F7FFD4FBFFD8CCDCADCDDFB5D0E5BAC9E1AFC3DFA5CAEAA7CCF0A6C6EB9BC4EA95
C8EE97CAEE97C5E494C4E093D2E9A3D7ECABBCCE929BA571DADCB5E3EAC0C1D69BC5E4A0
CDF1ABC0DEA2606F46030800737158D2D1B2DAE0B4D1D9A84D5327AEAA8DFFFBF4EBE2DD
D3E1CAB2DBB397DEA444944F8BC986BFE7A8E0E9B2DFDCA5E1DFA27B7D3CD8E19ED3DF9D
E7F3B1CFE59DC3E696C4E596D0DB99DADEA1DDE7A87E8C4E54672FCEE2AFE2F3C7ECF7D9
FFFFF6EFEBEAFFFEFBFCF8EDE6E6CC5A613562732D90A852D0EF92C8EA8CC8E893CCEAA0
CAE7A7C6E1AAD1E8BAE1F8CEF5FFE3F5FFE1EEFFD6DFF3C2D4E6B2D0E3ABC8DC9FD0E3AC
D6E6C1F7FFEBF3FFEB353D30F6FBF7FEFFFFFFFEFFFFFEFFFCF7FBFFFEFDFFFBF8FFFEFA
FFFDF9FFFEFAFFFCF8B0ADA8FDFFFAF4F9F3FEFFFFFDFEFFFEFFFFF6FBFEF7FFFFDBF0E7
D4F3E1355C3D2B542A8AB27EC5E8AED4F1B1C8DF9BCFE099D7E59895A65692A758D0E69B
C7D891D6E5A2D8E7A6CFD99CE0E6AACBCC92F2F0B79A9B5FCBD795D3E7A0AAC179C2DD90
CAEA97C8EA96C7E995CAE999CCEB9DCEEA9FCCE89EC9E59B
CFE293D0E394D2E49ADBEAA58A965497A3636872339CA667AAB674D3E09BDBEBA4CCDD96
CFE39BD5EBA2CEE59DC9E59BC8E79BC5E697C7E794CCEC97D2EE99CAE692D5ED9F8EA45C
CDE2A1CEE4A4CDE6A5CCE7A2CBEA9ECBED97C6EB8CC2E78AC8ED9DB9DB91CBE9A3D8F2AB
C5D994DCEDA6CFE195D8EE9B677F27809B3EC4E385C6E88AD2F398C8E992C5E592D0F0A5
CCEFABC8EBA9C2E6A0C3E599C8E99ACEEE9BCEEB9BCDE59BD3E8A7CBDCA5848F64D0D7B5
DBDFC4FFFFECF3F5E0D8DBC6D2D6BFD0D9BECFDAB8CADDB0CBE4ADCDEDAECAEEA8C5EBA0
BEE499CFF0A9C8E5A5CAE2A8D6E6B7D3DEB6CCD1B19DA083DADFBFCFDAB2D6E6B5D7ECB4
C2DAA6CDE4B86C7C5F0006005F694ED2DCB7DEE8B3DAE4A883884E727143FEF7DAFAFAE0
C8E0BCBFEBBAB7F2B236773367A367C6F5BFBCD8A8DAE6B4DFE1A0837F38A09754E5DD9F
DBDAA2D2DCA0D4EEA5CEE89ECCD896D8E3A1D3E49EB7CE8883A0609DBA7AE0FAB3CBDDA3
FFFFECFFF8F5FFFBFAFFFBFAE6DDD6B8B69DA6B0748EA14FD4EB90C6DF83D2EB98DAF1A9
CEE6A8C4DBA5C9DFB0E0F6C8F3FFDCF4FFDCF5FFD6BFD79DD4E9AECAE0A2D8ECAFCCDEAA
D3E3BFEDFBE1E4F0DC2F3A2AFBFFF8FBFFFBF5F9F8FEFFFFFFFFFFF9F8F6FFFCF9FFFEFA
FEF6F3FCF3EEBCB3AC979088FFFFF6FCFFFAFBFFFCFCFFFFFCFFFFFCFFFFF2F7FDE4EEED
D5E3D640523A000A0093A97B8FA36EABBD83CDDD9FD8E7A48B98499BAF5AAFD079C3E58F
D1E99DD0E69DC7E59DC5E39DD0E9A7CDDD9EE3E9AD666F30D0EAA1C9E89CC7E1978FA55A
93A95E81974C7F954AD4EA9FC9DF96DDF5ABC5DD93CDE79D
B9CA7CD0E095F1FEB9C7D19298A065E1E9B0E3E8B0CFD599ADB373757E3B95A05B9FAC66
5A6B25778A48D1E5A6D7EDACD1EDA2CCEC99CBE894C6E28DD2EE99D9F2A1BAD28889A05C
D0E6A8CFE4A9CBE3A7C8E3A0C7E69AC8EA93CAEE8ECAEF90C9EC98CDEDA2CBE59EC1D691
E2F1AED0DD98C7D48C6E8130B0C870B3D074D1F496CBF093CDEF98CCEB9BC6E297CDEAA7
C2E1A6C2E4A8C6E6A5C9E9A0CCEB9DCFEC9ACEE99ACFE59CC5D799FCFFD6858D68FAFEE5
FFFFF1F8F6EAFFFFF6FFFFF4FFFFF1FFFFECFEFFE8F9FFE1F5FFDAEDFFD0D7FAB8C4E9A3
C8EDA8CBEEACC4E0A6CFE3B2E4F0CAFEFFE6FCFBE7FFFFEC97A083ECFBD4F7FFDAF8FFDC
F6FFDEEAFBD963755D33422FA2B097DDEBC7C1CE98DEE8ABDDE3A752521EE4DEBAD6D7B8
D1E2BECBECBDB4E2A497CE8D245F27BBF3C2BFEABDBDDBA9DEEDA8C6C87D675E195B5012
C1B988E8E8B4CBD795D1E29BE0EBA7D2DF9AD6ECA3C3DF95C2E0A087A662BCD985D7EBA4
FFFFE6FFFDF8FFFAFBFFEFF2EFE0E3F1EBDBE1EAB3B1C272B6CB70D0E58AD1E795C3D991
CBDFA2CEE2ADCEE4B3E6FCCBF4FFD8E2FBC4DFF7BDC7DFA1BBD193CBE1A3CCE0A5E4F6C4
DDECCD838F79000500F9FFF4F7FFF6E8EFE8FCFFFDFDFFFEF8F8F8FFFEFFF5F1F0FFFAF7
FFFDFAEFE6DFDDD3CAFFFAEEFEFFF0FCFFF3FCFFFAFCFFFFFAFDFFF9FCFFFBFEFFFCFFFF
D1D9CEA4AD9828361589986DD6E8B6AABD8692A76E91A464BBC97CBED47FBEE58CC5ED95
CFEA9BCFE99FC8EDA0C8EEA3CEEFA8CCE39FCFD597616A29C0DC92C8EA9DD4ECA0C6DB90
CEDF98E4F4ADB4C47DA5B66FD2E69EC2D88FD5EBA2CAE298
9AAD5E84964AD1E09BCFDB9BA7B278A3AC73CDD59CDFE9ADACB67786934E8E9E5791A25B
6579326A7F3CA8BE7DC9E29ED7F3A6B6D381DDF8A9CEE99ABBD387CEE49CE0F5B27A8F4E
D4E8ABD0E6A8CEE4A6CBE4A2CAE59EC8E799C9E996CAEC98CBEE9CC6E798D6F0A7C8DD98
D4E3A0E3EFADA1AE696C7E34D8EF9DCFEC98CEF09ACAED9BC6E69BD2EFACC9E2A8D1EAB3
CBE8B2CAE9B0CBE9ABCAE9A3CAE99BCBE896CDE897D1E79EDBEEAEFCFFD4B0B88FCFD4B6
D2D4BEF0F1DFFFFFF1EFEDDEFAFCE7F7FDE1F3FDDBF1FFD6F2FFD6EDFFCDDBFEBAC8EEA5
C1E59FC0E09DCDE7AADAEEBBE1EEC3FAFFDEFFFFEAFCFEE6BDC6A7F9FFE1F7FFDAF7FFDB
F7FFE1F7FFE8758471546253CBD7C3D1DCBED2DBACDCE3ADC3C6915D5A2FF1EACED3CDB7
DCDCC4CAD8B4C8E9B4C3F3B93973408CCB9CBCF7C9BEF1B9BDE398D5EC9C9DA3597C7839
8A834F908A58A1A163A7AC69D4DB98E0EBA7C2D68ED7F1A8D3F0B0AAC7859AB564CBDF9A
FAFDE2FFF9F7FFF5F8F7E8EDF8ECF0FFFCEDD6E0AB93A6578DA14AD5E992E0F5A6CDE39B
D9EDB0D7ECB3CCE3ADDEF5BFEEFFCED5EEB4C7DFA1CBE3A595AB6DD5E9AECADBA4F9FFDD
F9FFED798174000400FBFFFAF5FBF7FCFFFFF5F9FAFEFFFFFFFEFFFDFBFEF8F4F3FFFEFB
FFFAF6C8C1B9EEE7DDFFFFF1FDFFE9FAFFE9FAFFEFF9FFF5FAFCFBFBFCFFFBFFFFFBFFFF
F9FFF6BDCBB4768969516A40C5E3B1CDEEB7C0E3ABC3E3A4D4E8A0D2E999C6EE98C3ED99
CDE89BCFE79BC8EA9DC7EC9FCDEBA1D8ECA7D6D899777C3ACCE49AD1EDA2CFE39BDDEDA6
DAEBA4CDDE97DBECA5667730BED28ACCE299DDF3AAD5EDA3
D7EC9DC3D88BBCCD8760702F69773CB9C68EF0FBC3C7D296CCDB9AE9FAB4D8E9A2C7DB93
D9EFA7C7DE98A6BF7DB3CE89C5E194CCE796DFF9AFC9E09AC8DD9CE0F4B585995CD3E7AA
D1E3A7CDE1A2CEE2A3D1E7A6CFE8A7CAE4A3C5DF9EC2DF9CC9E99DBADB8CD9F3A9D7ECA7
C8D796B3BF7F9DAC69C1D28CD1E99DCEEA9DC3E398CAEBA4C0DEA0D2EDB8CEE5B9D8EFC5
E9FFD5DCF9C3CDEBADC7E59FC7E396CAE594D0E998D5EBA0D9ECAAC5D49BE4F0C2FEFFE1
E7ECCC86896ED3D5BDF9FBE3FEFFE8FCFFE4E6F5CCD6EAB9D0E9B0D0EEAECAEEA6C3E79D
C8ECA2C9E8A2E9FFC4F5FFD1E5F1C3DAE0BAFFFFE3C2C5A8CCD7B5DFEFC8E7F8CBF8FFDC
EDFFD7F2FFE56D7B6C000A007D8576EEF6DEFFFFDDF5F8CB5E5D31D2CCA8F9EEDCFFFDF1
FFFDEDFDFDE1F5FFDDC1E9B588C29250936766AB7CADECB3BEF2A7C0E693CCE194DBE29F
A19E69918B57A6A2634A4B078F9451D8E39ECCDE94DAF1A9BFD99AD0EAA9ADC675C4D493
AFB199ADA5A3C5B9BDE3D6DDFEF5FAFEFFF1D3E0ABAFC17796A957C6DC89D1E69BCADF9A
C8DE9EC2D79CCAE2A8DAF2B8DCF6B7D2ECABCCE5A4CAE0A0809459DAEDB6D2E2B1F9FFE3
7C8574000500F7FCF8F0F4F3EEF2F3F8F9FDFCFDFFFEFFFFFFFEFFFFFFFFFFFFFDFBF7F4
EBE8E1E0DED2FFFFF3FCFEE8EFF9D4E5F4CDE4EFD1EEF6E1FEFFF8FEFFFBFEFFFDF4F9F3
F9FFF698AA928AA38383A37A4B7243A4D39DC9FAC3C0ECB1CBE4A2CBE59BC1EA9CC2ED9D
CDE99ECEE99CC6E999C4E797C6E297DEEEA7E0DF9E7A7B39D8ECA4D2EAA0CBDA95D6E39E
DCEDA6BED28ACCDD969CB06892A65ED4EAA1C5DB92C7DF95
D2E999D0E799D6ECA4C8DD9CD2E4AACADCA2CCDBA2DCEBB0CEE1A1CFE49FD2E8A0CDE59B
CEE89FD3EEA7BAD7948FAD65CCE999D2ED9CCBE29CC7DB9CDFF2BB5D6D3C6A7B47D2E3AD
D8E7ACCEE1A1CBDE9ED1E5A6D7EAB2D5E9B6D3E5BBD0E8B6CCEAA2C7E696CDE59BD1E5A0
DCEBAA5D692BCBDA99DBEBAACDE49ED2F0AAC6E5A2CFEEB2C0DCABCEE7BFD6E9CBE3F6D8
F2FFE3E3FECBCCE8ADC9E4A1CCE89DD0EB9AD2EB9AD3EA9CC9DD96D5E5A7C9D6A1FEFFDA
FEFFDD515733B0B692FEFFE1FBFFE1F7FFDDE3F7C6CEE5AFC2DEA1C3E49FC5E99FC6EB9E
CDEFA3C9E79FE3FCBAEEFFC7DEEAB8DBE1B5BFBF9BD0D4B1D2E1BACCDEB4F7FFDAF7FFDA
F6FFE0ECFCE185918500040090958EEEF2E1F6FAD92C2C06504C27FFFADEFFFCF3FFFAF5
FFF1EAFFFFECF0FEDAC0E4B6B2E7BD74B78E3D8458B6FBC4B6F3A6C7F7A3C4E393D7E6A1
D5DAA2E1E1ABD9DA9861641D50551297A15CD9E9A0D3E7A0CBE1A3CCE2A2D4EB9DD2E2A3
FFFFECF2ECECFCF3F8FFFCFFFFFDFFFFFFF4D4E2AFD0E49CB2C77AABC073B7CB83DFF4AF
D9EFAEC7DD9DD3ECABC9E4A1D1ECA7CBE6A1D6EFABCEE4A48EA169CADCAAD3E2B9FBFFEA
030801D6D7DBF5F6FAFEFFFFFEFEFFFFFEFFF3F2FAFFFEFFF4F3F9FFFFFFF8F8F6A8A8A0
DCDCD0FFFFF1FFFFEFFDFFE5D4E4B3CDE0A9CEDDB2DDE8C8F2FAE5FEFFF4FEFFF8FCFFF8
E9F4E499AB958BA889B9DFB85A895B3C7443BAF8C5ACE3ACC4E6AAC7E6A3BEECA3C1EFA4
CEECA2D0EAA0C8EB99C7E897C5E08FD8E69BDDDA955C5916D0E099CAE098DBE6A4DBE6A4
DCEDA7D3E9A0D1E59DCAE097CAE097899F56D8EEA5CDE39A
D0E998D0EB9EC0D791D0E6A6F7FFD1F7FFD3D4E7AFC7DB9EDBF1B0C4DB95CCE69DD5F1A6
C8E49ACFEDA3D6F5AFBDDB91B0CD7BCCE594D0E5A2C7DAA3DDECC1727E58C3CFA7F5FFD4
EFFCC4DBEBACCFDFA0D5E7ABE3F3C2ECFCD7F2FFE7F4FFE5DCF9B7CFEEA0CCE39BD2E6A1
C8D698909C5ED8E6A8D1E4A2CBE4A0D2EFACC7E5A5CDECB3C7E2B5D0E8C6E7F9E1F3FFEB
F3FFE3DDF5C5CBE4ABCFE8A7D5EFA5D3EB9DC8DF8FC1D888CFE39BE5F8B6CAD99ECBD8A3
B0BC8AADB687D3DCADD2DEB0C9DBABCDE1AECEE5ADC8E4A7C5E4A0C8EAA0C8ED9FCAED9D
C5E697C1E094CEE59FDBEEAED6E1A9E2E9B64E4F23E3E8BFCFE0B3C3D9A8D3EAB4BFD3A0
D3E5BBCBDABD76817303090573766FFFFFF3FFFFE39C9976585333FFFBE1FFF8F0FFFBF8
FFFAF6FFFFEFF9FFE4CDECC3B8E7C394D0AC43835E72B280AEE7A0C5F4A3C7EA9AD3EAA2
CFDEA3D3DEA2E4F1A9C8D4885E682158641C94A257CDDE98D7E9ADD7EBAED2E79CD7E5A8
FFFFEDFFFCFDFFFDFFF9F7FCFDFCFFF9FFF3D2E2B1D6ECA4CDE39A9BB16894A964CCE39D
CDE4A0C0D995D9F4ADC1DD93D0ECA1C3DD93D3EAA4D6ECACB1C48DB5C69AD0DEBBFBFFEF
00010068676DFBFAFFF9F8FFFFFDFFFFFDFFF4F1FAFFFEFFFFFEFFCFCFCFD3D4CEBABCAF
E5E9D8FEFFECDDE3C9EEFAD2CAE3A2CBE6A1D0E5ACD3E3B6DBE4C5E9EED8FCFDEFFFFFF4
FCFFF3BFCEB9849E81B5DBB6B9E9C15B966A70B284A5E0B0C6EDB8C6ECAFBBF0ACBBEFA5
C6E7A0C8E79BC7EA98C8EC95CDE693D7E495E4E0995D5A15D2E29BCCE099E3EDAED7E2A0
CBDF98CDE59BE1F7AEBDD38AEEFFBB6C8239B5CB82DDF3AA
C1DC8DD2EEA1D3EDA6CFE8A7DFF7BDE0F7BFDFF6BEDCF4B8C9E3A2CCE7A2C5E399C7E79B
CFEFA3C5E59AC1E29BD3F3A885A14D455E0DB2C687D8EABA576542FBFFEAF9FFE3FCFFDF
FEFFD4E2F0B3CFDD9FD8E5ADECF9CEF8FFEBF9FFFBF7FFF3E6FFC6CCE89ED0E7A1D2E5A3
8B995BE4F2B4CCDC9DD3E8A5C9E29ECAE9A3C1E19ECAE9AEDCF8C8DFF5D1F7FFEDF7FFED
F1FFE0DBF0C5CDE4B0D1E7A9D0E79FC1D88AACC373A1B868B6CB80B0C47FDFF2B2D7E6AB
94A36ADDEAB2D4E1A9D0E2A8C7DFA5CBE4AACDEAAACCEBA7CBEDA3CAEC9FC6E999C0E391
CDEC9CCDE99CD5EBA2DBECA8DAE6A8D8E0A74D511ED9E1AED0E5ADCBE7ACCCE6A7BED69C
DCF0BFD5E5C16B73640002007B7C74EAE8D9E8E7C9E3E1BB54502DDED7BDFFFCF3FFF8F4
FEF7EFEDF1E0F7FFE6DAF8D2D4FDDFB6E4C884B59854845AC9F6B5B9E294C3E495D6F2A8
C9E1A3BDD796CAE99BD6F29EA3B3686571275F6D22A9B873C9D89FE4F3B8C6D68DD4DFA3
FBFEEBFDFDFFFFFEFFF8F9FEFCFFFFF9FFF6CCE0ADCEE59FDCF1ACB7CC87889D5A8FA660
889F598FA960CDE99CD3F0A0CFEA99CCE798CBE399D6ECABCCDEAAB8C7A0DDE8CAFCFFF3
E5E5E515121B69666FFFFDFFF1EEF7FBF8FFFFFDFFFFFEFFFFFEFFC4C5BFE4E6D9FEFFEF
FCFFEAF6FFE0CEDAB6DAECBACAEA9ECCEF9BD1ECA7D1E6AED5E0B8E1E5CAF7F6E4FFFFF3
FFFFF3E5EEDB91A58CCFEECFC0ECC9BDF1CD0F4B274A825BBAE5B7BCE8B3B4F0B0B6EFAA
BFE7A0C3E599C2E996C6EC95D0EC97D6E594EBE99F7F7C37D9EAA3D0E69EDBE7A7CEDA9A
CFE59DD4EEA4CCE49AD9F1A7B7CF85B0C87E657B32A3B970
D3F0A0C7E398CDE8A3C4DE9FCEE7AECEE7B0EDFFCFDEFABFC3E0A0CEEDA7C8E89DC4E498
CCEEA1C9EB9FC3E59BCDEDA1AECA7588A150A7BB7ECADBAFADB79CEFF8E3FEFFECF6FDDC
FAFFD4DDE8B0C9D49AD5DFABEAF4D1F4FDECF7FCFFF5FFF8DCF2C1CEE9A4C7DD9CBDD090
6B793CCEDC9ED8E8A7CCE39DCEEAA0CAEA9FC4E59ED0F0AFF1FFD8EDFFDAF7FFE8EEFDE0
F8FFE8E4F4CFD4E6B6CEE2A7C2D794A8BE7390A757859C4C8EA35897AB6490A45F94A765
A1B474CEE19FD5E8A6D2E7A4CEE8A7CAE9A6C5E4A0C2E49AC6E89CCCEF9FCBEE9CC7E995
CEEB99CBE697D3E99ECCDD97D0DC9AB8C285A6AB71CCD79DCAE3A2C7E6A2D1EFA9D4EDAB
CBE0A8D1E0B76D7560000200646458DDDAC7D2D2B0F9F7CE5E5A34F2EDCDFFF6E5FFFEF4
FFFFF4F9FFEFE9FDDAF0FFE6E4FFEBC3E9D088B096375F3ABDE5A6D1F7AACDEFA2BCDC91
CEEEADD2F5B1BDE491C9ED96D7EC9D94A25787954A75823DBEC991CBD69ED6E19CDCE5AC
FFFFF1FAFBFDFCFFFFF3F8FCF9FFFFF8FFF6C8DCA7D3EDA6C5DC98E5FCB8C5DC98ACC67F
92AC638AA45AC1DE8ED1EE9AC9E590DEFAA6CAE296D0E5A4D5E5B4CAD8B4F1FBE2F8FEF2
FFFFFF37343B010005FBF8FFFAF5FCFFFDFFFFFDFFFCF8F9C1BDBAF1F1E7FCFFECFAFFE8
FAFFE3F9FFDFCFDFB2CFE7ABC1E993BFEA8EC5E79ACFE7A9E0EDC1F1F6D8FFFCE9FFFFF1
FFFBEFFEFFF1F3FFEBD2E5CFE1FFE7BFE7CC6FA0832F6241A8D7ADAEE2B1B0F2B5B5F6B2
C1EEA9C5EBA0C3EF9AC8F098CEEC96CCDE8CDDDD938A8C43CDE199CAE49DD1E4A2D4E4A3
D4EBA3C5DF95C8E298DAF4AAD5EDA3C9E19792A85F566C23
D0ED9DC7E398D1ECA7BCD697D3EFB5C6E1ACF2FFD8E0FDC3C1DFA1C7E8A3CFF1A7C2E498
C4E699CAEC9FC2E498D0F1A2C8E48FD3EC9BD4E8ABD0E1B7D4DEC6FBFFF3FDFFF0FEFFEA
FEFFDEDEE6B7D3DBA8D4DDB0EAF0D4FCFFF6F8FBFFF9FFFFE2F8CAD6EFAECDE1A4D1E3A7
909E61D6E6A7CADE97D3EB9FCDEA9AC9EB97C7EA9AD1F3A9DFFDBDDCF4C0DDEEC4EAF8D5
F9FFE8EFFDDCE1F0C5DDEEB8B7C98BAEC27BC3D88DCFE497D7EDA2C6DC939FB56DC9DE99
CFE59DD1E79FD0E69BCAE49ABFDF96C7E8A1CBEDA3C8EA9EC8EA9DCCEF9FCDEE9DC9E996
D2EF9DC3DB8DD6ECA1D1E29BE6F5B05F6B29D0DA9BD4E3A2CFEAA3C7E99CC8E797CFEBA0
D1E7A7D3E3B4666F540003006D6C5AE1DFC6DBDCB28C8E5C90905EE7E5BCF0EFD3FDFCE8
F3F8E4F7FFEADAEFC8D7F2C9E6FFE6CFF1D8789C82719770BDE5A6C2EB9DC4EB9CC3E79D
C4E9A6C9EEA9C5EF9BC1E790D4EB9BCFDF94D7E598A2AD686C733DACB37DDEE8A3D6DEA5
FEFFF1FCFFFFF7FCFFF6FFFFF6FFFFF7FFF4CBE2AAD0EAA1CDE4A0D0E6A5CEE5A1CEE8A1
C6E097CBE79A8EAB59CBE993D1ED96CBE792D1E99DCDE1A2D6E6B7A1AC8AFCFFEFF8FBF2
FEFEFCF6F4F7837E82B9B4B8FFF9FDFEF8FAFFFDFDAEABA6ECE9E0FEFFEFFFFFEAFAFFE2
F6FFDAF9FFDAD3E5B1C5E29FC1ED94B7E688C5EC9DD2EFAFFBFFDCFFFFE6FFFFEDFFF6EA
FFFAF1FFFEF3FFFDF0919888F5FFF2E3FAE8B6D5C3ABD1B852805B74AE7EA4EBB1AAEFAE
B6E7A5C2ECA2CBF8A5B3DD87D1F39CCDE08EDFE397565C12C4DE94C5E59CD3ECA8CDE4A0
CFEBA1CBE79CC8E499CCE89DD1EBA1CDE79DC3DB91B7CF85
C6E192D0EAA0DEF7B5C6E0A3C6DFA8C6E1ACF0FFD8D7F4BCCCEAAECAEAA7CEF0A6C5E79B
CAEC9FD1F1A5C4E498CCEB9DC9E590D2EA9CD2E8AACFE0B6D1DDC5FBFFF4FBFFF3FEFFEF
F9FEE0DFE5BFD9E0B7DAE0BCEAEFD8FCFFF6F5F8FFFAFFFCE4F6CCC3DB9DDCF0B5CBDDA1
93A164D8E8A7DDF1A9CBE695CCED96C8EC92C1E790C8EB99D0EFA9CFE9ACD6E8B6EBF7D1
FBFFEAF1FADFFCFFE1BFCC9ED6E5ACD9ECAACADE96D3E89DD2E89FD4EAA2BBD189D4EBA3
D0E89ED1EC9FD1EC9BCBE898CCEEA1C9EEA1C5EA9DC1E698C4E797C7E899C8E797C8E593
C4DF90E0F8AAC9DF94C9DE93A2B36C9FAE69E2F1ACD8ECA5C8E99AC3E994C5E790CCE997
CCE39FCDDEA8646B4A010300606048DBDBB98B8F5C62682CC1C78BE0E7B1D3D8B0ECF1D1
FEFFE8CCD7B5D4E5B8C7E1B2CCEBC9D8FCE0779E8187B287C8F6B5C5F4A4C5F2A1C6EFA3
C1E6A3BDE09CC7EA98D7F7A2CBE493DBEDA1D3E194C3CE89B5BA84939862D1D693E1E9B0
FDFFF0FBFFFFF4FEFFF6FFFFF4FFFFF5FFF1CBE3A7CEE89ED0E7A1CFE6A2CAE39FD0EAA3
CAE69CCDE99C8BA854C7E58FCDE992C8E48FCEE499DBEDAFCCD9ABA4AF8FF6FDEBFEFFF8
FDFEF9FBFAF8F0EFED797574FFFDFDFFFCFCF4EFEB86817BFFFFF3FFFFEDF2F6DBEBF5D2
E4F1C6E2F4C2C7DAA3D4F1AECCF8A1C0F196C7EDA0C2DEA1DBEAC1E7EACFFFFBECFFFCF3
FFF4EDFFFBF4FFFCF2888478FDFFF3F0FBEDDAE8DBD0ECD662906C5694635EA76FADF3B4
C8F9B8B8E19BBBE798D8FFB0D0F29ECBE18FDDE399666E25CDECA0CCF2A7CAE9A3C2E09A
CAE89EC6E599C7E398CAE69BD0EAA0D0EAA0CCE49AC6DE94
D1E99DC4DC92C6DC9BD1E9ADD0E8B4DEF9C6F2FFDCDCF9C3C5E3A7C0DF9CC9E9A0C5E59A
C6E69ACCEB9DC2E193CCE999C9E791CFEA9BCFE5A7CDDEB2D0DDC3FBFFF4FAFFF4FEFFF4
FCFFECEBEFD6ECF1D3EBEFD4F4F9E5FEFFF6F9FDFCFBFFF6E1F4C7C5DA9FD9EDB293A569
556325CCDD99E0F7A9B9D581C9EA8FC9EE8FC3EA8FC4E891C8E69CC7E09FD1E2AEE7F3CB
FEFFECFEFFEDE0E7C8B2BD93DDEAB5C8D89AD0E49FD5E9A2C7DD95D7ECA7CDE49ED5EFA6
CAE49ACBE898CEEB97C8E895CDF2A2C6ED9EC3E89AC5EA9CCAED9DCBEC9DCEEA9DD0EB9C
C9E195B2C87D899F54BDD38892A65EC6DA92CFE39BC8E094C8EB97C5ED94C8EC92CDEE97
CEE59DD0E1AA6B734E090C00808162797B53636B30949F5ADEEBA5CFDE9DCCDAA5DFEABF
F6FAD5C4C9A0DDEBB6CDE5B1B8D8AFCBF5D182B18D8BC392ACE8A0AEE995B6EC98C3EFA2
CDF0AED1EBAACFE59ACCE290CDE695DCF3A3CFE092DBE6A1C9CE98676A35D3D693DADFA7
FEFFEFF9FFFFF5FFFFF5FFFFF3FFFCF5FFECCEE7A5CFE897D2ECA3CCE69FC8E29BD4EEA7
CEEAA0CDE99C89A654C7E58FCDE994CBE793D8EEA5CDDFA1CEDBADCFD8B9FEFFEFFBFEF3
FEFFF8F7F8F2FFFFFB817D7A201B18B3AEAAFFFDFAF5F1E87C786CFFFFEDE6E9CED8DFBD
DAE7BCC6D8A6D1E4ADD2EFAFC2ED9DBBE897C6EBA6C4DFAADDEBC7E7E9D4FFFAEFFFFBF6
FFFAF6FFFAF6FFFBF4BAB0A6FFFEF2FFFFF4FDFFF4EAFBE8BEE8C44883530F561EADF1B4
ACD99ECDF1B1B6DE97B5DB90C5E498C7D98FD9DC976E7831C8E89DC8F3A4C5E99FCDEFA5
C9E99EC7E79BC6E599C7E69ACCE89DCFEBA0D0EAA0D0EAA0
E0F5AAD9EDA6CBE09FD8EDB4CAE1ADEDFFD5F4FFDCC7E2AFCEEAB0C5E2A2D2F0AAD0EFA3
CAE699CBE79AC8E396D2ED9ECBE894CDEA9ACBE4A3CCE0AFD0DFC0F9FFF1F9FFF5FEFFFA
FEFFF6F9FBEEFFFFF1FBFFECFDFFF0FEFFF3F8FEF2FBFFEDE6FAC9D4EAACD1E5A8839557
4B5B1ACDDE98D6ED9FCCEA94C3E68AC8F090C8EF94C9EC98CBE9A1C9E1A5D3E3B2EAF4D1
F4F7E4E0E3D2E0E4CB838B66D0D9AAE1EEB6DFEFB1C4D795CDE29FD0E7A3CBE4A0CEE9A2
C9E59AC6E595C8E895CAEC98C7EC9CC2E99AC5EA9CCEF0A3CFEFA3CBEA9ECDE79DD2EAA0
DCF2A98399508FA55CCDE39ACCE49AD1E99FCDE59BC8E497C6EC97C6EE95CBEF95D0F19A
D1E8A0D4E6AC727A551217007D816032380A9DA768DBEBA0D3E997CCE297D3E9A9D6E9B2
D6DEADDAE1ADD7E7A8D3EBADC2E2B1BFE8BE8BBE9578B17CBAF8ADC2FFAAC1F8A4BAE699
C3E1A1D6EAABDCE9A1D0DE8FD1EC9BCCE796CFE293DDE8A49EA06E51511DE7EAA7D1D69E
FEFFEFF9FFFDF5FFFDF4FFFBF0FFF6F5FFE8D2E9A3D0E995D2EDA0CBE59CC8E299D3EFA5
CDE99FCAE6998AA757CDEA96D0EC98C8E190E2F8B0C4D69AD7E4B6DDE7C5FEFFEFFCFFF2
FEFFF6FEFFF8FAFBF5FFFFFA86837E100B07FEF6F3FFFCF68C857BFFFFF1FBFDE7F6FDDE
E4F0CACCDCAFCBDDADC0D9A0C4E8A2BCE19BC9E8ADD1E6BBF4FEE3FCFDEFFFFEF8FFF7F6
FFFAFAFBE9E7FFFBF4F8EBE2FFF8EBFFFFF3FFFFF3E3EFDBCEF2CEA7DDAC7DBE86478248
CAF1BACBE8AED1F1B2D8F7B4D4EBA7DCE9A4EDEDAD888F4CCCECA1C5F0A1BBE194CCF1A4
CBEB9FCBEB9FCBEA9EC9E89CCAE69BCBE79CCDE99ECFEBA0
A9B970D2E19CD4E4A5D6E7B0C0D2A2F6FFDCF5FFDDD4ECBCE3FCC3C6E0A1CCE7A2CFEBA0
CAE598CEE698CAE193CBE395CCE995CAE999C9E49FCBE2ACD3E3BEF9FFEDF8FFF3FCFFFB
FEFFFFFBFDFAFEFFFBFEFFF8FCFFF1FBFFEEECF4DCEBF7D3D9ECB4C9DF9ECFE4A398AB69
98A965CADE96C2DB8ADBF9A3C4E78DC9F095C7ED96C5EA9CCCE9A9D0E7B3DEEDC6F7FDE3
FFFFF3E2E2D65B5D48F0F5D5D3DCB1E2EFBAE2F1B8EFFFC5E9FDBED0E6A6C8E19FCBE6A1
CFEDA3C7E899C6E796CFF29EC6EB9BC5EC9DC8EDA0CBEDA1C8E69CC5E197C9E098CFE59D
D1E79F8DA35BD0E79FD1E8A0D9F3AAC9E39AD8F4A9CAEB9CC2E998C1EB95C5EC93CCEC99
CBE29CCEDFA86B72500B1000383E1C707849DBEAA5D1E795CCE68FD3F09CCCECA3C8E5A3
CADE9FD8E8A7C4DA8FC5E099D1F0B7C3E9B87DA87B7BAE76ADE699BCF49DC7F9A4C5EEA2
C6E3A3CEE0A4D9E49FD8E99BCCE999C5E494CDE496DAE7A29494625A5825D9DA98DCDFA6
FEFFEDF7FFF9F5FFFAF2FFF8E5F8E5EAFFD8D1E79CCFE88DD0E998CCE79AC9E59AD1EDA3
C8E49AC5E4988CA85BD3F0A0CDE899C5DD91D5EAA5D2E4A8CFDCAEDCE6C4ECF1DBFEFFF3
FCFFF6ECF2E8FEFFFAF5F6F1FDF9F6FFFAF7372F2DFBF3F1F6EFE9E0DCD1FEFCEDFFFFEC
E8F1D2E5F3CFCCDCB5D2E8B9D1ECB5CBE6AFD8EDC2DCEBCCF9FFF0FBFCF6FFFEFDFFFAFB
FFFCFBFEF3EFFFFDF4DED6C9FFFFEEFEFDEBFFFFEEE2ECD3C8E4BCC2EEBDA2D9A2164710
779360C9DBA9D1E8B0BFD29AD0DEA3D3D99DE2DCA2828445CDEBA1C9F4A5BCE394C8ED9F
C9E99DCBEB9FCCECA0CAEA9EC8E79BC7E69AC7E69AC9E89C
919D559BA8639DAB6DD1E0A9DCECBDF3FFD8F7FFDFF5FFDCF5FFD6C4DC9EC3DC98CFE79D
D1E99DDBF2A4D6EB9ED0E799CBEB98C9EA99C7E59DCEE7ADD6E9BCF8FFEAF5FFF2FBFFFF
FCFFFFFCFCFFFEFFFFFEFFFDFAFFF1FAFFE8E3EDCADBE8BACDE1A2CFE49FD9EDA893A762
CDDE98CFE499CBE395C8E591C9ED95C9EF98C1E899BEE29CCDE8B3DBF0C7EEF8DDFEFFF3
FFFFF8EEEBE2D4D2C3B9BCA1C0C6A0E0E9BAFCFFD4F6FFCEF8FFD1CDE5A7C8E2A3C4E19F
D1F0AAC5E79AC1E492CBF19EC5EA9CC8ED9FC9EB9FC5E59AC7E29BCDE7A0D5EAA7D7ECA9
CFE4A1A0B572D9F0AAC7E19AC6E19AC1DF95CDEBA1C7E99CC4ED9EC3ED9BC5EB96CAEB9C
CAE09FCADBA7646B4A0105001E2402BBC495DAEBA5CAE28ED2F096BFE38BCFF5A8C1E79E
C8EDA0C0E190D0F29BC0E190CBE9A9C5E3AF6483579CC18DC8F2A8BDE896BEE896CDF1A7
D5F1B4D0E6A8CFE099D0E797C5E896D1F4A2CCE496DBE8A3BDBD8B5E5B28A0A15FDBDEA5
FCFFEAF2FEF4F4FFF8F2FFF4D5E8D2DBF0C5CDE391CFE789CDE692CDE899CAE699CEEA9F
C3E197C8E69C8DA95ECDE99CC6E194D9F1A7C3D895D2E1A8C6D2A4FEFFE3FEFFEBFEFFF3
FBFFF6FBFFFAFBFFFAFFFFFDFBF9FAFFFDFFDDD4D7291E22797071FBF6F2FFFFF6FFFFF3
F3FBE4F1FBE0F9FFE8F1FFDDC6D8AED3E4BAEFFCDEF2FBE8FCFFFAF5F7F6FFFEFFFFFEFF
FCF8F7FFFFFAFFFFF39B9C8AFFFFEDFCFFE9FFFFECFBFFE8EFFFDCCAECBAC7F3BEB8E0AB
000A005C6538869262C0CA98E8ECBAD9D6A3D8CC9867652AC2DD96C7F0A1C4E999CBEE9E
C5E599C7E79BCAEA9ECAEA9ECAE99DC9E89CC8E79BC8E79B
CCD68FA4AF6B859054C1CE99E5F5C8D8E9BFD8EAC0F5FFDCF5FFD6D0E8ACD3E9A8D7EDA5
C7DC91CBDD91D2E498D5EC9ECCEB9BC8E99AC8E69CD1EBACDAEEBDF8FFE6F5FFF0FBFFFF
FCFEFFFAFCFFFCFEFFFBFFFFFCFFF3FCFFE6E1EEC0D2E4AAD6EBA6CBE196B5C981A5B66F
D6E7A0DEF3A8DAF2A4CAE795C9EC98C9EE9EC1E79EC4E6AADAF3C9EAFDE1F8FFF1FEFFFA
FFFEFBFFFFF8FDFBEEDADCC4CAD0ACBDC699DFEBB9E5F6C0E7FAC3C7DFA5D0E9AFBFDC9C
CDECA8C5E79BC1E494C8EE9BC2E799C9EEA1CAECA2C4E49BCBE6A1D6EFABD4E9A8C7DA9A
CADD9DA9BE7DCFE6A2CFE9A2CDEBA3CDEDA2C9EB9FCAEFA2C7F0A4C4EDA1C6EB9DCCECA1
CFE5A7D0E0B1676E4F0004002E3514CCD8A8CADE97D3EF9AD3F698B6DD82CCF7A7BFF09F
BCF49BB2EA89D5FFA1C4EB90C7E29FCFE1AD68754A768453CBDF9AD2EA9CD0EC9FC6E69D
C3E1A3C9E7A9CDEDA2CAED9BC3ED99D0F7A4CAE596D8E7A2DBDDAB5A57249C9B5AD9DAA0
FDFFE9F2FEF2F4FFF6F0FFF1C9DDC4D2E5B7CDE18CD1E987CDE78ECFEC98CAE797CAE699
C5E399CFEDA38CA85EBCD88DC8E298DDF4ACC9DE9DC8D79ECDD9ABF6FDDBFCFFE7F8FCEB
FBFFF8F7FFFBF5FAF6F0F2F1FFFEFFFAF3FAFFFBFFACA1A9261B23EEE5E8FCF7F4FFFFF8
FEFFF4F7FFEDF9FFEFF5FFE8D0DBBBDFE8C9FEFFEFFEFFF6FEFFFFF8F9FEFEFEFFFDFEFF
FCFFFFFCFFFAE1EAD997A189F8FFE9EFFCE0F9FFEAF3FFE1F7FFDDCCE7B4B8DDA9C1DFAD
222900060400393A128A8B61DDDAAFE1D6A9F6E4B4746D36CDE49EC2E799C5E896C5E695
C7E899C7E79BC7E79BC8E89CC9E99DC9E99DC9E99DC8E89C
DAEBA4CFE09A9CAF6F9FB177C4D4A3CEDFB3DFEFC8F8FFE1F1FFD5CDE0A9D6EBAAC6DA92
91A65982974A95A961ACC279CCEB9BC7EA9AC7E79CD3EDACDAF0BFF8FFE4F5FFEFFBFFFF
FCFEFFF6F8FFFCFEFFF7FAFFFCFFF8FCFFECE0ECC6CEDCA9CCDEA290A05F5A6928CCDB98
D3E29FD6E7A1BFD38BDBF3A9C9E59ACBEAA4C9E9AAD4F0BDECFFE0F5FFEFF8FFF8FBFFFA
F5F7EAF9FBE6FFFFE8FFFFE3F0F7CEEEF7C88E9A68B9C792D3E4AEC5DAA1DCF4BAC3DDA0
CCEBA8CAEBA4C8EAA0CBF0A3C3E89BCCF1A4CDEDA2C6E49CCCE7A0D1EAA6BBD28E99AE6D
93A867A5BC78DBF4B0CBE69FC9E79FCAECA0CBEDA1C1E79AC2EB9FC1E79AC3E696CCEAA0
D0E8AAD4E4B5697253020700282F10D7E3B5D6EAA5C2DB87D1EF95CFF39BBBE092C3EFA0
BBF496BBF591BAE989C1E38DD6E7A3E9F0BA797F4F06100005190078914FD4EDABD3ECAA
C1D99BCFE9A8D2F4A8BEE594C4EF9DC1E897C6E597D3E7A0DBE3AA5C5F2AD1D296E3E6B1
FEFFEAF7FFF4F7FFF4F4FFF0C5D8BCCFE0B3CCE192D6ED92CCE893D1EC9BCAE596CBE399
CDE49CDBF2AC8EA45CB1C77FD6ECA4C4D994DCEFAFD2E1A6DAE4B080875DC2C6A3FFFFE8
FCFFEDFCFFF4FEFFF8FAF9F5FFFDFFFFFBFFF4E8F2FFFAFF96899044393DAAA2A0FFFEF8
F9F9EFFFFFF4E9EFE1FEFFF1FFFFECFCFEE8FFFFF3F4F7F0FCFFFFF7FAFFFCFFFFFCFFFF
FCFFFDD5DBCFB1BAA5C1CEB2C6D6B2D4E9C2D5EBC4C7DEB0C8DAA6D2E3ACD3E6AFD3E1AE
2B2C021210007175527177534C5129868255E9D3A283743BE3F0ABC6E49CC5EBA2C1E9A0
CAEEA4C9EB9FC6E89CC6E89CC7E99DC8EA9EC8EA9EC6E89C
C3E89BC2E498CFEFA44D6B25455D21D6E9BBD8E6C3F5FFE2FBFFE3D6E3B5CFDFA0CFE499
546B1BCAE29694AB6785A05BBDDE8FD6F9A9C7E79ECDE7A8DEF4C5F8FFE6F7FFEFF8FFF7
FCFFFFFEFEFFFEFEFFFEFFFFFBFFFEFBFFFAF9FFF4F9FFEAC9D0AEA4AB7F4A5022A1A875
FFFFD1FFFFCFD9E4A8CDDB9DDCEEB0CADEA3F7FFD8F5FFDFEAFFDEF4FFEFBFD2BFD6E8D0
D2E1B8D1DFACCEDBA6DFECB7D2DCA7D4DFA7949F6748531BD2DFA7DAE9B0C4D69CDCF1B6
C6E0A3F2FFD1EBFFCAD1F1AEBDE197D0F5A7C8E89CBCDC91D7F5ABC6E298829C53567027
90AA61C5DF96D5F1A7CBE99FCFEFA4C6E89BBCDE91C9EEA0C6ED9CC4EA97C6E892CFEE9E
CBE4A0D1E3AF687351050B00202706D4DDB0E1EDABD2E395C8DE8BC7DE8ED5ECA8CEECA4
B6DE86D8FFA7BEDD91D3E4A0EFEFB1DAD89D9CA46997AC7400120089B584436332DBEDB9
D1D99DD4DD9AD4EBA5C6E89EC5EB9EC4EA9DCAEC9FCAE69CCCE1A097A56AD4DDA8D6DDB4
FAFEE7FEFFF4EEF6E7F9FFF1CDDABCD5E6B9C4D996D5EDA1C5DF95DCF4AAC9DD96D8E9A3
D0DC9ADCE7A5A6AF6E4E5917DCE8A6D8E7A4CFDE9DD1DD9DDBE5A8D7DFA6C8CB96B8BA89
FFFFD8FFFFE1FFFFEAFDF5EAFFF7F7FFFAFFFFF5FFFFF9FFC0B0B18475700A0000F6ECE0
F7EFE2FFFEF4FFFEF6FFFEF5FFFFF1FFFFF1F6FAECFBFFFAF6FFFDF4FEFDF7FDFBF7FCF6
FCFCF2A7A694CED1B4DDE5C0CEDFB2C6E1ACC2E8ADC7EBABCEE5A1DEE9A5ECE6A8595017
575725737B52607053C4DBBECEE8C14F5829E7D1989F8344DBD694C8DC9DCBFAC4B5ECB5
C4F1B0BFE7A0C9F1AABCE49DC5EAA4D6FBB5C2E6A0BDE19B
CFF5AAC7EC9FC5E697C1DD93BFD597D2E2B3C8D1B4FEFFECFFFFE6C5CCA2EAF6B8ADBF73
D1E697DAF2A6CAE3A290AA69D9F9ADC2E394C6E19CD0E8AEE3F4C7F6FFE3FCFFF1F8FBF2
F7F7F5FCFBFFFFFEFFFFFEFFFCFBFFFAFBFFFEFFFFFEFFFBECEADBDCDAC3FFFFE6DAD9BA
8B8B67CCCDA5DCDFB4D9DFB1C6CDA1DBE3BAFBFFE1F4FFE1F7FFEDF5FFF3C1D3C3CEE0C8
DBECC0D3E4AED5E3AECDDAA5D1DBA9DCE4B3C9D09D8F9663E1E7B7BEC695E6F2C0D2E3AF
B8CA96F5FFD6F2FFD6BCDA9ECCEBA5CDEDA1C8E79BCDE99ED5F1A6C0DA9098B268BED88E
C9E197D1EBA1C4DE94BBD78CCCE89DD2F1A5CAEA9ECCEF9FCFF2A0BEE18DC7E792D3F09E
C7DE9AD3E4B06E7856000500383D1FCAD1A7D0DA9BD9E79AE4F2A3D9E99ED2E2A3C4D795
DDF4A2CBE290D1E1A2C6CE95D3CA91CCC2879B9C60D1E2ACC6EFC526522FBAD8B2809063
AEAC717F7B3BCED796DBF0ADCDE8A1C8E69CC9E59ACDE59BD5E6A29BA66AD2D5A6E4E4C2
FFFFEBFFFFF1FFFFF0FEFDE8D1D5B4DDE6B7D6E1A5D0E19DD8EDA8C8DD98D6E7A3D7E3A1
D5DB9BDBE0A0C8CD8D9BA161D1DC9AC9D593E2EEACE2EEACCFDA98DBE4A3E1E7A7D0D497
575721B9B68BEBE4C7FFFEEDFFFBF8FEEDF3FFF9FFFFF3F7D1BFBDFFF2EAF2E4D7221505
92867AF9EFE5FFFCF8FEF0EDFFFBF4FFFBF4FCF3EAFFFFF4FAFAF0FFFFF6FFFEF4EBDED5
A79589FFEFE1FFF6DEF1E4C4D1D0A4E7F1BCD2EBAAC4DD99D3E4A0D3D492F1DD9E755C23
4F4311A1A37C4B6245ABCCAFC4DFBE30390E79622C75551AFEEAAFD5D8A3D0F9CFACDFB6
C0E3ADCCE8ADC4E0A593AF7496AF75C3DCA2BED69CAAC288
CEE9A4C8E29BD7EDA4D0E49D919F6452592DFFFFE8F7F6E1F9F8DCEEF0C8C3CB8F616F24
D2E395CEE398CDE1A2D3E9AB39530ACEE89FDDF3B3CCDFA8E9F6CBF9FFE3FFFFF1FFFFF8
FFFEFDFFFCFFFFFCFFFFFDFFFFFDFFFFFEFFFEFCFFFCF8F9FAF5F1FFFEF8FFFDF4FAF2E7
FFFFEFACA59345402CFAF5DFFFFFEAF4F3DEFFFFEFFDFFF2EAF2E5F2FCF3F8FFFDF8FFF8
F5FFE7F5FEE1FEFFE8FFFFE8FFFFE6F8F8DCD5D4B6828162FFFFE1FFFFDFFCFFDBFEFFDD
FCFFDDCFDEB3D7EABDD5ECB6D1EAA6B5CF85CDE79DDCF4AABFD58CDCF0A8C4D890D8ECA4
DAEBA4D6EAA2D1E59DCFE59CD1E99FCFE99FCCE69CC9E59ABCDB8DD8F7A7D3F09EC4DF92
D9EDAEDFEDBC6B72530509000F13006D724A4C561949570C505E0F47570C4858174E5D1C
79813660661E919B5F4449138D844DFFF7C0AD9D698F8C5FC6D9B9577458647C5AD9E6BB
CFCA92EFE3A7CBC289D7D79BD3DE9AD6E39BD6E29AD9E09AD8D8988F8A52B7AC7FE4D4B3
FFFBE6FFF0E2FFFBECFFFDE6E9DCBADED8A8E6E2A5D8DD9ADAEBA5B4C883DCEBA8D6E19F
E3ECABDFE5A5E1E7A7D3DC9BADB977C1D08DE1F0ADD4E3A0D0DF9CD8E4A2CDD896E6ECAE
DCDFA8A6A577A5A080F6EEDBFFFBF5FFFBFBF5E4EAFFFAFDEAD8D6DDCCC4FFFCEF4D4030
0A0000FFFDF4ADA29EEEDADBFBD6DDFFF2F6EFC9C6E2C2B7FDE2CFFFECD7DFBCA9CBA193
C4928BD8A19CD69F98F3C2B3F6CFB28E7348AFA067BDB77B615E275C551F8B753C6E4E1B
745127604D2C152A0B1C3A1E576149413A1D5D481B3012001D00001E0B00000A00000D00
000700040500121000070500090700151300070300070300
D4E3A2CFDB99D5E09BD3DC9BDADDA888865FF5EFD7FFFFEDFFFFE887855E81854AD8E299
CAD88BCDDF95E7F9BBBCD093ADC27F617530D6E5AACCD8A6FDFFDCFFFFE6F6F5E3FFFFF6
FFF6F7FFF4F8FFF5FDFFF7FFFFFCFFFFFCFFFFFDFFFFFCFFFFF7FBFFF9FDFFF5F9FFFAFD
FFFBFBFFFBFAFFF8F4FFF9F5C0B7B0ADA6A0CAC5BFFFFFFAFFFFFAFEFFFBFCFFFBF4F9F2
FCFFF6FAFEF0FFFFF3FBFCEEFFFFF1FFFFEFDDD6C488806BF2ECD4FFFFE4F8F5D6FCFDDB
FEFFDEC8D0A7D6E3B8D1E2AECFE4A1E1F7AED5E9A1C6DA92D2E29BE1F1AA8F9C56D3E09A
D0DD97CEDB95D7E7A0DFF0A9D9EAA3D1E59DD0E69DCCE49AD5EFA6C5E196D4EFA2CEE49C
C2D196C8D3A8767A61010200696B53D0D4AFD1D99EDDE99FDFF0A0D7E99DD3E6A4DDE9A9
E2E59EDDE09BD4E3A8E2F1BAD1D2997E753E857542776E458D9A7E000D00274523798F61
5D60277A72349487528C834C797A388D934BA4A55FB9B671BDB57673662F8F7D4FCEB893
C4A890957964A68B76AC947889764E6B5B289085459E9B56A4AF6B8394507B8A475A6624
77803F818A499BA664A9B5737786435B6C289AAB67A2B671798A4687985492A15E8D9758
7C81496A6C3B6D6A47CEC8B0C1B7ADEFE1E0CFC1C1F4E4E5C8B9B6C1B2ABA09287A4988A
766C62D2C9C09F9691D0C0C0F0D3D8F0D0D3C7ADA0C1AB93BEAC86D5C298C3A984967556
B28776FFDAD0E9B7B0AA7C6FF8D3B8AB9269BBAC71A49E62A8A475D6CDA2A78F5F755325
5F350DAC94708192702C492D909984ABA58FA394731600002903005E421D878D69697954
7B825878794D85835A9695699A986F939266918E659E9B70
E1E0A7D4D498E4E3A3EFEBAEE9E3B1FFF5D1BCB09AF0E3D38B806AD0CAA6E0E1A7DFE79E
EAF6AAD8E89FD1E1A3D4E6ACDAE8AA96A2646D783ED1D9A8D8DDB5CCCBADE6E1CEFFFEF3
FFFCFAFFFBFBFFFBFFFFFBFFFFFBFDFFF8F9FFF9F8FFFCFDFFFAFFFFF9FFFFF3FDFFF9FF
FFEFF9F4E3EDFFF9FFFFF8FFFFF3F8FFF6F8DBD1D0E3DBD8FFFEF8FDFAF1F6F4E8FFFFF4
FEFFF8FEFFF8FAFAF0FFFFF4FDF7EBFFFEF1E4D8C8A49985FFFFE6DAD1B4E5DFBFEBE7C2
D8D9B1EBEEC3D6DCAECFD9A4D5E4A3C7D891D3E39CE1F1AAD0DB96D1DC9797A15CEBF5B0
DFE9A4D1DB96CFDA95D4E19BD5E29CD6E69FD8E9A2D2E69FCCE39DCFE6A0D0E69ED6E6A5
E3F0BA989E78201F0B0301007D7C68DFE0BEDCE4ABD1DD95C5D686CCDE92CDE09ED3E3A2
D7DE98C9D992CBEEAEBEE4A7DBF3B5E2ECB0D7D19D9B9970BCCFB342664A7EAC87BDE9B6
C5DD9FABB473DFDCA5E8E1AAD9D897D9DB92D4D48CD9D490D5CB8D95864D988656CBB58C
866B4D6C51349F8668B19B769280505E4F147268236E6A21B2B975D8E4A2DAE6A4C9D593
DEEAA8D9E5A3CFDE9BCEDF9BD1E5A0CDE29DD7ECA7D6EBA6DFF4AFD6EBA6C0D48FE1F0AF
DFE9ADD3D7A551522ADBDABEE7E0D0FFFCF6FFFCFAFDEFEEFFFBF8FFFCF4ECDFD6A3998F
C0B6AC3C332AFFFDF8F8F5F0F3FCF9F5FFF8C4D9B8B6D19EDAF7B4DFF9B0C1D691D4E2A7
C4C69EECE8CBFFFBE5FFFDE4EAF0CAD0E1ABDAF4ADC2DB97CDDAAFDBD8B7FBE2BA624013
9C7B4EE2D1A5CAD6B0516A4C536C56CFDCCADDD5C01C04007C5D3E5B431FB8B48ED3DFAF
CAE3A2CDEDA4CEECA6CDEBA3CDEBA5CFEDA5D6F1ACD4EFA8
E4DBA4E4DBA2D2C88BDDD29AD6CA9ADED0ADEFDECCCBBBAC8C806AE7E1BDE1E2A8C0C87F
C1CD81C7D98FC1D395D9EBAFC6D294D7E1A4848C539FA673979A6FE4E4C2F4EED6FFFFED
FFFDF3FFF5EFF8EDE9FEF3EFFFFCF8FFFDF6F8EDE7E7DCD8D3C7C7D1C5C9FBECF1EFE0E7
DFCED8E4D2DEF2E0ECE3D2DCEAD9E1EADBDEDED3CFAAA198E4DDCDD4CFB9E8E7CBD4D4BA
CACFBBD8DCCBE5E8D5FAF9E5D8D6BFDAD4BCB4AA8F898061E3DBB7ABA37EB3AC82CDC99A
C2C290C4C792BBC088D7DFA38F9C57B7C780A8B56FA2AF69CCD792C4CE896F7632BAC17D
A8AF6BB0BA75B2BC77A7B26D96A35D8A9A538D9D5694A55FD2E7A69EB372B7C786BFCD90
8D95642F33120B080019150A655F4FCAC9AADFE4AEDAE5A0D5E698E2F7A8D6EBA8C9DC9A
D4E49BD6F0A6B3E29EB3E7A5C7EEABC9E2A1D4DCA3939C6DC5E4C24A7957BFFCD0AAE4AA
A2C782CFE59DD5DB9FD6D79BDBE29CDCE49BE3E9A1F1F4AFE9E8A7A39E646B612E625529
897A539E8E6AE0D1AAE8DBAED1C891A8A3619D9B5075782B858A47ADB675D5E09ECDD997
D2E19ED5E6A2CEE29DDAEFAAD3E8A3C2D993CBE29CD5ECA6C6DD97C7DE98D4EBA5CADF9C
D7E2A6CFD8A37A8054E2E3C3F7F2DEFDF5EAFFFDF6FFFCF8FBF0ECFFFCF6F6ECE3938A81
DFD6CD3F3830F2EBE5FBFEF7F2FFFFE3FFF2C4E6C1CCF3BABAE397C5EC99D3F6A4D4EFA8
B3C792EAF9D0F9FFE6ECFDDDF2FFE1DEFCC6C5ECA9CDF4B5D9F5CFD2DBC0B3A37F6D5527
9F8E58DDD8A1D4E1B59FBD99537F64ABCEB8DCE0D10A00009F90739B8F67797546DAE3AA
C9E79FC8EFA0C2E79AC8ED9FC6EB9EBBE092C2E79ABFE496
61511E82723E58491081723BEAD9AD514120C2B19F92827370654FB9B590D1D59AA0AC62
52631391A659A8BD7C91A5686B7A39D2DD9B949C60373F06868A58393A107B7B59C7C3A6
DBD5BFCEC7B4CBC4B2E0D9C9FFF9E9FFFFEDFCF5E3E5DFCFFFFFF3EDE6DCFFF9F4EBE1DF
F8ECEEF4E5EAE0D1D6EFE0E3F8EAEADED1CBECE3D4B6B098878360A4A377C9CB9A8E9562
9AA6789BA87CACB78CB8BF93A7AA7DA7A97AA8A6759A9764615E2786844BA2A065979757
A8AB68B4BA74C6CD87C4D08899A962A6B770A9B9729AA761A0AB66B1BC777F89445D6722
939D58C3CD88D8E29DC6D18CAEBB7596A65F93A35CA5B67282945693A567BBC98BC5D096
CAD0A466654909030006000080786DD7D3B8E3E8B2D3DE99C2D586D5EA9BD2E9A5D1E8A4
D5ED9FC1E494C6FBB3B6EFAABBE69ED3F2ACAFC282AEC7901B4A206EAB829EE2AFAAEBAB
8FBB70CFEB9ED1E29EE1F0ADD9EFA6CAE296C4DA91C6DA93CEDE9DD5E0A4D5DEA7DEE5B2
C7CD9DD7DAABE9EDBBD6DEA5CCD795CDDA92D2E190BBC879868D495F6424D8E1A0DFEBA9
D8ECA7D7ECA7C3DA94CAE49D8FA962D9F3ACCBE59EC4DE97D8F2ABCCE7A0CEE9A2D1EAA6
D0E0A1DDE8AEDAE2B19DA47BD9D9BDFFFFEDFFFAEEFFF8F1FFFDF8D5CCC7A29994BFB6AF
F6EDE6746D67E6DFD9FFFFFAF6FBF7F9FFF8E1EED2DFEFC2D5E5A7CCDD96CAD78FDDE8A4
C7CE98CAD0A4F2F8D4E5EFCDF8FFE4D2E7BED0ECBBBFE0B3AED7B9C5E2C6A2A27C5C5423
BFC482CDDC99E7FFC7A6D0A07BBF984C8B6EC3DECD000800D6DDBCD6DCAE8D9258868F4E
D7EAAAD7F0AFC7DFA1CEE7A6CEE6A8C7E09FD6EEB0D1EAA9
6454239B8B57F0E1AAE3D39FE3D4A96B5C3DFFF2E2BEB2A4E6E0CACBCBA5DBE3A7CEDE93
D4EA98CBE395C8E3A0D0E6A6D9EAA6C0CD88E0EBA9DAE4A7D3DCA3DDE4B08E94669A9F76
DBDDB8E8E9C7F8F9D9FFFFE3FFFFE4FFFFE1FFFFE0FFFFE5FEFDE8F8F7E5FFFFF3FBF7EE
FFFDFAFFF5F4FFF8F9FFFCFBFFFCF8FFFEF1FFFFEAFCF9D6959768D9DEA4DFE5A5D6E39E
D3E8A5BFD692D4E7A5D5E5A4DCE8A6D3DC99E5EAA8D9DC9995985361641DE7EAA3D4DA90
D2DA8FE4EFA1D8E596D1E294D1E399CFE39BD9EAA3D2E39CD1E19ADAE7A1D9E6A0CDD893
98A35ECBD892DDEAA4D3E39CD9EAA3D1E59DC9DD95D8ECA7D2E4A6CDDFA3D7E5A8D4DDA6
FFFFDCFDF9E0877E770F0503271E15969279D1D5A2E0EBA7CFE293D4EB9DCAE19DCBE59E
C8E392D2F5A3B5E39BCAF7B2C0E19AB7D18ABCD18EC5E3A74E8252377649BBFCC6B9F0AF
7EA356D3EA9AD9EAA3C5DB92C5E498C6E89BD1F3A9CCEBA5C3E09ED9F3B6ECFFC9F7FFD6
D1E3AFD3E6AFD2E5ADCBE1A1CBE59ED2EDA0CFEC9ACBE091EBF0AD4C4C0EE0E6A6D3E29F
C9DE99CFEAA3C4E29AD2F0A84E6922C7E19AD0EAA3CCE69FD0EBA4C7E59DD8F8AFBFDD95
CEE3A0D0E0A2D4E1AB858E61F8FCD9F7F7DDFFFFEFFFFCF2928B85DCD4D1FFFAF8FFFDFA
FBF3F0716C66040000FCF9F2FDFCF8FFFFF8FDFFEAFFFFE3DCDFB2D9DEA6DFE5A9D6DCA0
959D64DCE6B2D2DFB3E7F7D0F4FFE6E6FFDFBCD9BAC5E9CD53836B4E765B586841535C25
B9C883DFF7ADA8CD88C5FBC1ABF4C7094E2F001906000A0092A683CEDCA9E3EDA85C641B
949C60D3DAA4DEE5B1D4DBA5D6DDA9E1E8B2D4DBA7919862
736536B0A36FDACF99E7DBA7E5DAAD807555FFFFECCAC4B4FEFEE6D8E0B9D7E7A8CEE597
CDE995C2E191D0EFABC4E19FCEE49BDAECA0C7D98FDAEBA4DAEBA7D0DF9EBBC98C8A975F
697640AEBB86ACB684DEE7B8DEE7B8CAD3A4D8E0B1D8E0B7FDFFE5FEFFEDFEFFF1FCFEF1
FDFCF7FFFEFBFFFEFDFBF7F4FFFEF8F1EFE0D1D1B5999E76B3BC85E2EEACCDDA92D4EA98
CEEC96CDEF98D2F09ACDE692C5DB88CDDF8DD7E494D4DF91DCE7999CA759949F5197A357
D3E496CBDE8FDCF1A2CCE393D6EEA2C0DA90D1E99FDCF2A9C7DD94CCE098DDEEA7C6D790
53641DCADB94D6EAA2CCE299D6ECA3CEE69CD6EEA4C5DC96CADE9FE2F4B8CDDB9ECFD9A4
FFFFDDFFFFEA857C77080000574C46706A54969867DAE5A3D5E79BCEE597C9E29ED7F1AA
D2E997D2E997CAE39FD1E5A6E1EAA98E9551929F5ACDE9AC4A7C4988C091B9E8B4BDDCA0
9AA65CDFE494D7E296C6DB90C3E599C5EEA2C4ECA5CCF1AEC4E6A9CAEBB2EFFFD6F1FFDA
D9F6C0E6FFCBD0EEB0C3E29FC5E69FC7E99DCBF0A2CAE49AB1B372767235CED393D6E5A2
CAE49DD2F2A9BFE197CCEEA4739149BDD891D3EDA6D2ECA5C3DE97D3F1A9C5E79DCAEAA1
CBE4A0D2E7A6C8DA9EBAC893C7D0A5E0E5C5E2E4CED2D0C3C3BEB8FFFBF8FFFCFDFFFDFD
FCF7F48E8B867A7770FAF7EEFFFFF6F9F9EFFFFFF2FDFCEAEFEFD5F1F5D2D4DBAF909D67
607437DBF5B6C4E6AAD0F6C3D3FDD7A0CCB189B8A866968A114131517B630D2C03263B03
5A6521D6ECA1BDF0A1B4F6AFAFEDBE4782621B523B0015007D916EE0EAB5EFFCAD929949
494307918352AEA071DED09FEFE1B2C0B281675B2B615523
ABA072918A56EEE7B0EBE6AFD3CFA2C0BD9C9A9784C9CAB8FDFFEBD5E1B9D1E7A6CBE898
CCEE98C2E593CFF3ADC8E7A3CBE397DAF1A1CAE193C5DC8EE4FAAFC5DB92C6DC94E2F7B2
C8DD9ADFF4B18EA1617F9153D3E2A7DEEDB2D4E3A8D5E3B0F8FFE3EDF6E1F5FEEDFCFFF8
FEFFFBF4F6F5F6F6F8FFFFFFFFFFFAAFB3A4D5DBBFEEF9D1CEDDA6CDE09ECEE398CFEB97
C3E88BC0E887C8EB8DCDEE93D1EE94DCF49EDFF2A0D4E595C5D386DBEBA090A05555671D
CBE198DEF6ACBED88EC8E499C4E397CFEEA2D3EFA4CCE89DCDE79DDEF6ACC3D990DCF2A9
AEC47BE2F8AFC8E096C5DF95D2EEA3C0DC91CBEA9ED6F1AAC5DE9DCBDFA2D7E9ABD9E3AE
FBFFD8FFFFEA837977080000675C58A59E8B67693ADCE7A5C6D68BDFF6A8CCE5A1CAE49D
CEE492D3E494CEDA9A55581FE1DB9FA09C5C96A15DBFDD9D00190070A877C7EFBBDEF3B8
9D9F56D2D181DEE99BD4EB9DC7E99CC8EEA5C5EAA5C8ECAEC0E1A8C7E8B3ECFFD8F1FFDC
EFFFD6EAFFCDCCEAACC8E8A5CEEFA8C9EBA1C9EDA3CBE29CA3A1648E854ADFE1A2D8E7A4
C9E49DCFF3A9C3E99EC6ECA173934ADEF9B2C8DF99C5DC96E2FCB5C6E19ACBEDA3C4E69C
CFEAA3D6EDA9D4E9A8D0E2A8E2EEBEFDFFDEFFFFE8FFFFEFFFFFF8FAF6F5FFFEFFF4F0F1
FFFEFD5F5B58A6A39CFFFFF4FFFFF4F9FBEEFFFFF8FFFFF8FEF9F3FDFBECD8DFC092A275
89A56AC0E5A2C7F6B2B3E6ADABE2BA538A753B726F093A3EE2FFFFCFF5E06D8D68000D00
01090096A760AFE08FB6F2AABCECBCBDEACB3C6D58001802768765D6DDA9CEDA88E5EB95
9088475649126B5E27EADDA6EADDA661541D51440DE6DBA3
A19D6E8E8C59E1E0A8FFFFCAFAFDD0FFFFE1BCBFAAFCFFEFF8FFEBCCDEB4C9E2A0C7E696
CAEE97BEE491CEF2AAC7E8A3CCE79AC8E190CFE897CAE392C3DE8DD7F2A1CEEB9BBDDA8A
CCE89BC7E396AEC87E8AA45BAEC57FAFC680C2D794CDE0A9D4E3C4E8F3E3F9FFF8FBFFFD
FBFFFFFBFFFFFCFFFFFCFFFFE8EEECB2BAAFEFF8E3F9FFE4C3D6A8C9E1A7D9F2B0C5E498
C1E991D1FCA0C3EA91BBDD86D3F09CCEE998BED587CBE198D6EAA38FA35E8BA05FC0D696
D3EDAEC9E5A8CEECAED1F1B0C2E49AD6F8ABCCECA0BDDD91CAE99DC7E398C2DC92CCE69C
B7D187D6F0A6BFDB90C7E69AD6F6AABFDF93C4E699D1F1A6D5F2AFC9E2A0F3FFC7F1FFC7
FDFFDBFFFFEC7C72701004088E8381B3AC9A4E4F23BDC788CFDF96C9DF94D7F2AFC4DF9A
D1E898E1F3A7A0AA6E5B5B25978E55A4A061B6C783C4EBAA78B7828ECE9CAEDAA7C2DBA1
9EA45CE5E899D8EB9CC5E292CEEA9FD0EBA4CAE4A3CDE6ACC6DEACCEE6B6F2FFDAF5FFDC
EBFFCEE1F9BFCAE2A4CEE9A6D1ECA9C8E3A0CEE9A6D2E2A3A69D64A4985EDFE1A2D7E6A3
CCEAA2C9EFA4C3ECA0C4EDA1CEF0A6BBD68FD5EAA5C6DA95CFE49FC1DB94C4E49BD0F2A8
C6E49CC8E39CC9E29ECCE2A2D7E8B1E9F6C8F9FFDFFFFFEDFFFFF8FAF8F9FFFEFFF9F7FC
FFFEFF353430FEFEF6FFFFF4FFFFF3FAFCF1FFFEFDFFFDFFFFFBFFFFFDFFEAECDEAEBC9B
93B07AB9E3A1B3E8A4BDF9BD0016003B78688EC7CEDCFFFFE3FFFFF1FFF8F4FFEDC5D4AD
848B57505C1EA6C57FBFE4A1CAE7B9E5FFE48CA899000900CFD8BBD9DDAAD6DD8DDAE388
D1DA89C6CE8190984B5860137C8437BAC577DCE799D7E294
949665A1A371DCE1A9EEF6BDFDFFD6F0F8D3EEF8E0F9FFF1F8FFECCADFB4C6E19EC6E595
CCEE98C1E492CDF1A9C6E5A1C7E197D2EA9CDAF2A4D1EC9DC1DC8BE1FEAAC5E590CBEB96
CAEA95BCDC89DAF7A5C2DF8FA3BE718DA75DACC37BE5F9BEC4D3B4E7F2E2F7FFF4F9FFF9
F6FCFAFAFFFFFCFFFFF6FCFCD3D9D5EEF9EBF8FFEFDAEBC9C0D6A8D1EDB3CEEBABC5E79D
C6ED9CC6F09AC7ED9AC6E997C9E89ACEE89ED4EBA3D8EFAB8CA16094AA6AA7BF81D5EEB4
D3F0B6CDECB3BDDEA5CAECAFC3E79FC6E89BC2E497C6E69AD8F7ABBEDD91F1FFC2C1DD92
85A156C3DF94CCE89DCAE99DD0F0A4C7E99CC8EA9DC4E69AD0F2A8C7E59FE5FFB8E8FABE
E6EFC4FFFFEA433B380800005C514F5C5543505127BFC98CE8F8B1C5DB90D2EDAAC6E19E
D4EA9FBBCC85E1EBB6989C6AA49E6AD9DAA0C4D998BDE9AA478B58499161C8FECCD0F3B9
899952B8C576C1DC8FD1F2A3CDE89BD2E89FCDE2A1D2E7AECEE0AED5E6B9F4FFD8F7FFD9
CDE0A9D2E6A9CDE3A2D3EAA6CEE5A1C8DE9DD4EAAAD5DFA3A59A62A99A61D5D597D4E5A1
D1F1A8BFE89CBDE99CC4EEA2D4F4AB7B954EC0D48FDDEEAAD9EDA8D2E9A3B8D68ECEEEA5
CDEDA2CAE89ECBE79DCEE7A3D1E5A8D4E5B1E5EFCAF7FCE5F9FCF3FFFFFFF6F3FAF9F6FD
BCBABD000000FFFFF8F6FAECFCFFF4F8FEF4FFFDFFFFFBFFFFF8FFFFFCFFFDFEF8DBE8CE
A8C595AAD397D1FFC789C58F5793719CD6CACDFFFFDDFFFFEEFFFFEFFCF2E5F0E0DCE6CD
D0DCB41A280086985CCADEA3BCD2A4F7FFECF6FFF5222A1FBBC3ABD2DBACDCE799DDEB93
DDEF9DC6DB8CCBDE8FC4D98AD5EA9BCBE091D3E899CAE191
989E6E79804CCFD89FCBD69EDBE7B9FBFFE3F9FFEFF8FFF1F7FFECCEE3B8CAE5A2CAE797
D0F09BC8E797CFEEA8C1DB9A97AC69677B34CBE198D6EEA2CDE899A8C573CEEE99CCEC97
CEEE99CFEF9ACBE896CBE898D2EDA0BBD387849A51B9CD90E3EFCBECF5E0ECF3E1FCFFF4
FCFFF6F2F8EEFEFFFAFCFFF8CED6C7F9FFEFF8FFE8DAEFC6DCF4C2D2EEB3BAD996CDEEA7
D1F5ABAFD487C9EBA1DBFBB2BED992C6DF9BD3E9A8AABF7E889C5DD6ECAECBE3A7BAD699
C0DFA3D1F3B7B4D89BCBEFAFCBEFA5C3E598C3E397CCEB9FCFEEA2C3DF94BBD58B95AF65
96B066CCE89DD7F3A8C5E498C3E296C8E89CCCEEA1C4E99BC4E99CCBF0A3C7E59BD5EBAA
D0DCAEFBFEE30901000700005A4F4D4C453394956BDEE8ABCEDE97DBF1A8C5E09DD8F1B0
D0E49FDFEFB0CBDBACBFCCA0C6CE9BD9E4ACE7FFC5BCE7B1A6EBBE69B68CBBFDCFB5E8AF
7998528FAA5DD3F5ABCDEFA3CDE695D2E798CFE39ED5E9ACD1E2AED2E4B4E9FBC9E5F8C1
C4D89BD0E5A2D2E8A0D5EBA2CEE49CD2E7A4D4E8A9B8C28683743D9F8E56DBDB9DD4E5A1
C9EBA1BCE89BBEED9FC2ECA0CBEBA2C5DC96AFBE7BCDD997DAE9A6D9EDA8CFE9A2CFEDA5
CDEDA2C9E99DCAEA9ED2EEA4D3E9A8D3E6AEE7F3CBFCFFEAFEFFF8FCFDFFFCFBFFFFFEFF
919095626260FEFFF7FBFFF6F6FFF7F6FFFAFCFFFFFCFBFFFCF6FFFFFDFFFFFFFAF7FFED
E1FBD49CC492ABDDA877AF8252896CD0FFFADDFFFFDBFFFFF1FFFFF3FEF8FBFFFDCBD7CB
DCF6D9213A12586031D9DFAFE2F3C9F8FFEAFFFCF6060100717D67CEE4B6D5EBA3C8DE8C
D0E49FC8DD9CE0F3B3D7ECABD1E6A5C0D594D6EBAAD7EDAC
D8E0AF99A16EB7C288D9E6AECDD9ABFBFFE3F1FDE7EEFBE7F5FFE9D2E4BACDE6A4C7E293
CEEA96C9E495CBE6A1B0C688AABC7E90A061829553D5EBA3BED68CF2FFBECBE896CAEA95
C3E08CC7E490C8E593D4EFA0D4ECA0D9EFA699AF6698A86ABAC59AE3EAC8ECF1D3FFFFE8
FFFFEAF5F9E2EEF2DBC6CCB2CFD8BBDFEAC8E2F3C9D8ECB9CFE8AECCE9A7C9E9A0C9EBA1
C8E9A2CEEDA7C6E49ECCE7A2DAF3AFC3DA9699AE6B8B9E5CD9ECACC8DD9CCCE5A3E0FDBA
B8D994C4E8A2CDF2ACCBF1A8CAECA0CFEFA3CAE99DCBE79CC7E197D2ECA2647C328BA359
C5DD93D1EBA1D0EAA0C9E59ACCE89DCAE99DC8E89CC9EB9EC1EB99D2FCAABDE090D0EBA6
CFDFAEF8FCE1040000170C105C514F6E6755F6F7CFDCE6AAC6D68FDBF1A8CCE7A4D3E7AA
D3D89E989A68AEBA92CBD9B59EA77CB5BD8EC0CD9FD3F0C4B6EDCD5EA18071B48BBFF8C5
AACE8E66813CBED897CCE7A2CEE793D0EA93CDE599D5EBAACEE3AAC8DFA7D6EDB5CCE6A9
D0E9A5D0ECA1CBE697CCE798CAE598D3EDA4C7E09E939E625C4D168C7941E6E6A8D5E6A2
BDE197C1F0A2C2F3A4C0EA9ECAEAA1DBF0ABBDC98799A26185914FCBDC98D6EDA7BAD88E
C6E69AC2E595C5E898CBEA9ECBE59ECDE2A7E2F2C5FBFFEAFCFFF8F2F3F7FFFDFFE2E0EB
626167FFFFFDFEFFF8FBFFF6F1FFF7F5FFFFFCFFFFFFFEFFFFFAFFFFFAFBFFFEF5FFFFF1
EDFDE08DA98370966F1E4727AAD1BEE7FFFFE3FFFFEEFFFFF0FFFFEDFCF9F3FFFFBED4D1
C3E8D6163718516039D7DEB4CFDBB5FBFFE9FFFEFA030000445744A9C9A0BFE49FC9EEA0
C9E49FC9DF9FCEE4A4C5DE9DCEE7A6D6EFAED6EFAEBBD594
CAD4A2AEB884859058DAE7B1D3DFB1FAFFE2F9FFEFF9FFF1F3FFE6D8E9BFD7ECABC9E092
CFE694CEE597C9DE9B9FB175D6E3ABE4EFB793A164485819D5E9A4CAE097BED98CCCE999
D8F3A2C9E493D8F3A4D7EFA3BCD289CEE29BDCEDA9D0DEA0737A44C6CA98DFE3B1EAEDBE
F2F5C8F2F5CADFE5B98F9567D0DAA8D4E1ACD3E5A9C9DE9DBDD78EC9E898D6F8A4C5E695
BBD98FE1FCB7CBE4A0C1D892DFF4AFC4D891A5B670C8D992CEE096D0E598C9E193C9E694
C1E38FCBF19CC5ED95BEE48FBDDE8FD1EDA2CDE79DCFE99FD8F0A6D0E89E91A75ECEE49B
D2E89FCBE198CEE49BD2EAA0D6EEA4CFE99FC7E398C8EB9BBCE893C1EE99BBE28FCAE8A0
CBDDA9DEE5C6040000160D10170D0B787360FFFFDCD3DDA1E1F0ABD3E9A1D4EEADC8D59D
E0CDA2BDA583D2CEB3FBFFE4E3E2C3B0AA88FFFFDFF9F9DFECFFF9709F8D42795CAFE2B7
D8F7BE8A9C608F9662D3DDA0CEE891C9ED8DC6E892CDEFA3C7E7A4C0E3A3CBEEAEBEE39D
CDF2A4C4EC96C1E88FC7EE95C0E691C6EB9DC3E79F98AB6B71622B715C25D2D093D0E49F
BEE499C6F7A8BDEE9FC2EEA1C8E69EC2D691EDF8B6D3D999A6AF6ED2DE9CDBF0ABCEEAA0
CBEDA0C8ED9DCCEF9DCDEE9FCCE89ECFE7A9E5F6C9FBFFE8FCFFF8F8FCFFF4F4FF91919D
2F3035FEFFFFF0F3E8EBF1E7F7FFFFF9FFFFFFFEFFFFFBFDFFF9FAFFF8F3FFF6ECFFFCEE
FFFFED919A8594A38E2F4131CFDFD5F2FDF9F5FAFDF2F7FBF1FFFFCDE6E3D2F5F9D8FFFF
8AB5AC001400597D57D1EAC2D9E0BFFFFFECE0E7E0091A1425402F9BC59FAFE8A4B3EC9B
CAF1A2D0EFA1CBEA9CCCED9EC4E596C8E99AC7E899CDF0A0
D9E6AED0DDA5A5B378D3E0A8D2E0ADECF9CEE7F2D2F7FFE6FBFFE4E6F3C7E5F5B7D3E49D
D9EBA1DAEBA4D1E1A29EAD72CEE0A4D5E7ABCDDFA1D2E5A58EA15FA0B46DD6EAA3D1E79E
D1E79CCCE297CBE196C9DF96E7FFB5CDE59BC8DF97D3E7A27B8548C2C78FD8DDA7F7F9C7
FFFFD3F9FBCCF3F6C7B8BF8CD5DEA9D7E5AACEDE9FD4EAA2D8F3A4C9E791C4E58ACBEC95
D2EEA4C1DA96D7EEA8CBE09B90A15B93A35CC7D78ED5E899D6EC9ACBE491CAE892CEF099
CAEE96C5EC93C7ED96CAED99C8E799D2ECA3C9E098CAE199D0E69E899F56CCE29AD5EBA2
D1E79ED0E69DD5EDA3CCE69CC8E298CBE79CC9E59ACCED9EC4EE9ABBE591CDF0A0D4EFAA
D1E2ACCDD5B0070800141206373826C7CAADE7F0C1D6E4A7C6D997CEE5A1D7EFB3F2FAC7
C7AD8CFFE0CAA79787ABA5959C9583EDE4D3FFFCEFFFFFF4EEFFFD8BAEA752826A7BA984
C5E6B1D0E5AA717A43DAE6A4CBE88EC7EC8CC4E890CEF1A1C7EBA3C4E7A3CFF4AFC3E8A2
C4EA9DBEE594C3ED97CFFAA1BDE793BFE997D1FAACC1D892A5995F59460EACAC6ECADF9A
C8F1A5C3F8A8ADE292C5F6A7CAECA2D5ECA6C8D492E2EBAAD1DA9B6C783692A764C1DB94
C5E59AC7E79BC8E99AC8E79BC8E39CD1E7A9E5F7C7F8FFE5F1F9EAFCFFFFFCFFFFDCDFE8
969A9DF5FAF6FEFFF8FCFFF8F9FFFFFBFFFFFDF8FCFFF7F7FFF9F8FFF8F4FFF6F0FFFBF1
FFFAF1A6A69C939891242D28CDD8D4F8FFFFF8FDFFF9FFFFF7FFFF4D67645F938F80B8B5
4C76742D4E4555755D7D9575D4D8BFF8F7E3F9FFF6000800000C00002C08AEEDB4B5F5AB
BEE997CDEF98BEE28AC9ED95C5E992D0F49DBFE590C5EB96
CBE09BC8DD9893A664D5E8A8D2E1A6C6D59ED4E2B1FCFFDAFCFFD8F8FFD2FCFFD1CEDC9F
CFDD9FD6E4A69CAA6D8C9F5FCBE9A1C2E297D2F0A6C5DF9695A9649BAC68C8D492D2DD9B
D8E3A1CFDC97DFF0AACAE097CAE699D1F2A1B4DA87D6F5A9CDDCA19FA774C4CA9AEBEEC3
FFFFDDFFFFDFF9FBD6979C74D3DAB0D0DAA8D0DDA5D3E6A4D3EB9FCCEA94C8E98ECAEC95
C9E79DC9E4A1D2E7A49CB06941510ACCDA8FEBFCAECCE290CFE894CAEA95C8EB97C6ED9A
C7EE9FC7EDA0C6EAA0C8E89FD0EAA3CDE49ED7ECA7CEE39EBCD38D778E46DDF4AEC7DE96
CDE79ECDE79ECCE89ECAE89ECAE99DC9E99DC9E99DC9EA9BCAEB9AC3E294CCE39BD3E6A6
D7E4AED0DCAC020D0027340995A679BFD6A0D7F1B4CEE8A9C7DFA1CEE3AAE2F4C0FFFFD9
ECD7BABFA38EFFFAEFFFF8F2FFF9F9FFFEFFFCFFFFF1FEFFEDFFFF6F928C000F005F8B67
B4DFA7C6EDAACCF1A4C6E89485A349D8F69CC6E48ECAE797D0ECA2C1DC99DEF8B9C8E5A5
D0EDABD0EFABC4E59ECEF4A7BEE799C6F1A1C7F2A2CBE59BD9D1937E6F34C7CC8ACAE49B
CBFAACB5EE9DB8F6A3BFF6A5BFE99FBAD892E5F8B6D7E3A3CCD89ACEDE9DA7BC7BB9D290
CEE4A3CDE3A2CBE29ED6EDA9CBDFA0C7DBA0ECFCCDF8FFE3F9FFEFECF4E9FBFFFDE2E8E8
5C6260FBFFFDFBFFF7FBFFFAF1FCF8F9FFFFFAFCFBFFFEFDFFFCFAFFF1F1FFFAF8FFF4F1
FFF9F8FFFFFD9DA3A16472725D7575E6FFFFE6FFFFEBFFFFF7FFFDE8FFF57BB9AA317568
8EB2B2F4FFFFC7CCC856564CB0B19FFFFFECF9FBE55E6B518CAF8F1F512E75AF87ADE6AF
BEE997C2E788C6EB8ED9FDA3C6EA92CAEE97C5E896CDF09E
D8F0A4CFE79DC2D8904F641F96A969D1E1A3E1EFB4E4F1B9D7E4AEE3F0BAF8FFCDDAE7AF
E4EFB5CEDC9F717C40B9CE8BC1E494D3FAA7C1E494CAE699D7EDA58D9C597A8543DFE8A9
D7E0A1D3DE9CDCEBA6D6ECA3B4D083D3F6A4D3FDA7B5D888D8ECAD9EA874ABB384E2E9BF
E6EAC5F7FBDAFDFFE1DADEBDD9DFBBD8E0B7D4E2AFCFE1A5CBE29EC9E598C9E994CBEB98
CEECA6D5EEACCBE09D677832D3E09AE1EDA3CDDE90C8DE8CCFEB97CAEC98C6EC99C3EC9D
C3EC9EC5EBA2C7E8A3C8E5A2D4EBA7C9DE9BD5EAA7C0D59271884296AD67C2DC95D7F1AA
CCE89ECAE89ECAE89EC9E99EC8EA9DC8EA9DC8EA9DC9EA9BC5E292D6EEA2DAEEA9CAD89A
636E3657642E000B0065793EBED899CBEAA7CAEBA6C2E29FC8E4A7D2EAB0DAECBAEAF0C4
FBECCB6D5740FFF3E5FFFCF6FFFDFFF9FBFFEAF6FFF0FFFFEAFFFFE9FFFF547B697FAB88
BCEBB7BFF0AEC3F6A7C0ED98CAEA957E9743C3DC89D2E99BC9DF97DCF1AEB4C889D5EBAD
C2DA9CCFE9AACCE9A7CAEBA4BEE499C2EB9CC2EC9AC5E093E1DD9D4F4508F6FDBAC7E198
BAE699BCF3A2AEE997BCF3A2CBF7ACBEDF98D1E7A6CDDD9ED5E5A6D4E7A79CB271879D5C
D3E7A8CEE0A2DCEEB0C1D395F1FFC5D7E8B1E4F4C5F7FFE1F7FFEAF4FFEFF1FBF2818783
161C18FBFFFDF4FBF3FBFFFBF3FEF8F0F9F6FCFFFFF2F1EFF9F3F3FFFCFBFFFBFBFFFBFB
FFFCFFF3F1F4FBFFFF47595B143033BDE3E4E0FFFFD7FEFDE8FBF5EEFFFDADE7D981BAB1
CCE5ECFBFFFFFFFEFFABAAA8484C3EA0A48DFFFFE4D8DFBDCDEDC67CAC842154338DC296
CAFABCCCFAB1B6E199B2DD95BFE9A1B3DD95CAF2ABBDE59C
CAE296D9F1A7D2E8A0C4D9948A9D5B6E8141CAD99ECEDDA2D6E5ACD5E4ABD4E1A9CAD99E
87955A7A8A4CD9E7A9C3D893CFF2A2BBE38DCCEF9DCEED9FBED68CD3E7A0D1E09D929E5C
A1AD6BB4C380A6B771D7EDA4D1EC9FB9DA89CCEF9BD8F9AAC8DD9AD8E6ABC3D09A9EA876
899066EEF4D0FDFFE1B1B696C9D0AFD1DBB8D5E1B9CEE0B0CCE1A9CDE7A8CCE9A6C8E6A0
C7E1A0CAE09FD7EAA86E7D3AECF7B3D3DE99DBE8A0DCEEA2CAE594C6E796C4E999C3EA99
C4EB9CC6EB9ECAECA0CDEBA3CEE5A1CBE09DE3F8B5B8CD8AA9C07ACDE49EC5DF98CDE7A0
CCE89ECAE89ECAE89EC9E99EC8EA9DC8EA9DC8EA9DC9EA9BCCE796D7EEA0CCDD96B3C281
6A753BD7E2AAC9D69EDCF0B3D5F0ADD1F0AAC5E79DC1E399CCEBA7D0EAA9CEE3AAD9E3AF
E0D7AE786948FFF4DCFFFCECFFFDF6EEF2F3F7FFFFEAFBFFEDFFFFDCFAF8AED2C44A755A
AFDEB4BAECB7B7EBABBBE9A1CCEB9F6A813191A85AD0E59ADEF2ABE1F5B0C6D997CBDE9E
D2E7A6CFE5A4C9E29ECAE59ED4F4A9CFF1A4C5E898CCE498E1E2A05E581ACAD18EE7FDB5
C5E99FBBE79ACEFFB0BDEC9EBFE99FC1E59DC8E3A0CDE3A2D4EAA9D7EDACCBE4A2C0D997
4C6120B5C888C6D999C5D898C8D89AD5E4ABE3F1C0FBFFE1E9F3DAFBFFF4FBFFFBD6DAD9
6E7271FBFFFEF9FEFAF5FBF7FBFFFFFBFFFFFEFFFFFFFFFDFFFDFDFFFCFDFFFCFBFFF5F4
FFFAFCFFFEFFF8FDFFE5F5F5A2BABC2A494B89AFB0BFE6E5B2D5CEE9FFFFE5FFFFE5FFFF
F8FFFFF0F3FFF5FFFF96A9A7011202758169FFFFE4E8ECC9E6FFD5C2E7BBAFDCB1184A25
073F243E7A612E684F8AC1A29DD3AFB8EBC0BBEBB7BDEDB3
C4DC90D5EDA1D0E69DDAF0A899AD68162900D4E6A8DDEFB1D1E3A7DDEFB3CBDDA1CFE1A3
4D5F21B6C989C5D594D3EAA2C4E594C4E793CDEE9DCEED9DCCE79AD7EDA4D7EBA4C4D591
C6D79390A45D90A45DCEE49BEAFFB6C9E598C8E595C7E494CBE198E6FAB5DDEDAEA3B279
717D4DB1BC92E5EDC8DCE3C2CBD4B5E0EBCBECFAD7E9F9D4E6F8CEE6FCCDDDF5C3D0E9B0
CAE2A6CDE3A3D9E9AB707E40DCE5A6CED798DEE9A7CEDD98D1E99FCCEB9FCAEC9FC7EC9E
C6EB9DC8EB9BCBEC9DD0ECA1D9F0AAC5DA97A2B774809552CFE6A0D4EBA5CCE69FCEE8A1
CCE89ECAE89ECAE89EC9E99EC8EA9DC8EA9DC8EA9DCAE99BD8F1A0CFE495A1B16A818D4B
9DA76BD8E1A8D1DFA4D0E2A4C9E39CCBEBA0C9EB9EC8ED9FCEEEA3C7E59DC7E09ED8E6AB
E5E3B260592DF7F1CDFFFFE6FFFFEFFCFFF8F3FEFAEEFEFEF0FFFFEBFFFFD5F9EB3A644E
AFDEBCC2F5CAA9DFADCEFEC4B9D894B8CE8591A55DAABE76C6D791C6D791E2F3AFDDEEAA
ACBD798A9E5783975097AD65C6E096CFEB9EC8E497D9EFA4E0E5A2656525909956BBCC86
E1FBB4BFDF96CCF0A6C0E69BC0E69DCCF0A8C9E8A4D4F1AECAE7A4BAD592D1ECA9DBF4B2
7C914E7B8E4C6C803BE7FAB8CBDB9CCDDCA1F4FFCFF1FDD7FBFFECE9EFE1F1F6F0FCFFFF
5B5F60F4F8F9FAFCFBFCFFFFFCFFFFEEEFF1FFFFFFFBF9FAFBF5F7FFFDFDF7EEEFFFFDFD
F5F1F0FFFFFFFBFFFFF7FFFFF2FFFF344C4E3551546A888872928FE8FFFFF5FFFFE9F0FF
EDF8FFE8FDFFD4F7FD4D716D000700919984FFFFE6FFFFDFD7E7BADAF8C6C6EEB9497D4F
5D99808ECCBD4683714B8670498466A1D9B4ADE2B4BBF0BC
D9F0A2D1E79CD3E9A0C9DF97D6ECA47D924D899E5BBCD190D3E7A8BCD190DBF0AFAABF7C
A3B875C7DC97CEE29DD5EDA3C8E797D3F5A1C1E090C3E292DDF9ACC4E095B5CF86E3FAB2
D1E8A0CBE29A8FA65E6C8239C2D88DC5DB90D4EA9FD9F0A2DBF4A3BED688C6DC94D1E6A5
D6E7B0AFBF8E8A966E606B49DDE8CAF0FDE1F9FFECF8FFEAF4FFE7F1FFE4E5FBD7D4EBBF
D5E9B4D9EDB2CDDAA2DBE6AE3C410BA7AC76CDD59CE0EBAFD5EAA9D2EDA8CFEFA6CBEDA1
C7EA9AC6E796C8E895CBE898D2E9A397AC697E935097AC69C6DD97D4EBA5C3DD96D4EEA7
CCE89ECAE89ECAE89EC9E99EC8EA9DC8EA9DC8EA9DCAE99BC0D785DCEFA09AA7614D5816
D9E1A6D1D9A0C7D296D9ECACC4DE95C9EA9BC8EE9BC9EF9ACDF09EC5E697C6E298D8ECA7
C2CA8EEDEDB79B9D6C73784FE0E5C5F9FFE9F9FFF3F5FFF8DFF5E9EDFFFDDCFEEEB7E1CB
517F6377AA89BAF1CAACDBADCDECB1D4EAA9CFE4A192A66171823C697A3452621B65752C
E7F7AEC6D68DB0C077A2B46AB7CC81D5EBA0CBE196CFE39BC8D590D8E19E4E5714B8C37F
D4E09ED5E6A2D7ECA7C9E49DCDECA6C9EDA5C1E6A0E8FFC7EAFFC8C3E49FC6E3A0C3DC98
D8ECA7D2E39D7F90498A9B55E7F8B4D2E2A4C4D19CE5F0C8E3ECD1F1F5E7FEFFFBFEFFFF
F1F2F70B0C116A696EBAB9BEF6F5FAFFFFFFF6F4F7FFFEFFFFFEFFFFFEFDFFFEFDF2EEED
FFFFFDEFEFEFF3F7F6F5FEFDF8FFFFD9E7E8EBFAFDF4FFFFECF9FFF0F6FFFFF7FFFBFDFF
C5E8FB80B9C464A5A794C8C4F5FFFF857B72604B38F0DFC1E7EABDCBE2AAC4ECADBCF0B0
B5EBB7A8E0AFCAFFD1AEE6B57CB48318511E3C723EC6FDC6
D4E99CC6DC91D1E79CD2E89FC2D890D4EBA3859C56A1B872CEE5A1E0F9B5C3DA9699B06A
BCD38DCFE69ED8EFA7C1D98FD3EE9FCAE795D1EE9EC7E696BAD98BD4F3A5DDFCB0B5D389
D6F2A8C9E59BC8E298879F55CDE297EEFFB6CFDF96CFE195C7E08DCEEA96DDF8A9C7E198
D2E8A8C7DCA4D9EABDD8E8C3F0FFDEF8FFEAF8FFECF7FFEDF7FFEDF5FFECF5FFECEFFFE0
F5FFD9F3FFD2FCFFD8DEE5B9E7E8BEC7C89CD7DAADD9E1B0C7D8A1C7DFA3C8E5A3C7E6A0
C5E599C6E595CAE795CDE899C0D78F5D722FC3D895DFF4B1DEF5AFD5ECA6CAE49DCBE59E
CCE89ECAE89ECAE89EC9E99EC8EA9DC8EA9DC8EA9DCAE99BD3EA9AC9DA8CA1AC685A6324
D6DBA3DEE5AFF0F9C0CBDB9CD1EBA2CFF0A1C4EA95C0E890C9EF9ACAED9BC8E799D0E89E
EAF9B6C7D192D5DFA3E9F3BEF2FBCEFAFFDFF1FFDEF7FFECF4FFF1DFF8E2E8FFF2E6FFF4
4C7A5E4C8262AFE8C7C2F5CCC6E7B2AEC68AD3EBADDAF0AFCFE49FDBEFA7D3E599DFF0A2
CFE092D4E293CCDA8DA1B1668D9F55D8EAA0DAEEA6D5E9A1DBEFA8CFE09AD6E19D4F5613
DCDE9FD3D898DAE3A2D6E7A3CDE8A3C1E59DBBE59DE8FFCAEBFFCCD0F4AECFECA9CBE4A0
D8ECA5D6E7A0E0F2A891A3597D8E48D3E3A2DCE9B3C6D1A7F8FEE2F7FBECFEFFFBFEFFFF
FDFCFFDAD9E1D3D2D86A676E0A080D878288F8F6F9FFFEFFF6F4F5F4F2F3F7F7F5F5F5F3
61615F0608055C5E5B0B0F0ED0D4D5F6FAFBDBDFE2FCFDFFFFFCFFFFFAFFFFF7FFE2E8FF
68A1AC3A898D287676B1E7E9F9FFFFFFF7F7654F4250412498966DCFDEA7C3E6A2C5F0A8
C3F1A9AEDD97CBFAB6B3E4A2B1E4A28BC1835A915776B075
77893F859A4FDCF1A6CEE499D0E69DD5EDA3DBF2AA7A944B445E17809C5299B36A3D570E
D4EEA5DDF7ADBCD68CDCF4AAC4DC8ECFE799D7F2A3D6F2A5C7E899BCDF8FC4E699D8FAAD
BDDD91E0FFB3BEDA8FE1F9AF6D8139354500E1ECA7D4E499D4ED9ACDEB95C6E391C7E398
D2EBA7C8E0A4D3E7B4EFFFD5F7FFE1F7FFE4F2FFE3EFFFE2F3FFE6F7FFEAF7FFEAF7FFE8
F8FFE3F7FFDDF9FFDCD0D4B3DAD7B8BBB899D4D5B5D5DBB5D1DEB2D2E6B3D4EDB4D2EFAF
CEECA6CCE89DCDE899D1E99DCEE39E738845CCE19EC8DD9AD4EBA5C4DB95D3EDA6CDE7A0
CCE89ECAE89ECAE89EC9E99EC8EA9DC8EA9DC8EA9DCAE99BDAEFA48C99517C8546ABB076
D9DBA9D4D8A6D4DBA7CAD89DCCE39FD0EFA3C6EC99BEE690C6EE98CBF19CC8E998C9E598
C3D990D8ECA5DBEBAAD0E0A2CBD8A0CDDAA5EAF7C9C3D4A8DBF0C9C4DEB9C6E8C3A7CFAC
A3D2AE6CA27E5E9872B6EBC1C8EEBBD9F8BFBAD89CCCE9A9CEE7A3BED68CDCF3A5CAE08E
D4E795DDEF9DDFF0A0BCCD7F7A8C40CEE096CDDE97C4DA92C8E49ACCE69DE1F0AB555A18
989457C2BC80DFDDA0CFD595D1E6A3C8E9A2C0EBA3C9F7AEC5F0A8B7DC96BFDE9AC9E29E
D1E79FC3D88DD3E599CDDF9392A45ABDCE8AD0DDA5DCE8BAE5ECCDFEFFF1ECEDE8FAFAFC
FFFDFFFFFDFFFFFCFF7C777E827B824E484C9590942F2D30211F206C6C6C1214113E403D
787A779B9D9A8D8F8C71716F0908067A7677FFFEFFF8EDF3FFF6FFFFEAFDFFF8FFF0FFFF
9CE6E753AFAC3C8689E0FFFFFAF9FFFFFAFFF8F1E7D2D0B7797953C8D09DB7CB8ECEE9A2
D2F3A4C4E795BADF8FD7FFB2B8E499B6E59F558947447C3B
DAEAA18A9C5292A45ACDE297D8EEA5C8E096C9E399CBE79CCAE69BDBFAAEB8D489D4F0A5
CFEBA0BEDA8FDBF5ABC6E096D5EBA0CCE297C5DD93C9E59ACFEFA3C7EC9EC1E899C4EB9C
C4E99BC3E397D0ECA1C2DA90DBECA5E4F1AB626C27DCE9A1C3DC8BD5F5A0C8E797CCEB9F
C8E39CD0EAA9C5DEA4DCF3BDF1FFD6E3F6C9D4E6BCD0E2BACFE1BBCEDFBBCCDDB9CEDEBA
CBD8BAFBFFEAF6FAE1FFFFECFFFFECFEF9E5A4A28B7E8166FAFFE2F8FFDFF4FFDAEAFFCC
DFF9B8D3ECA8CEE59DCCE39BD7ECA7C6DB9892A764B0C582C7DE98D8EFA9CCE69FCBE59E
CCE89ECAE89ECAE89EC9E99EC8EA9DC8EA9DC8EA9DCAE99DD3E79FADB977545C219C9E6C
E3E2B4E8E9BD63693B57612DB3C788CAE59ECFF1A4C4EB98C5EC99C8EE9BC7EA9AC8E799
CFEBA0CDE49CC2D890869A55CADA99DDEDAEC9D99BCEE0A6C1D69ECEE9B4CBEDBAC6EEBC
BAEABAB2EAB995D0A24F8756305C29C5ECB5C9ECB2C1E4A4D6F7B2C1DF95D0EB9CD1EA97
D4EC98C6DC89D1E794D8EB9A8BA053D9EDA5CFE39CD3EAA2CEF0A4C2E297CFE09A9BA05E
5A5116EADEA4DCD297E7E7A9D1E1A0CAE9A3C5EFA7BCEAA1BDE8A0C8EDA7D0EDAAD4EDA9
CCE299D9EEA1D3E899D0E394B1C3776B7C35D1DFA2CFDBA9E7EECCFEFFEDFFFFF8FFFFFF
F9F7FCFFFDFFFCF7FEFFFCFFFFF7FCFFFCFFF5EFF3FFFEFFFFFFFFEDEFEEFCFFFDFCFFFD
FCFFFDF6F8F5FFFFFBFCFBF7FFFEFB160C0B6E6262B1A1A4FFF6FFFFEAF4FFFBFFF0FFFF
CEFFFF75C5C2437880BAD6E4F9FFFFF6F9FFF1FFFBA5BBA4303515060400E3E5B4D5DFA2
CAE296CCEE98C7EA98CDF4A3BBE697C4F2A7B4E8A0A2D793
D0DD97C3D08A8D9D56D5E69FD2E89DD5EDA1CBE699C6E295CAE99BC9EA9BCAE99BCAE99B
CAE99BCAE99BCCE89BCDE79DCDE39BD2E6A1D2E9A3CEE8A1CBEBA0CAEFA2C7EDA0C2E89B
C6EC9FC6E89CCDEBA1C3DA92E7F8B2D5E29D6A7330D6E39DD3EB9FCCEB9BC7E698C7E69A
CCEAA2C7E59FCCE9A7E0FABBECFFCBDFF6BED4EBB5C7DEA8D1E5B0D6EAB7C9DDAAD4E5BB
D2DEC6FCFFF3F9FAECFFFFF3FDF7EBFFFCF0EFECDD949681D9E2C7F0FFDCF5FFDFF3FFD9
E5FEC5D3EBADCAE09FCFE4A1D1E6A3D4E9A69CB16E9BB06DC6DD97C5DC96DEF8B1C7E19A
CDE99FCCEAA0CCEAA0CAEA9FC7E99CC7E99CC8EA9DCCEAA0CEE3A0CEDC9F141B006E6F43
DCDAB3E0DEB80305001E250081925CD3EDAEC6E89EC1E699C0E798CDF2A4CFF1A5C2E297
CDEBA1C9E59BB9D38A3B520AC6DA92D2E39CD8E9A2D2E69ED0E7A1CCEAA4C4E7A3BDE6A4
BEEFAEBCF3B2A7E1A48EC88D1C4F17A4D39CC0ECB1B7E1A2C2EAA4D1F5ABBFE091CFEF9C
C9E791D0EC97C9E28FD4ED9CADC579D1E99FCEE59DCDE8A1C6EC9FC9EB9FD0E49D929755
5E551AB2A36AFFF5BBD7D598CCD898E2FDB8BBE09AC3EDA5C1E9A2C2E6A0C9E4A1D8EFAB
D5EBA2CCE395CFE696D7ED9BCBE091B8CA80BCCB8AD0DDA7EBF3CCFCFFE8FFFFF4FCFDF7
FFFFFDFFFEFFFFFDFFFFFDFFFFFBFEFFFCFDFFFDFFFFFFFDFEFEFCF6F8F5F8FDF9FBFFFD
FCFFFDF8FAF7FFFFFBFFFEFBFDF3F2938584382828594949C2B7B3F8F3EFFFFFFDF5FFFF
E4FFFFAAD2D46B7C8C8794A5EDFFFFE1FFFFBEFCED2D614A000500120300927F5FE8E1B5
D2EBAAC2EB9FC9F3A7BFEB9EC9F7ACB8E89EBEF0A7BBEFA5
D0D996DDE8A4C9D69190A059DAEEA6D5EBA0CDE89BDAF9ABCAE99BC9EA9BC9EA9BC9EA9B
CAE99BCAE99BCCE89BCDE79ED7EAAAD5E7A9D0E4A5CAE3A1C7E4A1C7E8A1C7EBA1C6ECA1
BFE598C8EA9ED3F1A7CEE89FC0D48DDFEEA9DAE5A153601BC7DF95CDE99ED4F0A6C9E59B
C1DF97C5E39BDBF9B3B2D08AD4EFACCDE8A5CEE7A6C8E1A0D1E7A7D3E9A9C2D89ACDDFAF
CCD8C2FCFFFAF2F1ECFAF5EFFFFEF6FFFEF4FFFFF3FFFFEFC2CAB2D2E1C0D3E8BFC7DFAF
C4DCA8CCE3ABE3F8BDF8FFCFF6FFCAF5FFC7E2F7B4C7DC9991A8627D944ED3EDA6D2ECA5
C4E096C4E298C7E59BC9E99ECAEC9FCAEC9FC8EA9DC9E79DCBE09FD5E2AA676F3E474820
D7D4B1DCD9BA131300000700576534C2DAA0D3F2AFD4F8B0C3E79DC0E49AC8EAA0CCECA3
C7E59FC9E49D769049E5FDB3DFF5AACFE497CEE394CDE492CCE592CCEC99CAED9DC1EA9C
C0EFA1C0F4A9B5EDA2A6DF9896CC904C7F4784B67BC6F6B8C4F1AEB9E39BCCF2A5C1E494
C7E995C9E996D1EE9ECEEA9DC4E095D0ECA2C2DD96D2F2A9CDF6A8BDE295D4EBA3DEE7A4
A4A06371672C8D8348BDBB7EE1EBACB5CA87D9F8B4B9DD97DBFCB7E7FFC1D7F0AEC9DE9B
CDE49CCCE498CFE897D6ED9BD5EC9AC3D88BA7B872919F64E4F0C2E3EAC9FEFFEDFFFFF4
F0F0E8F7F6F1FFFEFBFFFCF9FFF9F7FCF4F2F9F5F2FFFFFBFFFFFDFEFFFDFCFFFDFAFFFB
FDFFFCFFFFFDF4F3EFF5F0EDFFFCFAFFFBFA8B79779C918B46463A7E8476F1F4EBEBF2EB
EDFBFBF7FFFFF2F1FFF7FFFFE2FFFFA0E0DF3482752F6C5CADB7ACCDBBAF513C29080200
D4E9AEACD08ACAF0A7BBE39AB1DB91C3EDA3C3EFA4BFEDA2
F3F8B8CDD393DAE3A24B5813BFD089CCE297D4EFA2C0DF8FCAE999C9EA99C9EA99C9EA99
CAE99BCAE99BCCE89DCDE7A0CEE0A6CEDCA7CCDDA6CDE2A7CCE6A7C8E7A4C5E6A1C3E79F
D0F4AAC0E298B7D58BDFFBB1DBF1A9B6CA83E7F6B1859650B4C984D6EDA9CBE59EE4FEB7
C6E19AC8E49ACBE99FD5F4A8C7E69AC5E498CEEA9FCAE69BD1EBA2D2ECA3C8DF97D9ECB5
CFDBC7FBFFFFFFFFFDFFFDF8FFFEF8FFFEF4F1EEDFFFFFECB9C2A5CDDDB9D3EABECAE4B4
CAE2B0D1E8B4E5F9C4F7FFD3F8FFCDF8FFCAD2E7A4C3D895C1D89299B06AC5DF98C7E19A
D3EFA5CDEBA1C9E79DC8E89DC9EB9ECAEC9FC9EB9EC9E79DDBF1B0CFDEA5656D3C565830
989576CAC5A80D09000E12007A855ACEE2ADCAE6A9CCEDA8C5E69FC6E7A0CAEBA4CBEAA4
D1ECA9C8E19DB8D28BC7E198CAE296C5DC8CDCF3A1C9E38CC7E38CCCED94CDF199C4EC94
BFEB94C1F19BC2F49FBCF1A3C2F9B841783F669C60C2F4B7BAE8A7BAE5A0C5EDA6C5EBA0
C2E79ABFE194D0F0A4BEDD91CFEDA3C0DE969AB870C6E89EC0E99BC0E699CAE49BDFEEA9
CED393807E415C5A1D848446D4DD9EE5F4B3C5DA99CAE3A1EEFFC3EBFFC0D6E9A9DCF1AE
CDE49CD0EAA0CCE798CAE390D0E996D3EA9AB8CC8496A667D2E0ADCCD7AFE1E7CBFAFFE9
FFFFF1FFFFF3FFFFF3F5F3E7FFFFF6FFFFF8FFFFFAFFFFFAFFFFFBFCFDF8FBFDFAFEFFFD
F8F8F6FAF9F7FFFEFBFFFDFBFFFCFAFFF2F1B4A6A3D3CCC4A1A99A5C6756FEFFF4FFFFF8
FFFEFBFFFCFFFFFDFFF1FFFFD5FFFF83CBC8387F7B9AC8C5FEFFFFFFFBF8565445101700
CDDCA3DFF3AEDAEFAAD9F3ACD1EDA3CAEA9FC0E296BEE396
D5D49BDADB9FDADEA15A6322D9E6A1E3F7AFC5DD91D0ED9DCAE999C9EA99C9EA99C9EA99
CAE99BCAE99BCCE89DCFE6A2D2E3AFDAE7B9E5F5C4F4FFD2F5FFD4EDFFCADEFBBBD5F4B0
C7E6A0D3F3AAC8E69CC4E096D7F1A8C4DB93CFE59DDAEFAA90A363AABD7DC0D594C6DD99
C4DE97D3EFA5CDE99ECFEEA0CCEB9DC9E898D0EC9FC9E598CDE79DD1EBA1D3EBA1EFFFCC
EFFCEAF3F9F9FFFFFDFDFAF5F9F2E8FFFFEFFFFFEAFFFFE6B1BD97C7DAADD3EBBBD1ECB9
CEE9B4C7DFABC3DAA6CBE0A8C9DD9EDFF4B1CADF9CCADF9CE1F8B2A4BB75C4DE97D5EFA8
EFFFC1E1FFB5D1EFA5C6E69BC5E79AC8EA9DCAEC9FCBEBA0C5DE9AD7E9ABD6E0ACB1B38B
827F5E3B36190602005253339EA97EDCEEBAC2DC9FC1E09DC5E49ECDECA6CDECA6C8E5A2
C7E09EDAF1AD849B55D2ECA3D9F1A5BDD889D2EE9AD9F5A0C8E68ECBEE94CCF096C4EB92
C0E88FC1EC93C4EF96BFEE9EB1E5A36CA369598F53C3F5B8B2E0A2CFF9B9BBE2A1CCF1AC
C6E9A5C5E6A1D1F0AAC0E097D6F4AEC3E39A85A35BCBEDA3BFE598D9FEB1CDEBA1C2D991
DAE9A6D3DE9CABB171999E5E767C3EE5EEAFD3DDA0D4E0A2DAE6A8F3FFC3E6F4B6C5D896
CAE39FD0EEA4D0EC9FC5E290C7E38ED6EF9CD5EC9EC9DD988C9E64D4E1B3ECF6D1EFF6D7
FFFFEAF9FDE6EEF0DAFFFFEDF7F8EAF5F5E9F8F8EEFEFEF6FFFFFAFFFFFBFFFFFBFFFFFD
FFFEFDC2BEBDA49F9CC8C0BECFC5C49E9492FFFCFAFFFEF8BCC2B8000500D7DBCDFAF7EE
FFFCF8FDF4F5FCFFFFE9FFFFD8FFFF64A4A40E3F44E9FFFFEAEDF4F0F0EEDEF3E2000F00
43491BFDFBC8DCDFA8E1E9AEE8F6B9C8DD9CD3ECA8CDEBA3
5A551E9E9B64F0EFB6D3D79A96A15DB8C982D1E99DD2EEA1CAE999C9EA99C9EA9BC9EA9B
CAE99DCCE89DCDE79ECFE5A5C7D7AAD6E2BCE6F5CCF5FFD9F8FFD8F0FFCDDAF2B6C8E1A0
CBE6A3CEE9A2D4F2A8C8E69CBEDC92DCFAB0CCE89EC7E19AD7EAAA505E219DAD6ECDE09E
E2F9B3BDD78ECBE79CC9E598CDEC9EC9E89ACDECA0C7E399C8E29BCCE69FD4EBA7F7FFD6
F8FFF3F9FFFDFEFFFAFFFFF4FFFFEDFFFFE6FAFBD9DDE4BABECC99C8DDA5C8E1A7C5E3A7
CEEBB1D0EBB4D1E8B4D6EBB3D0E4A5C9DE9BD7ECA9DBF0ADC4DB95889F59D1EBA4CFE9A2
EFFFC1E1FFB5D1EFA5C6E69BC5E79AC8EA9DCAEC9FCBEB9FD5F1A7CFE6A2DCE9B1DBE1B1
D3D1AB605B3B060300030500778055CEDFABD0E6A8D1ECA9C6E49CC6E49CCBE9A1CFE8A4
D5EAA7D7EAA8839853CCE39BC6E096E5FFB4C4E393C1E18EC8EA96C9EC98C9EC98C7EA96
C6E995C8EA96C7E995C0E699C3F4B280B476487A3DB9E9ADBEEAAFD2F9C0C2E5ABC7E9AD
C6E3A9CAE6A9C9E6A6C7E4A2CEE9A6CBE9A3839E57D1EFA7C5E79BCFF1A5CCEEA2C5E59A
CEE9A2DAF1ABDAEBA7D7E2A0525619545519D6D59CEBEAB1D9DAA0D2D69BE0E8ACD3E3A4
C7E29FCAE9A3D0EFA3CFEF9CCDEB95CCEA94CEE998D1E99F576A2AC3D19CDDE8BDBEC9A1
DEE5C3FEFFE3FFFFE3FFFFE6FEFFEDFEFFF1FFFFF3FFFFF4FFFFF8FFFFFAFFFCF9FFFCF9
FBF5F5857F7FECE3E4F8F0EEFFFEFBFFFEFAFCF7F3FFFEFAE5E1E0050402E7E8E2FFFFF8
FFFFF8FDFFF9F2FFFFE6FFFFE2FFFF83AAB1C7DAE9F5FFFFC8D7DCCBE6DDD5FFEE000F00
343017FFFAE3FFFDE3FFFFDFF3F1CAD2DAABD8E9B3C7DCA1
584E1BB4AD79CBC891E3E4A8AFB877E5F4AFD7EDA4C9E598CAE999C9EA99C9EA9BCAE99B
CCE89DCCE89DCDE79ECFE5A7E7F6CFF5FFE0F9FFE4F9FFE1F9FFDCF8FFD8E7FAC3CFE5A7
C9DF9EC8E19DC2DD96DDFBB1C5E59AC8EA9EC5E79BC8E69ECADA9CD5E0A4BAC88B889857
A5BA77E7FEB8C1DB92CEEA9FCAE99DC8E69CD0EEA6CBE9A3CCE7A4CCE5A4D1E7A9F5FFDA
E5F2E0F7FFF9F3F6EBDEDFCDEAE9CDCACAA6A5A8798B965ED0E2A4D1EAA8CAE7A4CBEAA7
DEFCBEEBFFCEF1FFD3F5FFD4D7EDADCFE4A1CEE3A0CBE09DD3EAA491A862CAE49DC6E099
D3EFA5CDEBA1C9E79DC8E89DC9EB9ECAEC9FC9EB9EC8E89CC7E698C3DD93CFDFA0E3ECB7
C8C99F5F5B360D0A00040400666E3FCBDAA3D5E9AAD4EEA7C8E49AC9E59ACBE79DCAE199
CCE09B6E7F3BB7CB86C8DE96D7F1A8BEDC92B5D589D4F6A9C8EA9DC7E99CC7E99CC9E99D
CEEDA1D0ECA1CEE89EC6E69DC5EFADAFDFA16B995B739F64B6DDA6C8EAB7C1E1AFD4F0BF
DAF5C2E0F8C4D7EEB6D9F1B5C6DF9ECEE7A590A965C7E29BC8E69CBFDF94C3E89BC8EEA1
BEE499BDE197CCE7A0D6E7A3C5C98C585319574C16A79C66DED59EE0DEA5DDE1A6D2E0A2
D2ECABC5E6A1C3E599CBEC9BCEF099C9EA93C9E692CEE99ACFE49F94A66A96A471C4D0A2
BFCA9F9EA67D9AA178A8B08BD1DABFD6DEC9D3D7C6B8BAAC97948B8C8781A49F9BC6BEBC
CDC4C5FCF3F4FCF3F4FFFDFDFFFBF8F7F6F2FCFBF6FBF7F6CDC3CC040005B9BBBAF5FAF4
FFFFF8F4FAF0F0FFFCE7FFFFEDFFFF9FB1BD1B2234E3F1FCE4FFFFCAFFEE407F62507B5F
7572617D6559CCB9AAFFFEE8F8F4D7E8EECAD2DFB3D2E4B4
5E5222988E5BE4DFA8EFEEB588915296A560C8DE95D2EDA0CCE999CAE999CAE99BCAE99B
CCE89DCCE89ECDE7A0CFE4A9E9F7D4F6FFE9F3FEE0E1ECCADFEBC3E6F3C5D7E5B2B9CB91
99AD6ED3EAA6D2EDA6C2E299C2E498C6EC9FCAF0A3CFEFA6E1EFB2D2DA9FCAD498C7D695
506321A4B974DDF7AEC2DE94CBE9A1C7E59FD0EDABCDEAAACEE7ADCCE5AECFE6B2F3FFDF
F7FFF3F8FFF8FCFFF1E6EAD1D3D5B0ABAE7FCBD398D1DD9BCBDF97CFEA9DC9E89CC9EBA1
D8F8B5DFFDBFDFF8BFE0F8BEB9CF8FDAEFACD8EDAAC6DB98E0F7B190A761C0DA93D9F3AC
C4E096C4E298C7E59BC9E99ECAEC9FCAEC9FC8EA9DC7EA9AD7F9A5C2DF8DE2F6AFC4CF93
9FA17235330A0703001617007E8653D7E6ABCEE3A0C8E299CAE49AD5F0A3C8E396AFC57A
5A6A23919E59CBDC96D6ECA4CFE9A2C7E79EE8FFC2BEE29AC8ECA4C6EAA2C7E8A3CBE8A5
CFEAA5D1E8A4D1E6A3CDE8A5B8DF9ED2FFBEA8D195395F26739562C8E5B5C9E4B7E3FACE
F5FFDFF5FFDCF7FFD8EFFFCCD2E7ACD5EBABB6CD89C3DA94D2ECA3D2F0A6CAEFA2C2ED9E
C2F1A3C6F2A5C5E99FC9DE99CACE91F4EBB28A7643725C2A7666329F965FBFBE85D6E1A5
D3F0B0C5E8A4BFE497C4E795C8EA93C9EA91CEEC96D5F09FCDE59BCEE3A2DEF0B6D4E2AF
BBC797D3DFAFEBF4C5CDD8ADD5E0C0E4F1D7F0F8E3DEE1D0BEBCB0B9B5ACE2D8D6FFFCFB
F2E8E9FFFBFFFAF1F4FBF5F5FBFAF6FFFFFBFEFFFAFFFFFFA8A2B0181425AFB4BAF4FAFA
FFFFFAF8F9F1EFFCF3F3FFFFF1F8FFF4FAFFC8D4E04F727472BDA93D9072266344C4E6CB
E7EFDA47422FA09E89FFFFEAFCFFE8F3FFDECBE0B7CEE5B9
7B6A3C867A4AD9D6A1D8DBA2C1CA8B8F9A58AFBE79D3E9A0CCE89DCAE99DCDE79DCFE69E
D3E4A0D4E3A2D3E3A4D3E2ABE9F5CDF7FFE2EFF9D6D4DFB7D1DAAFDEE7B8CDDAA5ACBB82
91A367A5BA79DBF4B0C4E49BC9EEA1CAF1A2BEE798BFE497CEE19FD9E5A7D7E6A5CCDD99
B7C884748841C9DF97D1E8A0D0E7A1C8E19DCFE5A5CBE0A5CBE0A7CADEA9D0E4B1F8FFE1
F8FFF1EAF5E7FCFFEDFEFFE4ADB3877A834CD7E3A1D4E69CCCE594D1EE9CC9EA9BC3E599
CAEBA4CBEAA7C7E3A6CAE4A5D6F1AECAE49DD4E9A4C9DD98CFE39E92A65FDAEFAAC9E098
CDE99FCCEB9FCAEC9FC7EC9EC5EA9CC5EA9AC8EB9BCBEC9BC5E28ED7F09FC9DA94E2EDB1
777B498E8F650405001C1F007C8654D9E8AFD2E7A6CAE49BCDE89BD6F1A2BED98896AF5E
AABA71CADA93E1F2ABBED48CD3EFA5CEEEA5B5D991CAF0A7C9EFA6C8ECA6C9EAA5C9E8A4
C9E4A1C9E2A0CDE3A2CBE8A5CFF8B2B2DD98BEE3A048672C284614D0EBC0E0FBD2DBF1CA
E8FAD0E7FBCAF2FFCFE1F9BFC9E3A6C7E09FCADF9AB9CD85CADE97D8EFA7C9E79DBCE295
C6F1A2C0EB9CBEE096D7EEA8E1EAA9DBD99CBEB37B665B23625C226161256A733497A567
CDDCA3D1E7A9D4EFAACEEEA2C6E894C3E58FC7E492CBE697D4EEA5CBE4A0C3DD9ECCE6A9
D6EEB2CEE2A5CDDB9ED9E6B0D3E4BADEEDCEF1FEE4FCFFEFFFFFF4FFFDF7FFF8F6FFF8F9
FFFBFFFDF2F6FFFAFBFFFDFDFFFFFBF8F9F4F0F5EFFEFFFF7F7B8A676475EFF3FCFBFFFF
F7F6F2FFFFFAFBFFFBFBFFFDFFFEFFF8F8FFEEFCFF84ACA31863451D6E4599CDA6C7E6C4
C8D8BE535F499BAA93D9EFD8E8FFE9EAFFECE5FFE5D1F3D2
BBA97B7B71409BA068C3CE92DAE2A7E5EBAF868A4DDAE4A5D1EAA6C8E39E6174349FA76C
958E5AA59B689D9D698286539CA471D5DDACC2C898CED5A2DEE5B2D2D9A5DBE4AFB0BB83
D8E6ABCADC9ED8EFABC8E69CCCEEA1C3EA97C4EE9ACBF29FD0EFA1CAE49AD8F0A6CDE59B
C6DA92BACE867E8F48DEEDA8D2E19CD4E3A0D2DE9ED5E3A5DAE8ABCDDB9ECFDEA3ECF9CB
E6EED9FBFFF1FEFFECAEB895BDC997D9EBADC6DC94C9E495C2DF8FC8E998CCECA0C8EA9E
C9E9A0CDECA6CDECA6C8E7A1C0E296D0F0A5C7DE96DBECA6B7C27E89934EDDE8A4D8E9A2
CDE79DC8EB9BC3ED9BC1EE99C2EE99C3ED99C6EC97CAEA97C7DC8FEAF7B1D7E1A28E975E
6E7645D9E0B60C1400384319929F74DDEFBDCEE3A8C7E09ED3EFA4C2E28FCAEB94C8E690
9BB061CFE499C9DF94E0F8ACCCE89BC8E99AC2E497CCF1A3C5EC9DC5EB9EC6EB9EC6EB9E
C8EA9EC8EA9EC8EA9EC5EBA0BBEEA1BFEFA3C3E398BCD593435D2EB4CEA9EEFFE8DCF7CE
D2E6B5ECFFC5E8FFBFE2FFBDD1F5B5B7DA98DBF1A691A25294A159B3C37CDCEDA6C2D88F
D5EDA3D3EDA3C7DE96D6ECA4CFE09AD8E7A2C4D38ED7E8A2CEE29BD4EAA2B3CD848B9B5A
605827544C1D8F985FDFF6B2C6E49AC6E69ACDE79DC7DE96C8E39ECEEFAAC2EBA5BBE9A0
C2ECA0CEF0A3D7EC9DC8D792D2E6B1DDF2CBEFFFE0F9FFEFFCFFF4FBFAF6FFF9F9FFFBFE
FFFCFFFFF7F8FFFDFBF9F4F1FFFEFAFFFFFBFDFDFDC0C1C347464CF3F2FAFEFFFFFEFFFF
FDFCF8FFFFFBFFFFFBFBFDF8F7F9F8FCFFFDF8FFFAF1FFF3CDF5D0B6E4B3CDF4BDC4E4B2
CAE2C2243C2610311C4D786574A796AADFCFDFFFFFDFFFFF
D9CB9A9B956191995EF0FEC1CBD598D5DE9FA9AF71B2BE7EDCF5B192AB67374708989D63
A49A677E72424F49173D3D096F773CB8C286969E63E9F1B8D5DDA4E1E9B0D2DBA49FA86F
D3E1A69EB072CCE39FD5F1A7BFE292C7ED9ABBE58FC0E892C9EC9AC5E695CEED9DCFEA9B
D4EA9FC9DE937D8D469EAB65DDE8A4D4DF9BDAE3A2D8E3A1CCD697D8E4A4E1F0AFD0DDA8
D8DEC2FCFFECFEFFE6687348CDDFA5D6EDA9DAF5A8C7E696CEED9DCCED9EC7E99CC3E599
C5E59CC7E79EC7E79CC4E69ACEF3A6CEF0A3C0D78FCBDB947E8542A7AE6AC5CF8AD4E59E
CCE89DC6EB9BC1EE9BBFEF99C1EE99C3ED97C6EC97CDE897D7E79ECDD695A2AA6E838C55
7D8554E9F5C70008000009006E7F53CDE1B0D0E8AEC7E29FCEEDA1C5E793D0F399CBEC93
7E9545DAEFA4D2E89DAFCA7DC6E295D0EFA1CBEC9DCEF1A1C6EB9BC5EC9BC5EC9DC5EC9D
C5EC9DC5EC9DC6EB9DC2ED9EB3E898C4F5A4CAE797D2E7A271885AA5BF9CEDFFEAC5E1B9
D1E5B0DCF0B1E0FCB2D2F6ACBDE7A5BAE19EDBF2A2CCDB8A909C528B9651D1DE98E1EEA8
CCDC95CCDD96E1F5ADC7DD94D1E99FDAF4AAD0ECA1D3F2A6CBEA9EBFDF93C0E094E2F3AF
AFA3739A875C65642EABB97BD3EAA4CBE79DD4EEA5D4EEA7D1EFA9C7EBA5BEE9A1C2F3A4
BFEC99B9DF88CCE48CDAF09ECFE7A9D4EFBCE3F8CFF1FFE2F9FFF1FCFFF6FFFFF8FFFFFA
F2EFE8FFFFF6F9F7EBFFFFF4FFFFF8FFFFFAAEB0AD7476759C9D9FFEFFFFFFFFFFFFFFFD
FFFFFBFFFFFBFFFFFBF9FAF5FEFFFBFCFFFAF1FCECE5F3DAEEFFDCD1ECB7B6D496C8E7AC
A3BE95000C000A351981B79D508E778ACBB5CFFFF5BBF2DF
E2E1A8D4D59B707638D0DA9BD5E4A1DBECA6BFD58DB0C87E879F55BDD48CCBDF98DCEBA8
C7D091D4D89DE4E5ABE7EBB0D8E2A5D2E0A2B6C284879256D3DEA2D2DDA18F9A60A3B174
D0E0A29BAE6EE1F8B4BEDA90CEEEA2CCF29FC7EF99CAF29CCAED9BCAEB9AC6E595C9E696
D3EB9FD7EDA2A8B9729DAD668A9752929F5A929D5B9AA664BAC684CEDD9ACEDD9CCCD9A1
DAE2B9BCC29EB2BB90D9E8B1CDE0A0D9F1A7B1CC7DDBFBA8D1F0A0CAEB9CC6E69AC8E89D
CBEBA2CBEBA2CCEAA0CCECA1CAECA0B6D48AC8DD989AA964D8E1A0CED794ECF9B4C9DD95
CAE99DC5EC9BC1EE9BBFEF99C2EE99C5ED97C9EB97CFE799DEEBA5E1E7A7B8C0847A834A
7D8552BECA9A0E1A00000B005B6D3DC0D49FD2EAAEC7E29FC7E69AC3E591CFF19AC9EA93
9BB166D4E8A0CDE39AF0FFBECAE49AC6E599D6F6AAB6D88BC6EB9DC6EB9DC6EB9DC6EB9D
C6EB9DC6EB9DC8EA9DC3EC9EC7F8A9C2EE9FC5E091CDE19C576D3E9BB590B5D4B4C8E7BE
C9DBA7CADD9DD4EEA5CEF0A6BCE6A4C8F0AACAE392DDEF9DE3F3A8CBDB945B6B244B5C15
DAEBA4E2F6AEC0D48CDBF1A8CAE298BFD78DD2ECA2C5E196D9F5AAD2EEA3B1CD82D4E8A3
D9D8A0DFD8A2939357686F2CC9D690CFE499CBE59BC1DF95C4E49BC2E39CC4E59EC8EA9E
CEED9FD2EF9BD0EA91CCE591C8E69EC9E5A8CEE9B2DCF3C5EBFFDAF3FFE4F3FFE4EFFCE2
FBFFEAE9F2D7FCFFEAFCFFECF5FDE87F86762A3024B4B9B3FDFEFFFEFFFFF8F8F8747472
484743585753ACABA9C2C1BFFFFFFDE6E8E3FBFFF6303C26879874BDD3A4DCF5BCD1EDB2
0A220038552580AA7AC0F5C7A3E0B463A577C7FFD5AFE7BA
DAE5A3D6DF9E8B9050616825DBECA5BCD78AD9FAA9C7E897CFE799D2E79AD6ECA1D4ECA0
D4EEA4DBF1A9D5E09ECDD695DBECA8C8DC97D6E9A74A5A1995A5667383446E7E3FD1E1A2
CDE0A091A663C6E099CBE79DC9E99DC5E898C7ED9AC7ED9AC7EA98CDF09EC9EA99CAE999
C9E497D3EB9FD7EBA3CBDC95909F5A53621D5F6E2B748340505F1C4C5D19576726314103
202A0057612DE7F4BCC8D899D6EAA3C1D98DE7FFB3BCD989CBEA9CC6E798C8E89CCFEFA4
CFEFA4CBE99FCAE89ECDEBA1CAE8A0D8F1AD81945293A261D6E2A2D6E2A0D2E39FC4DE95
C8EA9EC3EC9DC1EE9DC1EE9BC3ED9BC8EB99CCE999D1E69BD1DC9AD2D89A979F63555E25
D1DAA3D9E6B15D6937000E007D9059C4DCA0D2ECABC8E6A0C8E89DC2E593C9ED96C9E996
8BA1584A5B17C5D994BCD18CD2ECA5CAE59ECEECA4D0F0A5C8EA9EC8EA9DC8EA9DC8EA9D
C8EA9DC9E99DC9E99DC6EB9EB9E397C8EEA1DEF4A9CDDE9A9AB07F5C7852C4E6C5BCDAB4
D1E4ADD2E5A3C6E099C9EAA3C1EBA9D1F9B3C2DB8ACEE18FC6DB8ED5E9A1C6DA92D8ECA4
D2E89F4D631A41570E97AD64D5EDA3E4FCB2CDE59BCBE399D6EEA4C1D98FE6FFB6CCE29A
D4DE9FDFE3A6E2E2A25A5B17CBD189E8F6ABD4ECA0CCECA0CAECA2C8E6A0D0E7A3CCE099
D2E299D9EF9DD1EB92CDEB93CAE999C6E69DC5E4A1C9E7ABD2EDB8D5EFBFD1EBBBCDE4B6
CDE3B4DFF5C6D3E4BAC6D6B1D1DEC079856D828B7AFBFFF8E6E8E7000002030303050503
C1C0BCD7D6D2666563010000C9C7C8FCFCFAFCFFF8040D00E3F0D2E4F5CB91A570000D00
000F00C2DDAABAE0ADB8EAB7C8FFCF82BE8A3B743DBAF1B8
C7DD95D9E9A2A2A562656B257C9345D0F39FBCE88FD0F8A0D4ED9AC3D685CEE796CDED9A
C7F19DBBE18EC6D88EE2EFA7CDE39AD5EFA5CDE79ECCE39BA7BE7898AF6BC9DE9BDCF1AE
DCF1AE92A96386A059DCF8AEC4E397CAEB9CCAEB9CC5E898C2E595C9EC9CD0F1A2D6F5A7
CCE89DC3DD93D7EFA5CEE49BDBEFA8CCE099C7D892D1E59EDAEEA9CDE29DC3D893CBDF9A
D5E4A3CEDD9AC3D28FCADE97D6ECA3D8F0A6C3DE91D5F1A4CAE99DCAE99DCCEAA0CDEBA1
C8E69CC5E196C6E297CBE79DD0E6A5D5E9AA8B9B5DD7E5A8CEDC9EDCECABCAE19DDCFAB2
C5EBA0C2ED9EC2ED9EC3EC9DC6EB9DCAE99BD0E69BD4E49DD7E0A1ECF2B68F975C525C20
DAE3AACAD89DD6E3ABCADCA0BACE91D2EBAACFEAA5CCEAA2CFEFA4C7EA9AC9EC9ACFEEA0
C6DB96DBEBAC9AAA6BDFF2B2CDE4A0CFE8A4C1DC97CCEAA2CAE8A0C9E99EC9E99EC9E99E
C9E99DCAE99DCAE99DC9E99ECDF1A7B7D78CCDDF958594532C400D213D154F7051A9C7A3
D5E8B0E4F7B5C4DE97C6E7A2BCE7A2CBF3ACCFEA99CEE491DAF2A4D3EDA3D6F0A6CFE99F
C7DF95C9E197E2FAB09FB76D6E843B758B42D6ECA3D6ECA3C8DE95CFE59CD4E8A0CFE59C
D8EFA7C9DA93DFE29D817E39ABAB63CCD489C5DC8ECCEB9FCEEEA5CCE39FE6EFB0E7E9AA
E0E39ED6E394C1DB84CAED91CEEF98CCEE9ACAEA9EC8EAA0C5E9A3C3E8A3C1E6A1C0E5A0
BDE09CBDDD9CC6E2A7CAE2AEDCEEC6F8FFE82D3925000400070906ADAEB0FEFFFFE9E9E7
FFFFFBFFFFFBFFFEFD040001C9C4C8FFFEFFECEDE8696D5FE7EFD7C1CDA9A5B284000A00
95A57ECCE2BCC6E8C3BBE8BF7FB48A01390A4E8251497E48
CBE59CCCE098DBE09D4046009FB668C9EF9AC0EE94BFEA90CDE693D7EA99D5F19DBCDF8B
BAEB92D1FDA8D8F0A2C9DE93D5F1A4CBEA9CB2D183E3FFB6C8E49ADCF8AECDE79EBCD68D
D1EBA4C7E19879954B6B873DD4F3A7CCEB9FCFEEA0CCED9ECBEE9EC2E797C9EC9CCDEE9F
CEEDA1C1DD92D1EBA1CAE49AD3EAA2BFD68ED5EBA3DEF4ACC5DC96D8EFA9ECFFBDCCE39B
D8E9A2DFF1A7E4F5AED9EDA6CEE59FCCE69FCCE7A0C9E49DC9E79FCCEAA2CBE99FC6E599
C7E396CCE89BD1EE9ED6EEA4C6D89A7B8A51C7D49CD3E2A7E0F0B2C3D998D6F1AEBDDE97
C3EBA2C2ECA0C3ECA0C5EB9ECAE89ECFE79DD3E49ED7E2A0D7DDA1B9BE84464E13606A2E
DDE7AAD3E1A3D5E5A6D9ECAADAEFACD2ECA5C7E29BC6E69BCEEEA3C9EB9EC4E999CFEDA3
D8EBABD2E0A58E9D62C7D99BD5E9AACBE1A0C4DD9BD2EDA8CCE7A2CAE8A0CCE7A0CCE89E
CCE89DCCE89DCDE79DCCE89DCBE99FCCE69DE6F3AD859151566D390120004C6F5187A782
AEC388D0E19DCEE5A1D2F1AEBFE8A4C0E89FD3F09ECFE694CBE79AC5E498C6E599C9E89C
D3EFA4B4CE84CAE49AE5FDB3D5EBA290A65DD8ECA4D1E59DCADB94E3F4ADC3D48DD3E9A0
C8E79BDFFAADCCD48BB7B76F64611A9B9E57D0E298D3EAA2DAF1ADCCDC9ECFCE96B0A972
BBB778E2E8A0D2EB98CEEF96CCEA92CEEC96CCEE9AC9EC9AC3EA99C0E99AC2ED9DC5F0A0
C5F0A0D7FFB2C4E5A0D3EFB5C2D7ACF1FFE1F7FFEDF4FAF0FCFEFBF8FAF9FBFDFAFEFFFD
F5F4F0FEFDFBFFFEFFFBF6FA767177706B6F656462010100E5E8D3E2E7C7AAB188626D43
AABA95D7EFCDB3D5B0618B633D714394CA98A3D8A0C5F8BD
CDE49EDDF1AAD5DC985C631D93AA5CC1E38FC5ED97C4EA93D0E998D3EA9ACBE695CFF2A0
C1EE99BEE997C7E698CEE99CC7E698C0E190D3F4A3BADB8CC9E89AD7F6AAB9D58AE2FEB3
BDD98FDEFAB09DB96F3D590FCFEBA0C6E297C7E398C6E599CFF1A4C2E799CAEC9FBDDD91
CCECA0C9E89CD0EFA3D1EDA2CAE49AD8F2A8CFE9A0C3DD94CAE49BC9E39AC0DA91C3DD93
D7ECA1C0D58AD0E49FD8EDACDBF1B3DFF7BBEAFFC7BDD99CC6E3A1CDEBA5CEEAA0C7E396
CCE798D6F1A0D1ED99C6DC91DAE8ADAAB480DDEAB5D7E6AFC8DCA1D0EAABD6F5B2C1E6A0
C3EBA2C3ECA0C5EBA0C8EAA0CDE7A0D1E59ED6E2A0D8E1A2D9DEA493985E666E338F995C
CDD798DAE9A6D0E19DD0E69ED3EAA2CBE59BC8E499C3E398C8E89DC9EB9FC2E79AC9E7A1
D3E5A9DEEBB588975EBFD197D1E5AAC6DC9ED8F1B0C7E09ECDE6A2CCE7A0CDE7A0CDE79E
CDE79DCDE79DCFE79DCFE79DD2E9A1C9DD96DCE5A28F995C3E57205E7F54476B4FC0E2BF
94AA6C9FB069CFE4A3D6F3B3C6EFA9C0E99DCAE795CCE592D6F5A7B5D78ACCECA0CEEEA2
D8F7ABD5F4A8D3EFA4B8D288CCE49AC5DB9295A961CBDC95E0F0A9CDDD96E0F0A9CADE96
B7D78BDDFCAED5E59ADCE29A5758128E914CE0E9A6DDE9A9CED99FAAAE7BA19B6B827847
8D864FB9BE7CBDD285D8F4A0CBE290CCE592CBE896C8EA96C3EA97C0EC97C2F098C5F39B
B7E58DB2DD8BD2F6AECCE8AED3E5BDFBFFEDFEFFF6FFFFFDFEFFFFFEFFFFF2F4F1FEFFFD
FAF9F5FFFFFDFFFBFCFFFBFFDDD6DD403940797576030000D8D7C5CFCFB38F916C4B5229
C5D6ACB1CCA1759B6C0E3D09457A42B3EBACD6FFC7AFE79C
D2E2A1D9E8A7D2DD9B98A35F47581188A054E0FCAFCDEA9AD1E99DD4ECA0BEDA8DD0F0A4
C6EB9EC5EA9DCBEBA2CBE99FCDEE9FC8E998CEEF9ECDEE9DC2E394C3E294CBEA9EC3E296
D4F0A5C6E297C7E399D2EEA4BEDA8FD9F5AAC9E59ACAE99DC2E497C3E89AD8FAADBDDF92
CFEFA3CCECA0C7E79BC7E69AD0EFA3C4E397C3E197D0ECA2D3EFA5C8E49AC8E49AD6F0A7
CBE199D8EDA8CEE2A3F3FFCFF5FFD8F4FFDACDE7B7D4EFBAC7E3A8D0EDAAD0ECA2C9E495
CDE897D3EC98BBD4809AAF64818A55D2D8AAD2DCAAD7E8B2C7DCA3CDE9ACC6E9A7C8F0A9
C3EBA4C5EBA2C8EAA0CAE8A0D0E5A0D4E3A0D8E1A0DAE0A2757A405E662BD5DDA1E2ECAD
D6E2A2D5E49FD2E69FCAE097C9E195CBE79AD4F0A5CAE99DC8E89DCFF1A5C8EAA0C7E4A1
E6F8BEF3FFCBF0FDC74E5F28E0F2B8DCF0B5CCE2A4CAE3A2CDE6A4CDE6A2CDE7A0CDE7A0
CFE69ECFE79DD0E69DD0E69DD0E49DD6E5A0D9DF9F9AA46748642A6288592951368AAF8D
A4BD7C83954BC8DC9DC8E4A7C4ECA6C7F0A2C6E391D4F09CCDEE9FBCE193D7F9ACBEE093
C3E397C9E99DCCE89DD0EAA0D3EBA1D1E79ED3E79F8B9C5574843D99A66075823CD6EAA2
DAF8AEB4D288D3E9A0DBE8A06D7430696E2C92965B9797617A794959562BA29A73DBD4A8
BDBB8870763A55641FB1C379D4E499D2E498CEE499CAE699C7EA9AC4EB98C2EE97C1EF97
CFFDA5CBF4A5B3D390F4FFD8EDFCDBFCFFF3F8F7F5FFFEFFF3F3F5FEFFFFFBFDFAF6F6F4
FFFFFBF7F6F4FFFEFFFEF9FDFFFCFF3B343B040000040000FFFFF1F9F5DCB9B695535830
C4D9AE45653689B081BDECB8B2E9AFC7FFC0A2DC92BEF8AB
D8DDA3DDE7ABD4E4A5D3E3A27B8A474D5917B6C17FD3E29DCFE6A0D1ECA5CAE5A0C4DD9B
D3E9A9CDE6A5C5E3A3CCEDA8C8E69CD1F0A2C7E698C6E597D2F1A3CAE99BC3E294CFEEA0
CDE99CBEDA8DD1EDA2DAF6ABA6C077C8E299CCE69DD2EEA4CCECA1C7E99DD5F7ABC0E296
CEF0A4C9EB9FC9EB9EBFDF93C9E99DC9E99DC9E99DCAE99DCAE99DCAE99DCAE99DCCE7A0
CEE4A3CBE0A5D2E6B3F3FFDDF2FFE1F4FFE6DDF6CFCBE5B8C1DCA5D7F4B4D3EFA5C3DE8D
D1EA97C7DF89CDE58F92A45AC8CF9CC6CBA2F1FACDF1FFCEDEF7BEE4FFC4DAFFBCDAFFBB
CBF0AAC0E19AC8E69ED5ECA6CCDC9BD8E4A4E0E6A8B3B97D3840056A7539CBD799DEEDAC
D1E09FDEEFA9D0E49DADC37AB6CE84C5E196CBE79CC9E89CC7E79CC6E89EC8E9A2C9E6A3
F1FFC9F0FDC8FCFFD46B7C45E6F8BED0E4A9D3E9ABD1E7A7C0D997D4EDA9CCE39DDFF6B0
C9DF97CDE39BD6EAA2C5D991DBEBA4D0DB97E5E9AC8C975B68864A87B17F49775D396242
C6E19CC3D889C7DB9EC8E1A7CEF3ADBFE89AC3E08ED3F09EC4E797C9F0A1C4E99BCDEFA2
BDDD91DAFAAEB8D489D0EAA0C7DF95D7EDA4DCF0A8C3D48D9BAB6487975095A25CA8B973
CCE39DCEE9A4C3E199CCE69FB5C886959F625D5A275E5228756744B2A885B4B08DC7C9A2
EFF7C8A3AC775D672A959E5DDAE3A2D7E2A0DCEBA8BFD38EC8E39CDBFBB0B4D98BCCF3A4
C5EB9ECEEFAACEEAB0F7FFDFFBFFEFFAFBF6FFF7FFFFFBFFFFFEFFFEFFFFFFFFFDFFFFFD
FFFFFBFFFFFDFFFEFFFFFEFFFCF7FEBAB3BA040000060000FFFFF1FFFFE8A39E7EADB18C
BDD6AE51764BA2CDA2B4E5B6BDF3BFB8F4B8AEEBA87EBB75
D2D29CE3EBB2CADE9FCAE0A0CCD89AA5A96E49470EBBBF84D1E6A5C5DF9ED1E9ABDDEFB5
D6E0ABCBD9A4C5E2AAC4E4A5CAE5A0D4ECA2C9E197CBE399CDE89BCDE89BD1EDA0C7E396
D0EC9FD1EDA0C8E499C2DE9397B168DEF8AFDCF6ADBEDA90C7E79CC0E296CBEDA1BCDE92
C6E89CC1E397CEF0A3D4F6A9C8EA9DC8EA9DC9E99DC9E99DCAE99DCAE99DCAE99DCCE7A0
D1E9ADC8DFABCFE4B9F4FFE6F4FFECF4FFEDDAF2D2CBE4BCD1ECB7BFD99AC6E096D2EB9A
D0E894F0FFB3C5DB88BBCB84E7EDBDDFE4BCF8FFD8F6FFD6E6FFC8EEFFCFE7FFC9E7FFC6
C2E39CCBE9A1CDE49ED6E7A3DFEBABCAD495999F63636B2FB9C587CFDD9FD6E6A7C8D897
DBEBAAC5D994475D15142B00758F46CAE49BCDE99FC7E59BCEECA4CDEDA4C5E59CCAE5A2
D4E6ACCDDAA4DAE8B3CEDFA8E8FCC1F5FFCDCFE5A7C8DE9EE4FDBBC5DE9CC2D995C8DF99
6A7F3A8DA35BDDF1AADAEBA4CAD791DFE8A5D9DDA098A669ACCF8DB5E6AF5D8F76154223
C8E69EC8DE8CB3C58BC8DFA7CDF2ACC5EC9DC6E595CDEA98CBEE9EBADF91D0F5A7C0E295
CDEDA1C2E195D8F4A9CBE79CD8F2A8CBE399C3D990CCE098DCEDA6D6E7A0B8C88199AA64
D7EAA8D4EDABCCEDA8C4E5A0D2EDAAD3E1A6D6D2A3E6D6B2FFF6D8FEF0D5FFFFE3F2FCD7
C9D9ACDEECB7C7CF965A5E23BBBF84D5DAA0D1D99EF0FEC1C5D99AD2EBA9D4F2ACC2E19B
C4E39FCCE6A9C8DCABF3FFDEFCFFF1FFFDFFFFF8FFFFF9FFFFFDFFFFFFFFFFFFFDFFFFFD
FFFFFBFFFFFDFFFFFFFFFEFFFFFEFFFFFAFF0A04060B0400FFFFEFFFFFE59A9472FFFFDF
EEFFE5DCFFDFC1EAC8B9E9C3AEE3B9B3EDBDB8F4BE9CD99E
A5A46ED4DCA3D5EDAFCCE5A4DAE4A8ECEBB38A804BA8A570E3F2B7C5DDA1D9ECB5FCFFD6
FFFFD6FDFFDAE8FFD3CAE8B2D2E4A6CCD896D8E7A2E5F6B0D3E79FCFE59CD5EDA1C6DE92
C2DD90D5F0A3C9E399D5EFA58AA45B8BA55CC1D892D2ECA5D4F2AACEEEA5D2F2A9CDEDA4
D1F3A7C2E498C5EA9DC6EB9EC6EB9DC6EB9DC8EA9DC8EA9DC9EA9BC9EA9BCAE99BCAE8A0
D3ECB2C8E0AECDE3BCF4FFEAF4FFEFF2FFF1DBF2D5CCE5BDC7DFABD8F2B1C3DE91D1EA97
D8EE9C879A49415307CEDD9CCBD1A3D9DFB9FBFFDCF6FFD9D4F1B7C9ECACC9ECA8D5F6B1
CAE59ED9EFA7D2E19CD4DF9DD2DC9D959E5F646C30798346DBEBAACADD9BD5E8A6D2E7A4
D0E5A2CBE09D2F4602000F0058712DDFF8B4D0E9A5C7E29DD4EFA8D1EFA7C5E39BCAE39F
C8DA9EE0EFB6CEDDA6B5C78DF5FFCEF7FFCFE6FCBEDEF7B6C7E09ED2EBA9D9F0ACCDE49E
4D621D617530B2C37FDCEBA6E6F1ACBFC885A3A96D97A96BACD58FC1F8BEADE5CC154628
C9E99ECFE59297A871C9DDA8C9EDA5C8EF9ECBEA9AC8E595C3E495CFF1A4BCDE91D3F3A7
C1E195D2F1A5C8E499D0ECA1C5DF95D0E89ED9F1A7DBF1A8D5EBA2CEE49BCCE098CFE09A
546224AFC384D4F4B1B0D590CBEBAAC8DBA3DEDBB0F5E5C4FFFDE3FFFEE3FEFFE4E7FCD5
BFD7A7E1F6BEE8F0B796975D585920555821D9DEA8D7E0A9D7E4ACB9CB91E4F9BEC4DCA0
CBE3A7DBEFBAD8E7BCFCFFE8FEFFF5FFFDFFFFF9FFFFFAFFFFFDFFFFFFFFFFFFFDFFFFFD
FEFFFBFEFFFDFEFFFFFFFFFFF2F0F5FFFDFF0C0606060000FEF7E5FAF5D89B9571FAFED9
F1FFECD6F9E1C3EBD3ADD9C0C7F7DD53886A3B7350B2ECC4
B3B87E758044CDE6A5CAE3A2CAD497EAE9B1A59B66958F5BC8D59DC9DCA5D6E7B3F6FFD2
FFFFD9FFFFDFE2FBD1C3DDAEC4CD965C602573773A9AA362ABB672CDDD96D3E49DDFF5AA
C9E195D8F3A6C0DA90C9E399C2DC93375108DFF6B0CFE9A2C5E099C7E59DC4E29AC7E79E
CEEEA3CAECA0CCF1A4C0E598C6EB9DC6EB9DC8EA9DC8EB9BC9EA9BC9EA9BCAE99BCAE89E
CFE9AACBE3AFCCE3B9E7FFDDE8FFE3F2FFEFE0F8D8CBE4BACBE4ABD4EDA9CEE698CEE593
D5E899ACBC73CDDC99DBE6AED0D7ADE3EBC4F7FFDBEDFFD2CEEBB1BBDE9EC0DF9CCEE9A4
C4D994D8E7A2D6DF9CB4BB788C9252697233869254E3F3B2CDE29DBAD189D7EEA8DCF3AD
C8DE9DD1E7A7354B0D0013005A7234DAF2B4BDD695C5DE9CD0E9A5CCE69FCEE89FD3EAA4
C7D99BDAECB0B0C28674884BD2E8A8C5DE9DE2FBBAE6FFBDCBE4A2CEE7A5CCE39FD5ECA8
879C57A1B570A6B77395A46177823D68712E889256CAE0A2C8F8AEB3F0B4B7F5DC063B1D
C6EB9ED5ED9782935DCCE0ADC4E8A0C6ED9ACFEF9CC7E293C8E497D3F2A6CDECA0C1E094
DCFBAFD4F0A5BAD68BD2EEA3CDE99ECFE99FCFE99FCBE59BC6E096C8E298D2EAA0DBF1A9
889658A0B274D3F2AED7FAB6C2E2A1D2E7AEFFFFD8F7EFCBFFF9DCFFFFE4EFFDDAD7F0C6
D2EEBBC6DFA5C7D597E0E6A87F85494D52187F844C8E976098A26D9DAA74CDDCA5D1E2AB
D3E4AEEEFECDF3FED6FEFFE8FEFFF3FFFDFEFFFCFFFFFCFFFFFDFFFFFEFFFFFEFFFFFFFD
FEFFFBFEFFFBFEFFFDFEFFFFFFFFFFF6F4F5BDB9B6070300EEE9D5E2DDBF9B986FD4DBB1
E3FDD6D9FDD9C5EAC9D3FADDBBE6CA2654372357334C845D
C8D995B7CC878BA55ECCE39DE9F5B5C7CD8FB7B67D3637007D864FC8D5A0D6E2B2D6E1B6
DEE6BFFAFFE0E8FED8F5FFDDFFFFD66056237E7942848249575B1E646D2C6A7731C5D68F
DCF2A7C1D98DCEE89ED8F2A8B7D188D6F0A7728C4557712AC1DA96D8F3AECEE9A2CBE9A1
C3E39AC8EAA0D4F9ACC8EDA0C6EB9DC6EB9DC8EB9BC8EB9BC9EA9BCAE999CCE999CCE89D
C7E59DCDEAAAC9E4AFD4EFC4D3EDCAF1FFE8E3FED5CAE5B2CAE4A3CCE69CE2FBAAC8DF8F
8FA157889756E0EAB5CAD3A6FEFFDFF4FFDAD8EBBECCE4B2CCEBB0CCECADCEEBA8D0E7A1
F0FFBAA0AA65717431666827909555CCD795D4E3A2CBE09BD1EBA1D4F3A5CEEAA0BFDA93
D3EDACD1E9AD152C00000D00677C44CEE3ABC5DAA1DBF1B3D5ECA8BED58DD4EAA1DBF1A9
CFE4A1C8DD9CA5BA79C9DF9EC5DB9AC9E2A0E2FBB9E9FFBFDEF9B4BDD893CBE4A0D9F0AC
91A663CBE09DD2E5A38A9B5799A660BFCA86C0CB8FD0EAABCAFFB2A2E7A6A6EAD1538E70
C2E99AD7F19A7D8E58CFE3B2C2E49AC2E893D1EE9CCDE597D6F1A4C1DB91D1EBA1CDE79D
C3DD93D9F5AABFDB90D5F1A6D0ECA1CCE89DC9E59ACCE89DD0EFA3D1F0A4CAE99DC6E097
D5E9A4B0C3817F9854AECC86D4EFACDAF0B2E1EEB9EFF8CBF5FDD6EDF9D3E1F6CBD4EEBE
CAE7ADCBE8A6D4EAA2D3E49DD5E29CD0DB998A94559CA76B8F9A623E4813A0AD77CFDCA6
D4E1ABECF8C6ECF7CCFCFFE4FCFFEBFEFFF6FEFFFFFCFDFFFFFEFFFFFEFFFFFEFFFFFFFD
FEFFFBFEFFFBFCFFFDFCFFFFFEFFFFFEFFFD6F706801020076765CC6C6A29C9B6DCFD8A1
F0FFCBC7ECA9CEF2B58DB37A1A420EAFDBA8A7D7A386BB83
D2F1A5D7F3A896AE64C8DC94CEDF99EDF9B7BFC98A373F03757A42DAE1AEDAE3B4C8D5A9
D2E3B9F5FFE3F0FFE0FBFFE1FFFAD1665328B9AB7CD4CA97928D5578793D5F6825C6D38D
D3E49DCCE297D4ECA2C3DD93EEFFBFC4DE959BB56E2A44009EB773CCE5A1CDE7A0DAF5AE
C6E49CC0E298CFF1A5C3E89BC6EB9DC6EB9DC8EB9BC8EB9BCAE999CAE999CCE999CCE999
C6E595CDEBA1C7E5A5CBE8B2C5E0B3E5FFD5DEFAC9C8E6AAD6F1AABDD889CDE693D5EA9B
B1C27CC5D098C4CBA1E9F1CCFCFFE3F5FFDDCBE1B3C0DBA8C9E8ADC6E6A5CBE6A3CCE09B
D4DE996B6E2B6A6928989756B8BD7BDAE5A3D5E8A6CBE59CCCEB9BC6E796CAEA9EC0DE98
CBE8A8D0E9B0364E1A000F006A7E4DCCE0ADDBEEB7D5E9AEC1D69596AA63A6BB70AABF74
99AE69BED58FA8BF7BD6F0A9C6DF9BCFEAA5C2DD98C9E49FC7E29DCEE9A4DAF3AFC2DB97
A0B572CDE29FDBEEACCCDD99CCD993E0EDA8D8E7ACC7E5A5BAF5A3A9F2AD70B8A03D7C5F
BEE997D5EF96839460D1E4B6C3E59BC0E691CEEB99D0E89AD1E79CA6BC73BFD58CE6FEB4
8EA65CCAE49ACFE99FCEEA9FC3E296CBEA9ED1F1A5CFEFA3C8E89CC3E598C5E79ACCEB9F
C9E098D4E8A196AA63A8BE76BACF8CBCD291BED69CD8F1BAC8E0B0C4DEAFCDE5B5CEE7B0
C7E1A2CAE8A0D1F0A0CDE995CCE192E9F9AEDCECA5D0DF9CD8E3A7535E24717C44D2DDA5
D6E1A9DEE8B3D2DEAEF3FFD7F7FFE2F9FFEFF9FFF6F8FFF8FFFEFFFFFDFFFFFEFFFFFFFD
FFFFFBFEFFFBFCFFFDFCFFFDECF1EDFCFFFB000200121502606344DDDFB77D7F4ED0DA9D
C6DE92D0F1A0CBEBA0C8E8A583A769BCE4A8BEEAAFC2F2B6
C4F29ABDE58F849B4BE7F9ADC6DB90BBD389D7EEA677874682854CDADAA8D7DDADCCDEAE
C4E1B3EEFFE3D2E8C2D3D9B7EDDDB95F4520A79168F6E5B7F3E9B4D9D79E8D92528F9A55
D8E8A1D3E79FCCE49AC3DB91D0EAA1C1DB92DAF5AECCE69F839A56A1B8749AB36FCBE6A1
C9E79FC2E49ACCEEA2C4E99CC6EB9DC6EB9DC8EB9BC8EB9BCAE999CAE999CCE999CCE995
CBEC91C9EC92C4E498CFEEABC2E1A8D4F2BCD0EEB2C9E8A4CAE699C9E591DFF8A4CBE091
A2B170DFE9B7EEF3D3F2F8DCF3FEDCF7FFE1D9F0C2CFEBB8D1F0B5C3E1A1CBE4A0D4E39E
BBC07D6C6926999452DCD898E5E7A6DAE5A1C2D792CDE99FCEF09CBADD89D6F8ABD0F1AA
C0DEA0C7E2AB617949000D005E7046C9DCAED1E3B192A36CA6B97991A25C93A55B90A256
A0B66EDBF2AAD3EAA4BED88FDBF6AFD7F5ADC7E59DCBE9A1C5E39BD7F2ABC4DD99A6BF7B
E4F9B6F1FFC3CCDF9FD9E9A8DEEEA7C5D48FD1E3A7C5E8A6B3F39FB2FFB94591775B9C7E
C0ED9ACEEB8F8C9D69D1E2B5C9E9A0C4E793CBE896D1E89AB3C87D9FB069D4E8A0CBDF97
B9CF868EA65CE0FAB0C3DF94D1F0A4C8E89CBFE194BEE395C5EA9CC9EEA0C7EE9FC5E79A
CCE89BC5DB90DCE9A1DBE79F77843F7D924DD7F7B6B7DFA0B9E2A8D5FBC2DFFAC3DAEFB4
D7EEAAC4E093B8E087CEF799CCEB8EC7DF89BDD381D7E99FD9E8A5DDE9AB515C20DFE9AD
D7E2A6D8E3A9C9D6A0E6F6C5E5F6CCE9FAD8EDFFE6F7FFF4FFFFFDFFFDFFFFFEFFFFFFFD
FFFFFBFEFFFBFCFFFBFBFFFBFBFFFBF2F7F06D7365363B25C9CDACC8CB9E6B703ADBE6A4
DCF3A3C1DC8BD1EBA2C6E09FCDE8B1678553385D2AB3DBA7
BFF296C7EF97CEE394DAE69ED3E49DD4EBA5CFEDA5869F5B465013A3A66DCCD19BE5EFBB
CDE4B0F2FFDDE1F3CBD9DDB8E3D1AB775E369E895EE3D5A6E5DEA8D8D79EABB171939E5A
CEDB96D7E7A0D7EBA3DBF1A8CBE59BCDEBA1C6E89CCCEEA2D4F0A6C1DB9290AA63C5E099
D0EEA8C9E8A2CFEFA6CAEAA1C9E99EC9E99DC9EA9BCAE99BCCE999CCE999CDE89BCCE997
D1F496C5E88AC1E38FD7F7ACC7E6A3C8E6A6C4E19FCDE8A1D2EDA0D0E79962772A4F5E19
D3DCA5E1E6BDE9E9CDFFFFEAF8FFE6F4FFE3C7E1B2C0DDA7CEEAAFC8E1A0D1E5A0D5E09C
989B589A9656DEDA9AE6E6A6D3DA97D9EAA6C7E19ACEEEA2C8EA96CCEE9ACAEA9EBBDA96
D9F5BAD2EAB85F7547000B0062744AD7E8BBCBDCA867763DBCCC8DD6E7A3D7E79ED1E399
D0E89ECAE49AD1EBA1D4F0A5C4E397C6E599CAE89ECCEAA0D0EBA4C4DF9ACDE6A4C2D697
F9FFCDF5FFC9D5E4ABD3E3A4D1E198CFE499DCF2B1BFE4A1AFEC9E79C07E00190078B593
C4F0A3C6E69191A46DD0E2AED1EDA3CDE897CEE396D3E59B8DA159CDE39AD1E79ED5EBA2
E0F6AD879D54CEE49BD0E69DCAE298CDE79DCFEEA2CEEEA2C9EB9EC4E99BC4EB9CC6EB9B
C3E493D3EB9DD0DE93DCE8A0D2DF998196519CBC79B8E19FBDE5A7E3FFCCF4FFD3DCEEB4
CEE19FD7F1A7CFF5A0BBE38AC8EA8CCFEC92D5EE9DD2E89FD7E7A6CBD99B515D1FD4E0A0
D2E19ED9E8A5CDDD9CE1F5BACAE0AFC5DBB4D7F0D2F5FFF4FEFFFDFFFEFFFFFFFFFEFFFF
FCFFFFFCFFFDFCFFFFFCFFFFFCFEFBFFFFFB000200010300949875505324A3AB70CEDB96
C8DF8FD9F4A3CAE199D1EAA8D8F1B7BFDAA3BFE0A9CFF2BC
BFEA90C8EA96E0EDA7525619DADFA7D0DBA3DDF7BAA4C17F90A76372813CA6A966B5B172
E4E3AAD7DCA6DFE8B9D5DBADCCC291574716C3B984EAE9B1CFD599DDE7A8919D5B7A8742
E7F2AEC3CE8ADAE7A1D4E8A0CEEA9FBCE394BEEF9DB9E995C7ED98CAEA97C5E49887A55D
779451A8C281809958B2CB89CFE6A0CFE69ECFE79BCFE799CFE79BD1E99DD2EAA0D0EC9F
C9EB95C8EC94C8EB97C9EA99CAE99DCCE89ECFE6A0D0E5A0D1E29E909C5C7A8247B9BC87
FAF9CDFFFFDDFFFCDFFFFFE4F4FFE8EEFFE4BFDAADD3EBB7CCE0A5CBD99BD7E09FE1E6A4
535315E5E5A7D9DDA0D2DC9DDBEBAACFE8A4BEE096CBEDA0D5F2A0BCD788C8E29BDBF3B5
C5D9A6D1E4B74E5E3700090067764BA7B5849EAD76CBD99CDAE9A8D6E5A2BBCA85DBEFA7
D0EB9ED2EEA1C6E295C4E395D3F2A4CCEB9DBFDE92C8E499D5EFA8CDE3A2E5F9BCC6D59E
F4FFCEFEFFD8DCE3B7CDD8A0CEE492C4E089C4E397D3F8B3BAE8AA75AA74001F00B1E4B9
BCE8A9C0E39F87A162B1C685D7E7A0D7E198BABD769AA15BB8D288C0E094C9E79DCBE59C
CBE199C5D690B0BD7898A35FD5E29DD4E39ECFE39BD3EBA1C4E395C7EA9AC7EC9CC6EB9B
C9EB97CAE795D5ED9FBBD186DAF0A8DBF0AD849D5C8EA66ACBE3A9E2F7BFF5FFD0EFFFCA
DBECB5CDE1A6CAE2A4CDE8A1C6E391CDE995CDE79ECEE4A3DEF2B7C8D9A2728244B2C37F
CFE195D7ED9BCAE191CFE6A0D0E9B0C0D9B1D4ECD2F4FFFAF8FEFEFEFFFFFBFFFFF7FFFF
F9FFFFFBFFFFFCFFFFFFFEFFFFFDFFA39A9D0E050058513F93906D5C602DB7C081D7E79E
CFE79BCCE89BCDE79DCCE89ECCE7A2CAE8A2C9E8A4C9E8A4
CEF29AC8E593D1DE99585B229A9C6BD4DCABC8E0A6C0DE9EC4E29A899E5354580E635C18
E9DFA2ECE7AFC3CC97E3EAB6948F58615821A3A269DAE3A4D8E7A6D4E4A38D9E5A44500E
BEC784EBF2AFD7E19CC8D992CBE79CCEF8A6CAFEA9B8ED95C8F098C5E791D4F5A6CEECA4
C4DE9DBDD597708447788C4DD7EAA8D4E8A1D0E59ACCE395CDE398D0E69DD4EAA2D6EDA5
CEE698CEE796CEE796CEE796CFE698CFE59AD0E49CD2E39FA3B173C7D598DDE7B2DBE3B2
E7EDC1FFFFDDFFFFDFEEF8D3EFFFE2ECFFDFD1EDBCC6DBA3E0F0B2D0DB99E2E7A5CDCF90
626128D3D69DDCE3ADD2DFA9C7DAA2CEE8ABCDEDACCFEEABD2E9A5D5EAA9D0E1AAD6E6B9
C5D3AFD8E5C75562460C170066724EA4B186BCC898E8F5BFD0DDA5D6E3ABD2DFA7DAECAE
C5DF98C7E398C7E398C9E89CD1EDA2CBEA9ECBE79DD2EDA6CAE09FD1E5A8F9FFD1A6B280
FFFFDCFAFED9DADBB9E4ECBBDBF0A3D4F29AD0F1A2BEE19DC7EEB783AF7C001400C5F3C2
B4E1AAD8FFC2BDDD9C849B55D0DD97D8DE985D5C19D4DA94C2DE93C3EA9BCAEC9FCCE89E
CFE59DD0DF9AC3CE8AB0B9765A6320A2AD69D7E7A0CADE96DBF6A9CCEB9DC9EC9CC4EA97
C7E995C5E592CBE898E8FFB6C7DE96C7DC99D3E5A75062268B9A61C1D099E7F5C0DCEDB7
C8D9A3CBDCA6D6E7B1D6EAADDEF9AACEEB99D1EBA4C7DFA1CDE0A9D1E4AC9AAC6E91A55E
D3E997D6ED95C4DC88D4ECA0D4EDB3C5DEB4E2FAE2F4FFFBF5FEFDFCFFFFF6FEFFF3FDFC
F8FFFFF7FFFFF7FAFFFEFBFFFFFBFF7E72740A0000766E5B322E0B4D511EDAE5A3C9DB91
CDE79DCAE99DCAE99DCAE99DC9E99DC9E99DC9E99DC9E99D
C4E58CCDE995D3E39CDDE7AA929B64DDEAB4C8DDA2D8F2B1DBF5ACC5DA8FDDE59AA6A761
504F0F707137CCD59EF9FFCD86854DC1BF84CBD193D7E3A3D1E4A2D3E8A3D2E39F7E8D4A
5F6825E2E9A6D2DB98D3E39CCBE59BBFE194BAE796C5F29FCAF09BBFDF8CC0DF93D0EBA6
D3ECABD9EEB3B8CC8FBACC8E8798548E9F5898AA609DB2659DB26795AB628AA058869750
9BA25C9EA15A9EA15A9CA25A9BA25C98A45C95A55E94A55FA7BC79C7E09ED9F3B6CBE7AC
C2DFA7CEECB8D1F1BFC8E8B6B4D2A0E0FDC7BCD59BCFE3A4E0EFACC4CF8ADEE5A2515518
95955FD1D3A2E4EABEDAE2B9C8D7ACE6F9CCF1FFDAEDFFD5EBFCD2F9FFE1FBFFE8E6F0D8
FBFFF4FBFFF8000400000300828977D0D8C0ADB69789937086906BDBE5C0EBF5D0DAE7BB
DCF1B6CFE8A6CEE7A5CEE9A6CAE3A1C8E3A0CCE5A4C9E1A3CEE3A8B4C7908E9C6BC4CFA4
EDF3CDE9EDCCEFF0D1E2E9BFCDE09EBBD689CFEDA5C2E5A3BDE5A9C0EDB65B8A5662925E
BFEEB7B1DAA0CBEFB1DEFBB9B0C47FC0CD87E1E8A2D8E49ACBE79AC9EE9ECCED9ECCE89D
D0E89ED5E9A1D1E19AC8D58FC7D48EE1F1AA7C8D46BFD58CDBF3A9BDD98ECAEB9CCAEB9A
CBED99D0F09DC3E090CCE69CD1E8A0D2E7A4DFF2B2C6D89CC6D59CE2F1B8B8C99261723B
5B6C35ACBF87DAEDB5C7DD9CC8E392BBD884D4EEA4D1EAA8CDE1A6D6EAAFAFC282465710
90A351D0E78FD2E895D1E79CC8DDA2C6DBB0ECFFE7E4F4E7FBFFFFFEFFFFFBFFFFF9FFFD
F9FFFDFBFFFDFCFFFDFFFFFDECE4E23126220D03003A341E605E389EA571D3DF9DDBF1A8
CAE99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9D
D8F29BB6CF7CD7EBA3DCECABA5B4795C6B32CCE0A3C8DD9CCAE098DAEFA4D2E095DDE99F
DBE4A198A26547521A78814A4B5115E0E6A6E7F3B1D0E49FC8DF99CAE19BD8ECA78B9A57
4B5612CED592D8DF9CD7E49FDFF3ACD3F1A7C2E79ABFE697C7E897CDEC9CCDE99FCDE6A4
C8DEA0D5E9AEDFF1B5D3E5A7E1F2AECADB94A9BB7190A55890A55AA5BB70C4DA91DEEEA7
DADD98DCDC96DBDC98DADD98D7DE98D4E098D1E19ACDE39AD5EFA8C4E39DBFDF9CC4E8A8
C2EAABBAE4A5B8E5AAC5EDB1D6F3B9CAE0A2D7ECA9C2D68FCDDD94F0FCB47D86435C6226
C6CA97DCDEB6EFF3D2ECF0D5EAF3D8FBFFECF8FFEBF6FFEAFBFFEFFBFFF2EFF5E9FCFFFB
FEFFFFF5F6F821222402070380837AFCFFF3F9FFEAF7FFE5F9FFE7F1F9E1D1D9C1FBFFE6
DFEFC0CADDA6CCE1A9D4E9B1CFE4ACD2E7AFD4E8B3C7DBA6DBEDBB9AAA7BBDC89EC2CAA5
DADDBED6D6BAFEFCE3FFFFE3DBE9B6C6DEA0C9E5A8D8F8B9B3DB9DCFFBBEBDEDB3002A00
A3D49CBFECB5C4EBB2BDDFA3C4DE9DCADF9AC8D88FD6E89CCCE89BCBEC9DCAE99BC8E497
CEE69AD4EA9FD4E8A0D1E29BE1F2ABCDE199D2E69E95AB62C5DD93D2ECA2CCE89BC9E89A
D4F3A3C1DE8ED2EDA0D2EAA0C9DF97CEE39ECDE0A0DBEDAFD9E8ADEBFDC1F9FFCFEDFFC4
C7DB9EA6BC7EA1B779AAC47DD2EF9BCBE993D7F2A5CCE39FC8DC9DD4E6A8CFDF9E51621B
627524D3E792DBEE9CD1E59DD1E5AACCDDB3EFFFE5F2FEF0FDFFFAFAFAF8F9FEF8FBFFFA
F8FFF3FAFFF3FEFFF4FEFEF2DDD9CEAEA699150E0006020053552DB7C089CFDF9ECEE69C
C8EA9DC5EC9DC5EC9DC5EC9DC5EC9DC5EC9DC5EC9DC5EC9D
DAED9BD5EB99D3EB9FCFE6A0CFE5A46E8243CFDFA0EDFCBBD0E099D4E69CD0E598CEE499
B9CF87CADD9D97A46C727D43667232D2E39DD4E8A1C4DB93D1EDA3D0EAA1C4DA9293A45E
5C6725B5BB7BEAF0B0CED796D1E09DD2E7A2D0EBA4C7E59BC9E89AD1F0A4D3EEA7D3ECAB
CCE1A6C5D99ED4E6AAC5D799D8E9A5D6E7A0D2E79AD0E596CFE497CFE59AD1E79ED3E7A0
D5E59ED7E49CD7E49ED5E59CD4E69CD2E79CD0E89CCEE89EC9E79DD1F1A8D2F3ACCBEEAA
C6EBA8C6EDACC6EDAEC5E8A8D0E5A4CAD994E5F5ACD3E398E6F4A7C8D68B384300949E62
D7DFB0E9EFCDFCFEE8FCFDEFFFFFF8FEFFF9EEEDE9FBFCF7F9FAF5F8F8F6FFFFFFF7F6FC
FFFEFFFFFEFF0000040001007A7B73F4F8E9EBF0DCF1F6E0F7FCE6E9EEDAC3C7B8F5FDE6
FBFFE4EBF7CFEAF6CEE9F5CDD8E7BCDDECC1EEFDD4EEFDD6E6F2CCFCFFE3B0B796A5A98E
EBEBD3E8E6D1FFFFEDF0EFDAEAF4D2E7F9CFC0D8A6CCEBB0C7EEADB1DE99B9EAA8578B4B
88BB83AADAA6CDF9C6C7EEB9C3E5A9CDECA8D7F1A7D0EB9ACBE898C9E898CAE797C8E595
CAE596CEE99ACEE99CCEE69AC3DB8FCCE498D4ECA0C1D98D96AE64DBF3A9CBE399C7E295
BDD889D6F1A2D4EFA2D7EFA5D4EAA2D6EAA5DDF0AEC1D494CEE1A1E0F2B4DFF4B3CFE5A4
D1EAA6D8F3AEB9D48F88A459BEDC86D1EF99D3EEA1C9E09AD2E7A6CEE1A1D3E4A0809049
667727CFE18FCEDF91CBDA95DDECB5CAD6AEDFE9D0FCFFF4FFFFFAFDFCF7FEFFF6FCFFF3
FBFFEFFBFFECFEFFECEFF1DBDEDCC7918C760602001A1A00B5BB8DD5E2AAE3F8B5BFDB91
C5EC9DC2ED9DC3EC9DC3EC9DC3EC9DC3EC9DC3EC9DC3EC9D
9EAC5DEDFFB1B8D487CEEEA3CBEBA2D5EEAA899855CED995E3EEA9CADC92C4DF92DBFCAD
D1F1A6D3EEA9C0CF94D5E3A6CDE29DDBF5ABCAE69BC3E296D6F4AAD4F0A6CCE39BDAEEA7
879351818A49B5BB7BC7CD8DDEE8A9CAD998CADD9BD7EEA8D1EDA3BEDC92BEDC96D4EEAD
E9FEC3D0E5ACD5E9AED9EDAECEE29DCFE39BD1E89AD2E999D1E99BCFE79BCAE49AC8E299
CEEAA0CEEAA0CEEAA0CEEA9FCEEA9FCCEB9DCCEB9DCCEB9DC1E195C7E79CC8E89FC4E39D
C4E39FC9E8A4C8E7A4C7E09EDDEAA5DCE69FAEBA6E869344707E2F4E5C119CAB68CFDCA4
E7F2C8FAFFE4FFFFF3FCF9F4FFFDFFFFF5FDFFFAFFFFFBFFFFFDFFFDF8FCFDF8FEFFFCFF
F4EFF6FDFBFF706F6D0002007A7D6CD9DDC6D5D9BED0D6BAD4DAC0FEFFEDF1F5E4C1C6B2
929780B0B69AE5EBD1FEFFE8FCFFE8FCFFE8F7FFE3F2FBE0EAF3D8FEFFECE7EAD5D6D8C3
C9C6B5F3F0E1F2ECE0FFFFF3F3FAEAE6F4DAD2E7C0C0DDA7CEF3B0C3EEA6B0E29BC9FDBB
396E36679869B3E2B6C8F3C5BEE7AFB9E09FCDF2A5C1E291C9E898CBE898CBE898CBE898
C9E898C9E898C9E898C8E797D5F1A4D8F4A7C2DE91DAF5A8C9E197798F469BB168334900
93AB5FA8C072C8E094C7DD94CFE39CD1E59EC1D590D8EBA9CDE09ECDE29FD2E9A5D5EFA8
CDE99FC1DF95C7E69AD5F4A69CB965C8E490CDE599CEE59FDFF2B2CEE0A2C9D897AAB974
627025CCDA8DE6F3ABD2DE9ED8E2B0D9E1BCE4E9D2FCFEF0FFFFF6FFFFF3FFFFF1FCFFEA
F4FDDEFCFFE3F0F7D5C1C5A4E0DFC053502F0A0700141600F0F8C7C6D59CCDE3A2C9E9A0
C3EC9EC2ED9DC2ED9DC3EC9DC3EC9DC3EC9DC5EC9DC5EC9D
9CA85CD9EB9FD2F3A4B5DC8DC8EEA1CFEDA393A35C9BA25ED0DA93E2F2A9CCED9EB3DC8D
C2EB9FD9FDB5CADE9FD7EAAAD0ECA2C7E899C7EA9AC9EC9CCCECA0C3E296C1DB92DAEEA7
D6E5A28D985663692B989E60E0E6AAE2EAAED9E3A6D2E2A1CEE9A2BEDE95CDECA8E2FFBF
F4FFD3E0F8BEC8DDA2CDE3A3D2E9A3D1E99DCDE897CDE897CCE999CDE99CCDEBA1CCEEA4
C2EB9FC0EC9FC1EB9FC2EB9DC2EB9CC4EB9CC5EA9AC7EA9AD6F7A8C5E498C0DC91CCE69D
D4EBA5CFE6A0D0E5A2DBEAA7DFE6A2C5C8839EA45A657024606E2187974ED7E7A6CFE0AA
FAFFE0FCFFECFFFFF6FBF7F6FFFBFFFFF7FFFFF8FFF0DFE9FFFCFDFFFEFAFFFEFBF9F5F2
FFFEFAFAF7EE6361521214008C906FD0D5ADD6DBB2E3EAC0CDD3ADF4FAD8FFFFE6FFFFEC
FFFFEFFFFFF0F6F7E9F4F5E5FAFDECFAFDECFCFFEFFEFFF3FEFFF3F7F9EBF0F0E4FCFAEE
FFFFF4DED7CFFFFDF6FFFEFAFEFFFFF0FAF1F7FFEAD9F0C2BFE2A0D3FDB3B7E69EBAEDAB
7DAF7C4D8055B8E7C3B7E5BEBCEAB9D2FFC2AEDA8FC2EC9ACAE99BCCE89BCCE89BCBEA9C
C9EA99C6E997C5EB96C6EC97BADD8BCBEC9BCCEB9DC9E598B2CA80DEF4ABE7F8B2CEDF98
CFE59A93A95EC9DF96DCF2A9CFE39CDFF3ACD0E49FDCF0ABCBE09BD7ECA7D1E8A0C0DA90
C6E597DCFDAED6F7A6BBDC8BB7D484D6F1A4CCE39BCAE19DD0E2A4D3E5A9D7E5A8E3F2B1
8F9C57A2AD69CFD99AD8E0A7DCE2B6FDFFE1FFFFEDFFFDF0FFFBEFF6F3E2F2F2DAE1E6C6
D3DEB6DDE8BDBDC69971774B494B236B6C44040500292F01D1DEA9CADEA3D5EFAEC4E59E
C5EB9EC3EC9DC3EC9DC5EC9DC6EB9DC6EB9DC8EA9DC8EA9D
66702B8EA056BDDF92D6FFAFBCE596C3E495DEEBA3989E58D5DC96CEDE95CFF1A4C3EFA0
BDEC9EC4ECA3CAE09FD6EBA8C8E89CC5EC9BC8ED9DC5E898C5E599D1F0A4D5EFA6CBE199
D6E7A3D6E2A0697233565C1E767A3FB1B57ADDE1A6DAE6A6CBE6A1CAEBA4D8F8B5CBE9AB
F0FFD1DEFABFCAE4A7D7F2AFC8E49AC9E598CAE795C9E996C9EA99C9E99DC8EAA0C5E9A1
C3EDA3C2EEA3C2EEA3C3EDA1C4ED9FC4ED9EC7EC9CC9EC9CC2E394CBEA9CD4F0A3D4EEA4
D0E89ECCE39BCEE49CD4E39EDADC9BEBECAA4D500B6C762FCFDC94D3E49ED0E4A5CCE0AB
F8FFE1F7FFE8FEFFF6FFFEFDFFFAFFFFF6FFFFF0FD806B725449455A53494C483F59554A
5A564A2623120E0E00030400787E52E2E8B8D8DFACD4DBA8DEE4B6FFFFDDFDFFDFFFFFEA
FFFFF3F7F0EAD5D0CAD9D4CEFFFCF5FFFFF8FCFCF4FAFBF3F5F5EDFFFFF8FFFEF9FFFEFA
FFFDFAE9E1DEC3B9B7FFFDFFFEFDFFFCFFFFF9FFF1EDFFD9C3E1A5C7ECA6C1ECA5BBE9AB
BFEFBF80AF8B54826580AF8FBFEEC2ADDEA6C7F9B0C2EE9FC9E99ECBE79CC9E89CC9EA9B
C5EA9AC3EA97C4EB98C7EF99D0F6A3C5E896C4E596D2EEA1DDF5ABC7DB93C8D993D4E59E
D7EBA3D0E69B475D14475D14B6CA83C8DC95CCE09BD0E5A0D1E6A1CDE49CCFE99FD4F0A3
CBEA9AC0E28EC4E793D3F4A3B1CD82CEE59FCEE4A3D6EAABCCDEA4D6E8AEC9D89DD5E3A6
E0ECAE4751145A6229B4BB88DCDEB7FFFFE3FFFFEDFFFFF1FFFFEDFFFBE2F5F6D7DCE3BA
CCD5A6D2DFAAA6B07B464F1ADADDAE6F7243090C00101800D4E2ADD6EBB0C0DD9BCBECA5
C6EB9EC6EB9DC6EB9DC8EA9DC9E99DCAE99DCAE99DCCE89D
C1CB8CB3C782C8EDA0BFEC9BBEE997DEFFAEC8D68B9DA35B9BA25CD2E29BCFF1A5B8E497
C1F1A5D0FAB0C4DD99D1E8A2C4E99BB4DE8CD9FFAFC4E797CCECA0C6E297CBE59CD3E9A1
CCE09BCFE09CD9E5A5D7E0A1555B1F54581D99985FDBE4A5D3EEA9BEE29ACDF0ACDCFCBD
F0FFD3D2F0B2C9E6A6C6E3A0D1EFA5CAEB9CC0E190C2E591CAEF9FC7EC9FC0E69DC7EBA5
CBECA7C5E4A0CBEAA6CAE9A3C9E99ED0F0A4C4E596CCED9ECDEE9DBFE08FCAEB9AC2E394
C9EA9BD2F2A6BFDF93D3EAA2E1E5A895935A9BA060D9E29FD7E6A1C9DC9AD2E8AAC9E0AA
F7FFE1F2FFE4FEFFF1FFFDF4F3E8E6EFDDDD674F4F9F8A87E7DDD1E4E1D0FFFFF0FFFFF1
FFFCEBBEBCA524250604060064673AE0E4B1D1D6A0D3D7A4E4E7B8FEFFDAEFF3D0FFFFEA
FFFDF6F8ECEEFFFCFDB4AAABFFFCFDFFFDFDFBF7F6FFFFFDF7F3F2FFFEFDFFFEFDFDF7F7
FFFAF8FFFBF9D5CBCAFFFCFFF8F4FFFAFAFFFBFFF6F8FFE6F1FFD3D8F8B7C7EBABC1E8B1
C1EAC0B2DDBF1C462E113D2297C5A0BEEEBCB8EBA9C1EFA7BADB94E6FFBCBEDE95C9EB9F
CBF0A2C2E998BCE390CAF4A0C5ED97C6EC97C9EA99CCE89BCFE79DD1E59DD3E49ED3E49D
CFE59CC2DA8EDFF5ACC8DE95D7EDA58AA058273C00C8DD98D2E8A0D3EAA2D6F0A6C3DF92
D1F0A0C3E591C8EC95CEEF9E869F5BCFE3A6D2E6ABECFFC7F4FFCFCEDFA9D5E4ADD1DEA8
DAE5ADD0D9A4949A6A52582CFFFFE1FEFCE3FFFFECFFFFEDEDE7CFDDDAB9E5E7C0CBD3A4
D3DDA896A469525D23D5DEA5D3D7A4DDE1AF030600717948CEDFA9C4DCA0CDECA9C9EAA3
C4E69ACEEEA2C6E599D6F2A7CDE79DCBE399D3E9A0C7DD94
D8E7AC95AB6BD0F4ACBFEA9BB8E290BEDF8ED3E496CBD38A8C964FD3E49DC0E298CBF5AB
B5E398BCE49BD2EDA6C7E198D0F5A7C4EE9CC3E898C2E394C5E498E0FAB0CBE29ACCE39B
D2E7A2DCF1ACD7E7A6D2E1A0CFD79BB9BD82626128868F50CDE8A1BCE098C9E9A6D2F2B1
DAF8BAD5F3B5D9F6B6D1EEABBCDA90CCED9ECFF09FC7EA98C7EC9EC7EDA2C5EAA5C9ECAA
C8E7A4C8E2A1D5EFAED0EBA6C9E49DCDE99FC4E095C8E799D3EFA2C9E898D3F0A0D7F6A8
C5E496C3E294CFEEA2C7DE988A8F5573723CC8CE92D7E1A2C9D998DDF3B2C1DB9CD2EBB4
DAF1C3EBFCD8F9FFE9FFFFEFFFFDF1B5A598564033FFFBEDEBE4D2FDFCEAFFFFF1FFFFF0
FEFDEBFEFDE93E3E2407080050522A9396699B9E6FEBEEC1C5C79FFEFFDDFFFFE6FEFBE8
FFFCF8FFF6F9FFFAFDFFF4F8BBB0B4CBC2C5FFFBFFFFFDFFFFFEFFEFEBECFFFBFDFAF4F6
FFFCFDFFFCFDDCD2D3FFFBFFFFFBFFFFFDFFF6F9F2F9FFEAF8FFDDEAFFCCCFECB6BADAAB
BCDEBDD3F6DEB0D5C36B927D2A533319461BABDAA3BFEBACCAEEAEB7D794C9EAA5C7EBA3
C7EDA2CEF5A6CDF4A3BEE592C5EC99C8EB97C9EA99CCE999CFE79DD0E69DD1E59ED1E59D
DCF4AAC8E094D9F1A7C9DF96CAE098D1E79FA5BA75A2B772ABC27AC9E39ACEE89EC7E396
D3F2A2C8EA96C7EB94C7E899B4CA8ACFE2AAD2E3ADD4E5AFF9FFD6E4F5C1D0DEA9E0EEB9
CCD9A4D9E3B1AEB5898F946C9B9C7CFFFFE6FFFFEAFBF7DEEBE6C6F2F0C9C7CA9BE5EEB7
C1CC923E4C0E5F6A2ED6E1A7DAE1AD2F3301171D003A4412D5E6B0DDF7BAB5D491C4E59E
CCEAA0CFEBA0C2DC92BDD58BD8EEA5D1E59DD2E29BE5F5AE
C3DAA6D4F0B6709351DBFFB8C7EC9EC6E393DAED9EE9F5ABC6D18C80914BDFFDB7ADD189
D9FFB8BFE59AC9E79DCEEDA1C3E89AC3E89ADDFDB1C3DF94CFE69ECDE39BD6EDA5D7EEA6
D6F0A9C4DE97C6E099C8DD98D9E8A7E5EEAFA9AA6E6A7334D0E7A1D1F1A8C4E19EC1DE9E
C6E0A3CCE6A7C4DD9CCAE39FDBF7ADD6F2A7C6E295BEDD91C7E99FC7EBA5C0E3A3BFE2A2
D2F2B1BEDE9BC6E5A2C3E29ECEECA6DDF9AFD6F2A7CEE99CC1D98DD4EA9FCFE499CDDE97
C4D58EE1F1AADEEDA8707C3C666B339FA46EDBE5A9DEECAEC9DE9BCFE8A6D1EEAEC4E0A5
D3EBB9E1F3C9F6FFDFFFFFE6FFFFE5A89C82645538FFF3D9FFFFECFFFFF1F7F8EAFFFFF4
F4F4EAFCFCF20C0D00010300717159A5A589818062727153504E35DBD8C5F8F5E6FFF7EE
FFF2F2FFF9FBFFFAFBFFF5F8FFFBFFFFFBFEEEE8EC7F797DFFFDFFFFFDFFFFFEFFFFFEFF
FFFDFDFAF4F4D3CBC9FFF9FEF4EEFCFAF7FFFFFFFBFEFFF1F5FFE0EDFDD6F1FFDFF2FFE8
F1FFF1E7FFEFDCF8EAEBFFFAEAFFF3B1D6B4587F52C0E8B3CDF3BAC1E5A8D6FABAD0F5B2
BDE59EC5EBA0CDF4A5C1E696C8EB99C9EA99CAE999CCE999CDE79DCFE79DD0E69ECFE79D
D7F1A7C3DE91CAE49ADCF4AACCE39BD7EEA6E6FBB6B3C8838BA25CCDE79EC9E399CAE699
CEED9DCBED99C8EB97C6E599AFC38880915DFBFFD6EEFFCBD8E9B3B8C993DCEDB7C5D39E
CAD8A5FCFFD6EBF4C7D0D7AE555934585939DFDEC0E2E1C2D8D6ADE1E3B29198624C571B
505E209CAC6DE8F6B9D6E1A9DEE5B2010700010700293203C3D49ED4EEB1CBEAA6D1F3A9
C7E59BCDE79DE4FCB2DEF4ABC7D891BDCD862B36005C6722
CDEABCC0DEACA3C589C0E09DCBE99FD2EDA0CDE295C0D085DDEDA68EA25DBFD594CCE9A6
D1F0AABFDF94D2F3A4C5E697D3F5A8C2E297C5E197E4FBB3859952B5C680C5DB93C8E299
C9E79FC1E198CFEFA6DFFAB3C1D590CCD896E5EBAB3B4403A9BD76C0D78FD7EDACECFFC1
CCE0A3CEE0A4CEE1A1DBEEACC7DB94CAE097CEE49BD3EDA4D2EDA8C3E0A0CAE6ACE5FFC8
D6F6B7C3E6A4D6F6B5C4E3A0BBD993BFDA93CEE59DD2E89FDDEEA7D5E29CD6E19CEDF4B1
DADF9DB3B5749193545B5C209CA46BD7E2AAD7E7A9D3E8A5CAE49DC7E29DD7F6B2BDDB9D
CBE6AFDEF4C5F6FFDCFDFFDEF5F5CFC6C199595027ACA47FF2F5D8F4F9E3F4F8E9FEFFF6
FFFFFAFFFFFB0607010A0A027B796CD8D6C7B7B4A3D5D2C188847890897FDCD5CFFFFCFA
FFFAF8FFEBEAFFEEECFFF4F3FFFBFBFDF3F4FFFCFFC7C1C3C3BFC0FFFEFFF4F0F1FFFDFC
FFFEFDFFFDFAE4DFDCFFFDFDFFFCFFFFFDFFFFFEFDFFFFF6FFFFEFFCFFEDFBFFEDF8FFF1
F7FFF6E7F9EDF0FFF9F1FFFAE0F9E4D7F4D85D7B5971946A97BF8BC7F0B8B9E1A5BDE5A6
BAE19EBFE49EC6EAA0CFF1A4CAE99BCAE999CCE999CCE999CCE89BCDE79DCDE79ECCE89D
C7E398CCEB9DC2DE93D7F1A7D7F1A8C2D991D0E7A1D9EEA9889F59DBF2ACCBE59CCAE69B
C6E295CBEA9ACBEC9BC9E79DD5E6AFB6C491E8F6C1E0EEB9DFF0B9D0E2A8D0E1AADBECB5
D0E1AAECFAC5FCFFD8D5DEB1ACB3875B603783855D9FA076999B69999E646E763A576323
93A362D2E2A3D3E1A6CBD5A16C74453D42190207004F582BD9EAB6C3DB9FD4F3AFC0E298
C2E096CDE79DC3DB91B8CE85DDEEA7919E58A5B06BB9C37E
84AA83C7EBBFC4E2AE496326CAE19BCCE498C3DA8CE5FBB0CDE39B9EB16FD1E4A4DFF2B2
BFD491C1DD93D0F1A0C0E391BADA8FD9F4ADABC07B95A662E1EDABAEBA787E8F4BA9C07A
C1E196CFF4A7C7EC9FCAECA0D4EEA5C7DB94D7E29E606A2553601ADDEAA4D8E4A4C6D093
DEE8ACB0B87D5B63278D9655DCE5A2DDE8A3D7E49ED1E09DD1E1A3CDE0A8D9EBB9EFFFD2
F1FFD3C1E4A2D1F1B0CDEAA8DAF5B2DAF1ADDAEEA9C7D691D7E29EDDE4A1D4D494989659
625C2050470C7D723ADFDAA2D4DEA1CADF9ED7EEA8BFD990C5E498D5F5A9BEDE95CFEEAB
CCE8ADEEFFCFF6FFD8FCFFDAFFFFD6E5E7B64B4916AFAE7ED0D8B1E0EDCFF6FFE8F6FFEE
FCFFFAFEFFFD1A1C1B0606047A7975FFFDF6FFFFF6FAF6EDFFF9F3BFB5B35F5554998B8A
E0CFC8FFF8F1FFFBF4FFF6F1FFFBF8FFFBF9ECE4E2FCF6F6EDE9E8F8F7F5FFFFFDFDFCF8
FBFAF6FAF7F2D7D4CDD6D1CDF8F2F2FEF8F8FFFEFBFFFEFAFFFFFAFFFFFAFBFCF6F7FAF3
FCFFFBF6FDF6F9FFFAF2FFF3F5FFF6CEE1CEC2D5BF2742237DA67A9ECD99C7F4BDBEE7AD
CCF3B4CBEEACC1E09AC1DF95CDE89BCDE89BCDE899CCE999CCE89BCAE99DCAE89EC9E99D
C4E498D9FAABCBEA9EBBDA8ED2EEA4D6F0A9C9E09CD1E8A48EA561D7EEA8CFE9A2CDE99F
C2DE94CBEA9ECAE99DCDE8A1D5E4ADEBF8C3BDCA94EAF9BEC3D597DAEDADBACE8FD5E9AA
D0E4A7DEF0B6DBECB5C3D29BCBD8A2B5C0886A733C555D22808648929B5ABAC581DCEBA8
CEDE9DDBEBADD8E5AF6D76471B2200A5A9865E623F333B12C7D7A6C4DCA0CFEEAAC5E79D
CCECA1D1F0A4CEEA9FE6FEB4CFE39BAABA73C4CF8AE8F3AE
1C482787AD88C5E0B35B7038C9DC9AD5E9A1E7FFB5B4D083D3EDA67E9352D6E1A5D5DFA3
DEEAAAD5EBA2C4E793CEF4A1D8F6ACCCE39F97A665C5CF90D1DA9BE6F1AFCCDB98D1E8A2
CEEEA3B9DF92C1EC9DB1DA8BCFEFA3D2EAA0CEDE97D3DD966067212A2F00696B2CECEDB1
E4E3AA8B8A515B5B1F656527A0A060C7CA87DEE09FD7DD9FD3DBA2D8E0ADE2EBBEEDF9CB
FBFFD4C1D399CAD99EC9D99BDEE9ADCFDB9DC9D394AAB3725258186065235B5D1E4B4B0F
9B995EE6E4ABDBD69EE4E8ADD1E5A0CCE89DC5E496CDEC9CD1F39FC4E795C2E497CDECA6
C1DE9EC4DDA3CFE1ADD3E1AED2DCA7D8DFA96A6D3480884FD6E4B1CFE0B4DDEDC9E0EDD3
FBFFF4F0F5EE131716000100858482FFFDF8FFFDF7FFFDF7FFFDF8FFFCFAFFFBFBA49693
5D4B41675547FFF2E8FFFCF3FFF4ECFFFDF8FFFDFAFFFEFBFCF8F5999894FFFFFBFEFDF8
FFFFFAFFFFF8FFFFF6FEFBF2C1BAB2DED7D1FCF4F1FFFCFDFFFBFFFFFAFFFFFCFFFFFDFF
F5F1F2FFFFFBF3F6EDF0F6EAFBFFF6CBD6C8D7E2D4C8DEC93F6945235425B8E6B5B4DFA9
C2E8ADC6E6A7CDEAA7D1EBA4CFE79DCFE79BCFE799CDE899CAE99BC9EA9BC8EA9DC6EB9D
CAEF9FC6E999D2F4A7C1E195C0DE96D7F2ABCDE6A2CBE29E90A763BBD28ED1EAA6D2ECA5
C8E29BCFEBA1C9E59BCCE5A1CFDCA4EAF4BFD1DCA2F0FEC0D6E7A3D2E69FE9FFB7CBE09B
8FA461BACF8EBFD394DBEDAFCFDFA0D7E6A3E7F4AFD7E29DD3DD96E1EBA4CDDA94C3D48E
DAEDAB627438000D008A9269E3E9C7E1E4C5010400242A06DDEBBAD7ECB1BDDA97CFF1A5
C1E396D0F2A5B9D98DC9E59AD3E9A0687932DCECA5CCD993
36674A749D7BE0F9D1425221ACB77BD4E59FC2DE91CCECA0CAE8A2B7CC8B919960D6D9A0
D2D89AD5E69FD1F4A0B6DC87839D568C9F5FB7C184D6DC9EF4F8BBD4DA9CCAD9968AA15B
D1F3A7ACD788D4FFB2CCF9A8C4E99BCAE99BC8DD92DDE9A1BDBE7A7B76345E5618554C11
60551F8C814BAFA46C91874C8A8244C3BE7EEFE9ABDEDCA1A5A370787749898963C1BD97
B3A67A9B8A5CE5D7A6F3E7B3DCD09C9089527B793E626425919656919A59909C5CA2B170
CDDD9ED5E7A9C4D899CBE4A2C1E094DCFFABBBDF88D7FBA3D3F79DB4D880D8FBA9BFDF94
D9F6B3CAE2A6D7ECB4CFE0AAC8D59FE5F0B6CED69A5F6B2BD4E9A6C5DD9FC8DCA9DDEDC6
F9FFECF6FFEE373D3306090287877FF4F1E8FFFFF4FFFCF0FFFBF0FFFDF3FFF4ECFFFCF1
D9C7B9786755988678A7998CF8ECE0FFFDF4FDF6EEFFFFF8FFFFFAAEADA8FFFFFAFAFBF3
FFFFF8FBFDF2FFFFF4FFFFF3EEE8DAE8E0D5E2D8D6ECE1E7FFF8FFFFF9FFFFF9FFF8ECF8
FFFBFFFFFDFBFFFEF8FFFFF6F7F9EEFEFFF8F3F5F0F5FFF8ACD8B7659A70A7D8A9D7FFD0
D0F5BFBCDBA0C7E09FCDE29DD1E59DD1E69BCFE799CDE899CAE99BC8EB9BC5EC9DC5EC9D
C8EF9EB7DC8CCBF0A2D1F3A6C1DF97C3DE97CBE4A0D3ECA89BB1709BB170D2E8A7D0E9A5
CBE4A0D0EAA3C8E29BD0E7A3D5E0A6E3ECB3929E5E778641D4E69CCBE093D3EA9CA3BB6D
879F557A9149B8CF87CFE59DC8DC94CEE094C3D484D7E596D3DF93CEDA90E7F7AECEDF99
D3E6A4617339020F00E3EDC8C1C6A8DEE1C61313002C32106774468DA269DBF6B1BBDD91
C4EB9CC3EA9BC9EEA0DBFBAFC3DD93B8CE859DB169D1E29B
002D0A79A37DBCD7AAD8E9B38D9C5BE1F1AAC5E091CBEA9CC9E59BD5EAA7CFD99D82854C
A0A668CCD994CEE99A8BAA5AD1EBA2D1E6A1D5E4A1D6E2A0D2DD9BCED997D6E7A393AA62
C8EA9EC3EC9EC1EC9CBDE898C1E698CDEC9ED7EFA5CDDD94D3D993E6E7A3E5E4A3D1D090
EEEAADD9D49AD8D497E9E5A6B6B27281803F5A591959591D58571F585826999A6EFFFCCF
F7E5B7856D3D6E5A285A49156F622B7F763BC9C78AE8EDADD2DD99E0F1ABCDE29DCBE59E
C7E4A1C8E9A4D6F9B5B9DD95C4E999CAEE97CCF098C2E68EBEE28ACDF19AD1F2A1C3E296
BDD891D3E9A8D0E4A7C2D498E1EFB4CDD99BDDE9A95B6A27BFD68EDAF5AED0E8AACCE0AB
D4E6BCF8FFE854604C010A006F7666F1F6E2E9EDD4ECEFD4EBEBD1FFFFEAFFFFEFFFFEF1
FFF5E9FFFCF1CFC1B682766A8E8178FFFDF4FFF9F2FFFBF5FDF8F4EFEBE8B3B2AEDDDCD7
FFFFFAFFFFF8FDFFF4FCFDEFFFFFF1FFFAEEEDE5E2E5DAE0EFE3F1FFF5FFFFF9FFFFF9FF
FDF2F8FFFCFDF7EFECFFFAF4FFFFFAF5F6F1FFFFFFF3FFFDDBFFF48FC7AC1C4F30B6E2BE
D4F9CDCBE7B4D2E7AED5E8A8D1E59ED0E69BCDE899CAE999C8EB9BC8EA9DC8EA9DC8EA9D
C4E596CEF19FC1E897C2E99ACBF0A3CBEBA2CFE9A2D0E7A3ABC07D8AA15DCFEAA5C9E7A1
C6E49CCDE99FCBE29AD8ECA5D3E3A2D0E09F88995399AD6592A75CCCE194BED5876C8335
AEC479C9DF9493A95ED7EEA0D5EC9ECFE696D7ED9BCFE592D5EB99CBE292C7DE90D1E99F
CDE29F7B8F523848175C673F7A7F5F212409010400111700253204102400C6DF9BCCECA1
CBF0A2BFE697C8ED9FC4E498C5E196D3EBA1859B52D3E79F
234F1C6F9762C7E6ABCBE4A28FA459D8EB9AD4EA97CAE18FCBE395CDE49CCFE2A0B6C486
9BA767919D5D909C5A97AB63CDE99CCBEA9ACDE99CC4DF92DBF3A9D4ECA2C8E09686A057
CDE99FCAE89EC5E59AC3E398D7F5ABC3E296D2EEA4C6E096D0E69DD1E59DD1E59DD1E59D
D3E49ED3E49ED4E39ED4E49DD1E19AB2C27B97A760909D58909C5AA0AC6CCEDC9EFFFFCC
FDFDC1C2C0859F9F639EA0619EA361AEB873CCD993D7E99FCCE297CEE99CCDECA0CAEA9E
C9EDA3CCF2A7C7EFA6C1E79CC0E295D8F9AAD1F2A1BDDE8DD5F4A4C5E496C6E295CEE89E
D1E8A0CDE39BD5E9A4D0E19DCFDE9BD4E19CDAE7A2677834CAE19DCFEAA7CBE6A1C6E19E
D5EEB4F4FFDC546A46001000617456CADEB9CADDAFD7E9B5CBDDADF9FFDFF9FFEAFBFFF3
FFFEFBFAF1F4FFFCFBD2C7C5655A56FDF0EAFFFBF8FFF5F3FFFBFDFFFBFFBAB1B69E999D
FFFEFFF7F9F6EFF2EBFEFFF8FFFFF8FAF9F4FBFAF6F1EDEEDCD6DAEEE8ECFFFCFFFFF9FC
FFF7FAFFFDFDFFFBFBFFFEFDFFFFFDF3F3F3FDFDFFF2FFFFDDFFFF96D2D24E867DB5E4D4
E1FFEBC8E2BDD3E7B6DDEFB3D1E6A1C8E497CEF4A1C3EA97C3EA99C5E79ACBE59ECFE59D
CEE398CCE798C6ED9AC2EF9CC0ED9CC2E89BCCE39BD1E29EDEEDAA869B56CDEFA3C0E699
D4FBACC0DF91D8EAA0D4E499C2DF8FCDEE9FD2EEA3BAD48B99AE69889C5797A862ADBD76
DEEEA5CDDD9290A354C8DF8FCEE796CBE697D7F3A6C5E697C5EB98D3F9A6B4D785CDEE9F
D8F2A9DCF2B18A9B646C7848717950868C686D734F09110032400D5C7035D3EAA6C2DE94
C9E99EC2E297D0EEA4D1EDA3C1DB92D0E79FD4EAA2B3C780
608951C4EAAFC9E9AACAE59E8DA4568DA04ECFE38ED9EC9AD5EC9CCEE69AD3EAA4D2E9A5
C4D797B6C486B9C384CAD994C5E292CBEE9AC2E591BFE08FCBEA9CC2DE91D5EFA5A6C076
D5EFA6C3DD94E1FBB2CEEAA0B3CF85CFEDA3CEECA2CCECA1C9E99DC9E99DC9E99DCAE99D
CAE99DCAE99DCCE89DCCE89DD4EEA4CCE69CCEE69CD2EAA0CEE49BC6DC93CDE39ADFF3AC
E5F4B1D1DD9DCCDB98D1E29CCCE098D2E89DD8F0A4CDE899D1EE9ECFEE9ECAEB9CC1E494
BDE294C1E79AC2EB9FC3E99CCEF0A3BFDE92CFEEA2C4E397C5E196D9F3A99AB268CFE79D
D2E89FD2E69ED6E7A0D0E19AD2E29BD6E69FD1DE98576822D3E8A7DEF7B5D2E9A3D3EDA6
C3DC9BD8F0BC637953000A00596F4BCEE5B9CFE8AED3EBADC4DCA0E5FCC8F1FFE0F7FFF1
F5F5F3FFFDFFFFF8F6FFFDF85D504AFBEEE6FFF6F1FFFBF8FFFAFDFFF5FCE9DEE6FFFCFF
BDBBBED2D2D2FCFFFBECF1EAF1F3EEFEFFFBFFFFFDFEFDF9F7F3F0D2CECBCFCAC7FCF7F4
FDF8F5FFFBFBFFFCFCFFFEFDFFFEFFFFFFFFFFFFFFEDFAFFE4FFFFCAFCFF4C7D8133625A
A5D0BDDBFEE0D3EFC6B6CE9AD7F1B4C4E29CB7D98DDCFFB3C3E89AD2F2A7D4EEA5C9DF97
D7E99DD1EA99C6ED9AC0F09CC2F1A0C9F0A1D2E9A1D6E7A1D1E09B82984F45671AD0FAA8
C8EF9EC7E696CBDB90D3E496CEF09ACBF39DCDF0A0CAE89EC7E09CC8DD9CCFDF9ED4E3A0
CBD890DCED9FBACD7CB0C775E9FFB3BBD78AC4E298D2F7AABAE593BEE997D5FCABD0F3A3
B8D489C5DC98E0F2B6DAE7B2D0D9AEE5EDC4747C53000900879560A7B97DDCF1AED4EEA5
D1EDA3C6E49ACAE69CC4E096C6E097DFF6AECBE09B889C57
729A66DAFFC9BCDB9FCBE6A3B7CB838B9C4EB7C977D4E595D0E598CAE298CCE69FD6F1AC
D4EDABCAE09FCEE19FD8EEA6CAE99BD5F6A5CCED9CD2F1A3D5F1A4BFDA8DCEE89EA7BF75
BDD48CDEF8AFBBD58CD4F0A6D5F1A7C9E79DC3E398CFF1A5C8EA9DC8EA9DC8EA9DC9E99D
C9E99DC9E99DCAE99DCAE99DC7E398CAE69BD2ECA2D7F1A7D5EFA5CCE69CC9E197C9E098
C8E19FCBE4A3D4EDABD1ECA7C9E49DD0ECA2D0EFA3C1E092C7E698C9EA9BCBEC9DCAEB9C
CAEC9FCEF0A3CEF0A4CBEDA1C6E599C8E499D3EFA4C8E49991AB61A6C076728A40C7DF95
C8DE95D5EBA2D4E8A0D0E19AD4E59ED8E9A2C7D79052631D9CAC6DBFD292C3D490D7EAA8
D8EAB0D0E1B45F6E4F08160069785BD0E0B9CBDEA7D9EBADD1E3A7D4E5AFDCE8C4FCFFEC
FEFEF2FDF9F0FFFFF3FFFAEA746858C6B9A9FFFCEFFFFCF3FFF6F3FFFAFDFFFAFFFFFBFF
EAE6E7BFBFBDF7FAF3FAFDF6FEFFFAFFFFFAFFFFFBFFFFFAFFFFFADED9D5D2CAC7F7EFEC
FFFDFAFFFCF9FCF7F4FFFEFBF4F3F1F6F6F4FFFFFDF0F5F8EDFAFFEDFFFFA0C3C52F5E54
5087728EC5A8C4F3D1CBF1C87E9B6DD2EAB6D4ECB2CAE3A2C3DE99C5E399C9E99DCBEA9C
D2EA9CCCE798C1E696BEE896C0E99AC6E89BCAE49ACCE098D2E39CB2C87F68873BC0E393
C8E99ACCE798E4F4A9D5E899C9E994C0E691C1E494C7E59BD0EBA6D6ECABD3E8A5CEE29D
D8EAA0DAED9EB6CC7A7F9644C8E092CFE99FD3EEA7C1E198CCF2A5BEE798C5EA9CC6E69A
CFEBA1D5EAA7DAE9AEC8D5A0D9E2B7CDD4AB50582F030F00DCEAB5D2E4A8CDE29FC6DD95
C6E19ACAE8A0CAE59E9EB9726E88417D944EA4B974ACC17C
588252B5DBA8C1E2A9CEE8A9D8ECA5C6D68B97A558D3E496CFE195D0E89EC7E29BC6E49E
C7E4A1C6E49ECEE9A2C7E399C4E397BEDD8FC4E093CDE99CD2ECA2CEE69CC9E197B2CA80
586F27C3DD94CAE49BD2EEA4D0EEA4CBEBA0CCEEA2BEE396C6EB9DC6EB9DC6EB9DC8EA9D
C8EA9DC8EA9DC8EA9DC9E99DC8E89CC9E89CC6E599C2E195C7E398CDE99ED0ECA1CDEBA3
C7E7A6CAEDADCBEEAEC4E4A1BFE09BC6E7A0CCEEA2C9E99DC9E99DC7E899C7E698C8E799
CAE99DCAE99DC5E498C1DD92D3EFA4CAE69B839D53546E24A1BB71C2DC92BBD38950681E
AFC57CD4EAA1D4EAA1D0E49CD0E49CD6EAA2C7DB936C7D3795A163E4F0B2DAE6A4D3DFA1
D7E1ADDDE8C0797E68000400797E68E8F2D0DCE6B4D5E0A4DAE6A8DFEAB2DDE5BCF1F6D6
FEFEE6E0DBC5FFFFE6FFFEE2EDE1C79F9177CFC0ABFFF8E9FFFBF4F8E8E8FCF0F2FFFCFF
F9F3F3FFFFFBD0D1CBFFFFF8FFFFF8F3F4ECFFFEF9FFFFF8FFFEF8FFFEF8F0E9E3BDB6B0
FFFDFAFFFDFAFAF5F1FFFEFAFFFFFAF8F7F2FFFEF9FEFFFDFBFFFFF8FFFFF2FFFFA6C3BE
5D877B2A5D4A3A72597DB495D0FCD98DB088A1B68BC5D6A2DFF1B5BED58FCBEDA0C5EA9A
CAE99BCAE99BC9EA9BC9EC9CCBEB9FCDECA0D0EAA0D3EBA1CFE59CCAE298D1EC9F8EA95C
AFC77BC9DF94DBEDA3C8DF91C8E895C9EC98CBEE9ECCECA1CBE9A3CAE5A2CAE39FCCE39D
CDE599C4DC8ED1E898BDD685CFE59ACAE199C6DD99D9F4AFC6E89EC7EBA1C4E69AD2F0A6
D5EFA6CCE19EC6D59ADFE9B5DEE5B9656C43141B00434C1FD2DFAACFDFA1CCDF9D92A961
93AE677F9D5792AD68BAD58ECFE8A4D1EBA4CDE49EBFD690
4E7D51ADD8AAD3F6C0CFEBB0CBDE9CDEEBA58A964CD4E297DBEBA2DBF1A9C6E19AC9E8A2
CAE9A3C2E39CCEF0A6C7E79CDAF8AEC5E196D3EDA3CEE69CC7DE96DAF0A8CBE199D2E8A0
C2D9918FA960DBF5ACCBE99FB5D58ACFF1A5CAECA0C7EC9FC6EB9DC5EC9DC5EC9DC6EB9D
C6EB9DC6EB9DC6EB9DC8EA9DCAEC9FCDEDA1CCECA0C8E89CCAE99DCFEEA2CDECA0C4E59E
C4EBACC5ECB3C4ECAEC4EBACC5ECABC5EAA5C4E8A0C8EAA0CBEB9FC6E599C3DF92C7E396
D0EB9ED5F0A3D6EEA2D3EBA1CBE399CBE59B587026DFF7ADC7DF95DBF3A9C8E096C7DF95
92AA60CFE79DD4ECA2D2E89FCBE198D3E9A0D1E79E9BAF68495314272D00D9DF9FDCE1A7
D0D3A4FFFFE35C5A4B0101007F7D70FFFFE8FFFFD8D7DCA2D4DA9CE5EAB0DEE1B2CDCFA7
D0D0AADEDCB6EFECC3FFFFDAFFFFDA807350544528FFF9E5FFFBF1FFFAF6FFFBFBFFFCFD
FFFBFCFFFEFBAEADA8FDFDF5FFFFF8FFFFF6FFFFF8FFFDF6FBF6F0FFFEF8FFFEF8D4CBC6
A79E99FFFDF7FFFEF8FFFEF8FFFFF8FFFFF8FBFBF3EEF4EAF2FFF5F8FFFDFFFEFFFFFDFF
F9FFFF9DB7B6194E44367B687EC4AADBFFF6CDECCC596841606837D3E1A4CFEFA4C8EFA0
BDE294C4E498CBEA9ECFE99FCFE79DCCE69CCDE99CCDEC9ED0EC9FC6E194D4E99E8A9C52
99A960DAECA2BFD58ACCE79AC8E895CAED99CDF0A0CCEEA2C9EAA3C8E9A4CDECA6D0F0A7
CAE99DCCE999D6F1A289A153D0E69DD6EAA5D0E3A3CBDFA0D0EDAABAD995C5E39DC4DF98
C4DB95D1E4A4E9F7BCD5DFAB000800464D23050C00616A3DD4E1ACD7E7A991A462D4E9A4
D0EBA6C3E09DCAE7A4D5F3ADCDE8A5C0D995CCE69FE0FAB3
4A8157A4D8AABFEAB5C7E8AFC4DA9AD7E6A3A1AC67AFBB73CCDC95D1E59EC1DB94D3F1AB
D3F2ACBEE096CAEFA2C7E99DC5E099C2D993D9EEA9D8EDA8C8DD98DAF0A8CADE97D3E9A1
D9EFA7AEC57DCDE79EC7E59BCBEBA0C2E498C8EDA0CAEFA2C6EB9DC6EB9DC6EB9DC6EB9D
C8EA9DC8EA9DC8EA9DC8EA9DC5E599C7E79BC8E89CC8E89CCAE99DCAEA9EC8E79BC2E39C
C2E8AFC5ECB7C0E7B0C0E6ABC8EEB1C5E9A9BFE29EC5E69FC5E59AC6E599CEE99CD3EEA1
D4ECA0C9E195BED489B7CD82839B519BB369A7BF75CCE49AD7EFA5CBE399D9F1A7D0E89E
839B51CEE69CD1E99FD3EBA1C9E197CDE79DD6EEA4C4D891BFC98A9FA3664F541471743B
E1E2B6E6E5C9716D62100B07817D74F7F5DEFFFFD5E9EDB2DFE4A2D1D696DCDFAAECEEBD
EEF0BFDBDBA9DFDDAAEBE8B3FFFAC9D0C49A7C6E4B94826AFFFBEDFBE9E5FFF6F7FBEFF3
FFFCFFFFFDFDF8F4F1ACABA6E9E9E1FFFFF6FEFBF2F9F6EFFFFEF8FFFEF8FFF7F5FFFDF8
FFFCFAE5DED88A837DBBB6B0F7F4EBFFFFF6F1F1E7FEFFF6F9FFF6FCFFF8FFF6F7FFF8FF
FFFCFFEDF7FF5880800C453E448678417F6AC7F1D9BAD7B8D1E2B85A6B3793AB6DC4E39D
C8EEA5CBEFA5D3EDA6D5E9A2D2E39DCBE198C4E395C2E595C9EA9BD6F1A4D0E09798A25B
9CA65FD9E69ED3EBA1D3EFA2C9E996C4E692C0E393C1E397C4E8A0C6EBA5C5EBA2C3E99E
C4E699C2E394CBE898D2EDA03E520DBBCB8CD9E7ACCFDEA5CBE3A7CBE8A8D3ECABD8EEAD
CDE0A00F1F00000A004C55209FA778D6DDB1D3DAAE666F40B1BE88718143B5C886C6DB96
CCE6A5CDEAAACCE9A7C9E6A4CEE8A7D1ECA9CCE7A2C5E09B
34774E73B084ACE1ADBDE6AECAE6A9D5E8A6C6D38E9AA5609BA862C9DA94C9DE99D1EAA6
CFEAA3C4E29ACCECA1A8C67C8BA25EA0B574A5B876CCDF9DCBDE9CD5E9A4D0E19BB2C67F
162C00D8F0A6DAF4AAC7E69AD4F4A9BCDE92D8FDB0B6DB8EC8EA9DC9E99DC9E99DC9E99D
C9E99DC9E99DCAE99DCAE99DCDECA0CAE99DC9E89CCBEA9ECDE99ECCEB9FD1EDA2D4F1AE
CCEAB6E1FFD2DFFFCED6F4C0DEFDC4E0FEC2D5F2B2D2EFACCAE59ED0EAA1D5EFA5D1E99D
BBD2849EB5678FA6588CA2579BB168A4BA71CEE49BDAF0A7D2EAA0C8E096C6DE94D4ECA2
87A157CFE99FC8E298D1EBA1CBE59BCCE89DD1EBA1D2E8A0CFDB99D1D799AEB4748F945A
4F502665634A89827C0600008A837DBBB6A2A9AA7E9A9E61828943555C186B71358F945C
45490E5C5D21ACAC6EAAA86DCAC38CE0D6A5FAECC7B1A187665446ECDAD6FFF9FCFFFAFF
FDF2F8FFFBFFF9F5F6FFFEFBC1C0BBD5D5CDE3E0D9FDFAF5FFFEFAFFFAF6EFE5E4FFFBF9
ECE2E1FFFDFAFCF4F1E7E2DCC7C4BBFFFCF3FFFFF4FBF9EDFFFCF4F8F3EDFFFFFBFEFFFF
EBF0F6F9FFFFEDF7FFA2B6BD92B4B396C4B9326C5481BD9BB5E3BCD3F4C7A4B18596A471
C3E7A7BDE59FC3DC9ACCDB9AD5E19FD7E8A2CEEDA1C8ED9DBCDF8DD6F3A3DCE8A0949752
989B58C6D08BDCF3ABC3E397D1F19ECDED9AC8E99AC5EA9DC7EDA4C6EEA7C3EDA3C0EB9C
CDF4A5C1E696C2E394C0DA90E5F8B6A7B57A939C67C0CA98DBEDB9BED59DD2E5ADC9DB9F
617133919F62DEE9AFDFE8B3D2DAA9DFE7B8878F60959F6DB0BD87D9E9ABCEE19FD0E5A2
CAE2A4CFE9ACC9E3A6C3DDA0CDE7A8D4EEAFCEE8A7C4E19F
216E44458E61BFFDCAB6E7AFC2E6A8CAE3A1DDEEAAB6C37D707D38D1E09DDEF1AFCCE19E
C7DE98D8EFA7D8EFA7879E58B3C587C9D89D97A769CDDD9FD6E6A7D2E2A1D2E39F8A9B55
50641CD1E99FBDD78DCEEDA1D3F3A8C1E397CAEFA2C8EA9ECAE99DCCE89DCDE79DCCE89D
CDE79DCDE79DCDE79DCDE79DCEE89ECBE59BCCE69CD0EAA0CDE79DC5DF95C5DF95CAE3A1
C3D9AAF2FFDEF5FFDFF3FFDAF5FFD8F7FFD4E1F7B9CEE4A3C9E09CCEE59DD0E89EC7DF93
B4CC80ADC577BED688D7EFA3CCE299D3E9A0D2E89FCFE59CC4DC92D8F0A6D7EFA5C5DD93
91AB61D2ECA2C2DC92D1EBA1CEEA9FCDE99EC9E59AD0E79FD4E5A1DEEAA8D3DE9CB3BB80
747A4E35351B221F180D07073A352F6A695456592A47500F636D24869248C3CE8CD4DE9F
A5AE6B8D924F5255125B5B1BC4BF85DED7A3FEF2CADED0B55B493B9A8884FFFAFDFFF7FE
FFFBFFFFFAFFFFFDFFFBFAF8FFFFFAD8D8D0CDCCC7E6E3DEF5F0EDFFFEFBFFFDFBFFF8F6
FFFCFBFFFDFBFBF6F2FFFFF8C2BFB6D6D6CAFAFAEEFFFFF4FFFAF8FFF4F3FBFFFAF4FFFE
F5FFFFEAF3F8FCF9FFFFFDFFDDE4EAEBFFFF4A7D6A3D7C5F7EB796B9E5C2CCDCBF52623D
84AB747DA567869E629CAA6FB9C386CBDC98C9E99DC5EC9BCDF3A0C9E696CED891A5A662
969554D9E29FC8E299C9E99DC5E292CBE896CDEE9FCBEDA1C2E89FBEE69DC0EA9EC5F0A1
BAE394CEF5A4C5E697E2FCB3C1D494D2DDA59EA4747B8256AAB78BDBEDBDCCDDA9E1F0B9
2B3900758046909B61CFD8A3D3DBAA8891625A6334AAB684D6E5AECCDEA0D5E8A6D1E6A3
CEE6AACCE5ACCAE1A9CCE5ACCFE8AFC4DDA3C3DCA2D2EEB1
54AB80136535AAF0BCB1EBB1C6F0B0C8E7A3D6EBA6D3E29DD2DE9C97A36193A26194A362
91A05D8796518E9B56BDC987C9D69EE1EEB88B9860D5E3A8D6E4A7E2F0B2C7D69392A35D
CEE29AD5EBA2D4ECA2C7E398D3F1A7C2E498D3F5ABC5E59ACFE79DC8DE95B4C880879D54
75894181954DCDE199CBDF97D2E89FD1E79ED6ECA3D5EBA2A2B86F91A75EB7CD84A7BA7A
8D9669ECF2CEFFFFDFF5FED3F9FFD3F0FDC8E1EEB6D2E2A4CCDF9DDAF0A8C9DF968EA65C
859D53C9E497CAE598C7E295CFE79DCFE79DCFE79DCFE79DCFE79DCFE79DCDE79DCDE79D
87A157D2ECA2CFEBA0C4E095CEEA9FCBE79CD1EDA2CCE69DD3E8A3CCE09BD4E5A1D3E3A5
C9D5A7DDE3C7484A3F00010024261B9A9E85D0DAA6D6E5A0CCDF90D3E899CBDF98DBECA8
D7E49ED2DC95D2D993A5AA676060246B6835BBB28BECE0C6FFFCEF564744FFFAFFFFFAFF
FFF5FEFEF7FEFFFEFFF7F7F5FFFFFBFFFFFAFEFDF9EBEAE6C3BFBEBBB5B5827C7CFCF6F6
FFF7F8FFFEFBFEF9F5FFFFF8FFFFF6C8C8BCBEC0B2FFFFF4FFF8FAFBE8ECFBFFFDE8FDF4
ECFFFDF4FFFFFFFEFFFFFAFFF8E8EBFFFBFAF2FFFBBFE6D41A4B353B6B5383A994C4E8CC
BCEBBDC1ECB6C7DFABD3E1AC939E649DAD6EC7E79EBDE495C5EA9ACFEA9BDFE79EC8C784
686927E1EAA7CCE69FCDEDA2D1EE9ECDE899C6E597C5E59AC5E99FC5EDA4C2ECA0C0EB9C
CCF5A6BCE392C5E599DBF5AEC9DB9FDAE7B2E0E6BAFFFFDFECF6D1B4C09897A4788C9866
78854F879258D0DBA1939E6698A26ED8E2B0DAE6B4D0DEA9D3E2A98D9F61687B395D7231
62773E677E48667A47637A46647B4789A16DD7EFBBC2DBA4
46A1750F6534A3EDB8B1EEB3BCEAAABADE98CBE59ECFE39CD9E8A5CFDE9B9AA666677333
9CA765AEB774D9DE9CDAE0A2E2ECB7D7E3B17B8853C3D09AD5E3A8DAE8AAC7D69597A661
CADB95EAFEB6C4DC92C9E399DEFCB2B6D68BC2E299CBE99FDFF3ACCBDC9595A65F9FB069
D4E59E98A9628FA059BFD089C4D890D1E59DD6EAA2CADE9697AB638FA35BC7DB93DBE9AB
E3E4B8CFCBA6F9F7D0FFFFDAFFFFD6ECF3BFC8D198D7E2A6DBEAA9C9DD98ADC37B435A12
BDD78EC6E298DFFBB0CAE69BCDE79DCDE79DCFE79DCDE79DCFE79DCDE79DCDE79DCDE79D
8DA75DCAE49AD5F1A6CEEA9FD2EEA3C9E59AC9E59AD1EDA2C9E49DD2ECA5D0EAA1D0E6A5
D5E7B3D2E0BD353C2C010700525949C3CEAED9E8B1D5EBA2CEE794D0EC98C7E197CDE49C
D4E8A0D1E198DDE9A1CAD48F92965977774377724A6A6045F9EDDF605551DCD2D3ECE3E8
FFFDFFFFFEFFFBFBF9FEFFFAF5F8EFFEFFF8FFFFF8FFFFFAFDFCF8BCB8B5686463E7E3E2
FFFDFAFFFFFAFFFFF8F3F3E9F2F3E5FAFDECF4F9E5E7E8D8F5EBE9FFFCFDFEFFFBF7FFFA
F5FFFAF9FFF8FFFDF6FFFCF8F2E0DEFFFBF8FAF9F4F7FFFB79978B143E3046796AA4DAC2
C8FCD6CCF7CADAF5CADAEBBEA4B27D96A86CB1CF89D3F5A9CAEB9CC4DC8ED1DB92DFE29D
959855EAF5B1BAD590C9E99EC9E497D0E89AD2EEA1CFEDA3CAECA2C5E9A1C6ECA1C8EEA1
BEE596C7EC9EC7E79CD1EAA6CFE3A8F1FDCDF6FDD4FFFFE3E5EECFF5FFDDDDE8C0D8E4B6
BDC7934A551D717C42D5E2AAC1CE98D7E4AFCEDCA7DDEEB8617339394D0E2D4200627837
223500000C00000A0056693B4053267D936563794BD3E9BB
6AC194308252A7F0BBC1FEC2C9FAB8C5EAA4CEECA4D1E99FC6DA93D4E5A1DDECABC7D393
E5EEADD7DC9AF3F3B3B5B67A4E5625CCD9ABE7F3C3FBFFD3DAE5ADD2DDA1D6E2A297A661
97A661C8D992DEF4A9C6DE94C3DD94DDF9AFC9E79FD3EFA5B9CA8484944DAABA73E0F0A9
CEDE97BFCF88E1F2ABC1D28B9CAD6692A35C83974F9BAF67BBCF87D1E59DDFF3ABD7E3A3
DEDCAC8A825BD6D1A7FEFBCEE6E5B5CED19C8D955A949E61728140D4E8A3D7ECA7D4EEA7
C6E19ACAE8A0B6D48CD2F0A6CCE89ECCE89DCDE79DCCE89DCDE79DCCE89DCCE89DCCE89D
9FBB70B2CE83CEE89ED0EAA0D1EBA1D3EDA3C6E096C4E095C4E49BD3F3A8C8E79BC5E099
D5EDB3C3D5AB212D15000500657159D9E9C2D0E4A5CAE596CEEC96CDED98CAEA9EC5E39B
D1E8A0CADE96DAEBA4DFEEA9C8D295B2B78199976E7370517873609E978FFFFEFBFFFEFD
FFFFFBFEFFFAF1F7EBFCFFF4FCFFF3F2F9E9FBFFF3FDFFF5F4F5EDF7F7EFDAD9D4C5C4BF
ECE9E2F4F4EAFFFFF3E7EAD9D4D9C3F9FFE7F3FCDFA1AF95B8CDBAF5FFFAF5F2EBFFFCF6
FFFBF4FFFBF2FEFCEFFEFFF3FFFFF4DFDBD2968784FFF9F9F6FAF9EDFFFFA0D9CA3A7B65
82B79BD4FDDDBCDAB8C2D8B1D0E3B5CADFA786A361BFDD95C4E095E1F7ACD3E196D6E099
E4EEA944530ECFE8A4D2F0A6CDE599CFE799CEE99CCBE79DC7E59DC6E59FCAEAA1CEEEA3
C0E094D3F3A7C5E099C8E1A0D4E7B0F0FFD3FCFFE1FBFFE5FCFFECF1F7DDEDF4D3E4ECC3
C8D4A2BFCC9696A36B000B0083925BBFD0996C7D46000C00A3B77CAFC585CDE4A0CFE5A5
D6E8B4D7E8BCE5F4CBB7C7A0BCCCA770815D000900D1E2C0
6CB78C246C3E74B480A5DCA2BEEBA8C3E9A0C8E89DC3DF94E1F8B0D2E8A0C5D994D3E2A1
D7E2A0D8DD9B54531385864CF1FACBFBFFDDF5FFD6FAFFD4F0FAC5D9E4A8D4E0A08F9C57
596922C5D58ECEE398DEF4A9CBE29ACCE69DD4EFA8B9D38A91A55ED0E099D1E29BC3D48D
E0F1AAD7E8A1CADE96DFF3ABD5E9A1D6ECA3C8DE95CEE49BE1F7AEDAF2A8C9DF96C3D490
E4E7B2D8D4A5F2F0C0858553454813A4AC71D3DDA0E2EEAECBDB9AD5E8A6C4DB97D0E9A5
C7E29DD1EEABE0FDBAC5E49ECAE89ECAE99DCAE99DCAE99DCCE89DCCE89DCCE89DCCE89D
C8E4995D792E8CA65CD1EBA1C1DB91C5DF95D5EFA5D6F2A7C6E89ECBF0A3C4E797C0E095
D2ECADC6DCAB3445250007005A694AD8EBBDC3DC98C5E290CCED94C6EA93CDF2A5C5E69F
CAE89EC6E096D0E89ED9EDA6D7E6A5DCE7ADDFE5B7D5D6B4FFFFEAFFFFF1FDFDF1EFF1E6
FEFFF4FBFFF1F1FBE3F9FFEAF3FFE4F7FFE8F7FFE9F5FDE8FEFFF1ECF0DFFAFCEEFFFFF3
E6E9D8F1F4E1FFFFECF1F7DBCBD5B3DAE6C0E0ECC4ADC29B9CBF9ECAE6CDE5E3D4FFF7EE
FFF7F1FFF8F1FFFEF3FEFFF3F8FEF0F8FAEFFFFCFA675959F6F2F1C4D3CEBEE8DC639886
42715F5F89735B7D64DCF9DAD0EBC2BDD8A587A164C7E09CC8DE96DCF1A6CEE094D8E89F
D5E69FCCE0994B6420C7E198D8F0A4D3EA9CCCE498CAE199CAE49DCCE69FCBE59ECAE49B
D0EAA0DBF5ACC6E099CCE2A4D2E6B1D4E5B9E5F5D1F5FFE6FCFFEFF5FAE6F1F7DBFBFFDE
E1EDBDCCDBA4E2F1B8D0E2A6000C00000C00D3E6AED4E9AEDDF3B5C9E2A1BED793DAF3B2
C6D6A7E4F3CAFBFFE1F9FFE4F9FFE8000700EAF7DDF9FFED
B1E9C261996C86B885BEEBB0CFF6B3CEF2A8D1F1A5CDEC9EBEDD91C5E399D0EBA4D9F0AC
DFEEAB5E6724E4E6A5DDE1A6DEEABCF3FFD9F1FED3FAFFD9EEFBC6D0DEA3D4E0A09BA863
CAD791E0F0A7D7E79EC6D88EDCF0A9CBE199657C3693AA62D4EAA2CCE299D6ECA3D9EFA6
C7DF95CDE59BCFE79DC8E096C2DC92D3EDA3D1EBA1C4E095CAE69BC3E296C2DE93DEF5AF
DDEBAEC4CD94D2DBA2DDE8ACDDEBADDCEAACC9D998C4D795D0E5A2CBE29EDCF3AFCFE8A6
D6F0AFB3D090DBF8B8B9D895C9E9A0C9E99DC9E99DC9E99DCAE99DCAE99DCAE99DCAE99D
C2DE93D5F1A696B066536B219BB369D5EDA3B8D086D0ECA1CBEDA3BFE598CAED9DCBEC9D
D2EDAAD3EAB25C6E460008005A6A43D5E9B4C8E299CDEE97CBEE94C1E58EC9EFA6C1E6A0
CBEDA3C8E89CCDE99CCEE89ECCE19CD1E1A3D9E3AFD9E2B7F1F6D6FFFFEAF8FDE7FCFFED
FBFFEAF2FFE0F2FFDBF7FFDFF3FFDAF9FFE1F9FFE3FBFFE4FBFFE6EDF6D9FEFFEAF3F9DD
E6ECD0F6FFE0FCFFE3E8F4CCCDDAACC6D7A3D5E6B0E0F7C1A9C99A95B189D8E1C4FEF7E4
FFFAEFFFF9F3FFFAF6FFF9F7FFFFFBFBFFFAF9FFFBBECAC0C5CFC6CBD5CAEEF9EBF4FFFA
799890769E931942306B9277C3E5C0C8E5B77A91595F7334E3F4AEBBCD83D3EA9CD7EFA3
C0DA90E1FBB2CEE5A18BA159B0C67BBFD688D1E79CDCF2AADDF1ACD8ECA7D3E7A2D1E59E
BDD189CAE098D1E6A3D0E6A8D0E4B1CBE0B5E0F4D1F4FFEAE7EEDEFFFFF3FEFFEAF1F8D6
F2FED0DDEBB6C5D79DCDE1A4C6DC9EE6FEC2CEE6AACEE8ABBED899CFE9A8D5F0ABC8E0A2
D9E9BCE4F0CCF2FCDABCC7A93741287E8772FBFFF3F0F8E9
C8F0CD84AA818CB080CCEDB4C8E7A4BBDB90BFDF93C4E797C8ED9FD4F9ACC0E298BDDB95
C5DA95C2D18EBFC885D8E0A5EDFACEF8FFE3F9FFDFF4FFD5E0ECBADBE8B0DDE9AB94A15C
E1EEA8D0DD95D8E59DDBEBA28E9F5990A45DD7EBA6D9EFA7CFE9A0C5DF95CAE49ACFEBA0
C4E095D5F1A6CEEA9FCFEEA2D7F6AAD2F2A6C8E89CBCDE91CDEFA2CFF4A6BFE194CCECA1
C1DA96DFF5B4D2E9A5CCE39FCAE19BC3DD96D4EEA7D9F3ACCCE69FE1FAB6B7D08ECFE8A7
C8E0A2D7F1B4BFD89ECEEAADC8EAA0C8EA9DC8EA9DC9E99DC9E99DC9E99DCAE99DCAE99D
CFEBA0C2DC92CBE399D1E99FD0E89EBFD58C98AE65809A50CCEEA4BAE093CDF09ECEEF9E
C7E399C6DEA06E7F52000E006E7E51CCE0A5C9E497D4F29AC7EA90C0E691C9EEA8C0E7A4
CAF0A5C7EC9CC5E898C6E597CCE69DCEE3A0CBDDA3C9D7A6FCFFDFFCFFE4DBE6C6D1DFBC
C7D7B0D7EABCD6EDB7BCD39BD8EDB5C2D4A0D6E8B8CDDDB0C6D5AAD7E3BBD9E3BE707B53
D3DEB6F5FFD7F6FFD5DFF0BAD7E9AFCCE0A1C7DC99D6ECABBCD196899D68D8E5BAFAFFDF
FFFFEDFFFDF4FFFBFBFFF4FBF9F4FAFCFFFFEBF7F3F5FFFAF9FFF4929584AEA794FFFFF2
DEF4F2E4FFFFD8FFF980AD9689B290C0E1B6D5E9B6445217CEDA98E3F3ACCFEA9DC1E293
C4E498BEDC92D7ECA9D5E9A2CDE398BDD48698AD6266773041500D485412727F3A9BA863
8F9C56A1B06BD3E6A4CEE2A7D1E7B6E7FED4F2FFE8F4FFEFFCFFF6FBFDF0FDFFECFCFFE4
EFFCD0F5FFD0E9FDC2C7DD9FD6EEB0B4CE8F001900001000CBE8A8D8F7B3BEDB98D0EAAD
D1E0B5E9F3D1F9FFE58E967ED8DFCDFEFFF4E8EBE2FEFFFA
A8C0A06D865F718759CAE1A9CFE8A6C8E499CDEE9FD6FCA9C7F19FB8E394C4EDA1C7EDA4
ABC983B8CF89E9F8B3D7E5A8DAE9BEDAEAC6DFEEC7FBFFDCDDE9B7C3D098BFCB8D98A462
D6E19CCDDA92BDCA828A9A51BAC984DCEDA7BECF8BD7EDA5C0DC92D5F5A9D4F4A8C4E498
BEDE92D5F7AABCDE91CAEFA1BCE193BEE596CCF3A4C1EA9BC3EC9DC6F1A1B8E192C7F0A1
C8EEA1C5EA9DB4D98CCAEFA2D0F5A7BDDF92C6E89BC9E99EBEDC94D1EFA9D6F0AFE2FABC
E5FDC3E8FFC7C8DFA9D4EDB3C8E9A2C6EB9DC6EB9DC8EA9DC8EA9DC9E99DCAE99DCAE99D
D0ECA1CCE69CD1E99FD6EEA4C9DF96CDE199CBDF9798B268CAECA2BEE596CAED99C9E996
C7E197BFD59490A16D5868399DAB78CADC9EC8E190D1EE94C2E38ACAED9BCCEFABC1E8A7
C2ED9EC3ED99BFE693C3E694D0EFA1D6F0A9D5EBABD8EBB4F9FFDAECFBD0BFD0A6D5E8BB
DAF1BDCBE4AACAE7A4D5F3ADCEE7A6D1E7A9D0E5AACCDFA7DEEFBBBFD09CA3B180A5B382
CEDCABEEFCC7F4FFCAE3F6B6DFF4AFD9F1A7CCE496CADC90BABF7CACB073D8E2AEF9FFDF
F7FFEDF4FFF5FBFFFFF9F9FFFFFCFFFBF7FFFFFEFFFEFDF8FFFFF18A866DD1C8A9FBFBE3
EDFFFFE6FFFFDDFFFF76AB978FC0A0C4E9C0C9DDAC969F68B6BF80D1DE98C2DE91D4F9A9
D6FDAEBFE195C5DA97D4E59FCCE196D1E699CDDF95B7C780A1AC6AA0A968BCC380D6DD9A
98A25D87924ED2E0A2CCE0A5D1E7B6EDFFDEF0FFEAECFFEBF1F9EEFFFFF8FDFFEEFBFFE5
F4FFD5F9FFD4DFF3B8D6ECACCAE4A5CEEBAB0017001B3900D2F0B0C7E8A3C6E5A1D2ECAF
D9E8BDDAE1C2B2B89E797E68E3E7D8FEFFF7FFFFFDFAFAFA
A6B886667A49596E45C4DAACD6EBB3D1E7A6CBE59CC7E79BCCF2A5BDE899BFE899D8FDB0
C8E39C8BA25CD3E9A1CBE1A0CBE2AED6ECBDCBDFAED2E4B0C6D89EE6F6B8DBEBAA909F5A
56661F526219B0C077D5E69FCFE099CCE099DFF5ADC9E098D0EFA3C2E497CAECA0D1F3A7
BFE197D3F7ADBFE399C7EC9FCBF0A3BEE596C8EFA0BFE697C0E99BCAF3A5BBE498C3ECA0
C6F1A2C4EF9FC5EE9FC8EF9EC0E595C8EB9BD5F6A7C3E397D3F3A8BFDD95E2FFBDF4FFCF
E5FDC3F7FFD6E4F8C5CBE3A9C9E8A2C6EB9DC6EB9DC8EA9DC8EA9DC8EA9DC9E99DCAE99D
CDE99ECDE99EC8E298D6EEA4CEE49BD3E79FD1E59D889F57C8E89FC9EB9FCAEB9AC8E895
D9F4A7D2E9A1C8DC9FD3E5ABD0E2A4D6ECA4CEE794D0EE96BFE089D0F3A3CBEEAABEE3A0
BDE39AC8ECA2CAEBA4C8E7A1CDE99ECAE49DC8DDA2D1E3B1EFFFD4F8FFDFDBECC0C5D8AA
CDE0B2CDE4B0C9E3A4CAE5A2CEE6AAC5DAA1D9EEB5D0E3ABC8D9A2DEEDB6C5D29A93A068
CDDBA0D3E3A5D6E9A7CDE29DC3DB91CAE598D3EFA2D4E99EA6A562CFC98FD6DAA8FBFFE1
F4FFEEEEFFF5F7FFFFF7FDFFFCFBFFFFFCFFFFFDFFFEF6F3FFFEF1DFD4BED9CBAEFFFFEA
F3FFFFE0FDFFE1FFFF82B0A3699B80D3FFDBC7E4B8D3E4B0949D64D8E3A1CDE59BC5E697
BBE293C5EA9DDDF4AECEE29BD0E69BD4EB9DD8EDA2D6E7A0D0DF9AD1DC98D6DF9CDBE5A0
D7DE9A8E9754D6E2A2D1E3A7CAE1ABD4EEBFC5E1B8C9E3C0D2DFC5D6DFC4C8D6B3D5E6BA
D0E4B1D4ECB2BDD796D2EDAACDEAA7C0DD9ACEEBA8C9E8A4C5E69FC5E9A1D1F5ADC1DFA1
CFDEB570795C5E674CC0C8B1FAFEEDFEFFF4FFFFF8FFFFFA
A7C168CDE8A1274521A7C3ACCCE2BECFE0B3D1E0A7D6EBAAC5E5A2C9EFA4C5E894C7E490
CBDF978FA35CD7F5ABC5E79BCCEBA7C9E6A3C8E3A0CDE6A2D1EBA4CFE6A0C3DA92B8CE85
889E55A0B86EBFD78DCEE89ECFE99FCAE69BCAE99DCEEDA1C8E89CC9E99DC1E198D4F3AD
C9E8A5CFEEABC3E29FCAE9A5CFEFA6C0E095CFEFA4CBEBA0CEECA4D3F0ADBEDB99C4E4A1
C4EA9FC5EE9FC5E79AC9E89AD5F0A3CDE597CEE698CFEA9BC3DF94CDEBA1D4F1AEDAF7B7
EAFFC9F5FFD6E8FCC9CDE2AACCE7A2C9E99DC9E99DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9D
CAEA9EC6E599D1EDA2CEE89EC8DE95D8ECA4C8DC948BA159C5E099CDEBA3C5E498CBE898
D0EB9CCEE99AD3EB9FC5DD91C6E192D2ED9CC7E490CFEF9CC4E594CDEDA2C8E9A2C2E19E
CCE6A9CCE0ABCBDDB3CEDFB2D1E6A5D3E8A7D1E3B3CFDDBAF9FFEAF5FFE4DAE9C0D0DFB8
D5E1C9D1DEC4D2E1B6D2E4B4CDDFB5CFE1B9CDDCB3D7E4B6D1DDABD9E4ACD7E1A48F9A58
DDEAA5D8E7A2D5E6A0CCE19CC8E19DD5F2AFCEEDAAC9DFA1B6B682B9B286DED8B6FFFFE9
FFFDF4FCFCFCFEFEFFF6F9FFFCFFFFFCFFFFFEFFFFF7F6F1FFFAF0E1D5C9E5D3C5FFFBF2
F5F9FAF4FFFFF0FFFF617E79709F8DA7DEC1BAEAC4C1E5B997A776949C63E5EEADD5E69F
C6E69ACBF2A3C8E69CC5DF96CDE79DCDE89BCCE89BCCE89BCDE79DCFE79DD1E59DD3E49D
ACB77298A35ED6E19FCCDB9ADAEEAFD1E9ADBAD89CCCEAACCEE7A6D1E7A6CDE7A6C9E8A5
C6E7A2C4E8A2C5E9A1C9EB9FC8E89CCBEA9CCEED9DCFEE9EC5E898CAF1A2CAF3A7C5E8A8
A5B7912C361DA2AC91F7FFE6F5FEE3FCFFEAE7F0D5FCFFEA
A8C45DCDEC9C7B9E80BFDFD4B8CEB795A38091996AC8D59FCCE8ABBCDD96E9FFB2D0E894
E1ECA7ADBC79A5C379C7EC9FC8EA9DC4E699C4E498C8E79BCFEBA0CFEBA0CAE49AC4DE94
C1DB91C6E297CEEA9FCDECA0CAE99DC7E79BC7E99CC9EB9ECCED9ECDEE9FC3E398CCEBA5
BEDD9AC8E7A4C4E19FCDEAA7C7E29BC7E399CFEBA0C6E298C1DB94C8E19FCCE4A6D8F5B3
CAEEA6CFF4A7BFDF93D1EBA1D9EEA3CCDE94D8EAA0C8DE93D3EDA4D2EDA6CFECA9D1EFAF
E1FAC0EDFFCCE7FBC8D5EAB1CDE6A2CAE99DC9E99DC9E99DC8EA9DC8EA9DC6EB9DC6EB9D
C9EB9EC4E699D0EFA3CFEBA0C5DD93D3E9A0CEE29AA2B870CBE59ED2EDA6C9E59BD1EDA2
D1EC9DC1DC8BCDE897DDF9A5DCF7A6CEE998C4E191CEEA9FCBE9A1D2EFACCEEDAACEE8AB
ECFECCFBFFE1FBFFEDFBFFE8E8F7C0D4E6ACCFDDB9D1DDC5F8FFF2F9FFEFF1FFDCEFFDDC
F9FFF6F7FFF2F9FFE2FBFFE1F8FFEAF8FFECF5FFE4FBFFE1FBFFD7F3FCC7D2DA9F798241
C6D18CCEDB95D1E29CCEE39ECDE8A3C2E19EC6E6A5F4FFD3FEFFD6D9D3AFECE2C9FFFDEF
FFFBF9FFF5FBFFFDFFFDFCFFFCFFFFF4FAF8FBFFFBFBFEF5FFFEF8F4E7E1CCB9B5FFFAFA
FFFFFFF7FFFFFCFFFFECFFFD346456538F7694CBABBAE4BCA8BF919BA46FACAA71DCE19F
D5F4A6ACD684CDF0A0DBFAAECCE89DCCE89DCAE99BC9EA9BC9EA9BCAE99BCDE89BD0E69D
B3C07A96A15DDBE6A4D4E0A0D2E2A3F2FFC7DBF8B6D0F0A7CCE999CCE997C9EA9BC6EB9D
C2EB9FC1EB9FC2EB9FC5EC9DCDEE9DD2EF9DBFDC88D1F19CC4E594CAF1A0B6DF91C7EAAA
000A00A5AF94FBFFE8F3FEDEE4EFCDBECAA4EFFBD5D3E2B9
DAF493CCE7A086A68FE8FFFFF4FFF4F3FEDEB1B68DDEE6B5D5ECB4C6E3A1C0D88ADBEE9F
CFD595D7E1A48DA662CFEFA6C8EA9EC6E89BC5E599C6E69ACAE99DCDECA0CFEBA0CFEBA0
D8F4A9D3EFA4CDE99EC8E79BC9E89CCAEA9ECAEC9FC9EC9CC1E291CBEC9BCAEB9CD1F1A6
C9E79FD1EFA9CCEAA4CEECA2CFEBA0D6F2A5CFEA9BCEE99CD0EAA0D0EAA1D1EAA6C2DD98
CFF1A7C6E89ECAE69CD1E79FCBDC96D4E39EDAE9A4DCF0ABD2E9A5C6E19EBEDB99BFDD9D
CAE3A9D0E7AFCFE4ACCBE0A5CCE7A0CAE99DC9E99DC9E99DC8EA9DC6EB9DC6EB9DC6EB9D
C7EC9EC3E598CFEEA2D1EDA2C4DE94CEE69CD3E9A0BFD58DCEE8A1D6F1AABFD990C3DD93
DAF2A8D5EDA1CDE599C4DC90D5EDA3C3DA92CDE49ED3E9A8CDE5A7C7DFA5C5DEA5C8DEAD
E2F1CAF4FDE2FCFFF3F9FFEDE2EFC3CFDCAEC9D6BACED9C9F7FFF6F9FFF4F9FFEAF9FFEC
F9FFFAF9FFF8F3FFE0F6FFE0F5FFECF5FFEEF7FFEBFBFFE8FEFFE1F6FDD1D5DCA88B9358
E0EAABE0ECAADAEBA5C9DF97D3EEA7C4E49BBFE099F4FFCFFEFFD8F4F4D2BFBBA2C8C0B3
FFFCFAFFFBFFF8F1F8FFFEFFFEFFFFF5F9F8FCFFFBFAFDF6FFFEFAFFFCFAC3B0B2FCEDF0
FFFFFDE9EFEDFCFAFDEAF9F66297870848307CAA8EC9ECCBBCD7ACADB98769622BD5D494
C4E596D5FFAABADC88C3DE8FCCE89BCAE99BC9EA9BC8EB9BC8EB9BC9EA9BCDE79DD0E69E
D1DD9B98A263CDD599E9F3B7D3E1A6F8FFD1E4FCC2CCE9A7CAE69BC8E797C7E99CC5EB9E
C3ECA0C2ECA0C2EB9FC5EA9DC2E193D5F2A2D1EC9DD3F0A0C7E698C4E99BBFE598D7F7B6
0009001116006B72515A613FCBD5B0DDEABFCCDBB0D2E3B6
D1E991C4DE9D4E6D5DEBFFFFEFFFF0FCFFE8BDBF98D7DDAFCCE0ADCEE8ABCEE49BD9E69E
EDEEB4A8AD75BDCF91BCDA94CAECA0CAEC9FC9EB9EC8E89CC8E79BC9E89CCDE99ECFEBA0
CAE69BC5E498C4E397C6E69ACAEA9ECBEDA0CAEC9FC7EA9AC5E793CBED99CAEB9AC7E899
C3E296C7E59BC2E195BDDC8EB7D484D4F1A1CEE998D0EB9ACCE798C9E497DCF6ACCCE89E
C1E198C8E89FD5ECA88093516E7A3CD6E2A4D7E2A6D1E0A5D4E8ABCDE7AACDE9ACD2F0B2
D1EDB0CBE5A8CCE1A8D1E7A9CCE7A0C9E99DC9E99DC8EA9DC6EB9DC6EB9DC6EB9DC6EB9D
C9EEA0C2E497CAEA9ECFEEA2C8E499CAE49AD3EBA1CFE79D59732AB2CD86D1EBA2CCE39B
D0E79FD5EBA3D6EAA5C9DD98CEE1A1CDDFA1DBEDB3D1E2ACCADAA9CFE0B3EBFCD0F8FFE3
FBFFE8FCFFF1FCFFFAFCFFF4FCFFE4FBFFE3FBFFF1F9FFFAF7FFFBF9FFFBF9FFF1F8FFF0
F9FFFAEEFAEED6E4C3D4E4C0F7FFF0F8FFF4F9FFF1E5EFD6C4CDAEB2BA939EA57978814C
C3CC93C4D090DDEEAAC9DF97CFEBA0CFEFA3C3E598CDEAA7C4D4A5FFFFE3FDFDE5DFDCCB
FFFAF5FFFCFBFAF1F2FFFDFDFFFFFBFDFFF9FEFFF8F8F9F3FDF9F6FFFCFDDECFD6D7CBCF
FFFFFDFEFFFDFFFDFFF8FFFFB7EDDF599A8498BFACEBFFEEC9E5BDC6D6A7D4C896AAA468
C9EA9BC5F39BCBEB96CBE491CDE899CAE99BC9EA9BC8EB9BC8EB9BC9E99DCDE79ED0E5A0
E2F1B098A2669CA36DFCFFCFEBF5C1E3F3C2CFE3B2CCE5ACC9E49DC7E69AC6E89CC4EA9F
C4ECA3C4ECA3C4EA9FC5E79DCBE99FC5DF95CFE79BBDD589D0ECA1D0F0A5D2F6ACB4D292
ADBD9069714C727854A4AC85767F54222B00D0D9AAD9E3B1
D0E89AD0ECB229493EEAFFFFF1FFF7F8FFE7ECEEC9DAE0B4C7D9A9DEF5BDD6E7A3CCD592
9E9B665D5D29CFDDA2C9E4A1C8EA9EC8ED9FCBEDA0C9EB9EC7E79BC6E69AC7E69AC9E89C
C5E498C8E79BCBEA9ECDEDA1CDEDA1C9EB9EC4E99BC2E797CBED99C9E994C6E693C1E18E
CCE999D2EF9FD8F5A5D5F2A2E2FDACC4DF8E8BA65594AF5EC1DA89D6EEA0CCE49692AD60
AFCA838DA8638EA16195A366868F58959C6879814E8F9B69C5D7A3CEE5AFE0FCC2EBFFCD
E1FDC0CEE8A9CCE2A2D3ECA8CAE89EC8EA9DC8EA9DC8EA9DC6EB9DC6EB9DC5EC9DC5EC9D
CAEFA1C1E698C5E79ACDEDA1CCEB9FCBE79CCEE89ECFE99FEAFFBCBAD68C6F8942768D47
B7CC89CFE2A2ACBC7E738146A6B07BD2DBACDDE6BBD8E3BBD7E1BEDDE8C8EEF9DBF0FAE1
FCFFF1FAFDF4F4F6F5F3F8F2F9FFECFBFFEDFBFFFAF9FFFFF9FFFFF5FEFDF8FFF6F3FFEF
F8FFFAF5FFF2D3E2C1D0E0BBE0EED7EFFCEBF9FFF1F8FFEAE8F1D4EAF1D0EBF1CBE7EEC2
7D8752748245CEE19FD4EBA3C5E194C8E998CFF29EC2E297DCF3BFEEFCD8FEFFE8E0E2CD
BDB7ABDBD2CBFFF9F2FAF3EBFFFFF4FDFEF0FFFFF4FFFFF6FFFCF9FFFDFFFFF7FFC6BCC4
FDFEF9FBFCF6FFFAFED8DDE06CA49965A595CEEFE4E5FCECDDFADBDCECC5FAE9BE9E935D
C7E899B7E58BD3F19BD5ED99CDE899C9EA9BC8EB9BC6EB9BC6EB9DC8EA9DCCE89ED0E5A2
D5E3A6A0A771727644FFFFD6FFFFDCD2DDB5C7D6AFD0E6B7CCE6A5C7E79CC3E79DC4EAA1
C4ECA3C4ECA3C4EAA1C5E69FD6F1AACDE49EE0F6AED8EEA6CCE39DC9E49DD6F5AFC1DE9C
D5E7B3CDDAACCBD7A9A0A97AA3A9796D6F3E302E003A3704
CDE99FBDDBA70F322BCBEAEFF1FFFAEFFCE0FFFFDDC3CB9CCBDFAEDCF3BBC2D291D2DB9A
64612E777544C4D297DBF4B2C4E69AC3EA9BC7EC9EC9EB9EC9E99DC8E89CC8E79BC8E79B
C9E89CCCEB9FCDEDA1CCECA0C7E99CC4E99BC5EC9DC8ED9DC8E998C5E592CDED9ACDED9A
D8F5A3C9E694C7E492C0DD8BA3BE6FA5C07194AF628DA5598BA3558DA55792AA5C869E52
A7C17ADBF1B0C1D193DCE7AFE3E7B5EAEDC0B7BC93727B50B7C79AC9DFAEE2FDC6EDFFCF
DEFABDC8E2A1C4DD99CCE69DC9E99EC8EA9DC8EA9DC8EA9DC6EB9DC6EB9DC5EC9DC5EC9D
CAEFA1C4E99BC4E699C9EB9ECEEEA2CAE99DC9E59ACCE89DB5D186D4F0A6ADC47E7E9350
A2B575DCEBB09AA46F00080043481F9DA17C959879C1C5AAE9EDD6FEFFEDFEFFF1FEFFF3
FEFFF6FEFFFBFEFFFFFEFFFFFCFFF4FBFFF3FCFFFFFBFFFFFBFFFFF3FBFEF8FFFAF1FDEF
F7FFF8F7FFF1D1E3BDD0E2B8D5E4C7DFEDD4F5FFE9F7FFE6F9FFE3FEFFE3EFF7D2EDF6CB
ACB8866D7C43C9DC9CD9F0A8C5E292C2E48ED3F79FC7E99CCCE7B0E2F7CEF9FFE4E0E6CA
9B99849F9886E1D8C7FFFFECFFFFEAF3F3DBF6F9E4FFFFF1FFFFF8F3EFEEFFFCFFD9D2D9
FFFFFAFEFBF6FFFAFFC1C4CB457A7467A69EE9FFFFF1FFFFEAFFF0E6F5D6C9B793C8BC8A
CEEEA3C9F59EC6E28DCCE490CCE999C9EA9BC8EB9BC6EB9BC6EB9DC8EA9ECCE7A0D0E5A4
CCDA9FAFB68375784DFBFBD5FFFFE3D8DFC0D2DDBFD2E2BDD1EAB0CAE9A3C4E8A0C3E9A0
C3EBA2C5EDA4C6EAA2C7E6A0D0E9A7C9DE9DC2D595CFE2A2C5DA99C9DF9ECDE8A3DFF9B8
D1E4ACD2E3ADDDEBB69AA46F6067316F723B504D1657521B
D2F3AEC4E9B64A736BD5FBFEEEFFF6E9FAD8FEFFDABFCC97CAE1ADC2DBA2E3F6B4DDE8A6
D3D09BA6A471D9E7A9C5DF98C6E89CC3EA9BC4E99BC7E99CC9E99DC9E99DCAE99DC9E89C
C8E79BC9E89CC7E79BC6E69AC5E79AC5EA9CC7EE9FCBF0A2CEEDA1C9E598D5F2A2CDEA98
C8E3929EB96895B06191AC5DB4CC82B7CE86C8DF99CCE19CCFE59DD4EAA1CEE49BD2E89F
CFE6A2E6F8BAC4D297D9E1AEE6E7BBF1F2CAB9BB96B5BB97D5E4BDE6F9CCF2FFDAF1FFD4
E0FDBDCFEAA5CCE69DCFEBA0C9E99DC8EA9DC8EA9DC8EA9DC6EB9DC6EB9DC6EB9DC6EB9D
C7EC9EC8ED9FC7E99CC7E99CCBEDA0C9E99DC6E69ACCEB9FD8F4A9CBE79CCCE39BDAEFAC
C5D59798A56F5B6332050700828260E5E4C8969580C7C6B4E7E5D8F3F3E7FFFFF8FFFFF8
F5F8F1FCFEF9FEFFFFFEFFFDFDFFF9F9FCF5FCFDFFFCFFFFFBFFFFF1F9FCF8FFFDF0FCEE
F5FFF1F4FFE9C7DDAFCAE0AFD4E6BCD7E7C2E9F7D3E8F4CEF1FBD6F5FFD8DEE9BFE1EDBF
DBE7B5899B61D2E7A6CFE9A0CBE898C6E892CDF197C3E996C5E7AAE0FCCBE8FDD2EDF9D3
FBFCDCE8E3C5C4BDA0BAB494F5F2CFEBEDC8E4EAC8EFF5DBFAFDECF7F8F0FFFEFFF8F6F7
C0BDB8FFFEFAF8EBF2F9FCFF5A86896BA2A5D1F6FCE7FFFFEDFFF9EDF5E0FFF9DCC2BA8C
D1ECA7B7DE8DD3EF9BDCF3A1CCE999C9EA9BC8EB9BC6EB9BC5EC9DC6EB9ECAE8A2CFE5A5
D4E1A9A7AD7D92936BFEFDDEFFFFE8ECEED8E9EEDAE0EDCFD7EEBACDECA9C6E6A3C2E7A1
C3EBA2C5EDA4C7EBA3C7E6A2D3E9A9BED094859358647237D3E2A7DAEEAFC5DE9CC0D997
D9EBADA0B07293A164BECC8ED2DEA0E7F1B2DCE5A6DFE8A7
C7EEABB3DDAD59887EDBFFFFDEFFE7F2FFE1EDFEC8BDCF93CBE7ADCDEBADCBE29CD2DF9A
DFE0A79A9B62D2E39FC7E398CCEEA1C6ED9EC4E99BC6E89BC8E89CC9E99DCAE99DC8E79B
CDECA0CBEA9EC9E99DC9E99DC9EB9EC8ED9FC5EC9DC5EA9DCDEBA3C2DD96CCE89DC5E093
C5E091A7C273BBD689D2E9A1D0E7A3C4DA9AD6EAADD0E4A7D1E5A6D8EDACC9DE9BD8EDA8
D0E5A4C8DA9CE3EEB6D3DAA7D2D3ABEBEBC7858563D0D6B4F7FFDFF7FFDFF2FFDAEDFFD0
D9F6B4CCEAA2CCE69CCCE89BC9E99DC8EA9DC8EA9DC8EA9DC8EA9DC6EB9DC8EA9DC6EB9D
C6E89BCEF0A3CAEC9FC5E79AC9EB9EC7E99CC6E89BD0F0A4C8E799C8E499CCE69DD6EBAA
D5E4A9D6E0AC93996D08080079755AFEF9E5ADA797FCF8ECFFFFF6FFFFF7FCFBF6FFFFFA
FEFFF8FEFFF8FDFFF9FDFFF9FEFFFAFEFFFBFEFFFFFEFFFFFCFFFFF3F8FCF9FFFDF5FFF1
F7FFECF5FFE1C9E2ABD2EAAECEE3ABCDE0A9D8E9B5CADBA7CFDDACD7E5B4CBD7A7DDEBB8
919F6A788A50D8EEADC7E19ACBE79AC9E996C7E992C2E895C5EAA5C3E5A9C9E1ADCEDEAF
D9DFB3DAD8AFA49F75525020D1D3A2EAF1BEDCE5B8D0DBB3E3ECD1FCFFF1F1F4EBFFFFFB
B6B1ABFAF0EEFFFBFFEFF3FE6E909A0E3E48C9F5FEE7FFFFF5FFFFF6F6ECFFFEE8828057
829A5CD5F7ABC4DF90CEE796CCE89BC9EA9BC8EB9BC6EB9BC5EC9DC6EB9ECAE8A2CFE5A5
D9E6B0888E60A1A17BFFFFE4FFFFE9FDFEECFEFFF2FBFFECDBF1C2D1EDB0C7E7A6C3E7A1
C4EAA1C7EDA2C9EAA3C9E6A4CBDFA4EAF9C2BCC6922B3500DEEBB3C3D597D3E8A5D0E7A3
91A1605464238D9E5AD4E5A1D1E29ED2E69FCEE29BCFE39C
C0EDAABAEABA447A6DB1E4DDBBE3C1C7E5B1CAE0A0A5BE7AC3E6A4C5EAA5CFEEA2C6DA92
DBE1A3C0C6889DB368CCED9CC8ED9DC4EB9CC3E89AC6E89BC8E89CC6E69AC7E69AC8E79B
C8E79BC8E79BC7E79BC8E89CC9EB9EC8ED9FC3EA9BBFE399CAE7A5C9E2A1D8F1ADCDE49C
C6DE9294AC60C8DF99D1E6A5D1E4ACC7D9A5CBDBACD2E2B3CFDFAECFE0AAD2E4AACEE0A2
C8DC9DF9FFCDF4FFC7EEF5C2ABAC84BABA96F5F5D3D5DBB9DEEAC4CEE0B6C5E0ADCBE9AD
CFECA9C8E69CC8E396CBE898CCED9EC1E396CFEFA3C5E599CBEB9FC0E295CEEEA2C3E598
C1E195D1F3A6CAEC9FC4E699C7E99CC6E89BCBEDA0CBEDA0D3F4A5B5D488D7F1AAD9EEAD
CAD79FDCE4B3BEC0990403008A866D8B8673FFFBEDFCF8ECFFFFF4FFFFF6FAFCF1EAEDE2
E1E8D8E8EFDDF3FBE6FAFFEFFCFFF6FAFCF7FCFCFAFEFFFFFCFDFFFCFFFFF9FFFBF7FFF2
DBEDC7E3FAC4D4EEAFC6E099C9DE99E1F5AEBDD18CD5E8A6C5D79977894D84935A95A76D
CFE1A5D0E4A5D0E6A5CDE7A0CBE79CC9E898C9EB97C9EC9AC7F0A4BEE39ECFECACC7D99F
D9E2ABD7DAA39D9E656E6F33DAE0A2D2DC9DCFDDA2D5E3AEDCEBC2E4F2D1F1FAE5FEFFF3
90877EFDF2F0FBF6FCF7FFFFEAFFFF86B0BE7BB1BBE0FFFFF6FAFFFFFBFBFFFCE99EA47E
869962C9E2A0CEE89EC7E295D6F2A7C4E397BDDD91DDFFB4B5DB8ECEF3A6CAE9A3C8E19F
DBEAB18D95649A9A74FBF7DAE0DEC9FFFFF1FFFFF4F1F9E2EAFDD0E3FCC3D6F4B4C0E19C
CDF3A8C8ECA2D6F5AFC3DD9CD2E5ADCDD9A791996A212900D3DDA8E2F2B4CBDE9C4D631B
ADC17AC8DC95D5E9A2C9DF97D5ECA4C6E096CFEBA0CAE99D
BCECAEB6EABA336B5EAAE2D7C8F5CEBFE3A6D3EEA7C3DF94C7ECA6C4ECA3C6E798D0E89A
DFE8A7BEC9859CB766C1E58EC5EA9AC5EA9CC7E99CC9E99DCAEA9ECAE99DCBEA9ECCEB9F
D1EDA2CEEDA1CCEB9FC8E89CC7E79BC9EB9ECAEFA1CEF0A6D0EAADD9EEB5BCD292D0E7A1
D6EEA48AA159D5EAA7D7EBB0D4E6B6CEDFB5D3E1BED6E4C1CEDCB8CDDCB1D2E0AFCCDDA6
E0F4B7E9FBBDFCFFD1AEB683FFFFD8FFFFDCEBEDC8D3D9B3C7D6ADD1E4B6D2EDB6CCEAAC
C7E4A1C9E59BCCE798CBE898CCED9EC8E89CCBEB9FD0EFA3C5E498CAE99DCCEB9FC9E89C
C9E89CC8E89CBFDF93C4E699D1F3A6CFF1A4C6EB9DC0E597CCEF9FD1F0A4CDE7A0C0D495
D8E7B0DAE2B3CCCEA9060500716D54DCD7C3FFFFEFFFFFEFFFFFEFF2F6E5E7EEDCD3DCC7
D0DDC3D8E5C7E8F3D1F6FFE2FCFFF4FEFFFAFEFFFAFEFEFCF9FBFAFAFCFBFAFFFAF9FFF1
DAEBBFCBE1A3C2DC95CCE79ACEE597CADF90DEF3A695AA5F889C55D3E7A2D2E5A3D3E8A7
D5EAA9D1E8A4CBE4A0C8E39CC7E59BC7E69AC7E899C5E898BDE495D2F7AACAE8A0D4E9A6
D9E5A5DBE1A19AA15E4E550FD8E49AD3E39AD0E49DD0E4A5D0E5ADD7E8BCE7F6D5FCFFEA
A19889C2B7B1FFFFFFF7FFFFE2F5FF6E94A137787CABDEE2FEFCFFFFF5F6FFFFEFCCDCB5
BBCC98D1E5A8C8E29BD7F3A9BDD790DFFBB1CCECA1B8DA8EB7DC8FC8EDA0C4E49BD3ECAA
CBDA9F919966575830DCD9BAEBE9D2FFFFEFF7F8EAFCFFEDF9FFE1ECFFCDEBFFC8C6E5A1
C0E296C7E99DC8E69ED5EEACCBDCA5E4F0C0DAE1B5343A0CD8E0ADC7D59A97AB66D2E89F
CDE59BE8FFB6C4DC92DAF4AAC7E398C6E298D5F3A9C4E499
BEEFB7B8EDC32D675BA8E0D5DDFFE1BBDF9FCBE79CD2F1A1C7F0A4C4EEA2C2E593D3EE9F
D1DC98A7B46EA8C670CCF39AC6E997C8EA9DC9EB9ECAEA9ECAE99DCCE89DCEEA9FCFEBA0
C0DA90C5E196CCE89DCEEDA1CBEB9FC6E89BC4E699C5E49ECBE3A9BDD099DFF3B6CEE3A0
C5DB93B7CD85D6E8AACFE0AAF9FFE1F7FFE6FBFFEDFBFFEFFBFFECFBFFE6FCFFE1F6FFD5
F2FFCCC4DA9ADDECB1455018D2D6A4DEE1B4D7DDB1D5DEB1D0E0B1CEE5AFCCE8ADC9E7A7
CBE9A3CFEBA0CFEA9DCDE899CAE99BC8E79BC0DF93D0ECA1BCD88DCEEA9FCAE69BCCE89D
CAE69BCFEEA2D7F6AAD3F3A7C6E89BBCDE91C0E597CEF3A5C1E494CDEDA1CCE7A0CAE0A0
C4D39CFDFFD785896404030028270BEEECD3E6E6CEFFFFE8FDFFE7DFEACADCEAC9D4E4C0
CADCB4CEE1B4D7E9B9E5F4CBF5FDE8FEFFF8FFFFF8FFFFFAFFFFFBFDFFFCF7FCF8FBFFF1
D4E6B4CBE29ECAE49ADCF4A6DAF1A1CBE0917A8F40ABC073DAF0A5C0D68DDBF1A8CEE59D
D0E79FCCE69DCAE49BCBE79DCCEAA0CDEBA1CAEA9FC7E99CCCF29FB0D381D3EFA4CBE198
D4E19CD2DD9898A45C96A457D3E695D2E997D0EB9CCBE79DC7E09FCCE3ABE3F4C7FEFFE3
FFFEEAC4BAAEEBF1E7E8F7F4F2FFFFD5FAFF3F87833A7770FFFEFFFFF6F5F9FFECD3EAC0
B2C38F9CAE727C95538AA55ECCE39FC6DD99D2EDA6D5F5AAD2F7AAD4F6AAD5F5AAC4DD99
CDDFA1A6B07B4A4D20D5D5B1CFCEB0FFFFE8F2F3E1FEFFECE6F2CCE5F7C5D5EDB1D8F6B0
CCECA0C5E697C7E399CBE1A0D7E6AFC5CEA1656A41494E25DAE2AFCFDDA298AC67C8E094
C8E497C8E799C1E094CBEA9EDDF9AFCAE59ECDE6A2CBE4A0
D2FECDC9F8D6437A75AEE3DBE6FFE8C3E6A6B0CB7ECFEC9CCAF0A5BDE59CC4E797D8F0A4
D3DE9CA1AE68BFDD87D0F49AC7EA98CAEA9ECAEA9EC8E79BC9E59ACDE79DCFE99FCEE89E
DEF6ACD6F0A6D0EAA0CCE89DC7E69AC5E599CAEA9ED2F0AAD3E8AFCFE2ABDDF1B2819651
94AA61CEE49CD4E6A8EDFECAF4FFDFF3FFE7FAFFF3FBFFF6F6FFEEF9FFEBF8FFE2E6F5CA
E5FDC1CAE5A2D6E8AA909E63A4AD76B0B783E0E9B4D5E2ACD9ECB4CCE4A8C5E2A2C9E8A4
CAE8A0C7E398CDE599D6EEA2D0ECA1CBE79CC9E59AD9F3A9D0EAA0DCF4AAD4ECA2C9E399
CBE59BBFDB90C5E196C5E498CBEB9FD5F7AAC8ED9FBCE193C1E696C5E79AC8E69EDFF8B7
C7D8A1FCFFD86E734B0708002C2D0DECEDCDCED2B1F9FFDCFBFFDDD0E1B4D1E7B6D0E8B4
D1E9B5CEE5AFCCE2A4D3E5B3E6F0D7F8FEF2FEFFF6FFFFF8FFFFFAFFFFFDF9FBFAF1F8E8
D1E2AED9EFA7CCE49ABED68AB1C57D63772FBDD189D5E9A1C5DB92E0F6ABBCD488CFEA9D
C8E396C9E59ACDE99ECFEBA1CEECA2CCEAA0C7E79EC5E59AC6E796D2F29FD5ED9FD2E69E
DEEDA8BFCC86C5D58CA2B76ACEE794CDEB95CCEE9ACAEB9CC7E59DCDE7A8E1F6BEFBFFD7
FFF8D9F4ECD5FCFFF1F5FFF8E5F8F4E4FFFF59A89540806FF7F8F2FFFAEDF8FFE6DFFBCA
D5E8B1DBEDB1C9E4A1CAE8A293A86772874698B16DD2F0A8BEE094ADCF82C1E195D3EDA4
CFE2A0CFDA9EA0A472EAEBC1CDCDABFFFFE6FFFFEAFEFFE8EDF7D2E2EFC1B9CD92CEE7A3
C8E497C7E696CFE99FD4E9A6E2EFBAD6DDB1C4C9A15F643BD0D8A79DAB70ADC17AD0E89A
C9E898C7E899C8E79BD5F3A9C1DC95CCE7A4C5DE9DDBF4B3
E7FFE7D7FFE7548488AEDCDAE9FFEAD3F1B59BB168CFE698CEEFAAB7DA96CAE89EDAEEA7
D2DA9EAAB372D0E996BFE18AC8E998CCEB9FCBEA9EC9E59ACCE69CD3EBA1D3EBA1CFE79D
CEE49BCAE298CCE49AD0EAA0D0ECA1C9E89CC5E498C7E29BC8DDA2E0F3BBA0B37171853D
B6CB7CC4D98ECBDB9AF1FFCCFBFFE4FBFFF1FCFFF8FCFFFBFCFFF6FCFFF1F7FDE1D8E7BE
D6F2B7CAE9A5C6DC9BC4D797828E508D995BC3CF91D7E7A8C9DE9DCEE9A4D0EEA8CAEAA1
C5E399C8E49ACDE59BCEE69CCDE79DCCE69CDBF5ABD1E99FC8E096BED48BCFE59CD0E69D
D9EFA6CFE79DD8F2A8C2DE93B5D589CDEFA2CDF2A4C7EC9EC9EE9ED3F8AABFDF96DAF3B2
F3FFCED6E4B1B7BE94010600393E16C8CFA6D4DDB0E7F5C2EAFFC6C6E0A1CEEDAAC5E4A1
D1EFB1CCE9A9C7E29BCDE2A7E0EDD3F8FEF2FEFFF6FFFFF6F6F5F1FFFEFFFDFCFFF9FCF1
D5E1AFD1E29CB4C8819BAF6AA3B57BBCCB94C7D99FCADCA0D4E9A8D3E8A3CCE49AD5F0A3
CBE699CDE99CCFEB9ECBEA9EC7E59BC5E399C6E69DC9E79DE6FFB3C4DD8CC6DB90E0F1AB
BFCE8BE0F0AFA5B974D8F2A8CAEB9AC5EB96C5ED97C7EE9BCAEA9FCFEAA5DBF1B3ECF6C1
FDF8CEE6E0BEECF3D2E5F8DCD6EFDAD3FFE92B7B58357855E8F2DAFAF3D7EBFCCFCCE8AE
CAE0A2D8EEADCCEAA2C4E29CD6E8AAACBB80728746A4BF7ACEEEA3E7FFBBC5E496D4EFA2
E1F5AEC0CF8EB4BC83B3B785E5E7BFFBFFDCEFF4D4FEFFE4DCE4BFD1DDAFEDFFC3C9E09A
8AA55692AD5C839B4FD0E3A1C5D29DF0F7CD676B46242901929C6A92A264CCE299D2EB9A
D4EFA0C3DE91E6FFB8B9D48DC4DF9CCFECACDAF6BBBFDDA1
EDFFF0D8F8EB436974A8CFD4E7FFE7D4EBB396A560D2E39CC9E6A4C1DFA1D9EFAED0DF9E
91945D959B5FCEE396CFEC98CAE699CDE99ECCE89DCBE59BD2EAA0D7EFA5D0E69DC4DA91
D4EAA1CEE49BCEE49BD2EAA0D0EAA0CAE69BCCE89DD3EEA7D7EDAF96AA6D9BAF68C4D98A
DDF3A0D2E896C8D995D5E3AEE7F2D0EEF7E6F8FDF7F8FDF9F8FDF6FCFFF3F6FCE2D2E1B8
BFDDA1C1E29BDCF7B2E8FDB8D1E29CC4D38E91A15AC5D991C9E197D3EFA4CFEEA2C3E397
D1EDA3E3FDB4D1E8A2ABC17988A0566E863C81994FA0B66DD2E89FBACE867E924A2C4000
485C14758B42D3EBA1DEFAAFC3E296C9E99DC2E497C3E89AC4EB9ACFF4A6C6E69DD6F1AE
EFFFC8DBE9B6B4BD90050C003A4115A3AC7DD9E8B1CCE0A3CBE6A1C3E397D3F9A6BFE695
C5E9A1C6E7A0C7E698CFE8A7E5F4D7FBFFF8FEFFF6FCFCF4FFFCF9FFFAFEFEFBFFFFFFFA
D8E1B2C4D390B8C985BFD195FBFFDDE1EDC7D8E7BEDFEFC0CADDA5CDE3A3D5EFA8C3DF94
CCE89BCDEA9ACAE999C9E89AC9E89CCDEBA1D2F2A9DBF7ADC4DB8DC4D68AE3F4ADC7D693
DFEDAF98AA6CC7E09FC3E29CC9EFA2C1EC9ABFEB96C3ED9BC8ED9FCAE8A0D0E6A5D9E4A8
DBD8A58C8859D8DFB5C2D4ACD3F3CEAADEB72D7B4BACF0BFCFE1B9D6D9AECCDDA6C8E2A1
CBE6A1CBE99FC9E99ECDE8A1D1E0A5E6F3BBC2D496B1CA868CAA60C1E293C6E595CCE999
C5DA8FDBEAA5D7DFA3CCD19B1F2200F1F6CDFFFFDFFEFFE1FAFFDAD0D7AB5F6D3295A962
CCE594CFE895E4FBADA6BA759CA67242491F50542F1E2300DCE6B4D2E2A4CAE095CFEA99
D0EB9CBCD68CC0DA93E5FEBACEE6A8BED69CD6EDB71F3602
F2FFF6E0F9F5264559BEDBE9EFFFEDCCDDA99DA866D4DF9BCBE0A5CFE8AFD6E8ACD0D9A0
545221A1A16BCCDC95DEF6A8CBE699CEE89ECEE89ECFE79DD2EAA0D1E79EBDD189A4B870
42560E5F752C93A960C1D98FD4ECA2CDE79DCBE59BD0EAA1D2E6A7819454C3D88DE0F6A3
C5D982DCF09BD8E9A2DAE9B2D8E2C0EAF1E1FCFFFBFCFFFDFDFFF9FEFFF3FCFFE8DAE9C0
D1EFB1C4E8A0CBEBA2B9D38AD5E9A1D6E89C849748D7EE9ED3EE9DCFEC9AC7E696C3E495
CDE99ECCE69FB5CC8897AC67D1E8A0CFE79DDAF0A7D9EDA5D0E49CCDDE97D1E29BCCDD96
CADB94AABE76CDE59BCEE89EC1DD92CFEFA3C6E89BC7EC9EBFE695C1E899CDEFA5D4F1AE
CDE2A7D3E4AE838F5F565F30909A68C3D09AE3F5B7CCE69FC9EA99C4EB92C6F394BCE98E
BFE89AC4E89EC7E897CFEAA7E4F4D9FBFFFAFEFFF8FBFAF5FFFEFFFFFDFFFFF8FFFFFEFF
D8E1B6CCDB9ACADA9BDAE8B5ECF6DBFBFFF1F9FFECD5E3C0CEDFB2D2E7AFC8E19FD9F5AB
CCE89BC8E797C7E696CBEA9ACFEEA0CEEDA1C7E59BC4DE94CBDD93F3FFB8D2DE9C8D995B
516027C6D9A1C4DDA3D4F7B5C7F1A9BFEEA0BDEC9BC1EE9DC6EC9FC7E79ECAE39FD2E1A0
EAEAAE939158EAEEBBC5D9A6BFEAB585C18B307C3EB7F7BACFEAB3D6E1A7CFDF9ED4EBA3
CDEE9FC0E595C2E595CAE49BC8D69BD1DAA5D8E7ACCDE3A292AE64B9D88AD6F6A3C5E290
DBF0A1D6E69DD4DF9DC7CF94E0E7B3A2AA794A5326525A314A4E2962683CCFDAA0D0E19B
CCE391D3EB97B5CC7CE3F4B0D9E3AF62693F070B002F360DC6D09ED5E5A6D6EEA0CCE995
C5E697DBFBAFCDE8A1C6DF9DD1E5AAE3F1BC0007005E633A
EEFFFDEDFFFF1A3747DFFCFFF2FFF1C8D8A7A9B374D2DF9AD2E8A8D2EAB0C2D59DDEE8B3
565525DDDDA7D4DE97CADD8ECFE59CCFE9A0D1E8A0CEE59DCFE79DC5DD93A5BB7283994E
D7EDA2C4DA8FAAC0758FA55C798F467E944BA5BB72CFE59D6D843ECBE29AD8EF9FCFE791
CEE58DCCE28DD6E7A0CDDCA3CFDBB5E8F2D9FBFFF4FBFFF6EEF7E4F1FBE2E8F4D0C8DCAB
C5E5A4CAEEA6C9E9A0C8E299D6EAA2DAEAA191A156D3E697D0E596C7DF91CDE89BD1EDA2
AECA80809A53819A56A2BB77CFE9A0CBE59BC4DB93D3E9A0C4D890D7EBA3D7E8A1D8E9A2
D9EDA5A4BA71C7DF95D6F1A4C9E89ACEEFA0BFE292CCEF9FC7EC9CCDF2A2C8E89DC8E39E
D3E9A992A66B9CAB74CCDBA4D6E5ACD7E9ABC9E09AC9E598D3F59EC7EF8FBFEC87C9F795
C8F09AC9EE9EC7EA98C8E5A5DCEFD3F6FFF7FCFFFBFCFEFBFAF8FBFFFDFFFFFBFFFCFAFB
DCE1C1DCE5B6C6CFA2AFB996E9F0E0FCFFF8E9F2E1EBF8DEE3F3CEC5D9A8CEE6ACC5E09D
CEEAA0C8E799C8E797CDEC9CCDEC9CBDDC8C9FBE6E89A45596AB5E8193498E9F5998AB69
CADE9FCFE7A9CFEDADC2E7A2C5EFA5BFEEA0BEED9CC2EF9EC6EC9FC6E89CCCE7A0D6EAA5
888F4C8C8E4DDDE6A7D7F0AFABD99886C78559A565A3E8A9BBE4AAD0E8ACD3E4A0D1E69B
CAE795C5E894CCF1A1CBEBA0DAEAACD7E2A8D3E3A4D1E6A3BED88F9AB669A3C070CEE998
CAE191D6E89CD3E39CDDE9A7D4E2A4D6E4A7CDDFA5D1E0A9D5DDACD9E2ADCFDF9ED0E598
DFF9A0C8E289DCF3A1C9DD96CEDBA5DFE8BD5E6440353D14D0DDA8D6EBA8D0EC98C9EA93
CBEE9CC2E498CDEBA5CFE7A9CADDA62F3A0F747553FAF9DB
E0FFFFE0FFFF8AADAFEAFFFFEFFFEBC7DDACCBE09BC7DF91C6E599C3E29CD2EBB2C1D3A1
5D67339FA569D5D889DAE28FDBECA6C8DE9DE1FAB6C1DB94C9E59B8CA85D829E51CAE797
D2ED9EC1DC8DD2E99BD3E99ECCDD96E2F3ACC3D28D5B6F27CEE99ACDED9ACDEB95C9E58E
CDE692D4EB9BD5E9A2CFE1A5D0E0AFE4F3CAF9FFE3F1FFDCEDFED4D3E7B6D4EBB3C9E3A4
CFEFACC6E7A2C3E19BD8EFABD3E3A2DBE7A5949D5CD6DF9EDCE5A4C3CF8DDEEDAAC8DB99
93AA66C8E39ECDEAA7C8E6A0C4E29ADAF8AECCE7A0C8E49ACFE9A0C9E39AD3EBA1D6EEA4
8CA458CDE599CCE79AC9E696C1E090CEEF9EC9EC9AC5E695CAE999CCEB9BC7E396D1EBA1
8CA65DCAE19BCBE29ED4EBA5CBE29CC3DD93DBF8A8C9E994CCED94C3E688CDF390C8EE8B
CBF090C8EC94C6E69ACEE9B2E3F6DAF6FFF9F9FFFFFAFFFFF9FCFFFEFFFFFDFCFFF8F8F6
FFFFF4FEFFEFFAFBEDFFFFF4B1B1A7F6F8EDFEFFF3FCFFEDF2FDDFEEFDD6CCE0AFD3EAB2
C1DB9CD3EEA9CEEDA1BEDD8DC8E893DDFEA782A34ACDEE97CCE997C8E595CCE89BCDEC9E
C2E193C5E697C8EB9BC4E999C6ED9CC8F2A0C4EE9CBCE694C3EA9BCFF4A7CEF0A6C6E19A
CDDE9AA1AE68CDE091CFEE9EBAEB9ACAFFC22E7E413A8854B8F3C3B9E1ADD1E7A9D9E6A0
D6E998CDE897C0EB9CC1EBA1D2EEA4C4D891D5EBA3D9F1A7CDE59BC8E09492AA5EC7DF91
CEE597DCF3A5BFD789D9F1A3C9E495C4E191CEED9DD2EEA3D1E6A1CBDF98CEE794CDEC8F
C8E885C9E988D2EE97D3E9A0D3E2AB6D784D000700030E00CCE0A5C8E298CAEB90CAEF90
C9EF98C3E89AC8E7A3C8E1A76D8052798764F9FEE8F9FBED
D9FFFFA5D8D186B0A6E9FFF7F1FFE8CCE3AFA6C079D1EC9DCBEA9ACAEA9FD6F4B6CEE7AE
88975E8C9554E2E395F1F4A5CCD994D0E4A5C2D796D2E9A5B3CD8487A358AAC97BD7F6A6
D0EF9FC5E292D1EC9DD1E99DC2D68ED8E9A2E2F1ACBACE86C6E595C9ED96CCEE98CBEB98
CDE99CD2E9A1CFE4A3CADCA2D8E8B7E1F1C4F8FFDDF2FFD6EFFFD0CDE5ABC9E3A2C2DF9D
C2E0A2DCF8BDE1F9BDD4E8ADC6D59AD4DFA3A1A96EB9BF83E3E9ADDEE7A8D5E1A1A6B675
A2B975CFEAA5C1E09ACFEEA8CDEDA4C3E398C3E199D1EFA5D3EFA5CCE89ECBE59BC3DD93
8DA85BCEE99CD3EEA1D4F1A1C7E696CBEC9BC4E594C3E493CFEC9CC7E293A9C475B0CB7E
BCD68CD3EDA4D0ECA2C6E298D2EEA3C4E093CEEB9BC3E38ECDEE97C2E38AC7E88DC5E789
C9EB8CC6E790C7E29FD0E8B8E4F6DCF6FFFAF7FFFFF0F7FDF7FCFFFCFFFFFFFFFDFFFFFB
FFFEFAFFFFFDFFFEFFF3EFF0D8D5D0FFFFF8FCFCF0F8FCEBF0F8E1EBF8DACEDEB9C7DAAC
D4EBB5D1EBACCCE7A2D6F2A7C1DE8E85A24E75933BCDEE97C9EA99D0F3A1CEF19FC0E38F
D5F8A4C7EA96C6E995CCF29DC6E995C8EE99CAF09DC6EB9BC2E799C2E79AC6EAA0CDEDA4
D8EDA8BDCE87D6ED9BC3E38EAADB89B0F0A657A56B075525A6E9BDC6F8C7C8E4A9D2E39D
C8D98BD5F09FB9E397C3F2A4D1F1A5D3EB9FCBE397C6DE94CFE59CDCF2A9BCD289B1C77E
C7DF93CBE397CDE899C1DE8CDFFFACC0E28ECBEF98B1D37FD3EDA3D3EDA3C5E68FD6F99B
BBDF7BCCF090C6E48ECCE39DCBDCA6D8E5BA0007009EAB80CCE1A6D9F5ABCDF295C3EB8B
C9EF98C2E797D1F0ACC1DDA25E73486C7B5CFBFFF4FCFFF8
BBF2F560928F91BCABE8FFEDF1FFDFD1E9AF819854D2E9A1D3EFA5C0DE96C3E09DD9F2B0
D2E5A398A35FD3D68FC8CB84F0F9B6C6D292E1F0ADDFF0AA5F752DD1EBA1CEEA9DC6E597
CAE99BC5E496D0EFA1D5F1A6C6E297C6E097D7EEA8DCF6ADC6E69AC9EB9ECCECA0CAE8A0
CBE6A3D0E5AAD2E4B0D0E2B2CDDCB3E1F0C9F7FFDFE4F5CBD4E8B7C0D79FCBE3A5D1EBAE
CEE6B6F5FFDFF7FFDDD7E9B9D3E1AEDEEBB5C0CB919BA66A89955565712F9AAB67C1D590
D1E8A2D2EDA6C6E49CC3E39ACEEEA3BDDF92CDEDA2CFEEA2C4E095CDE99ED4EEA4D1EBA1
8BA359C5DF95CAE49AD1EDA0C8E497C9E89AC6E597CCEB9DD3EFA2D5F0A397B167BAD48B
D6F0A9C2DC95C7E09CD2EBA7D3ECA8CBE69FC8E49AC5E196D6F2A5CDEA9ACFEC9AD0ED9B
D9F4A3D2ECA3CEE3AAD2E4BCE6F3DFF9FFFBFBFFFFFCFFFFFCFFFFF8FAF9FFFFFBFFFFFA
F9F5F2FCF8F7FFFDFFFFFDFFE4E0DFFFFFFBFDFCF7FEFFF6FCFFF3FBFFEDF8FFE7E8FAD4
C9DCAFD0E7B3C3DBA1CCE5A4A0B975829C53A9C177D0EB9EC3E296CCECA0BCDC90CCED9E
C0E192D0F1A0C1E291C9EC9AC3E493C2E392C6E798CAEB9CC8E89CC4E499C9E9A0D5F0A9
D1E59E90A15ACDE496D4F3A5CCF8ADB9F0AD98DCA3488C5B5D9B6AAFE1AECBEFB2D3EEA9
C7E197D5F4A6BFE697C2EB9DC4E499D5EFA5CFE99FC9E098CFE59DCCE29AC5DB938FA55D
B6CB86CDE49CDDF7AEC8E499BFDE92D2F2A6C9E99DDBFBB0C8E5A2C0DE98CAEB9CC4EA93
C7EE93C7EB93D3F2A4CEE7A6D1E3B399A581010B0079855FCBDFAAC7E29DC2E591C9F095
C6EC95D4F7A5C2E19BD1EBAEE6F9CC6F7D5CF3FAEAFEFFF6
AAE0EA4A7E7CAED9C5E0FFDCE8FFCDCDE3A3809554CBE09DCFE6A2C7E19ACAE69CD1EBA1
D4E8A09AA762D6DC9EF6FABDCFD693E1EAA7D2DD9888954FBACB84C6DC93DAF4AABFDB90
C9E99DC7E79BC6E89CCDEFA3CFEFA4C4E49BBEDE95C6E69DCAEBA4C8ECA4C8E8A5C7E5A7
CBE4ADD4EAB9DFF1C9E6F6D2E0EECDF9FFE6F9FFE4E5F4CDD0E1B4CFE3AED6EBB0D1E6AE
D1E2BEF6FFEAF8FFE8E9F7D3E7F6CBD7E8B4D8EAB0AEC0829CB06B62762F9FB56DD2EAA0
D9F3AAC5DF96CBE69FC8E69EC9E99DCAEC9FD4F4A8C1E195C0DF93D6F2A7D2ECA2CDE79D
ABC379D8F0A6CEE69CCFE9A0C6E097C8E49ACAE69CD6F2A8C2DC92CCE69C758F48D4EDA9
D0E9A7C2DB9ACCE5A4D3EBADBAD294D9F1B3D2EAACC3DD9CCEE7A6C9E4A1CBE4A0CBE4A0
CFE4A3D0E1AAD0DFB4D4E1C3E2EADBF1F6F2F9FDFEFAFBFFFFFFFFFDFEF9F8F7F2FFFFF8
FFFFFAFFFEFDFFFDFFFFFDFFD1CCD0FDFBFEF6F6F6FEFFFBFEFFF8EFF7E8F1FDE7E2F1D4
D0E0BCC6D7ADC5D6A9C5D7A595A870C9DBA1D6E8ACCDE1A2D6F1AEC7E6A0C7E79EDFFDB3
BDDB91D3F2A6D3F2A6C5E496D6F5A7CFEEA0CCE89DCEEAA0D0EBA4CCE7A0C7E09CC5DC96
D3E4A0778842C9DE99C7E4A1C1E8A7BFECB1B1E8B1AEE8B559925F8FC48CB9E5A8C8EFAC
C0E49CC1E396CFF2A2CEF1A1C9E79DC9E59BD5F0A9D1EBA4D7EEA8CADF9CD0E5A2A5BA77
9CB170DEF3B2BCD291DDF6B4C7E29FBFDC99CDEAA7B2CF8DCFEBB0CDEBADC7E8A1CEF3A5
BBE28FC8ED9DC6E59FC3DCA2C1D2A8808B69000600879270DEF0C0C7E1A2CFEFA3C6EA93
BFE18BCCED9CD0EEA6BFD799BED1A3697754EAF2DDFCFFF2
74A9B92B5E5FA5D1B6B8DEADC1DF9FC5DC96AFC282CEDE9FD6E9A9D2E7A2CEE796C9E28E
CBE091ADBE78A4AF77BBC28CE5ECA9DAE098979E5896A25ADAEAA1DEF2AABFD78DD2EEA4
CFEFA4CDEFA3BEE298BBDF95C7EDA2C8EEA5C3E9A0C7ECA6C6E9A5C6E9A9C9E8ADCEEAB7
D8EFC3E2F6D1EFFFE4F8FFEDF9FFEFF9FFEDEEF9DBE1EFCBD7E6BBD4E6B2CEE2A7CBDBAA
D7E0CBECF4E9FAFFF0F9FFEAF6FFDFBED2A1D8EDB2D2EBA9C8E49ACEEA9DD2EEA1B9D588
D3EDA3C9E39AC9E39CDBF6AFC8E89CCEF3A3C7EA9AC0E192D5F4A8D8F4A9C0DA91C1D890
889E56BED48CC4DA92D8EFA9D8EFA9D5EFA8C7E19AC6E099D1EBA4CBE29C6F8544D3E9A9
C9DFA1D3E8ADCDE2AA667A45A1B580F7FFD8F7FFD8D4EBB7D2E6B3D0E7B3D2E6B1CFE1AF
E4F1C5F4FCD7FEFFE8FEFFF1FFFFF8FFFFFDFFFFFFFFFFFFFFFEFCFFFFFAFAF7F0FBF6F0
FFFAF6FFFDFACAC1C4ABA4ABEAE5ECFFFDFFFFFEFFFEFFFFFEFFFDF7FCF5FBFFF6F9FFF3
F9FFEDB2BFA3ECF7D7E7F3CDC3CEA6E4EDC2CED7ACD5E3B2CEE6ACC2DEA1CFECACC5DF9E
D1ECA9C4DF9AD0E9A5C6E099C9E09ACAE19BCBE09DCCE19ED1E6A5D6EBAAD5E7A9CFE2A2
8D995796A564DDF1B4CAE3AABEDCA8D3F8C5C1E7B4BFEBB67BAC7550864C558D50BFF3B1
BEEDA7BFE89CCAE999CDE899D1EFA5B9D78FD0EBA6C4DD99CEE5A1D3E9A8DBF0AFCBDFA0
99AB6F9FB376DBEFB2C9DEA3CFE4ABC6DEA4D5EDB3DDF6BDD0EBB8C2E0AAD2F4B7BCE19C
CEF4ABC2E69ED7F5B7C7DFABD4E4BF8E997B000500939C7DCBDAAFCEE3AAC9E49DC8E998
D8F8A3CFEC9AD6F0A7D9EFAFC8DAAA6B7753000600000300
8EC2D04E8081D3FFE4D1F7C4CCEBA8CBE29AC9D99892A062D3E3A4D3E79FC9E18DCFE78F
DCF3A1D5E9A482935F616D3B4D5613525A0DDCE79BE0ECA2D1E198C1D58DC4DB95DAF5B0
C8E6A0CFF0ABC8ECA6C0E49EC3E8A2C7ECA6C4ECA3C8F0A9C1E4A4C2E4A8CCEAB6DBF6CB
E8FFDEF1FFEAF5FFF3F7FFF4F9FFF3E3EFD9D1DBC0DCE8C4CEDBAFCBD9A4DBEAAFFCFFDA
FEFFF3FFFFFBF9FFF1F9FFECF8FFE3C7DEAAC9E6A6CBEBA2BEE191C9EC9AD0F1A0C6E597
CEEAA0CFE8A4E1F7B6F1FFC8C5E59ACDF2A2C1E396CCECA0D5F1A6C2DC93CDE49CDFF6B0
CEE39EF2FFC2D7ECA9CCE19EC2D796CCE2A1D1E7A6D9EFAED9EFAED0E6A593A969CADFA4
CADFA6D8ECB7CCE0AD000C00627548ECFED4F2FFDBD0E0B9C9D9B4D0E0BBD1E1BCD0DEBB
F1F7DBFCFEE9FFFFF1FFFFF5FCF8F5FDF9F8FFFBFCFFFDFCF4F1ECFFFEF8FEFAF1FFFFF6
FFFEFAFFFAF7EDE4E7FFFCFFFFFCFFFDFAFFFFFEFFF4F3F8FBFCFEF7FCF8FCFFFBFCFFF8
EFF5E7A2A997FEFFEDF0F6DCE3E6CBD6D9BCCDCEAFDDE3BFBED1A3DAF2BEC5DEA7C6DDA5
D7EEB6D7ECB3C1D59ADDF1B4D9EBAFD7E9ADD7E6ADD5E4ABD1DEA8CFDCA6D2DFAADAE5AD
636D30BEC98DCEE0AED8EDC2CBE1BACEE7BFD1E8BABAD8A4C5EEB656894E115115B3F3B6
BBF3B2CDF8B1C1DC8DCEE394D3EFA5C8E7A1DCFAB4CDE8A3C8E19DCEE4A3CDE2A1CFE3A4
D1E3A792A46AD1E2ABD6E9B2CDDFABD9EDB8BFD39ED1E7B6CCE6B7C7E3B2C7E6ADC2E4A7
C0E3A1CCECABD3EFB5CBDFAED5E1BD767C60020500696C4DD3DBB2D2E3ADD7EDACCDE79D
C5E08FC5E08FC3DA92C7DB9CEFFFCEDAE6C0FCFFECECF1DD
5F919A073835A7D3B8BBE2B5CAE9ADD2EBA7D7EAA86A7936ADBC77DBEBA0D8EB99D3E994
CFE698D4EAA9C3D7A6B5C793B3C57BE5F4A3BFD080D7E79CCBDF97DDF2ADD2E8A7C8E1A0
C5DFA0CAE6A9D1EFB1D0F0AFC9E9A8C4E4A1C1E59FC2E5A1C4E7A7C3E4ABCDEBB9E1FBD4
F1FFEBF4FFF3F5FFF6F7FFF6F9FFF4E7F3DDD2DDBDDEEAC2CFDDACD2DFA9D5E3A6F2FBCC
F6F4E5FFFFFAFFFFF3EEF8DDF6FFDCD6F2B8C4E5A0BEE395D5FDA7BBE38BBEE491D7F8A9
C2DD98CBE1A1EBFEC6F7FFD1C5E49ECCF1A3C1E397D4F4A9C4E096BED891E7FEB8C1D693
657836AFC280C2D595D4E7A7D4E6A8DBEFB0D0E4A5C9DD9EC3D798C3D79A99AD72D2E5AD
CDDFABDBEDBDC9DAAE00090061714CF8FFE6F9FFE8F2FFE3F4FFE7F9FFEDF9FFEDFCFFF1
FDFDF1FFFEF8FFFDF9FEF9F6FEF8F8FFFCFCFFFEFBFFFEFAFFFEF8FFFEF6FFFCF4FFFEF6
B5ADAAB8B0AEDBD2D3FFFDFFFDF8FFEEEBF4FFFEFFFFFEFFFEFFFFFEFFFFF7F9F6FDFFF9
FCFFF6E0E2D5EBECDEFFFFF1FFFFEFFFFEEBFFFFECFFFFEAF9FFE4F5FFE3F5FFE1EEFFD6
E5F6CCD3E4B8D4E4B7D3E0B2DBE7B9B4C0909CA5789DA478959A717D8259757A52808658
CBD098ECF5BECAD9B0D5E6C6CAD8BEC2CFB1DDE8BEDCEDB9C4E5AC8FC18642874E8DD69E
A9E9ADBAEBA9CFE79BDEEFA1D4F0A5B8D88F9AB870BDD891D5EFA8D2E9A5CDE29FD1E6A5
D4E6A87C8B503F4E15CCDDA7DBECB8D1E3B1D6E8B68EA271BDD3A5D6EDBF8FAA75D1EEB4
708E52C6E2A78DA16C9FAF80666C486566470602008D8A69DCDFB4CCD5A0DBE9ACBFD38C
D4EB9DD1E89AE3F7B0D0E0A2C8D6A5E6F0CBFEFFEA2E331D
99C7C70D3A33A5CFB9B4DAB5C3E3B1CEE8ABD1E6A350611A95A658D4E595CDDF8DCDE293
CEE49CC7DFA1DBF3BFC0D9A0CDE597BED881E3FAA8CFE79BC8DF99D3E9A8C9E1A5CCE3AB
D3EAB4C7DEA8C9E2ABD2EBB2CDE6ACC8E2A3CDE7A6CFECAAD1EFAFC9E8ADCCE8B7DEF7D0
EEFFE9F4FFF3F5FFF6F7FFF4F6FFEFEAF7DBCAD6B0D0DDAFD1DEA9D5E3A8929D61555D2C
A09D8AFBF7ECFFFFECD4E0BCC7DBA8C9E6A6C3E89BCCF6A2B5E188D6FFA8BEE594C5E59A
CDE7A8D7EAB3CAD7A9D2E4B2CDEAA8CCEEA4BCDB95D6F4AEC8E19DDDF4B0ECFFC0506524
8EA062D6E8AADCECAED7E6ABC7D99DD1E3A7D0E4A7D1E5A8DEF2B7CCE0A584975FE1F4BD
C5D7A5CEDFB29AAB81000800606E4DFBFFEAFBFFEDF5FEE9FBFFF1FCFFF3F5FBEFFDFFF7
E0DCDBEDE4E7F9F0F1FFFBFCFFFDFBFFFDFBFDF5F2EEE7E1FEF7EFFFFEF6FFFEF6EAE3DD
89817EDDD5D2FFFDFBF7F1F3847F858F8C93F2F1F6F7F6FBFEFFFFFEFFFFF2F4F1FEFFFB
EDEEE8DFDFD76A675EDCD8CDCCC6BAE0D8CBEEE4D8D3CDBDC9D1BA637157C7D5BB627154
667355010C00626C4A000700606745181E000104000C0D00201F030B0A000602000E0E00
090B00000800000800000700000500040800040400000800000E0057864F79BE886FBC88
B9FCC7AFE1A6DEF5AFCBDB90C4E09663833A001300648036C8E299D3EAA2D4E9A4D2E6A1
CEDE9D000D00000B00021100000B00000B00000B00021400011200000F00000D00000E00
000E000011000213000008000404000703001B1200544C27827F528B8E59767E42BCC984
B8C881D7E8A1CEDD9CD6E3ABD8E4B4EBF3CE000500070C00
CAF4E870998B294E3DD0F2DAC1E1BCBBD7A4D4EDA9AEC37492A651D2E490D8E89DCFE09C
D2E6A9CDE4AC91AC759EBC7CC1E492CEF29AC6E894BFDF93CEEBA8CFE9ACCDE4AE576D3E
6E7F535D6E426372476676475E6C39717E4858652D6B7D41647E3D6F8B4EA7C28D92A97F
99AD916E816B73847177866F7584676C7A566B784A6C7A4564723759672A5F6B2D6E7643
6C6B4D37351C7278566976486F8449516F29CEF3A3BCE690C1ED96C1EB97CCF1A4C8E7A4
D3EAB45A693E071100C8D4AED3EAB2CAE7A5C8E5A5CEE8A9D1E9AB91A76933470A213300
657439637237A4B378CEDDA4D0E2A8CEE0A6C4D89DDBEFB4CEE1A9D0E3AC97A872D4E5B1
C7D7A8D5E4B9CCDBB4010C00000B000005000005000B1202000300010400060902000100
0701030D04090600000600000D0502060000060000060000060000362F27857E78CDC5C2
F8F0EDFFFDFAFFFDFAFFFEFB2E2A2B888689E5E5E5FFFFFFFFFFFFFAFAF8F6F7F2F1F2EC
26261E14140C2F2B222F281E241B122D231931241B2B231825291B172212323D2D293221
020900232B16484D392528132E301B4F4E39302D1A2B2817363022231D0F2D251A342D1A
2A2A046E734B6F796149514425281D4F4D3E736C4F595A326175443B632F73B587378053
7DBF91C0F2BDC8E2A3D1E29CC4E096729247557329A6C277D4EEA4C9E197D7EDA4D4E8A0
D9EAA48B9C5899A96A4F5F2196A86E8A9B6498A9738A9B65919F6C93A16C94A56E85995E
A5B77BA0AF74949F679397649A9669645B32A0926BC1B48AD7CF9EBCB982B5B67A979E5B
89945278824366713577814D4B5429727757262A13979A87
052611000F0000150A000B00001600042300C3E09ED2ED9CB6CD75ACC06BD2E29BD5E5A7
E2F5BEBED59F405C2151722BC4EE9AC9F49BC9F09FBEE29AC6E6A7CAE5B0D2E7BC84946F
5D6B4A576041505736555B376C71486F72432E3200333C03697E3B5C773460773F6B8055
6C7F5F62745A7D8F75677A5C687A526274445D6E376272346A7A3C6977395C672B4D5522
35350F53532F80875D687641607636638139C3E898CCF3A0C8F2A0BEE497C2E29FC0DCA2
EAFCD2D2DDBD979C85DEE7CAC7DAACCAE3ACD0E7B1CEE5ADCEE3ABA3B67F6677416A7942
6877402534001A2900263500203200293D0233470C34480D5F723B61743D3546121E2E00
3C4C1D000C000C18000007005C6546FDFFE9F3F8E4D3D5C7F1F3E6FEFFF7EEEFE9FFFFFB
D9D5D4979191A29D9AB8B3ADAFABA0E8E4D8FFFFF3BFBBB0D3CFC6E4DDD7F7EFECFFFCFA
FFFDFBFFFDFAFFFBF8FFFCF8FAF6F5FFFFFDFFFEFCF8F8F6FCFCFAFFFFFBFFFFFAF6F7F1
EEEEE6F1EEE7928E85FBF4ECFFFDF4FFFDF4FFFCF3FFFBF2FFFFF8E6EBE4D4D9D2E7EDE3
E5E8DDE4E6D9FBFDF0FFFFF4FFFFF3FFFFF4EFE8DEA49D959A918CB9AFADC3B8B6EFE6DD
F4F0D5EEEFD0D7DBCCE5E8DFECEBE6E0DACEFFFEE8E6E3C2EAF9D0C0E1B6ACE4BD5E9F77
26633AAFE0B1C3E0AAD8EEB0DBF6B3D2F0A8BCDA92D7F3A9CDE59BCFE59AD4E99EC9DE93
CFE197D0E19ADBECA697A766809353CADC9EDCEEB2CEDDA4CFDAA0DCE7ADD5E3A6D2E2A4
DFEFB0C7D597DBE3A8D7D7A1E1DBA9A49868AD9F70A69867A2966289844AACAC6E979C5C
E7EDB1D9DEA8E0E7B4CED4A8D8DCB9676B50818471FFFFF3
5971595F78651B342E00130E1231224E704FC7E9ACC8E99AD6F29D5C7321CFE09CD5E4AB
C9DBA7D7ECB4688241698B3FC4F09BBDEA97C7F1A5C2E7A4C9E7B1D9F2C8EEFFDFD1DDC5
EAEFDBDEE1CED9D8C3D4D3B7D2CFAEE4E0BA8D8A5D575A25C5D692E3F8B3BCD196C5D9A8
C8DAB4D8ECC9F5FFE6E8FDD4D1E5B2D3E7ACCEE3A2CDE19CD9E9AADFEFB1CBD8A2AFB987
92986CD2D8ACDDE7B5CFDEA5C7DD9DC8E39CC9EB9FC2E79ACAEBA4C5E3A3D1ECB5CFE5B7
E0EECDF9FFEAE8EADCD5D9C8D5E5C1D5E7BDD3E4BAC8D9ADD2E2B5CCD9ADB3C092C4D0A0
D4E0AE99A671808F5894A36A8C9E6485995C83975A5F73381427000A1B00445221273504
172400182300051000040C00272E0CD4D9BBE1E5CCD4D6C1DDDECEFEFEF2FFFFF6FFFFF8
B6B6AEF7F7EDDFE0D2999A888C8B7786857091907EC3C1B2FFFFF6FFFEFAFFFDFDFFFDFF
FFFDFDFFFEFBFFFEF8FFFEF8FFFEFBFFFFFBFFFEFAFEFDF9FFFFFBFFFFFAFFFFFAF6F7EF
FFFFF8FFFCF5615D54CCC5BDF2E9E0FFFCF3FFF6EEFFF7F0F0EFEAFEFFFBF7F8F3FFFFFA
FFFFFAFFFFF8FFFFF8FDFAF1FFFEF8FFF8F2FFFDFAFFFCFBFFF7F8D1C6CAAB9FA3D9CFCD
FFFBEBFFFFEDFFFFF4F8F7F2FFFCF8FFFEF4FFFAE9FFFFE8EDF6D7F1FFE8C5EECE7BAE8D
2A5E3AB5E3BEBEDFB4CCE8B5BEDA9FD2ECABCDE8A5C9E29ECDE49CD3E9A0DBF0A5CBDD91
DEF0A4C7D98DCDDF95B1C27C4E621D9DB26FC9DE9DDAEAABE3EFAFC2CC8DDDE9A7CEDD9A
DCEBAAE0ECACD3D99BDADB9FE5E0A88C814B52450E5E511A7C733A6F6B2E9C9C5E51551A
D2D2A0E0DEB5D8D8B2E5E5C3A8A88E7A7C67FDFFF1FBFDF2
F8FFEFF5FFF4DEF3EE8AA4A14C6D648CB398C3E9B6C3E8A3C8E99ACDE89BA3B674A2B47A
DAEBB5BED199C6DF9DD1F1A6C8F1A2B6E293C5EDA7C8E9B0D3EEC1ECFFDFF9FFF1FCFFF6
F6F7EFFCF9F0FFFDF1FFFFECD8D3B6E4DEBCA29D759E9E6A6F7C37DAEBA5DBEDB1D4E6B4
DCEDC3D7E9C3CDDFB5BCD2A1D0E5AAD7EEAAD8EEA6D1E79FD1E4A4D6E5AED1DEB0C6D1A7
D8E1B6E4EDC0CDD9A9CEDFA9D9EDB2D8F0B2C2DF9FC6E3A3C4E0A6CBE3AFE7F9CFF9FFE6
F8FFE9FFFFF4FFFFF8FAFCF1F2FCE4F2FFE3F8FFE7F7FFE2FCFFE4EDF7D4B4BF979CA77D
CEDAACD9E5B3CBD9A4D5E7ADD6EAADCDE3A3D6ECACC0D698CEDFA9CDDEAAE4F2C1C8D6A5
C3CF9F4D592BCFD8AB020B007C825CDADEBBD2D5B6DCDCC2D1D0BBFFFFEFFFFFF09E9F8F
EDF0DDFEFFEDEBF1D7C9D0B1DDE2C4F2F7D9F7FBE2FFFFF1F6F6EEFAF6F5FDF8FCFFFBFF
FFFDFFFFFEFBFFFDF7FFFEF5FEF9F6FFFBFAFFFEFDFFFFFBF9FAF5F6F7F1FEFFF9FFFFFA
F5F4EFFFFFF8FFFFF8DDD9D0BAB1AAFDF2ECFFFCF6F9F0E9F6F3EEFFFFFAFFFFFAFBFBF3
F8F5EEFAF7EEFFFFF6FAF6EDFBF4EEFFFDFAFAF0EFFFF8F9FFFBFFF9EEF4FFF7FFFDF2F6
837F76CDC9BEEEEBE2FFFEF8FDF6F0F8F1E9FFFFF3F8F7E5FEFFEFD4E3CCCFE9D0D7F9E0
C2E9CE365F41C4ECCAB9DCB4D4F0BFCBE2AAD5EAB1C3D99BD7ECABBACE89D2E39CD6E89E
C8DA8EDEF0A4DCEEA4D4E99ECEE49B92A8605368238A9E59DBE8A3D9E49FD2DF99DCEBA6
C5D6928C9B58A0A968808545A2A063666022F5EBAEE8E0A2DBD79AE7E7A9CED496E7ECB4
7F7C53D5D0B0B0AB8E39351C33301DF5F3E6F4F4ECFFFFFA
FFFFF1FBFFF6EBFAF5CEE7E37CA096000F00C3F0C9BAE5AFC8ECACCFEDA7B5CA879CAF6F
DAEDADDDF0B0D1E6A5CFEAA5D2F3ACC3E6A2CCEBB0D7F1C2E0F3D3F5FFEDF8FDF6FFFFFD
FFFEFFFFFDFDF3ECE6FFFFF1E2DDC7D0CBAD85815BE5E7B59FAA66C1CE89D8E6ABC8D6A3
CAD9AECBDCB2D1E4B6D4E9B1C4DD99C6E096CCE498CFE59DCEE2A7D0E0B1D5E3C0DCE7C9
D2DEBAC7D3ABCEDBB0CEDDB2CDDEB1C8DBADD0E3B5DAEDBFCFE1B9D1E1BDDBE5CAF9FFEC
FFFFF4FBFBF3FFFEFBFAF9F5FEFFF6FCFFF4FCFFF3FCFFEFFEFFEDFCFFE8C6CDAEA7AF8A
8D986ED8E4B4D1DFAAC4D69CCFE5A5C5DE9CCFE8A4DAF0B0CFE0AADBE9B8CBD9A6CAD8A5
D9E5B3505C2A9EA876000800010700C8CDA4E7E9C4DCDBBCD4D3B5FFFFE7FCF7E1E1E4C9
FCFFE4EAF9D2EBFAD1DFEEC3C7D4A9D6E0BBF4FDE0F4F9E5FFFFFAFFFFFFFFFDFFFFFBFF
FFFAFEFFFDFAFFFFF6FFFFF6FFFEFBFFFEFFFFFCFDFFFDFEFFFFFFFEFEFCFFFFFDFFFFFB
FFFFFBFFFFFAFFFFFAE3DED8FFFEF8BAB1AC4037325C534C605C5139372A5D5B4EDCDACD
FFFFF3FDF9EDFFFCF0FBF7EBFAF3E9FFFEF6FFF7F4FFFCFAFFFCFFFFFCFFFFFBFFFFF9FE
FEF8FAA8A3A0FFFEF8FFFDF6FFFEF4EFEBE2FFFFF8F0F1E9F9FCF3FBFFF6F9FFF4D2E3D0
D2EBD5769981518169B9E6C9BAD4B1CDDFB5E8F9CCCEDEAD8FA06966753A8F9F5ED1E09B
D9EBA1C5D78DCDE297CFE499D6ECA3CDE49CCCE39DD4EAA2C0D2885C6C214D5F154B5F17
8BA159C7DB96CCDB96CDD693D7DC9A8B8C4AD6D594DEDD9DD2D797C9D293D8E6A9D6DEAB
F1ECCE0A0000080000EBE4D4FFFFF4FFFCF5FFFFFBFFFFFD
F6EFE7F7F7EFF8FFFBF0FFFDE7FFFF7EAB9741725598C69FB2D8A5CAE9ADD6EDA9CBDF97
85964F798A44D6E9A9C5DB9BC4DE9DD2ECAFD8EEBDEEFFDAF3FFE7FCFFF8FDFDFDFEF9FF
FAF2FDF4EDF4FFFDFDFFFFF68986739D9C7EB0B08CD6DAA8C7D08F848F4BB9C48AF2FECC
F2FFD3E4F3C8E1F3C1C8DDA2D4EEA5CFEA9BD2ED9EE2F9B3F1FFCEF8FFE1F9FFEFF9FFF3
F6FFEAF1FFDFF8FFE6F8FFE6F4FFE2F3FFE1F9FFE6EBF8DAFBFFECFCFFEDFEFFF3FFFFF4
FFFFFAFFFDFAFFFBFBFFFEFDFFFFFDF7F9F4FAFBF5F0F2E7F3F5E7FFFFEFFEFFE9FFFFE4
89916AD5E2B4D9EAB4CBDFA4DBF1B1CEE9A4C2DD96D2EBA9ECFDC6D1DFACDFEDBAE3F1BC
C4D19CCFD9A4565F2A030B002E3502D6D9AAD8D9AFDEDFB7F3F0CDFAF7D69F9C7D969775
F4FFD7F0FFD3CFE4ACC3D8A0DCEEBAD7E7BAD7E2C0FCFFEFF7FCF6FBFCFFFEFCFFFFFCFF
FFFCFFFFFEFBFFFFF4FFFFF4F9F3F3F9F2F9FCF7FDFFFDFFFFFEFFFFFFFFFDFDFDF9F9F9
F6F6F4FFFFFDFFFFFBFFFEFBFAF5F2FFFDFAFFFDFAFFFEF6FEF8EAFFFFEDFFFFECCDCBB6
95937EBFBCA9FFFEEBFFFFEFFFFFF1FBF4EAFFFEF6FFFDFAFFF7F5F8F2F2F0E7ECFFFCFF
FFFDFFF7F1F5B7ACA8ECE2D8FEF6EBFFFFF4F8FDF9FBFFFFF7F8FAFFFFFDFBF8EFEBEDDF
DDEBDAE8FFF60F443494C7B6E3FDE4E6F3D5D8E6C3DFEBC3A5B284C4D29DAEBC81AAB978
D4E59FDEEFA8CDE199D2E89FCDE59BD5EFA6C7E19AD5ECA4DEF3A6D7EC9DC5DB90CFE79D
D8F2ABC3DA94E4F8B3D5E49FCFDA96757C38DBE09DE0E7A4DCE8A8E6F6B8D5EAAFCDDAAC
A6A08853453AA0938AFFFCF6F8F0EDFFFBFBFFFEFFF2F0F3
FFFBFBFFFDFAF2FAEFD4EBDB1A412FB0DFCD9BCEBD25553D7CA47FBBDCA7D9F3AACEE492
D7EA98CADC9081915275864F9CAE74D5E6B0E2EFC4FCFFE6FFFFF3FFFFFBFFFDFFFFFBFF
FFFAFFFFFBFFF6F0F4B6B3ACFBFCEAFFFFE6E6ECC8E8F0BFEBF1B3A2A86899A168E8F2C0
E9F4C9D3E3B6CEE0ACCFE5A5CBE59BCAE797CAE797D3ECA8E9FDCAF7FFE8F8FFF8F5FFF8
F7FFF4F4FFEEF7FFEFD6E4CDDDEAD6F9FFF1FBFFF3FCFFF3F2F6E8FDFFF4FFFFF8F8F5F0
F8F4F1FDF7F7FDF7F7FFFDFFFFFEFFF9F8FDFFFEFFFFFFFBFFFFF8FFFFF3FFFFECFFFFE8
BEC6A1CAD7ABD1E2AEC8DDA2CDE6A4D0EBA6CCEAA0E4FFBAF8FFD3E3F1BED5E1AFCCD9A4
D4DEA9DBE6AEC7D099000900252C00868A579C9E6DC9C89AD9D6ADF8F4CEB7B38ED5D8AD
DEF1BAC9E6A6CBE5A4CEE8A7C4DCA0CBDFACE8F8D3F9FFEFF8FEFAFCFFFFFFFDFFFFFDFF
FFFEFFFCFBF7FEFCF0FFFEF2FFFDFFFFFBFFFFFCFFFFFAFFF9F6FDFAF9FFFFFEFFFEFFFF
FEFFFFFDFDFFF0F0F0FFFEFFFFFEFDFFFDFDFFFDFDFCF5EDFFFFECF5F1D6FBF5DBE8E4C9
D4D0B5BAB69B8E8A7195907AC4C1AED4D1C0FFFFF3FFFBF2FFFBF5FFFFFAFFFDFDFFFBFF
FEF8FFFFFBFFFFFBF8AB9F93FFFFEFFFFFF3E1EAE9F3FCFFFCFFFFFFFDFFFFFBF6FFFDF3
FCFFF4E2FEF0D4FFFF053D348AA294BFC8B5F4FEE5E8F1D2A4AE89CFDBADC8D5A0A4B277
B7C786BFD08CCBDF98E8FEB6C0D78FCDE7A0D1ECA5C9E59BC7DF91C2DB8AD7F2A5C5E197
D2F0AACCEAA4C3DC98CEE39EDEEFA98E9B56CAD792D2E19ED0E5A4CBE3A7B5D2986B7D53
070200AB9995C2B3B0FFFBFAFFFCFDFFF9FDFFFDFFFFFEFF
F9F5F2FFFFFAFCFFF4D3E4D2314C3D88AC9EDEFFFD002B19356243BFE6B7C5E5A2CDE899
D1E896D0E799C8DF9BBBD095768952D2DFB1E5ECC3FFFFE3FFFBE5FFF9EDFFFEFAFCF8F9
FFFEFFE6E1E7FFFDFFE2DDD9FFFFF3F1F3DDFEFFE6FCFFDCD3DEA6E2ECB0989F6BD2D8AA
D6DDB4A9B18A889369AEBE8DC8DE9ED2ECA5D0ECA1C7E29DD6EAB7F3FFE3F9FFFBF3FDFC
EEFEF1F2FFEEEFFFE6D5E5C8DDEBD1F8FFF0EFF6EEFEFFFDFFFFFFF7F6F2FFFFF6FFFFF3
FFFFF3FFFEF4FFF9F7FFF6FAFFFBFFF6EFF7FFFDFFFFFFFFFDFFFAFEFFF3F9FFE3FEFFDF
CEDAACAEBA88CDDBA6D8EBB3CAE0A2CBE6A3C9E99EDBF9B3EFFFCEF4FFD3C9D7A2D7E6AB
D6E4A7CEDC9FD8E3AB0009004D5522A5AC79A2A976989C6A9DA16FE7EABBBBBE91F1FBC7
DAF0B0C5E39BCEECA6D5F0ADC6DEA2D0E4B1EAFAD5F1FDE7FBFFFAFEFFFFFFFEFFF9F4FB
F3EDEFF4EFEBFFFAEEFFFEF4FFF8FDFFF9FFFFF8FFFEF8FFFFFCFFFFFDFFFFFEFFF8F9FD
FEFFFFFCFDFFFEFFFFFAFAFCFDFDFFFDFBFCFCFAFBFFFFF6FAFBDCF6F8D0F7F9D1CCCEA6
DDDFB8E8EAC5A8A987B6B798C3C6ABBBBDA7C0C1AFFDFEF0FFFFF4F3F4ECFFFFFAFFFFFD
FFFDFFFFFCFFFFFBF5CDC1B5D1CBBBFDFDF1FBFFFFF7FEFFFBFBFFFFFCFFFAEAEAFFFCF4
FFFFF8EEFFF9E2FFFF3F6D6A0F2D23344B39A6BFAA98B096A9BE9FD3E1BDE4EBBF8C905D
939B5FDDECA7D4EFA2BBDC8DD4F6A9D2F2A9C6DF9BD1E8A2CBE697D6F3A1D0EC9FBEDC92
D3F1ABC4E39FC9EAA5CDE8A3D2DE9E6A7032E5F1B1C7D799C8DBA3DEF5C15A7445000900
443E32BCACACFDEFEFFFF8FAFFFBFFFFFCFFFFFDFFFEFBFF
E5FEE9DDF0DDFCFFF4E7E9DEDDE0D757625AE4FFF486B19D4B7E5D9ED1A6BFEAB4C3E7A9
CCEDA6C8EA9EC6EFA0C1E9A2C4E2AE95A77DC6C8A0FFFFD8FFF9D1F2EAC3F2F6D1DEE9C9
F0FCE6FCFFF6D9D4D0E0D4D4FFF5F2FEF5ECFFFFEFF5FFE2CADBAEE1F2BEC2CC98525528
3B3616C5BFA7FFFFEFB1B09CDDE7C4E9FBC7CEE9A2CCE89ECFE4A9F6FFE0FCFFFBF8FCFD
F7FFF6D2E5C5E1F8C4D4E9AED1E5B0F8FFE4F9FFFBF7FBFFF6F8FFFFFFFFF7F9E1DEDEBA
FEFAD4FFFFE3E0D3CBCBBBBEFFF7FBFFF9FFFEF6FFFDFDFFF9FFFDF1FFE9DCEFC1E5F9BA
C9DA969CAB6ACFD9A4D1DDABDEF0BCC3DDA0BFE195E1FFBBF4FFDDE0F5CACFE4A9D6EDA7
CFE59CD5E9A494A36C00090049552FD9E5BDC9D6A8CCDDA7D9EBB1F3FFC9E5F6BFD4EAAC
D2ECA5CFEBA0CEE9A4CCE6A7C9E0AACFE2B5E3F2D1FBFFEDFCFFF4F2F3EDFFFEFBFFF7F5
BBB0ACA4958EDFCEC4FFFAF3FFFBFFFFFBFFFFFBFFFFFCFFFFFCFFFFFDFFFFFEFFFFFFFF
FCFCFEFCFDFFFDFEFFFCFFFFF8FCFDFBFFFFFCFFFFF1F9EAF9FFD8CFE4A3D8ECADC8DA9E
D8EAB0C6D49FF2FECEF6FFD7FCFFE1E6EFD0FCFFECFBFFEFF9FFF3F0FBEBF8FFF6FBFFF8
FFFFF8F6EFE7FFFEF3FFFEF1E7E1D5D1CFC3FFFFFAFFFFFDFDFBFCFEFAFBFFFAFBFFFEFB
F7F5F6FCFFFFF7FFFF9EB6B6002316396C596BA690A7E1C9E3FFF6C8DFC3E4DFC1DED1A7
A59C63BCC67DB3DB82BFF698BDF59AC3F09FD6E9A9D3E1A3C7E396CAEB9AD1EDA2D1EBA4
CEE4A3C7E4A2C2EAA4CEEBA9D1CE97A29463D5D5A3E0EAB89DA88036411F323C23E4E8D7
A09991F7EDEBFFFCFBFAF0F1FFFCFFFFFBFFFAF2FDFFFCFF
BBE1C8E5FFECEEF9EBF7F7EFEBE6E2090C05677B6FBDE0CCA4D2B5346841B4E3B5C1EEB7
B3DB9CBCE69EC8F4A5B9E59AC5EAB4BFD6A8BFC595AAA472EEE3ADD9D49CDCE3ADDBEBBC
F8FFE4E9F2DDC0BBB5D4C6C6FFF8F9FFFCFAFDFFF2F9FFEDCADEB9D3E6B9DAE3B6BABB93
B1A78CECDFCFFFF8F5CFC8C2DCE1CADEEDC2CEE7A5C9E59BCBE1A3F7FFDDFFFFFAFEFFFF
F8FFF4C7DCB5D4EDACCBE59BCDE3A2F3FFD9F6FFF9F8FFFFFBFEFFFCFDFFEFF2D3E0E2B1
FBF9C6FEF9D1B4A89CCCBCBDBCA6A8FFF9FDFFFBFFEDEDF5F7FFFBF4FFECCAE3AADAF2A8
DAED9E7A873FB5BC86D8E0B1E4F4C5CCE3ABD3F5ABDAFEB8F2FFE3DEF4CECCE4A8D0EAA1
CBE395D3EAA29FB27A051400152300D4E4C0DFF3C2D3E8AFC8E19FE2FDB8DAF4B3C5E09D
C2DE94C2DE94C8E3A0D3EDB0DCF2C1E4F6CCEDFCDBF8FFEBEDF5E0FFFFF1FFFFF3FFFEF3
8B7F738D7F72B9A799FFFBF3FFFCFBFFFCFFFFFDFFFFFDFFFFFEFFFFFEFDFFFFFDFFFFFB
FFFFFBFEFFFBFAFFF9FCFFFBF7FEF7F1F8F1FBFFFDF8FFEFE9FFCAC9E49FD3EEABCAE3A2
D4EAACCCE0A5E9FAC4E1F1C0DFEFC2F1FFD5BCCBA4D6E6C2E5F6D4E9FCDCD4E7C9E7F4DA
F5F6E6FFFFF3FFFAF0FAF3E9FFFFF6E3DED8FEF9F5FCF7F3FFFEFBFFFEFDFAF8F9F6F4F5
FFFEFFFFFEFFF1EFF4F0F5F84D6660629083397E6B6CB7A2D4FFFDB4E0C7D9E2C7EDE3BF
C3B783A0A15DD7F8A1BEF091C0F79CBEEB9AC8DE9EDFEFB0CCECA0C7EA98C7E398CBE29C
CEE2A3CAE4A5BAE4A2BDDB9DFFFED1947D54E7E2B8D4DBB1373D1B1E240AA6A795D6D4C7
BFBBB2FAF5EFFFFEFAF8F3F0FFFDFDFFFDFFFAF5FBFFFDFF
D9F8E8D6F1E2E5F9EDDBE6DEFAFFFAFBFFFB09160C9AAFA0CAEAD27EA78549784C4A7A46
D4FFC6D3FDBDB2D794D7FAB8DCFEC2B9D59BDCEAAFFFFFCAA9A868BDBD7FD6DEA5C7D0A1
FCFFE4FEFFEFBCB7B1E1D7D8FFFCFDFBF3F1FFFFFAF9FFF1E4F7D9DEF0CAEEF6CFFFFFDD
FFF9E2FFFAEDFFFCFAFAF5EFDEE3CCD1E0B5D3ECAACDE7A0CCE2A4F9FFDFFFFFF8FEFFFD
F7FFF1CBE2B6D3EEA9CCE89BCAE49DE4FAC9EBF9EAF8FFFFF7FBFFF1F6F0EEF4D2DADEAB
E6E6B0D8D5ACA19889FFFBFAD1BEBACFBFBFFCF6FAFBFCFEF8FFF8F5FFE8CDE5ABC8E096
D4E798A6B36BA0A771EBF3C4FBFFD9F6FFD3B5D38DE0FFBCF2FFE4DFF7D3CEE7AECFE8A4
C8E096CCE39DA1B47D000E0020300BC1D1AAC6DAA5D0E6A6C8E299CFEB9EC9E59BCDE8A1
D9F4AFCFE8A7C9E1A5D1E8B0E0F6C5ECFFD4F6FFE2F8FFE6F1FBE0FEFFECF0F3DEFFFFEB
A19C88B7B19BBDB29EFEF5E4FFFEFAFFFEFFFFFFFDFFFFFDFFFFFBFFFFFAFFFFF6FEFFF4
FEFFF3FCFFF1F0F7E5FBFFEFFBFFEFF4FDE8F5FFE9F8FFE8F5FFDDD1E8B2C4DBA5D7EBB6
D2E6B1C3D69FD0E1ABDAEBB590A16BCFE0A99AAD75C6D9A1CEE3A8CCE4A8C5DDA1DEEFC2
FFFFF1FFFDFBFFFBF9F8F0EEFCF7F4DAD4D4EAE4E4FFFDFDF3EFEEFFFEFFFFFEFFEFEDEE
FFFEFFFFFEFFEFEDEEFFFDFF9A8F97A9B1B462948B4895817ED8BE9BEACBBEEBCAC7D9B3
D9D5A6A69B63B4B772E0F2A6BADB8CC3E99EE0FFBDB6D792C9EEA0C8EB99C9E59BCDE4A0
D3E5A9D3EBB1C8F0B2CFEAB3FDEEC5A78D6AE5E0B8DBE2B92D330F787F60B7B9A1DFE1CC
F6F5E3FFFFF1FFFFF3FFFFF4FFFFF6FFFFFAFFFEFAFDFCF8
E1FCF3EDFFFF7E9990758C84D3E4DEF1FCF690958F0004007A8B79BAD7BBC8F2CC457647
00140085B07ACBE9B3C7E2ABC6E5A9D0EFACCEE3A0CCDB96D5DF9A959C595C61295C6234
4447289A9987FBF6F2FFFDFFFFFEFFFFFDFEEDEDEBFCFFF8F8FFF1F8FFEAFAFFE2FDFDE3
FFFEEDFFFCF3FFFCFAFFFFF6DADFC8C3D2A7D6ECACD0E9A5CDE1A6FBFFDFF7FAEFFCFFFA
F7FFECD0E8B8D2EDA6CEEB9BC9E59BD7EEB8E0F2DCF6FFFEF9FFFFFBFFF6F1F7D1CAD19B
CFD29B9D9C708C8573FFFCF6FFFCF3B5A8A0DED9D6FEFFFBF8FFF4F7FFE6CFE4ABCCE19C
D9E9A0D5E09CC5CC96919769D9E2B5CEDFABC9E2A0E5FFC4F2FFE6DDF5D3CDE6AFCDE8A5
C9E39ACCE39FA6BA85000A0055653ED8EBBECBE0A5D8F2ABD1EE9EC9E996BEDD8DCAE8A0
CCE4A6D1E8B0DFF6C0F2FFD5F5FFDAF5FFDCE3F8CDD5E7BFD8E8C3DAE8C4CCD6B4DDE4C3
F2F7D7FFFFE4FFFFE0FFFFE8FDFFF1FAFFF6FCFFF6FAFFF4FAFFF2FAFFEFFAFFEDFAFFEA
F4FEE3E7F2D2CDD8B6E4F0CCFAFFE0DEEAC2CBDAB1CEDFB2C0D4A1C9DDA8CCE0ABD5E8B1
CDE0A9DAEBB498AA703D4F15CCDEA2D9EBADC7DC9BDAF1ADD7F1AACAE59ED4F0A6BFD29B
FEFFF1E9E0E5FFFCFFFFFCFFFFFCFFFCF6FAD2CCCEBAB4B6FFFEFFFFFEFFFFFEFFFFFFFD
FAF9F7FFFFFDFAF9F7FFF4F8FFF0FEF0E2EFEAFFFF4B8D81247D672C8569ABEACBCBF0CE
D1D9B29A966757561DD6DC9CCEE29DCFEAA5CDECA9C9EDA7C0E595C9EC9AD1EDA3D1E7A6
CFE1A7D0E7AFD4FBC2EAFFD2FFFEDCCCB193D7D1AD333712707652EEF5D3D6DBBBEBF0D2
FFFFE8FBFFE5FAFEE5F8FDE6F8FDE7FEFFEFFEFFF3FEFFF3
EBFFFFEAFFFF52777011342DD7F2EBF3FFFDE7E6E279747075776CD1E0CBCDF2D3D4FFDE
124218729B71B3CCA5C8DBAECAE8ACC0E19AD3F3A8CEEA9FD6ECA4DAE6A4D1D49F98956C
E0DBBEFFFFEFEEEBE6FDFDFDFEFFFFF5F6FAFFFEFFF5F7F6F4FEF3F9FFF3FEFFEFFBFAE8
FFFEF4FFFDF6FFFAF7FCF9F0CCD1BAB5C297CEE2A5CFE5A4CADDA5FBFFDFF3F7E8ECF2E4
E1F2D0C9E2ABC9E79DC9E996C5E496CEE8ABDFF2D4F7FFF8F8FFFAF9FFEFECF5CACDD69D
E9EEB6A2A377B0AB97F7EEE5FFFDF1E4DACEF8F4EBEDF0E5F8FFF0F8FFE4C7DAA3DAEDAD
D0DC9AE3EDAEDAE1AEB0B68A9AA177BDC999D2E4AAE1F8C0F2FFE6D8F2CFC6E1ACCAE4A3
CEE9A4D4EDABBED29F000C00314319D6EAB9D2EBAACEEA9DC6E48ED2F39ACBEB98C6E49C
C7DEA8D7EABDEBFED1F5FFDCF5FFDCECFFD2D7EFBDC6DCABC3D9A8CBDFAECEE2B1CBDDAD
F9FFDCFBFFDCFBFFDCF8FFDDF9FFECF8FFEFF9FFEFF8FFEDF8FFEAF8FFE8F9FFE4F9FFE1
F9FFDDEFFFD0D5E5B4E7F8C2F8FFD0DCEEB2CEE0A2D2E5A5D4E9A6CEE3A0D1E6A3DAEDAB
8FA2607B8B4A90A05FC2D291D2E5A5C7DA9ACDE2A1C9DF9EC2DD9AC4E19ED1EEABD5E9B8
FFFFF6FFFBFFFFFBFFFFF9FFFFFBFFFFFCFFE8E2E6A7A1A5EFEBECF5F1F2F3F2F0FFFFFD
FFFFFDF9F8F4FFFFFBFFFAFBFFF5FFD1BCCBD5E2EAD8FFFF93D2C9387F6F43816C5D8E71
BCDCB7C7DDAFBFD09A8A995ED9E9ABD0E0A1C6D698D7ECA9C5E697C8EB99CEEAA0CEE3A2
D0DFA8D4E8B5DBFFCCF3FFDEE8D4B9BFA08BE4DBBC5C603DD2D8B2D1D9B0B4BB92E1E9C0
DAE7BCCDDCB1D3DFB7D9E8C1D9E7C3E4F2CFF4FFE3F6FFE5
405F6226494BC9F3F1DEFFFFEAFFFFF4FFFFFDFCFADFD5D36B645E2C3224EEFFF3AED7B9
C7F2D4789D7E596D54536442CDE6AFCAEAA7C0E8A1C8EDA7BEDD99D8ECAFE1E3B4E2D9B8
FFFDE8FFF5ECFFFEFBFCFFFFF4F9FCF9FCFFF2EFF6FFFEFFFBFFFCFBFFFAFEFFF8FFFFF8
FFFEF8FFFDFAFDF8F4FFFFF3CBD1B5B9C69BCCDDA6D2E6A9CCDDA7FBFFDFF8FFEBDCE5D0
D2E4BCCEE7ADCDEC9ECCEC97C8E895C9E6A3DDF3CCF5FFEFF1FFEBF8FFE9E6F2C2D3DEA4
E2EAB1B5B88BE8E6D1FFFFF3FFF8E9E8E0D3FFFFF4FFFFF3F9FFEDF9FFE6D4E4B5CFDEA5
D6E1A7C0C992EEF4C6DEE3BBF6FAD5848B61A0AC7AD6E8B8F4FFE4DEF9D0CAE6ACC6E3A0
CEE9A4D3EDACCDE4B0001300384A20C9E0ACBDD895C3E090C3E48DD1F49ACBED99CBE8A5
E9FCCFF0FFDCF3FFDEEBFDD3DFF5C6D7EFBBD4EDB4CFEBB0C9E5A8D8F5B5D2ECAFCCE6A9
D2EAB0CFE6AEC8DCA7D2E6B5CBE0B7CBDFBACBE0B9CBE0B7CBE0B5CBE1B3CDE1B0CDE1AE
CFE2ABD5E9AECADC9ED2E5A5D5E9A4C8DC94D1E69BD8EDA2D1E699AEC37691A659A1B369
98AA60BCCD86CDDE98D2E39FD5E8A6D8EDACCFE5A5D3ECABD6F0B1D6F3B3B3D193CEE4B6
74766BBBB2B77B71798E858A908A8E777175C7C1C3FFFDFFA9A5A4FFFEFDFFFFFDFEFDFB
FFFFFBFDFCF8FFFFFBFFFCFDFFF3FEFFF9FFA7A7B1BECFD6DFFEFFE2FFFFCCFCF074A38F
618E6FA6CFA5B6DBA8ABC88E7B8F54ADB87CE3E7ACDAE3A2D2EEA1C8E99AC8E299D1E5A6
E3F2BBF0FFD3EDFFDFF5FFE4FFFBE6DEBEAF7A7055808463EDF4CBAEB78ABAC492D9E6B0
CCDFA7C4D9A1C8DDA5CDE1ACCBDFAED3E6B8E1F4C7E4F7CA
426B710F3B3EDEFFFFDBFFFFE9FFFFF2FFFFF8F8F8EEE4E3B8B0AD696A6285958886A190
D3F2E0A8C4B53F51453C4E38778C6161804780A96D74A264DCFFCAB8D2A2E8E9C7FAEED6
FFFAEFFFF6F1F2F1EDFBFFFFF8FFFFF9FFFFFFFDFFF8F3FAFEFFFFFAFEFFFBFBFBFFFFFD
FFFEFDFCF9F4FFFEF5FFFFEFDDE4C5D1DCB1D3E1ACD8E9B2CFDDACFBFFDFFCFFECC8D5B9
C2D8A9CFECACD1F0A0CEEF98CBEB96CAE8A0DFF7C7F3FFE2EEFFDFE5F5D0DDEBB6D1DFA4
ACB57EAFB589E5E5CDFFFFF1FFFFF1D6D0C4F3F1E5FFFFF3FEFFEFF7FFE3E2EDC5C6D2A4
DFE8B9D6DDB1CBD0A8F4F8D5FDFFE09DA17E7C835ACBD8ADF0FFDBD9F7C3CEEDAAC9E79F
CAE69CC8E2A1CAE1AD000B0060754ADFF6C2C9E4A1D4F0A3CEEE99CCEE98BFDF93C7E3A6
E7F7D3F5FFE8F8FFE6F2FFDCE0F6C5D2EBB2C6E3A3BFDE98C1E399C9EB9FBEE096C6E89E
C3E29ECBE9A9C4E0A3D0ECB1CCE9AFCCE9AFCCE9AFCCE9AFCDE9AECDE9AECFE9ACD0E8AA
C7DD9DD1E8A4D0E5A0D3E9A1D0E59AD2E79ADFF2A3CEE192C9DC8B99AC5B97AA5BCEDF91
DCECA1DDEDA4D2E19CCADB97D6E9A9C7DB9CC0D698CBE3A7C6DFA593AF756C8951586D42
050800504943403835736B686D6864423D3986817DFAF5F1C9C5C2FAF6F3FFFFFBF5F4F0
FEFDFBFFFFFDFDFCFAF3F2F0FFFEFFEBE9EEC8C1C9AAA2AFFFFCFFE4EBF3F0FFFFD1F7EA
A4D9BD427C5382BB88D7FFCDC9E5AA515B1FECE6AAD0CF8ED4ECA0C8E99AC9E39AD6E9A9
EBF8C3F4FFD8ECFFE1F0FFE3E8D1C3DAB8AE665B45898D6CCCD5AA7F8C57E9F7BAD1E1A0
D1EAA6CFEDA7CEEBA8CCE9A7CCE6A7CDE7AACEE7ADCFE8AE
90C3C69ACBCF88B8B8C7F1EFBDDBD9EAFDFBFCFFFFFFFFFDFFFEFBF7F6F2A5ACA5000500
73847EEDFFFDEBFEFAB5C7BB0D1D02304922729B6F77A678A5D2A7ADCBA9EFF2DDFFF9ED
FFF7F2FFF7F5FFFFFBF6FFFCEAF6F4F9FFFFFFFEFFFFFCFFFFFDFFFAF9FFFEFDFFFFFEFF
FEFCFDFCFBF6FFFFF3FFFFEAEDF5D0E4EFC4D6E2B0D9E7B4CAD7ABFAFFE0FBFFE7B5C3A0
A8BF8BC2DF9CC8E797C8E992C9EA93CDECA0E4FDC4F4FFDDEAFCD2C9DAADCBDCA5E1F0B5
ABB580DFE6BCF0F2DAFFFFF2FBF7ECF6F2E9EDEBDFF5F6E8FFFFF1F4F9E2D7DEBFDBE2C0
D0D7B5EEF4D0FFFFE3FDFFE1FCFFE0F8F9DADADBBC959D78CDE5B3C4E4A5CAEA9FCBEA9C
CAE69BC1DC99C6DCAB000B00091E00C4DAA9D3EEABCFEBA0BEDD8DCDEE9FCCEBA7CBE6B1
E4F3D4EBF7DFE9F6D8D9EBC3CBE1B0C7E3A6CAE9A3CCEEA1C8ED9DC5EB98C8EE9BC7EC9C
C9EEA1C0E49CC1E59FC6E7A2C8EAA0C8EAA0C8EAA0C8EAA0C9E8A2C9E8A2CCE7A2CCE7A2
D3EAA6D5ECA6D1E6A1D2E8A0CDE199D0E59AC9DB9194A65C95A45FAFBE7BD2E19EDCEBA8
D3DF9DCFDB9BA8B6786A783B5F6F31708447D0E5AAD2EAAE93AC7232501497B47A92A877
FFFFE6F8F3E0FFFFEDFFFFEFFFFCEDFFFFF1B4B0A5A7A398FFFCF57B7871777672BFBEBA
ECEBE9FFFEFFFFFEFFFEFEFEFCFFFDFEFFFDFFFBFFE5D5DFB6A4B0FFFBFFACB4B7769087
5C8972002100002000B9E8B2C5E2A8BDCB8EB5B575E4EAA4C9E497C7E899CFE69ED3E6A6
D7E4AED3E3B4C7E6BCCEDEC1C8ADA26E4C43130600F3F6D7A9B285748149CDDC99D2E79C
C6E597CCEF9FC9EB9EC5E59ACAEAA1CAE9A3C3E29CC2E19D
AFF0ECC3FEFA2D5E5B436A67637D7AF1FFFFEFFEF9F8FFFDFBFFFCFDFDFBF8F4F57C7A7D
111518A5B0B2E2F7F8EEFFFF5E6A5E7586745578627FAD93C3F0D9B4D5C4B8BFB7FFFCFB
FFF9FBFFFAFBFAF9F5FBFFFDE8F3EDF9FFFFFFFEFFFEF7FEFFFCFFF9F6FFFFFDFFFBFAFF
FEFFFFFCFFF6FAFFE9F0F7D6CCD5AAE1EABBCED7A8E1EDBFD4DFB5F4FED9F2FDDBAAB992
9AB179C9E49FDAF7A7CEEC96C3E48DC8E797E1FBBADAF3BAE0F4C1CDDFADD0E1AAD8E7B0
E0EAB8E4EAC4FFFFECF7F5E9FFFFFAF9F6F1D3D0C9FFFEF2FAFBEDFFFFF1D5D8C5D3D8C2
D3D8C2E6ECD2FEFFE8F1F8D9FFFFE6E5E5CBE0DEC7A6AC8ACEE6AAB9D98DCEEE99CCED96
B9D686E1FCB9A9BF8E000C00000D00C4DAA9CFE9AACFEAA3CDEBA1CCEBA5BEDBA1D6EDC1
E3F1D7F3FFE7E2EFD1D4E6BECDE4B0CBE8A8D2F2A7C4E795CFF59EBDE58CC5ED95C7EF99
C1E897C3E99CC9EFA4BFE497CEF49FBBE289D6FCA5BEE18DCDEE9FCCECA0C1DC95CFEAA5
CAE09FD7EDACD0E4A5C2D496E1F1B3CEDE9FCDDB9D505E2397A375D0DBB1D4DCB3DCE5BA
D2DBAED3DCAD353F0D000A000E1D00243600C6DA9DD7F0AF93AE6BACCB85BFDE98D7F0AF
FFFFDAFFFEDBFFFFE1FFFFE3FDFCDEE3E1C8807E69FFFEEDFFFFF3605D546C6B6641403E
686667FFFEFFFAF8FDFFFEFFFBFCF7FAF9F4FEF6F3FFFCFBCCC2C3F2EEEF868A89000500
000800001400000D00C8E5B7CCE7B0CEE8A7829C53CFEB9ECCED9EBEDF90D1E8A0E0F0AF
C6D197DEECBBC6E3B7D1E0C194776F7C57510B0000FFFFE4C1CA9D849456D1E29BCDE492
C7E993C6EC95C7ED98C8EB99C8EB9BC9EB9EC9EB9FC7E99D
5EA69A3B7D710D3E384D716D000904E9FFFAEBFFFCB2C7C08F9B97FCFFFFFFFCFFFFF6FF
A8A1A9969BA15D75776D8585AEB7B6F6FFFEB9D6D185AEA646716AC8EBE7F5FFFF98969B
FFFBFFFCF0F2FFFEFBFCFFFAFBFFFBFBFFFAF4F0EFFFFDFFFFFBFFFFFCFFFFFCFFF8F8FF
FCFFFFF4FCEDFBFFE6EEF9CFACB684E0EAB8DBE2B6C8D0A7DDE5C0FCFFE3B1BD99F9FFDD
D2E7AECFE9A2C0DB8CCAE793D1EF99C2DF8DC7E29BCFE8A7C2D79CD8EBB3D4E5AE3B4914
FCFFDCF9FFDEF4F6E1FFFFF6FFFFFDFFFEFFDBD8D3C2C0B4DFDDD1F2F0E4FBFBF1FEFFF6
FBFFF3FBFFF1F8FFE7FCFFE6FEFFE6FFFFE6FFFDE6CACEABDCF2B1CEEE99C9EA8FDEFCA4
D7F4A4AFC886DBEEC0000A0022340CE0F3C5D4ECAEBED994C8E39EF0FFCDF2FFDCF4FFE4
F1FFE3F9FFEAE5F5D1CBDEB1C8DFA9B9D694BEDE93CEF19DCAF198BCE388C6ED94D0F69F
CCF29FC4E99BC5EA9DCEF3A3BFE389C8ED8EC6EA90C2E68FBCDD8CD2F1A5D7F2ADCBE4A3
D8EDB29AAD7563743E64723F374512192500BAC694A8B486CFD9B64A5334666D4C363D1B
646C47858D66B2BA91ECF5C8E1EDBDBBC994DDF0B8D2E8AAC6E0A1E0FDBBC6E5A1C0D998
D9E2AD777648C5C498BEBC95BFBF99E1E0C1FFFFE6FDFBE6FFFFEFF1EFE3FFFFFAB8B7B5
8A88893A383D7F7C83DBD9DCFFFEF9FFFFF6FFFFF6FFFFF6FFFCF5ADACA79E9F99DADDD6
D8DBD262685A222E168E9F7BD1EDBACCF0B096C27782AF5E9EC5768BAA5E9DB56B73823F
D1DB9ED8E5AFCCE8B8D0DEBDFFE2D85029247D6D5EFFFFE4B2BE9090A062D9EB9FC5DF88
C6EA90C5EE92C7ED96C6EC97C6EC99C6EB9BC9EB9EC9EB9E
2C77600D513CAFE2D300180D88A69EC0DED6E9FFFF6C8B83203530FBFFFFFFFBFFFFF7FF
FFF9FFFEFEFF6A828400070921242B575761D0E3EAE9FFFF14393F90B3B9F0FFFFF8FFFF
A6A4A9FFFDFDFFFFFAF2F2EAF0F1E9FFFFFAFFFEFBFAF4F6FFF9FFFFFBFFFFFDFFF8F9FE
F8FFF8E3EFD9ECFBD2C6D49F96A36BC0C994E4E9C0DBDFBCCED5B4FCFFE4B8C7A0F8FFDA
C5D99CDEF5AFCEE69ACAE594CFEB97CCE796D0EAA0D7F1AAD7EDACCADEA1CBDCA5576534
E5F0C8F5FBDFFFFFF0FFFFFAEFEDF0F8F6FBFCF9F4FAF6EBE6E2D7FFFFF6FFFFFBEAECE9
F6FDF5F8FFF4EDFCDFF8FFE3FCFFE1FCFFDEBEBCA3E1E5C0BED58FCAEB92CDEC8FB8D47D
CFEA9DD4EAAA839669011100000B00C4D7A9DAF0B2D3ECA8D1EAA8F4FFD3F2FFDFEFFFE1
F8FFE6ECFAD7D6E7BDD8ECBBD1E9AFD2EFACD8F8ADB8DB89C3E790CBEF97D9FDA6B9DC88
B7D887D4F4A8BDDD92C5E697D2F59BD1F498C4E68FCDEC9CE7FFB8C1DA96D4ECB0C7DBA6
5365350110008A9970DDE9C3C9D3B0D3DAB8E1E8C67D876277815CD6E2BCD9E3BEFCFFE1
ECF4CDFEFFDFECF4CDC0C89FCFDAB0D3E0B5D3E3B6C3D4A7CAE0B1D2EABAC6DEAEDAEEBB
4E55229B9B69EAE9B9D9D8ACFFFFD8FCFCD8FFFFE4FFFFEAFFFFEFFFFFF3FEFEF6FFFFFB
FAF8FBFFFEFF0100051C171D625D59F4F0E5EDEFE2F9FDEEFAFEEFFFFFF4DED7CFE9DED8
D8CAC7908780000300637356C0E0B1B9E7A9C5FDB4B5EB9DCCF5A7C0DF93BAD085576720
CDD695D5E0A4C6E1ACD5E1BBC9AC9E59322B564636F4F7D8E3EFC1899C5CD7EC9DD5F19A
C7EB91C4ED91C6EE96C5ED97C5EB98C5EA9AC9EB9FCCEEA2
B9FFE2A1E3C79DD1BA527D6ABEE4D53B5F5380A89D5A7E743D5652A0A8ABFEF4FDFFF1FD
FFFAFFF4F5FAEDFFFFF1FFFF88858E251D2A838B98C7DDEAE0FFFF5175816D8B95E9FDFF
4A5456FFFFFDF1ECE6FFFEF6FFFAF2FFFEF8FFFEFBFBF5F5FFF7FBFFFBFFFFFDFFFEFFFF
F9FFF6D9EACACFE3AE899B5D9DAC6BD1DAA1EAECC4D4D5B6989C81D2DBBCF9FFDFF8FFD8
BFD396D1E6A1C0D68DD5EDA1DEF7A6CCE796BFD789C8E096CDE49EDCF0B1BDCB96B3BE93
E4EBCAFFFFEDFFFFF4F6F5F1FFFEFFFFFEFFFBF8F3A09A8EFFFFF1F2EBE1FFFEFDFEFFFF
F6FFF8F5FFF3F4FFE4E1F7C8E0F0BFC3CC9F555634DCE3B9D3EAA2D1EF99C8E48DE3FCA9
BFD68EDFF2BAC8D8B100080044522FD3E4B7C7DB9EC5DC96BFD692D1E9ADCDE4B8C5D9B4
DFEFC8F8FFDDC3D5A590A56D94AC6E9AB570B4D288DDFEAFC1E38FE6FFB2B3D380D6F3A3
D8F4A7BED88ED8F2A9CFE99FC6E391BEDB89D8F4A9C9E39CB5CB8BDCF1B9D0E1B4000F00
42502D869173CBD4B9E5EDD5FEFFECF2F7E0F3F8E1DBE2C3D1DEB2A4B27F768453AEBA8A
C8D4A6E1EABFE0E8BFFEFFDFFBFFE2FCFFE4FBFFE6F5FFE4F7FFEAECFFE3D5E8CCD1DFBE
555A31A8A779DFDEB2D1CFA8DFDFB9DFDFBDD2D1B5E8E6D1DFDECCF3F1E5FAFAF2F4F3EF
FFFEFFF8F6FBFFFDFFADA8ACE1DCD9FBF8EFFAFFF1FAFFF0FEFFF1FDFAEBEADCD36A5552
766160CBC0BC50584B2F49304C754D7EB07BC5F9B9B0E29BC3E9A0D3F2A6CBE1968D9B50
A0A761D1DC9ABFD99CD8E3B88E6F5D3610070D0000FFFFE4DEEABCBCCE90C5DC8CD5F19A
C7EB91C4EC93C5ED95C7ED9AC5EA9AC6E89CCAECA2D0F1AA
95D6AEC4FFDB73AC8B81B899C1F5DE2C5D4A214D3E91B6AECDE3E1E5EFF1FFFDFFFFF5FE
FFFDFFFCFFFFF4FFFFEBF7F5FFF5F9FFFAFF201E29000410EBFFFF8DB2BB4A7377C8ECEC
6F8582F9FFFBFEF7EFFFFBF4FFFBF6FFFBF7FFFEFBFFFEFDFFFBF9FFF8F8FFFEFFFCFFFB
F8FFF1DFF4CBC7DFA1768C4386964FDCE4A9D3D3ADC0BFA3EBEDD7F1FADDF9FFDFC5D7A3
899B5FD1E4A2D8ECA7D6ECA4C5DB90D4EC9ED4EB9BD0E799D6ECA4829456A3B17EF8FFDD
FEFFEAF5F7E9FFFFF8F3F2F0F8F7FDF4F3F8D3CFC6C7C1B1F5EEDCFFFFF3FFFEFBF5F7F4
F7FFFAE9FFE6E6FFD2CCE8ADCFE5A5B6C58A878F60DFE9B7DBF0ADC7E295CCE496CCE299
DFF3B4D3E3B4CFDDBC000800333E1CCBDBAED4E7A7E1F7AED5EBA2D7EDACCCE2B1C9DEB3
8A9C6AA2B57EB8CB93C5DB9DC1DA98CBE6A1C5E19788A45989A558BBD78AC6E194D0E89C
CCE299DBEFA8CADE97D2E6A1D7ECA9D3E7A8CBDFA4EEFFCCE5F5C8DAE8C4D3DEC0F7FFE9
FCFFF1ECF3E3EEF2E4F4F8EAFFFFF4FFFFF4FFFFF3EAF0D4F1FFC7D1E59EC6DA95C8D899
94A267ABB883EDF6C9FAFFDBFEFFE4FCFFEAEFF8E3F8FFF3F9FFF8F8FFFBF8FFFDE5EDE0
F1F1D7C1BE9DFBF8D9EFEBCEF2F1D5EDEBD2EBE9D4E7E4D3E3E1D4F9F7EBFFFFF8FFFFFB
FFFEFCFFFEFFFBF9FCFFFEFFFEFAF9F2F3EDFBFFF6EFF6E68D8C7A7E7264C3A7A35F4141
200C0ED0D0CEC4E0D45C8974548766001400BEDFB2D3F0BABFDE9BCBE79DD4E99CD8E697
97A051DCE89ED7F0ACD8E2AEF7D9C1A67E720E0000FFFFE4CAD6A8CEE0A2ACC375C4E08B
C8EC95C4EA95C5EB98C9EC9CC7E99DC6E59FCCEBA8D6F4B4
C2F7C9C3FCCF549368A5E8BFABECCC124E34023222D7FAF3F1FFFFF8FFFFEAEDF2FEFFFF
FCFFFFE5EBE9F1FCF6FCFFFBFFF5F0FFF9F8756A6E01040BE4FBFF7BA0A629595984B5AF
B1D5C9E8FAEEFFFEF4FAE7E0FFF8F6FFFAFAF2ECECF4F0EFFFF2EFEFE2DCFFFCF9F7FDF3
EFFFE4E0F8C8CFE9A295AC5CA0B065C6CF90C0C09AA5A38CFFFFEDFBFFE9F0FFD6CFE1AD
97A66BCDDD9ED1E1A2D9EDA8B9CD86D0E69BD8EF9FD4EB9BC7DB935A6A2CB9C597FEFFE4
FCFFECF8F8EEFFFEFBFFFEFFFEFDFFFFFFFFE3DFD3B6B09AFFFFEAFFFFEFFBF8F1FCFFFB
F0FFF1D3ECCCC3E4ABCCEDA6C9E598C7DD94ECF7BDACB77FC2D697DBF2AEC2D792F9FFCC
F9FFD4D1DDB5CBD5BC000600343D1ED2DFB1CEDF9BCBE091C6DB8CD2E8A0CCE1A9CDE1AE
6B8045C2D898D6ECABD1E8A4DDF6B2D6F0A9CDE7A0CEE89F7D974EADC47CD6ECA4E4F5AF
CBDA97DEEDAAC3CF8DDBE6AACFDDAACDDAAEC9D5ADBAC6A2FCFFEAFCFFEFFCFFF3F2F5EC
FEFFFAF6F7F2FFFFFBEEEFEAFFFFFAFFFFF8E1E1D9FFFFEAF8FFD0CDE39AC9DD96BBCE8C
E3F2B77B8852F5FED1F6FED7FCFFE2FDFFEBFCFFF1FBFFF6EEF5EDECF5F0F9FFFFF3FAF3
FFFFF1B8B3A0B8B3A0DCD6C6F1EEDDFFFFF1F5F2E3FFFFF3FFFFF4F1EEE5FDFDF5FCFBF6
FDFCF8F6F5F1FFFFFDFEFAFBFFFDFFFDF9FAEEF5EDF1F9EA4A4B391F11043A1B18371718
47373AF9FFFFE3FFFF1853413E7A600F3D209DB094CFDBB5D9F3B6C7E399CADF90D5E493
9FA754B4C171D6EEA4C3CE94DFC0A3B58E7D0E0000E9EACBD8E4B6CADEA19AB26695B25E
C9EB97C3E996C6E999CAECA0C8E7A1C6E3A1CEEAADDBF7BC
B3DDABAADCA96BAF7CA2F0C061AF87397E5FBBEBDB7E9D97BECDD0F8FFFFEDF7F9F3FFFF
E4F0ECF2FDF5F5FCF4FFFFF4FFFBEDFFF6E9D1BFBB1E1C1D233537E4FFFF91C9C0427C6E
BDE9D8BED6C6DBD5C9FFF3EDFFF7F6E0CACCD2CCD0DCDBD9EFE2DAD6C9C0FFFEF7ECF2E4
D2E5C5D2EDB8CFEB9EBED88192A452BFC887FFFFDCF7F2DCFFFFEFD1D9C1D4E3BAD4E6B2
D3E2A78B995C687639BCCC8BAABB7791A65B7F94458BA05198A962CFDFA1E5F0C5C9D0B1
DDDFD1FFFFFAF3EFEEFFFDFFFEFFFFFFFFFDF9F6E5FFFFE6D9D2B8FFFDE7FFFFF6F6FCF2
EBFEEACEEAC2C7ECA9CCF3A0C2E58BC9E28EE1F0AB89945882945AD1E5AACCE0A5D0E1AB
EFFCD1E8F1D2707863060E00585F40E3EFBFCCDC95D7EB96DDF49CC2D9897E925362773C
CDE4A0D3EAA2CCE39BCAE49BC5DF98C9E39CD5EFA8C3DA96DEF3B0AABD7B1E2E00A8B474
DDE7A8C0C98ACCD2947B824C9AA27DAAB3986F775F686F5DF4F8EAFEFFFAFEFFFDFBFBFD
F6F5FAFFFEFFFDFBFEFFFEFFF4F3F1F5F1EEFFFFF8E8EBD6D9E9BAD7EDAFD9EDB2D5E6AF
D3E1AEC0CC9CA4AD82F7FFD8E9F0CEE1E8C9E5EBD1E9F1D9F4FDE8F9FFF1F9FFF3F9FFF1
FFFFF8FFF8F5F9F1EEFBF3F07B7672B0ABA5D7D2CCFFFEF8FCF9F2FFFFF8FCFBF6EEEDE8
FFFFFAFFFFFAFFFFFAFFFAFAFFF8FFFFFAFFFCFFFDD9E5D7E6EDDBFFFFEFFFE9E4B19496
F2E3E8E6F1F3DDFFFF55978B3F7E6DA0CBB80C1405313117C6DBA3D6F2A8D5EA9BD2E18C
D4DC86909E47CDE695E6F2B27557353A11003D2D16B6B798CDD9ABE9FDC0ABC37985A250
CAEB9CC5E79AC7E79CCBEAA4C9E6A4C5E1A4D0E9B2E0F8C4
CFF4C07EAF7873B882419460004A1DCEFFF8DEFFFEB4D1CDBDCBCEEEF5FBF5FFFF798988
5E7269D8E8DDFEFFF8FFF9EBFFFBEAFFF3E1FFFAF358534F000505CFF6F3CBFFFB418170
B7E8D3E8FFF0878175BCA39E907071B39A9EFFFDFFFCFAFBE6D9D0CDC1B3FFFFF6EDF4E4
C3D7B4C6E1AACBE898D7F198CADC88F4FDBAFFFFDDFFFFEAFFFFF1D3DBC3D9E8BFCBDEA7
D7E4ACD6E1A5CCDA9DEEFCBEB9CA86D2E49ADCF1A2CFE593D3E49DD3E3A5D2DBB0DAE0C4
EFEFE3F3F2EEFFFDFFFFFAFEFCFDFFF8FAF5FFFFEDFFFFE4AFA88BDDD7BFFFFFF4FAFFF4
CDE0CAB8D7ADCDF5AEBAE58CC5E88ADBF89EC6D68DDCE8AA8C9D66CFE1ADD7E8B2D2E2B1
B9C39EAFB89BE7EBDC0003002C3314CFD9A7CEDE95DEF299CADE8598AE5B889D5AC5D99A
CAE199D8F0A4C9E399CEE89ED4EEA7C4DE97CDE4A0DBF2AEC1D494E4F4B5CAD89A959F62
535B1FA5AB6FD1D598DEE2AFD9DEC0686C5B000300DADDD2FAFBF6FFFFFFF1F0F5FFFEFF
FFFDFFFFFDFFF6F3FAF8F6F9FFFEFFFFFEFBEAE7E2DDE0CDD0DFB4D5EAB2CBDDA9CADCA8
DCE9BBC9D6A89CA47B4B532CD9E1BCDAE1BFDBE2C3D0D9BAE6EFD4F8FFE7EEFBE1FCFFF1
FAF7F2FFFCFFFFF9FCFFFBFEFFFDFDFFFDFDF7F2EFB1ACA954514C827F7AD7D6D1FFFFFA
F0F0E8FFFFF8F9F9F1FFFDFBFFF0FFFFF5FFEEF2F1F7FFF8F2FDECFCFAEBBFA8A2B99FA0
FFFAFFF5FFFFD8FFFFA5EBE100140783ADA1A1A29C35301C687A46C8E49AD3E899D0DF8A
E7F097526008859E4BD3DF9DC09F7CE3BAA463533C6C6D4DD9E4B9C6DA9FD0E89ED3F0A0
CAEB9CC5E79BC7E79ECBEAA6C8E5A5C4E0A5D2E9B5E3F9C8
pop
P
% End of image
1 0 0 r
.03 w
.0625 .01583 Mdot
.00075 .02163 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.984127 0.34127 1.30159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
C4E397CFEDA3CAE59E819C59ADC788C7E0A6EFFFD2F6FFDCF8FFE3F7FFE5FAFFE9FBFFED
FCFFEFFCFFF1FDFFF3FAFDF2FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFEFEFEFAFAFAFFFFFF000000000000757575FFFEFFFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFDFFFFFDFFFFFBFFFFFBFFFFFBFEFFF1
F2F4CF919864D5E3A8CAE19BCEEEA2C4EB98C1E895C8EF9EC8EA9DCAE89ECCE7A2CDE7A0
CCE89ECAE99BC9EA99C8EB99C3E898C9EB9ED2F2A6C4E095D0EAA0CEE69C889C545A6E26
DAEEA6D0E69DC8DE95CCE69CD1EDA2C5E599C2E497D9EAA6C1AC81957455A69778030400
7285586D8A52587533D2E9A5D1DCA4A1A278B3A892FFFEEFFEFFEBF2FFDFCAE5B2C8E8A9
CDEAA7CEE9A4D3EEA9CCE7A2D1ECA5D5F0A9B9D48DADC881C9E49DDAF5AECBE59CC0DA91
D7F1A8CAE49BD6F0A7D0E4A7D8DCB7C5C5ADCBCAB6F0F1E1FFFFF4FFFFF8F9FBF8FEFFFF
FDFEFFFEFFFFFFFEFFFFFEFFFFFBFFFFFEFFFFFCFDF0E7E8CAC0BFF4EFECFFFEFFFCFFFF
FBFFFCFEFFFBFFFFF6FFFAF1CEB8ABA28479B8988DFFF7EDC0ABA6EFE4E0FFFEFFFCFFFF
FEFFFFECEFE6F2F7E3DAE8C4CEE9B4C1E09DD7F1AAD2DF99797837D2D190D6E5A2D3EEA7
C4EAA1C7E29DAAAA6C9B9A5AD6EDA5C7E99CC6E297CEE69CB2C37C4B5B14D3E49DD0E49C
D9F3A9CCEB9FCAEC9FC5EA9CBFDF93CAE99DD6F2A7D0E49CA6B06BE2EFA9C6EB9DBBE495
D5F3ABC7E09CC6DF9EE2F4BA9D9A6F6C5738BF9585FFDAD1FFF9ECFBFFF6F9FFFAF8FFFC
F8FCFFFEFFFFFFFFF8FFFFEDF9F8DAC1BD97BFBA90AEA779
DEFAB0B9D58BD0EBA4D5F0AD829C5BD7F1B4DDF4BEEBFFCEF6FFDCF8FFE1F9FFE6FBFFE8
FBFFECFCFFEDFCFFEFFEFFF4FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFBFBFBEDEDED111111000000000002FFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFBF8F9F4F9FAF5FEFFFAFFFFFBFFFFF2
CED0AB9FA672D9E7ACCAE19BC6E69AC7EE9BC7EE9BC6ED9CC8EA9DCAE89ECCE7A2CDE7A0
CCE89ECAE99BC9EA99C8EB99C3E898CAEC9FC4E498C6E297DFF9AFBED68C92A65EC2D68E
D2E69EC8DE95DAF0A7CFE99FC3DF94CCECA0C8EA9DD2E39F473207654425E0CFB1111200
627548C9E6AEDAF9B5BFD894DBE6AC9D9E72AFA88EFFFFEDFEFFEAF7FFE2CAE5B0CEEEAD
C6E3A1C6E19EC0D997C8E3A0D2EBA9BBD492A1BA78D5EEACD5EEACB2CB89E7FEBAD6EDA9
C6DD99D9F0ACC7DE9ACEDFA8C4C8A7D9D8C3F5F6E4FFFFF3FFFFF6FDFEF8FAFCF9FEFFFF
FDFEFFFCFDFFFFFEFFFFFEFFFFFEFFFFFDFDFFF6F7E2DAD8D1C7C6F7F1F1FFFFFFFCFFFF
F9FFFDFEFFFBFFFFF8FFFBF29B857866483D6E4E43FFE8DE9E8A83908581FAF9F7FCFFFF
FEFFFDF4F7ECFAFFE9E4F2CED5F0BBBFDD9DD1E7A6D8E4A2625E21E4E2A7D3E2A1C9E4A1
CDF2ACD4F2AC49490BDFDE9ED7EEA6C3E598CAE69BD3EBA196A760E1F2ABCBDC95D2E69E
BCD68CB5D488D2F4A7D2F4A7C3E397CAE99DCAE69BCFE39BACB36FD2DF99C8EA9DC3EC9E
C3DE97DCF3AFC0D998D3E5ABDAD7AA796445DCB3A1F5D1C5FFFDEDFBFFF4F9FFF8EBF6EE
F8FFFFF9FFFDF4FCEDF5FDE5FEFFE1E6ECC0C5C9979EA06E
CAE49DC8E29BCAE49DCEE7A367823FC9E3A2C5DFA0D5EDB3CDE4AECEE5B1D0E3B6CFE0B6
CCDAB6CED9B7D1DCBCD6DEC7FEFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFEFEFEF7F7F7FFFFFF0000000000007E7E80FFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFDFEFEFCFBFCF7FDFEF9FFFFFAFFFFFAFEFFEF
B3B590C0C793E2F0B5D2E9A3C0E094C9F09DC8EF9CC1E897C8EA9DCAE89ECCE7A2CDE7A0
CCE89ECAE99BC9EA99C8EB99C4E999CEF0A3C7E79BC0DC91D6F0A6CBE3999AAE6694A860
D7EBA3C5DB92DAF0A7D0EAA0C2DE93CEEEA2CBEDA0CFE09C6C552BA28162F2E1C3040400
738658CEEBB1C6E59FCEE9A2CDDB9D909364BFBA9CFFFFEAFFFFE8F9FFDFEBFFCCEAFFC7
F4FFCFF5FFCFD7EDAFD5EDAFD4EAACA7BC81758A4FBFD499D2E7ACCDE2A7CCDFA7C6D9A1
D5E8B0CEE1A9D3E4AD9AA678A1A487D1D0BEFAFBEBFFFFF4FAFBF3FAFCF7FEFFFFFEFFFF
FEFFFFFDFEFFFFFDFFFEFCFFFFFDFCFFFEFBEEE6E3C6BCBADCD4D2FCF6F6FFFFFFFBFFFE
FAFFFEFCFFFBFFFFF8FFFCF3503A2DFFF7ECA08073AB8D83E3CCC6776966DEDAD9FBFDFA
FCFFFAFCFFF3FEFFECEFFDD9E0FBC8C3E0A6CEE3A8E6F1B7645E2CDDD7A5D0DDA5CCE6A9
D1F6B3A2BF7C737337E4E4A4C5DF96CEF3A5CAE99DD0EAA099AD65C4D58ED7E8A1CFE59C
EBFFBBCDECA0C0E094C0E295D7F7ABCFEEA2B7D187DAEEA67E8541DAE7A1C1E397BDE698
CDE8A1D6ECABD2EBAADCEBB2F6F3C654401FD3AD98FEDDCCFFFFECF7FFEDE9F6E4F5FFF6
DDF5E7EAFFF4F0FFEFD4EEC9DEF8C9D4EBB5CBE0A5CFE3A6
C3D893E7FEB8C6DD97C9E39C829C55C9E49DC9E49FD4EFACD0EAA9D2ECAFD2E9B1D1E5B0
CFE1B1D4E5B8DFEEC3EAF5D5FEFFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDF8F8F8FFFFFFFCFCFCFFFFFF0909090505055A5A5CFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFDFDFDFFFFFDFFFFFBFFFFFBFFFFFAFEFFF9F4F5EFEAEBDB
A6A883D5DCA8DCEAAFD6EDA7BFDF93C9F09DC7EE9BC2E998C8EA9DCAE89ECCE7A2CDE7A0
CCE89ECAE99BC9EA99C8EB99CAEF9FC4E699D2F2A6CAE69BC0DA90D9F1A7B0C47C465A12
D3E79FCFE59CC7DD94CEE89ED1EDA2C7E79BC8EA9DD3E3A26A53298F6C4EF7E6C8040400
647749CBEAAFCEEFA8BFDD93D4E4A39AA16DD5D2AFF0ECCFEEF4D2E0F1C4E8FFC4D7F8B1
F1FFCBF3FFCFCBDEA6C8DBA4D5E8B1DAECB8B9CA96EBFBCAEAFAC9EAFAC9C9D6A8D3E0B2
CEDBAFFBFFDC97A277B4BC97D9DBC5F3F4E4FFFFF3FFFFF6FAFDF6FEFFFDFEFFFFF9FAFC
FEFFFFFFFEFFFFFEFFFFFDFEFFFEFBFFFDFAECE3DEC0B7B2EBE3E1FFFCFDFEFFFFFAFFFF
FAFFFEFCFFFDFFFEF7FFFCF3644E41FFF7ECFFE9DC74564BA08981443731B8B4B1FEFFFB
FCFFF4FCFFEFFCFFE6F0FEDAEAFFD3D0EBB8D4E8B5F8FFD1887F56DBD4AADCE8B8D4EFB8
C8ECAE90AD6BDDDEA2D5D595C8E298CEF3A5C5E498D5EFA5B4C8805D6E27CDE199D9EFA6
B7D187CFEEA2D1F1A5C1E396BFDF93D2F1A5D0EAA0ABBC75B9C07CDEE9A4CDEFA3C2E89D
D1ECA7C1D796D4EAAAE3F2B9DFDDAD7E6A47F6D1B7FFDFC8FFFFE6F9FFEAF5FFEAF2FFEF
EDFFF4EAFFF3EBFFEABBDCAFC6E7B0CDECB0C2DF9DCCE9A6
D1E4A2D0E49FCBE09BC7DE9699B369D7F3A8CBE79CCAE99DC6E49AC7E59DC8E5A2C9E3A2
CDE5A9D8F0B6EBFFC8F8FFDFFEFFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFF0000000101016D6D6FFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFBFDFEF8F6F7F1E8E9E1DBDCCA
ACAE89D6DDA9CBD99ED4EBA5C2E296C8EF9CC5EC99C9F09FC8EA9DCAE89ECCE7A2CDE7A0
CCE89ECAE99BC9EA99C8EB99CDF2A2BADC8FCCECA0DBF7ACC4DE94CEE69CCEE29A92A65E
A3B76FDDF3AAC4DA91CAE49ADAF6ABBFDF93CAEC9FD3E3A2654C23664325E5D4B60A0A00
5C6F41C2E1A5CDEFA5C7E69AD2E39F949C639F9D76D9D9B7D2D8B2D1E3AFCFEFA6C7E99D
F5FFD1F5FFD3DBEBBACCDCABC6D6A7D8E8BBD0DDB1EBF8CDF7FFDBDEEAC2DFE9C4D8E2BF
DDE4C3C9D0AFA2A988E3E7CCFFFFEFFFFFF4FFFFF6FFFFFAFEFFFDFEFFFFFEFFFFFCFDFF
FBFAFFFDFDFFFFFEFFFFFEFDFFFEFAFFFEF8F6EDE6C9C0BBF7EFEDFFFEFFFEFFFFF9FFFF
FBFFFFFCFFFDFFFDF6FFFCF36C5649F3D6C8FFF2E665453AAE978F0A0000837F7CFEFFFA
FAFFEDF7FFE5E7EECFE3F1CDE6FDD1DEF8C9E2F3C9FFFFDF8A7F61E2D9BAD7E2BABCD6A6
B3D69C99B676D3D498DFE1A0DCF8ADB7DC8EC6E599DBF5ABBED28A94A55EA8BC74D0E69D
D3EDA3C1E094C0E094DCFEB1BFDF93C5E196E0FAB0879851F0F5B3C9D490CBEDA3CEF4A9
C5E09BD9EFAEDEF4B4FBFFCFBFBF8D8E7C54CAA588E8C9ADEDEDCBE3F3CFE7F8D6E8FFE0
E4FFE5E6FFE5EEFFE4C0DEACC9E6ACCFECAAC8E39ED0EBA4
D5E4A3C5D692DFF3AC5E742BB1C97DD6F3A3C6E693C1E38FCFF09FCEEF9ECCECA0CBE99F
CCEAA4D6F1AEE2FCBBEFFFD2FCFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7F1F1F1101010000000030305FFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFEF9FBFCF7FDFEF8FEFFF9F7F8F0EEEFDD
D0D2ADDFE6B2CDDBA0D8EFA9C8E89CC7EE9BC0E794C8EF9EC8EA9DCAE89ECCE7A2CDE7A0
CCE89ECAE99BC9EA99C8EB99C2E797CCEEA1C2E296CCE89DD4EEA4CDE59BD4E8A0D6EAA2
768A42D8EEA5D5EBA2CAE49AD0ECA1C1E195CEF0A3CFDF9EA78E65704B30C4B095030400
66794BCDECB0C0E598D9FAABCCE099929C60525329DDDDB7CAD1A7DDF0B8C2E296D0F2A5
DFF4BBD7E7B8EAFACDE9F6CAD5E2B7C0CCA4C9D3AEF1FBD8F8FFE0EDF4D5EDF3D7E6EAD1
D4D8C1B5B7A2FFFFEDE9EAD8F6F6EAF5F5EBF7F8F2FDFEF9FDFFFEFBFCFEFDFEFFFEFFFF
FDFCFFFFFFFFFFFEFFFFFDFAFFFEF8FFFEF6E9E0D7B6ADA6FFF8F6FFFEFFFEFFFFF9FFFF
F9FFFFFCFFFDFFFCF5FFFCF3D0BAAD65483AE3C1B56A4A3FA48D85150600716C69F9FCF3
F8FFE8EAF5D3D2DCB9D5E4BDD7F0C6E9FFD8EEFEDAFFFFE6887C66F0E4CED9E0BFC0D7AB
CEF1B9718F51CED295E1E3A2D0ECA1B7DE8FD4F4A8CFE99FCADE96D5E69FA9BD75A0B66D
CBE59BDAF9ADBADA8ECBEDA0D8F7ABC3DF94CAE49AB7C881848947F0F9B6BFDF96CCF2A7
CEE9A4E6FDB9EDFFC3F8FFCCC8C8969180557B5737BD9E7FEBEBC5C0D1A7CEE0BAF4FFE4
F4FFEAF4FFE8F5FFDFD8EFBBD0E4A7C6DB98D2E39DD7E8A1
D9E5A5DCEBA8BCCD8750641CD2EA9CD2EF9DCFEF9ACEF099CBED96C9ED96C6E995C4E594
C2E296C4E298C6E49CCDE1ACFCFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFF5F5F5FFFFFF0000000B0B0BCECED0FFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFEFEFEFDFDFBFBFCF7FCFDF8FFFFFAFFFFF8FFFFF8F8F9E7
E8EAC5DFE6B2D7E5AAD7EEA8C9E99DC8EF9CBEE592C4EB9AC8EA9DCAE89ECCE7A2CDE7A0
CCE89ECAE99BC9EA99C8EB99BDE292D7F9ACC3E397C3DF94D1EBA1D0E89ED3E79FC8DC94
93A75FB8CE85D8EEA5CFE99FC6E297CBEB9FCBEDA0D0E09FAC936A613C21B5A1860B0C00
586B3DD1F0B4B5DA8DC1E291DDF1A9C4CE91606233E3E5BDD0D9ACD3E7ACBFE08FC3E696
CDE2A9D6E3B7F3FFD5DEE9C1D3DDB899A380ABB291F1F8D9FEFFEAFFFFECFAFDE8FFFFEF
AAAB9BF5F3E6FFFFF3FFFFF4FFFFF8FFFFFAFFFFFBFFFFFDFEFFFFFAFBFDF9FAFEFAFBFF
FFFEFFFFFFFFFFFEFDFEFBF6FFFBF3FFFAF0D8D0C59A9188FFFDFBFFFEFFFCFDFFF8FEFE
F9FFFFFCFFFDFEFBF4FFFCF3FFF7EA5E41336241326F4F44A38A830B00009F9A97FEFFF6
FAFFE6E6F2CCCCD6B1D1E0B9CCE5BBF0FFE2F8FFE8FEFFEAA19182FFF8E8F8FEE4ECFFDB
EDFFDA78965ADEE2A5DCE19FC1DD92C8EFA0D3F3A7C5E196D3E9A0CADE96C5D99199AF66
4D671DC1E094E3FFB7BADC8FC6E599D4F0A5C9E197D9E9A2646927D2DB9AC8E89FC6ECA1
D7F2ADCAE19DD9EFAFCAD99EE4E4B0DFCEA294724F7F6240DBDCB2CEDFB2D6EBC0EAFCD4
FCFFE6D5DABACED3AAD6DDAAE1E5AAD7DC9AEAEBA9D2D38F
D9E5A3CBDA9552631CD2E79CD0E89AC6E190C6E790CBEE94C9EC92C9EC92CAEC96CCEE9A
CEEDA1CEECA4CDE8A5CDE1B0FCFFF3FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFF1EFF0FFFEFFFFFFFFEDEDEF00000248494BE6E7EBFFFEFFFFFDFFFFFCFFFFFDFF
FEFFFFFCFFFFFCFFFFFEFFFDFFFEFBFFFDFAFFFEF8FFFFF6FFFFF6FCFEF1EEEEE2E1E0CB
DCDEB6CAD39CCEE2A3C8E39EC0E597C8F3A1BEEE9AC4EE9CCDE79DD0E69ECAE8A0C8EAA0
C8EA9EC9EA9BCCE999CCE999C9EA9BC7E79BC8E79BD9F5AAC4DE94C2DA90DFF5ACCAE097
D4EAA197AD64CAE298D5EFA5C4E095D5F5A9C4E699D3E7A2C4B687917955998E6E010500
6A7B515A7540001A00CCE7A2CBDF9AE0ECAE8B925CD3DCA7D9E6AEC6DC9BDCFDACC6E798
CADFA4D7E7B8DBE6BCA2A886B5B89B87876DAAAC94FFFFE8FAFFE4EEF7D8E8F3D1E5F0CE
D7DDC17F836AF1F0DCFFFFEDFEFFEFFCFFF1F9FFF0F4FAECFAFFF6FCFFFAFCFFFDFCFFFF
FEFFFFFCFEFBFCFDF7FEFEF6FFFFF4FFFFF3DBD5C7949180FFFFEFFFFFF1F8FFEFF6FFF1
F9FFF6FBFFF4FAFCEEFFFFEFFFFCEBFFFBEACFB8A8A69082DFCEC44F463FCAC9C5FAFDF2
FBFFE6E8F5CACFDCB0D3E5B5C8E3B0F2FFDCF8FFE1FAFFE199907FFFFAE9FFFFECF7FFE4
F0FFDCBFDB9E949F5DD1DC97D3EFA4C9E99DC4DE95D3EBA1CBE29AD3EDA3C6E097CDE79D
B1C77F778D44C1D890DCF8ADC2E297D3F3A7CAE49BD3E49ED2D699222B00CFE9A2C6E69B
CDE79ECBE59CCEE9A2CFE6A2D8E3A7DBD5A392704B5F3E1DDEDBB2CAD7ABD5E4B9FCFFDF
FFFEDDE6DDBCE3DCB2DCD8A8A09E65565417605F1E424100
D2E299607228D9EAA3CADE96CFE79BCCE798CBE894CBEC95CCED94C2E38ACEEE99C6E597
CCE7A0C5DFA0D3EAB4CDDDB8FBFFF4FEFFFDFFFFFDFFFFFDFFFEFDFFFDFDFFFCFDFFFCFD
FFFAFDFFFDFFF9F4F8FFFEFF7B7C8104090D7A8187F7FCFFFFFDFFFFFBFFFFF5FFFFFCFF
FCFFFFF1FCF6EFFFF5FBFFF8FFFCF6FFF9F3FFF9F1FFFCEFFFFFEFFCFFEAEFECD9E1DDC2
DAE0B0CBDD9FC7E4A1CBF1A8CAF4A8B3E795AEEC96C5F4A3D3DA96DADF9CCBEDA1BDF19F
BDEC9BC3EA9BD5E79DDCE9A1CFE79DCCE89DCCE89DCDE79DCDE79DCDE79DCFE79DCFE79D
D2EAA090AA60C5DF95C7E398D4F3A7C4E397D5F5A9C8E299D9E1A58E8E5CA1A67D000700
687355657352001000C9D9ACD3E2ABD3E3A551621E8A9B55D3E9A0C6DE94CCE89BCDE99E
D0EBA8D2E7AED5DDB4B7B3988A7E702D1F14B5A99BFFFFE8F8FFDAE8FFC7C7E6A3D5F4B0
BCD6975A6B34666D41D1D8AEDAEABDC9DCAFD7E9BFF7FFE3EDFEDEF8FFECF8FFF1F0FDEC
F7FFF4FBFFF6FBFFF4F9FFF0FCFFF1FEFFEFF1F4DFDAE1C0E7F5C2CEE0A6E2F3BFCADBAE
D6E6BFCDDBBAFBFFE8F3F9DDFFFFE8FEFFE8FFFFE7FFFEEAC9C9BD0001008B908CF7FFF2
FBFFE6E1F1C2D0E3ABCFE8A7C9E7A1C6E19ED9EEB3F8FFD7838667FFFFEAFDFFEACDD8B8
DDF0C2C9E1A5CDE59B546C1ED2EAA0C5DB93DBE6A4DAE9A4BEDC94D0F6A9BCE599CFEFA4
DAE6A4959A58535C1BCDE19ACCEEA4CAF0A3C8E69ECADD9BD7DFA4575F246E7F3BCEE69A
D5F09FC1E18CC6EA93C6EC99C4E99CBCCA8C82623B71482AE2D5B2F8FAD3FBFBD5FFFFDD
FFF3CEF2E0BADBCEA2EFE7B858552055561DC9D195E2ECAD
8D9F5572873CCCE098CBE199D9F0A8C5DF95CCE999D0ED9BD0F19AC6E691D3F0A0CAE49B
D0E8AAD2E6B1E8FAD0E8F7DAFBFFF8FCFFFDFEFFFDFFFFFDFFFEFDFFFDFDFFFCFDFFFCFD
F9F0F3FFFDFFFFFDFFE1E0E503060B878C92DAE3E8FCFFFFFFF9FFFFFAFFFFFBFFFFFDFF
FFFDFDFFFDFAFFF4F1FFEFEBFCD3D1FFD3D2FFDAD8FFCCC7FFEFE2FFF1E1F8D7C4B6A184
A1A16DC9D799D7F2ADC0E19ABAE095C2F3A4BCFCA6BCED9BE8E7A6E0DC9CC0E597B9F09C
BEF4A0C4ED9ED2E39CD7E29DD0E69DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79DCDE79D
CCE69CACC67C8DA95EDAF6ABC5E196D4F3A7B3D286D7F3A9CDE09E9FAC74889466000A00
5961496B735C091100D0DAB8D1DFAEDDEDAFD1E59D8BA252DAF3A2DAF2A4C6E096D1EDA3
D0F0A5C5DE9DCDD6A9ECE6CCFFF2E8FFF9F4FFFCEFF5F4D8E4F4C3D4F3AFB1DB89C1EB95
D7FAAABED58FBDC890D2DCA7CADEA1CDE7A8C8E1A8E8FFCCF5FFDDE4F9D2F3FFE2F7FFEA
F8FFEDF8FFEDF9FFEDF6FFE9F9FFEAFBFFE8F5FFE2E4F3C8C3D893CCE496C2D792CEE2A5
CBDDA9D9EABDF1FFD9F9FFE3F3FFDEF9FFE6F5FFE2D4DEC6E9F1E2F1F8F0F3F9F7FBFFF8
F9FFE6E0F2C2D0E5AACFEAA3CEEA9DC8E497D3ECA8EAFDC5B5C096FEFFE4F5F9DEE0E7C6
C7D7A8CFE7A9D1F0A2A9C9768FA75DBBCA87DCE5A4D8E4A2CBEBA2BFE99DCEFDAFBEE298
D8E1A0D4D295A6A869778341D4F4ABB6DC91C2E098DBF0ADDDE6AD90985D8C9856D5EA9D
D0E995C2E38ACEF59CBFE993C6F5A5EAFFBE5E3C16986B4ED8C8A6EBE9C3F7F3CEBCB48F
B8A97EAB9D70C5BB8A66602E5A5A24DDE5AAE0EEB1C2D595
AEC27ACDE39BDAEFAACFE6A2DAF3AFBFDA93CCE89ECCEB9FCCE89BC4E093D2ECA3C9E2A1
D1E5B0D4E5BBF1FFE1F6FFECF9FFFAFBFFFFFBFFFFFCFFFFFEFFFDFFFFFDFFFFFFFFFEFF
FFFEFFFFFFFFABABAD393A3E2A2E31F1F6FAFBFFFFFFFEFFFFF9FFFFFAFDEAEAE8FFFEFB
FFE5EADEA6B1D07D8F7A1C2E842835AD4C57CD5D6989101994121A972324B35C528D5A3D
AE9C6CC9CD90D6E0A1E4F3B2C8DC97DAFAB1BCF19FB5E091DBDC9AD9D897C6E89BC2F6A3
C2F3A1BFE899CAE298D4E59ECDE79DCCE89DCCE89DCCE89DCCE89DCCE89DCDE79DCDE79D
C9E399C9E399A7C177A3BF74CDE99ED5F1A6CBE79CCCE69DD6E9A7909F666E7A4C000700
757D65505841020A00D1DBB9D2E0AFC7D799E9FDB5586F21CEE796D5ED9FC5DF95C5E197
CCECA1CCE7A4DDE9B9797859D8CBBAFFF6E9FFFEECF0F1D1D4E6B2D6F5B1C6ED9CC3ED99
CEF1A1CBE29CA3AE745560289FB473DFF8B4D0E8AAD0E8AEE0F7C1C7DDAED9EBC1CEE0BA
CDDEBAD1E2BED0E0BCCBDBB6CDDDB6D3E2B9D2E1B6C9DBA7ACC37D667E32687F39D4EAAC
CBDEA7CBDDADD0E1B4C6D7ADD1E0B7D4E3BCFBFFE4FBFFEAEEF7E4FBFFF8E0E6E2FBFFFA
F9FFEAE1F2C6CFE4ACCEE9A6D0ECA1CAE699CDE7A0DBEFB2D5E1B3A0A883BCC1A1DDE5C0
D3E3B2C4DD9CD1F0A2C5E592D4EAA1A7B8745C6B28D0E49FD7F7AEBFE89CBEE79BD0F0A7
E1EDABD3D898D0D595D2DE9C738E47CDEDA4DAF8B0C4DB97D8E6A9C8D4969BAA65D7ECA1
CAE390C5E28ED8FAA6BDE292B6E096BFD1958D6947D8AA90FFFFDCFFFFDC51522A99986C
D6D3A0908D5674753C71763CCAD497D1E09FC8DD9AD7EEA8
CAE19BE2F9B3C6DC9BBFD897CDE7A6C7E4A2D0EDAACDEBA5CEE9A2CFEAA5E6FFBEE3F8C0
E7F8CCE4F1D3F9FFEFF9FFF6F9FFFBF9FFFFF9FFFFFBFFFFFBFFFDFBFFFDFBFFFFFBFFFF
F5FBF9FCFFFF262A290B0C0E737476FEFFFFF5F6F8FFFBFEFFF5FAFFE4E8FFF9F8DCC4C4
B99096B47681AA5262E07F90D97D88FFA7ACFFBDBDDF7975D56861BC5B4B9E5F405B360C
7A6935C7C187F7F1B7C4C287EAEAACC1D28EBAE498CAF0A3DDDF9EE1E2A0CDECA0C1EE9D
BFEC9BC4EB9CCBEA9ECFE99FCAE99DCAE99DCAE99DCAE99DCCE89DCCE89DCCE89DCDE79D
D0EAA0CEE89ED7F1A7779147C3DD93C9E399E5FFB5C1D890D5E8A6A8B77C6470420C1600
636B53767E67000500D3DDBBDFEBBBCDDD9FC4D58F617629D5EC9CCAE294DAF4AAC8E49A
C8EA9DCEEEA5CBDCA57A7F579C947DFFFCE8FFFFE6F1F5D0C1D49DC6E59FC7EE9DC5EC99
BEDF90D4EBA5D7E5AA99A46A637833CEE89EBCD68FB4CD8BD5EDB1D3EAB2BFD3A0D6EAB9
CFE2B4D4E7B9D4E8B7D0E4B1CFE3B0D4E9B1D6EBB3D4EAACD5ECA4A2BA70647B379CB272
E7FAC2D2E5AEC9DBA7DEF0BED1E1B0D0E0B3FBFFDFFBFFE6FBFFEFF6FEF1FBFFFDFAFFF9
F9FFEDE1F1CCCEE2AFCBE5A6CCEAA0CAE699CAE49BD2E7A6CFDCA7A0A97E7F865DC5D0A5
C1D29CE1FAB8BCDD8ECDEC9CD6ECA4D6EAA5899E59D2ECA5C0E298CAEEA4C6E89ECEE9A2
D0E19DD2DD9BE3ECABE3EEAC8B9F5AADC780CDE8A1C8E29BCDE0A0D9E9A892A35DD4E99E
D0E799C8E092D7F3A8C0E097C9ECAADAE7B28E674AE0B29AFAEDCACAD0A4545A2CD5DDAA
D2DA9FECF6B7A8B4749AA968DCF0ABC1D892E2FCB3BCD88E
CCE5A1C6E19CC3DD9CCCE6A7CAE6A9D3EFB2CAE7A7C3E0A0C6E09FD0EAABF3FFD2F7FFDC
F8FFE6EFFBE5FBFFF8F9FFFBFBFFFFF9FFFFF9FFFFF8FFFFF8FFFFF7FFFFF7FFFFF7FFFF
F7FFFFF0FBF7060C0A000100FCFBF9FFFEFDFFFBFBFFF9FAFFEEF1FEBDC5B76E79AC6A74
EFC8C9FFF8F4FFEEEAFFF5EDFFF6ECFFF9E4F5EFCDCED6A5D0DDA5DEF5B1D0F2A6B3CF84
7D7D3F54450E67521DA9945FAF9B66C6C688CEECA4CDEDA4DBE1A1E2E7A5CFE69EBADF92
BEE395CEF3A5D0F5A7C5E79AC9E99DC9E99DC9E99DC9E99DCAE99DCAE99DCAE99DCCE89D
D3EFA4CAE49AC5DF95A7BF75839B51D3EBA1CDE59BD3E9A1D1E5A0C5D79BC1CEA0000700
565F44787D660F1500CCD3B1D4DDAEE5F3B6C9DA94ACC174CEE597C6DE92D6F0A7CBE99F
CBF19EB7D98CD6ECAED5DEAFB5B593E2DDC0FFFFE1E4EDC2D8EDB2CAE9A3C6ED9CCDF4A1
BEDE92C7DE98E3F1B6CEDC9FACC277849D4CC0D88CD3EAA2C0DA93CEE7A5DFF7B9CBE3A7
C6DEA2CBE3A7CDE5A7CBE4A3C9E2A1CAE39FCAE5A0CAE59EBFD68EDEF5ADC9E09CB9CF8F
ABC183B5CB8DDFF3B6CBDFA2D4E6AACDDEA7CADAA9C4D3ACDDE7CCABB4A3B8BFB8EAF1EA
F7FFF1E3F2D5CEE3B8C9E2A8C8E6A0CAE69BCBE59BD0E5A0C5D499E3F0BBB3BD8B4D5A25
E7F9BFBFD894C2E394D5F4A4CADE97D6EBA6C0DE967FA15784A65C8EAE65BED992D2E9A3
C8DD98D7E8A4D9E5A3C2CD8BACB77581924EC2DC95D9F4ADCCE39DD2E8A0879D54CEE499
DAEFA4CDE39AD2E7A4CCE4A6CBE8B0DEE5B96C422A80523B5C532C4C5624B2BF8AD7E9AD
D3E8A5D2E8A0D1E8A0C4DE95CCE89EC3E197C2E195D5F4A8
DBF6AFC3E19BD9F6B4D8F6B6C6E2A5CBE9ABC2E0A2C3E1A3C0DC9FCDE6ACF3FFD6F8FFDF
F9FFEAF5FDEEFCFFFDF9FDFEFCFFFFFCFFFFF9FFFFF8FFFFF7FFFFF5FFFFF4FFFFF4FFFF
D7E6E18E9993565B57E8E7E3FFF8F6FFFCFAFFFAFAFFEEEEFFDBE0571016C77782FFEAF3
FFF0EFFFFDF4FCFFF1FBFFEFFCFEE8FAFFE2E1FDCCC7F4B3ADEA9AB0F298B1F191BCE891
E2EBA8D6C790694D1B997948F3D5A3DDD29A4154123C571099A563BFCA88D6EAA5D0ECA2
C9E59ACAEA9EC8EFA0C2EB9CC8EA9DC9E99DC9E99DC9E99DC9E99DC9E99DCAE99DCAE99D
C7E398D2EEA3C3DB91D2EAA05E742BD5E9A1CCE098D9EDA6CBDF9ADDEFB1D4E2B1000800
161F045D624B000500D8DFBDCAD2A3E1ECB2D6E5A0CEE094A4B96CCFE59AC9E098CBE99F
C4EC96C6ED9AD9F2AED2E1AAD3D8AF7E8059A3A87FD1DDABCCE2A4BEDE95B5DA8AC9EF9C
CFEEA2C9E09AD5E5A7D0E0A1D7EEA0C7E08DD0E9988BA355D9F1A7D0EAA1B9D38CD4EDA9
CCE7A2CFEAA5D1ECA5CFEDA3CFEBA0CCEB9DCCEB9BCBEA9CD1EBA2C8DF99D4EBA7C7DD9C
263C005D7332EAFFBCC6DB96D7EBA6D9ECACD6E8AEDBEBBCCED9B9535C470A1207F9FFFB
F6FFF3EAF8E1D9EEC7CEE6B2C8E5A2C8E79BCCE79AD1E79EDEEEADC9D79ACED9A194A267
CADF9EC6E099E4FFB6B6D585D9EDA6BFD48FCAEEA4C4EDA1D6F8AEB9D48DA2B772D1E5A0
D0EAA3D0E7A1C7D894EFFAB8818646939C5BD6EDA7C8E69ED3EFA5CAE49A98B064C0D68B
D2E69ED6E7A3CEDDA2DAEDB6CCE2B3F7F9D4FFDAC4F7C9B2DDD5AECBD9A4D8ECAFC3DC9A
C8E49AC2E195D8F7ABC7E69AB4D488DEFEB3C8E89DC8E89D
C6E49ABDDD92CBEAA4C1E29DC0DF9CC4E2A2CBE9A9D0EEAECFECACD4EDB3EFFFD2F2FFDB
F8FFEBF3FBECFCFFFDFEFFFFFFFFFFFFFFFFFCFFFFF9FFFFF7FFFFF4FFFFF2FFFFF2FFFF
F5FFFD6F7873353732BFBAB6FFF8F5FFF1F0FFF7F6FFF3F4925A5DEDB5B6FBD8D4FFF0EC
FFF7F6FFF6F2F6FEF1EBFFECF2FFECEBFCD8E6EFC4D4E1A9D0F2A8C7ED98D1E993CFDC8C
CFD491EFE6ABD8BE8B664414C8A879E0CF9BF0FCBEC8E19D889B59A8B975CCDD99DAEEA7
D5E9A1C6E297C0E796C5F09EC6EB9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DCAE99D
C4E095D3EFA4DCF4AACFE59C8CA058A0B16AE0F1AACFE09AD4E8A3C5D99AD5E5B4000800
222B101B2009000400D9DFBDDBE1B3DAE3AAD6E39ED3E39A8DA255C6DC91D2E9A3D4F0A6
BCE48EDFFFB1B2D086D8ECADE2EFBAC3CC9D8D9765B3C28BC5DB9AE1FFB5CFF1A4C4E797
CFEEA2CDE7A0D3E5A7DBEBAACCE395D7EF9BD5EC9A88A15094AC5EC3DB8FD2ECA2D5EFA5
CAE69BC9E59AC7E698C7E897C8E895C6E892C6E891C6E894CAE69CD3ECA8C6DF9DD7F0AC
8BA25E70873FC0D88ED4ECA0BED587CDE39AD7EAAAD1E2ACC2D1AA839076010C00F2FCF3
F6FFF5F2FFECE8FCD9DAF2C0CCE9A7C8E79BCDE899D0E89AD2E39CDBEAA5DFEBABA6B574
CBE09BD7F1A8BFE091D1F0A2CEE29BD4EBA5C3EDA1CFFBAEBBDD93CFE6A098A764C9DA96
C8E39CD2F0A8D7ECA7D9E4A2A0A062A5A768C9DE99C9E79DCFEFA3C8E799BBD689A2BA70
B0C17BD7E5A7D1DBA6E6F4C3EDFED4FFFFE3EDBFAFF2C3AFEEE9BFD6E9B1CAE5A2D1F1A8
D0EEA4CFEFA4C3E398D3F3A8C5E59ACDEDA4D1F1A8BEDE95
C6E798D3F4A5CBEDA1BCDE94D3F4ADCAEBA6CDECA8C4E39FCAE7A4C6E0A1D4EBB5CEDFB3
D5E2C6D7E0CFF3F8F2F9F9F9FFFEFFFFFEFFFFFFFFFCFFFFF8FFFFF5FFFFF4FFFFF4FFFF
F5FFFB7A817A0602008C817DFFF3F0FFF6F4FFECEDEEC4C5B48A8BFFF7F3FFFDF4FEF7EF
FFF9F8FFF1EFFFFFF8F8FFF4DDEFD5D4E2C1EAE8C1CFCF9DDAEEA9C6DB8CE2EB9ADAE191
DBE79FD7DC9CEBDAA4DCC08E68491A91804CCED498D4E9A8D6EFADB6CD89ACBB7AC3CF8D
DBE8A3D5EBA2C6EB9BC4EF9DC6EB9DC8EA9DC8EA9DC8EA9DC8EA9DC8EA9DC9E99DC9E99D
CFEEA2C2DE93D4EEA4D1E79ECBDF97596A23D4E49DCDDE97D3E9A1D2E7A6CADBA7010D00
2730132A2E17070900D0D4B3D9DFB1D5DDA4D1DC98DFEFA68B9D5193A85DCEE39EC8E49A
CBF19CBAE28AD2F2A6CBE4A0C7D99DE1F0B7DCEBB2889A5C4F6622BEDA90D5F5A9C0E094
CBE99FCCE69FCBE09FD0E3A1D3E89DCEE593D3EA9AD0E797435B0D94AC60D4EFA2CAE598
D1EDA0CCE89BC8E797C8EA96CAEC96CBED96CBEF95CDEF99D2EEA4CCE5A3C7E09ECEE7A3
D0E7A18EA65CD4EC9ED2EB98E2F9A7C6DD8DD1E59ED4E6AAD0E0B3C4D2B1636F5BF9FFF6
F6FFF4F7FFF1F4FFE7E1FBCBD0EEAEC9E79DCBE898D0E998D5E79BCCDC93DAE7A1CDDE98
001000CCE89DCCEF9FC7E899CCE29AD0EAA3BDE99CBBEA9CCCECA3CFE39E949F5D96A562
CCEAA2C3E59BD3EDA6C9D5939A985BAAAA6CBED28DD4F2A8C6E798C7E897D5F1A4869E54
8D9E5AD6E1A5D4DCA9EDF6CBF9FFE1FDF9DCD8A999F2C3AFC5C297DBF3B5C0DF99C3E599
C9E79FC9E79FCBE69FCDEBA3CAE8A2C6E49ECAE7A4CAE7A4
C8EC95C8EB97C8EB9BC8EA9DC6EB9EC6EB9EC8EA9EC9E99EC4E298CDE8A3CEE6AAD6E8B6
CEDCB9D5DFC7F8FEF0FFFFFAFFFDFBFFFCFDFFFCFCFFFFFDFBFFFFF8FFFFF6FFFEF4FFFB
FBFFFD868782362C2BC7B3B2FFF6F6FFF2F3E0AFB2593634FCF5EBFBFFF5FCFCF4FFFEFA
FFFDFBFFFBFBFFFBFAFFFCF6EEE2D4E6E0C8D5D5AFE5ECB9D1DD9DDBEDA1D2E895CBE490
C3E296D6EBA6E2E2A6E3D49DA894615B4E1AD2D59CD4E6A8C1E09DC8E5A2ADBC7B737C3B
BBC481DBEBA4BEDF90C5EC9BC7E99CCDEDA1CCEEA1C6E89BC5E79ACAEC9FCBEDA0C8E89C
C9E99DC5E498DDF7ADCFE59CCFE39B8B9C55DAEAA3CCDD96CEE49CDAF0AFCDDFAB051100
5D63477B7F68010300292A0A64673ACCD199D6E19DE7F4AC8D9D5492A65ED4E9A6C9E59B
C8EE99C8EE97CBEC9DCEEAA0D2E7A4D3E6A6D3E6A6D2E7A4D2E9A3617D33A6C579C9E89C
D3EFA5C5DF98D7EDACCCE19ECEE29AD3E89DD4EA9FCCE297D4ECA296AE6486A056A9C379
C5E196D4F0A3CEED9DBBDB88D6F8A4C2E48EC4E690CAEA97D3EEA7C7E09EC6DF9BD1EBA4
D8F2A9BFDA8D96AF5E8DA652C5DF88E1FAA6C9DF94D2E7A6D3E5B197A7802A371DA9B5A1
F8FFF3F0FFE8F3FFE5D8F2C2C7E5A7D3F1A9CAE797CDE695D6EB9CCFE293D5E59A91A359
CCE297C6E295D3F6A6C4E699CEE59DCDE8A1C1EDA0CBF7AAC9E79FCADB97D2DB9A96A260
C3E39ACEF2A8CEE9A2CCDB98A1A1639A9A5CD4E5A1D3EFA5C0E190CDF09ED7F3A6BFD78D
889857D5E0A6E7EFBEE9F2C7F9FFE1FFFFE3EDBEAEFFD6C2D9D8AACBE5A46F93498CAE62
89A25EDBF1B0BED392D5EBAAD1E7A7D5EBABCBE3A5F5FFD1
C8EC94C8EC94C8EB97C8EB99C8EB9BC6EB9BC8EB9BC8EB9BC6E798CCEB9FCDE6A2D3E8AF
CCDDB1D2E0BFF6FFEAFFFFF4FFFCF7FFFAF8FFFBF9FFFEFBFEFFFDFBFFFFF9FFFFF9FFFD
FEFFFD75716E0E0000937B7BFFEAECFACECFBE8A8CFFDFDDFCFFF8F4FFFBFFFFFBFFFCFD
FFFCFDFFFAFBFFE2E8FAD1D5FFE6E0ECD5C3D6D0AED3CFA2C3B682B0A669C1C980DCF5A4
CDF4A5B5D98FD5E1A1D9D89FD2C8939D935E96935ED8E3A9CDEDACD4F7B3CCDC9DBBC183
9DA363D3DE99C3DE91CEEFA0C7E69AC8E89CC8E89CC6E89BC7E99CC9EB9ECAEC9FC8EA9D
D1F1A5C1E094C7E197CBE399E0F4ACD1E29B8A9A53E3F4ADD1E8A0C4DD99CADDA61D2A00
6D74555F61491010009F9E7F4E4F23E5E8B1CDD693C9D58D96A65D8A9E56CEE3A0D6F0A9
C6E796C5E894C6E796C9E59ACCE39BCDE29DCDE29DCDE29DC9E098D8F2A9B5D18649651A
9FBB71CEE9A2C2DB97C8DF9BD9EFA7C4D891D8EEA6D4EAA2B9D088BED58DC5DC9493AD64
8EA85FA6C277C5E194D5F4A6C3E292D6F5A5C8E895CFEEA0CBE69FD3ECA8CBE4A0BFD992
D0EAA1DDF8ABC4DD8CA7C06CA5BF6895AE5ACCE393CADF9ADEF1B9CDDEB16C7A57728164
E0EED4E7F8D8F4FFE3DDF8C5C2E0A2CBEAA4CAE699CFE897CDE293C4D788EFFFB262772A
CDE599D1F0A2BBE090CCEEA1C8E49ACEECA4C2ECA0C0E99DD2ECA5E4F3B0D2DB9A8F9B59
D7F7AEB9DF94C5E39BCFE39EA0A56547490AC9D895CDE79ECBEC9DC8E998C0DC8FDAF2A8
C5D6928B995C727A47E8F4C6F5FFDEFBFADBEBBEABEBBEA7A2A4738AA765769B4EC6E89B
ACC281BACA8CD5E4A9E0EFB4EDFFC3C3D59BD6E9B1E8FBC3
C9EC92C9EB94C9EB95C8EB97C8EB97C8EB97C8EB97C8EC95C8EA94CCEC99CAE69BD0E9A7
CCE1A9D4E5B9F7FFE4FEFFEDFFFFF3FFFCF6FFFEF8FFFFFAFFFFFBFEFFFDFCFFFFFEFFFF
FFFFFD7E76741805078C6F71FFF4F4BE9293A67274FFF1F2FEFDF9F4FDFAFFFEFFFFFBFF
FFFAFDF1D0D7DD9FACCD8791AF7977CCA797F6E1C4B59775A465468B4D28AA8B55D1D491
C1E699D3FFB2CFE8A4D1DD9FE4E5ACC3BC88A19565DADAA6CFEFB0B7DE9BD4E9A8D1DB9C
B1B7778E99549EB368D1E99DCCE69CC8E499C6E599C8E89CC9EB9EC8EA9DC6EB9DC7EC9E
CEF0A3C6E69ACCE89DC9E399CBE198D4E59E4F5F18BFD089CDE59BC9E29ED0E3AC0B1A00
71785960624A0D0B008B88695F5E32E6E6B0E8EEAEC7D18CA6B36DA0B16BC6D999CFE6A2
CEEDA1CDEE9DCEED9FD0EC9FD1EBA1D3EBA1D4EAA2D4EAA2D4EAA2CEE59DB3CA82B4CE85
1B3700C7E399DDFBB3D6F1AACDE29DCFE39EC9DE99D3E8A3DAEFAAE3F8B3D4E9A4C8DF99
687F39728C43708A41CCE69CC6E096BBD78CDDF9ACC4E095C0DC92D4EFA8D6F1ACCCE7A2
C7E19AC3DD93CBE697DBF7A3BCD67F314A00D3EC9BCAE298B9CD90DAECB853643A687853
CDDDB8DDF2C9F4FFDCE0FBC6C6E4A6CCEBA7CEEAA0CBE699DFF4A5D5E899C1D48596AB5E
CEE69ACEED9FBADF91C5EA9DD7F7AEB1D188C9EFA4D4F6ACB8CD88DBEAA7DCE7A594A360
BEDC94C7EBA1DAFAB1C7DE98B2BD7B737C3BD0DC9AD3E9A1C9E598CEED9FC1DC8FD1E79E
CEE29B75834547541CB9C794D9ECBFFFFFDFE9BFA79B7256757745B3D08DC7EC9EC6E69A
BFD49392A065D7E4ACF8FFCDFCFFD1CAD7A1D4E3ACCDDBA6
CAEB94C9EB95C9EB97C9EB97C9EA99C8EB97C8EC95C8EC94C8EB91CAEC95C7E794CFEBA1
CCE4A6D7EBB8F8FFDFFCFFE6FFFFEFFFFFF3FFFFF4FFFFF6FFFFFAFCFEF9FDFFFCFFFFFF
FEFAF97A7071160305886E6FFFF5F4683E3FE8BABAFFEFEFFFFBFFFCFAFFFFFAFFFFEFF8
FFE8F095626BB06D76C0797D783934844C3FD29F8A763E259E543BA156378B4B278D6D3A
BCD38DBCE899CCEBA5CBE09FDEE6ABD3CB9ABAA276BFB383C9E5A8C1E8A5D7EDADCFDE9D
DCE7A58E9B558B9B52C7DC8FD5EBA2CCE69CC9E59ACBEA9ECBEB9FC6E89BC4E99BC8ED9F
C2E497C1E396D6F5A9D0ECA1C8DE95CFE39BA0B0699EAF68CAE49AD4EFAAD3E8AF000900
6C73546C6E560402003D3A1B504D22CDCD97DFE4A4D3DD9894A15B7A8B45DAEDADCCE2A1
C9E39AC9E399C9E399C9E497C9E497CBE397CCE299CCE299D1E79FC3D991E0F6AEB9D088
BEDA908CAA607B9B4F79974DD3EAA4D6E9A7CDE29FD4E9A4BFD491CDE29DCBE09BCFE49F
CFE49FCBE09BE0F6AEB3C98195AC6494AB63C4DB93DDF4ACD4EEA4D2EEA4C2DD96CAE5A0
D6EFABCDE79ECAE598CBE695D0E996C3DC88789140DCF4A8D7ECABCBDEA6D4E6B42E4010
D2E6B5D3EAB6DFF8C1D7F5B9C9E9AACDECA9CDEBA3C8E298C8DD928D9F53798B3FCCE194
CAE598C5E498CAEFA2CCF2A5B9DD93D4F6ACD0EEA6C9E39CDBECA8C8D79497A361CADE99
CAE59ECEEEA5C7E79ED0EBA4D1E5A0ABBA7764702EAFC07ACFE79DD1EBA1D5EDA1D0E69B
D2E69ECADB97C2D294C7DAA2B1C99590976B835E41BC9574DEE1ACCBE6A3C8EA9DD4F4A8
D6EBAA7A884D7A884DA4B277A9B47CBFCA92CAD49FDFE9B4
CCE999CAE999CAE99BC9EA9BC9EA9BC9EA99C8EB97C8EC94C9EE91CBEE92C5E790CCEB9B
CAE5A0D0E8AEEBFFD0EEFDD6F1F7DDF9FAE8FFFFF1FEFFF4FDFFF7FBFEF7FDFFFCFFFFFD
FFFEFF7268690B00008F797BF5D7D7462422FFEBE8FFF5F6FFF8FFFFF7FFFFF5FFFFE9F6
FFE3F3732B36D6A7A1FFF3E6A0605475271AC66D5F752711B68A67CA9A74993D24AC6040
D2D29463883BC7E6A0CDE3A2DEE7AEE8DEADB78F6B977A52C0D39BDDFFC3CBE5A6D1E4A4
CBDF9AD0E19AA4B1699FAD62D5E9A1D2E89FD0E89ECEEA9FCAE99DC5E79AC4E99BC8ED9F
CAEFA1BFE194C9E99DC6E599CDE59BD8EEA5D7E8A183974FD0EC9FCAE8A0CCE4AA000900
6C735465674F060200514C2E5B562EF1EFBCDBDD9EE8EFAB96A35E485915D4E7A7CBE09F
D3E8A5D3E8A3D3E9A1D2EAA0D2EA9ED2EA9CD3E99ED3E9A0D5E9A2D1E59ECEE29DCFE6A0
CCE89ECFEFA3C3E696D1F1A54A641BBFD48FD5EAA5CFE59DDAEEA9E0F4ADC2D68FDDF1AA
DEF2ABD1E59EB4C883DCF0ABCBDC985364208A9B57C8DC95B7D187D8F4A9CDE99FC7E29D
D1ECA7D6F1ACD6F0A7BCD68CC7E293D7F2A189A251B5CD81D2E9A3D9EFAFD1E4AC60733B
D6ECAECAE3A2C6E3A3CEECACC7E7A6C3E29FCCE9A6CFE8A4DCF2AA91A55DCCDE94DFF4A9
DBF6A9CDECA0B9DE91BFE89CC4EA9FD5F7ADC4D994C6D592DEEAA8CFDE9B90A15DC8DD98
CDE49ED8F3ACB8D88FCCECA3CDEBA3CDE49E566220899452D8E9A3C5DB93C8DE95CEE398
CADF94D6EAA2E2F7B2C6E09FD6F5B9CDD9A79F7D5AA6825EC6C992BED795CCECA1BDDB91
D0E7A3BED092B3C5879AAA6C4250154F5A2070783FC5CD94
CDE79DCCE89DCCE89ECAE89ECAE89EC9E99DC8EB99C8EC94CAEF92CAEF92C4E78DCAEC98
C4E298C6E09FD9F2BBD6E9BCD6E4C3E4EED5F2FBE6F9FFF1F9FFF4F9FEF7FCFFFBFEFFFD
FFFEFF7C73740800008B7979D4BCBA9A7E7BFFE8E4FFECEAFFF9FFFFFAFFFFF3FCFFF0FA
FFE6F37B292FDE9F96FFEEDFA65446943225D06457882915C58F6DF0B595B84E3ECE745A
D4C88E7C984ECBE9A3D3E9A8D8E1A8E7D9AAF4BFA0926544D3E0AAC2E6A6C3E0A0CEE7A5
C4DE97D5EBA2CAD68E859147C6D68FCDE199D4EAA1CFE99FC9E89CC7E79BC8EA9DC5EA9C
CBF0A2C6EB9DC6E89BC3E296C7E197D6EEA4B9CD859BB168D2EEA1C6E49CCDE5AB071700
6B72536A6C540703004C47295E5931D2D09DDADC9DD9E09CD0DB97A9BA76B3C686DCEEB0
D2E2A4D2E2A3D0E49FCFE59CCEE69ACEE698CFE59AD0E59AC4D58FD8E9A5DFEFAED8EDA8
C2DD96C8E89CC4E999C8EB9BC2DC92798F47566C245E742B697D35BACE86E7FBB3C3D78F
BFD08ADBECA6E9F8B3DBEAA7D3E29FD4E09E7E8A4A78894599B165C2DE91C7E399D1ECA5
CBE6A3BAD592D2EBA7D7F1AAD3EDA3CAE596D0E89A9AB264C7DF95CAE19BC4D899D9EFAE
D2E9A1CDE79EC7E59DD1F0ACC6E6A3BDDD9CCFECACD2EBAA798E4BB0C47DCDDE97C5DA8F
C4DE94D3F3A7C3E79DC6EFA3BBE599C1E399E0EFACD9DF9F7F88479AA966C2D792DEF5AF
C4D994DEF5AFC3E199C8ECA2C0E69BD5F3ABCCD795A4AA6ACCD896E5F6B2D8ECA4DBF0A5
D8EDA0D0E799CAE49ACCECA3BBE09BD1E3A9A88B63C9A67EF0F3BCD1EAA8D8F6ACCCEAA0
D3EEA7D3ECA8D8EFABD0E5A2D0E0A1D1DD9FB8C084ACB276
CFE6A2CDE6A2CDE6A4CCE7A4CAE8A2C9E9A0C8EB9BC8EC95C6ED92C6ED90C3E78DCCEE98
C5E599C3E09DD0ECB2C7DFAFC5D9B4D8E8CBEDFDE3F8FFF1F8FFF4F6FFF5F9FFF9FCFFFD
FFFEFF75717012090A827775AD9B99D8C5BFFFFAF3FFFCF6F8FFFFF8FFFFFFF7F7FFF3F6
FFE2E6943B3D9D2F30C24B479B251BB14231A73E2B781200BE503FEB7D6EA84130A45A3D
CFBE88DCEBA6D0E7A3D6EBAAE4ECB3F3DEB1FFEAD0AB7255EBEFBDB9DB9ECAE8A8CFECA9
D9F7AFC2DC92E3EFA7B1BB72A7B46EC0D18AD1E79ED0E89ECAE69BCBEB9FCAEC9FC2E799
BBE293C9EEA0CBEDA0CBEB9FD2EEA3DAF2A8CADE96D0E69DCFEB9EC6E49CD3EBB1162600
666D4E7878600701002A23069F9770D9D6A3EBEBADD4DB97DBE6A2D9E8A56F814385975B
D6E1A7D6E1A5D3E3A2D1E59ED0E69BCFE799D0E799D1E69BE0F1ABD0E19DCADA99C9DE99
CDE8A1CBEB9FCFF6A3C4EA97CCE79AC1D78ED2E89FDFF5AACDE2979CB1668EA05690A258
92A25BB9C982CEDB96D7E49FC9D593DCE7A5CCD697CDDC97C1D98BACCB7B8BAA5EB9D78F
DBF6B3C5DF9ECFE8A7CDE6A4D2ECA3C4DE94D6EEA068803292AA5ED5ECA4D3EAA6C7DE98
CEE796D3F09ECAE99DCFEFA6C9E9A6C5E5A4CCE8ABB0CA8B8DA261EEFFBDCBDC96DCF0A8
BFD98FCDEDA1CCF0A6BEE89CD0FCAFD1F3A999A462A5A567AEB474D5E4A1C6E099CDE7A0
DDF1ACCCE09BBDDB93D5FBB0C5F1A4AED288DDE8A6CED393778142D2E19ECDDE97CCE194
C6DD8DD0E998C5E292CDEFA2CAF2A9D7EBAC7F6437A7865BE1E4ABC5DE9ACAE59EC7E59B
C4E69AC4E69AC9E79DC6E097DEF4ACE1F0ABD0D9968B904E
D0E5A4CFE5A4CFE5A4CDE6A4CCE7A2C9E99EC9EA9BC8EC95C2E990C4EB90C3E790CFF09F
CBEBA2C7E4A4D2EEB4C8DEB0C9D8B7DDEAD0F3FFE9F9FFF3F9FFF6F6FFF7F6FCF8F9FDFC
FFFFFF62615F393431C2B8B6AE9F9AB3A29AFFFAF1FFFDF4F1FFF8F4FFFDFBF3F0FFF5F6
FFEEEFE78E92A31F2AA40F15AD1F1BED6B5EBB4B37A1321E9C2414881D0D772D14B28B64
D5D194E5F4B1C7D99FD8E4B2FFFFDCFFFADCFFC6AEB18060CCCF9ADCFBB8BFDF9CC4E8A2
BFE39BCAE8A0D3E49DD6E29A8B9B52B2C47ACFE499D0E69BCAE49ACFEEA2CDEDA1BFE497
C7EDA0CCF2A5C0E597C0E295D2EEA3C4DC90DEF3A8ADC378CFEBA0BDDB95D2E9B12B3A0F
64694B7270590A0400433C1F969167EAE9B3C6CB8BE8F3AECDE19AC3DD96B7D49286A363
90A46791A36590A5628FA65E8FA75D8FA75B90A65B90A65B8EA25BB6CA85CDE19CCFE39E
DDF4ACC3DD93C3E292CDEA9AD3EBA1D4EAA1D2E89FC4DA8FDBF1A6C7DD92CBE095D8EDA2
A9BB6F889A50D4E49DD1DE98DAE5A1E5F0ACD4DD9CD6E69FD3EE9DC3E58F90AF63A8C37E
CCE4A6CEE3A8DCF1B6C6DC9CD8EFA9C0DB8ED2ED9EA7C27390AB5EC8DF99D6ECACCCE2A1
C9E495D4F19FC1E092C2E299C9EAA5CEEDAABFDC9C7E9857D0E6A5BBD08BD9EDA6D5EBA2
CFE9A0C7E59BC8ECA2C9EFA4BAE397C6E49AA5B06ED8DD9BD6E19FDFF0AACCE7A0CFEBA1
C7DC97D0E79FD0F0A7BFE89ABEED9FCCF5A7CEE29DDCE5A4727C3DD3DD9ED7E6A1E3F5AB
C2D98BD3EE9FCCEB9DC6EB9DC0EC9FD0E6A5664B1C9A794CE5E6ACCEE3A0CEE3A0CFE9A0
CAEA9ED0F2A5CBEB9FCDECA0BFD98FD3E7A0E0EBA797A05D
D1E3A5D0E5A4CFE6A2CDE7A0CCE89DC9EA99C9EB97C8EC95C6EC95C7ED98D2F5A5BDDD94
D2EFADCBE4ABC4DCAAD6E6BFEDEFD9F4F0E4FBF9EDFEFFF7FEFFFBFCFFFDFAFFFEF8FCFB
FEFFFF5655530E09058D827CA7968EDBC5BAFFF8EDFFFAEDECF4E5F8FFF8FFFBF5FFEFF0
FFECF5F19FAD880F20F66572A70B0FCF3631E159498A1800A34C30D09A78C1AF87D5DFAA
CEE89FC4DD9BEDF9D1E7E5D0FFFAF3FFE7DFC39F87634C22D7E09FD0ECA1C2E69CC5EDA6
C5ECA9C2E5A3D1EAA6CDE39ADEF3A47F9543ACBF70E4F9ACBED489D9F1A7C7E59BCAECA2
C7EDA2C0E99DC7F0A2C3E89ACAE99BD0E89AD6E79990A256C8E499CDEAA7D0E7B1000800
676A4D6C684F100900413819484518D7DAA1D8E5A0D7EFA5B3D88BC2EEA1BBEFA5BCF0A8
BDE79FCFF3A9C8EAA0C1E196D0ECA2D0EAA0C6E096CCE69CCAE49A9BB56B89A157A7BB73
D0E099E5F2AAE1EBA2CED891CCDB98DEF2ADC9DE99D3E9A1C8E096D9F1A5C8E396CCE798
C8E190D8EF9F6C813493A358B3C176DCE89EDAE49DD4E597CBEC93D4F8A0C2E195B7CD8C
5566304D5B28DBEAB3D1E1A3D4EAA1CDE897CBE993CBE894B1CD83B8D190D6EAB7354914
CAE3A1CCE89ECCE89ED9F7AFBEDC94C2E09899B46D8FAA63D3EDA4C8E299C8E299D3EDA4
CAE59EC7E59FD1F0AAC6E59FC2E09691AB61B0C47DD2E39CCFE39CCDE59BC3DF95C9E89C
CDEBA1CBEA9ECAECA0C1E899B8E394C4ED9ED3F5A9D4EBA3D9E4A24C5212BFCA88D2E19C
CEE49CD1EBA2C7E79CC7EDA2BEEA9FD5ECA8987C4CE1BC8FB8B37BA4B0729EA86BDAE9A8
C5DD93E3FFB2BEDD8FC1E094CCEAA0CEE8A1D4E7A58F9D5F
CFE5A4CFE6A2CDE7A0CCE89DCAE999C9EB97C8EC95C8EC95C8EB99C4E699D3F2ACC5DFA0
D6EDB7D1E4B6CDDFB7D7E2C4FFFCEDFFFBF4FFFEF8FFFFFAFFFFFDFCFFFFFAFEFFF9FDFE
F8F8FA7F7B7A070000887672E1CAC4E4C8BDFFF6ECFFF9EDFFFFF3FEFFF6FFFBF9FFF0F6
FFECFBD17C8F8B1A2CFFAEBCAF1D20A9160FFF7C6D891C05B16649FFF0CFF7E4C3DBE1B5
CAE4A3C9E5A8FCFFE8FFF9F5FFF3FCFFF5FABBA28E63572DD6DF9CD1EC9DC1E699C4EEA4
C5EEAAC2E7A4CFECA9CAE49BBFD688C3D8896E8132BED084D6E7A0C5DB93D4EEA7C2E299
C7EDA2C0E99DC7F0A2C3E89ACAE99BD1E89AD6E79990A256CBE99FCAE9A6D3EAB4000900
707356726E55090200524928514E21DFE2A9CCDB96D2EDA0D5FBAEC5F6A7B4E9A1BAEFA7
BCEA9FBAE093C5E79BCEEEA3CBE59CCCE69DD2ECA2CEEA9FC5E498BBDA8EB0CC7F98B064
83954B98A25BCACD86E6EBA8DEEAA8C9DC9AD3E8A3D6EBA6D1E8A0BCD68CCDE89BD2EEA1
D4EFA0B7CF81B8CD8094A65C67772EC8D58DE5EFAAD0E095C3E48DC1E58DCBE79CD5E9AA
A5B27D899361C1CB96DBE9ACCDE199C3DC8BD0EE98D2EF9DB9D48DAAC286A2B6855A6E3D
C2DA9ED8F3B0C6DF9BCBE69FD1EBA2E8FFBA829C52C1DD92CFEBA0CEEA9FC8E49AD7F3A9
B5D089D3EEA9D7F2ADC3DE998FA65E8DA35ABFD78DD9F1A7D3EDA3D4EEA4CDE99ED2F1A5
C2E296C4E699CCEEA1CDF2A4C7EE9FC6ED9EC4EB9CC0DF93DBE8A3999F5FA5AE6DCEDD9A
CCE19CCCE7A0CAEBA4CDF5ACB9E79CD7EEAA9F8353B994679E976090985CA9AE74D9E3A4
D1E29BC7DF93CAE598DCF8ADC3DE97C2DB97CDDFA17D8C51
C9E9A0C9E99EC9E99DC8EB9BC6EC99C6EC97C6EC97C8EB99CDEDA2C6E3A0E3FCC2DDF1C0
E7F6CFE7F2D2E9F1D9E9EDDCFFFFF4FFFEF8FFFFFAFFFFFBFDFFFEFBFFFFFBFFFFFFFFFF
FFFCFF695E624A3A3BB69E9CF0CECC653E39F7CAC5FFEBE4FFFDF4F1ECE8FFF2F7FFEFFB
FFD8ED620319FFB7C8FFD8E09C29248C1E0FFFB29C91321CC87160FFE8DDFFB6B2FFD2C5
EAEBC1EAFDD0FFFFEEFFFAFBFFF5FFFFE9F0BB9F93544524D8DDA3D2EAA0C2E497C4ED9E
C7F0A4C5E9A1D0EEA6CEE59FD7EDA5D8ECA5ACBD7783944ED3E49ECBE09BD7F1AAC8E89F
C8ECA2C2E89BC9EFA2C3E89ACAE99BD1E89AD6E69B90A258CEECA2B9D996C0D9A2000A00
787D5F7270570701003B35135A5629BDBC84DDE4A1C4D48BC2D991C9E9A0C3E8A5CAEFAC
D1F0AACAE59ECEE59FD5EAA5D2E69FCCE099CFE59CD4EEA4D6F5A9C8EA9DC7E899D0EFA1
DBF3A7CEE39896A35B4E5B1544551190A45F809550D1E6A1D9F0AAC1DB92D8F2A9C0DA91
D9F0A8BFD68ED2E6A1DFF0ACB1C07F556121CFD79BD4E3A0D1EE9EC8E998D6F0A7D8EBAB
DBE6ACC6CF98A5AE75D1DD9FDFF0AACCE297D4EFA0D4F0A3CFE9A2C2D89A7688544F612D
CEE3A8DAF3B1C9E09CCAE49DD6EDA5BFD990859D53DCF6ACC7E295CAE598CBE59BC9E39A
D8F2A9CFE9A2BFD992B6D089AFC67EC1D98FDCF4AAD4ECA2C7E197CAE49AC4E095C6E599
CCEB9FC7E79BC6E69AC7E99CC8EA9DC7EC9ECCF1A3D6F2A7D1DE99D2DB98ACB773B5C680
D1E6A1D4EFA8C4E59EC0E89FC5F3A8B9D28E8C7241603B0EE6DFA8D4DEA1B5BD81212B00
9AA762D0E19ADBEFA8C6DB96D0E5A4E0F2B4C8D59DA1AA73
C5EC9DC5EC9DC5EC9BC5EC99C5EC99C5EC99C6EB9BC8EA9ECDEAA7C9E2A8F6FFD9F7FFE1
FBFFE9FCFFEEFFFFF6FDFDF5FFFFFAFFFFFAFCFEF9FBFDFAFAFEFFFBFFFFFEFFFFFFFEFF
F9F2F9817277927C7FFFF6F8FFE9EA6C3E3EB5827FFFF3F1FFF7F4FFFDFBFFF7FDFFD6E0
FFE9F8D88C9968161CD5807D7E2F20AB5F48FFD0B789422C6F25187E302E79282FFFD1D3
FFFFE6F4FFE1FFFAF0FFF8FDFFF3FFFFEEF8A88B8787775EDFE1B0D7EAA8C3E495C5EC99
C8ED9DC6E89CD2EDA8CDE3A2D3E5A9CAD99ECEDCA19EAC6F717F41E0F3B1B8CF89CAE89E
CAECA0C2E99AC9F0A1C5E898CCE89BD1E79CD8E59D90A15ACDEBA1C7E8A3D7F2BB000A00
5F68496D70551E1A00D7D3B0A5A1748C8952EDEFAEE7EEA8CCD994DAEBA7D1E5A6CEE2A5
CEE19FD9EAA6CFDB99CAD694DAE7A2D2E19CC8D993D6EEA4C3E397C1E698C4EB9AC1E696
C0E192CFEB9EDBF1A6D1E59DD7EBA4E3F7B2DBF0AB869B56CEE5A1C8DF9BCAE19DD1E7A6
CCE2A1D4E8A9DBEAAFC1CE96DCE6B1EDF6C1474E1BDBE8B0C7E09CCCEAA2CFE6A2C0D091
D5DFA3DCE4A991995E95A163D3E3A2CFE49FC9E39CC9E29EC9DF9ED2E6A96F81471E3000
DDF1B4BBCF90E5FAB9BCD18ED7ECA7566D25C4DA91CFE79DC9E195DEF9ACB8D086D3EDA3
D4EEA5BCD68D637D348CA65DCFE79DD9F1A7D4ECA2C3DB91C5DF95D1EBA1CDE99ECDE99E
D1EDA2CDECA0CAE99DCDECA0CFEFA3C6E69AC0E094C9E399DDECA7E2EDA9D0DF9A99AD66
D0E7A1DAF8B0BFE39BB7E197CAF8ADDAF3AFAA905FBF9D6FDED9A1D4E0A2D7E3A5CDD999
C7D290626F2A8D9C59D6E6A7D1E1A3D9E6AECFD6A3A1A573
C1EE99C1EE99C2EE99C2EE99C2EE99C3ED9BC6EB9DC9E8A2C9E3A6CCE0ADF9FFE1FCFFEA
FFFFF3FFFEF9FFFDFFFFFEFFFBFBF9F8FDF7F8FEFAF9FFFDFAFFFFFBFFFFFCFFFFFFFEFF
FFFBFF15040C60454CFEDBE1FFF1F6956366B67E81FFE9EAFFF2F1FFFEFCFFFCFDFFFBFA
FFFAF6FDE2DB9C7B6C79533E80573BC99E7EFFE4C6FFDCC2DFBEADA98C84A28A8AFFFBFA
FFFFF4EDEDE1FFFBFAFFF7FDFFE5F3FFF2FFA48489FBE7DCF2EFCCE6F3BBCBE79CC9EB97
C7EA96C5E498D0E9A7CBDEA6CFDFAED7E4B6D7E3B3DFECB7919F64CADA9BD3E8A3D8F4AA
CBEC9DC3E898CAEF9FC5E898CCE89BD1E79ED8E5A091A05BD3EEA7C0E19CC8E3AC000F00
6974546E74580303009E9B78CECC9C67652C979656D2D38FE3E5A4D3D596DCDFA6D6DBA1
DBE1A3DBE1A1E1E6A6E3E8A8DEE3A3DEE7A4D7E6A1C4DB93D4F4A8C5EC9DC3EC9DC7F0A1
C7EE9DCBEE9ECCEB9DC6E194C9DF96C9DD969DB26DB7CC89CFE4A3D7EBACCCE0A3CDE1A6
D6E9B2D6E7B3CDDAACD9E4B9D2DAB1C2C9A0A0A47FCAD3A8CDE2AADAF2B6CEE0A4CFDA9E
D7DFA3E3E9AB999F63707A3ED2E0A5DCEEB4CCE1A8D8EDB4C3D79CD3E5A9A2B073243200
CFDEA3D4E6AAC8DA9CE1F4B48396548A9F5AD0E49DD4EAA1CFE59AD5EDA1D4EA9FD2EA9E
C6DE94AFC77D849C52A8C076C8E298CEE89EC6E096C7E197D2ECA2D4EEA4CFE99FC9E399
CBE59BCBE79CC1DD92C1DD92CEEA9FCDE99ECBE79CDAF2A8D3E49ED2E19CD4E59FB3C981
BED88FBADA8FC3E79DD6FFB4AEDC91BFD894957E4ACFAD7DE0DFA6D1DFA1CFDD9FE2EEB0
E7F0B14F5819899356E5EFB3C8D39BD4DCA9E0E1B5B6B38A
C1EE99C1EF97C2EE99C2EE99C3ED99C5EC9BC8EA9EC9E8A4CCE5ABD0E4B3F9FFE3F8FFE8
FFFFF4FFFBF8FFFCFFFFFCFFFCFEFBFAFFFCF9FFFFF9FFFFF9FFFFFBFFFFFBFEFFFDFCFF
F0E9F06F606721080E97777CFFEFF3FFF0F49B6469D1A7A9FFFCFAF5F7F2FCFFFAE7EDE1
FEFFF1F0F2DAFFFFE3E1D9B5F7E9C2F0E1BAE4D4B2FFFEE3FFFFECF5F2E9FCFFFFF7FBFC
FFFFFDFFFCFBFFF9FAFFEFF3FFDFEAB8929FD8B7C2FFF9F8FFFFEAF6FFD2D5ECA8CCE999
C8E797C7E399D5EAB1D1E1B4D0DEBAC6D2AEDBE6BED8E1B4E3EDB99BAB6DB0C47FC3DD93
CCEB9DC5E896CCEF9DC6E796CDE79DD2E69FD8E4A291A05DC9E39CC7E4A1CFE8AF021800
596746636E50080D00AAAE89E0E2B1B9B87F61612172712EA4A362999558E1DCA5E1DEA7
A3A3678E9051C2C083E4E2A5C7C789D7DD9DF0FDB8C6DC94BFDE92BDE495C9F4A4CFFAAA
C2EC9ABFE695CBEE9ED4F0A3D2EA9E51651DA1B76FBACF8CD8ECADD0E4A9CDE0A9F8FFD7
F7FFDAF0FCD4FCFFE3EAF1D0FFFFE64C4F34B2B298FFFFE6F7FFDFF3FFD7D0DCAAE1EAB3
D8DEA2D4D89DA1A46B878E58FDFFD7F1FED2C7D8ACE2F3C6CFE0ACD6E3ABD0DA9D384203
D6E1A7E4F1B9F3FFC8ADBD7F94A465CCDC9BD8E9A3D1E59DCDE199C8DE93E3F9AECEE499
879D52BCD48AD3EBA1D8F0A6CCE69CD2ECA2CDE79DD4EEA4D0EAA0C7E197CDE79DC6E096
CCE69CD8F2A8CEE89EC8E298D8F0A6D2ECA2C6DE94CAE298C4D89198AC65657B33C4DB93
DBF7ADDCFCB1CDF1A7B0DA8EC9F7ACD3ECA8A7905C6444139091577E9151C9DC9CCDDB9D
CED69A8A9054ACB479D0D9A2D4DCA9FFFFD8FFFFDDDDD7B5
C5EC9BC5EC99C5EC9BC5EC9BC6EB9BC8EA9DC9E99ECAE7A4D0EAADD1E5B2E8F7D0E3EED0
FCFFEFFEFFF6FCFDF7FFFFFDFCFFFDFBFFFFF9FFFFF9FFFFF9FFFFFBFFFFFBFEFFFDFEFF
FFFDFF7C71770D0000876C71FFF5F8FFE0E4A87B7EA88685FDF8F2F9FFF8EBF6E6E3EFD9
E0EDCFEDF9D3EBF4C9CED6A5CFD3A1D2D4A5E8E8C2FFFFE4FBF9EAFAFBF5FEFFFFF7F6FC
FFFBFFFFF9FDFFF8F8FFE1DFDEBABE7E5961FFEAFAFFE8F0FFFDF4FDFFE1D7E9AFCFE69E
CFE9A0D4EAAAE6F7CAE5F3D2F0FDE3E9F3D8EDF6D7F7FFD8E5EEBFD4E2A78E9E5DD2EAA0
CCEB9BC5E894CCEF9BC6E796CDE79DD2E69FD8E4A491A05FD9EEA9D2EBA9CAE1A9152800
6E7E5A707E5D000700535E34D3DBA8E8F0B48489465457126364225E5C1F99945D97945D
58571E5354187F7D42A8A66BA4A466A9AE6EC7D28ED6EAA3D3EFA5C8EDA0C4ED9EC0EB9B
BEE798C9EEA0CCECA0C0DC8FAEC67A8BA15699AF67E6FBB8D1E3A7CBDCA6D3E3B4FBFFDF
FCFFE3F4FADEFCFFEAFFFFEDEEEFDDABA99AD6D4C5F6F7E7FBFFEDF9FFE8D4DCB5E3E9BB
DBDEA9D5D59FA6A876BDC397FEFFE1F8FFE3CAD7BBD4E2C1D2DDB5D0DAA6D3DB9F3D4607
DCE5B0F2FCC8FAFFD0A9B67EACBA7FEBF9BBCDDC99D2E39DD1E29BDDF2A7C2D78CC2D98B
556C1ED2E89DBED489CAE296C9E399CCE69CC8E298D2ECA2C8E298C9E399E1F9AFCFE79D
BBD389D9F1A7D6EEA4CAE298D1E79EB9D1878CA259798F4690A65D99AF6698B066E3FDB3
C7E399BEDE93BDE197C8F2A6BBEA9CCFE9A2937C48886A387A7E416E8340A0B773D3E6A6
DFE9AC737B40909962D9E3AEDDE6B7FFFFDCFFFFE1CBC6A8
CAE99DCAE99DCAE99DCAE99DCAE99DCCE89DCCE89ECCE7A2CFE8A7C8E0A6D1E5B4CADBB1
F6FFE3F9FFECF5FFEBF9FFF4FBFFFAFAFEFDF9FFFFF8FDFFF7FFFFF8FFFFFBFFFFFCFFFF
FFFEFFEDE8EC0700001002028A7476FFF7F8FFF6F6CBADABAD918EFFF2E8FFFCEADEE5C6
D8EAC0C0DBA6CFECB2CCE8ABD4E9B0D7E5B2F6FDD4F0F3D8FFFFF3FEFFFBFBFFFFFFFEFF
FFF9FFFBE4EAFFF7F3FFF2EA957371D5B2B6FFEEFDFFF6FFFFFBFDFCFBE9D7E3B5D0E4A7
D6EAADE0F2BEF8FFE7F9FFF1F3FFEBF5FFE9FCFFEAECF4CFD3DAAEDCE7AFACBC7BD0E69D
CEEB9BC6E894CCEF9BC6E796CDE79DD1E6A1D6E5A4939F5FCBDC98D3E6A4C6D9A20B1C00
53633F606F4E05150066774BD2E0ABCEDC9EE0EDA7DEEAA0D1DB94BAC17E9A9E63969960
909459A8AC6F929357909054A3A5667277376A7533C4D891CDE79ECBEBA0C8EDA0C2E99A
C5EA9CD2F2A6C0DC9196AE628CA456D7EDA2D5EBA3C3D897D1E3A9D6E4B3C9D5ADFCFFE4
CBD1B7C4C7B4D6D8CAF7F7EBC8C5BCFFFAF4FFFBF5FFFFF8F3F8F1FCFFF4F5F9E0FFFFDF
FFFFD8FFFFD6CCCAA3FFFFDEF2F7E0FCFFF1F9FFF2E0E9D4DCE3C4D8DEB2E2E5AE64672E
DAE0B0E0E7BBEDF5C6BCC692CBD5A0CDD89EDCE8AAD7E6A3D7E8A2C8D992D9EEA3768B3E
C9E092CDE496D7EDA2CFE79BCEE89ECDE79DC9E399D3EDA3C6E096CAE49AD8F0A6A9C177
96AE64A9C1778FA55C738940869C5392A85F899F568CA259D4ECA2C4DE94DDF7ADC3DF94
C2E096DDFDB2BEE298C3ECA0BAE99BD8F2ABB8A16DBA9C6AE6ECAECFE8A4BED793889F5B
ABB97BC3CE94CAD79FCFDCA7D8E4B6D8E0B9D4D5B5D3CFB4
CBDE9CE2F5B3CCE09BD2E7A2CEE49CD1E79ECAE199D2E9A1CFE9A2CDE6A4CAE4A5C9E2A8
D6EEBAE3FDCDE0FCCCDAEFCEFCFFF8FFFFFFFEFFFFFCFFFFFBFFFFF9FFFFF9FFFFF9FFFF
F4FAFAFCFFFF30322F040300827D79FFF9F4FFFCF6F4D2D0BD7078FFB6BAFFEBDBEEE4C1
C2DDA6B7E9A4BBF3A8BAEEA4C1E6A3D4E6B2EDEFCAFFFBE2FFFFF2FBFEF7F3FFFDF9FFFF
FFFAFFFFEDEEFFF8EDC1A597D4B6ACFFE5E3FFF5FFFFF4FFFFFAFFFBF8F1F1F8D9EBF8CC
ECF9CDEFFAD8F6FEEFFBFFFAF8FFF4F5FFEAF6FFE5F0FAD5D6DFB2D7E4AC8F9F5EC8DE95
CEEB9BC7E995CDF09CC7E897C1DD92D9EEA9CDDD9C909C5CCDD997D8E4A4E1EEB9162600
717F5B637450000A00697F50CFE7ADCBE4A0D1E99DCDE597D0E69BD7EBA4D2E5A5D6E6A8
D4E0A2DCE6A7DCE2A4D9DFA1E0E4A7999F5F4A5614D7E8A4D5ECA6C9E59BC4E499CFEFA4
C8E499E2FAB0D1E29B46580ED8EF9FC6DE90D3E9A1D7ECABC0D19BD1DEB2DBE5C2BFC5AB
B2B5A4C3C3B9EDEAE3FFFBF8F2EDEAFFFCFDFCF3F4FFFDFEFCFCFEFBFDFAFFFFF4FFFFEC
DAD7B8B0AD8CE9E5C8FFFFECFFFFF6F7FCF6FBFFFBE7EDE3DEE2CBD8D9B7D7D6A6646432
DBDDB5E7EBC6D2D7AEB4BB8FC6CE9DDDE7B2D6E1A5D5E4A3D1E29EDEEFA8A2B76C9DB267
CCE395D2E99BCBE395CCE498CFE99FC8E298CEE89EBDD78DCCE69CD9F3A9A9C17793AB61
96AE64ACC47AC8DE95D5EBA2D3E9A0CDE39ACEE49BD1E99FD1EBA1CDE99ECAE69BC8E79B
C9E89CC9E99DC8EA9EC3E99CBDE99AD0E79FA28B55C7A975D5DB9DCEE7A3C8E6A0D4EFAA
B0C584CADE9FD5E9AED6E8B4CEDFB2D5E1BBDEE3C5C3C3A9
E5EFB3BAC48797A365C6D292DFEEABD6E7A1D8ECA4CCE299CBE399D1EBA1CEECA4D1F0AA
CAEEA8C1E6A1C5ECA9CAE6B6FCFFF4FFFEFFFFFEFFFEFFFFFCFFFFFBFFFFF9FFFFF8FFFF
F8FFFFF6FFFBE2EBE6707770030801EBEEE5FAFCF1FFEDE6FFBCBFBD625FBC826EE2CBA2
DDE8ACC3E9A0C3F4A5BBEBA1C9EDADD7EEBAEBF3CEFFFDE6FFFFF3FFFFF8FEFFFBFBFAF8
FFF8F9DCC0BDC2A89BA48A79FFECDFFFF9F3FAE5EEFFF5FFFFFAFFFFFCFBFAFDEAF6FFE2
F7FFE5F9FFECFBFFFCFBFFFDF5FFF0F7FFEAF4FFE1EAF5CDD6E2B2C6D49999A968D6ECA3
CEEB9BC5E793CCEF9BC9EA99C5E196D8EFA7D0E3A1A0AF6EDBE6A2DDE6A7C7D19C273207
606C4865755100110092AA7AC8E4A9CAE8A2CCED9EC5E695C5E697CBEBA0C6E5A1C4DE9D
CFE2A2DAE9A8CAD495D4DD9ED3DC9D959E5F788442C9DA96C8DD98DBF5AEC9E59BC3DD94
D6ECA3BECE87C3CD889CA860C7DC8DD4EC9ED0E69EC4D698E8F6C3CBD6AE898F73CFD2BF
FFFFF6FBF7F4FFFDFDFFFCFFFDF4F7FFFCFFFFF7FAFFFCFFFFFDFFFDFCFFFFFEFBADA99E
B9B2A0FFFFECF7F4E3FBF9EDFBFCF7F9FDFCFBFFFFFAFFF8F1F4E1EAEBCCE5E2B7838055
DBDBB9F2F5D6B5B996B3B890FFFFDAD3DBAAD0DBA3D8E6A9C9D998A5B972849850B3C97E
CEE499CEE698D2EA9CD1E99BD4EEA4C7E197DDF7ADCCE69CCFE99F8CA65C657D33CFE79D
C3DB91CAE298D1E99FD3EBA1D1E79ECDE59BCEE49BCDE79DCAE69BC8E79BC8E79BC9E89C
CAE99DCAE99DC9E99EC5EA9DC8F3A4C9DF9799804AA68854D7DD9FD2EDA8CAE9A3B5D48E
CBE6A1CEE8A7D7F1B4EBFFCBEFFFD6F8FFE1F9FFE3C9CBB3
D9DEA6A7AC745D62285D6529616C2A7F8C47CCDC93D1E699CAE193D3EE9FC6E595CEF4A1
C5EF9DB3DE8CC3F09FC6E8ACFCFFF3FFFDFFFFFDFFFFFFFFFEFFFFFBFFFFF9FFFFF8FFFD
F0FDF6F7FFFBEDFAF1E9F6EC000B00000400F1FCEEFFFFEFFFF7E4F0C1A7A87D5B6C4A1D
BBA66FECE4A6D8DD9DCCDC9DDAF1B9E7FFD1F5FFE4FBFFEDFFFDF1FFFAF6FFF6F8FFF1F5
BFA19F664B44D2BBABFFFBE8FFF5E6FFFAF2FFFAFDF8ECF6FFFBFFFFFDFFFFFFFAFEFFF4
FEFFF6FCFFFAFCFFFFFAFFFCF1FFE7ECFFDAD3E4BACADAABD9E6B1C9D79A9BAC68CAE097
CEEA9DC3E493C9EC9ACBEE9CC7E69AD5EFA6D5EAA5B8C985E2EDA9C4CD8EE6EDB9151E00
636D4A7B8966000A00586E3FC6E2A7CCEBA5CDF0A0C7EE9BC8EF9ECAF3A5CBF3ACC8EBA7
CCE5A3D6E9A9CDDB9DDCE8AAA2AB6C525C1D939F5FD8E8A7CFE49FD1E8A2CEE59DD1E79F
DCEBA6E7F2AE848947DDE4A0CBE093DFF7A9C7DC97D9EBAFD9E6B88F9976B2B69FF0F1E3
FFFEFAFFFCFFFFFCFFFFFBFFFFFBFFFDF2F6FFFBFFFFF9FDF6F3FCFFFDFFABA6AAD0CBC8
FFFDF8F3ECE4FFFEF8FFFFFAF9FBF8F7FDF9FBFFFDFCFFF6FFFFEFFBFCDDE2DEB8908C66
D9D8BCFAFAE2DFE2C5D2D6B5FFFFDFD4DBAFD1DBA7D3E0A8E6F6B792A563859952DDF3AA
D5EDA1C9E497CDE899C8E394CDE79DD6F0A6B6D086DDF7AD8EA85E455F15D5EFA5C2DC92
D2ECA2CFE99FCBE59BCAE49ACEE69CCEE89ED0E89ECCE89DC6E597C7E899CBEA9CCBEA9C
CCE89DCBE79CC8E79BC7E79BC3E99CD3E7A0BFA46FAB8B58D4DD9CC4E29AD5F7ADCBEDA3
D2F2A9C4E39FCDEBABE8FFCBEFFFD7F7FFE1FCFFE8C4C8B1
D5DAA4B7BC848F945AD6DCA0B4BD7E7C8743A0AD65D7E99DD1E89AD8F3A2BFDF8CC8EC95
C7F19BBEEC94CFFDA5C4E7A7FCFFF1FFFDFFFFFDFFFFFEFFFEFFFFFCFFFDFBFFFDF9FFFB
E9F4ECF8FFFAF8FFFAF1FDF12D372C0007007B8678EFF7E2FFFFE0ECE5B9E4D4A3816A36
62440E7C5E28AC925FC9B787FFF6CFFFFFE2FFFFECFFF7EDFFEAE8FFD5D8E8ABB3BF868D
AA8785CFB6AFFFFAEFFFFCEFFFFDF1F4EBE2F2EAE8FFFDFFFFFDFFFFFEFFFFFEFFFFFFFF
FFFFFDFEFFFFFBFFFFF2FCF1F0FFDFE2FAC8CADEABC9DCA5DDECB1E3F3B499AD68CEE59D
CCEB9DC2E595C5EA9ACAEF9FC8E99ACEEDA1D5ECA4CADE97919C57DCE5A4CED5A1656C40
606745727C5A17230067784BC8E0A6C8E6A0C2E394C4EA95C1EB97BBE696C2EEA3C5EAA5
CEE7A5DAEAABDAE6A8D1DB9E929B5C848D4ED8E4A4CFDE9DDBEFAAC5DA95D0E5A0D9EDA6
D2E19CD0D996828443E1E8A4DAEFA2CBE699CDE49ECFE1A7C6D3A799A07FFFFFEDFFFFF4
FDF5F3FFFBFEFFFBFFFFFBFFFFFBFFFFF4F8FFFCFDFBF2F3EAE8EDACAAAFFBF6FCFFFDFF
F8EFF2FFFCFFFFFDFFFFFFFDFCFFFBF5FCF4E0E8DBEBF2E0FCFFE7FEFFDFCBC5A18C8664
92907BF2F1DFAAAC96FFFFE8FFFFE4CDD5AEE5F1C3C4D29DD2E4A8829756819651D9F0A8
CAE49AC9E598CDE89BCCE79AD3EDA3BDD78DD1EBA192AC627C964CC7E197C7E197D7F1A7
C9E399C7E398C6E297CAE69BCEEA9FCFEBA0CCE89DC7E69AC9EA9BCAED9DCDEC9ECBEA9C
CAE69BC9E59ACAE49AC9E89CC8EDA0C6D791AE905C9F7F4CD7DD9DCCEAA2CEF0A6BEE298
C7E99DBCDE94C3E6A2D3F2B6CDE8B5EEFFD6FEFFE8BBBDA5
E0EBB1D0DB9F929C60E4EEB1D3DD9EA9B6718D9D56B6C87ECADF94DBF3A5CCE999C8EA96
C6EC99C4EE9ACFF9A5BEDE9FFCFFF1FFFDFFFFFEFFFFFEFFFFFFFDFEFFFBFCFFFBFCFFFA
FCFFFAF3F9EFEAF0E6BBC1B5D7DACF0002002F312678826AC7E2B5B9D89DE0F4B7DBE4A5
D5CB90AF95629B7149A56F53611F13994E52C47280BC677AA85164B1586CD57D8DE9A0AB
FFE5E5FFF0EBFFFAF6FFF6F2FCF4F1FFFDF8FFFFFAF6F7F1FEFEFCFFFEFFFFFCFFFCFBFF
FEFDFFFEFFFFF9FEF7EEFAE2D4ECBACDEAAAD1E9ABD2E8A8C8DB9BDEF1AF8A9F5AD5EFA6
CDEBA1C5E79AC4EB9CC8EF9EC7EA9AC8E99ACFEA9DD2E89DACBC75AAB573B7C08B252C00
767C588389672B310D5D693BD9E8AFD8EDA8C9E495D1F19ECBEE9CB8DF90C1EBA1C6EAA4
D9EEADBECA8CD9E1A5E8EEB2A8AC71A1A76BD7E1A2D8E7A6D3E6A4CBE29CD6EDA7C6DB96
B7C882505D18D3DA97D5E09BD5EC9EBBD689DCF3AF8A9B64EAF5CBFDFFE4FDFCEAFFFFF6
FFFDFBFFFBFFFFF7FEFBEEF5FFFBFDFFF4F4FFFCFAD4CCC9C1C0BCF2F1EFFFFBFFFFFCFF
FFF8FFF9F2FAFFFDFFFFFFFDFCFFF8F5FFEDCBD8BED9E4C4EBF1CDF4F6D1B8B28EA19A7D
040100A8A89CC1C2B2FFFFECEFF3D8FEFFE3D7E2B8DDEBBACEDFA8A2B677A1B874CAE49D
C5E197CCEB9FCBE79CCDE99ED4EEA4CCE49A9DB56BC0D88EC1DB91DCF6ACD1EDA2C5E196
CBE79CCBEA9ECDECA0CDECA0CBEB9FC9E99DC6E69AC5E599CAED9DCAED9DCBEA9CCBE79A
CBE699CCE79AD0E89ECFEBA0D0F2A5C8D891B0915BB1905BD6DC9CCDE8A1BFE197C2E79A
C6EB9DC4E99BCCEDA6CCEAACC6DEAAF2FFD7FFFFE6B4B299
C7DA9AD0E3A3A0B071C8D897CFDE9BE8F7B4ADBC7790A15AABBC75C4D890D7EFA5CFEBA0
C6E599C8EA9DC8EDA0CAE6ACFCFFF3FFFEFFFFFEFFFFFFFDFFFFFBFFFFFAFFFFFAFFFFF8
EFEFE7FFFFF6BBB8AF9B978EC1BAB2140D05070000000300829C6DB6D89CB9D696C4D797
EAEEB1E0D39FE0BC98FFE9D5DD9394E08999DC8099DD809BEE9AB1FFC0D0FFDCE5FFE8EA
FFF1EEFFF9F7FFF7FCFFF5FDFFFEFFFEFFFDFCFFF8F6FCF0FEFFFAFFFFFFFFFDFFFCF8FF
FEFDFFFEFFFFFCFFF1ECFAD6C8E5A5BCDE92CAE69CCFE9A0C2D890D2E7A290A761CAE59E
CAEAA1C6EB9EC5EB9EC3EC9DC6EB9BC6E997CBE898D2EA9CD3E89DB6C5826D7840535A2E
7478553A3B1B0304006F7247C8CF99DAE6A4D0E296DAF1A1D4F1A1C5E599D0F4ACC7E4A1
93A16383874CA5A66CB3B27979783F97985EBFC587E6F2B2D1E4A2C3DC98DBF5AEC6E099
92A86054651FECF9B4D2E29BCAE294D2EDA0D0E7A380915AF8FFD9FFFFE8F8F6E7FFFBF5
FFFAFBFFFBFFFFF8FCFFF5F9FFFBFBFFFCF8FAEFE9C1BAB0F2F2E6F6F8EDFCF8F7FFFCFF
FFFAFFFAF2FFFEFBFFFEFFFDF8FFF0F9FFEACDDCB5D8E5B9DDE4B8E8EBC0B1AD87D0CBAE
100E01787870A9A99DFFFFEFF6FBE4EBF4D5FBFFDFD1E1B2DAEDB6C4DA9CCAE3A1C8E39E
CAE8A0D0EEA4CAE99DC7E69AC3DD93CEE69C89A157D0E89EE9FFB9C7E197B8D489D5F4A8
CBEA9ECBEB9FCBEB9FC7E99CC4E699C2E799C6EB9DCAEFA1C8EB9BC7E899C6E597C9E598
CFE79BD2EA9ED3E9A0D0EAA0D0F0A4D0DD97C6A570C4A06CD9DE9EC9E49DBFE197D8FDB0
C8ED9DCBEE9ECAECA2CBE8A8D0E7B1FBFFDDFFFFE1AAA48C
D5F0AB97B26D9DB672CEE59FCEE39ED3E7A2C2D38FC2D38FA6B773AABB77D1E5A0D1E6A3
CCE39FD1EAA6C7E29FE4FBC7FCFFF3FFFFFFFFFFFFFFFFFDFFFFFBFFFFFAFFFFF8FFFFF6
FFFEF6FFF7EE958880BEAFA8EFDED726130D210C070D0000736D4B6A6C3B6D743ED2DCA0
DDE7ABDADDA8ECE4BDFFECD4FFEDE9FFEBF3FFEDFEFFF3FFFFF7FDFFFEF8FCFFF3FBFFEE
FFFCF6FFFAFDFFFAFFFFF8FFFAFAFFEBF0F3EFF9EEF9FFF3FCFFF6FEFFFBFFFDFFFDF9FF
FFFEFFFEFFFBFCFFEAE7F9C9D6F6ABC4EA95CBEB98D3F0A0D6EEA4C2D890BCD38DCCE7A0
C7E79EC9EFA4C5EEA0C1EA9BC6ED9CC6EC99C8E895CDEA98CDE599CCE09BC9D69E040D00
7172509E9D7E3833134E4B22999764D0D293D0D88FD1DF92CCE194CBE399D1ECA7A8BD7C
4C511788854E817C445F58215A531CE2E0A7EDF1B4CCD697D6E9A7C0D995D3F1A9CEECA4
8DA861C0D791C7DB96D2E69FCAE598DDF7ADACC281B3C48EE3EEC6E1E5CAFAF8E9FFFEF8
FFFAFBFFF9FDFFFAFFFFFAFDF4E6E5F8EBE5EEE4DAECE6D6F6F8E2FFFFEFFFFFFAEFEAF0
FFFBFFFFFBFFEEEDF5FBFFFAF3FFE7F8FFE1CCDEACD7E8B1D6E0ABE2E6B4A6A37AE7E2C5
E8E6DA2E2D2883857AFBFDEFFEFFEDF6FFE2F8FFDECEDEB1C1D39FA0B57AC4DD9CBFDA95
CBE9A1C9E99ED2F2A6CAE99DD0EAA08FA55CB0C87EDAF2A8BAD48ABED88EDFFBB0C7E69A
C6E69AC5E79AC4E699C1E698C1E899C3EA9BC7EE9FCAF1A2C6EB9BC5E695C5E496CBE699
D3E99ED3E99ECEE29AC6DE94BDDC90A2AD6895743F8C6834D5DA98D5F1A7C5E79BBDE294
C5E896CAEB9AC5E59ACAE4A3D2E5AEEBF4C9EDEACBB3A990
CDE2AA798E55BBD095D7EDADCEE3A0D1E6A1DCF2A9C6DA92C3D78FA2B66FC7DB96CBE09B
D0E5A4D7EDACC2D898F0FFD2FBFFF3FEFFFFFEFFFDFFFFFBFFFFFBFFFFFAFFFEF8FFFEF6
FFFBF4FFFCF4867770E6D4D0FFF6F2B7A29F56413E15010095856CBEB490838057C2C596
D2DAA9CDD6A9DBDCBAFFFFEAFFFCF4FFFAFBFFFAFFFFFDFFF9FFFDECFFF5E5FFF1EEFFF6
FFFFFBF4E9EFFEF6FFFFFEFFF1F7F7F3FFF3F7FFEDEDFEDEF6FFE9FBFFF3FCFFFFFCFDFF
FEFFFFFEFFFAF8FFE8E3F4C7C2E297C3E992CDEF9BCDE899CEE49B8BA159CDE49ECDE7A0
C5E49ECCF0A8C8EEA3C0E99BC8EF9ECAF09DC8EA96CCE999D2EDA0D3E8A3DAE7AF242A00
75724F948F6F2A240276734A8C8F5ADDE3A5E3EEA9D6E69BD3E39ADBEBA4D9E8A5929C5F
7E8349C6C990B0B178AAAB71909157DFE3A6D5DE9FD6E5A2D1E6A1D4EEA7C7E59DC0E097
AAC580DDF6B2C3DA96D5ECA6CEE89EC2DC9293A968CADBA4DFEAC0E3EACBC6C8B3FFFFF4
FFFDFAFFF7F6FFF9F8E5D9D99F9490A79C96C2B9B0FFFFF1FFFFEFF3F5E7FCFBF7FFFCFF
F8F0FDF5EDFCFFFDFFFEFFFAFBFFEDF8FFE1C4D6A2D2E4AAD3E1A6DEE7B0959766DDDDB7
FFFFEA666A59A5AA94E1E9D1F9FFE6F7FFDFF9FFDFCFE1B1CEE0AC93A86FCBE4A3CEE9A6
D4F2AAC1DF95D0F0A4C1DD92CEE49B92A65ECCE299C3DB91DAF4AAD1EDA2CAE99DC5E498
CCEB9FCBEB9FCBEB9FCCECA0CBEDA0C8ED9FC5EA9CC2E799CDEC9ECBE79ACBE399D0E69D
D5EA9FD3E59BC5D991B7CF8588A85C798640876631674110C5C587C7DC97D5ECA8CCE89E
C5E494CCEE9ACAE99DCEE7A3CBDEA6D3DCAFE2DFBECBC4A8
ADAF9AB9BBA3FEFFE3FCFFDAD8E7ACC3D991D3EE9DD1EF99CBE993B8D5817C9947BDD88B
D9F0A8D2E9A3D2E7A4CCDCABBFCAB9FBFFFFFAFFFBF3F5F0FFFFFBFFFFFAFFFAF4FFFDF5
FFFDF6D9CEC8BAAFA9EBE0DCFFFCF8FFFDF8E6DCDA777068070400A2A28ADCDCC2C6C6AA
B5B599CECEB2B3B19AC2BDAAFFF7EAFFFDF6FFFDFAFAF6F3FEFFFDF2FBF8F5FFFFF2FEFC
FCFDFFFFFEFFFDFFFAF9FFF1D2E1C2CFE4B9CBE3AFD0E9B2C6DCABD3E8BFF6FFE9F8FFF1
F3FBEEFBFFF8FCFFF4E2F1D2C6E4A4CDF0A0C5E496CCE49AD3E7A093A460D1E5A0D3E8A5
CCE7A2C8E9A2C6EAA0C6EB9EC6EB9EC8EA9DCAE99BCCE89BD2ECA2CFE39ECBD49D444315
6B633E6E63430802005B5E33677842CBE3A5C3E19BD5F1A7D3E49EDCE3A0EAE6A9929057
B8C68BC7DCA1D3E7AACEE2A3CCE19ED3E8A3D6ECA4CFE69ECAE199CFE9A0C4DF98A0BB76
C9E4A1CCE6A5C3DB9DD4EDACCAE49DCBE59C94AA69D6E8AED1DFAECAD5ADE6EDCEF9FCE7
FDFEF0FFFFF6FFFEF7898480F7F2EEFFFEFAFFFAF6FFFEF9FFFFFBF6F6F6FFFDFFFFF8FF
FFF3FDFFFBFFFFFDFFFFFFFAFAFFEFF9FFE8D4E5B9D2E4B0C9DBA1D4E2A5A3AD70D1DB9F
EBF9C64F6131A7B989DFF1C1DDEFBFEFFFCFE5F7C5CDDFABC9DCA59CB176E9FFC1CCE5A3
C9E39CC9E59BCFEBA0D1E99DAFBF78C3D38CCEE29ACAE298D3EFA4BDDC90CBEB9FCEEDA1
D7F1A7CDE59BC1D98FCFE79DD3EDA3C7E398C7E69ACAE69BCCE29AD1E29ED2E19CE0EDA8
DBE8A2A5B56E859A4F99B568C6EB9DD6E7A1C7A975C49E6F958C5574793FDBDEA7CFD99C
CCE79ABFE18DD0EFA1D3EDA6C6DA9BDAE8B5DBE2B9A9AA8A
E1D8D3E4DDD3FFFEE9E9EFCDE1EFBCD2E7A6CBE699C6E691CDEE97BDDF88CCEC97A3C070
CAE199C6DB98D7E9ABD4E4B5E6EFDEFBFFFDF5FAF6FEFFFBECEBE6FFFEFAFFFEF8FFFEF8
FFFDF8AFA6A1FEF5F0FFFDFAFFFEFAF5F1EEFFFEFDC0BFBA0002007C806FCDCEBECDCEBC
EEEBDA4E4B3AFFFFEFABA595FFFFF1F0ECE0FFFDF4FEFDF8FEFEFCFEFFFFF9FDFFFCFFFF
FEFEFFFCFFFFFBFFF5F6FFE7CEE1B3C9E3A6C6E19EC8E5A2CFECACD1ECB5EAFFD5F5FFE6
F8FFEFF7FFF2F6FEF3E1EFD5D5F1B4B4D689D4F0A6D1E8A0D3E4A0DEEDAAACBC7BD2E7A4
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCCE89DC4DE95C5D896DEE6AD474515
7C6F4CB5A88638320E171E0092A973D2F5B5C3E8A2CDEDA4CDDE98D0D291B7A86F61581F
CEE1A1CDEDAAD1F0ACCCECA3CBE99FD0ECA1CEEA9DC9E497CAE598D3EEA1DDF7ADB8D289
D4EDA9D0EBA8CBE5A4CDE8A5CDE7A0D0E7A1859A59CEE2A5D9EAB6CCD9ADD1DBB8FDFFE7
F8FBE6FFFFF1F6F6EA46463CFFFFF8FFFFFAFFFFFAFFFFFBFFFFFFFFFFFFFFFDFFFFF7FC
FFF5FCFFFAFEFAF2F0FEFBF2FCFFEFFBFFEAC2D1AAD8EAB8D4E6ACCFDD9F9CA763C0CD88
D6E9A9667C3E5F7439D3E8ADCBE0A7C9DEA5CEE1AADAEDB5D4E7AFA3B87DE8FEC0D1EAA8
D0EAA3CDE79DCCE69CCDE398CFDC96C7D28DD0E19AC7DF95D1F0A4C8E89CCBEB9FC7E69A
B7CF85D5EBA2DAEEA6D0E49CD0E49CD2EAA0D2ECA2CDE79EDFF3AEC5D491DDE9A7D6E19D
919C5794A45DCFE59CD9F8ACD5FCADBBD08B654917B38C61DAD09FBABC8ACCCA9AE7ECB6
C2DC93DCFFADCDEC9EB8D48ACDE6A4D2E6ABC8D5A7D4DFB5
FDF7EBFFFFF1FFFFEDF3F7DCFCFFE1EBFBCACEE3A8C5E09BD2F1A5C9E898C8E4979EBA70
B1C786CADEA3DBECB6DBE7C1F3F9EBFAFCF9E7E9E6FFFFFBFAF7F2FFFEFAFFFAF4FEF7F1
FFFDF8C0B6B4FFFCFAFCF4F2FFFAFAFFFBFCFEF9FD71706E080901909486DADACEF7F8EA
FFFBEFFFFFF1F5EFE1FFFFF1C4C0B4A39F94FFFFF8FFFFFBFBFBF9FEFFFFEAEEF1FBFEFF
FEFEFFFCFFFFFBFFF5F9FFEAD4E7B9CFE9ACC8E3A0C7E59FC8E7A4C0DCA1CDE5B5E6FAD5
F0FEE4E2EEDAD7E0CFD1E0C1D1EDB0C1E396D1EDA3BFD68ED1E29EE2F1AEB3C382C5DA97
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCCE89DDAF6ACCDE29FDAE2A9716F3F
6A5D3A837956120E0052592DA9C08AC6E6A7BCE09AC7E79ED6E7A1E1E1A19D8C545F5518
D2E69EC7EA9AC5E695C6E693CBE896CCE997CCE894CCE592D8F19EBAD380D1EA99C4DF8E
90AB5CC1DC8DE1FCAFC4DF92CFE79DDFF6AE8CA15ECFE3A6DCEDB6D7E5B4CCD7AFFCFFE4
FEFFEAFFFFEDFFFFEE57584AFEFFF1FCFCF0F3F3E7F9F9EFF9FAF4F6F5F1FCF7F4FFFCFA
FFFBFBFCF1EFACA39C837F739C9E89F4FDDEBDC9A1DBE9B6CDDBA0B1BB7CACB16FDBE29F
CDDD9E84985B5B6F34D2E6ABDAEDB5C9DCA4C7DAA2ECFFC7E6FBC2AFC587E1F7B7D0E9A5
D2ECA5CCE89DC9E59ACEE499A3B06A9EA964D3E49DD3EBA1CEEDA1C7E79BC7E79BCCEB9F
D8F2A8DAF0A7CDE199CBDF97D5E9A1CAE298BFDB90D0ECA2C4DE97DDF2ADADC17C9AA964
D4E49DD7E8A1B7CD84C9E79DB9DF94CBE09D957A4B9C7951FCF5C7EDF5C68D8F67CED8A6
CFEDA7C9F0A1C3E598CAEA9FD5F3ABCBE5A4D2E7AFF6FFD6
A9A490CECCB7FFFFEDFAFDE8FCFFECF8FFE5E7F9CFDAF1BBBDD796D7F2ABC8E49AC2DC95
A6BA7D91A26EDFECC1FCFFE8FEFFF6FFFFFBFBFCF7F9F8F3FFFFFAFFFDF9FFFEF8FFFEF8
EFE5E3E1D9D7FFFAF8FFFDFDFFFEFFFFFEFFFCFAFFFCFCFE494B4623261DBABCB1FBFBF1
FFFFF4FFFDF2FFFFF3FFFFF3FFFFF4BAB6ADFFFFF8E9E8E4FFFEFCFFFFFFFEFFFFF7FBFE
FDFDFFFEFFFFF9FFF3F9FFEAE3F6C8E1FBBED4EFAACBE9A1CCEBA7C6E4A6CBE3AFE1F6CD
F7FFE6EDFBE1DFE9D1DCECC8BAD898D1F3A6CBE79DD2E9A1D1E29ECCDB987F8F4E637835
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCCE89DBDDB91DAF1ADD7E0A7504F1F
8C835CA89E7B222000686F43CAE1A9CAEAA9C6EAA2CBE9A1DAE9A4E4E4A47E6B33665C1F
D6EB9CC8EA94C7E792CCE995CFEC9ACEE998D1EA99D5EC9CD3EA9AE4FBABC8DF8FC2DB88
97B05DD3EF9BC5E18DD7F2A1BBD387D0E79F8FA461CCE0A1CADCA2DBECB8D7E4B8FCFFE1
FCFFE4F5FBDFFFFFEACBCDB7CACCB7FDFFEAFFFFEDFFFFEFFDFFF1FFFFF4FFFFF4FCF5EB
FFFDF4FFF8EEEDE5D8FFFFEC6A6D52FFFFE3DFEABFDCE9B4C5CE9583894BA7A968D5DA98
D5E0A48F9E6394A36AC6D89EDFF0B9D7EAB2CEE1A9F1FFCAF3FFCDB8D092D4EDACC9E49F
CDE8A1CCE89ECAE69BD3EB9F88934E848E49D7E7A0D9EFA6CAE69BC6E69AC5E599CFEEA2
A0BA7095AB628A9E568CA05896AC6380984E6C883D8AA95D80A05590AE66D2E9A1E6FAB3
C2D38CCFE099E9FFB7CFEAA3D6FCB3D6EAABB59971BF9D7AFFFFDCFBFFDFF1F8D67B885C
A4BE7DBAD88ECDE99ED1EDA2CAE49DC2D897D3E6AEF9FFD6
8F8C6BADAC8EFEFDE9FFFFF3F9FFF5F7FFF4F8FFEFDFF3CECCE3ADCAE3A2DDF6B2C8DE9D
D0E3AB8C9B70E9F4D6EFF4E0F0F2E7FFFEF9FFFFFAFCF9F2F8F3EDFFFEF8FFFAF4BBB4AE
8B8380F9F1EFFFFBFDFDF8FCFBF9FEFFFEFFFFFEFFFEFFFFA1A3A2000100262721FFFFFA
FFFFF8FFFFF8FFFFF6F8F4EBF4F0E7CFCAC4FFFFFAFFFFFBFFFFFDEEEEEEFEFFFFFDFEFF
FFFEFFFCFDFFF6FCF0F9FFE8ECFFCFEBFFC6D9F4ADCAE89ECBEBA2CEEDAAD0E9B0DCF2C3
F6FFE0F8FFE4F3FFE0E7F9CFCEEDAAC3E598C0DC92E3FAB2CBDC98D8E7A47383427E9350
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE99DCEEEA3DAF5B0CDDBA0040600
776F489D9570413F186C7546D3EBB1CAEAA7CCF0A8CBE99FD4E19CDDDC9C67521B7E7236
D4E798C8EA94CBEB98CFEC9CCDE79DC8DF97C9DF97CEE29DBBCF8AC8DC95DEF2ABD4EA9F
95AD5FBED786CDE995D2EE9ADFF7ABC7DE9699AE69DCF1B0C7DB9ED5E6AFD0E1ADDDEABC
F6FFD7F2FAD5FCFFE1FDFFE1989D7DEFF4D4F0F3D4EAEFD1F1F7DDFEFFECFFFFECF5F3DE
FEF7E4FBF3E0EEE8D2FFFFE8818262F3F9D3D6DFB0D2DCA7E2EAAF8B8F52C0C080EEF0AF
DAE4A88D9B60A0AD75C7D69DCEDDA4C9DBA1D2E6ABE3F7BCEBFFC5BDD597CDE6A5C9E49F
CFEAA3CCEAA0C8E79BD2EAA0A8B36E96A05BD6E69FCFE59CC7E398CDECA0C7E69AC8E499
9AB46ABCD289DCF0A8CFE39BC8DE95C1DB91AECD81BFE194C8EDA0CBF0A3C3E197C7DE96
DBECA6D6E7A1C2D691BED793BDE09CC9DAA3D2B593BB977DFFFFE3F8FFE8E8F6DCCDDBB7
7B8850DEEBA6EDF8B3CCD792D7E2A0D3DB9FD7DBA9FFFFD8
D6D5A5D2D3ABFFFFEAFFFFF4F6FAF9F7FFFFF8FFFADCEBD4DBEEC1B8D096D3E9A8C7DC9B
DFF0BAE1F0C9EBF5DDD4D8CAD3D3C9FFFFF6ECE9E0FFFFF6FFFFF6B0ACA3545047CBC6C0
FFFEFAFFFEFBF5F1F2FFFEFFFFFEFFE9E9F1FEFEFFFCFCFFFEFFFF000201000000F3F3F1
FFFFFBFFFCF9F6F3EEFFFEFAFFFDF9D6D1CDB5B2ADFCF8F5FFFFFBFFFFFDFCFCFAFEFEFF
FFFEFFFDFFFEF5FBEDF9FFE8E5F9C8E3FDBED0EEA6C3E397C0E095C7E6A0CAE6A9CCE5AE
DDF3C4F5FFDDF5FFDEE1F5C4DAF9B5BFE194C4E096D2E9A1CFE09C8C9B58BACA89DCF1AE
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE99DC3E59BC3E19BD3E2A9616533
726D45817C54121300606A38C5DDA1C2E39EC8EAA0CBE79DD4E19CE2DE9F6A5520A7985F
CEE096CDEC9ED8F4AADDF6B2DEF4B4DAEEB3D6E7B0D6E4AFF0FEC9D5E4ADA6B57C6E8042
C5DA97D3EAA2C7E295CCE79AB8D0867D954B6A8038C4D996C7DC9BD0E4A7D4E7AFD9EAB4
E6F4C1F6FFD2DEEABCD8E1B6A3AC81DAE1B8DBE2B9CCD3AAEEFAD4F3FFDBFEFFE3FFFFE4
FFFFE4FDF9DCBDBA9BA4A482E3E8C0FEFFDAD7E3B1D1DCA4E0E8AD7A7E41979757D8D89A
D8DDA397A067929D65E8F5BDD7E4ACC6D59CD8EAB0D0E6A8D7EDAFBFD897CCE7A4CFEAA5
D1EFA7D1EFA5C7E69ACBE39988934E96A05BD6E69FCFE59CC8E499C8E79BCAE99DC9E59A
A9C379ABC379D6EAA2DBF1A8D6ECA3D3EDA3C2E195D3F5A8C3EC9EC0E99BC0E095C8E299
D7E8A2D6E39ED7E6A3E4F9B8C5E3A3DDE9B7B39175DFBAA7FFFFEAEFFEE7F5FFF3CDDBC1
BAC696BDC78BC4CD8EDAE3A2E6EFAEDAE3A4DEE6ADFBFFCE
DFE4A4D5DAA4F6FAD9F1F5E6F9FDFFF9FFFFF8FFFFECFAE9C9DBB5C8DDA5D4E9A6DCF1AE
C1D29CF0FFD8F3FCE7F1F5E7FBFCEEAAA798636051535041494539C4C0B4F1EDE2F8F6EA
F4F1EAFAF9F4FFFFFDFFFFFFFCFDFFFCFFFFFCFFFFF0F3FCE7E8ECEBEBED6B6B6D616163
EEECEDFFFEFFFFFFFDFFFEFBFDF9F6FFFCF9E1DDDAFFFBF8FFFEFBFFFFFBF9F8F4FAF8F9
FFFEFFFEFFFFF5FBEDF5FFE2D4E8B5D2ECABC8E69CC5E697CAEB9CC8E89DCEEDA9CDE9AC
D0E7AFEAFECBF5FFD7DDF4BCC0DF99C8EA9DD5F1A7D1E8A0C4D5915A6926CDDD9CC4D996
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE99DCBEFA5D7F6B0C4D69C5F6633
646136A49F77262700768250CEE8ABD0F1ACCBEDA3CEEA9FD6E39EDFDB9C624B17A99A63
D3E3A4D9F6B6EAFFC9F2FFD5F8FFDCF9FFE1F0FBD9E2EBCC3A432456603EAAB690B7C79A
D9EBB9CEE3AAD4ECAECCE5A3E1F8B0C0D68DB5CB83DBF0ABDCF3AFCFE5A4CBE1A1C9DDA0
CDE1A6E4F6BCCDDCA5CCD9A3CEDBA5B5BF8BD9E1AEE3EFBDCCDEACCBDFAED6E6B7D0DBB0
CFD4ABD4D9B0D1D6ADDFE6BAF0FCCCF2FFCDCDDEA7CFDEA3D2DC9F9BA163999B5AE5E7A8
DADDA4939862959D64CBD49BD9E7ACD2E1A6D9EBAFCBE1A1CCE2A2C6DF9DCDE8A5CCEAA4
CBE9A1D0EEA4C9E89CCDE59B57641E939D58D6E69FD2E89FCDE99EC3E296CDECA0CCE89D
D1EBA19AB268B9CD85D0E69DCFE59CCEE89EBCDB8FCBEDA0C3EC9EBCE597D1F1A5E0F6AD
D3E09AD0D996D7E09FCFDB9DC1D99FEBF1C3EEC8B3D8AEA2FFFFEFF7FFF4DFEFE4F5FFF4
F7FFE6809164839860D4EAACD2E9A3C3DD93D2ECA2C9E399
D3DE8FDBE4A1F1F8CEEBF0DCFBFFFFF8FFFFEBF5F6F2FEF0E7F9D3DCF1B8C9DE99D0E5A0
D3E4ADD2E1B8FBFFEDF3FAEAFFFFEFFAF8E3FFFFECFFFFEBFEFDE9F2F1DFE2E3D1FEFFEF
FFFFF4F5F7ECFEFFFBFCFEFBF6FAFBFBFFFFF3F8FEFCFFFFFEFFFFB6B5BA434247000004
FFFEFFFFFDFFF1EFF0FFFFFDFFFEFDFAF6F3CCC8C5878380ECE8E5FAF6F3FFFEFBFFFCFB
FEFCFFFEFFFDF7FEEEF0FEDDC8DCA9C6E19EC6E599CEEF9ECEF19FC2E497CBEBA2CBEAA6
C1DB9ED5EDB3E9FEC5D4ECAEC6E69DCCEEA1CCE89ECFE69E91A25EC4D390D6E6A5D0E5A2
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DC9E99EBDE197CDEEA9CFE3A6242C00
817E536D6A3F03060063703BC8E2A3CCEDA6C0E296CAE69BD8E5A0E2DEA1634C18AB9B67
C7D69DCDEAB0DEF6C4E7FACDEEFEDAF1FCDEDCE4CDC1C9B4DFE4D0DDE2CCD9E2C5DCE8C4
C7D6ADD3E7B6C2D9A1D3EBADB0C580D1E79ED7EDA5CAE098D0E79FCCE39DD1E8A4D0E7A3
CBE1A0D2E7A6CADD9DE0F0B2C4D49659672A9DA86CCAD99ED1EBAEC2DEA1D0E8AED1E4AC
D3E0ABDCE9B4D5E2ADD2E0ABF8FFD3F7FFD1D4EAACD3E7A8CCDC9DD2DE9EA2AB6AD7DB9E
E3E6AF7D804B9DA26A687138B6C187D2E2A4D1E3A5D1E7A6CBE4A2CDE8A3CBE9A3C4E29A
C1DF95CDEBA1CDECA0D5EDA3727F39AEB974D2E39CC9E197D4F0A5CAE99DD3F2A6C2DE93
CBE59BA9BF76D5E9A1D9EDA5C6DC93D9F3A9CDE99EC0E295C2E89BCAEFA2CBE79CCDDE97
D8E29DDFE1A0DEE0A1E0E5ABD9EAB398996FAF8171AC7D77FFF9EFF7FFF8F8FFFDF4FFF6
F8FFEEA7B5929CAB80C8DBA4D1E5A6CFE69ED5EDA3C9E497
849539A9B768CFDCA6E5F0D2F1F8F0F9FFFFF8FFFDF6FFF1F7FFDFE4FABCD1E79ECCE299
D5E9AAE3F5C5F1FEE0FCFFECFFFFE8FFFFE3FFFFE3FFFFE6FFFFE8FAFEE3FAFFE6FEFFEC
FAFFEDFCFFF1FCFFF6F7FFF4F6FDF6F9FFFFF9FFFFF7FCFFFEFFFFF7F6FCABAAB0000004
FFFEFFF8F8FAFFFFFFFBFBFBFFFDFEFFFFFDFFFDFABAB6B3FBF6F2FFFEFAFFFAF6FFFEFB
FDFBFEFEFFFDFCFFF3E5F0CECFE3AECBE6A3CCEB9FCAEC98C8EB97C6EB9BC8EA9EC9E8A2
CAE7A4CCE6A5CDE6A5CCE7A4CBEDA1C4E699CAE69CC9E09898A965D6E5A2C1D190D7ECA9
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DC9E99EC3E79DD5F6B1C9DDA0000900
8281539693682E310267743EC6E09FCCEEA4C9EEA0CCE89DD3E09BE8E4A75D4813AC9C69
CBDAA1CBE8AECBE3B1D2E8BAD4E4C0949F81828A73F0F5E1FFFFEFF8FDE7FCFFE8F7FFDF
F9FFDFF7FFDAF5FFD4CBE3A5849956DCF0A9BFD58CD8EEA5CEE69CCDE79ECBE59CD3EDA4
D0EAA1D2E9A1CAE199CADF9AD6E7A352611E98A764CEE3A0D0EFA9C3E7A1CAE9A6C6E09F
CEE2A5D9EDB0D1E5A8D3E9ABCFE9AABBD898D2EFADD2EDAAC7DE9AD2E5A38998579DA569
E5E8B1929560969B637B834A657034CEDEA0D7ECABCCE39FCBE4A0C8E39CD1EFA7BCDA90
D3EFA5D5F1A7CFEBA1CEE59D9DAD66C2CF89D7E8A1CFE79DC8E499CDEDA1CFEFA3C7E69A
CFE79D9DB36ACBDC95D3E49DD0E49CCFE79DD7F1A7C2E195C8EA9ECCEAA0D7EDA4D2DD98
A4A764545011615D2056551D57612C555028A67264DAA5A1FEEDE6FDFFFAFCFFFFFFFFFD
FFFFF3FEF6E1FFFDE0A9A57FC8C696E6E6B0E9ECB3DEE3A9
839935A1B55EBED191D1E0B7E0ECD8F1FDF3F8FFF6F7FFECF4FFD7E1F7B6CFE79BCCE496
D4E9A6DAEDB5DEEEC7E4EFCDEAF0CCE7EBC6E8EEC8EEF4CEEAF2CDE4EEC9EBF7D3F9FFE2
F8FFE7F6FFE9EDF9E3E5F0DFEBF6E8F9FFF8F9FFFBF7FDF9F9FAFCFFFEFF8B8A8F000004
C7C6CBFCFBFFF3F3F5FFFFFFFFFEFFF6F4F5FCF8F7F9F5F2C4BFBBF9F2ECFFFEF8FBF6F2
FFFDFEFFFFFBFAFEEDE2EDCBCFE3AECAE5A2C8E799C2E591C6EC97C6EC99C8EA9DC8EA9E
C9E8A2CAE8A2CCE7A4CCE7A2C7E99DCBEDA0C4E096D8EFA7B4C581E6F5B2FBFFCACBE09D
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE89ECDF1A7BCDD98CDE1A489925D
656436848154666A38D1DEA6CEE9A6CBEFA5C5EA9CC5E496D3E09AE1DFA25F4A15A59863
D7E9ABC8E8A7D0ECB1C7DEAABFD0A3A8B48EE6F0CEDDE4C5FFFFE6FAFFE0FCFFE1FBFFDC
F7FFD7F7FFD3F1FFCCD2EBA993A863CDE19AE1F7AFCFE79DC7E197CEEA9FCCE89DCDE99C
CBE79AC4DF92CEE99CD7EFA5C7DB93B3C47E92A35DD9F0A8C1E699BCE599D5F7ADD9F7AF
D3ECA8C7E09CB9D290C5E09DCAE9A5D0F1ACC7E8A3CBECA7CBE9A3CFE8A4E1F4B2889456
C8CD95AEB17CD6D9A2434B12B4BF83D6E6A7C1D693DEF8B18DA760CBE79DC9E79DDDF9AF
BBD78DCCE69DCCE69DB7CD85CADA93D8E8A1DAEEA6CCE69CC5E498CBEB9FCCECA0C6E599
D2EAA0798D45D5E59EE2F2ABCADB94E2F6AEC3DB91CFE9A0C9E49DD2E9A39EAD685A611D
6261207C77379C9358A2A0678A915B736A41875242AD736FFFF9F4FFFEFBE6E4E7FFFDFF
FFF6F4FFFCF3FEF6E3BCB598605C36989767939361CED19C
C3DD78D1EA8FD9EFA7D7EBB6D8E9C7E3F3D9EEFEE3F0FFDEF5FFD4E2FBB7CFEA9BCAE594
D0E79FD1E7A7D0E4B1D0E0B3D5E1B3D5DEAFD5E1B1D7E3B3D2E0AFCFDFB0DBECBFECFDD1
F7FFE1EFFFDBDFEECDD7E6C9E3F1D8F5FFECF8FFF3F4FFF1FEFFFDF1F1F3FCFDFF000004
05060AFDFEFFFEFFFFF6F7F9FDFDFFFFFEFFFBF7F6FFFEFBC0BBB7EFE8E2FFFDF8FFFCF9
FFFEFDFFFFFAFAFFEBE5F1CDD3E7B2CEE9A6C9EA9BC3E692C6EC97C6EC99C6EB9BC8EA9E
C9E9A0CAE8A0CCE7A2CAE8A0C6E89CCAEC9FC6E298E0F7AFC8D995FCFFC8FBFFCACCE19E
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE89EC1E59BCCEBA7CDE1A4909964
6C6B3BA3A073979B68D0DFA4CAE8A2C6EB9EC1E897C7E899DCECA5DDDD9D695520A59A62
CDE39AD0F5A5BFDF94C6E19CF2FFC88D9F65CCD9A3D4DEAAD0D8A5CDD7A2D0DDA5D3E5A7
CCE39FD3EDA4D1F0A2C7E396AEC47CA3B770DEF4ACC6DE94CCE69CD1EDA0C9E89AC8E797
C9E898C6E595CEEB9BD6F1A4C0D68BE4F8B093A45DBAD288D0F5A7BCE798BEE396B9D98E
C5E099D6F1AAD1ECA7D4F2ACC6E7A0C8EDA7577C3654783295B671C0DD9ACAE09FD6E6A8
A6AB758386519A9D66525A21B1BF82CDE0A0CEE3A0CAE49D8AA45DC1DD93D8F4AACDE99E
D0EAA1C9E098C6DC94899D56DAEBA4D6EAA2CFE79DC7E398C5E599C9EB9ECAEC9FC9E89C
C7DF95B9CD859DAD66BFCC86DCE9A3CEDF98D0E49CDBF1A9CDE29DE0F4AFBCC7834C4F0C
9F9B5BDFD798E2DD9DDCDA9DEDF5BABBB38578412DB47971FFEDE6F3ECE6FFFCFDF5F0F4
F6F5FAFEFFFFFAFFF4D8E0C8C5D1ABDDEDBCC6D7A0D1E5A8
CBE987D1EE94D1EBA1CBE3A7CBE1B2D5ECC2E2F7CEE8FECDF5FFD1E6FFB9D0EB9CC9E493
CCE69CCEE7A3CEE6AAD0E5ACD4E5AED1E3A9D0E2A8CFE3A8CBE0A5C8E0A4D1E9AFDDF4BC
E8FFCCDFF7C5D4EABCD3E5BDE2F3CFF6FFE4F8FFEAF9FFEFFEFFFAFFFFFDFEFFFF0C0D0F
000002B3B4B8FEFFFFFEFFFFF8F8FAFFFFFFFFFEFFF6F1EEE5DDDADFD6D1FFFCF6FFFDF8
FEFAF7FFFFFAFAFFEBE8F4D0D5E9B4CDE8A5CAEB9CC9EC98C6EC97C6EC99C6EB9DC6EB9E
C8EAA0C9E9A0CAE8A0CAE89EC0E296D3F5A8C6E298C5DC94E1F2AED1E09DF0FFBFC7DC99
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE89EC7E99FCFEEAAD3E5A949521D
807F4F898757949865DDEDAFC4E29AC3EA9BC3ED9BCBEE9CDFF1A7CACC8B695A239F965B
CFE799CCF49CCBEE9AC0DF8FC4DE94849851DFEEA9D4E09EE4EFADDEEBA6D5E49FD2E79C
C6DE90C7E492C5E791C8E895C9DF9781924EAABE77C5DD93D5EFA5CEED9FC9EA99C9EA99
C7E995D6F8A4C3E292CCE999D1E99DCBE196AFC37B99B167A8CD7FBCE394D6F8ABC8E79B
C7E198D6F0A7CAE59EC0DE96C9EAA3C0E69D1B4000698E485F803BCEEBA9CAE3A2CEDDA2
CBD29CB3B681686D371C2600DDEBADC6D997D8EDA8D4EEA58FAB61CCE89DC5E196DAF4AA
C1D890DCF2AA9AAE6795A660D0E49CCAE097C5E196C7E79BC9EEA0C8ED9FC8EA9DCAE99D
D4ECA2C7D8919DAA64949F5AD9E49FE3F0AACBDB94C2D38DD9E9A8CDDC9BCCD5943E4000
A7A461E1DC9AE6E3A0DEE09FCAD698E9E6B35F2B13793F33FFF9ECFFFCF2FFFCFAFFFCFF
FFFEFFF3F8FCFBFFFBCCD5C4E5F2D4CBDAB1CFE1B1C9DDA8
C2E38AC5E590C5E498C3E09DC5E1A6CDE8B1D7F0B9DBF4BAEDFFC6DDF8B1CEEA9FCAE699
CDE99ECEEAA0CEE9A6CFEAA7D6ECABD1E8A4CEE5A1CEE7A3CEE9A4CCEAA4CDEAA7CEEDAA
CAE8A8C9E7A9CAE6ACD0E8B4DEF1C3ECFFD2F5FFDCF6FFE3FEFFF4F9FAF5EEF0ED2A2C29
0A0E0DA3A7A8FCFFFFF2F6F7FEFFFFF1F1F1FFFEFFFFFEFBF2EAE7BDB4AFFBF0EAFFFCF7
FDF9F6FFFFF8FCFFEBE8F4CED1E6AEC6E19CC6E69ACBEE9CC6EC99C5EC99C5EC9DC6EB9E
C8EAA0C9E9A0C9E9A0C9E99EC7E99DC8EA9DCDE99FC9E0988A9B57DAE9A6C5D594DAEFAC
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE89EC6E7A0C4E19FDDECB159602C
6C6A3AAEAC7BA4A973CADA9CC8E89FC8EF9EC7F19DC7EA98D0E69BA8AD6B6A5D28A19D60
C4E191C1EC93C6EC95CEF09AD2ED9C98AF5FB2C375E0EEA1D6E497D4E597D1E495CEE593
D1ED99CFEF9ACFF39CD4F4A1D4EAA294A561889C55CEE69CCEEA9FCAE99BCFF09FC8EB97
C1E490D5F8A4C0DF8FCBE898DDF5A9BED48BD2E69FB0C67E7E9C5268883D86A258B2C981
CEE29BCCE099C7DC97DFF9B2C7E6A0D0F1AA001300C9ECA8A8C784C8E2A3D5EBADD7E6AD
EAF1BDD6D9A47D844E475216C7D798D4E9A6C4DB95CFE9A0728E43CAE69BCCE69CD5EDA3
CADE979FB06A9FAE6BC8D993D3E9A0CDE79DCAEA9ECCF1A3CBF2A3C4EB9CC3E89ACBEA9E
D3EBA1D0E19AD1DC97B4BE79919B56838D48E1ECA7DCE9A4D8E6A8CBD799E9EFB16D6F2E
939450E3E49EDBDE97CAD68EC5DA95E1E4ABBA8D6E7E4937DEC8B3FFFEEDFEF1E9FFFCFA
FFF8FDFFFDFFFFFCF9F9F6EDF4F3E1FFFFEAFFFFEBFFFFEA
D1F4A4D1F4A4CFF1A5CDECA6CAE9A5CAE7A5C9E6A4C8E5A3D1EEABCBE9A3CBE69FCCEAA0
CDEBA1CAE89EC7E59DC6E49ACFEBA1CBE79CC7E69AC9E89CCCECA0CDEFA2CAEC9FC5EA9D
C2E69CC6E7A0CAE9A6CCE9A9D0E8AED4E8B3D7E9B7DAE9C2E1E5D4FFFFFAFEFFFA545651
020703949897E3E7E6FCFFFFFEFFFFFCFCFCF8F7F5FFFEFBFFF8F5B7ACA8C3B6B0FFFCF8
FFFEFAFFFFF6FDFFECEAF6D0D3E8B0C7E29DC7E79BCAF09DC6EC99C5EC9BC5EB9EC5EB9E
C6EAA0C8EAA0C9E9A0C8EA9ECAECA0C6E89BCCE89ED7EEA6556622D0DF9CCFDF9EDAEFAC
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE89EC3E29CD4EEADDCEAAF030800
7773448E8C5B929761D5E5A6CCECA1C7F19FC5F19CC0E693CBE3979AA15E887D47C7C58A
D2F0A6CDF8A6B6DD8AC8EB97DAF7A57B9242273800859344D5E394D4E595D6E99AC3DC8B
D8F5A5C9EA99C3E898BCDC90D0E5A0C9D99890A45FD6EDA5C2DE93C6E798D1F4A2C5EB96
C4EA95C5EB96C7E897CFEEA0CCE69CCEE59DCFE39CD1E79FCCE69DD9F3AACBE19993A45E
9AA762D6E5A0DDEEAAC3D893C9E49FD6F5B1001300C9E8A5D7F4B4CCE4A6C0D499D2E1A8
DAE1ADDFE4AE010800687337D2E2A3CDE29DE4FBB3BCD68C799548CAE598DDF5ABC1D78E
DDEEA865742FCEDA98D7E6A1D2E9A1CCEB9FCAEC9FC7EE9FC1EC9CC0E99AC7EC9ED1F0A4
C5DD93EBFBB4D9E39ED9E09C9CA35F515814C0CA85DEE9A7E3EEB2D9E3A7CAD394535816
2C3200D2D890DBE79BDCF1A4D6F5A9D4DE9FAB856073442AC6B299FFFFEAFFFDEFFFFCF6
FFFCFFFFFDFFFAF5F2FFFEF8FFFFF4FFFFF4F7F3EAF9F5EC
C1E59FBFE39BBFE399C4E69CC7E99FC9E9A0C9E9A0C8E7A1C5E49EC5E4A0C9E6A3CCEBA5
CBEBA2C6E69BC5E599C7E899C9EA9BC8E998C6E995C6E995C6EC97C6EE98C5ED97C3EA97
C8EF9EC9EEA0CBEBA2CAE8A2CAE3A2C8DEA0C8DCA1CADAABEBF0DAFDFFF4FCFFF6BABDB6
000200383D39FBFFFFFCFFFFF7F9F8FFFFFFF8F7F5FFFCF9FFFCFAE6DBD7BDB0AAFFFBF7
FFFEFAFEFFF3F2F7E0E3EFC9D4E9B1CBE6A1C9E99DCAF09DC6EB9BC5EC9BC5EB9EC5EBA0
C6EAA2C8E9A2C9E9A0C8EA9EC3E599D4F6A9C8E49AC5DC94B4C581889754E0F0AFBCD18E
CDE6A2C9E8A2C8EAA0C6EAA0C8EA9EC9E99ECAE99DCAE89ECEEDA7C2DC9BD4E2A7DADFA9
6F6B3CAEAA7A969B63DDEDAEC9E99EC4EE9CC3F09BBFE693D2EA9E9AA360A49B64E3E2AA
CCE9A7BBE69FC9F1AACCEEA4BFDB91D9F1A7CADC92C4D48B91A15892A45A9FB36B89A058
C8E39EC5E6A1D4F9B4CBEBA8CCE1A0DFEFAE97AB66D1E8A0C8E499C9EA9BC7EA98C7ED9A
C9EF9CBEE491CFF0A1CCEB9DC3DD94D3EAA4C9DD98D4E8A3D3E7A2C7DB96D9E8A5D7E2A0
B6BF7E929B5A8E9957B4C581D4EBA7D3EEAB496322CFE9A8B4CC8EE9FEC3D9EAB36D7A44
6B723E3F4610A8B17ADEECAFDCEFAFC9E09AD1EBA28DA95EABC77ADBF6A9C5DD91D8ECA4
8D9C57AAB772D5DE9DD4E19CC9E39AC7E79BC4E99BBFE899BDE898C1EC9CC8EFA0CDEDA1
D2E89FC8D891D6E09BD6DB98EAEFACD5DA975C611E969F5ECFD99DD8E3A9D1DB9E626B2A
3C4600DCE89ED9EC9DC8E593CCF3A2CBDF9ACDAC81BA8F6F7C6D4E5E5A3FCFC7B4FDF5EA
F9F8F6FEFFFFFEFFFDF6F9F2FFFFF8F4F5EDFFFFFAFFFFFB
C9EEA8C4EAA1C3E79DC5EA9DC7EC9FC9EB9EC8EA9DC9E99ECAEA9FC9E9A0CCEAA2CDEBA3
C9E79FC6E49ACAE89ED2F1A5CBEC9DCCEF9DCCEF9BC6EC97C3E994C3E992C4EC94C5ED95
C7ED98C4EA97C4E699C7E79CCCE7A2CDE8A3D1EAA8D7E9B5ECF4DDFAFDF4FBFEF57B8079
0306006F746DF2F7F1FBFDF8FFFFFBFAFBF6FFFEFBFAF5F2FFFAF7FFFCFAFFF4F2E3DAD5
FCFAEEEDF0DBDBE4C5D1E1B4CEE3AACBE6A1C7E79BC6E999C6EB9BC5EC9BC5EC9DC6EB9E
C6EAA0C8EAA0C9E9A0C9E9A0D1F1A6B6D68BDDF9AFCDE7A0C7DC99D6EBA8495E1BD4EBA5
CDE7A0CCE89ECAE89ECAE89ECAE89ECAE89ECCE89ECDE7A0C6DF9DDAEEAF919A63545624
7773449E9C6B8B9058D4E4A5C9E79DC6EB9BC8EF9CC7E897DAEBA4969B5BA39763DCD6A2
C9DDA2CEECACD1EBACCCE2A1CEE5A1D5ECA6C9DF97CFE099DFECA6D2DF9ACADB9590A761
CBEAA6BCE19CD0F5B2BFDF9CCDE3A2D1E4A28B9F5AC6DD97DCF6ADD1EDA2BBDA8CCFF0A1
C9EA9BC3E495D0EFA3C6E298CFE9A2CAE19DD9EEADC9DC9AD1E5A0D5E6A0DCEBA6D0DF9C
DAE6A4D4E3A08E9E5D4C5F1DCBE1A0CFE8A7031C00CCE6A5D4ECAEC3DB9DCDE3A58A9C60
535E249BA66CD0DB9FD5E5A6CBDE9CD0E5A0D4EBA3476117D4ECA0C8E094D6ECA1CCE098
465710E0EFAAD5E09CD5E49FCCE69CCDEDA1CAEFA1C5EC9DC3EC9DC6F09EC4EB9CBEE093
D0EAA0D4E8A0D8E5A0DFE8A5CAD18EDEE3A35F6424929B5CD9E7AAD3E1A4D3DDA0505918
5D6420CED891DAECA0C7E696BDE896C8E39CA68E609F7B59DDD0B07F795F665949FFF8F0
FFFEFBFEFFFDF9FBF6F9FCF5FEFFF8FFFFFAFFFFFBFFFFFB
BFE695C6ED9CC1E897C2E99AC9EFA2C1E698C8ED9FD0F3A3C9EA99CAEA97CCE997CDE899
CFE79DD0E69ED0E5A2CFE6A2C9E99EC8EA9DC8EB9BC8EB9BC8EB99C8EB97C8EC95C8EC95
C8EC95C8EB97C9EA99C9EA9BC9E99EC9E9A0C9E8A2CCE5AEE4F1DDFBFFFDFBFFFBF3F8F1
010400383A2FFFFFF4FAFBEDFFFFF3FFFFF4FCF9F0FAF7F2FFFEFBFFFEFFEFE9EDC8C5C0
BDC1A8E8F3C9D4E1B3CADDA6D1E9ABC9E7A1CAEA9FC7EA9AC6EB9BC6EC99C6EB9BC8EB9B
C8EA9DC9E99ECAE8A0CCE7A0CFE9A2CFE9A2C9E7A1C7E6A0C9E8A4C4E39FB1CF899DB96F
A4BE7494AA5F9AAF64A5BA6FD8EEA5D9EEA9C8DE9DD3E7A8CFDDA0E4EEB2858A54040600
D7D6A6333504303701E4F2B5D5EAA7CEE59DCDE39AD3E39C898E4E676127C5B383EDDDAC
CDCE95DAE2A6E4E3AAD9DA9ED8E7A4D1E8A2BFDA93CEE59DD2DD99DCE3A08D9A557D944C
B6DC8FC8F4A7CAF0A5C1E198CAE39F728744889D58D6EBA6C6DC94D1E79FDBEFA7CFE59C
D5EBA2D6ECA4C8DD98CBE09DCEE3A2CBE1A1D7EBAED3E8A7D3E9A1C9E197D1EBA1CDE99F
D3F1A9C5E49ECFEEAAACC987CAE7A5D1EBAA011A00C5E09DC3E09DCCEBA5CBEFA7CBEAA4
CEE59FD7EBA6D3E7A2D6EAA3D0E49DD2E69F95A65F1C3000D5E69FCADE96D2E39C95A961
CCE098D3E79FCEE29AD8EEA5CEE69CCDE99ED5F4A6BCDF8FCFF4A4D3FAA7A9D07FCCF3A2
C1E494D7F6AAC1DB94CEE19FDBE9ABD5DFA34A4F179AA468D3E8A5D2E7A2CFDB9B565A1D
7E793FE0DEA1DBE1A1C8E299BAE99BC7EBA5A29666A68C6BFFF6DCFEF5E4C1A7A661474A
726763F8F5EEFFFFF8FFFDF6FFFFF8F9F4EEFFFEFAFFFCF8
CAEFA1C6EB9DD3F7ADBCE096CBEFA7D3F7ADCAECA0BDE090C9EB97CAEB94CCEA92CDE994
CFE799D0E69ED0E5A2CFE5A4C9E8A2C6EB9EC8EA9DC8EA9DC9EA9BC9EA99C9EB97C9EB95
C9EB97C9EB97C9EA99C9EA9BC8EA9DC8EA9EC6EB9EC9E6ACE2F1DCF9FFFDFBFFFBF5FAF3
000200282921FFFFF6FEFCF0FFFDF1FFFFF4FFFFF6FEFEF6FFFFFAFFFFFBFFFFFFF4F8EA
DBE3BED0DEABD5E4ADCCE0A3D2EBAACBE9A3C6E69BC8EB9BC8EB99C6EC99C8EB99C8EB9B
C9E99DC9E99ECAE8A0CCE89ECBE29ACEE59DCAE8A0C9EAA3CBEFA9CEF2ACCAEBA4C2E098
D4ECA2C4D98EBFCF86A0B069CDDC9BD0E2A4CCE0A5CEE1A9D7E2A8C5CD926B703A040600
E2E6B4434A17353F0AC3D297CADD9BD2E8A0DEEFA8DFEAA58B8B4D635A23BDAB7BEBDBAA
EFEAB2E7E5AAC2B77F9D975DB2BD7BD0E7A1CCECA3D2ECA5DAE3A0C5CA88B3BE7ABAD189
CCF7A7B9E897BDE495D4F4A9D5EFA87A914DCADF9ADDF2ADD1E59ED0E19BC9D893CEDD98
C3D28DD8E9A3D8E9A5DDF0AEDEF3B2CFE5A5CFE5A7CBE1A1D8EFA7CBE397CAE69BC3E599
C6EAA0C6ECA3C6EBA6C1E4A0BBD898CEE8A71C3500EAFFC0C9E8A2C4E89EBAE395C7EDA0
CBE79CC4DC92D7EDA4C8DE95CADE96CBDC959DAD66CDDD96D4E49DDDEDA6BCCD86ADC179
CCE299E0F6ADC2DA90CDE59BD2E89FD2EAA0D0EB9EC2E193C4E594CCF29FCBF19ECEF5A2
CDF2A2BDDF92C3DE97D9EFAECBDB9DDEE7B0B0B481B2BB84CFE6A0C2D991E6F5B24E4F13
675E27F6EBB5D9D99DD0E5A2C2F5A8BFE8A29C9666B59E7EFFFEE8FFFCF3FFF5FAFFF5FD
AA989472685FC0B6ADFFF9F3B7ACA69F9490ECE1DDFFFAF6
CCE8ABBEDA9FDAF6BBC6E2A7C2DEA3CAE7A7C7E4A1CEECA2CAE999CAEB94CAEB92CAEB94
CAEA97CAE99DCAE8A2CAE8A2C8EAA0C8EA9EC8EA9DC8EA9DC9EA9BC9EA99C9EA99C9EB97
C9EA99C9EA99C9EA99C9EA99C8EB9BC8EA9DC8EA9DCAE6A9E2F2D7F8FFF7FBFFFAF8FDF7
000100121212F7F5F8FFFEFFFFFDFEFFFFFDFFFFFBFFFFF8FAFDF2F6FAEBF5FCECF7FFE5
F0FBD0A6B57ED7E6ADCEE2A3D2E8A7CEE9A2C3E296CAED9DC8EB99C8EB99C8EB9BC8EB9B
C9E99DC9E99ECAE8A0CCE89DCDE597CEE998CBEA9CC7E99CC6EB9ECAEEA4CFF0A9D1EFA9
DBF2AED9E9A8D7E6A599A76AC9D6A0D0E1ADDAEEBDD3E7B4DFEEB5E1ECB0879059000900
CAD29F919B679AA972CEE2A5CDE6A2CAE49BC7DF95BECF88767F3E5E5E22B4AD77E4DDA9
BAB980B9B97D89804767622895A15FC9E39CCCECA3C4DF98D5E09CB1B674DCE7A3D3EAA2
C9F2A3C1EE9DC2E799CBE99FCDE6A2768D49D8EDA8C4D994D1E59ED3E7A0D7E8A1E3F4AD
D9EAA3E1F2ACC4D893C1D693D3EAA6C9E2A0BCD594AFC8867D934B91A75CCAE49AD7F7AC
C8EAA0C5E9A1BEE19DDBFBB895AF6EC4DD9C334C0AC4DD99BBD993C1E59BDEFFB9BDE396
D4F0A5C9E197DFF5ACE0F6ADC9DD95E2F3AC8D9D56D3E39CC7D790DBEBA482934CCADE96
D5EBA2CFE59CD0E89ECEE49BCCE098D0E49CD1E79CD3EEA1C3E090C0E190CFF09FB4D785
C7E899D0ECA2CFE6A0D2E5A5D2DDA1D3DAA4C8CA98B5BA82DAEDABC2D890D7E8A44C5214
4B420BD0C38EDCD79DDDEDACB6EB9DBEECA4979565A99273FFFAE7FFFAF1FFF6F9FFF7FD
EED9D66F5C557D6A638976705B48426D5A569E8B87D3C0BC
8BA278849B719AB187DAEFC6D5EBBDCFE6B2C7DFA5D4EDABCCE89BCAEA95C9EB94C9EB94
C8EB97C6EB9BC6EAA0C6EAA2C8EAA0C8EA9EC8EA9DC8EA9DC9E99DC9E99DC9EA9BC9EA9B
C9EA9BC9EA9BC9EA99C9EA99C8EB99C8EB99C8EB99CAE7A5E4F3D2F8FFF1FCFFF8F8FDF7
00000404040CF4F2FDFFFDFFFFFDFFFBFAFFFCFEFBFCFFF6F9FFEDE6F3D5D8E6C3D4E3B8
E8F6C1819055DAECAED0E5A4CCE39FCFEBA1C6E599CCED9EC9EA9BC8EB9BC8EB9BC8EA9D
C9E99EC9E99ECAE8A0CCE89DCEEA95CFEB94CBEB96C5E896C1E698C2E79AC5E69FCAE5A2
CEE2A3CDDCA1D4E1AB8F9B69C8D3A8D2E1B8EFFFDBEDFFD3CADEA3C3D395909E630B1800
CDDAA59CAA75B9CC94CFE8A7C4E29AC6E69AD3F2A4DDF8ABA8B9736E79376C6D3357581F
5B612575793C5C571D57571B96A763C7E29BCEF0A6CCE7A0DCE7A39DA461DEE9A5CEE59D
BDE697CAF7A6C8ED9FC2E096D4EDA9C2D897B9CE8BECFFBCCCE099CFE39CC9DA93A9BA73
8D9E57889C54586E265067217C964FA4BF7AC6E19ED6EFABE2F6AFAEBF78D0E79FCAE59E
C3E29CCFF0A9C5E4A0BFDC9AC6DF9ECBE1A0E4FAB9CAE39FC4E29AD5F7ADB5DB8EC2E89B
CFEBA0C6DE94C9DF96BDD38AB3C77F475B13D2E39CDEEEA7D4E49DA6B770859951D5E9A1
D5EBA2C9E197CEE69CDAF0A7D1E59DD1E29BD2E79CD7EDA2D0EB9ECFEC9CD4F3A3D2F1A3
BEDA8FD8EFA7D2E6A1D1DFA1DDE7ABE0E5ADCECE9AD0D59DD2E1A0D8ECA5D4E4A3ACB576
8B824BAB9E69E7E1A7CDDD9CC3F8AAC8F7AF939161968162FFF5E2FFFDF4FFFAFDFFF9FC
FFFAF6F6E2D9ECD8D1E5D1CAFFF9F4FFF9F4907B7857423F
F4FFF3D5E8D4748572C7D6BFC3D3B6CDDFB9D3E5B5CFE3A8CFE6A0CCE999CAEB94C8EC94
C5ED95C3ED99C1ED9EC2ECA0C6EB9EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99E
C9E99DC9E99DC9EA9BC9EA99C9EA99C9EB97C9EB95CCE7A2E8F7D0F8FFEDFAFFF4F7FCF8
02030800000BF8F7FFFEFDFFFCFBFFF7FAFFFAFFFAF9FFF1F5FFE3DEF1C3CFE4ACCCE2A4
D1E3A5778748DEF1AFD5EAA7C8DF99CFEBA1CAE99DCBEB9FC9E99DC9E99DC9E99DC9E99D
C9E99EC9E99ECAE8A0CCE89BCBE790C9E88BC8E98EC9ED96C8EE9BC7EC9FC8E7A1CAE4A5
D5E8B0CCDAA7D3DEB398A27DD3DDBBD7E4C6F7FFEAF5FFE3D6EBB2C3D897A5B77B000B00
C5D39E98A972DBF0B5CEE8A7D6F8AEC3E89ABFE592CFF2A0CDE79DCBDF98D9E5A5CED89B
CCD697D9DFA1A5A3689A9B5FC4D893CCEAA2C3E79DC7E59DD8E39F959C59CCD793D6EDA5
C8EFA0C3EE9EC4E699D3EFA5C9E09C4A5F1E9FB4711B300051651E576B24495D15596E23
9FB469C8DE93CDE59BCDE79DD3EFA5CCEAA2CAEAA1C6E19AD3E49E97A45FD1E59ECCE39D
C9E49FD0EEA8C4E19E94AF6CD0E6A5D2E7A6C6DB9AC6DD99DDF8B1BBDD93CCF2A5D0F5A8
C6E599D1EBA1DCF4AAD6ECA3C1D58DC8DC94E2F3ACC4D58EE1F2AB7A8B44CFE39BD0E49C
CFE59CDAF2A8C4DC92CCE49AD8E9A2CEDF98D6E7A0CDE297DCF2A7D3EB9FAFCA7DD3EEA1
DBF3A9C9DF97CADB97D9E5A7CFD79CE4E9B1BFBF89C3C88ECBDA97E3F4AECFDF9ED0D99A
9C935C978A55EAE4AACAD996BAEDA0B8E69E908E5EA38E6FFFFBE6FFFEF2FDF9FAFFFBFE
FEEFEAFFFAF3FFFAF4FFF4EEFFF2ECFFF5EFFFF5F1FFFAF6
E8FCFAF2FFFF879794E5F5EBF6FFF5F8FFEDF8FFE3DEF0BED0E4A5CDE79DCAEA95C8EC94
C5ED95C2EE99C1EE9DC2ED9EC8EA9EC9E9A0C9E9A0C9E9A0C9E9A0C9E9A0C9E8A2C9E9A0
C9E9A0C9E99EC9E99DC9EA9BC9EA99C9EB97C9EB95CCE7A0E7F6CFFAFFEFFAFFF4F7FCF8
07080D00000BFEFDFFFCFEFFFBFEFFFBFFFFF9FFF6F3FFE6DEF4C5CAE4A7C6E49CD2EEA3
C8DE96879854D1E5A0D6ECA4CBE29ACDE79ECEEAA0C9E89CCAE89EC9E99DC9E99EC9E99E
C9E99EC9E99ECAE8A0CAE99BCBE991C8E78AC7E88DCAEE96CAF09DC8EDA0C9E8A4CFE7AB
D7E7B6D5E0B6E8EFCDC6CDAEF7FFE6EFFCE2F5FFEBF5FFE4C5DAA1E4F9B85C6E32000C00
616F3ACFE0A9C9DEA3CAE7A5C7E99FBCE392BCE692C4EB98C9EA9BD2ECA2DAEFAAD8E8A7
D8E7A6D9E3A495965A9B9F62D3E8A3D0F0A7C4EA9FCBEBA297A45FB4BB78D2DF9AD4EBA3
C1E899C0EB9BC5E79AD2EEA4D8EFABD0E5A4CEE3A0CCE19CCADE99CDE199CEE29AC6DB90
BFD58AD6EEA2D4EFA2CEEA9DC6E599C6E69BC7E99DB1CD83909C5A919C5ADAE9A6D2E6A1
C5DC98D4EFAADEF7B5BDD694AFC483E2F7B4C8DB99C9E09CCEE9A2D3F3AAC3E89BC3E89B
CFEEA2C1DB91D2EAA0869E54ADC37ADFF3ABC3D48DDBECA5B6C7809AAB64DDF1A9D1E79E
D3EBA1CAE298DDF7ADA2BA708EA25A75863F697A3350641C768C4192A85D829A4EC8E096
D4EAA1D4E8A1C9DA96DAE9A8EEF8BBE9F1B694995FACB478D1E09DD5E6A2D1DD9D9A9E61
675E27A89D65E1DDA0D6E7A3C1EFA4CCF4AEA8A475A39072E9E8D3FAFFF5FCFFFFFCFAFD
FFFDFAFFFDF4FFF4EEFFFCF6FFFCF6FFFBF5FFFCF6FFF8F2
E7FFFFEDFFFF95A9B0C9DCE0ECFCF9E9F9ECF5FFE9E6F7CDD0E3ABCFE6A0CCE999C9EB95
C6EC97C3ED99C2ED9BC3EC9EC9E9A0CAE8A2CAE8A2CAE8A2C9E8A2C9E8A2C8E9A4C8E9A2
C8E9A2C8EAA0C9E99DC9EA9BCAE999CAEA97CAEA95CDE6A2E6F1CFFEFFF4FEFFF8F9FBF6
08090B000005FCFFFFFCFFFFFBFFFDF8FFF3ECFCDFDBF0C5C8E4A9C0E097C3E694CCEE98
CDE3989CAD66ADC179CDE39BD2E9A1CAE49BD0EAA1CAE69CCCE7A0CAE89ECAE8A0CAE8A0
CAE8A0CAE8A0C9E9A0CAE99DCDEA96C8E990C8EA93C8EC95C4E999C5E79DCFECAADDF4BC
DDEDC0E6F0CDF8FFE0E2E8CEFBFFEAF8FFEAE6F9DBD9F0C6D7EFB3BFD4917D8F51000D00
D6E3AEC2D09BDBEEB6D2EBAAC8EAA0C7EE9FCCF6A2C9F19BC6E997C9E89AC8E299CADF9A
D1E4A2D9E5A59094579AA062D6EDA7CCEEA4BEE499C2E299515E19E1E8A5D8E5A0CBE29A
BAE192C3EC9DC9E99DC8E299C9E09CD9EEADC9DE9BD3E8A3D3E7A2CDE199D9EDA5D5EA9F
D5EC9ED1E99BCBE697CEEA9DC9E99DD1F3A6C5E79A88A45A626D2BB1B779D2DC9DDDEDAC
D6EBA8D3ECA8859C584B621E000D00D1E4A2CBDB9AE4F9B4C8E29BB3D38AD4F9ACB8DD90
CDECA0B8D288465E14B8D086DDF3AACEE29ACEDF98D4E59E97A861CFE099C3D78FD5EBA2
D5EDA3BBD389D4EEA493AB61CBE198CCE299D5EBA2D0E69DD9F1A7CFE79DA0B86E99B068
9FB56DD4EAA2CDE19CDAEAA9FCFFCCE0ECAEABB578D4E2A4CCE19CCCE09BE7EBAE8F8A50
685F26DAD49AD9DE9ECFE39EBAE299C8E5A393875D503F2163715898AF9FF2FCFDFCFFFF
FEFFFDFFFFFAF4F5EFF0F1EBFEFFF7F9FAF2FFFFF8FFFFF8
E7FFFFDEFEFF8CA8B4B3CCD3F0FFFFE4F7F1E4F7E3E6FAD7CFE3B2CFE5A7CDE79ECCE999
C9EA99C8EB99C6EB9BC6EB9ECAE8A2CCE6A5CCE6A5CAE7A5C9E8A4C9E8A4C8E9A4C8E9A2
C8E9A2C8EAA0C9E99EC9E99DCAE99DCCE89BCCE999CFE5A7E2ECD1FEFFFAFEFFFAFAFCF7
060803000100FCFFFAFBFFF4F9FFEFEBFAD9D5EBBDC8E1A8C7E6A2CAEF9FC9F199C8EC94
D2EA9CA5B76D8A9E56C2D68ED8EEA6C8DF99D1E8A2CDE6A2CDE6A2CCE7A2CCE7A2CAE8A0
CAE8A0CAE8A0C9E9A0C9E99EC8E799C8E797C9EA99C8EB9BC4E99BCAEBA4DFFBBEF7FFD8
FBFFDFFEFFE4FAFEE5D7DDC3EFFADAF4FFE0D9F0C6CAE2B0CEE4A4D5E8A68A9A5C000A00
D1D9A6D2DCAAD9E8B1C6DA9DC9E7A1C8EA9DCBF19EC1E792C3E694CDEE9DCEEA9FD3EAA2
C7DB96DAE9A893975A939C5DCCE39DC6E89EC5EBA0D1F1A8424F0AF5FCB9C9D490D4EAA2
CDF2A4BDE697C0E094D2ECA3CFE6A2D1E6A5CDE29FC9DE99DAEEA9D1E59DCFE39BCCE196
D2E99BCBE395CCE798D1EDA0C1E195CCEEA1C8EA9D84A0564D5718E0E4A7D0DA9DD5E4A3
C5D896CEE5A16E85415F7431273700CDDE9ADFEEABCADE99D5ECA6CAE8A0CAECA0CAECA0
809F538EA85EB6CE84CDE59BCEE49BC6DC93C0D48C90A15AB4C57ED7EBA3CEE49BD0E69D
C8E096D3EDA38CA65CA8C278CEE89ED0EAA0CAE49AC9E399C8E298D1EBA1CEE89FA4BB73
8DA45CB9CF87CEE39ECEE29DC1D49294A463C9D99AD6EBA8D5F0ABCEE39ED8D69B7D7039
60571EDDDD9FD6E5A2CDE79EC7E79ED4E6A8AF9D755D4E31213B20244938ACBEC0F9FFFF
F8FEFEF7FDF9FCFFFDFBFFFDFCFFFBFAFFFAFBFFF9F5FCF4
C4EFF6A9D4DB173D46E0FFFFDDFCFF56736F91A99BE1FADDD7EEC4E0F7C1C5DE9CD5EFA6
C8E396CAE699CFEEA2D4EFA8E9FFC3C3DB9FD0EAADC8E5A5CAE9A6C6E5A1CAEBA6C5E69F
C8E9A2C7E99FC9E9A0CAEAA1C9E79FC9E49DCBE59ED0E2AEF6FDEDEBEDECFEFFFDFEFFFA
0002003C402FE8F1D6E7F2D0E2F1C6EAFEC9CEE8A9BEDC96D2F4A7C9EF9CB9E189CEF29B
CFE799CADF9491A55DB1C57ED0E49FD6EBA8CCE1A0D2E8A7D1E7A7CEE7A6CEE9A6D1ECA7
CDEBA3C7E59DC5E59AC9E9A0CAE8A0C9E79FCBEBA2CCEEA4C4E8A0C6E6A3E0F9BFF7FFDA
FBFFE1F6FDDEF2F6DB9CA384DAE6C0E2F3C6CEE7AECFE9AAD6EBA8CDDD9C717C42020900
D6D9AAD7DAABD6DEABD5E2AAD4E9A6D2EEA4C0E190D0F39FBFE18DCCEB9BD3EEA1C6DE94
D4E8A3D2DE9E6061259EA466CDE29DB9DB91D8FEB3C5E59C4E5B16CDD491E4EFABCCE29A
C2E799D0F9AABFDE92CCE69DCDE4A0D0E6A5D1E6A3D5EAA5D8ECA7CADE96C7DB93D9EEA3
D6ECA1C6DE92CFEA9DCFEBA0C4E397CAEA9FCBEDA1CBE59E96A063DBDFA4D3DBA09CAA6C
4D6020253A0098AD6ACEE29DB6C582849350E2EEACD6E7A1CFE59DD2EEA4C4E49992B468
C2E195D7F3A8D1EBA1CCE49AD4EAA1C6DC9394A860CFE39BCFE39BCEE29ACDE39AD2E89F
DAF2A8607A30D7F1A7C8E499C1E094CBEA9ED6F5A9C9E89CC4E096D6F2A8CBE69FCBE59E
CEE8A1B0C7818CA35D4D641EA5BC76CDE7A0CFE8A4CDEBA5C7EDA4CBE4A0DFD69D604C17
5F591FE1EAA9CEE8A1C6E49ACCE39DDBE0A6AF97715F513670977A2C5F4CDDF5F7848C97
F8FDFFFCFFFFFEFFFFF5F9FAFEFFFFFCFFFDFCFEF9F0F5EF
70A39E53848075A3A1CAF6F7B6DCDD4D706CAECEC3EBFFF2F0FFEAD4F0C0CEE7ADBED795
D7EEA8C3DB91DCF4AAD6EDA9F2FFCECFE3AED8EFB7CBE5A8CBE8A8C7E6A2CAEBA4C6E89E
C9EBA1C6E89EC6E69DC8E6A0CBE5A4CDE5A7CFE4A9D2E1B8DCE1DAFEFFFFFEFFFFF9FCF5
000300121800C3CDA8CFDCAED4E5AED3E9A8CDE8A1C7E79BC7EA9AC5EB98C4EB98CCEF9D
DBF3A5D8EDA2C5D991A5B974C4D795BFD193DFF1B5C4D89BCDE1A6CDE3A5CAE3A2C8E3A0
C5E39DC8E69ECBEBA0CFEFA6CAE7A5C7E5A5C9EAA5CBECA7C5E9A3C6E6A3DBF4BBF5FFD9
FCFFE3FDFFE5F6FBDD9EA583E5F2C6DDF2B9C0DE98C5E197D3E8A3CCDA9C8F985F191D00
B3B286DDDCB0F3F5C6CCD39FC8D699D5EBA3D4F0A3D0F09DC5E592D6F3A1D9F1A5D5EBA2
CBDC98E5EFB04E4E12AAAE71DBEFAAD5F5ACB9DD93D0EEA645500CF0F5B3D1DA97C5DB93
CEF3A5B5DE8FD5F4A8D2ECA3D1E8A4CFE6A2CCE19EC9DE99D1E59EE1F5AEE1F5ADD0E59A
C9DE93DCF2A9C6DE94C9E39AE0FAB3BAD58EC6E49ED5EBAABFC98DA9AE74D6E0A46A783B
5E71317A8F4CC8DD9AD8ECA7D7E6A399A661A8B570D6E5A0D6EAA3C0DA91B5D3897A9A4F
CDECA0CEEA9FC8E298CEE89ECEE69C94AA61B7CB83D0E49CD8ECA4CFE59CD0E69DD7EFA5
BBD58B809A50B5D186D9F8ACD5F5A9C7E99CC9E99DC7E79BCFEDA3BCD88EC9E49DD9F3AC
CBE59EC6E099BDD7909DB770CDE8A1D1EFA7CBE9A1C7EBA1C2ECA2CFEAA5E6DBA369541F
5F5A20DEEAA8C2E096D0F0A5CCE09BDFDEA6AD8F6B66583D7FAE8E407E69E7FFFF8A94A0
E5E5EFFAF5FBFCF7FDFFFDFFF7F3F4FFFEFBFFFFFAFFFFF8
CAFEE7BAEED8D6FFFAB0DFD56C9994B9E4DDE0FFFFE6FFFBDBFFE3D6F9D1D0EEBCD9F5BA
C9E2A1D9F0AABFD38EF0FFC4F9FFDAE0F1C5E3F9C8CDE6ADCBE8A8C7E6A2CAECA2C6EB9E
CBF0A3C9EB9FC7E6A0CCE9A9D6EFB5DFF6C2E4F5C8E4F1D3EDF1F0FEFEFFEAEBEDF9FCF5
0F130223290DEEF9CFEDFBC6CDDFA1C4D994CDE79ED0EFA3C2E296C3E89ACCF3A4C5E79A
C8E096C9DD95DCF0ABC3D694BDCD8F9EB076DDEEB7F0FFCCE7FAC3E7FCC3DCF4B8CDE7A6
C4E29CC9E79DCCECA0C9EBA1C9E7A7C6E4A8C7E7A6C9EDA7C9EAA5C7E6A3D5ECB4E5F7C7
F3FDDAFEFFE5E6E9CC717954CAD8A5D0E6A5C6E693CAEA97D2E8A0D6E4A7919864040600
E2DFB61D18000B0800C4C695B2BB82526221152D00AAC576D4EF9EC6E190BFD78BCADE96
DFEEABCED798838146E3E4A8CDDE9ACAE59EBEE096CFEAA367722ECBD08ECAD390D0E49D
D6F8ABB1D889CFEEA2C4DE95D9F3ACC7DE9AD5EAA7DBF0ABC9DD96CDE19AC1D28B8A9B54
D3E49DE1F2ACC6DA95C6DB98CADF9EE7FDBCD8F1B0D5E9AAC4CD946C743BD1DCA23B4B0D
677C3BBFD692DBF0ADC9DD98CBDA95E1EEA88C9752D6E39DD3E49E98AE667B954CD2F0A6
D5F1A6C5E196CCE69CD0EAA0ADC57B8FA75DCEE49BD1E79EC8DE95D5EBA2DCF2A99AB268
9CB66CD0EAA0C7E398C2E195C8EA9DC5E79ABDDD92C6E49AD6F1AACEE8A1CCE39FCDE4A0
D8EFABDCF3AFCBE59EC1DC95CBE99FC0E095C8EA9EC9EFA2BEEA9DD1EFA9E4DDA67C6B35
5B5B1FCAD996BBD98FD2F2A7D7E8A4DBD8A1BA9976998B70ABD9BC387764D2F8FBE8F6FF
A59FABF6E6F0FFF7FCFFFAFDFCEEEEF1E3E0968981FAEDE4
BBECBFBEEEC67CAD8F4879631E4E40DFFFFFD8FFFDD9FFFAE2FFF88FB896B4D9ADB8D9A4
D1EDB2D1EAA9CEE3A0E6F8BEF9FFDFEFFFDAF1FFD9CDE5B1CBE7AAC7E8A1CAEC9FC7EC9C
CBF0A0C7EC9FC7E6A2CEEAAFE1F9C7F3FFDDF9FFE6FAFFF0FAFEFFFBFBFFFEFFFFFEFFFB
0003000A0F00F8FFDFFCFFDAD9E8B1CFE3A4CFE5A4D0EBA6CDEBA3CDEFA5C9EDA3C2E299
D9F0A8D5E9A4C3D694E7F9BBDFEEB5DFEDB8D4E2B1EBFBCAF9FFD8F8FFD6EFFFCBD6EEB0
C9E49FCBEBA0CBEB9FC3E599C9E7A7C5E5A6C4E8A2C8ECA4CAECA2C8E7A1CEE6AAD8E8B9
F1F8D6F0F5D7F0F3D6424A23D0DFA8B6D087DFFFA8C8EB91CAE199E0EFB49EA673030600
DCD8B34D4723080300565529717844D5E3A552682099B467C1DC8DD6F1A2CEE69AE7FBB3
CCD79563672A969056DCDA9FD3DF9DD2ECA5DBFBB2C9E39CC8D18E6B6D2CE5EEABD1E59E
BEE093DCFFB4B2D185D5EFA6BED891D7F1AA8AA15B43581350641D43571061722CD9E8A3
909F5A4D5C19DBEAA9D8E8AAD7E6ABC9DBA1C8DAA0CBDAA1E3ECB79BA46DDBEAB144581B
657B3BC9E09CD2E9A3CEE29BD9E9A2CFDC969FAA65D5E09B8E9D58D7EBA4C2D991C6E298
CFEBA0C6E297D8F2A8CDE79D8FA75DC5DD93CCE299D2E89FDBF1A8BED48BD5EDA3859D53
C0DA90D6F2A7CCE89DC9E89CC7E79BCFEFA3CDEBA1CCE89EC5DC96D7ECA7C0D391DFEFAE
C7D796D4E7A5C4D994CEE8A1CDE99FC4E498D0F2A5C2E799BEE89CCFEEA8D6DA9F9C975D
5B5F22A9B671CAE298CCE69CCCE099E3E4ABAF916D49371F658B72104A3B7CA8ABEEFFFF
F4F1F8B5A5A899898A7B6C69BEAFA8FFFCF1514434A89B8A
C4ECADC1EAB099C49687B59176A791C4F8EBDBFFFFD7FFFFCAFFEE5C9175B9E9C3CAF4C4
BDE3AAC4E4A5DDF7B6DDF2B9F9FFE4F9FFEAF8FFE3CDE3B2CBE7AAC8EAA0C9EC9CC8EE99
C5EB98C2E799C3E29FCAE5AEE0F5CCF7FFECF9FFF3FBFFFAFCFFFFEFF2F7FEFFFFE9EBE8
000200333729F6FBE7F6FFE2EAF6D2E9F9CCD0E2AEC9E1A7E3FDBEDDFAB7C5E49EC7E59D
BFD690E4F9B6C5D799DBEDB3D2E0ADF7FFD4D6E3B7F6FFD8E3F3C6E9FBCBE3F7C2D0E8AC
C9E4A1CDEDA2CEEFA0C6E89BC8E9A2C6E7A0C4E99BC7EC9CC9EC9AC8E89CCAE3A2CFDFAE
E8EFCDFFFFE7C5C8ADAEB691BCCB94E6FFB6BCDF81CAEF90C2E096D6EBB0808E5B171C00
4E4B282B26060C0800D4D2A9D6DDAAB3C186798E49CDE79DC8E394CAE596CFEA9DC4D890
B7C07F504E13CCC189DFD99FDCE7A5D0E5A0C2DD96CDE49EE9F0AD9292528E9552A3B770
89AB5E82A95AD5F4A8D1EBA2819C5586A0598AA15BA7BD75D2E69FD5E6A0C8D792D4E09E
A1AD6D465214D6E1A5D8E3ABD2DCA7D9E6B1D0DCAABBC795B4BE8ACAD7A1D7E9AF95AB6D
98B170CFEAA5CAE49DD1E79FC7D79094A159D5E199C4D08887944EDCEDA6C9DF97D7F1A8
C8E499CDECA0D1EDA2CBE59BA5BD73E1F9AFCDE39AD0E69DDBF1A8C9DF96D9F1A79BB369
D0EAA0BFDB90D0ECA1CEEDA1D1EDA2C6E297D8F2A995AB638E9F5B98A766909A5DCED89B
CED89BE8F4B4D9E8A5D6EAA5CCE39BC6E297D1F0A2BFDF93C5E79DCFECA9C5D898C0CC8C
70793A8D9653E7F2ADCFE099D7F1A8C6D195AB916E846E57EBFFEF689A8E3A6D70E4FFFF
FBFFFFFFFDF8ECE3DAFFFEF1FFFFECFFFFE8FFFFE3D9D4B4
CDEC9CCAECA2C8ECAFC0EABC83B4967CB3A0CEFFFE87C5BA4A8A7A75B39AB1EAC78ABE90
81AD78C0E8AAC1E4A2E4FDC6F1FFE3F9FFEFF8FFE6CBE1B2CBE7AACBEBA2C8EB97C7ED96
C5EB94C7EA9AC6E5A2CAE5B2DEF1D1F6FFF1F9FFFDF9FFFFFCFFFFFCFFFFECEDEF8E8F91
040507888A89FEFFFBFEFFF8F6FDEBFBFFECDAE8C4CFE0B3EDFFCCE4FEBFC5E39DD0EBA4
D0E7A3DFF3B4CDDFA5A2B37D818F5E7F8C6099A47CE7F2CAD0DCB4D5E5B8D5E7B5CBE3A7
C9E4A1CBEBA0CDEE9FC8EB99C8EA9DC7EA9AC4EA95C5EC93C8EC94C8EA96CCE39FCDDEAA
EFF5D3C0C3A8BDC0A5CED5B3E9F7C2C6E096C1E486C9F191C6E89ECCE8ADD4E6B4000700
D4D5B30F0C00100D00DDDDB7D9E1B089985DC5DC98CCE89DD6F2A5CBEA9ACCE89BD9EDA5
AAB0704F490FCDBE87EDE2AAC5CB8BE0F4AFCDE7A0DAEFAADEE3A1CDCD8DE4EBA8DAEEA7
CBEDA0BEE596BCDB8FC6E297C2DE94DBF6AFD8F2A9CCE39BD5E9A2D8E9A3D6E2A0DEE8A9
858F5261692ED0D7A1DFE6B2D3D9A97A805250572B0912007C8856D3E4AECEE3AAD4ECAE
C9E6A4D1EFA9C9E49DC8E096DEEFA85C6820D5DF988A944D98A35ED6E69FD2E69FC8DF97
C8E499D4F3A7BEDA8FCCE89DCDE59BCAE298D9EFA6CDE39AC9DF96D0E69DB0C87EADC77D
C5DF95CDE99ED7F6AAC1DD92CDE79DC3D990D1E59E45540F7E88498D9657868A4F76773D
9FA066C8CE90D9E2A3D0DF9AD5E9A1CDE599D2ED9ECBE79ACCE7A0CEEBA8BFE09BD0EEA8
99A565848645EBEAA9D9E39EC6E69BD2E8A8AD9772614834F9FFF6CBF3EB4E888AC0F3F4
F1FFFDE9F0DEFCFFEDDAE3C6C5CFACD5E0B6D3DFB1D2DEAC
C8DD80D1E993CAE8A2C5EAB492C09CA3DAC3C6FFF765A99E307769559D8777BA9917542A
84BB84A8D89CBDE7A5D1EFB9E1F1D7F7FFF1F8FFE8CBDEB1CDE7AACCECA1C7EB94C6ED92
C6ED94CBEE9ECBEAA7D0E8B8E2F2D7F7FFF9F9FFFFF9FEFFF4F8F7FCFFFDFCFEFD7A7B7F
000007777783F7F5FFFEFEFFFAFEFFFBFFFAECF8E4E1F0CFE4F8C7D9F1B5CBE6A1CFEAA3
BDD3928195588E9F6888996595A2769AA57DCBD5B2F9FFE0D2DEB8D2E1B6D3E5B3CFE7AD
CCE7A4C7E79CC7E897C7EA96C8EB97C9ED95C6ED90C4EC8BC6EB8BC8EA93CFE69ED0E1AB
EAF0CC999C81A1A38BE6EDCCDCEAB7BED891C9EC90CDF497D1F7ACBCDEA1BCD4A00B1A00
DAE0BE222304040300D7DBB6E2EBBC798B51CCE5A3D5F3A9C3E397C4E596D7F6AACBE199
A0A56551480F786731A89B64929757D1E29ECDE7A0CADE99D8DA99E6E5A5DDE2A0D4E59F
C3E598C3EA9BC6E69AD8F4A9D0ECA2BDD98FCFE9A0D6EDA5C3D790D7E8A2E7F3B1C0CA8B
9FA76C6A6F37ECF0BDD4D8A69B9E71030500272902161D00758352BED19AD5EDB3CDEAAA
C7E6A3BCDB95D3EEA7CEE69CA6B770929E56DDE7A06D7730A3AE69D2DF99CADB95DCF2AA
CBE79CD0EFA3BEDA8FCFEBA0BED68CBFD78DD8EEA5CEE49BD8EEA5ACC2796E863CD0EAA0
D4EEA4CAE69BC5E498CFEBA0D5EBA2D3E49DB5C27D565F1CB7BB7ED1D195C3BE867B763F
6A652D88884CB0B175AAB370DAE7A1D1E399CBE093D5EBA0D0E49FCFEAA7BDEDA3C1EFA4
BCCC8B7E7D3DC3B578DEDF9DBFE89AC6E9A59E8F68705341FFFFF6D5EFEC37747560A39C
E4FFF8F0FFECF0FFE6C3E0B4C9E7B5CCEBB2BCDC9DD6F6B3
D2E782D0E88AD2EEA1BBDFA2C8F5CEADE2C879B6A42669575B9F88286E4C76B78CAAE6B0
C1F5B5B5E49EC0E8A1CEEDB1D8E9C5F4FFE5F8FFE3C7DDACCDE7AACDEDA4C7EA98C8EC95
C3E692CAEA9ECCE9A9D1E7B9E1F1D7F7FFF8FBFFFFFAFFFFF7FCF6FBFFF9FEFFFDA5A5A7
100F17807E89FFFDFFF8F8FFFCFFFFF8FFF5F9FFEDF4FFDFD6E8B6CBE1A3D0E7A1CCE39D
BBCE8E8C9E62C8DAA0DAEBB5D5E5B4EAFACDF9FFDDD9EABED2E3B6CFE3B2CEE5ADD0EAAD
CBE8A5C6E49AC6E798CAEB9ACAEC98CBED97C9ED93C6EA90C6E891C9E898D1E7A6D3E4B0
E7EFCA999D82A9AD92FDFFE3D3E0B2CDE1A2D7F4A4BFE08FBFE09BCEEBB1D5EBBA000800
D9DEBE232307050600DADEB9CDD6A7B5C78D90A665C0DC92D5F1A6CCE89BC6E194D4E8A1
D2DB9CE4E3AAAAA168787236545917424D0852621B9DA762A5A1619E9657B9B878DFE8A5
C8DE96D5F1A7CFE69EC9E098CFEB9ED3EFA2C8E298CBE29ADBF0ABD1E1A0CAD89AE4EFB3
929D6397A069CDD69FDCE5B0191F00A8B081949A6E5F68390612004E5F28CBE0A5C3DD9E
D6F1AEC1DF99DFFAB3C8DF97DDEEA7505D158B974FDFEAA5CAD791D5E49FDEEFA9C9DF97
CDE79ECCE89ECEE89FD1EBA28BA25AD4EAA2C9DF97D1E79FCFE59CB6CE84859D53D3EEA1
C5E194CBEA9CCFF0A1CCE79ADAEAA3CCD5927D8441979D5DDBE0A0DFDFA3DFDDA4DBD9A0
D5D098ABA96E8F8F515A5C1B959C589CA65FABB870DAE7A1D4E0A2D1E5A8C7F2ABB2DC94
CFDF9E7776368B8042D6D795BEE497DCFBB89E8A65664330FAEDE5F4FFFF7EB1B245827B
90C0A89EC6A3C1EAC0C4EEBEBFE7B2C4EEAFC4EDA9C0EAA2
D4F489CFEF8EC0E393C4EAADCBF6CB93C2A23C715583BA9ABCF5CA83BD83C0F5B1AFE091
CAF4A0CDEF99C7E490CEE69CD5EAAFDCF0BBDDF4BCD4EDB3C9E6A6C7E4A1C8E89FCAEA9F
C8E69EC9E4A1CAE2A8D2E5B8E3F2D5F4FFF1FBFFFFF9FFFFFBFFFAEFF5E9FFFFFA757470
030000858180FFFFFAFBFFF1E3EDD4E8F8D3E2F6C5E6FBC2C3D798CCDF9DE8F9B5ADBC79
6A7938E3F3B4CEDE9FCEE2A3CFE5A7DCF4B6D2ECAFD5F1B4D3F0B0BCDA9ACBEAA7D2F1AD
C7E59FC6E49CC9E49DCEEAA0C8E69ECDEBA3D0EBA4CCE7A2C9E1A3CCE4AADBEFBEE9F8CF
F5FFDDB9C3A1C5CCABF9FFDED4DFB5DFEBBBCEDDA6CFE1A5D5E9AEC9DCA5D1DDAF070D00
D9D8BA312D12070300D9DAB8D8DFB3CDDAA44D6020AEC27BCCE196D3E599DDEBA0D1E19A
D2E6A7CCE0A3DAE6A6B3BD789FA55B75772C6563185D550C6755136D5B1D7F6F3490854D
B6B479DCE0A5DFE5A9DBE8A3C2D987DDF9A4C7E293D3EDA4D8EEAEC5DA9FD6E9B1CCDFA7
A9BD82B6CA8DCCE0A1D2E6A7000E00F6FFCB93A5698C9E62283300030E00D3E1A4CDE0A0
D1E4A2D7ECA7C4DB93D4EAA2CCE09882964E8FA059CADB95D9EAA4D0E19DCCDD99D3E7A2
D7ECA7CEE59FC5DA95D9EEA9899E59CCE09BD4E8A3D0E5A0CFE59D8CA45AA4C073B9D888
D8FAA6C2E68FC9EF98CFEA99D9DE9BB9B5785B5D1ED2D898CDD695E3EEACD5DE9FDEE4A6
D9DDA0E4E4A6CFCD908886495655155D5D1D787A398F9356E1E5B3D0D8A7D6E5AEDBEAAF
DAE3A49398555D601BA9B56DC7E59DDDEBB0AC8868946959CDC1B5F8FFFDECFFFF557874
517B677DAA8DBFEBC8BCE6BEC0EABAD5FCC5BFE6A7C9EEAB
C6EA8AC1E58DC6EC9FCEF6B7A8D2A08AB78C93C298B4E5B6ADDEA6619250C3EFA4D1F8A7
C8EA96CAE692DFF5A3D5EA9DCBE29ACFE8A4D1ECA9CEE9A6C9E6A3CBE8A5CEECA6CFEDA5
D2EDA6CFEAA7D0E5AAD5E9B8E6F4D3F7FFEFFBFFFAFBFFFDF0F8EDF6FCF2FFFFFB191512
040000817C78EDEBDFFEFFECD3DFBBD4E8B7C5DDA1C6DF9DE7FCB9BDCE8AD4E0A096A061
6B7737DAE9A8CFDF9ED9EEABD1EAA6CBE9A3D7F6B0CDEEA7BFE39BCAEEA6C5E69FBDDE97
C7E59FD4F2ACD3ECA8C3DD96C8E49ACBE79DCFE8A4CEE7A6D0E5AAD5E9B4E1F3C3EAFBCE
F5FFD7FBFFDDB6C197C8D4A6C7D0A1D3DDABDBE3B0D5E2ACC7DAA2DDF2BAD3E3B4000700
B6B99A56563A010400D3D9B3DBE9B8D2E6ABCDE2A19AB068D4E8A0D0E298D0DD95D8E9A3
D8F2B3C1DFA1C9E49FC6DC93DBE99CD4DB8DD9DA8CDDD78DE6DB99E9DEA0ADA069A59A64
B6AF797F79454F4E184C5212768938C1DB84C9E193CBE29ACFE5A7C9DEA5D8EDB5C7DCA4
ADC287D3E9ABA8BE7D000F00D5ECA8CFE6A2879E5AD1E6A5CEDC9FAAB87BD8E8A9CDE09E
D1E4A2D7EEA8D3EAA2C9E39ACCE69CC5DF96CFE9A0D7F1AACAE19BC7DE9AD6EBA8D5EAA7
D0E3A1C1D492E2F2B3A7B778B3C384FAFFCBFBFFCCC5D596D9ECAA9FB670ADC77DC6E295
D1F19EC9EB95C6EA93CAE594DADF9CA7A5688C9151EDF9B7D2E6A1CADF9AD1E6A1D0E49F
D6E5A2D4DD9CE4E9A9D9DB9CD4D697D2D495ABB0709DA0675456275E5D31939161D5D59F
E2E3A79095525E651F99A65ED8ECA7D3D29CD0A185AD786AD6C4B6B1B4ABD4DAD8F4FFFF
9DBEAD113C20325B3BAAD2ADBFE4B8A9CE9AC6E8ABBFE2A0
C4E8A2C8EDA7C5ECA9C0E9A789B57675A365B6E6A8BFEFB1CAF8BA679354ADD493C9ECAA
C6E3A1BFD896CFE4A1CEE39ECCE49ACDE79DCCE89DC9E59BC7E59BCAE99DCAE99BC7E698
C8E595C7E398C9E09CD0E5ACE3F2C9F6FFE7FBFFF3FCFFF8FBFFFAFCFFFBFFFFFF2B262A
040002817B7BFFFFF8FDFFEED5E0C0B6C99CEFFFCEC7DFA1C8DC9DD7EAAAD7E5A895A163
8F9B5DE5F4B3CEDE9DD3E8A5C7E09CBFDD97C7E6A0B5D68FCAEEA6DCFFB8C8E9A2C9EAA3
CAE8A2BCDA94D0E9A5D3EDA4CBE894C9EA91CBE894C9E696CAE49ACDE4A0D3E7A8D6EAAD
D5E4ABD6E5AAEEFCC1AAB87BD7E3A5DAE5A3C9D490D6E9A7C3E3A4CAEDB3C3E1AF000F00
C8DAB45B6B46000900E2F5C7CFEAB3CFEFAEBFE099C9EB9F79994ED1EDA3D2ECA3CFE8A4
C0DE9EC7E7A6D4F5B0CEEEA3D5F1A4CCE798D6ED9FD5EA9FCDDC97DBE7A7C5CD92CED39B
D6D9A4EEF1BCE3E6B1595F2359691EC6DC8ADEF3A8CFE39ECFE1A3D0E2A8D9EBB1C7D99F
92A468D2E4A6D0E3A3CFE2A0D0E3A1C7DA9A9AAD6DCDDFA1CFE3A4D4EAAACAE3A1D0EBA6
C6E19CC5E59CC0E095D2F4A8CCEEA2C9EB9FB5D78DC7E8A1D1F0AAC7E6A2D3F0ADC8E1A0
CBDD9FDCEAAFA6B17949541CF4FFC7FEFFD1DCE7AFDFEAB0CCDA9DA5B576C6D997DAF1AB
BFD98FC9E598D1F0A0C5E093E2EFAA838F4D8FA35ED0EAA3C2E299B9DD93D6FAB0C9EBA1
D0EEA6C6DD97D2E6A1D4E5A1D9EAA6DDEEAAC8DC97CEDC9ED4D4A25E57296A6231221B00
464004999555504F0C989D5AD9E4A2E4DAA5C68D72B27465FFEADBFFFFF1CDCAC3FBFFFA
F1FFF4446548001F001D3D14C9E9B8D2F1B8D9F9BACAEAA7
C0E4B6C9EFBCBFE7ABBDE7A5ACD88D92C173BBE79AC7F3A8BAE4A2B4DA9DDCFDC6C0DCA9
CCE7B4DBF2BED5E7B3CEE2A7CEE7A5CDE8A3CBE6A3C9E4A1C9E6A3CDEBA5CBE9A1C6E49C
CCE89ECBE6A1CEE4A6D5E7B5E5F3D0F6FFE8FBFFF5F7FCF6ECF2EEFCFFFFE0DFE4010005
110A12F3EEF2F7F6F2F5F9EADCE9CDD2E4BAC6DDA9D6EEB4C7DD9FD0E2A6DAE8AD929D63
5A6628D0DF9ED3E3A2D1E6A3C0D995D7F5AFC5E49EDFFFB9B2D68EC5E9A1BBDC95D2F3AC
D0EEA8C3E19BDBF4B0B9D58BCFEEA0CDEC9CCBEA9ECCE7A0CBE6A3CCE4A6CCE1A8CCDFA8
C5D6A2E8F6C3DCE8B6E7F1BD929B64838C53949E62B8C68BCDE6AC92AD78899C6E051400
6F7750343A14000700C9D2A3CFDEA7B8CC8DE5FCB6D8EFA7889C57A3B372C9D597CFDA9E
D4DFA5DAE8ABD0DEA0C6D695CCE09BD3E8A3D8EDA8C4D797DEEEB0CCD79FE1E5B2F9F7C7
CEC698DED1A5E8D7AB605221908A4CE3E29FEDECACDCDA9FDFDDA4DBD8A1DDDAA5D8D59E
B3B079D3D198EEECB3E3E1A8D3D198DDDAA3EAE7B273723C757A40B1B97DDDE5A9CCD697
C0CC8AE7F6B3D0E19BCFE39CCCE099E4F8B3C8DB99D3E6A6D8E8A9C6D698D8E6ABCDD59C
DBD7A7D9D1A2DCD1A4E9DEB1E5DAADDFD4A7F3E8BBDFD4A7ACA475D3CD9BF2EFBAD7D69D
E2E6A9DEE4A4D7DE9BDDE4A1B6B678757738A5AE6DD1E09DD2E7A2CFE9A2CFEAA3BDD790
CDE19CDBEAA7D7E09FDDE3A3D7DD9DCCD594DEE9A7E4E8ABF2E6B4E0CB9EECD7A885713E
57440C918146A49659E4DA9DDDD99CF0D8A8BB735BBE7063FFF4E4FAE5D47D6B5FFCF2E6
F9FFEADEECD2C2D1B23644202E3D12839364BFD09AD5E8B0
6F957C658D6B8CB684C5EFADC8F5A2BBE88DC2ED91CCF49EBDE1996F8E53536F3F4B643C
677D5763785153653B6073466076476078486077495F794C657F506C86566C875466814C
647C48627A4A62744C6473546D7868757B7971747D686A76767B7F64686B44434B010007
07000A030004010000070B00000700000A00001200000D000012000012000E1D00A8B67B
6D793BD5E4A1CADB97CFE49FD5EFA8D9F7AF153500001300CAEEA4D8FCB2CDEFA5CEF0A6
C3E199CDEBA3BBD58E304A09000F00000E00000D00000C00000C00000B00000800000700
0006000005000005001419030D11000004000305001415001F1D000A03003D2F0C160300
190000492C0E3E2100725931A18C5D584711A99A615F5017BDAC78AC9768654C2374572F
A28154B49566B69C6BC9B583BBAE7AA49A67A59D6EA39B6DC6BA90C1B28BA68E6CA98668
D1A588C18E738E553A82492B9C6F46B08A5BA98354AE8859BD976AB08A5DAA8455B58F60
A78152BB9566A47E51B08A5DCFA87DA27B52AC855EB9936CBE9C6F6446146A4C1AB59967
E3CA94BBA46EA18C55B09B64A5925AD4C08BB6A06EAF9968CBB385E5CDA1F1D5ADB6966F
B98E6EF9CAAC855436916042AB785DC28F74B58267AD7B60855638E2B594EFC4A19E7750
F7D2A8D3B183A58556B4946375511F7B5A27A18651A491599C9056A9A0659A9156ADA368
AF9E66CBB67FA08751B19661B59A65A58C56C8B17BA68C59AD8B5DAA8457CAA475BF9968
B18B5ABC9763AE8A56AF8F5CB49A67A87B52D677658E291FE8A998FFE7D4FFE1D0664735
B19F89D5C9B1DBCFB7C4B89E33280C3B30140D04000C0500
254E3E002207497447C8F5B4BAE593C0EC8DCBF393C0E48A99B96E052100000C00031800
031700000A00000B00001500000C00000C00000C00000C00000D00001300001200000D00
000D00000C00000A0000070000050003090900020E00000C0000070C10130B0A120B0811
0400096E69701B1A1841443967745A52643E1B33011831005870342A3E0161703793A166
4F5B1BCEDD9ADDEEAAD6EBA6C3DD96BBD991052500001500C1E59BBDE197BEE096C9EBA1
C5E39BDAF8B0D4EEA7678140607D475E7B4B5E794E5F7A51637955637859647459627258
717D67707964555D46737861595D46797D6426290E64654685835C7B744A9E906B120000
6C52316F512F8E6E48A2855BBBA472B9A46DDAC78DAA975FB19B6AA0875E624422795734
7C572B7351216F5022AB93679A895E61552D61583179714DB2A885C6B597A0866B927055
C99D84A06C56672A15AA7058986D4A7A572D704E218765379775458564317A5924866530
59380581602D7E5C2E664417825F35A38058835F3B704D278B693B7A5828624010745423
9274406C511CA38A548F7842846D398B7543725A2A826A3CBA9F74E7CBA3E4C6A0A07E5B
997050FFD6B69467488F6245C8997DC29379AF8066B38468AB7E61B38868E0B895A27C57
D7B48CC09F74AD8E606545166B4717916D3B896B376B561F6A5B22877D4270662B93874D
897840A28D566B521C785D287F642F765B26A28B557E6731896E396F511B8A6B356C4D17
6E4F199677417A5C287D6330634F1C977045C16953872A19DDA58ADDBA9CF3D4B7A1866B
87735BCCBCA5D1BFA9AF9F885A4A314F412743371D0B0000
5E8B77224E33366338CCF8BDBCE69AC5ED97D5F9A1C4E48FC2DE94C0D998DFF6C0D6ECBD
B3C99BC8DEB0D6EEBEBFD7A3CDE9AFCFEBB1CDE9AFC9E5ABC7E4AAC9E7ABC7E5A7C3E0A0
D0EAABD0E8ACD2E6B3DAEBC1EBF5DCF9FFF3FEFFFFF7FBFEFCFFFFFDFEFF85848A07040B
FFFBFFF8F3F9F1F0ECFEFFF4C8D5B9B5CA9FD5F0B9C9E5A8DBF3B5CDE3A3D1E3A593A364
91A05FDBEAA7CEDF9BC6DB96CAE49DDEFCB4B9D990C5E79DD2F6ACC7EBA1C6E89ECEF0A6
CBE9A1C5E39BCBE59EC6E298CBEB9FCAEC9FCBEBA0C9E9A0CAE5A0C8E2A1CAE0A2C9DEA3
C7D99FD5E4ABA4B179A0AE73909B616E793DA8B275D3E1A6CDE4ACC8E0ACE2F2C3010A00
EBEEC19E9D6F9E9C69DFE0A7D7DC9CD7E09DD7E29EDDE7A8DCE4ABD0D3A4F4F4CED6D3AA
E0DDA6ADAD71787B44C5CC99DEEABCCDDCB3D7E7C2E8F8D4F4FFDFF0FAD7FFFFE2FFFFE1
B9AE8E6252319F8869FFFEDCF6F7CDCCD6A4CAD59DDCE7ABDBE7A5D3E09ACFDC94CFDC96
A7B46FBCC886D0DC9ED8E3A9CAD49FF2FCC8929C68DDE4B0E3E4AACDCD8F909052989A5B
E8EDADD9DF9FEAF3B2CBD694D6E0A1CFD99CD6DEA5E1E8B2E9EDBBFBFECFFFFFD6EFF1C2
F3F7C5F5F9C7AAAE7CA0A374ECEEBFECEDC1EBEABEE6E5B9ECEDC196996AE4EBB8DCE5B0
CED9A1CDDBA0E2F2B4697336B1AF74E5E1A4E3E5A6D0DB99DAEBA7E2F7B2C1D691CADE99
CCDB98E1ECAAD7DD9DE3E8A8E0E5A5D1D797E1EAA9D6DF9CD2D993EBF1ABD1D48FD3D693
DBDD9CDFE1A0EDF2B2C5CE8FCFDD9FE7E0AAD39D79BA7F5DE6CFA3D9D7A4EAECBAFFFFD8
EBEBCF787A64B7B79FF0F3D6DFE2C38E926F91986FA9B086
BAECC988B892346234BBE6B0C8EFB0C7EBA3CDEDA2CDE99ED0EAA1D4EBA7CBE1A1C7DFA1
D1E9ADD1EBAEC3DFA2D2EFAFC8E5A2CBE8A5CCE9A6C8E7A3C8E7A4CBEAA6CCECA3C9E9A0
CBE79DCBE4A0CBE1A3D4E4B3E6F1CFF9FFECFEFFF8FEFFFDFAFFFBFBFDFC838385030004
FFFCFFFFFEFFFAF9F4FCFFF1D3E2C1DFF5C6BCD89DCCEBA8CCE7A2C5DF98CEE3A08FA05C
92A15ECDDC99D4E5A1DDF2ADD2ECA5B5D38BD5F5ACC8EAA0BDE197CEF2A8CAECA2BEE096
D4F2AAD2F0A8C2DC95D9F5AAC6E894C8EA93CAEC96CBEB98CDEA9ACDE99CD1EBA2D5ECA4
D5EBA36E823B63742E8A995497A760BCC981D0DD95D2E6A1D3F1B5B8D9A2C6DEAC000F00
BFC997B7BE8B949C63D9E1A5DAE7A2D3E39CCADB95D0E3A1D4E3AAD7E5B4C6CEA7DBE4B9
8795589EAD6C9BAA71DAEAB9D2E3B9BFD0ACDAEBCBF1FFE2F6FFE4F6FFE1EFF9D6CFD5B1
5D5F3A4C4C28D3D0ADFFFFDEE4F9CEC2E0ACCCE9AFCDEDAABFDF96C8EB9BD2F3A2C8EB9B
83A3585E7F38CFEDADC3E2A6CFECB2B8D79C658248C8E2A5CDDD9EDDE9A7C1CD8B8F9E5B
D0E19DDAEEA9BDD28DD8EFA9D0E7A3C9DF9ED4EAACC7DCA1C9DCA5F8FFD6F9FFD8D1E3AF
CBE3A9C7E1A4C8E2A5ABC48AC8E0A6D1E8B0D2E7AFD4E9B1D6EBB38DA56BC3DDA0CFECAC
CCEBA8C3E49FC9EDA58BA66197A05FD0D595E1ECAACEE29DCEE8A1C4E49BC5E59CD3F1A9
D4EEA7C7DC97D1E29ED3E4A0D4E3A0D0E19DC5D994D2E9A1D5F0A1BEDB89D6F1A2D2EDA0
D3EDA3D0EBA4B6D18CD8F7B3C5EAA5CEE0A2B99A6C7B592CDFE2A9D5EEACC8E5A2C3DCA2
CDDEB285916D97A37DBBC69CDDE8BDBDC999212B00D7E4AE
BAEDB4C9FAC29ECD99436D3B7EA272C6E6B4C4E1ABC8E2A5CAE3A1D2ECA3CEE99ACAE594
C9E696CFEE9ECFEEA0C3E397C9E99DC9E99DC9E99EC9E99EC9E9A0C8EA9EC9E99DC9EA9B
D1EDA0C9E39ACCE2A1D6E7B1E2EEC8F6FEE6FEFFF4FEFFFAFCFFFAFEFFFBBEBDBB030000
FFFAFCFFFEFBF6F6EAF9FFE9CEDEB7CAE3ACC9E8A5CDEDA4CEEDA1CAE699C1D98FBACE86
8E9D58BAC984CFE09AD8EEA6D0EAA1C2E096C4E499CBEDA1BCE194C5EA9DCBEDA1C8EA9E
CAE89ECEECA2D1EBA2CBE79DC3E197CAE89ECEECA4D8F6B0C0DB98D9F3B2C3DC9B8EA466
97AB6EAEC084C9DB9FD8E8AAD6E6A8D1DFA1D2E0A2D5E5A7D4E9B1D0E4AFD6E2B2030600
D3CFA25E5628A69F6BE2DBA4E7E6A6E7E8A6FFFFC6C6CC90DCE0ADE0E1B7B0AD8C7E7F57
CCD69ADDE9A9D2DBA4F9FFD3EDECCDF8F4DBE9E3CDFFFBE6FFFFE6FFF6D95B52316E6844
F4F0CBD2CFACE8E8C6FFFFE3E4F4CFC7DEB0D8EFB9BFD99AD3EDA4D1EDA0C8E394C9E598
758F4896B06FC9E1A7D1EAB1C9E0AA001500294107CFE3A6D8E4A4DFE8A77E874487924E
D9E6A1D6E5A0CADB95DAEBA7D3E3A2CEDE9FD5E4A9D1E0A7D3E0ABFAFFD4FEFFD8D1DEA9
D6EAABC6DC9BC5DA99D5E9AAD2E4A6BED094E0EFB4CEDDA2C9D89DD7E9ADD5E9AAC7DD9C
CCE5A1CCE7A0C6E29871853E99975AE7DEA3DAD89BDAE0A0D4E3A0D0E49FC2D691D5E9A4
CDDC994D5816545A1AA0A666D5DA9AE8EEAECAD593DCF0A9C9EC9AB8E48DD2FCA8BDE795
BAE394CAF3A7B7E197C4F2A9ADE197D4F4B1A49460806C39CEE1A1C7EFA6B4E095C6ECA3
CAE09F98A869909E60D4E0A2D9E2A3D9DFA14E52158B8F52
B0E597BEF0A9B9E6ABBDE7B55E815984A47FCFEBC3CCE8B7C3DFA2E5FFB6C3E18BCAEC8E
CAEC8EBEE183CCEF95D1F39DC9EA99C9E99DC9E99EC9E9A0C8EAA0C8EAA0C9E99ECAE99D
CBE79DC8E19DD3E7AADFEFBEE9F2D3F8FCEBFFFFFAFCFCFAFEFFFAE0E3DA5C5B571E1A19
F8F2F2F8F5EEFFFFF3FBFFE7D0E1B5CAE3A9C5E49EC5E79AC9EA99CEEB99D1EA99D1E699
D1E19AA8B772CEDF99CBE199CDE79ECCEAA0CEEEA3C7E99DCAEFA2C9EEA1C7E99DC3E599
C6E49AC8E69CCBE59CC9E39AD7F2ABCAE5A0D0EBA6B8D390D7F2AFB9D2916F8847465C1C
C3D99BCBDFA0D2E6A9D4E8A9D2E4A6CFE1A3D1E1A2D1E3A5D2E5ADC9DAA6DEE6B50E0F00
8F865D5245199F9363DED39DE2DCA0FCFBBBF1F3B4E3E7ACFFFFD3FFFFD4FFFFDFF6F8D0
D2E2A3CDE09ED3E0AAF4F9D0FFFFE4FFF3E0FFFBEBECDAC6DBC7AEFEEDCF695D37A9A47A
CFD0A8DFE4BCF8FFDBEDF9D5E5F5D1C9DBB3D4E6B4CEE4A6CFE59DD3EB9FD5EBA08FA75D
95AA69C5DA9FCEE0ACC6DAA7000B00000D0062763BD8EAACC7D393DAE5A347540FE2F1AC
D6E7A1CEE29BC7DD95D3E9A1D3E8A3CDE29FD4E8A9D2E6A9D2E3ACF1FFCCFAFFD5D1E2AB
CBE09DD8EEA6E5F9B4C6DA9597A766E0F0AFC2D092D9E7A9D1DFA18F9D5FCEDE9DDCF0AB
D7EDA5D4ECA2CAE298D4E49D6561225A5116DDDB9EDEE3A3D3DF9DDBECA8DCF0ABD6E7A3
919D5BCFDA98DFE5A59398585E6323979D5DD4DF9DC9DD96D4F5A4C8F09AAED481CFF4A4
CBF0A2CAF0A5C8F0A7B4DF97D1FFB9B4D38FD4C490C4B07DD6E9A9B7DF96D7FFB8C8F2AA
C5E8A6C3E1A3CDE7A8CBE3A5051900748446D4E0A2949E61
CBFEA1B6E893C6F3B0C1E9B593B7933E5F4290AF8FC6E5BCCCEBB2BEE096BEE28ADEFFA1
C4EA85C1E782C1E686C6EA90C8EA9DC8E9A2C8E9A4C8E8A5C8E8A7C8E8A7C9E8A5CAE7A5
CAE4A5CDE5ABE1F3C3F1FFDBF7FEECFEFFFBFFFEFFFDFCFFF8FAF5868980010000AEAAA7
FFFEFBF8F5ECFAFDECF5FFE0D5E8BACDE9ACC8EAA0C6E999C7E995CAEA95D0EC98D4EB9B
E5F5AEB1C07B93A45EB3C981C8E299CEECA2CBEBA0C9EB9FCDF2A5C7EC9FC5E79BC7E99D
CCEAA0CCEAA0CFE9A0D0EAA1CBE59BC5DF95C7E197CDE79DDCF6AC9CB46A9BB369D3EBA1
D4EBA3D1E99FCDE49CCCE49ACEE69CD0E89ED0E89ECFE6A0D3EDAECEE5ADCCDAA7010900
4D4A1F5D562A989061BAB480E2E1A8CFD494EEF8B9BCC88AD2DFA7F6FFD0DAE5BAD6E6B5
C3E09DC5E49ED4ECB2FBFFDCFFFFE498927C7A6E585C4E346A5D3A3C3308A7A574C8CC99
D4E2AFC5D8AAD5EEC4E3FCD5EEFFDDEDFDD6CFDFAED4E8ABD0E49D859B5084985091A661
CBDDA1D6E8B4D7E7B85C6D4078895562753DC7DA9ACFE49FB9D08A8DA45EC8E299C4E096
CAE99DD1F1A5B8DA8DD0F2A6CAEFA2C2E69CCAEBA4CCEDA8C9E7A7DCFABCE3FFC4CCE6A7
CEE89FD5EDA1CDE39AD2E69E869751D1E29CD5E4A1D6E5A2DDECA97B8A47CDDE98D9EDA5
C3D990D3EB9FCEE69AD4E69C999B5A4A4A0CC8CE8ED8E7A4C1D691C8E29BD4EFA8BFDA93
B0C781D7EBA6DBEAA7CEDD9A93A25F6B7C38B0C580D1E79FC9DE93D0E59ACEE096DCEDA6
CEDF99C1D58EDFF6B0C9E49FC2E39CD9E7A9D3B48579572AE2E5ACD6EFAEC9E6A4B2D89D
BAEBBEADE3BF5C8E6913411A103B10749A6BCBEDBA72905C
C3F18FC3EF96BAE49AC3EAB1C9EEC591B6943C5F3E6D9269D0F5BFBBE39DB9E38FCBF498
B3DB7BD4FC9BCFF495BDE187C8EB99C8EA9DC8EA9EC8EAA0C8E9A4C8E9A4C9E8A4CAE7A4
CBE5A4D3E8AFE9FBCBFBFFE4FCFFF1FFFFFDFFFDFFFFFDFFFEFFFD2B2E27010000EFEBE8
FFFEFBFFFFF8F3F6E5FBFFE6CFE2B4CBE7AACBEDA3C9EF9CC9EC98C8EA93CAE793CCE594
CEE096E1F0AB5F702AB2C880CCE69DCCEAA0BEDE93CDEFA3C7EC9FC3E89BC7E99DCEF0A4
D0EEA4CBE99FCDE79ED0EAA0D5EDA1E3FAACD4EB9DC8DF8F61792B809948E2FBAAC9E291
C9E493C8E392C7E291CAE795CEEB99CFEC9ACCE997C7E69AC0DD9BCCE5ABB2C58E232C00
8A8B6178754C7F7B4EA2A06F999C65EAF4B7C7D7987C9150D9EFB1D4E9B0D0E4B1DAF1B9
D4F5AEC6E7A0C9E5ABDCEFC1A1AB89989B7ECCC8ABE3DFBAD9D7A7F2F3BADDE6A7CEDC9E
E1F6BBC9E4AFCFEFC0B5D1A9DBECCAE5F4CD9AAA79899B5FD4E8A1DEF2AACDE19AD1E4A4
54652F000A002F3E15CFDEB3C9D9A8CBDDA1BCD08B6D853BA1BD73CFEFA6C7E99DD3F8AB
B6DD8EB5DE8FE1FFBBB6E191C4EF9FBCE798C0EA9EC4EEA4C1E9A2C7EFA9CEF3B0C6E7A2
D3EFA4C3DE8FCBE397DBF1A67D9149BCD089EBFCB6CADB95CEDF9B3B4C06798A44D8ECA4
D4EAA1BED68AD4ECA0D5EA9FD9E09DA3A9698A9654D5EAA5C8E39CC8E89FCFF1A7C6E89E
AAC880D3EDA6D3EAA4C9DE99CCE39DC8E29BD8F3ACA4BE776E7F398A9751DEEBA5D1DE99
D3E09BCBDC96DBEFA8C9E39CC9EBA1CBDA99C2A174815E34E3E6AFCFE9ACC3E1A5D4FBC4
437A50488661639D77376E468BBB91C3F1C3D0F8C6BAE1AC
C5EC8FC5ED95CCF2A5BFE6A5BFE7B2D4FECE7FAA7D3E693B5D8954D3FFC3BAE7A2D0FCB1
D0F9AAB4DB8ACCF29FC9EF98C6ED90C6EE8EC6ED90C6ED92C8EC95C8EC95C9EB95CAEA97
C8E497CFE6A0E6FABDFBFFDCFDFFE7FCFEF1FFFEFFFEFCFFFFFFFD0000001A1819E6E2E3
FFFDFFFFFFFAFFFFF3F3FDE2CDDFB5C9E5ABC6EAA2C8ED9DCBEE9CCDEF99CFEC9AD1EA99
CEE096E3F3AC879851CAE097D1EBA1CFEEA2C0E094CCEEA1C6EB9DC6EB9DCAEC9FCBEDA0
C8E79BC3E296C7E197CEE69ABFD688D2E798A0B56691A7559AB161C9E08ECFE895CEE794
CCE894CDEA96CFEC98CDED98CCEC97CAEA95C6E892C5E695CFEEA8CEE8A98B9E672B3405
E3E4BC8F8B6689845EE1DEB38E925FCAD59BD2E4A68FA866D6F0AFB9D696D6F2B7BEDA9D
C9E7A1C0DD9ADAF1B9B7CA9C5B6945AEBA96EDF8CEC8D2A0D2E0A2C9D992CBDD91D6ECA1
BDD893BCD89DCFEBBBD7F0C8A8B9956273494A5C287E9253C3D893D6ECA4C1D693D8ECB1
000B003C4C259DAD88DBEBC4D2E4B2C7DB9CAEC4799FB769CCECA1C4E89EBCE194D0F6A9
B1DA8BE1FFBAAAD784C6F3A0C3F09DBDEA99BFEC9BC2EE9FC0EA9EBFE99FC2EAA3C3E99E
C5E599CFEC9CD1EC9FC3DE9161792FE4FAB2C5D994D0E49FD4E7A55A6E298EA25DCAE098
CBE29AD7F1A7E4FEB4B9CF86D5E09CC1CA89758441DAF1ABD4F2AAC9EDA3C4EA9FC1E59B
BEE096A6C47CC8E39CD2ECA5DBF6AFC5E39BC7E79EC7E79E94AD6992A963B4CB85C3DA92
CBE59CD1EDA2CEEEA2BFE598BDEC9ED2F0AAAD9D6A7E6C3EC6D9A2CAF2B67DAA6F508247
96CA8C8DC181B4E6A91D4B0DC1EBACC2E6A9CAE9ADC9E7AB
CEF09CC7EA96CCF1A3B8E195BDE8A3AFDD9DD1FFC88DC08872A46F2A5C2783B47DB4E1AA
B8E1A5D0F7B6BDE29DC6EB9EC6ED92C6EE8DC6ED90C6ED92C8EC94C8EC95C9EB97CAE999
CCE89BCFE6A2E4F7BFFBFFDDFDFFECFDFDF5FFFDFFFFFDFFFCFCFE000000010004FFFDFF
FFFDFFFFFEFDFEFFF5F3FDE5E6F8D0D8F3BCCAEDA9C3E99CC5EA9ACAED9BCEED9DD3EB9D
D5E69F8F9F58CDDE97D4EAA1C8E298D0EFA3CCECA0C7E99CC5EA9CC8ED9FC9EB9EC4E699
C5E498CAE99DD2ECA2D6EEA4EDFFB77D8F45BFD187D8EA9ED0E598D5EC9ED0E998D0EB9A
CDEA98CCEC99CCEC99C8EA96C5E793C4E793C8EB97CCEF9FC8E69EC3D99977844E010700
E6E0BCB4A989AEA383ECE4BFF9F8CAC3CC97C9D99B899F5ED2EDAAD1EEACD6F3B1C9E2A1
D4E7A5D4E4A6A3B17E77845892A17AC7D6AFD6E8B8CDE1A4D7EFA3D6EF9BD3ED94CBE490
D2E9A1E7FCC18497690009000313007E8F657B8E570010001C3100CCE19CE5F9BABED19A
D7E8BECCDCB8C6D5B4D7E7C2D7E9B7CEE3A2B5CC7CD3EC99D3EFA4C0E097CAEA9FBADC8F
D9FEB0C4EB9AB5DF8BC7F19DC5EF9BC3EE9CC3ED9BC4ED9EC4ED9FC4EA9DC4E89EC6EB9E
CDEDA1C0E192ACCB7F789449C8E299C7DE98D0E7A3D1E7A6C8DD9C2F46027F9451C9E09A
CEE8A1C6E298C0DC92E8FEB6B6BF7E939959A6B270D7ECA7C9E49DC3E59BC2E69CC0E49A
C5E59C90AE66D1EBA4C7E19AC9E49DC6E49CC5E59CCEECA6E0F9B7D9EFAE8EA561D5EFA8
CDE99FC3E296C8EA9DC3EE9EBBEF9DBEDF98877B477D6F424F673316430C20521D88BB83
B6E8A9BFEDADBBE7AA588044D0F3B9BDDCA3CAE5B0D1E9B5
BCD790D1F0A4B5D888DEFFB4C2F29CB4EA96B1EA9DC3FCB8ADE6B182B78B0019001A4824
C9F2CAB3D8ACC6E8B5CBEEAEC6EB9EC6EC99C6EB9DC6EB9EC6EAA2C8E9A4C9E8A5CAE7A7
CFE8AECFE3B0E4F2CEFCFFEDFEFFFDFFFDFFFFF9FFFFFAFFEEECF7050409020008FFFCFF
F3ECF4FDF8FCF3F4EEFBFFF1F5FFE4E7FFD0CFF2B2C2E89FC2E79AC7E99CCAE99DCCE69C
D3E49D51611ADCEDA6D1E79EC7E197CDECA0CBEB9FC7E99CC2E799C9EEA0CAEC9FC3E598
C9E89CD3F2A6D1EBA1C5DC9499A96897A665DBEAA9C9D998C4D591CCE09BD3E9A1D1EBA2
C9E59BC7E59BC5E59AC3E599C2E79AC3E99CC7EDA2CDEFA5CFE49FCCD89AD1D3A1191400
D9C8AADEC9AEDCC7ACEFDEC0F3EAC3F8F7C75C652C425213D7ECA9C2D995C6DD99D9E9A8
DDDEA2E4DEAA6966399EA078F8FFD9D8E7BCB9CD98DEF7B3C1DE8ACCE98CD2EB8DCDE188
D8E59DD4DCA1090A0053573495A17BD5E6BACADDA6C0D495D6EBA6DBF0ADB9CD90DFF1BF
F5FFE0F4FFE4F8FFEAEBFBD7CCDEACC9DE9BC7DF8BD4EC96C2D78CDCF0ABCEE49CD2EAA0
CEE89EC3DF92D2EF9FC9E996CAEA97CDEE9DCAE999C8E797CFEB9ECFEBA0CBE59CCCE89E
C8E89CCEF0A3527227BFDF96CEECA6D7F2AFC6DF9DD5EEADD4EAAA92AB6ACEE4A4D4EDAB
D0EBA8D4F2ACC9E7A1CBE09B8B8D4E727033CFD494D1DD9BC8DD98CEE8A1D5F0A9DBF6AF
D8EFA9829752CBDC98D2E39FD8ECA7D3E8A3D0E7A1C8DF9BBCCC8ED0DEA38F9F60D0E09F
E1F5AEC7DF95C9E598C2E497C7F3A4C3DE99B9A978E3D0A694A8778FB785BEECBDB8E7BB
B7E4BBC8F2CA5B835EB9DFBABDDFBC95B492000C00001200
D4F2ACC6E69DD2F5A5B1D983BFEB92C7F89FBAEB99BEF2A8C1F3B6B5E7B683B38B164523
4D7A5B8BB899C2EECDC6F1C6C2EAAEC3EBA5C3EBA5C5EAA4C8E9A4C8E9A4C8E9A4CAE7A7
CFE3AECCDDB3DFECD0F6FFF2F7FFFFF9FDFFFFF7FFFFF6FFAFA9B50302076A676EF4F1FA
FFFCFFFFFEFFFCFEFBF5FDEEF5FFEAE6FFD3CFEEB5C5E5A2C7E99FCBEDA0CCEB9DCBE699
D8E9A262722BC8DC95D6EEA4D4F0A6C9E99DBDDF93CBEDA0C5E79BCFEFA3CEECA2C8E499
CDE79ED3EBA1BBD28A99AE69869A5BE8FABEC3D897D1E6A3D7EEA8CBE29ACCE69CC4E095
CCEAA0CCEAA2CBEAA4CCEBA5CBECA7CAEBA6C7E7A4C8E3A0C5D493949A5EDFDBAB0E0000
594223694F36A48A6FF8E5C5FFF9D0E8E8B6BAC589B6C989CCE19ED0E7A39DB26F667234
E7E2AADED2A05F582AFBFACEF9FFD6DBE8BAD3E8AFCAE39FD6F1A0C3DD86D8EC93DFEE9B
B0BA73272B007A794B94976CCBD9A6DEF1BAC5D8A0D7EAB2CBDEA7D1E3B1D6E7BBCBDBB6
F6FFE3F8FFE8F6FFE2F8FFDDD6E9B1D2E7A2A8BF6DCBE18EDBEDA3CDDE98CBDF98D5EBA2
CFE79DCEE99CD6F3A3C9E696C7E696CEED9DCAE797C5E292D0E89CD4EA9FCEE49BCDE59B
CAE89EA8CA7EA2C279D7F5ADCBE6A1C4DD9BD4EDABC5DE9CABC483AFC988BED996CEE9A6
D1EEABC0DE98CEECA6A8BB797B793C938A4FE0E2A3D8E3A1D4E9A4CEE9A2C2DD96C9E49D
D2E9A38A9E59D8E7A4DBEAA7CEDF9BC5DA95DBF2ACCBE09DDBE9ABD7E2A6B6C2848D9C59
D5E49FCFE099D9EDA5CDE99EC4E99CD7EAA87F6737AA8E66CDD9A9C7E9B6C4EAB9BCE5B9
BEE5C6000F00001F0582A48B4C6D525D7960668067213921
BEE799CFF8AAC3E99CBEE094D3F3A8CEEDA1C0DF93D0F0A5C7EBA1C8F1ABB6E3A8AEE2B1
88C09D43816A39786D72AF9FBEEEC8ADD8A2B4E1A0D3FBB2CCED9CC7E792CCF099C6E597
D3E5A7CAD6A8DFEECFF0FFF3E5FFFAF0FFFFFFF6FFFFEFFF6C616700000089898BFFFEFF
FAFBFFFEFFFFFBFFFFF8FFF9EFFEE9F5FFE8CDE5B5C3DFA4CFEDA7C9E89AD3F49DCCE893
CFDF989DAC67C6DA95D4EEA5C7E79EC9EEA1C2E69CCDEFA3D0EEA6CAE49BCFE49FD0E19B
D4E5A1B3C27D93A25FC7DC99C5E2A2D0F0AFBCDD96C9EB9ED3F6A2C1E58DC9ED93C0E48C
C2E490CCEB9FD7F2ABCCE7A4D3ECABD0E6A8C5D99CD8E7AC6F793D2B2E00D7D1A167582F
402806341900B7A07EDBCEA4D0D09CE1ECB0C6DD99CAE8A0D3F1ABCDE8A55E76386A783D
E2E1A9D6D19A5A5825EDF1BECED8A4D3E1ACD5E6AFCEE0A4D4E2A4000B00E6F1ADCDD894
495412E0EAABD1DCA0DAEAA9C9DF94D7EEA6CEE3A8D5E6BAF8FFEAF9FFF3F1FCEEF9FFF3
F2FCE3F9FFE3D0E0AFCBDDA1D3E8A3CAE097A0B86ABDD486CADE96E7FDB4BED68CC9E59A
D4F3A7C3E598D0F5A5C1E897CDF4A3C5EA9ACAED9DCCED9EC8E499D0EAA0D8EEA5C6DE94
C7E39987A25BCBE59ED4EBA5CDE29DCFE4A1D7ECA9CCE39F92AD68BBDA94D1F0AAD1F0AA
C2E09ACFEAA3D1E8A28E9A58A39D61D3CA8FE3E5A6D0DF9CCCE7A0CAEEA4BCE096CFF3A9
C7E29B98AF69D6EAA5C6D793D1E6A1D1EBA4CAE8A0CCE7A0D0E5A0CBDC98D8E7A292A15C
8A9752D7E49FDAE7A2CDE19ACFEBA1D9E2A1684414AB8558E8E9B0D2EAACB9D799CDEEB9
8AAC8B001100000D00597859C2E0BED3EDCAC2D7B6000D00
BFE99DB3DC90D9FDB7CAE7A5C5DE9DCADF9CEDFFBAC8DE93D1EC9DC9EB9EBFE9A1C6F9BE
B2ECC48FD0B877BDB55B9E95A1D9BCDBFFDFDBFFCCBDE29FB5D687C6E790D3F59EC7E494
D2E0A5EEF9CEF2FFE5ECFFF1E5FFFAEEFFFCFFF4FDFFF1FE6F6566050601757774F5F7F6
FBFFFFF9FDFFF7FDFDF9FFFBF8FFF4F7FFECCFE1B9CAE1ABD1EAA8C9E598CAE892ADC672
96A65FC7D391D9EDA8CDE8A1C7E99FC5EBA0C3E99EC5E79DD0EBA4C9E09ADDEEAAD9E5A3
CFDB99B3BF7DC2CE8CCEE19FCFEDADC2E7A4D3F9AEBFE693CFF69DB9E083C1E689D5F89E
CFEF9CC3DF94CCE39FC6DA9BCADCA0D7E6ADDCE9B16E793F2B3600A0A56FEFEBBC332400
6F5836715937120000E3D8ABEDF0B9C9D99A59722E9CBB75BEDB98C6E0A1AEC18956602B
999963E5E2AB70733CA8B077D0DDA5C8D79EE3F2BBCEDBA5262F00656D345E662B5E662A
E3EFAFCADB97CBE09BC7DF93CBE790D3EE9DC9DEA3CFE1BBF3FFEFF9FFFDF3F9F7FBFFF8
FBFFECF9FFDDCEE0A4CCE29AD7EDA2CEE69AA0B86EA4BC729AB067BED68CD8F2A8CEEDA1
C0E295C0E597C0E99AC8F3A3BDE697BAE394C7EC9ED2F4A7CEEDA1D6F0A6C9DF96DCF3AB
D7F1AA6A843DC5DC96CBE09BD0E19DD8ECA7C2D6919AB16BAAC57ED1F1A8C4E69CC4E49B
DCF7B0D9F0AACADE99B5C07E655F23898045E0E5A5CFE09CCBE9A1C9EFA4BEE79BC9EDA3
8DAB63BFD690CDE19CD1E5A0D4EBA5CEE9A2C2E49AC8EA9EC5DF96E8FEB5CBDC95AEBF78
A7B46FAAB772CFDC97DAEBA5C8DF99DAE0A0704A19B08857DFDDA2CEE5A191AC67638246
224219739272B2D2ABC6E5BBCFECBE8DA7788BA07575875D
D7FAB6C6E6A556723761793F92A56D6D7F434C5F1DD9EDA6CBE397C3E294C0E69DC2F0AF
BDF1C0C8FFDEC3FFEA6DAC9964A489DCFFF0EEFFE4CFE7B5D2F2AFC9EBA1CBE99FD2EBA9
CFDDAAF9FFE1F1FFEDE9FFF0F7FFFDF8F9FDFFFAFFFFFAFF0D09080304007C7E7BF7F9F8
FCFFFFFCFFFFEFF5F5F9FFFDF9FFF6F1FFE8D1E1BDD3E6B8D1E6ABCAE49DC6E19290A759
6F7C37E0ECAAD6EAA5C3DD96CEEEA5C5E99FC4E89EC7E99FD0EBA4C9E09AD3E4A0C8D794
9EAD6AAEBD7ADCEBA8D3E8A5B6D391CCECA9CCECA3C2E394C3E38EDEFCA6CCE893C4DF8E
DBF3A7C9DE99D4E6A8D9E8AD69783F38450D000A00627035E1F0B7D3E0ABD3D2A65E5430
7863446750317E6A49382C045355235F6A3000130096AF6ECCE2A4D7E8B1DEE8B6909364
92905DDEDBA69EA16A8D955CDAE7AFD8E7AED7E6AF66733D6F7A42B0B980C3CD91C0CA8D
DEEDACD0E49FD3EAA4D5F0A3D1ED98D4EFA0CADFA4D1E3BBF5FFEEF8FFF8F7FFF8F9FFF3
D2E0BFD8E8B9CBE09FD2EAA0D2EDA0D1EDA0C0DC92C8E299A4BA7293A961D6EDA5CDE99F
C6E69BD6FBAEBAE093C8F1A3CDF3A6C5EB9EC3E89BC7E79CC3DF95CAE49BBBD189DDF3AB
8AA15BCEE8A1D7EEA8EBFFBBCCDD99CEE29DA5B9748EA55FCCE69FCEE9A2BEDC94CDE8A1
D4EEA7BDD28DC9DA96EBF6B4413F02595518E0E6A6CFE09CCCE7A0CAECA2C6EAA0C9E9A0
A1BB74C0D590D2E6A1D0E49FCDE49EC5E39BC2E69CCDF2A5C2E096C5DF95D1E79ED1E79E
CBDC9696A76180944DD1E8A0D5F3ABD4DF9D92713EDDB987D5D69AC7E29DD4F3AD001300
23491080A770B1D79CC0E4A6CCECAD88A668CBE2AA869A65
BBD49A9AB1794357226072405667331C2D00000B00768947B5CB82C9E598D6F8ACC5EDA7
B8E5AAC5F5C5D7FFE38EC7A7579B82D9FFFBF0FFF1C6D5B4D0ECBBBCDBA0C7DFA5E8FCC7
DFF0C6F7FFE8EAFFEBF2FFF6FFFDFFFFF4FEFFFDFFE8E7EC000000676863C8CAC7FBFDFC
F9FDFEFCFFFFF9FDFEFBFFFFFBFFFAF4FDECE2EFD3E7F6CDD3E5B1D0E4A5D3E8A390A15A
85904EE3EEACCDDE9AC4DE97D4F4ABC9EDA3BDE197CDEFA5CCE7A0D0E7A1CADE99BDCE8A
899A56C4D591D1E5A0D1E6A3D1ECA9D6F3B0BFDB91D5F0A3D0E998C4DB8BC9DE91D9EAA3
CBDA99C0CE91E1ECB4B9C38E000A00212F002F3D009FAE73C7DCA4D6E6B5E0E5BC655F3D
8C7B5F735E436F5C3E8E825C3534060D1600627136D4E6AAE9F6C0C1C996DEDFB5656237
A6A272DEDDA7888B548F985FC6D39BC7D69DDFEEB7081700CED9A195A066D6E0A4E1F0AF
C3D792D2E9A1C2DE94C5E496C5E290CCE79ACCE1A6D6E8BEF2FFE6F8FFF3F3FFEBF6FFE9
C8D7AECDE0A9D3EAA4D6F1A4CAE699C7E698CAE8A0CFEAA3D2E7A2879D55C3DA92C7E399
CBEBA0DAFCB0BBE093C6EC9FCCF1A4C7EC9FC6E89CC5E59ACEEAA0D7EEA6DFF3ACC2D890
526923BFD992C9E09AC8DD98C5D994D9EDA89DB16CBCD18CD7EEA8D2E9A3DFF6B0D7EEA8
BDD28DD6E7A3E1F0ADADB8766C6E2F818344DDE8A6CDE19CCDE7A0C8E69ECAE8A0CEE9A2
D8EFA9819550DFF0ACC9DD98CAE49DC4E49BC9EFA4C9EFA2D8F8ADC3DF94D4EEA4D2EAA0
D1E79FB3C9818CA35BC9E59BB3D58BD8E7A4AF915DC3A26FE5EBADB5D38DDAFEB64F7730
79A05F79A061CDF2AFD3F8B3C6EBA67B9E5CCAE9AE6C8951
000D004E5E2DD3E0B2D7E4B8D3E0B2BDCB9AD9EAB3B5C78963793192AD60CBEA9CC3E599
C3E8A2BBE2A3CDF4BDB6E6BC2C7059AAE8DBEBFFFDCBD9C8D5E8CACBDFBADBEBC6F3FFDF
F4FFEAF4FFF1F3FFF4FFFFFFFFF6FFFFF3FFFCFFFF6F7B7B000200C0C2BDFEFFFDFEFFFF
F4F5F7FEFFFFFEFFFFFCFFFFFCFFFBFCFFF6FAFFEBF9FFE1D5E0B5D1DEA9DAE9AE95A463
9BA465DAE3A2D6E7A3D2E9A3CCEAA2D2F4AAB9DD93CCEEA4C9E49DD1E8A2D7EBA6AEC27D
B1C580DDF2ADC5DC96CEE59FCFE8A4CDE6A2DCF3ABC7DD94D5E79DCEDE97D4DF9DE4EEB1
BBC28CA8AF7C90966681895857612C717F44DAE8AACBDD9FC4DBA5D6E9BBFEFFDF070200
A5957CA8947B89755AE1D2B1D6D3A8D9DDABE3EEB6D0DBA38D94617473456C643F4E451E
433D0D53511E686B36B8C18ADBE8B29CAD76384A1045541BD7E4AC4B591CD7E3A5C3D392
DEF5ADDFFBB0C0E393CCEF9DC9E696D4EEA5E1F6BBEEFFD3F8FFE6F8FFEAF8FFE8F8FFE3
DBEDBBCCE2A2CCE69CCCE999C9EA9BCAEC9FCBECA5BEDB98D8EDA89DB16CD0E5A0CCE69F
C1DF97C3E39AC6E89EC8ECA2C1E399C5E79DCCECA3C8E69ED6F0A9CDE49EDEF2AD637732
8DA45ED8F2ABD4EBA5DEF3AEC8DD98526621CADE99CEE29DD1E5A0BACE89D0E49FCCDD99
9FAE6B9DAC699AA6646C7735ACB574CCD594D0DF9CCDE19CD5ECA6CBE59ECBE59ED1E8A2
D5E9A46A7B37D9EAA6CCE19CD2EDA6CAECA2C7F1A5BCE798BBE093D7F7ABC1E094CEEA9F
D4EEA5CDE79ECBE79D87A75CDFFFBACBDF9A917842A38551E3EDAEC6E7A0B6DC93C4E9A4
C3E2A6AECB9398B77B3A5E2078A062D1FAC0BAE6B1396736
0009006C7846D1DDAFCBD8ACDDEDBECEDEADD3E6AFC4DA9C627B37718B41C0DC8FC2DE91
D1F0A4C2E299C7E6A2D7FFCD3774624B8883CAF3EDF0FFFDF6FFF5D1DAC7D9E1CAF8FFED
F0FFEFF2FFF6FCFFFBFFFBFFFFEDFCFFF7FFF9FFFF00100C010A05E3E6DFFEFFFDFEFFFF
FEFFFFFEFFFFFDFEFFF9FAFCFCFEFBFEFFF8FFFFF1FBFFE6D3D9B5CDD4AAD5DFAB919A61
7A8042CAD392DEEDAAD4EBA5B9D78FD5F7ADC5E79DCAECA2D0EBA4C9E09AC6DB96899E59
CFE49FD2E9A3C7E19AD2EDA6CCE69FB9D38CCFE59DDDEEA7CCDB96E1ECAA585D23474B18
8F9064D2D4ACE4E9C0DEE5B9D5DFABC5D398D6E6A5CBE09FF5FFD6F7FFDDC4CAA6140F00
34240B5F4932655035A89978E9E4BAE1E3B2C1CA93A2AB74606432969366C7BE978C8058
999264D2D29ED8DDA7D6E1A9D2E1AA73844D000C00CCDEA4CEDDA2546225E3F1B3CFE39E
BAD48BC1E293BCE390C4EA97CAE99DD7F0ACE7FCC1F2FFD5F6FFDFF6FFE1F5FFDCF2FFD5
CFE4A9C6E099CEEA9DC5E592C7EA9AC5EA9DD1F5AFCAE9A5CDE29FAFC37EE1F6B1D4EBA5
CEE9A2CCEAA2D9F9B0C3E39AC9E9A0CAEAA1CEECA4C6E19ACFE6A0C5DA95CFE39E4E621D
C9E09ACAE19BC4DB95CAE19BD5EAA5BACF8AE2F6B1DFF0ACD7E6A3DAE6A4DAE6A49EA967
4752102530004D591799A563CCDB98ECFBB8C7DB96CCE19CDBF0ABCFE49FCFE39ED1E29E
C9D8959EAD6ACFE09CCFE49FCDE8A1C3E79DC6F0A4C1EC9DC6EB9ECAEA9EC4E397D2EEA3
D3EFA5D2EEA4C6E29881A357B8E195CEE39E5F4610B49964CFD99AD1F2ABCFF5ACBCDF9B
C5DEA772895500190087A86FCEF5BCCDFCC5ABDFAF80B889
D8E3ABCFDCA6CBD9A6E7F8C4C5D7A5CDE1ACCCE3ABE0FABDC5E29F86A45CD9F5AAD1EDA0
D7F2A5CCE798C7DF93DAFBC2BBEBDB0B46447BB6B0E2FFFFF8FFFFCECBC6D6D6CCF9FFF6
E9FFEEF4FFFAFFFEFBFFF8FFFFF5FFFFFAFFF9FFFF0006002E352EFEFFFAFEFFFDFBFDFC
F7F7F9F9F8FDFFFEFFFFFEFFF7F7F7FFFFFBFFFFF4FAFCE7E1E4C7DEE2BDDFE4BB979E6B
64682DD4DD9CD2E19ED2E9A3BCDA92D0F2A8CCEEA4CCECA3D1ECA5CBE29C9BB06B90A560
D1E8A2C0DA93CBE9A1CFEDA5D5F1A7D6F0A7CAE098D2E69F939F5D9AA4688C905DDEDFB5
E6E6C27778568C906BDBE4B9CBD7A5E7F9BDBED38ED6EDA9EDFFCAF7FFD8DEE0BB0E0500
271300A28871AA9276594927565225515321626B32455014EEF5BFDEE0AFF8F4C7A8A175
686635EBEEB9CCD39FD7E4AED2E3AC97AA72A3B77CD1E3A9D4E3A89EAE6FB7C786DBF1A9
D9F5AAC2E595D6FFACC4EE9CC2E096C5DE9CCDE5A9D2E9B3D2E6B5D3E7B6D5E9B4D1E6AB
CEE5A1D3EDA3DBFBA8C6E894C5E898B8DD90C4E9A3C7E7A4CFE5A4A2B573D9EEABDAF1AD
EEFFC3E2FDB8D8F3AEC3E19BCCEAA4CAE5A0CCE7A2CEE7A3D2E9A5DEF3B0CDE09EB4C785
BACF8AF7FFC8C2D993D5EFA88BA25CCFE49FCDE19CCCDB98D5E09E949D5C676D2D565C1C
8D9353DDE6A5E4EFADCDDC99D1E5A0D5EAA5D0E5A0CBE09BD9EDA8D0E19DD9E8A5D2DE9C
D5E19F9AA664D2E39FCDE49EC5E39BBDE197C8F2A6C5F0A1CCEEA2C8E499D4F0A5C8E298
C6E097CDE99FC2DE94D1F1A6476D22CBE09B745B25BC9E6AD0D99ABBDA94CBEFA7D5F3B3
D0E2B05F6F42000C00AECA97C7ECB6A6D59FBCF4C581BC8E
CDDB9DDBEBACD8EAAECADFA4C9E2A8D3EFB4CCEAAEBBDB9CCBEBAA5E7F3AC5E59CC9E59B
CAE598D3EB9DCFE696DCF8BDE7FFFA000F0E3F857BCCFFFCF5FFFFFFFAFEFFF9F9FDFFFA
F4FFFAF6FFF9FAF0EFFFF9FBFFFAFDF8F2F2F5FEF9040F09000200FDFFFAFEFFFDFEFFFF
FFFFFFFFFEFFFFFEFFF9F8FDF8F6F9FFFFFBFFFFF5FFFFEFFCFCE2FFFFE0F9FBD6AEB182
7D8248F6FFBEC6D793D8EFA9CFEDA5C9E9A0C8EAA0C9E9A0C6E19AD8F2AB829752CDE49E
D9F3ACCBE69FCDEDA4C1E196C4E298D1EDA2879E564C611CD3E1A3D7E2A8D8DEB0050A00
010500737657E9F0CEFCFFDDF9FFD6F2FFCAD3EDA6CEE5A1D6E5AED9DFB3635E38130300
A58B72AF91777D6446EBD9B3E1DDADDADFA5D9E7A9DBEBAAFCFFCDF5FEC5CCCE9CE5E5B3
9797630308006D763FD6E3ADD3E4ADC7DBA0D9EDB2CFE1A5DEEEB03B4B0CDFF2B0CFE69E
C7E69AC6EC99C2EE99B7E290D3F2ACCDE6A5CCE4A8CCE4AACADFA7CFE4ABD3E8ADCDE3A2
CBE59BCAE797CBEB98BADC88D3F6A6CAEEA4CBF0AAC5E5A2D1E7A6879A58CEE3A0E4F9B6
F7FFCADAF3AFC1DA96D5F0ABCAE5A0C7E29DCCE5A1D6EDA9C7DC99CFE4A18DA05ED1E4A2
DCF0ABBED38ECFE6A0CEE8A1415B14D1E8A2D1E5A0DAE9A6D8DE9E5F642488884AE5E7A8
E6EBABD4DD9CD0DC9AD3E4A0D2E9A3B6D089E1F8B2C9DE99D3E4A0CDDC99E3EEACD5E09E
D8E3A1465210DAEBA7D2E9A3D0EEA6C1E59BCAF4A8BBE49649671DC7DF95D1E99FCFE79D
D3EAA2C7DE96D9F3AAC7E59BC2E69C94A561C3A873DCBC89D6DC9ED4EFAAC4E39DCDE7A6
D3E4AE8795629AAD76CEE7ADC4E6A9CAF3B7B4E5AE7CB37C
D0E69BCFE79DCDE79DCAE8A0C8E9A2C6E9A5C5EAA7C3EAA98DB4735E8340C5E8A4C6E59F
CAE69CC6E194D8EFA1DDF5B9F0FFF4C5F0E9448D7CBBFDEFEDFFFFFBFCFFFFFBFFFFFCFD
FBFFFBF5FCF4FFFBF5FFFBF7FFFCF6FFFFF8E4E9E2000200676964FFFFFBFFFFFDFFFFFF
FDFDFFFCFBFFFFFEFFFFFEFFFBF9FAFEFDF8FFFFF4FFFFEEFFFFE8F7F8D8FFFFDFABAE81
EDF2B8E6F1AFDAEBA7D0E7A1C8E69EC7E79ECAEAA1CEECA4CCE7A0C9E39CBFD48FDEF5AF
CBE59ECBE9A1C8EAA0C9EB9FC8E89DADCC80678339A2B975DAEEAFD0DFA6808D5F657048
6B7553C5D0B0EDF8D6F8FFDFF2FFD3F5FFD1C7E29BD0E7A1D6DEA5C1BD8E84764F3A2200
BE9C81C19F83CAAD8BEAD9AEE0DDA6D6E19FD1E59ED4ECA2D5EBA3D1E4A2D2E0A3D6E0A4
D7DFA68F975EAEB97FD9E8AFCCE0A5D0E4A9D4E8AD44561A91A163D3E3A4CFE2A0D0E79F
CFEEA2BFE592C7F39EC1EC9AC6E59FD5EFB0CAE2A4CDE5A7BED69AD4EDACCFE5A4D0E79F
D7F2A5C8E593C2E28FCFF09FBBDD90C1E59BCFF4AEC0E09DD3ECAAC0D5928A9F5CC3D895
C5DC98D2EBA7CCE5A1CEE7A3CDE6A2CCE5A1D6EDA9CBE29ECEE3A0C9DE9BB2C784D4E7A5
D0E49FD6EAA5D0E7A1CFE9A2829C55C9E09ACEE29DDDE9A7B3B878535315A7A366D9D79A
E1E3A4D8E1A0CEDD9AD7ECA7CCE7A0D3EEA7BED891DBF0ABD0DF9CD1DC9AB7C07F727B3A
6A7533C0CF8CD1E5A0CFE9A2CEEEA5BDE197C4EA9FC7E99D677E3660712AA5B66FDAEBA4
CDDE98CADE97D1E79FC9E39AC5E59C828E4C694815B18B5ADBDB9FCFE4A1D9F2AEC9E09C
D3E6A68DA05E95AA65D3EBA1DAF6ABC7E79CB5D99198C079
CDE995CCE995CAEA97C8EB99C6EB9BC3EC9EC2ECA4C2EBA7BDE6A45B8243C4E8AAC6E6A5
D3F2AEDEFAB0B8D386F2FFCCEFFFE7E9FFFB8ECFB93B7F6A97BFB6EAF8F8FFFBFFFBECF1
FEFAF7FFFFFAFFFFF6F4F4E8FFFFF6FFFFF6A7AA9F080B02999A95FFFFFDF2F2F2FEFEFF
FFFFFFF9F8FDFFFDFFFEFCFDFDFCFAFFFFF8E9EADCFFFFECDBDBBFD2D3B3959770E1E4B5
DCE4A9D8E4A2D1E5A0CCE69FC9E79FC9E9A0CBEBA2CDEBA3CCE7A0CCE39DC6DB96CFE6A0
D4EEA7C0DE96D3F5ABC6E89ECAEA9F648238D4EFA8C8E39ECEE7A6DEF3BA3E5221D8EAC0
DEEFCBF7FFE6F5FFE2F2FFDCCBE2AEC0D89CC8E19DD4E8A374773E5B5022D2BC95694C2A
BE997C7854349C7E5AE2D1A3DCDCA0D8E59FCEE69AC2E191C4E093CEE89ED4E9A4D4E4A3
D0DC9EDAE6A8BECE90C6D89AD0E4A75E7235687A3EE0EFB4DEECAFCFDD9FD9E9A8D3E8A3
BCD88DD3F8A8C3EF9AB5E090CFEEAACBE5A6CFE9A8CFE8A7D4EDABCAE39FCFE6A0D0E89E
CFEA9BB2CD7EE3FFB0CAE99BD0F0A4D7F9AFB8DC94D2F1ADC7E09CE2F9B5C4D996A7BE7A
90A763D3EAA6D1EAA6CAE39FD2EBA7C3DC98CDE4A0D3EAA6D2E9A549601C8BA05DC8DD9A
D5E6A2C3D792D3EAA4D7F1AA87A25BE9FFBCC4D994D2DE9CA3A5666E6A2DC1BB7FEDE9AC
DBDD9ED8E3A1D3E4A0CEE8A1C5E39BBBD991BBD58E8CA05B798543535C1BB8C180D7E09F
D9E5A3DFF0ACD2E9A3BED992C6E69DCEF0A6C6E89ED0EEA49BAF68B2BF799DAA64D7E7A0
D4E39ED9EAA4C7DB94CFE69EBDDB93CBD694825E2CB58D5CEAE8ADCBDB9ACBE09DCFE4A1
D5E9A4A1B56EA4B96EC4DB8BC5DE8BCDE995D9F6A6CAE699
C9EB94C8EC94C6ED92C6ED94C5ED95C3ED99C2ED9EC2ECA4C3ECAA456B2EC9ECB2C4E6AA
C2E2A3CAE9A5D3F1A7CDE7A8EEFFDCEEFFEFDBFFEF084027326755A4C5BEFCFAFFFFF2FA
FFF2F5FDFAF5F8FFF6F7FFF2FFFFF4FFFFF4696B60000200AFB0ABFFFEFFF4F2F3FFFEFF
FFFEFFFFFDFFFFFDFEFDFCFAF6F7F1FCFEF1FFFFEFFCFFE5D4D8B7E5EAC2A2A87CCDD5A2
D0DC9ECFE09CCEE39ECCE7A0CAEAA1C9EBA1CAEAA1CAE8A0CAE49DD2E9A3B8CD88CDE29D
D0EAA3BEDC94D3F5ABC4E69CCEECA45C7730CEE9A4D8F3AEC2DF9D5A763965804BD7F1C2
E8FFD9F4FFE4F3FFE3EFFFD9DCF0BFD3E6AED6EBAA939F5F7170389A8E5EE1CAA181603D
886444B38F6DA58761EEDEADDCDE9FDCECA3D2EF9FC4E692C4E793D1F2A3D3EFA5CADF9A
B2C281909F5EA4B777B5CA898AA060748849B4C688C8D89ACFDA9EDDE9ABD6E2A2CADE99
DFF9B0B9D98DCBF4A5C8F1A3C5E6A1C2DF9DC6E3A0C8E39ED0EAA3CCE69FD1E8A0D0E89E
CEE69ADBF6A9D5F0A3C1DD92C1DF95D0EEA4C7E79EC6E49CC6E099D1EBA4CAE19BA1BB74
7F9952B9D38CB6D089D0EAA3CDE7A0C0DA93CBE59E6E884192AC65819B54C3DA94D2E7A2
D3E4A0CDDE9AD9F0AAACC780A9C77FC4DF98C9DE99DBE7A5ACAE6F6F6B2EA2995EE4E0A3
D3D596D2DE9CCCE39DC1DF97D1F1A8D0EEA6ACC37D8FA05C8793519DA665DFE8A7DCE8A6
D8E9A5C2D993CFEAA3C7E59DCDEBA3D6F4ACC1DC95D2E9A1A2B16CE4EFAAA2AD68C0CD87
DCE9A4D5E49FC9DA94E0F7AFE0FEB6D0DB995D3706A87E4ED9D49ACFDE9DE4F4B3D4E4A3
CEDE9FA4B475AFC07AD3E89DD3EA9AD2EB9AD7EFA1C9E495
C6EC95C6ED94C6ED92C5EE92C5EE92C5ED94C5EC9BC5EBA095BA77587C3FC1E2ABCAEBB4
CEEDB1B9D996CDEDA4D7F4B1D3E9B8C0D9B2C9E8C839644941786192BEB1E9F3F4C2B7BF
97888DFFFEFAF0FEEFF4FFF3FCFCF0F3ECE482827A0506009A9899FFFEFFFFFEFFFFFEFF
FDFBFEFFFEFFFFFFFDFBFCF6FFFFF6F3F6E5FFFFEAFEFFE3DAE2B9BEC79889935FE2EFB7
D2E2A3D0E5A0CFE9A2CDEBA3CAECA2C9EBA1C8E89FC8E69EC7E19AD5EAA59BAF6AD5EAA5
C6E099C8E69EC7E99FC7E79E79924ED5EBAACCE39FCCE7A4D4F1AEBFDD9D5C7B40B9DAA5
C4E1B3CDE8BFCCE2BBCEE0B6D3E3B4E0EDB7BFC98D797F43CAC792E3D8AAD8C2996A4C28
CDAA8ACDAA8AB49871E9DBAADADC9DD2E49AC9E696C3E692C7EA96CAEB9AC0DC92B2C981
82964FD9EAA4E0F5B0C4DB97D8EFABD4E9A8C8DB9BD9E7AADEE8ACC0CA8EE2ECAFDDECAB
CEE39EC9E79DC2E79AC7EDA0C9EAA5D2F1ADCAE8A2C9E79FC1DD93D1EBA2CCE39BC8E096
CDE39ACFE59CBDD48CE5FCB4D4EEA5CDE79ECFEBA0D2EEA3CFEBA1CAE59ED3EDA6E0FAB3
C0DA93AFC982849E578EA86187A15AA4BE77DCF6AFBDD790C2DC95D5F0A9C6E099CAE19B
DFEEABD3E29F798E4967823BD2F2A9C0DE96DEF5AFD8E4A2E3E5A6686226675E23DBD599
E3E8A8D8E9A5CAE8A0CAECA2CBEBA2BAD58E96AB66DDEEAAD6E19FCBD694C9D492D2E39F
D4EBA5BFDA93CAEAA1C9E9A0C4E29ACBE59ECADF9AD6E7A197A45FCCD79299A45F8A9751
DFEEA9DBECA6CEE29BBFD990C8E89FCEDA987B5725B48C5B95905668773697A766D3E3A4
DBE8B09BA96E97A768C6DA95D1E79EC7DF93CCE69CD3EFA4
C6EB9DC6EB9BC6EC95C8EC94C8ED90C8EC92C8EB97C9E99EC3E29F658347CBE8B0C3E2A9
C8E7ABC9E9A6C3E59BBFDF96C8E2A5D1E5B4D5E5C16A84695E8E78558577EEFFFFFBFFFF
FFFDFF767070CCD6CDF8FFF6F4F4ECFFFEFA61615F0000009F9DA0FAF5FBFFFCFFFFFDFF
F8F6F9FEFDFBFFFFFBFDFFF4FCFFEEFEFFECE6EDCCFCFFDD2B37075B6832526025CADA9B
D5E8A6D3EAA4CFEAA3CBEBA2C7EBA1C6EAA0C8EAA0C9E79FCEE59FCEE39E95A964CCE09B
CFE6A0CEE9A2C4E49BCBE9A3495C1CCEDC9FD7EAAAC3D998C0DD9ACFEFAC577A3ACCEFB5
C6E6B4C6E3B5C7DCB1D7E6BBD6DEAFCBCD9C79764199965FC9C796FBF7CAF1E2BB5D4624
A08164B8997A9A825CE5D9A9DFE3A6D1E29BCFEB9ED9FAA9D6F7A6B7D68892A963788D48
D4E8A0CDE39AC2D991CBE29AD8EFA9D3E8A5CBDB9CE5F1B3D8E0A5EDF2B84F5519879353
CEE19FDCF7B0C7E99FC8ECA2C3E49DC1E29BCCECA3CBE99FD5F1A7CAE49BD0E79FD1E6A1
263A004A5D1BDFF2B0C5D994C9DE99C7DD94D1E79CC3DB8FD0ECA1D0EEA4B9D58BC6E298
C4E096CCE89ED4F0A6CFEBA1C0DC92CEEAA0B7D389E0FCB2CFEBA1BFDD93CFEBA1D1E8A0
C5D18FE0ECAA92A762C9E49DD4F4ABC4E49BC8DF99D1E09DEFEFB15E581C574E13DAD699
E7EDADD0E5A0C0E298C7EDA2C4E49BD8F2ABC2D792D1E09DE1ECAAE6F1AFEBFAB7CCE19C
CCEAA2CAECA2C0E49ACDF1A7D0EEA6D0E7A1E0EFACD3DE9A96A35ECCDC95D3E39C9EAF68
C6DA93D4EAA2D6EDA5CAE89EC6EAA0CCDD99694916A98553EBEBAFCBDE9C95AA67C7D99B
C0CD9896A06E9BA872C7D99BD5ECA8C8E39CC6E7A0CDF1A9
C6EAA4C8E9A2C8EB9BC9EB95CAEB92CCEA92CCE995CDE79DB9D290667E42000E009CB87E
D4F2B4B9DA95CAEFA2CCEEA2D0EBA6D5E8B0CFD7B09DAA90E9FFFA5A857BA8CFCAEDFFFF
F2F7FBFFFDFFDFDEDAECEDE8FAF9F5EDEDEB4F4E53000004D6D1D8FEF9FFF8F3F9FFFDFF
FFFEFFFFFEFCF9FAF4FEFFF4DADFC9D2DBBC9BA67E889665CBDAA3D0E2A4C9DC9AD9EEA9
D1E8A2CDE8A1C8E89FC6E89EC3E99EC5E99FC9EBA1CCEAA2D5ECA6C7DB96B2C37FABBF7A
DAEFAAC7E19ACDEBA3D0E9A5DEE9AFB8C087D3DEA2CEE3A2E3FEB9C2E39CC7ECA7B8DF9E
BEE1A9CCEAB8D0E3B6DCE7BCE0E1B5C6BF915244159F9564E4E6B7C9CCA1FFFBD62A1A00
967C61D9BEA1A38F6CABA073A6A97082914E698339708F41829E538EA55D9DB06EB0C17D
D9EFA6CBE397D1EC9FD6F0A6C0D78FC7DC97C8D897D9E3A68A8F55979A61A7AB70A7AF73
CEDC9ECEE5A1C5E39DC4E59ED8F9B2BADC92D0F0A5B9D78DC6E2977E954D879C57889B59
8B9B5C98A86A8F9F61A0B071778844E2F3ACDAED9ED7EE9ECBE79CDCFAB0CAE89ED8F6AC
D5F1A7C8E49AD1EDA3BEDA90DAF6ACD0ECA2C7E399C8E69CCDEBA1D2F0A6D4F2A8BED88F
DCE8A6B4BF7DAABF7ACEE9A2B5D78DD3F3AAD7F1AAD6E5A2D2D294635D2181773CE1DDA0
DCE7A5C8DF99B8DE93BEE89CD1F1A8C4DB9596AA65CFDE9BDDE8A6CFDB99C7D894CDE7A0
BEE096D0F6ABBEE79BBEE499AAC57E899D5898A16091985597A45FC7D891DBEFA7B2C87F
9AB068BAD48BC2DE94CAECA0C8F1A5D0E5A08A6F3AAD8D5AE6E7ABD5ECA899B06C9AB06F
A5B47BAFBC84C5D799D8EDAAD5EFA6CEEDA1C7E99DBAE093
C8E7ACC8E8A9CAE8A2CCE89BCFE894D0E892D1E795D1E69BE1F4B2CDDFA3C0D59D000E00
CCE9A9CEEFA8C7EC9EBBDE8ECDE99FCEE0A2D5DCB2A4AA90F5FFFA5D7E774D827CC1F4EF
EEFFFFFFFEFFDAC6CFDDCCD2FEFFFFF2FCFD5C5C6605020DF4EEF8FFFCFFFBF6FDFFFDFF
FFFEFFFFFFFDFAFBF3FEFFF3D6DBC49AA482828F63D7E8B2D7E9ABDBF0ABC4DA91D4ECA0
CCE69DC9E79FC7E99FC5E99FC4EA9FC5EBA0C9EBA1CBE9A1D2E9A3CDE19CCEDF9B90A15D
C6DA95C5DF98CDEBA3D0E6A5CACF99A9A774DBE3A8CCDC9BC1DB94D3F3AABCE299D3FBB5
C8ECAFD5F2BCCCDDB0CBD2A8D3CEA4A99A715F461DB5A479D7DDB1CBD6ACFFFFDF7D7455
89755CB59F87695636DED5ACDBDEA9D2E0A2D2E9A3DAF4ABDDF4AED4E7A5D0DC9ECFDB9B
C9DF94C5E08FCEE99ACEEA9DC6E097DDF2ADA3B372737D40E9ECB3D8D9A0C3C48B868B51
D1DCA0CEE3A2DCF7B4C6E59FCDEEA7C8EAA0D6F6ABCEEDA1D0ECA1BCD38BCADF9CD6E9A9
D8E7ACCDDAA2D9E7ACCDDB9ECAD99653631A8D9E4EC9DF8DCBE79AC2E296BEDE92C6E69A
C8E79BC1E094CDECA0D8F7ABCFEEA2B0CF83DDFCB0CBEA9EC4E397C6E69ABFDF93D6F0A7
606C2A7F8A48D5EAA5D8F3ACCDEFA5C3E59BCEE8A1CCDB98D7D7996C662A9D9358D6D497
DAE6A4D4EFA8C4EEA2C7F3A6BCDC93E4F9B4BECF8BD5E19FD0DB99DEEAA8D7ECA7D2EDA6
BBE196CAF4A8CAF4A8C9EFA4C0DB94AABB77C2C787EEF3B1DAE9A4D8EEA5CAE298C6E096
C9E39AD2F0A6D6F8ACC4ED9FBCEB9DC3DD96947D47B89D68D5DB9DCEE9A4DAF5B0C2DD96
C6DE94D0E89AD4ED9AC8E48DC0DE84C8E68CCFF097CCEF95
C8E7ABC9E7A7CAE8A2CCE89BCFE895D0E894D1E795D1E699CFE39EC8DC9DDEF3B8576F33
2C49094E6F2AD7FBB1C3E59BCFEAA5CADEA1E1E9BAAAB08EF5FEEBC8E2D74E837B7CB7B1
E2FFFFEBF8FEEBD4DEE9CED5F5F9F8F7FFFF6E6C7704000BE4DEE8FFFDFFFFFEFFFFFFFB
F2F5ECFCFFF1F9FFE9F9FFE3F8FFDDA5B284BAC893D4E6AAC8DD9ACBE399D7F2A3C6E393
CBE99FCBEBA2CAECA2C9EEA1C8EDA0C7EC9FC9E99ECBE79DC9DF97DCEDA7D7E8A4869753
A3B674CEE5A1C8E19DD0E2A6E7E5BC0D0700393A0E96A06CD8ECB1C3DDA0E4FFC7E9FFCF
F0FFDAEFFFDAF8FFDFFFFFDDFDF8D28779526B552CE0D1A6FEFFD6F6FFD7FFFFDD211B00
9483678773587C6C4BE4DBB2D8DDA7D9E9AAD7EEA8CDE99FC7E19ACBE09BD5E3A5D9E7A9
D4E8A1D6EDA5C7DE96B9D08AA0B57291A462899759E5EFB2F3F8BECDD097E5E9AEB5BD81
788648DCF3AFBED994CBEDA3B4D88EDCFFB4BFDF93C3DD9393A960D2E69FCDDE9AD9E9AA
CDDFA1DAEEB1D2E6A7CEE3A2DBEFAAD0E29890A153DBEC9ED5EBA2CBE29ADAF1A9C8DF97
CCE69CDAF4AAC7E398C7E398CCEB9FD2F1A5C3DF94CBE79CC8E49AD3EFA5CAE69C8AA159
869751DFF3ACC8E299BDDD92C9EB9FCAECA0C7E198D8E9A3E1E8A5515111757336A4A969
C5D692D3EEA7C1EA9EC1EB9FD5F5AAC3DA92AEBF7997A663E1EDABBBCA87DFF2B0C9E49F
CAEEA6C2EAA3D4FCB5DBFFBADEF9B6B3C587899156B4BA7ECCD896D5E9A2D5ECA4C7E398
CDECA08BAA5EBEDE92C3E89BBFE99DD6EFAB7B6732A38C58E4F3B2B9D990CBEBA2C9E99D
CDED9AC8E992C8E990CDF092D1F394CCF090C9EC8EC8EB8D
C9E99EC9E99DC9EA9BCAE999CAEA97CCE997CCE997CCE999C7E398D2EDA6C8E5A3C4E1A1
CBE9AB69874B001900203D03CCE4B2C8DCA9D9E7B295A16FE9F8D1F2FFEF476F64669D98
C0FEFBDBFFFFE6D7DADEC4C3FEFFF4F8FFFA04000507000988838AF3F3F3F9FFF5F9FFEF
DCECC8E8FBCDE7FCC4DFF3B8E8F8BA8E9E5FDFEFAECADE99C9E197D0ED9DC2E591CCF29D
C9EB9ECFF1A5C4E69AC6E69ACCED9EC7E698CBE699CEE69AD1E59DD5E69FD5E6A0C7D796
99A96AB8CA8CDCF0B1C9D5A50701004B3F33BDB8A5EDEFD7EAF3D4E7F7D3DEF2CDF4FFE6
F4FFE8E2F5D7F5FFE5EDF7D501050087855CF0ECBDD0D09CEAF9BED8EAB0FAFECC0A0300
60502C75613EA08E68E1D9AADADFA5D1E5A0CAE99DC8EB9BC8EB9BC9E99DCCE7A0CFE5A4
D3E5ABD0DEA9CCDAA5B8C790E4F1BBD5E0A8D0DBA3F8FFC87C864A9AA6688E9D5CA1B570
95AF68CDEBA1C8EA9EC7EE9FCBF4A5B8DF90D1EDA2DFF3AB444F0AD6E09BD9E4A0D2E39D
D1EBA4CBEDA3C4EA9FCEF3A6C1E196CFE99FDDEFA56C77327176368F9356DBE1A3DBE6A4
D3E29DD7EBA3CBE399CDE89BC7E396D3EFA4C5DF95C9E098D8EDA8A8BB7993A261D4E7A5
C7E69ACAEF9FBDE292CDF2A2C4E699CFEFA3D1EDA2C1D98FD9EAA3CADA93BDCC8751621C
CDE39BC3DF95C7E79CCDEFA3D0F0A4C2E195D8F0A6CADE9798A764DAE6A6CBDB9CD3E7A8
CFE9AADDFBBDEAFFCDF0FFD3F1FFD4E2F9C3C4D6A2B9C691C6D094E4F0B0CEE59FC2E195
C8E7998AA757D6ECA1CBE399D2F1ABD7E7A8816F3DB7A773C7DE9AC7EDA0C9EB9ECCED9E
CBEE9CBFE592C1E792CAF29CD4FAA3C7EF96B8E088C7EF96
C9EA99C9EA99C9EA99C9EB97C9EB97C9EB97C9EA99C9EA99C3E397C7E79CCCEBA7CBE9A9
D9F7BBA9C68C3956200A240097AE82CDE3B5DCEDB685945BCCDAA9F1FFE3A4C6B8255853
6CB5AEDBFFFFD5CBCAEED5D0F8FCEBF1FCEE2E242C160817BEB8C2FEFFFFF3FEF0F7FFEA
D1E7B9CCE5ABCAE3A1D4EBA3CADE97A5B66FA3B46EDEF2AAD7F2A5C9E898C7ED9ABCE390
C5EA9CC5EA9DC2E296C5E498CCE89BD0EB9ED4ECA0CFE59ADCEDA6C5D690DEEFABCFDF9E
E8F8B994A466B3C589E0E9BE1710007C6E6BA89F96FFFDECFFFFECF5FEE1F9FFE8F6FFE6
E8F8DDF8FFEAD3E0C2D5DFBD0A1100888B5EEAECBADDE5ACCCDF9FDAEDADD3D8A26F683A
382600A39068A39169C9C391D8E0A4D0E69EC9EA9BC5EC99C5EC99C6EB9BC8EA9DCCE7A4
D3E4AEEAF6C8CBD7A9F6FFD0FEFFD6D4DEAAB0B984B3BE866E7C3F87975899AE6BB4CE85
BDDB91D1F1A5C4E999BBE291C2E99AD8FAADC3DD93C5D68F57621DE6F0ABC5D28CDBEFA7
C8E499C8EA9DC2E99AC2E99AC2E296D1EDA2D4E8A0B8C37FA7A66D928D55D9D89FDDE3A3
D1DC9AC8D993D3E9A0D0EB9ED0EC9FC8E499D7F1A8D2E8A0A8B87799A867B6C084C5D594
C3E397D5FFADCBF2A1C0E393C6E798C2DE91D0EAA0D4ECA2C6DC93D3E9A0CAE298667E34
C8E299D7F1A8CCE89EC3E296B4D689D9FAABCCE89DCFE59C8A9956DAE9A8D2E0A2DAEAAC
C7DCA1DAF3B9E2FFC5DCF9C1DAF7C1E2FDC8E5FBCAE0F1BDBFC48EC7CF93D5EAA5CFEEA2
CEED9DAEC978D3E59BD0E099BBD28ECBD7998C77489B8B58DEF5B1B7E092C9EA9BC8E797
C1E494CEF3A5CEF3A5B8DD8DB3D888BEE393C4EA97CDF3A0
C9EA9BC9EA99C9EA99C9EA99C9EA99C9EA99C9EA99C9EA99D1F1A5C6E69BCDECA6C4E3A0
C3E1A3D6F4B8BDDAA095B07B000C00778A5C93A2696A793E82905DEBFFDAD0F1E074A59F
397F77C9FCF7D4CFCCECD7D2FEFFF3FBFFF634292F0A0007B6B0BCFEFFFFF5FCF4F4FFE9
CBE0B7C4DCA8C3DB9DD3EAA6C8DD9AC5D9948D9E5AB6CA85D1EBA2C7E69ACFF4A6C2E998
BCE193C3E89AD2F2A6D0EFA3C7E398CCE69CD3EAA2CEE49CD2E39FD2E2A1D8E8A98C9C5D
68783ACEDEA0D9EBAF3A43145E5943FFF7EBE3DCC9636246F1F5D2E1E9C2E8F5CADAE9BE
EDFCD5E6F2CCD9E4BCDEE5BC5A5D306D6D3BD4D39DD4D89DE2F5B3C6D999D4D9A33C3809
43340B64522AC0B188EAE4B2D8E0A4D0E69EC9EA9BC5EC99C3ED99C5EC9BC8EA9DCCE7A2
D3E6AEF6FFD19DAB78CEDBA6A9B68186935D9EA971C6D499D6E4A7CCDF9FD1E6A3CDE79E
D7F3A9CBEB9FCFF1A4D0F0A4C4E096C6E097D1E8A08FA55D50661EC4D891DDF1AAC7DD95
D3E9A1C3D991DDF4ACD3EAA2CEE59DCDE49CD1E8A0D2E39FCCD095D6D79D4A5014DCE7A5
D4E3A0D2E69FE4FCB2BDD98ECDE99ECBE79CC7E19893A96197AA68CFDE9DD7E1A5E1EFB1
CFE9A0B8D88CBFDE92CFEBA0DDF7ADC9E197D9EFA7C9DD96D9EDA6D9EDA6C8DE957E964C
C6E096D7F1A7C3DF94C5E498CDEFA2C0E295D2EEA3CBE399CDDE9A869554DBE9ABC7D99B
CFE5A7CFE9ACD2EEB3CCE9AFCCE8AEE2FBC4F7FFD8F9FFD2E0E5ADE5EBAFD5E9A4C2DE93
C7E494839C4B6C7931E2EFA9ECFFBECDD599654D1FA38F5DD3E6A4C8EA9EC9E497CFE59A
D3EDA3C6E298C3DD94D1EBA2DDF7AED8F2A8CEE89EC9E399
C9E99DC9EA9BC9EA9BC9EA99C9EA9BC9EA99C9EA99C9EA9BCBEB9FC2E297D1F0AAD1F0AC
BDDC99C3E1A1D1EFB3D1ECB5C8DEAF001200627138909E63ABB785C6D8B2C2DFCB5E8C81
37766DD7FFFFA4A3A1B0A19CFBFFF0E4ECDF897E820A00057F7786FBFBFFFBFFFDF7FFF0
D0E4BFD4ECBACDE5ABD0E6A6CEE3A2DEF1B1CFDFA0586B29E6FFBBBEDC94C2E498D4F9AB
D0F5A7C8EA9DCEEEA2C4E397BED891CCE39DCEE3A0C8DB9BDBEBAC5363254B5A1F909F64
DEEEB0C7D799D8EAACF6FFCCFFFFE4FFFFE8DEDBBCE9E9C39DA3734A541FD4E1ABE0EDB7
D5E2ADD3DFADE4ECBDD3D6A7D2D2A062612B5C571DE4E6A7C3D694CADF9EE8EFB9534F20
978A6068562E84774DDFDCA9D7E1A4CFE69EC8EB9BC3ED99C3ED99C5EC9BC8EA9DCAE8A2
D7ECB1C5D8A04F602999AA73BFCE95D8E7AEDBEAAFD6E6A8D6E6A7CFE2A0D2E7A2CBE59E
CDE99FC0DF93C4E498C9E59ACBDF98DDEEA8C9DF9793AD64415D13CBE79DD9F3AAC8DE96
D6E5A0D8E39FD9E29FCCD592DFECA7D1E59ECBE29ACBE09BDCE6A9E6EBB1545E2195A463
D9EDA8C2D890BDD78EDBF7ACD2EEA3C4E0954D641C829752DCECABCAD89AE6F0B4CEDA9C
D1E4A2DAEFAAD1E6A1D2E6A1D0E19DCADB97D6E5A2D1E09BCFDE99D0E19BD0E49D899F56
C2DA90CEE89ECAE69BCFEEA2CCF1A3D2F7A9B4D387DFF6AEC9DD98D8E7A4516120D7EAAA
D9EFAFC4DE9FC0DC9FC6E2A5C7E0A6CEE6ACD7EAB3D6E3ADC7CC94E3E9ADD0E49FD0EAA0
D4F1A18BA252515D15CED994D1E1A0D3D99D987B4FE4C99AD0DF9EC7E59BD4E99ED8E89F
C8DC95D5E9A4D7EAA8D6E7A3C9DA96C6D793D5E4A1D2E19C
C9E99EC9E99DC9E99DC9EA9BC9E99DC9EA9BC9EA9BC9EA9BCAEA9EC7E79CC5E59CCFEEA8
D0EFABBFDE9ABCDA9AC4E0A5D1E7B6000A00616E36B4BF85A3AD79CBDCB2D4F0D9D0F9EB
16504473A099AAAEAD9C9290FCFFF6FCFFF6BCB0B00C0005827787FFFDFFFCFFFFF9FFF4
E1F5D2E3FBCBCEE5ADC9DFA1DAEEAFC5D799D4E4A6D1E3A5798F4ED9F7B1CCEEA4B9DE91
C6E999B9DA8BC8E89CCFEDA3DDF6B2E2F8B8BDD194A6B87E74834CBDCC95D6E5AED9E8AF
BCCE92E8FABCD5E7A9F8FFCDFFFFDDE6E3C0E1E2B6D9DDAAC1C98DD5E09EC8D492C7D391
C9D595D8E2A6DDE2AAE1E4ADDCDBA39D985E5A5418B4B675D9EDA8DDF3B2D1DAA3312F00
7F73497C6D4461552BE5E3B0D6E2A4CFE69EC8EB9BC3ED99C3ED99C3ED9BC6EB9DC9E9A0
CAE4A3DFF7B9C5DB9DD5EBABCCE0A1CCDEA0C7DA9AD2E5A3C8DB99D1E6A1D0E7A1D1E8A2
C7E198CFEBA1CFEBA1D6EDA5DEE9A7DEE7A6D0E49F809B54A9CB81BFE399CDEBA3D7ECA7
D1DC9AECEEAF959154A6A265AFB474D2DE9CC9E09AD8F1ADD0DEA0CDD89C556325728241
D2E7A2BCD38B92AC639BB56C819B5293AD64CBE09BDCF0ABE1F0AFD7E3A5BEC88CDEE6AB
C6D093E4EEB19CA6698B935799A263D2DB9CD4DD9EDCE7A5DBE6A4D3E09BE3F4AE92A65F
CCE49ACFE99FD3EFA4C2E296C2E89BC4EA9DC0E095D8F2A9D1E5A0CDDE9AB0C17D788B49
D0E7A3D2EDAAD5F2B0D1EEACD0E9A8D5EBABD5E7ABD0DBA1BEC389D6DEA2CCE19CD8F4A9
C5E292CCE393B9C57DABB570899857A6A76D755429907445D8E1A2CBE29AE0EDA5CDD991
D7E3A1A1AD6D9BA769DCE6A7D6DFA099A263A2A86ABEC383
C9E99EC9E99EC9E99EC9E99DC9E99DC9E99DC9E99DC9EA9BC8E89CD7F7ABC2E297C0E097
D0F0A7CCEBA5CDECA6D4F1B1CEE2AD70804F738048D4DFA597A16CE3F2C7B5CEB1E7FFFA
C4F8EB3E6960C1CBCAA5A4A2EBF3E8FBFEF57F74720E0003A99EACFFFDFFF7F9F8F9FFF3
F4FFE5EDFFD5CCE3ABCEE4A6C9DD9ED8EAACD1E1A3D3E5A796AC6BA8C37EBFDF96CAECA0
C9EA9BC4E393D2F1A5C8E39CC5DB9AB0C48781925B889963D2E0AFD6E4B1AAB8832D3C05
9FB177B7C98BD1E4A4FBFFCFF0F8C9EFF2C5BBC28E858F52828F499BA95CD0DE91DDEBA0
DDE9A1D0D996D9DFA1E5E6AAD7D59AE9E5A8D0CA8C515312D1E6A1BDD694D9E4AC302F00
837A4F998C6285794FCBC996D6E2A4CDE79EC6EB9BC3ED99C2EE99C3ED9BC6EB9DC9E9A0
BFDD97C9E4A1D4EFAAC6DF9BC9E09CD6EDA9CEE3A0DDF2ADD5EAA5DAEFAAD0E7A1D0E7A1
C7DE96D0EAA1CDE79ED2E69FCED494A9AE6E91A25EB3CE87C5E79DD4F8AEBADA91D8EDA8
D8DE9EBBB97C60561BA9A06549470A9FA867CEE29DD6EBA8CFDFA0E2F0B37D8D4E8D9D5E
798C4A879C57BBD08BD7EDA5D4E9A4D9EDA8DBECA8C7D695D5DFA2D3DB9FB9BE84D8DBA2
E2E1ABACAB7575743EA4A36B76773EA0A167BEC287D8DEA0E9F2B387935184934E72863F
D5EBA2CBE59BCEE89EC8E89CC0E99BC1EA9CD3F5A9C5E197D3E8A3DCEDA9C3D490586C27
91A862C0D995D0EBA6BED994C1D894D0E5A2D5E5A6D6E2A4B5BD82DFEBADC0DA93CAE99D
C0DF8FD4ED9CE1EEA6C2CC8795A463D3D49A77562B896A3CC1C789869C548D9951E8F2AB
B0BB79B2BE7E8E9859838B4FA0A66AD4D89DD6D79B747438
C9E9A0C9E9A0C9E9A0C9E99EC9E99EC9E99DC9E99DC9E99DBCDC90D4F4A8CCECA0CDEDA2
CAEA9FBEDE93C4E499BCD996C5DAA2000E0057622AE0E9B09BA46F95A274D7ECCBEBFFF4
E2FFFF4C746C889A9AF1FAF9EEF8F0F6F7F1C7B9B60B00009F939DFFFDFFF3F5F0F9FFEF
F5FFE3F3FFD7CEE8ABD0E9A7CEE3A2DBEEAEC8D899D9ECAA8A9F5C8CA65FCAE89ED1F1A5
C8E998C7E696D3EFA4C4DE97CEE4A4C0D39BA1B27ED7E5B4D8E3B8616D3F334110374510
9AAC72E7F9BBD3E8A7A9BB7DA6B47FA2AF7A93A1649DAE68829546E4F7A5C2D482DDEC9B
D8E498E4EEA7D7DE9BC5C68AE9E9ADD6D497B0AC6D737836D2E9A3CDE8A5D2DFA76A6C3B
71683DA2966C91885DDEDEAAD4E2A4CDE79EC6EB9BC3ED99C3ED99C5EC9BC8EA9DC9E99E
D1F1A6C8E69CCFEDA3CCE89ECFEBA1DAF4ABC3DA92C6DD95CFE69EC1D890C7DD95CDE39B
E0F5B0D2E9A3CDE49EC8D995BDC6877E8446A2B170BFD692D4F2ACBEDD97D2EDA8CADD9B
B7BD7F817F44878147D8CF965A581D65662AA8B273CBDA99D9E7A9BCCA8CE4F2B4C2D092
D6E6A5DAEAA9D1E1A0D4E3A0E1EDADBEC889DDE6A7DCE2A4D3D79CA2A3695C5D239D9A63
E6DCABAA9E6E9D9362EBE4B099935F64612A88874EE0E4A7CFD59756611F505F1A72863F
CEE49BCAE49ACAE598DAFAAECBF4A6C2ECA0B8DC92E3FFB9CDE39BBBCF88DFF0AA677B34
A9BF77D3EDA4D8F4AACFEBA1DDF4ACD3E7A0C7D691DAE6A48A9658D0E3A3BCDC93CAEFA1
DDFFB0C9E996CADC92E0EDA7CDE09EE6EAAF6E4F23AB8F60BEC788788F4748550D8E9A52
6E7D38AFC07CCCDB98D8E4A4D6E0A1E6ECAED0D4995B5C22
C9E9A0C9E9A0C9E9A0C9E9A0C9E99EC9E99EC9E99DC9E99DD0F0A4C6E69ABCDC90CFEFA3
C9E99DC1E293D7F7ABCBE9A1D8EBB3000A006A743FD9E2AB8C955E9AA676D8EDC6DDFADE
E5FFF994B9B19FBCBAF1FFFF9BA5A4FFFFFBFFFCF60B000072676BFFFDFEFFFFF6FBFFEA
F4FFDAF4FFD4CEE8A7C5DF98D1E6A1CCE09BE2F3AFCEE29D889E568BA55CD4F3A7C3E294
CDEC9CCAE797D2ECA2CDE4A0D1E5A882935C010F00000B00000800313C119AA779CEDCA9
DAEBB4A1B3776E8342B6CA8BD0E5ADCCE1A8C9DD9ED0E69ECFE696D4EA97D3E694D3E494
DBE99ECDD893D8DE9EE8ECB19A9B61747438505014E1E7A7C8E19DD4EFACC9D89F707442
5F562B574B2162592EDADAA6D4E2A4CDE79EC8EB9BC3ED99C3ED99C5EC9BC8EA9DC9E99E
CAEA9EC5E599C4E397D2F1A5C8E499CEEA9FC5DF96D7F1A8CDE49C91A86081974F6E843C
96AB667F934E95A96499AA66B9C585C6D091D0DF9ED0E3A1D6EBA8D0E5A2CADF9CDAEAA9
6F793A7B7F42D1D195EFEFB3E0DEA3505014626327E1E5A8D0DA9DF0FCBEC7D395DBE7A9
D9E3A4DDE7A8D0D99AE0E6A88F9358ADAE72B4B478BFBF83848249908B53D9D49C857B46
A09263AE9D71655426988C5CE5DBA89E99626C6932E1E2A8E7EDAFCAD593DFEEABD2E69F
D4EAA1D5EFA5C5E194C3E397B7E293C8F4A7C4E89EBEDC94D3EAA2DAEEA7AFC07AAEC27B
D0E69ED1EBA1BED88EC7E197D9F1A79EB26A7080398E9D58B4C485DBF1B0CCF0A6B9E494
BEE894C9EC98D6ECA1D1E29BCDE4A0D8E0A4A98C60C1A677D7E1A2BFD990E0F0A7D2E297
CEE49BD5EFA5CDE49CDBF0ABD0E19DD0DC9CDCE4A8999F63
C9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99DC9E99DC9EA9BC9EA9B
C9EA9BC9EA99C9EA9BCAE8A0D0E3AB000A00717B46D5DEA7B3BC8596A270C6D7ABF2FFEA
E1FEECA4C7C096BDBCE9FFFFABB9BCC9C9C9FFF9F10D0000706561FFFFF6EDF0DBF4FFDC
E4F8C3D6F0AFCEEAA0C8E396C4DC90D3E89DE3F4ADCADE968BA158B0C87CD3F0A0CBE898
CCE999CFEA9DC9E39AD8EFAB879B5E3D4E185C6A396672446E794E889368D3E0B2D3E1AE
B3C48D9AAC72849859CFE5A7C8E1A8C8E4AACAE4A5CCE5A1C7E295C9E193DBF0A3C9DB91
D5E19FCFD99CDFE7AEBCC18953582072753CABAE75C8D295D6EFABC8E3A0DCEBB2939765
2A2100897D53463D12DDDBA8D3DFA1CEE89FD1F4A4C2E996B8DF8CD6FBABC4E498CDECA0
CAE99BCBEA9CCCEB9DC6E597C3DF92C6E295DAF4AACCE69CD6EDA56C833BA2B870CFE39C
DAEEA9CDDE9ACBDC98D6E7A3D2E5A3DBEEACCAD998DCE8A8DCE6A7D3DD9EDCE6A7CEDA9A
51601F899857D9E8A7DFE9AAD9DDA05E5C21453C03DFD99FE0E4A7CAD394D5DDA1DAE0A4
DDE1A6E7E8AED7D69DC6C48B5C57205D561F837A439C935C685F28A59A64E5DAA2C5B883
5F4D1FAB986D5C4B1DAA9C6DE3D7A5E7E0AAA3A26A9B9F64D8E1A2D6E2A0D3E4A0D0E69E
CFE79DCDE79DCCE89BC9E99DBCE798CAF6A9C9EDA3C5E39BC9E098E4F8B184954FDEF2AB
CBE198DAF4AAC8E298CAE598DEF6AA7D92477B8B42D4E49DD2E7A4C9E6A3C4EEA2C0F19F
BBEB95C2EC96CDE99CC7DF95D1ECA7D0DC9E7F6739B29C6BDCEBAAC7E59BD0E59AD9EEA1
C6E595C7EA98C9EA9BC8E79BC7E19AD4EBA7CADD9DAFBF80
C9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99EC9E99DC9E99DC9E99DC9EA9B
C9EA99C9EA99C9EA99CAE89ED9EEB5000A00656F3BD8E1ACE3ECB5808A56DAEABBF5FFE4
F1FFF484A59E67999A95C2C7F1FFFFFFFFFFA89E950B00000A0000938D7D9C9F82CDDAAE
D2E7ACD0EBA4D2EEA1CDEA98D5EE9DD9F0A099AE614F6117BCD186C3DB8FCEE99ACBE898
CEE99CC2D991D1E8A2D6EBAA6B7D416F7E47CBD7A5D5E1B1D5E1B3CFDBABAEBC8B9AA875
7C8D57C3D49DD6EAAFD4ECB0CCE9B1C7E4ACCDE9AEC8E2A1DAF3AFC9DE99DAEDABD9E7A9
E0EBB3939B68888E5E5A5D2E959967A5AA74E0E5ADE3EFB1C0DB98CAE5A2DCE9B1818352
4B421795885E75693FE2E0ADDFEBADCCE39BC2E394C9EF9CCEF4A1CBEE9EBBDA8ECEEA9F
C9E598D8F4A7B6D285E9FFB8D7F3A6C9E598C3DD93ACC67C8BA25AC5DC94E0F4ADE3F7B0
C3D490DFEEABD0DF9CD4E5A1C7DE9AD5ECA8CDDD9CE6EFB0D2D699DCDDA18C92545B6727
94A966C8E19DD3ECA8CFE4A1D4DE9FD3D19663561FE7DCA4CECF93E8EEB0E7EBB0797A40
4A49108B864E9F98625C521D928551FCEFBB655522AC9C68A79A65574A15AC9F68E2D5A0
A79766655426BAAC7D7D713FA59E6AE4E1AA898A50545A1CD7E1A2D4E3A0D1E59ED0E69E
CDE79DCDE79DCCE89BC9E99DC4ED9FC2ECA0C2E69CD0EEA6D1E79FD2E69F6A7B35D0E49D
DDF3AAC0DA90D0ECA1CAE6997F974B98AD62E7F7AED2E39CCEE5A1C1E29DB7E396B5E996
BBED96C3EF98CFEEA0D5EFA5CBE9A3D5E3A5AF996AD5C18FC5D594BBDB90DDF3A8C2D98B
C1E490CCF3A0D3FAA9CBF0A2C6E69DD0EDAAD2EBAAC2D89A
C9E99DC9E99DC9E99DC9E99DC9E99EC9E99EC9E99EC9E99EC9E99EC9E99DC9E99DC9EA9B
C9EA99C9EA99C9EB97CAE89ED1E6AD000E00606C3AD9E3AFD6DFAAA3AD78D7E5B2EDFDD6
F5FFF35D7C770C474B629BA4E5FBFFFEFFFFFFFDF40F02001105008E8870989C77D4E0AE
CFE5A4C6E295CBEB96C9E791CBE490C2D9879CB164D9EBA1D1E59DD6ECA1CCE498CEE99C
D9F0A8CDE49EDBF0ADBACD8D91A365A0AF74D9E6B0CEDBA5D1DEA9D4E1AC92A06BD1DFAA
D4E5AFE0F1BBCBDEA6EFFFCEE7FFCED8F4C1C9E4ADCFE7ADC9DEA3CDDFA5DDEAB4000800
53582F4F512A52542FDDDFB8FFFFD8FFFFD4B6BE85D1DFA1DEF7B5C8E3A0DDEAB2DFE1B0
0B0200685B317E7248E7E4B1CAD497DBF1A9CEED9FC6E997CFF2A0C6E798CCE89DD4EBA3
D0E89EC4DC92D4EEA4BFD98FC1DB918AA45A56702790AA61C0D78FE7FEB6CBDF9AC1D28E
DDECA9DFEBA9D4E09ED2E39FC0DB94E7FFBBB7C884919A590E0E006161234E5414909F5C
C5DF98D3F5ABCCEEA4D1EFA7D6E5A2EAECAD4B3F05E1D59BE3E3A7575D1F48490F86854C
E0DBA4FEF4BFE7DBA9A99B6AB7A575E6D4A2E9D7A557451360501C73632FA89B64E7DAA5
EBDFAB938755F7EDBAA9A46D4E4D15585C214E561A5B6727D4E3A2D1E5A0D0E69ECDE79E
CDE79DCCE89DCCE89DC9E99DC5EEA0C3ECA0C4E69CD2EDA6D0E5A0D0E19D657630CCE099
D7EEA6C6E096CDE99EC5E1965D752B798F46CDDE97D4E59FD5EBAAD0F1ACC5F1A4C0F4A1
C6F8A1C3EF98C3E294C9E399CEEDA7C0D0916C5728A59361D7EAA8CAEA9FD1E99DD1E99B
CFF5A0BCE692BCE694C5EB9EC9EDA7C0DE9EC6E2A7D2EBB2
C9EA99C9EA9BC9EA9BC9E99DC9E99DC9E99EC9E99EC9E99EC9E99EC9E99EC9E99DC9EA9B
C9EA9BC9EA99C9EB97CAE89ED4E9B0000B00758254D6E2B2CED8A3CFD9A4CFDDA8F9FFDF
F4FFEFDFFEF91A5D636AACB8EBFFFFF0F0FAFFFDF40B00001C1100898467979971DBE8B2
D1E8A2C4E191CDEE97CBE993D4F09CB1C878899E53CEDF99D8ECA5C8DC95C9E098D0E7A1
C9E09CBED392D6E9A9D2E5A5708041ACBC7DD9E7AAD0DEA1D2E0A5BECB9392A16ACEDDA6
CFE0AAD3E6AFCADEA9F5FFD8F4FFDAC8E0AEC0D7A3CCDEAADAE8B79DA6775F643C8A8A68
9F9B7EBDB79DEDE8CBC9C6A5FFFFDCF9FBCAF3F8C0DDE9ABC8E19DCAE3A1D3DEA6373606
8E825861522964572DEAE4B2D3DB9FDEF2ABBFDB8EBBDC8BD4F5A4C9E598D2EAA0CBE199
D1E59ED9EDA6D7EDA596AC64465D15CCE39BC5DC94D3EAA2D8EFA7D5EBA3C6DA95D1E29E
B6C280939F5D879250A6B572344E07405A136778345762208C9151BDC282D7E2A0CCE09B
D7F5ADBADE94C2E69CC0E097D5E9A4D4DA9A6F662BEFE6ABE5E6AA7C8244595A205F5E25
B3AE77E3D9A6E4D6A5BBAB7A7D6B3DE3D1A1F2E0B0A2925F625520C1B6805F541CD0C78E
E0D9A2A4A269B9B77ED4D59BBAC082A3AD6EB1C07FC4D591D0E5A0CFE69ECDE79ECCE89E
CCE89DCCE89DCCE89DC9E99DC2E89DCCF2A7CAEAA1C8E29BCADE99DEEFAB7A8B45D5E9A2
C2D991D1EDA3C8E69CCBE99FA6C07795AC64AFC37CD4E8A3C3D897CCE9A6C3EDA1BAE998
C0F09AC3ED97C5E194CBE399CEE9A4DEECAE776132917D4BCFDF9ECBEBA0CBE196D0E799
CDEE9DC0E796C2E79AC2E6A0D5F5B6D1EEB6E6FFCEF4FFDD
C9EB97C9EB97C9EA99C9EA9BC9E99DC9E99DC9E99EC9E99EC9E9A0C9E99EC9E99DC9EA9B
C9EA9BC9EA99C9EB97CAE89ED3EBB1000B00707D51C4D0A2E2EFBAA5B27CCAD9A2F9FFDD
F5FEEBEAFFFF27747A216D7BE9FFFFFCFEFFFFFEF46D624C0A00006E674A878961D7E4AC
D5EAA5C8E595CEEE99C9E692BED988C4DA8FCBDF9ADCECABDAEAABD0E3A3D8EDACB2C687
788C4F798B4F86985A758546D6E5A4D6E5A2D8E4A2D7E3A1D3DF9F586628AEBE80FBFFD1
F3FFCEF6FFD4F5FFD6EEFFD1F8FFDAEFFFCEFBFFDAFEFFDA767850A4A17EF3ECD0FFF2DF
FFFAEBFFF2E3FFFAE7FFFEE4E4DFB9DBD9A8C6C78DD6DF9EDBF2AED1EAA8CDD8A0212000
84774DA08E6665562D9A92619CA2666A7B353C570A7F9E4EC8E797CCE79AD2E89FD9EAA4
CFDE9BD0DF9CA4B5719EAF6BCBDF9AC4D994DFF4AFC9DE99C5DA95D3E8A3D1E5A0DDEEAA
525E1CA0AB69939C5BB6C280B3C780CCE099C4D58FD3E29DCDDC97DAEBA5DBF1A9CBE59C
CAEA9FC1E397D2F2A7C1DD93D7EBA4DAE5A1949957898B4CC3CC8DCAD495E6ECB0CECF95
AEAB74766F3B7A6E3EB3A274847347604F21F3E5B4AB9F6B5E5720A49F67ECEAAF6F6F33
555718717737DCE2A2D0DB99DCE8A6CCDD99CCE19CE1F8B0CDE79ECCE89ECCE89ECAE99D
CAE99DCAE99DCCE89DCAE99DC2E69CCCF0A6CAE8A0CCE39DCCE09BE0EFAC7A8B47D7EBA6
CDE49ECCE7A0D0EEA6CAE8A0CDE8A1CFE9A2CEE39E8B9E5CD0E0A1DAF0AFCFF3A9BEE798
BCE692C9EC98D4EA9FD4E8A0D1E8A4C4CC90886D40C9B181E1F0AFCCE89ED9EBA1D1E399
C8DF97D9F4AFE0FAB9C1DAA0D7EEBADCF2C4F3FFE0F6FFE5
C9EB95C9EB95C9EB97C9EA99C9EA9BC9E99DC9E99EC9E99EC9E9A0C9E9A0C9E99EC9E99D
C9EA9BC9EA99C9EA99CAE89ECEE5AD122500606F46CEDBB0D6E4B1889760D1E3A9F4FFD5
FCFFF1D5F3F353A6AE196C7EE0FFFFFBFEFFFFFFF40C0400180C00948D709D9F77D6E3AD
D1E6A1C7E396CDED9ACBE896C8E396B3C981CEE1A1D9E8ADCBDAA1C4D59EA1B27B485B23
5A6B3454662C91A06591A162E4F3B0BECD88E3F0A8D2DF97DFECA63A4904C2D190F9FFCF
F9FFD4F7FFD7F7FFDCF8FFDCFCFFD8EFF7C8FFFFD8C7C8A076704EFFFEE4FFEEDDFFFAEF
FFF8F3FFF5F0FFFAEDFFF7DFDFD3ADECE4B3ECE8A9D3DA96C2D792C6DC9BE2EBB4403E0E
76673EA491698D7B53D9CF9EDCE0A5A9B873789044A1BE6EBBD888D4ECA0CDE199C9D895
DEEAAAD6E2A297A365AEBD7CD1E1A0E6FAB5C9DD98CBE09BD7ECA7D0E49FCEDF9BACBB78
576321D7E2A0E3ECABE3ECA9D3DE9ADAE7A2D4E59FCCE29AD9F3AAB6D48AD2F2A7BDDD92
BFDF94D0EEA4D5F1A7D7EEA6CBDF98D1E29CA1B06B5968235968259AA666D4DEA1DEE3A9
D7D6A0B7B17F73683A594C1FD0C29554471A918756756E3A5C5922AFB076DEE2A5C2C888
9AA561ACB973E5F5AEE0F1AAC4DA91DCF4AAC4E096B6D48ACAE89EC9E99EC9E99DCAE99D
CAE99DCAE99DCCE89DCAE89ECAECA0C3E59BC6E19AD9F0AAD8E9A5D0DF9C647330CEE29D
D5ECA6CAE59ECEECA4BEDD97C8E6A0CEE9A4CFE5A47B8E4EC1CC90C0CE90C9E49DD0F2A5
CCEF9DD0ED9BD8E89FCEDB958B9B5AA9AD72725327A78B5CD0DA9BC3DA92D1DE96DDE8A3
DEEDACC6D89CC3D49ECBDBACFBFFDFFBFFE6FBFFEDFBFFEF
C9EB94C9EB94C9EB95C9EB97C9EA9BC9E99DC9E99EC9E99EC9E9A0C9E9A0C9E99EC9E99D
C9EA9BC9EA99C9EA99CAE89ED2EBB2405628687851E1F0C7CEDCAB9BAA73DEF0B6F2FFD1
FEFFF1EAFFFF459DA700586BE3FFFFF9FEFFFFFFF4080100382C16C1B89BB4B58DD0DAA5
C9DE9BC7E398CFEE9ED1F0A098B26999AE6DC6D89E6876415F6D3C394918627241849664
B8C995CDDEA7819057C5D596CAD994EBFBB2C6D487E1EFA0C3D18467772EE3F2AFC9DB9D
D0E1ABDDEFBFC7DAADC8D7ACC4CC9BECEEBDAFAC8171694477684BFFF2DDF6D9D1FFE7E5
E6C4C5B49291C2A49CC2A995B09E789588549D9554A6AA60C1D58ED0E5A4DEE5AF605C2D
7D6E458B785087744CEADEAEE1E2A8E0EDA8CAE095C1DC8D94AF60D7EDA2D8E9A2D1DD9B
AEB67A293100B0B87DDAE4A7CEDC9EC6D695D7EAA8D0E3A1D2E5A3C6D997BECF8B808F4C
A6B36EC5D08CD5DE9BD4D997CDCF8EE2E7A4CFE099DFFBB0B8DF90C4F1A0BEE999CDF6A7
CDEDA1D2ECA2C9DD95D2E39CC8D992C8DE95CDE79DC5E197D7EEA8D0E3A1CEDC9ED4DEA2
C0C38CDAD8A5A39D6D6A6233D9CEA0EFE7B8A49E6C7B7A44989B62E0E8ACCBD797CCDB96
D4E59ED5EA9FB3C97EE0F8ACB9D588CFEEA0D2F2A6D3F5A8C8EA9DC8EA9DC8EA9DC9E99D
CAE89ECAE89ECCE89ECAE89ECBEDA1C4E499C5E197DAF0A8D8E7A4CDDC995F6E2DCCDC9B
C8DF9BCCE7A2C3E29CC9E8A4D1F0ACC9E6A3D2EBAACDDFA1A1A66C7E864A97AC67CCE89D
D1EE9ECFE696DCE69FD3DA964D5919DCDAA199764C69481B8286499AAE67BCC67FD5DA98
ADB27A7D8451767C509A9E79FFFFE6FCFEE9FAFAEEFFFFF8
C9EB95C9EB95C9EB97C9EA99C9EA9BC9E99DC9E99EC9E99EC9E9A0C8EA9EC9E99EC8EA9D
C8EB9BC8EB99C8EB99C9E99EC9E3A4091D0062714AC6D2AADBE9B487965BCFDEA7F8FFDF
F4FFF8CBF1F23A848D31788AEAFFFFFBFEFFEEEFE7100E00413620D9D2B6CBCCA4DBE5B1
D3E8A7CEE89FCBE79AC7E398849B55899E5DE0F1BACDDEA82A3C0A91A572C9E0ACCDE4AE
CBDEA7D0DFA6BBCA8FDDEBADD6E5A0C5D58CE0EEA3D1DF92DAE89B525F17C8D792DAE8AA
CFDEA5CFE0ACD0E0B1DAE6B6E3E7B4D1D19DBCB88880794D4A3D1AB4A588B09B86978271
7F695B6953455F4D375C4F2F5C542667652A565711525810667530B9C587DAD7A27D6C40
7E643F8B714C9A845BE3D9A8D8DC9FD6E39ED4E69CD2E79A8A9C52D4E49DD3E09BDCE6A7
9AA468909960DBE4ABD1DCA0DFEFB1D2E5A5CEDE9FD7E3A3DCE5A6D2DB9A6E7A38495A14
C7DB94DFF0A9D5DC98E3E6A3E2E5A2D0DA95D9EDA6BBDA8EC2E89BC9F6A5BEE99AC0E798
C7E59BD0E69DDAEBA5CEDE97E4F8B1CAE298C8E89DCBEBA0D2ECA5C7DE98CDE09EC3D193
6B7539969E6581844D4A4A14E6E6B2CBCB95E4E7B0B3BB80DCE8AAD4E3A2D4E5A1D4E8A1
D3E89DD4EB9DD0E69BC2DA8EDEFAADC4E395BBDC8DCBEC9DC9E99DC9E99DC9E99DCAE99D
CAE89ECCE89ECCE89ECAE89EC8E89DCFEDA3CCE69DCDE49CCDDE9AD7E8A470813DCFE2A0
D4EBA7D0EBA6C3E19BD7F6B2BFDC99CCE7A4D6EFAECDE1A2DCE7AB8B975992A762D2EA9E
D0E89AC6D98ADAE49BDAE49D98A462BDBC83805B2F937143979C5C869C54B2C279DCE9A3
ACB479B4BB88AFB58792976FE3E7C6FAFDE2FFFFEFFFFFF0
C9EA9BC9EA9BC9E99DC9E99DC8EA9DC8EA9EC8EA9EC8EA9ECDEFA3C9EEA1C8EA9DC6EB9B
C6EB9BC5EB98C3E996C4E594CEE59D717F44272D07D4DBB2A0AE70ABBB7AD6E2B0EAFFE2
E0FFFF92C7CB689098B6D1DCF4F9FFF4F2FFF2F8F40005000A0500A5A082B3B58DF8FFCE
D2E5A5C6DD95CAE298D1E99F889C5792A565D4E6AACFE3A8D3EDB0C6E4A6C9EEABC2E29F
D7ECABC9D79956652494A0609AA664B2BF7ADEE9A5D5E09BD3DE99545F1B909B599DA768
919B5E919C6095A06496A064949A5EDFE3A8D8DCA1E6E9B0B5BA828D945EA0A773949E69
96A06CD1DEA9DEEDB6CEE0A4BED392D7ECA7C6DD95D4E59F7379395E581EA78C5D734D26
63361597714D6C572CE7E1ADDCE5A6E1F0ABC7D48CD2DC95989D5AAFB474E3E9ADB5BE85
B1BE86D6E5AECFDCA4DDECB3CBE0A5C4DA9CE4F0B2B5B5799D905953490E8C9552B6CE84
C9EE9EC2E193DDE49EE1E29ED1E09BD3E9A1C7DE98CCE69DCBE9A1C6E49ABDD89193AF65
A0B771DFF5ADBFD48FD2E8A0D2E9A3C9E39ACEECA4CBE9A1D0EAA3D0EAA3D0E7A1CEE3A0
98AD6A899C5A94A765B5C584CFDFA0D8E8A7D6E9A7CCDF9DC8DD9ACFE49FD1E8A2CEE49C
6C8038A8BA70D2E39CD1E59DD0E49CDCF2A9D7EFA5C0D88EC5DF95C9E399CDE79DCFE99F
CFE99FCBE79CCAE69BC9E59AD2F1A5BCD88DD2EEA3CBE59BCCE39BD1E8A0B5CC84C7DE98
CFE6A0D6F0A9C3DD96DAF3AFC6DF9BCEE7A3D3E9A8D0E6A5D1ECA9C4DF9AB5D1878BA657
D7EE9ED5EB99D0E191CDDF93C9DF96777D3D846232AF8D5DDCE5A2BFDF93D3F6A4B9DA8B
CAE19BDDF0B0D4E6AAB5C78DADBE87BECF99BECC9BA8B587
C9E99EC9E99EC9E99EC9E99EC8EA9EC8EA9EC8EA9EC8EA9EC4E69AC4E99CC9EB9EC9EE9E
CAEF9FCCF29FCEF4A1D4F5A4CCE395C8D494141800D8DDB581904DD6E7A1D1DDADF0FFEF
D2FFFF68A3A796AFB6FCFFFFFFFCFFFFFDFF747D7C000400EAE9D4B1AE8F9DA279FEFFD4
D5E7A9D0E5A0D8EEA6CAE0989FB36E7E9151687A3CCDE3A5BFD998C8E9A4C4ECA3D0F4AC
C7DE98E4F3B0D3E29FD0DF9CC0CF8C788744CFDB99DBE7A5D9E5A3B6C17F495412DCE7A5
D7E2A0DDE8A6C1CA89E0E9A85A6020DAE0A0D2DB9AD3DE9CD3E29FD6E7A3D8EDA8C2DC95
CFEAA3C9E79FBBDB92D0F0A7D5F5ACD4F6ACC0E097DBF5AED3DD9EE9E2AB6B4E227B532F
390C0075512D67582DD6D9A4CDDD9EC7DB96E4F1ACEDF4B18C8C509D9C638F945C99A26D
D4E1ACCBDCA8D1E2ACD3E6AFD3EBB1CBDFA4E2EAB19D965F6C5825DECF96E0E9A8C1DB92
C8EFA0D8F9AAD8E29BCDD490D0E69ED8F6AED0EBA4BDD790D9F3AC96AD674D641EC3DA94
95AA65C6DD97D7EEA8C8E29BC6E099D7F2ABC8E69EC4DF98D7EEA8CCE19CC9DE99D1E6A1
CEE39ED2E7A2CCE19CC1D691CDE29DCDE29DC8DD98CADF9ADDF2ADDCF1ACA6BB76667A33
C7D8929DAE6794A55EBCCD86D4E59EC7DB93C8DC94DCF2A9DCF2A9D4ECA2CDE59BCCE49A
CDE79DD0EAA0CEEA9FCBE79CD2EEA3C1DD92D8F4A9D0ECA1CDE79ED0EAA1BAD48BCEE89F
C7DE98D4EBA5C0D791C9E09ACFE6A2D0E7A3CDE29FCAE39FC9E8A4C7E8A1CFEDA393AE5F
C4DB89D1E795D8EE9CDBF2A2D7F3A8DFEAA6603E0EAF8D5DD9E29FCBEDA0C3ED99D8FFAE
C7E59BD0EAA3CEE7A3C4DD99C6DD99CFE5A4D2E7A6CCE1A0
C9E99DC9E99DC9E99DC9E99DC9E99EC9E99EC9E99EC9E99EC9E99ECAECA0CCECA0C8EA9D
C3E598C0E393C1E494C5E494DEF5A7D8E7A66B714BB1B88F95A463D0E19DD7E3B3ECFFEB
D5FFFF296468AAC1C9FDFDFFFEF6FFDDD8DF858B89000400A4A18E969174959770C9D3A1
C8DA9ED4EBA7C7DE96D3EAA2CDE29D607333607234DBEFB2CDE6A5C8E5A2C6E7A0C8E89F
CCE39DD2E39FD7E8A4CADB97E4F5B18E9F5BDFEEABDBEAA7D4E3A0CCD896E5F1AFCDD997
CDD997E2EEACD5E09ED4DF9D798241E8F1B0D3DE9CDCE8A6E7F8B4C9DD98BFD690D7F1AA
C7E29BD9F7AFCAE8A0C0DE96C1DF97D1F1A8C6E49CBEDC96D9F4B1C6D497DAD2A1493209
8467455F4924777449D5E2ADC7DFA1C8E3A0D7EAA8C9D595D6DBA1BCBF8A878E5BB9C391
DAE3B4E9F6C8E2F4C2CADEABC6D8A4ECF6C2ECEAB9BCB5815B511EE8E6ADD9E3A6CFE2A0
CFE9A2CBE29CC8D792A5B67086A15A7E9E5583A159BFDA93B1CC8592AC65C7E19AD1EBA4
B8CF89BCD68FD5EFA8D8F3ACD0EBA4C0DE96C7E79ED1ECA5D0E19DD6E2A0DCE8A6DDE9A7
D4E09ED2DE9CC3CF8DAAB674B4C07ED8E4A2DDE9A7B1BD7B8D995796A260AEBA78B5C47F
E5F6B0BACE86A3B76FAABE76A3B76F879D547F954C8EA65C8AA25893AB6199B16792AC62
8CA65C93AD63A9C379BCD88D8CA85D8FAE62BCDB8FC9E89CCCE89EC9E59BAFC980BAD48B
D5ECA6C8DF99D0E5A07E934E9EB370B3C885C2D593DAF1ADCEE9A6C2E09AC7E19880984C
97AE5ECFE593D3E899CAE294C5E59ACCD896684817C09E6ED6DC9CC0DE94CCF1A1AFD484
CEEDA1CAE69CCAE59ED1ECA5D3EDA6CEE7A3D2E9A5D9F0AC
C9E99DC9E99DC9E99DC9E99DC9E99EC9E99EC9E99ECAE89EC9E79DC9E79DCAE99DCBEA9E
CBEA9ECCEB9FCDECA0D0EC9FC6DE90C7D7986E764F7D855CBFCF8EC0D48FD9E7B6EDFFEC
C6FFFC316C70D4EBF1FEFEFFFFFBFF0B040C0002006A7064F0EBD8A49D83A3A580DFEBBB
CCE0A5D1EAA8DAF5AEC8E29B59702C051A0094A668C5D79BDFF3B4CCE2A1CBE69FD6F1AA
CEE59FD1E6A1CBE09BCCE19CC9DE9992A762C7DB96D5E9A4D6E7A3D1E29ED5E6A2DEEFAB
D1E09DD0DF9CDDECA996A260505B19D9E4A2DBE7A5CDDC99CEE29DD7ECA7D3EAA4CCE69F
C6E19AC7E59DC2E098D0EBA4CEE9A2C5E099CFEAA3DCFAB4B9DD97D8F2B3D7DBA8776B41
533F1E64563366693ECFE1ADDAF6BBC3E0A0D6EAABCED99F9297617A7C4BA1A77992996D
80875DA3AE83F7FFDCD9EDBCDCE8B8FFFFD6FFFDCF9892624E511CD7E0A7CDD89CC6D496
C3CF918B9A5990A763C8E39ED3EEA7CDE8A1D3EDA6C5DF98CBE29CDEF3AED0E5A0CBE09B
8DA15C90A560C8DD98CAE19BCDE49ECFE9A2D8F3ACC9E09AD4E3A0DDE8A6D4DF9DCFDA98
9DA86698A36188935186914F939E5C96A15F8F9A588994529EA967C7D290DDE8A6DBE8A3
C8DC95D2EAA0D4ECA2C1D98FA8C07698B06690A85E8CA45ACFE79DD7EFA5D3EDA3BAD48A
9AB46A8CA65C98B268ABC57BC5E498BFDE92D0EFA3CEEDA1CDE99FCFEBA1C6E097D4EEA5
DAF1ABACC37D889D58BACF8ABBD08DB1C4829CAF6DA9BC7CDAF0B0D2E8A7C7DE988AA057
778C3FD6ED9DD2E99BC7E398C7E99FD9E8A789693A9E7C4EE3E7AAD0ECA2C1E293D7FAAA
CEEDA1C9E59BC9E59BD0EBA4D0EBA4C8E29BC8E29BCFE9A2
C8EA9DC8EA9DC9E99DC9E99DC9E99DC9E99DCAE99DCCE89DCDE99FCAE69CC9E39ACAE49B
CEE89FCFE9A0CFE69ECCE49ACDE599E1F6B539441CA1AC84D2E5A3DAEFAAC9D6A8EEFFF1
C0FDF6488387EEFFFFFDFCFFE5DBE6090209000200E0E4D6FFFFEDCDC5AE9E9F7DD5E1B3
D2E7AEC2DC9BBCDA949BB973415A18485E1EBAC98EC6D59AC7D598E7F7B6C3D790CCE29A
C8DF99D0EAA3D1EBA4DCF6AFC9E09AA5BC76B9D08ACBE29CCCE19CCBE09BD7EBA6CFE39E
DFF3AEC3D792CCE09B92A35F94A360CBDA97D2E19EE2F3AFCDE19CCEE39EDAF1ABD6F0A9
C8E39CCFEAA3CAE59ED1EBA4CFE9A2C3DD96D0E7A1BFDD97CAF2ACC5E8A8D8E2AE8C855B
4333125E512F676C43CCDEACC0DCA2CBE4AAC7D69DC8CF9BA9A777CDC89EFCFAD4E5E5BF
A6AB83879268F7FFDDD3E4B7E2E8BCE7E2B8FCF0C86B683B9AA873C1D69DE2EFB7E3EBB2
6B6A349EA66BBFDC9ABBDF99C7DE9AE1F2AED7E8A4C5D491E2EEACD9E5A3BCC785E7F2B0
B8C180747F3DDDE9A7D1E09DD5E4A1E7F8B4B6C783D2E39FE0EFACCBD7959CA866B2BE7C
909C5ABECA88C8D492E9F5B3D1DD9BD5E19FDBE7A5DEEAA8DBE7A5D6E2A0D3DF9DD0E19B
D4EBA3CBE79CCBE79CD2EEA3D2ECA2C9E399C7E197CEE89ED0EAA0CDE79DC9E399C7E197
C7E197C8E298CBE399C9E399D4F3A7C8E89CC9E99DC3E397C3E197C6E49AC4E096CDE79E
C5DC966E853FD7ECA7CBDF9AD7EAA8D5E5A497A7669EAE6FC7D799DBEDAFD5E8A6B3C780
6F8439D0E69BC9E497D2F0A6B9DD95D8E8AA997A4EBB996CDBDCA2D6EDA7BDD78DD2EEA1
C8E499C8E79BCAE99DCBE99FCCEAA0CFEBA1CFEBA1CEEAA0
C8EA9DC8EA9DC9E99DC9E99DC9E99DCAE99DCCE89DCDE79DD0EAA1D0E79FCEE59DD0E69E
D2E7A2D3E8A3D2E6A1CFE59DCEE99C879D5C727E56D6E2BAD4E9A6D8EFA9CBDBACEEFFF1
BDFAF372ADB1EBFFFFFFFEFFB9AFB80A01043B3E35FCFFF1EDE4D3E9DEC8ABAC8AD5E1B3
D1E6AD96B3715E7F3A5776329BB574C2D898A0AF74505B1FEAF4B7D7E2A0D2DD99D6E7A0
D0EAA1BEDC94C6E49CC5E39BDEF9B2CAE59ED0EBA4C9E49DCEE8A1B9D38C889F59D6EDA7
C2D993E4FBB5DDF4AE8499548C9D59CCDD99DEEFABC9DD98A4B974D0E7A1BED89157712A
7A954E89A45D6C863F445B15465D17778C47CFE49FCDE6A2C7ECA6B2D291DEE6B39F966D
3D2A09685837686941DFEBBBCADEA9E8FBC3D1DBA6898957FFFED2FFFED7F4ECC8F4F1CE
A6AB83C0CBA0F8FFDCFBFFDCFFFFDACBC299847D51777A4BC7E0A7DCF8BDD0DFA6D1D49D
59531FDFE4AAC0E39FBDE79FCBE4A0D3E4A0CCDB98E9F8B5D3DF9DC5D08EF0F9B8D3DC9B
D7E09FB8C180909B59939F5D86955281904DB9CA86A6B773889C578DA25D92A762D8EDA8
C8DD98E0F5B0C6DB96CDE29DD8EDA8CADF9AC5DA95CCE19CD0E5A0CDE29DCFE49FD7EEA6
D3EFA5C7E79BC3E397C9E89CCCEB9FCBE79CCBE79CCFEBA0CFE99FCFE99FCFE99FD1EBA1
D3EDA3D2ECA2D1E99FCCE69CC0E094C1E396CAEA9ED1F1A5D7F5ABD5F3A9CFEBA1C9E59B
CDE49E6F8640E3F7B2B5C984CEDE9DE1F1B0BCCB8ACEDC9EBBC68AD7E2A6D2E1A0D0E19D
94A860CEE69CC7E398C9E9A0D7FFB9C7D99D85653C866137999860849853D3E79FCBE397
C8E499CEEDA1CFEEA2C9E89CC9E79DCFEDA3CFEDA3C8E69C
C8EA9EC8EA9EC9E99DC9E99DCAE99DCAE99DCCE89BCDE89BCBE399D0E69ED3E9A1D3E7A2
D1E1A0D0E09FD4E4A3D6EAA594AF623A531168774ED0DFB6CDE3A2C3DC98DAEBBEEBFFEF
D5FFFF76B1B5F0FFFFFFFEFF7F747A0E05065A5E50010400756C5B0A0000282909D4DFB4
CBE2AACBE9A9C5E8A4CFF0ABBCD997E1F7B9D0DFA4E1EBAF39420359601D9FA662D7E49C
D5EFA6C9E9A0DAFAB1C0E097CAE8A0C0DE96CAE8A0CDEBA3C0DB9456712ACAE49DCAE49D
C9E39CBED891C9E39CD8F2ABD7ECA7C5DA95B5CA85B8CF899FB670C7E19AE4FEB7CBE69F
CDE7A0CAE49DCCE39DD4EBA5C0D59097AB66CFE39ED9EEA9C7E59FDDF1B2D1CD9D69562E
290C005A401F91855FD8DAABD8E2AED1DCA4D1D49FA8A270FFF2C6EEDFB8FFFFDCE8E4BF
ACB387E0ECBCC4CD9EE5E8BBD9D2A6948C5E535321D9E6B0C9E7A9C1DF9FD6E4A9E4E5AC
656029CFD79BC9EEA8C8F6ABCEEEA5C1DB94DAF1ABC2D993C7DC97E6FAB5CBDC98CDDE9A
DBECA8C5D692CFE39E5C712C4E651FD4EBA5C7E19AC1DC95D0EEA6C9E9A0C9E9A0D6F6AD
C5E59CC8E89FC8E89FCCECA3CBEBA2CCECA3CEEEA5CEEEA5C7E79EC1E198C4E49BCBEDA1
B8DA8EC9EB9ECFF1A4C6E69AC4E498CEEDA1D0EFA3C8E79BC4E095CAE69BD1EBA1D0EAA0
CCE49AC9E197CDE59BD0EAA0D2F2A6CEF3A5C6E89BC0E295BEDE93BFDD93C8E49AC9E59B
DDF4AEB7CE88415510DFF3AEE4F4B3D7E6A5D4E3A2DAE6A8CDD59ADAE2A7D7E1A4DCEBA8
C9DD96C6DD95D0EEA6C6EAA2B7E09CDBEEB6A0835B714B24E1DEA991A05F9FAF68CBE095
CDE99CCDEE9FCCED9EC7E899C5E599C8E89CC7E79BC3E397
C8EAA0C8EA9EC9E99EC9E99DCAE99DCCE89DCDE89BCFE79BD1E79ED5EBA2D1E59EBFD08C
A4B372909F5E8B995B8C9F5D8BA55BC6E19E000900D7E6BDCEE7A5D1EAA6CDDEB1E9FFEF
C1FEF9569195E7FCFFFFFEFF887D810800000103002A2D18827B683F381E70714FEDFACC
D4EDB4EDFFCCBBDE9AC2E6A0CFECACD1E7A9CAD99ED1DB9FE9EFB1AAAF6D868944D8E49C
CAE49BC3E59BCCEEA4C4E69CC6E69DD8F8AFC7E79EC5E59CA8C67EC5E39BD2EDA6C8E39C
D9F4ADCCE7A0CDE8A1C7E19AD6EDA7CCE19CCCE39DE2F9B3C1DB94C1DB94C9E49DCBE69F
D0EAA3CEE8A1CDE49ED7ECA7D8ECA7BCD08BE3F4B0C2D691CEE59FD2E1A0F0E6B3391D00
240200DBBA979A8B62E7E5B5D0D9A2DDE8AC5B5E25B4B17ADBD1A0F2E7BAF1ECC2CED1A4
F3FFCCD0DFA8DFE1AFD9D3A3CABF915C5926758046C8DE9ECFEEABCCE7A4D3DDA0C3C488
B3B478DAE6A4C5EBA0BEED9FC7F0A4C8ECA2BEE298CDEFA5CBEBA2C3E199CFEDA5C8E69E
CBE69FCEECA4BEDC94CEEEA5BBDD93C8ECA2CDF1A7C3E79DC8ECA2BEE298C8ECA2B9DD93
C6EAA0C3E79DD1F5ABC0E49ABEE298C5E99FC7EBA1C5E99FC6EAA0CAEEA4CAEEA4C4E99C
CAEFA2C8ED9FC7E99CC6E89BC9E99DCBEB9FCAE99DC6E599D1EDA2CAE69BC5DF95C7E197
D1E99FD6EEA4D3EBA1CBE59BBDDD91C6EB9DC9EB9ECCEEA1CAEA9FC7E59BD1EDA3D0ECA2
CCE39DCEE59F99AD68869A55C4D493CDDC9BDFEEADF0FCBEC9CE94D4D99FDCE4A8D1DD9D
CDE19C92AC65C4E29CC6EBA6BDE6A4D0E3ACBC9E78A8825DE9E3AFD6E2A2919E59D7E99F
CCE89BC6E798C6E798C9EA9BC9E99DC8E89CC9E99DCDEDA1
C8E7A1C9E9A0CBE9A1C9E79DC9E59ACAE69BCEE99CD3EB9FD3E99EC4DA91E3F7B0899A56
96A564919F613F4A0E556524CCE89DC8E3A0687851D0E0B9D0E9A8BFD896CDDEB2ECFFF2
001B1666A1A5F0FFFFFFFFFF8278790600006E715EF8FEE4FFFEE5282305B8BD95F8FFD7
EDFFCCF0FFCFC2E5A1C7EBA5BFDC9CD4EAACD7E6ABD3DDA1DFE5A7E0E5A3C3C9819FAB61
C7E198DBFDB3BDDF95BBDD93D7F9AFCCEEA4C9E9A0C0E097BEDE95CCECA3C7E59DCFEDA5
D3F1A9C5E39BCCE7A0D3EDA6D0E7A1CBE29CDBF2ACC9E09AD0EAA3C8E39CD6F1AAC7E29B
C5DF98D2ECA5D1E8A2CADF9AD9EDA891A25EDCEBA8C6D791C5DB93E2EDA9E3D69F6B4F20
603D159777509D8F62DBDEA7E0EEB0C1D590596523D7E09FD5D99E9FA46C99A36EC8D9A2
CEE6A8D0E2A4D9D49DFAEDB89E955E93975ADEF5B1C0E097D7F2ABC6DA93E0E7A4999E5B
D5E29CD4ECA2C0E597C1EE9DBFF09FB4E798C9FCADBBEC9DBCEB9DCBF7AAB2DE91C6F2A5
C6F0A4C3EFA2BCE89BBCEB9DC3F4A5BAED9EB3E697BDEC9EC8ECA2CCEAA2CEECA4CFEDA5
CBE9A1C4E29AC5E39BCBE9A1D1EFA7C5E39BD4F2AAC6E49CD7F5ADBEDC94DBF9B1BFDF94
CFF1A5B9DE90CDEFA2CDEFA2C9E99DC7E79BE0FFB3B5D488CAE69BCBE79CCDE79DCDE79D
CFE79DCDE59BCAE298C7E197C3E397D1F3A6C9E99DC6E69AC8E69CD1EFA5C5E197D7F3A9
D3EAA4D2E9A3D2E6A18EA25DCADA99DAEAA9DDEDACE8F4B6A9AE74E3E8AED6DEA2D1DD9D
D7EBA6849E57C8E5A2C4E9A6C7EFB0CEE0ACE8CAA6E1BB97D4CE9AD4E0A09DAA65D0E298
C8E499CEEEA2BBDB8FD4F4A8CDEDA1C3E397D7F8A9C5E697
CAE9A5CBEAA6CCEAA4CAE8A0CBE79DCBE79CCDE89BD1E99DD6ECA1C4DA8FC9DD955F702A
DAEAA9CFDD9FE6F4B6C7DA98D3EFA4C6E09F55653E93A37CCEE7A6D7F0AEDEEFC397B59D
36746FCAFFFFE0F8F8FEFEFE877F7C0600006E735CF3FCDDF5F4D5CCCCA8DFE8BBDCEFB8
E2FFBFC3E3A0CBEFA9C2E39ED7F1B0D6EAADDDEBB0CDD79BA8B172A4AB67B5BF76B5C57A
D0ECA2C1E399D2F4AACFF1A7B5D58CCAEAA1C0E097B3D38AACCA82D5F3ABCFEDA5BDDB93
C6E19AD6F1AAD8F3ACBED891CDE49ECDE49ED2E9A3DBF2ACCEE8A1C5E099CAE59EDBF6AF
D7F1AAC8E29BC2D993E4F9B4B4C88395A662D6E5A2D8E9A3DAF2A8D4E49DE0D79C624B19
311200BEA678746D39D0DA9DC1D892DCFBAFB0C87CB1C77EA7BB74C2D794C7E4A4CEECAC
C1E29BDFF3AEDBD297A8975F4D4709D7E29ED7F7ACC5E79AC4DA91E9F6AE525913939D54
D6ED9FC8E797C8E998CCF1A1BAE697C8F9AABCEB9DA9D88ACEF8ACC0EA9EC2EB9FC2EB9F
BBE498C5EEA2C2ECA0BDE99CC2EEA1C0EFA1BDEE9FC7F1A5D2EDA6D0E5A0CBDF9ACBE09B
D3E7A2D7ECA7D7EBA6D2E7A2D0E49FBED38ED4E8A3D2E7A2BFD38E8BA05B849853DCF3AB
C5E59ACDEFA2C7E99CB3D387BFDF93CDECA0BDDC90DDFCB0CFEBA0CDE99ECDE79DCCE69C
D0E89ED3EBA1D7EFA5D8F2A8D1F0A4ABCB7F84A4588CAB5FC3E197D5F1A7BFDB91C9E39A
C1D892D0E7A1CEE39EC4D893A6B977CEE19FD4E7A5E3F1B3B6C084C8D095D4DE9FD6E5A4
DFF3AEB2C985C8E5A2C8EBA9B9E1A3C4D6A2BFA17DD6B08CDDDAA5E7F6B5BCCC8599AE63
91AD62D2F2A6CFEEA2C3E397D0F0A4D2F2A6B5D589CFF0A1
C8E4A7C8E5A5C9E6A4C9E6A3CCE7A0CCE89ECDE79DCDE89BD1E99BD5EBA0D0E69D71853E
BED28DE8F8B7D6E6A7D8EBA9C7E398CFE9A870805B85936FCFE7A9C3DC9BC9DBB1375740
70B1ABD4FFFFDFF9F8FEFFFD928D870401003A4527CCD8B4BEC49ED7DDB1CCDAA7D8EDB2
CAE7A4D2F3ACD5F6AFCEECA6A7C07F9EB0728A985BA0AC6ED1DD9BD4E19BC4D489D1E699
C3DF95D4F4ABB8D88FD7F7AED7F5ADC2E098A6C47C98B66EC8E39CCDE8A1C2DD96CCE7A0
D2ECA5C3DD96CDE7A0DAF4ADDAF1ABBFD48F6D843E5B722C738D46C7E19ACDE8A1C7E29B
CDE7A0D4EEA7D1E8A2D3E8A3596D28869753CCDB98D5EBA3C0E094D9F3A9B3B576413400
A18B5AA4946354571ED5EAA7C8ED9FB8E28ECAF29CC5EB98D0F3A3DBFFB4BCEA9FC0EEA3
BAE093D8EEA5BEB9796C6123878846DBEDA3ACCF7FDCFFADCCDE928C964DE4ECA3D2E395
CDEA98D6F8A4BAD58498B062B3CD848EA96267813AE6FFB9D5EAA5CBE09BD9EDA8CFE39E
D3E7A2D7EBA6CEE39EC8DF99D2E9A3D2ECA5C9E49DCBE09BCFDA98D3D999D6DB9BDCE2A2
E4E9A9DBE1A1B8BD7D939959969B5B9FA565A0A5658D9353ACB171DEE4A4979C5CD6E39E
CBE59CD5F5A9CCECA0E3FFB6CFEEA2CEEA9FC2DE93C3DF9486A0568BA55B91AB6195AF65
93AD638DA75D879F55809A509DB96EC9E89CD0EFA3BEDA8F728E44C6E097D1EBA2D3EDA4
E0F7B1DBF2ACC4DB95BFD48F6075328BA05DC1D693D9ECAAADBB7DBDC98BD4E3A2CEDF9B
C8DC9798AF6B7D9756C9E7A9C3E9ACF9FFD6A483608F6945D6D59FD4E7A5C6DB90D5ED9F
A5C176749248D6F2A8C6E49AC4E298B7D68ADFFEB2CAE99D
C8E4AAC7E3A8C6E2A5C7E4A2CCE7A2CEE9A2CEE89ECCE79AC8E092D2EA9CD5EDA193A960
D0E69ECADF9AC2D593C9DE99DDF7ADC6DF9E53613D707E5AD9EFB1CFE8A7D3E5BB2A4A33
76B7B1D2FFFFEDFFFFF3F8F28B887F0302004C5A39D8E9BF889466D7E4AFD8EAB0C7E09E
CFEDA5C8E89DBFDD93CAE59E92A7667E8E50A0AE71CEDC9ED0E19DD4E8A0DBF4A3CAE594
CBE99FC0DE96CFEDA5C3DE97D3EEA7C9E49D829D56B1CB84CCE69FD8F2ABCAE19BC9E09A
D5ECA6D3EAA4CFE6A0C0D791ADC27DA4B9748FA45FB3CA84BDD48EC9E39CBCD68FD4EFA8
C3DD96D6F0A9DEF5AFB7CE88576C2797AB66CDDE9ACCE39DD3F8ABBAD88EA5AB6F0D0300
7462349C9060898E54D4EBA7CFF6A7B6E28DD4FCA6C0E691BAE08DC4ED9EB2E394C1F0A2
D8FAADCCE1969899577C7936ACB671D6ECA1D8F9AAB8D787D3E196979F56C5D187D2E79A
C8EA96CDEF9BD2E9998E9E53AFBA766B7634384100E0E6A6D3D898D3D898E0E2A3DEE0A1
DBDD9EDFE1A2DCE1A1DDE2A2DEE4A4D4DD9CD1DC9AE0E9A8E9EBACE8E8AAE0E0A2D8D89A
D6D698C6C6889797596767295353155F5F2189894BB8B87AD9D99BE7E7A9929254D7DE9B
CEE49CC4E095B3CF84D1EDA2C9E399C9E399D6F0A6D0EAA0718B41809A5098B268B1CB81
C4DE94CDE79DD2EAA0CFE99FD3EDA3D0EAA0C8E298D7F1A790AA61DEF8AFCBE59CC9E39A
CBE29CC9E09AD6EDA7CCE69F95AC68889F5BCBE29ECBE09DBCCF8DDCEFADDDF1ACD1E5A0
CBDF9A8FA461566F2ED5F1B4C6E8ACFBFFD6C6A582D5B28CEDEEB5D1E8A2DAF5A6C4E191
D2EEA3B8D48AC3DD96D8F4AAB8D48AE8FFBCCAE89EB6D589
D9F1BDD3ECB5CCE5ACCBE5A8CDE7A6CFEAA3CEE89ECBE699C9E495DCF7A8779243BFD78B
E1F9AFC5DC94E1F8B2D1E8A2C2DC92D1E7A772805C8E9C78D2E8AAC7DFA1D2E4BA587861
3C7F78BEFFFFEBFFFFF9FFF976766A0205005E6E49CCE2B3A5B881D3E7AADCF2B1C1DC95
CEEDA1BBDA8CEAFFBB7F964EADBD7CD2E0A2D6E4A7D1E1A2D7ECA7C3DD93B5D783D1F4A0
C9E79DD6F1AACDE8A1BFD9929FB9728FA962CBE59ECAE19BCDE49ED1E8A2C6DB96D4E9A4
DCF1ACC3D893B0C580A2B67193A762C8DC97D8ECA7C2D792B5CC86CEE8A1D6F0A9D0EAA3
D1ECA5C1DC95CEE8A1ADC47EC1D691CBDF9AD8ECA7CFE6A0D1F5ADC4E19E53582265582B
7F6940A2916680804CDAEAACD3F1A7BEE191C4E491CDE897CBE395D2EEA3C9EB9FCFF1A7
C7DE96C7D89158631F929F59CDE19ADDF5ABC8E096D8EDA2D3DF976D7931E1F3A9D6EEA2
C4E395CAE6999BAD61D0DA93E3E3A3E1DFA2ADA96C999357E5DCA1DDD499E8DEA3E7DDA2
DAD095ECE2A7F1E8ADD6CD929892565F5B1E6361249191539294558183446567285D5F20
7E8041B7B97ADDDFA0E7E9AAF1F3B4D3D596D9DB9CEDEFB0E1E3A4BFC182A9AB6CD1DA97
D4E8A1DBF3A9E8FFB6B0C87EDBF3A9E4FCB28EA65C8AA258CEE69CCDE59BCBE59BCBE59B
CCE69CCDE79DCFE99FD0EAA0CDE59BD0E89EDAF2A8C4DC9289A058BFD68EC3DA92E2F9B1
C8E29BCCE69FDAF4ADCAE59EBCD5917E995496B16C819C57ADC682C7DE98BFD68ED0E69E
DAEEA7D3E8A3AEC382DCF6B7F0FFD4D1DDAB9E7C57B5926CCFD398BCD88ECDEF9BC3E591
CBE79D79934C718844D5EFA8CDE7A0CDE99FC2DE94D7F3A9
EFFFD7E3FBC9D5EEB7CEE7ADCEE8A9CFEAA5CDE79ECAE598D1EC9DC5E2905D7829D9F6A6
C0DB8ED2EEA3BEDA90CFE9A0D0EAA0D3E7A85F6B4774805CD6EAAFF7FFCFECFDD3779780
377A738CCECDE4FFFEE9F3EA898B7E0A0F00000B00CAE2AEA0B87CB7D08EBEDA90D0EFA3
C1E090D3F0A0ABC377859952D9E8A7CDD99BD4E2A5D5E8A8C6E099D1F1A5D4FEA8BBE38D
C5E399D1EBA4CFE6A09EB56F97AE68BCD38DCFE49FD9EEA9D4E9A4D0E49FCADE99DBEFAA
C5D6928CA05B9EAF6BCFE09CDAEBA7CBDC98CEDF9BDFF3AED7ECA7D4EBA5CEE8A1C9E39C
CFEAA3C8E39CCBE59E8BA55EDFF6B0D1E6A1DBF0ABCBE4A0BCDA9A95AD739D9A6D120000
8C6D4EAC8F6D706337D7D7A1D1E09FD6E7A0D9E59DDFE79EDCE29CD1D894CEDD9ACEDD9A
7881405B6725809751D2F0A8CFEAA3C3DA94D2DF9AE4EFABEAF5B18E9F59C9E39ABFDB91
D0EAA1C4DA92ABB872D5DE9BD3D898E8EDADC6C8895C5C1E6A682B6361245F5B1E4D490C
6E6A2D514D1049470A828043CACA8CE4E6A7DCE1A1DCE2A2DDE8A6DCE8A6D7E3A1D0DC9A
D2DE9CD8E4A2D4E09ECAD694C8D492D5E19FDAE6A4CFDB99D9E5A3E5F1AFE0ECAA889752
CCDD97D7EBA3C2D68EE8FCB4C1D58D3A500790A65DDCF4AAD2EAA0D1E99FD0E89ECDE79D
CCE69CCBE59BCBE59BCBE59BD1E79EC8DE95DBEFA7D7EDA4546A22DAF1A9DDF4ACC1D890
CDE7A0D1ECA5C5E099C9E49DD3EEA9C4E29CC7E59FCDEBA5CFEDA5CFEDA3D2ECA2DCF4AA
BAD088D5E9A4C9DC9C8AA062F1FFD4D0DAA6997752B08D65F6FCC0D4F3A7C0E691D3F9A4
CAE69CDBF2AECFE6A2849B57C7DE9AC7E19ADEF8B1C5E197
F5FFDDECFFD3D7EEBACDE4ACCDE5A7D0E9A5CEEAA0CBE79ACDEA9A86A653BAD785C4E393
D3EFA2CFEEA2BBD98FD6F2A8CBE399CEE0A2606A474C5633AFC388E8FEC0F8FFE1DDFDE8
C0FFFC377978C6E5DFF8FFF87A7E6F000600667B52C4DFA8809D5BDAF8AECBEA9ECBEA9A
CDED9AC7E291445B0DDDEEA7CBD795E0EAADDBE6AACDE0A0CDEBA3C5EC9DB8E990C3EF98
BDDB91E2F9B37D924DADC27DCEE39ED2E7A2D2E6A1CBDF9AC8DC97E5F6B2CFE09CADBE7A
9EAD6AA8B975CDDC99DDECA9D6E5A2DCEDA9D4E5A1C8DC9794A964C5DC96D5EFA8C4DE97
C3DE97D8F3ACCFE9A28BA55EC7DE98BED58FD4EBA5CAE09FCBE3A9AAB38488785678543A
8C5E47B58770886748E5D2A8DAD09BF2ECB0E4D99B806D326E581E604B126A5B245B521B
544D168B9357D3F7B1B7E29AD3F7AFD1E6A3DADB9FD9D99D808C4C9CB36FC2E19BD9F8B2
DCF1AED9E5A57C8647D8E7A6CEE59FC8E69ED9F4ADD1EBA4B5CC86C7DE98DAEFAACBE09B
CEE39ECCE19CC2D993C5DC96D0EAA3CEE9A2C4E29AC5E39BCEEEA5CCECA3C8E89FC5E59C
C6E69DCBEBA2D1F1A8D6F6ADCEEEA5D4F4ABD1F1A8C5E59CBEDE95BBDB92CCECA3A0BC72
8FA35C768740C2D38CAEBF78A0B16AD8ECA4D0E49CCDE39AC8DE95CAE298D0E89ED5EDA3
D4EEA4D2ECA2CEEA9FCCE69CE3F9B0BDD189D0E19AD7EBA3647831D2E8A0D1E8A0CBE29A
CDE7A0CBE69FC8E39CCFEDA5CAE8A2D4F3ADC1E09AC8E9A2BFE197BCDE92D2F1A5DAF5A8
C2D88FDDF1AAE0F3B3BCD093D8F1B7A6AE7B835F3B9B784EC5CE8FB9DC8CCCF79EB6DE88
D1ECA5C7DC9BD0E5A4B4CB878CA35FB1CB84BCD68FCFE9A2
F7FFE6EBFDD7D5E7BDCADEADCCE1A8D0E9A7D2ECA3CFEB9EC7E49292AF5BCBE894CBEB98
C9E898CFEEA2C9E79DC8E49AD2EAA0CCDF9F7681575F6A40C6DA9BD6ECACD2E6B5C2E1C1
B5EBDD91CDC57EACA2C2E0D4EEFCEF000600D1E3BBD2E9B3CBE6A3C8E49ACAE69BC4E093
D5F2A2C4DF90D3E99ECFE099DAE9A6D3E2A1D2E2A3D1E6A3C9E79FC7EC9EC6F29DC5EC99
DFF9B0B7CB86596E29D6EBA6C9DE99D4E9A4CEE29DD8ECA7DDEEAAC4D39094A3609AA966
C4D58FDAEEA7DCF0A9C8DE96D2E69FD0E49DC7DB94DFF3AE8EA35EC5DA95D4E9A4D4EBA5
D0E7A1D4EBA5C5DC96C4DB95E3FAB4CAE19BD0E7A1D1EAA8CFE7ABD7E3B161552F190000
50230C74462F684326F2D9B1AB9B6A5D521A60541865571AEADA9EE6D79CE1D69EE4DDA6
DFDEA5E0EEB0C2ECA4BCEFA4BAE29BD4EDA9DCE2A6D8DC9FE5F5B63A5510D0F1ACBAD993
CDE2A1D5E4A39BA769CFE4A1CEF0A6BEE799C8F1A5BCE295D5F9AFB6DB8ED7F9AFC6E89C
BFE197D3F5A9D1F3A9C0E598C3E79DC9EFA2C7EDA2C2EB9DC2EB9FC1EC9DC6EFA3CAF3A5
C7F0A4C2E89BC0E69BC3E99CC6ECA1C4EA9DC0E69BC9EFA2C9EFA4C2EB9DC7F0A4C7EC9F
C9E497E2F8ADCADF94DAEFA4CCDD96D0E19AD7E8A2D0E19BD6E7A1D2E69FCEE49CCCE299
CBE399CCE69CCEEA9FD2ECA2C7DD94E1F2ABD7E8A23D510A9CB069CCE29ACAE199D3EAA2
D3EDA6BFDA93D6F1AACAE8A0BFDD97CDECA6CAE9A3CDEFA5D1F3A9C8E89DC6E599C6E194
DBF3A7CFE59CB6CB86E5FBBAC8E5A5D4DDA675522A6F4C22DCE2A4CEEDA1CDF39CC7ED98
CDE7A0CDE1A2D7ECABC4DA99CCE39F94AB674B6420D1EBA4
FBFFF3FBFFEFCCD9BBCDDCB5E3F5C3C6DA9D9EB46C6B833559721FBCD883DCF8A3C5E28E
CFEC9CCEEA9FC0DB94D1ECA5D8EFA9CEE3A0B1C3893D4F15B2C784D1EBA4D1EAA9C4E1AB
C6E8C7AFDECA22695B51938967847F07130536401DDEE8B6D3E3A4ADC17CCDE39BDAF0A8
C7DE9696AD65D1E8A0CFE69ECDE49EDFF6B0B8CF8BD6EDA7D0EAA3C7E399CFEBA1CBE59B
C2D68F879852CBDF98DBF1A9C0D791D9F0AACCE19EB1C482B1C07F9BA765B0BC7ADAE9A4
D1E79ED2ECA2C1E092CDEE9FC8E79BD6F2A7BED88ED2E9A14A6018CFE39CD8E9A5CEDF9B
D6E6A5D4E4A3A7BA789CB16ED3E8A5C8DF9BD5EFA8C9E79FC6EAA2CAE7A5A0A9725B5325
3E28038E714F61452069562B554E187E834393A05AB4C67CC6DC91CDE59BE2F9B3CFE8A4
C8E39ECBECA5BFE99FC2EEA3C2EAA1CBEDA3D4EFAAC9E39CC7E59F94B46B4B6A24AECC84
C1DA96D9F0AAB6CD89CDE8A1C6E89CC1E899CAF0A3C9EEA0C3E89BCDEFA2C3E599CCEEA1
C0E095CDEDA1C8E89DCDEDA1C2E297C6E69AC9E99EC7EC9EBEE99AC1EE9DBDE899CBF4A5
C1E79AD0F5A7C9EB9FC8EA9DCCECA1CEEEA2C4E69AC1E396CAEFA2CBF2A3C3E99CC2E998
C3E692CCEE9ACBEB98D9F4A5C8DE93D8E9A3D2E19ECEDA98DEEAA8AEBA789BAA67C8DC95
CCE299D1EBA1C2E193CFEBA0D6ECA4C8DC95D9EDA86D813CAFC37ECFE49FD0E7A1D4EBA5
D1EBA4C8E39CC8E39CCEECA4CEECA4C5E59CC8E89FD3F1A9D8F3AECDE7A0C5DC94CFE79B
D5ED9FCBE697D0EC9FCBEBA0CBF1A8CFDFA18665389A7549959559899F56D4EC9ECCE798
CAE19BCCE2A1C8DE9DD9EFAECEE4A3CFE8A687A05E4E6723
FBFFF7FCFFF4DCE4CDC7D2B0C7D4A69EB076C5DA95CEE597B8D17EDDF7A0D2EE99BDDA86
CEEB9BD0ECA1C5E099D2EDA8C8DF99CADF9CD1E6A53F5413859C56C2DC93D7F2ABC8E5A5
C7DCB5E6FFF4439686308178678E8B000A00282D0DDDE1AFD3DDA1909F5CD7E6A3D4E5A1
D3E8A3879E58CEE59FCEE8A1C1DB94D0EAA3D7EEA8CBE29CD1E6A199AE69A9BD7884954F
8C9B56CCDC95E7F8B2C8DE96CBE29CCBE29C859A57839654B7C685CEDA9AE1EDABC7D691
C8DE95D7F3A6CCEF9FC1E696CCED9EC1E094DCF8ADC7E19890A65EC1D590D1E29ED7E6A3
D0DF9ECFDE9D91A160B0C381D1E6A3CEE59FD4EEA7D6F4ACCCF2A5C1E399C8DA9CE3E6B1
827549A6936B685229F2E4B5E9E8B0CFDB99C7E197CEF1A1D1F8A7C5EE9FB9DF92BDE197
CAEEA4C7E99FD3F5ABCAECA2C3E39AC3E199CEE9A2C8E39CCDE7A0C6E09990A761DAEFAA
C2D792CADF9AA2B671CAE199CAE89ECAEC9FC6E89BCBEDA0BFDF93D4F4A8BFDF93CBEB9F
D4F3A7C7E69ACAE69BCCE89DC7E398DAF6ABC4E095CFEEA2BDE294D8FFB2C7EE9FBDE294
CBEB9FC6E599B6D589D3EFA4C0DC91CFEBA0D0EFA3C9E99DC8EA9DC3E89AC1E899CAF1A0
CBF39DBEE48DCFF19DB8D585CFE59CD9EAA4E2EEACE2ECADB2BC7D909A5BBDCC89A9BA74
CBE199C6E096DCFBADC6E599C4DB93D7ECA795A964D6EBA6D1E6A1DBF2ACBFD690CEE59F
CEE8A1CFE9A2CBE69FC8E39CCEE9A2D4F2AACDEBA3C1DC95B7CC89DAEDABD9EDA6DBF0A5
C6DD8DC9E493D7F4A4BFE194BCE599CBDE9EB09163A17C50E2E2A6DBEFA898B064C0D88C
CFE6A0E6FCBBD5EBAAC9DF9EC2DB99CEE7A5CFE8A6CEE7A5
FDFFF7F7FDEFE0E8D3D5E0C0D4E1B58C9D66CFE49FDCF3A5DEF7A4D7F09CC6E28DC6E38F
D5F2A2D0EFA3C5E399CAE8A0CFE9A2D4EBA7DFF3B4243800A7BE7ACEE8A1CEE9A4D7F3B6
CFE3BEDBFFEB79CCBC04554E577E7D000400878C6CD9DDABDEE6AB65702EB8C482D7E6A3
CCDD999BAF6ACDE19CCCE19CD6EBA6CFE6A0CBE09BDBF0AB9CB06B6B7F3AA3B470D8E7A2
DDEAA5DBE8A2C3D48ED3E9A1C8DF99BBD28E97AC69ACBC7BD4E0A0D7E1A2E3EEACC6D590
D2E89FCBE79AC5E898CEF1A1CCEAA0CFEBA1C7E198C6E099ADC47EE3F8B5C1D693DBF0AD
D3E6A4D9ECAA8BA05BD3E8A3D3EAA4CAE19BBED58FBFDB91C4E69AC9E9A0D9E9ABD6D6A2
605327B29F77604D23DED2A2D9DAA1CFDB99DAF4AABFE292B9DE8ECEF3A5C8EA9EDBF9B1
DBF0ABB8CC87D4E5A1C9DA96DEEDAAD9E8A5D9E5A3DBE7A5DEE9A7909958BBC483CBD191
EEF4B4E8EEAE909555DFEAA6D2E9A1D3EFA4C4E095CAE69BC0DC91DFFBB0C7E197D4EEA4
C3DD93D2ECA2CAE298D3EBA1D4ECA2B9D187D7EDA4CCE49ACDE79DC9E59AD0EAA0D0E89E
D9F1A7DAF0A7D9EFA6C9DF96D6EEA4D7F1A7CBE79CC1E094C6E89BC9EEA0C5EC9DC7EE9D
C2E893C5E894CBEA9AD8F3A6CEE49BDAEBA5BFCE8BD9E5A598A464B4C080DCEBA880944D
CFE69ED2EEA3C9E89AC2E193CEE89FD3EAA4839853C5DC96D2E9A3C9E09AD1E8A2D6F0A9
CDE7A0CFE9A2D1EBA4CEE9A2C8E39CC4DF98C8E39CD1EBA4B3C684A1B06D7E8E47B7C77E
CDE091D8ED9ECDE597C8E79BC3E9A0DBEDAF94774B7C5B30D4DA9EC9E49DA2C276D8F7AB
A5BC76C1D693D1E6A3CAE19DD8F1ADCDE6A2D1EAA6D0E9A5
FEFFF8FBFFF1F7FCE8FCFFE6FBFFDD98A973D2E5A3C6DC91CCE594C2DE8AC7E490D0F09B
CFEE9EC7E79BC7E79CCAE8A0C4DE97CFE6A2BED2930D21006C8241CBE4A2BFDA97C7E0A7
CFE3C0E6FFF859AB9D1C6D66749B9A000B025C6342E2E6B4DDE5AA80894896A15FDAE6A4
CAD996BECF8B98A965D6EAA5CBDF9AD7ECA7C8DC97CFE39E9FB06CBBCC88D8E7A4D0DD98
D4DF9BD5E29C9AAB65AEC27B9EB370ACC17EB7CA88D9E9A8E0ECACC9D394D5DFA0DFEBA9
DAEEA7D4EEA4C3E397C0E094CAE49DC8DF9BA8BF7B7F9854C0D995D4EDA9CCE5A1C2DB97
CBE4A0D3EDA6849E57CFE9A2D2E9A3D5ECA6D9EFA7D8F2A9C6E49AD3EDA6D1DCA0979763
493C10C8B68E9E8D62E4DCABE5E8AFC9DA96CFE99FD3F4A5D4F7A7CBEB9FB9D58BC8DF99
CCDD99E4F3B0E4F0AE7A86449DA866AAB573A3AC6BC1CA898D9353C7CD8DBEC484E9EEAE
D6DB9B5156169FA162D6DF9CC6DA93D0E89ED4ECA2CBE399CEE69CC5DD9394AA61839950
96AC63A7BD74CFE39BD9EDA5C7DB93DCF0A8A3B46DA4B56ED8E9A2D5E59EB9C9828F9F58
AEBB75B2BF79C4D48DD9E9A2C9DD95D1E79EC9E399C3DF94CAEA9ECEF0A3C4EB9CC1E897
C0E391DDFEADC6E295C4DE94C6DC94DBECA8B4C382909C5CAEBA7AD9E8A5D5E6A293A760
536B21C4E093BAD989DFFEB0CEE89FCAE49DCDE49E9CB36DC6DD97CCE39DCDE7A0B8D28B
C3DD96D1EBA4C7E19AA4BE7791AB6496B16A92AC658198528F9F5ECBD795C6D38DB6C479
919F5494A45983984DD1EBA2D6F7B2CCDBA084673D907349D8E1A8CCEDA8CBF4A8B4D98C
BAD18B9CB06BD2E6A1C9DE99D8EFA9C9E39CC7E19AC7E19A
FFFFF6FCFFF2FEFFEFFCFFE6DCE9BE8A9B65CFE1A3D3E9A1D1E99DCBE695CFEC9ACCEC99
BEDF8EC0E295CDEFA3CFEFA4CAE59EDAF3AFD2E8AA6076381A3000BDD695E3FDBCCCE5AE
D0E3C3E5FFFA6BBDB100514B729899000500777E5DD8DFACD2D79DADB675939C5BD1DC9A
E0ECAACEDD9A5B6C28CCE09BE0F4AFC7DB96DCEDA9CFE09CB6C58291A05DCBD795DBE8A3
D5E09C5A672145540FD3E7A0C5DA97CDE29FE7FABAD3E1A3D0DA9DE8F1B2D6DFA08E9A58
495A14BDD58BE9FFBCD0EEA4D3E9A8D1E3A591A566879D5DC4DE9DCAE7A4D1F0AAC3E29C
BFDF96CBEBA296B46CC3DF95CAE49BCDE39BD8ECA5C2D890C6E097D6EBA6E1E9AEE0DEAB
74673BA5936B85784CE1DBA9D4DCA1D9EDA8C4E095BFE091C5E496CFE99FDEF2ABCCE09B
DEF3AE4156118CA15CC8DD98CDE19CCDE19CEBFFBACFE39ED7E8A4D2E39FE5F6B2DAE9A6
D0DF9CA1B06D96A260D1E09BDDF1AAD0E69DCAE09798AE65CCE098D2E69EDBEFA7DDF1A9
D0E19A92A35C55661F000D004D5D164C5C15CBDB94ACB9734E58135E6320CDD28FE7ECA9
A9B06C8E95519DA76259641F99A962BFD38BD8F0A6D5EFA5CBEA9EC4E498C0E597C8ED9F
D0F1A2BDD98ED1EBA1DEF5ADD3E9A148591596A564DAE9A8D9E8A5D6E7A3CFE39E475D15
C4DE94DDF9ACC6E595C1E092D3EFA5CFEAA3D4EEA78EA86193AD66CFE9A2CEE8A1DAF4AD
CBE59E69833C4A611B97AE68D2E9A3C4DE97C3DA94E4F9B4DDEDACD3DF9DCAD791DDE99F
D3DF9595A157364600CDE19AC3E09ECED9A1DDBF99CFB18BD0DDA7B7DE9BC3F1A8C7F1A5
D6F0A77F934CDFF3ACD0E69EC8DF97C7E198CAE49BD9F5AB
FEFFF3FDFFF1FEFFEDFBFFE5ACB78D92A36FCBDDA1D5ECA6D2ECA2CDEA9ACCEB9BC7E897
C2E595C8ED9DCDF2A4C6E89CC3E199C1DA96DBF3B5A2B77C5F753771894BCBE3A5C3DBA9
CCDFC3E5FFFC64B5AE368884325A5A000E04929C7ADCE3B0D9E1A57C8544919C5ACDD997
E1EDABD4E5A187985493A762C4D994CEE39EDBEFAACFE39ED2E39FDEEFABC9D895879651
BAC580E0EDA7CBDA95DEF2ABD1E4A2CDE29FCDDD9ED5E3A5D2DC9F9CA468889152B8C283
93A25FCEE49CC1DD93B9D48DD6E8AACBDAA194A66CCDE3A5C2DC9DCAE9A6C1E59FCDF3AA
D2F8ADC5E99F8EB0647B994F7B954C889E56A3B46E93A45EB0C47DD6E7A3D2D79DDCD9A6
4D4014918259807548E4E2AFD4DFA3DBF0ABC4E095CFEEA0D0EB9EB0C67D96A35E596825
849B557E9952CCE69FD2ECA5D3EDA6C7E19ACAE49DC3DD96D1E8A2BFD690D4EBA5C7DE98
D3EAA459702AAABF7AD5EBA3D2E8A0CCE299D5E9A192A65ED6EAA2C6DA92CEDF98C2D38C
D6E7A0C3D48DA4B46D91A15A90A059E2F2ABC9D690CCD792DCE39FDEE19EEFF2AFD5D895
A8AD6A9FA461B0B7739CA762ADBA74CCDD96D9EFA6D0E89EC9E399C5E498C7E79BCEEEA2
D2EEA4CFE9A0CBE29ABFD48FB9CD88889C57CEDE9DCEDF9BCEDF9BC7DB94E3F9B19FB76D
C5E093DAF6A9D0EF9FC1E092C1DF95CAE59ECEE9A2C6E19AA8C27B8EA8617B954E79934C
5E78318DA760BFD690D1E8A2D0E7A1CEE59FCCE19CC8DD98C8DD9AD8ECA7DDEDA6CCDA8F
DBE79DC9D58B6F7B33DBECA8DCF4B6DFE8B39F7D5A957451D9E6B1BDE4A5CDFAB5BEE89E
D6F0A774853ED7EBA3D2E89FCDE39AD3EDA3C5E196C5E196
FCFEF0FFFFEFFDFFEBFCFFE4A0AB81C6D7A3D5E7ABD0E7A3C9E39AC7E396C6E595CAEB9A
D0F3A3CEF3A3C6EB9DBFE496D1F1A6C9E49FDBF3B5C8E0A4D1E6AB4F672BC2DAA0D0E8B8
D2E4CCE4FFFE64B5AF388A886C9496000600677250D8E0ADE1EBAE596523A2B16ED2E39F
D1E29ED2E7A2D0E5A0869D57D1E8A2D1E8A2C6DD97DEF5AFC2D792CFE39EC1D590DAEBA5
D0DD97D3E09AD1E09BDEF2ABD5E8A6D3E8A5D9E9AAD4E2A4959D61D3D99DE3E9ADCBD596
98A764D5EBA3D7F1A8E0F7B3D1DEA6939D69C8D7A0D3E8AFDBF8B8B8DB97C6EEA7BAE49A
BAE498C3ECA0CEF3A6D2F2A7CEE89FD0E69EBBCC869EAD685A6B2599A563CED198DDD7A5
7B6E42E1D4AAAFA779DFDFABD3E1A4C4DB95C9E89CD1F0A295AD6151621B838C49E2EDAB
CEE59FCCEAA2D5F0A9CAE8A0CEECA4C5E39BC8E69ED6F4ACCEECA4D0EEA6C6E49CCDEBA3
CAE8A03F5D15C9E49DD0ECA2D1E8A0CFE79DD0E69D8CA259D3E9A0D2E89FE0F4ACDFF3AB
C5D991E1F5ADC3D48DDDEEA7C2D38CDDEEA7DAEAA3D4E49DE0EBA6C9D38ED1DB96DDE7A2
C9D38EDFE9A4D8E39EA1AE68C9D992D7E8A1D0E49CC4DA91CAE298D4ECA2D0EAA0CDE79E
CBE29CD0E5A0CEE39ED2E5A397AA68C6D997D6EAA5D7EBA6D8ECA7D2E8A0CBE1997F974D
CAE598BFDB8EC3E294CDECA0CDEBA1CCEAA2D0EEA6D8F6AEDAF5AEB9D48DD4EEA7CFE9A2
D6EDA7D8EFA9D2E7A2C9DE99D0E5A0DDF2ADDDF1ACCDE49ED4EFA8C6E298C5DD93CBE093
DBEBA0CAD68C9DA863CDDC99BED496E2E6B4936C4D8E6A4AE5EDBEB5D79BCEF7B5C0E59F
CDE49C9AAC62CCE196C4DA8FCFE59AD8F3A6D3EFA2C8E799
D5D8C3E7ECD5F0F6DAFCFFE3859266D6E7B3D2E6ABCFE5A4D2ECA5CBEA9EC6E597C9EC9C
CEF1A1C3E898BFE697CCF1A3C4E498D5F3ABBDD796D1E9AD99AE734A5F26D1E8B0CBE0B5
D0DFCAE3FFFF51A19E004B4C083032000F05B7C39FCEDBA5CFDD9F90A15DCCE09BD2E7A2
D0E7A1C4DE97D3EEA7BED992CDE8A1C8E39CD4EFA8C5E099D7F1AACCE39DCDE49ED4EAA2
D9E9A2DAE79FD3E49DC8DC95D1E6A1D2E7A4A9BC7C728042B9C185DFE5A9D1D79BB6BE82
B6C584CFE39EBAD48DD6ECABDDE7B2929A69EBF7C5F8FFD3E0FCBFEEFFCFDCFFBEC1EDA2
C5F1A6BEE89CC6EC9FC8EA9EC0DA91DFF4AFD5E4A1D7E3A1B5C47F8D9856BFC087ABA573
6C5F33AA9D73888153DEE1ACADBB7EA3BA74A7C37892AE61A7BD72D9E9A2DAE19ED8DE9E
D0E19DDBF0ABC6DB96C8DD98D8EFA9D5ECA6CDE49ECCE39DCAE19BD1EBA4CBE59EC8E29B
88A25BD5EFA8CCE69FD2ECA3C9E39AD2ECA2CCE69C90AA60CBE399CDE59BC9E197C8E096
D7EDA4CAE097D3E9A0CCE299D8ECA4D1E59DD1E59DD3E79FCDDE97DFF0A9CCDD96D6E7A0
DEEFA8D8E9A290A15A687932A8B972C8D992D5E9A1D0E49CD2E69ED5E9A1CFE59CCDE39B
D4E9A4C2D794DCEFADADC07E819452DBF0ABDBF0ABC5DA95CEE49CCBE29AD6EEA4ADC77D
D8F2A8C7E398D5F1A6C7E69AC3E197CEEEA5CAE8A0C6E49CB8D38CD7F2ABD4EEA7C6E099
CDE49ECFE6A0D2E7A2D2E7A2CFE39ECADE99CBDF9ACDE49EC0E298CCF1A4CDEDA1CBE697
D1E699DBEBA0D0DD9791A05FD5E9ACD0D2A1D8AC8FB1856AF4F3C7E7FFC9C7E9ACD3F3B0
869C54ADBF75D3E89DCCE297D3EB9FC6E194CCEB9DCAE99B
DBE1C5CCD5B6F9FFE0FCFFDFAFBC8EDAEBB5CEE2A5C9DF9ECDE7A0C8E69CC4E397C4E699
C7E99CD1F6A8BFE697C6EB9DC9EB9EC7E79CD1EBAAD1E9ADD9EEB360753D647B459FB48B
E9F8E5E4FFFF62B2B13081821A4345000900A4B38CCEDDA6CBE09FB6CD87C8DF99D3EDA6
D0EBA4C2E098C4E49B85A75DC3E59BD2F4AACDEFA5C7E79ECDEDA4C9E79FC5E39BD7F1A8
D1E29BDEEEA5D4E8A0C7DD95B4C984637835AFC282D9E7A9DEE6ABD8DDA3E0E5AB9BA367
A5B173C6D997CDE6A2CFE3A4D7DFAED1D7ABE9F3C1F4FFCFF4FFD3D2F2B1CEF6B0C5EFA5
C0ECA1CBF5A9BBE196CEF0A6D8F2ABC5DA97D3E2A1D5E4A3CFE09CCCD896B8BB825C5624
403307988B614C45179DA06B909E61B4CB85D2EEA3BFDB8ECBE196DBE8A2CED391E9EBAC
DADF9FE6EBABD7DC9C878C4CA2A868979D5DA3AC6B9BA463A0A9687D884696A15F8B9654
BAC583D9E4A2D4E09ED9EAA4CEEAA0CBEB9FCCEB9FA6C5797F9E52D1F0A4C9E59AD4F0A5
CFEBA0C4E095CFE99FD0EAA0CCE69CCEE89ECCE69CCCE69CC6E297CBEA9ED0EFA3C5E498
DEFAAFC7E398C6E096CDE79D859D5391A75EAFC37B8DA15995A65FD0E19AD1E19AD1E29C
D1E5A0D6E9A7ACBF7D899C5ADDF2ADC5DC96C4DB95DBF2AAC6DD95D7F1A8D6F0A7809A51
DBF5ACD0E79FC0D78FD5EFA6DAF8B0C2E299CBE9A1CFEDA5DBF6AFC3DE97CFE9A2C8E29B
CAE19BD1E8A2D5EAA5D7ECA7D1E5A0C7DB96D8ECA7C1DB94C7F0A4C1F0A0C8F1A2CBEE9C
C7E494CFE698D7E8A1D2E2A192A669ABAA7ABD8E72C29077FFFFD8F9FFD6DCF1B8CCE5A4
70863DD0E598D5EA9DCFE698CFEA9BC4E191D1F0A0C3E493
D2DEB8D7E3BBFBFFDDFBFFDAAEBF8BCFE2AACAE0A2D5EEACC7E29DCCE7A0D0EEA4D8F8AC
B9DB8EC7EC9EC3E89AC6EB9DD5F8A8C0E295D4F1AEBFD99ACFE7AB8FA46C000D00859A73
F7FFF4DBFEFA63B3B228797A214B4A0008008A9B71DFF1B7CFE5A49FBA73D3EEA7C8E69E
C7E79ED7F9AFB8DC928DB368C6ECA1C6ECA1C4E89EC6EAA0CEF0A6C9EBA1C3E39ACAE69C
C9DF96CBDD93CFE59C9AB1696E853F6D8440D8EBABCCDA9CDAE4A8CDD298E0E5ABB1B97E
D7E2A6D1E4A4CEE7A5CFE5A7CED6A7D1D4A9FEFFD8FBFFD4E6FEC4C6E4A4BEE19DC4ECA3
BEE69DCCF5A9C7EBA1C5E49EC4DD99D8EDACD3E3A5D6E6A7D5E9A4D6E7A3B1B67C9C9966
42370A8E815761592BDFDFABD3DEA2C2D792CFE99FD5F0A3D5EBA0DCECA5D9E09DD6D698
E2E0A3DEDC9F9C9A5D6262245C5C1E737536898B4C9196568C9151757B3B959E5D969F5E
C3CC8BDEE9A7D7E2A0D9EAA4CBE79DCCEEA1B6D88BE5FFBA8BAB5FBBDB8FC9E99DC3E397
CDECA0C8E79BCCEB9FCDECA0CDE99ECAE69BC7E398CAE99DCDF2A4C7EE9FC4EB9CC0E798
B6DB8DC5EA9CD3F3A7CEEDA1D6F2A7CCE69CD4EAA18CA0586B7C35B3C37CDBE8A2DFEEA9
CFE09CD1E4A29FB270889D58D5ECA6C6E097D2ECA3BCD88ED1EBA2BFD990C9E39A90A761
829953D4E9A4D8EBA9CBE09DC8E39CBDDB93D1EFA7C6E49CBDD891D7F2ABCCE69FDCF6AF
D8EFA9CAE19BCBE09BCDE29DBFD48FE0F5B0D2E6A1D2EDA6BDE99CB8E998BBE897C2E996
CAEB9ACAE797CCE299CEE39EC2D89AB2B181CB997ED8A288E5D7B0DEE6B3F2FFC7C1D494
80944CCEE597CFE698CCE496D0ED9DC5E494D1F2A1C8E998
CFDFAED6E6B5EAFBC7D6E9B28A9D6594AA6C83995990A967ADC8838DA86177954BCFEFA4
CCECA0C5E79AC9EB9EC8EB9BC8EB99C3E696CCEAA4D2ECABC8E0A4CFE4AC435928526641
EBF9EAE7FFFF3787862F808144716E041B09B7CA9DC5D99CC6DF9B95B069CBE69FBFDD95
BBDB92CEF0A6B1D58B80A65BC9EFA4BFE89CC2E89DC7EDA2C6EAA0C7EBA1CAECA2C6E49A
E2FAAECAE095A6BE748CA65DCAE59ECCE5A1D5EAA9D8E8AAECF7BDEFF7BEE8F0B7A1AB6F
D7E5A8D9EBADD8F1B0C6DBA0D4DCADBFC599F0F8C9DDEBB8D3E6AED1EBACCAE9A6D4F5AE
C8ECA4CEF2A8BDDC96CFECA9CCE5A4D1E5A8D2E4AACFE1A3C7E09CC8DD98D1DB9FD4D4A0
0B0300CBBE947E7648D3D19EDFE9ADDAEEA9C3DD93C9E497C9DF94A0B16A9099569FA464
989A5BD5D798DEE3A3E3E8A8D7DC9CDFE5A5E9F2B1D4DF9DD7E3A1C3D28FD7E8A4CCDD99
DCF0ABE3F7B2D0E49FCBE59CD0F0A5BFE496C3E89ADBFFB2B5D78A88AA5DE0FFB5C6E89B
C8E89CCCECA0C9E99DCAEA9ECEEDA1C6E599C5E498CFEFA3C0E798BCE797BBE696D8FFB3
C8F1A2C8F1A2BDE294C7E99CCEEEA2B8D489C1D98FD2E89FDEEFA8ABBB7486934DCAD994
D8E9A5A7BB76A4B974BBD28CE0FAB3C6E298D9F5ABC7E69AD0ECA2CFEBA1CBE59ED5ECA8
8DA06065753696A467D0E0A1D6EFABCDE8A1D4EFA8CAE59EC7E19AD6F0A9C3DD96C5DF98
CFE9A2C2DC95D3EAA499B06A94AB65758C46687D3865833BCAF4AAC7F8A9BCE998BAE490
CBEE9CCAE999C7E396D5EFA8D9F3B4ACAE7CA37456D7A185EEDDB2E5E9B6D1D9A05D6929
9EB26ACFE79BC7E295C9E598CFEEA0C4E596CEEFA0C8EB9B
C7DCA1CCE1A6D5EBADD6ECAEC1D797D7F0AFC9E2A0D5EEAAC0DB94C6E19A355309D1EFA5
C9E79DC6E69AD8F7ABBDDE8FCAF099C8EE99C4E499D5EFAEC2DA9ECDE2AAC9DFAE1F300C
D1DDCFBEE1DD04525264B6B4000E090009006D8150CFE4A3D6EDA9B8D28BCEE9A2DAF8B0
CEECA4C5E79DD0F2A886AA60C6ECA1C2E89DCAEEA4C7EBA1BDDF95C9EBA1D4F4ABC5E399
BFDA8D90A85AB9D389D1EDA3DDFBB3CDEBA5D6ECACDFF1B3FBFFCEFFFFCFD6DFA6A0A970
CBD99ED2E6A7D2ECABCCE4A8DCE5B6C2C89CE9F1C2DDE9B7D6E7B0D4E8ABCAE3A2BBD691
C0DE98D4F2ACC1DC99D3EDACD5EDAFC8DDA2F8FFD3F2FFCCD0EEA8D7F2ABD6E6A8DEE3AD
7870429B8E64958A5DF3F0BDC7CF94CFE09CE4FCB2CBE699526A1E2E42009BA863D5E09E
E1ECAADEE9A7D4DF9DCEDA98DAE9A6C5D692E6F7B3C7DC97DAEFAACAE49DD2ECA5C4DF98
C5E39BC9E9A0BCDC93BEE094CBEDA1C0E295DAFCAFB6D88BD0F2A577994CB9D98DC7E79B
C4E498CFEFA3C5E498C8E79BCFEEA2C8E79BCDE99ED0F0A4C3E89AD1F8A9BEE596BCE596
C2E99AC2E99AB4DB8CCAEFA1B5D78AD3F2A6DAF6ABCBE399D5EBA2C1D58DA8B972DAEBA4
D0E49D4F651DD5ECA6E1FBB2B3CF85D0EFA3CBEA9EC9E99DBBD98FC9E49DD3ECA8D6EBAA
CCDC9EE1ECB24C551EE3EEB4D1E6A3CDE8A1C7E19ACBE59EDCF6AFCAE49DD7F1AAD3EDA6
C4DE97DBF5AE475E187B924CD7EEA8DEF8B1B8CF8992B068B7DB93CEF7ABC7EE9FBCE28F
CDF09ECEEF9EC4E395CFEFA4CBEBA8C4CD96805533A67354DFD1A4CACD969BA165495513
BFD58CD2EDA0C5E194C8E799CEEFA0C2E595C8EB9BC4E999
D5EFA8D3EDA6CCE5A1CCE5A1C8E19DD4EFAAC3DE99C6E19AE3FEB7B4CF88DCF7B0648036
CAE69CCFEDA3CBE79CCFF09FD3FAA1C0E88FC6E89BC2DF9CD9F1B3C9DEA6CBDFAE6E7F5B
000600D9FCF80E5D5A2C7E7A29564F000A008EA571CBE09DC9DD98A5BA75C0D791D5EFA8
C5DF98BBD991CCEAA286A65DCAEAA1C8E89FCDEDA4C7E79EC2E098D3EEA7CFEAA3ACC87E
90AB5E94AF60D6F5A9CDEDA2B8D88FBEDD97CEE7A6DDF1B2EAF9BEE3EEB6A7B079CAD59B
DEEDB2CBE1A3C1DB9CEBFFC7E4F0C0CBD2A6E6EEBFDDE7B3CCD9A1C9D99BDFEFB0D5E8A6
D1E6A3CDE4A0DFF5B4C7DD9FD1E9ADD0E7AFF5FFD6F2FFD3BFE39DB4D68CDBEFB0D9E0AA
373002B0A379786B3FD3CB9AEEF1B8CAD69482984F89A457B7D285C6DE94D2E69FC9DA96
CDE29DC6DD97C9E09AD3EDA6DBF6AFC1DF97D1EFA7BDDF95C9EBA1C2E89DC5EBA0C1EA9E
C0EA9ECAF6A9C6F2A5CFFAABBEE094D1F1A5C9E99DC6E69ACAE99DA6C579506F23C7E69A
C8E499D6F2A7C6E297C9E59AD0EAA0CDE79DD0EAA0BFD98FC1DB91D1EDA2DFFBB0C3E296
C2E296CDEFA2DBFDB0C4E699D7F9ACC3E397CBEA9EBFDB90BBD58BE4FCB2B8D086475F15
8EA45BD2EAA0BCD68DC1DD92DAFAAEB7DA8ACDF0A0C7E99CD1F1A6C4E29ADAF0AFB7C98B
D9E4ACE2E9B5565A28BCC38DC9DC9CD1EBA4D1E8A2CDE49EC9E09AD1E8A2C2DC95D3EDA6
B1CB84657F38D9F3ACCDE7A0C7E19ADDF8B1C5DF9890AB648CA561C3DE97D2EEA3C3E292
D0EF9FD1F2A1C0E393BDE295B1D992ECFBC09A774F6E421D6C622F58602497A05FDBEAA5
D0EAA0CEEDA1C3E397C7E99CCCEEA1C2E799C4E99BC3EA9B
C6E597C8E799C8E79BC9E89CC7E399CBE79DCBE69FCEE9A2B5D089D8F3ACCDE8A19BB66F
BCD88ED1EDA3CDE79ECCEB9BC1E88DC3EC90C6E999CCEAA4D6EFAED1E6ADCFE3B0D1E2BE
5A665895B8B457A6A30F645F1B4841000B00ADC48CDBEFAAD5E6A28B9A57CBDC98D9EDA8
CEE39EDEF5AFD0EAA3A5C079D0EBA4C9E49DC7E29BCCE69FD2E9A3D2E9A3B9D08A95AC64
ADC87BC2DF8FCCECA0B6D88CD0F2A8DCFDB6C5DF9ED3E9A9D2E4AAD4E1A9919C64D8E5AD
D9EBAFCEE6A8C8E5A5F1FFCEF4FFD1C0C899DFE7B6D9E1AECFD8A1D5DFA3DCE8AAD4E0A0
D6E5A4738344B3C587C7DB9EF6FFD3F0FFD1C3DBA9CEEDB4C0EAA2DFFFBCC3DC9BC8D19A
837C4E988B61635429A69C6BB1B078B4BF7DCFE59CE0FBAEC5E194C8E499E6FDB5D3E8A3
D2E7A2E3F8B3B2C7828BA25C7B954ECBE69FD3F1A9C9E9A0C5E79DC5EBA0C2E89DC5EFA3
BBE599BFEB9EB6E597BCE798C9E99ED4F0A5BBD78CD3EFA4CEE89ED0EAA03E580EDAF4AA
CDE59BDAF2A8CBE399CFE79DCFE59CD0E69DCFE59C98AC64A2B26B82924BC4D58EE1F5AD
C9E197B6D287DBFAAEC1E195C9E99DB3D588C9EB9EDBFBAFC8E89CCEEDA1DBFAAECBE79C
CFE99FC0DA90E2FEB3CAE99BBFE091D3F8A8C9EE9EC6EB9DC6E89CC9E79FCAE09FD9E8AD
9AA36EA6AA78DDDCAEECF0BECDDD9ED3EAA4D7ECA7D3EAA4BFD690EFFFC091A8629CB66F
B5CF88CFE9A2BED891D9F4ADB9D48DC3DE97CCE7A0CAE49D99A968D1DD9BDFF0A9CAE095
C8E392CDED9AC8EB99C0E99AC0EEA3DCF5B4BEA376C09D73DEDCA3C9D895D4E49DCEE398
D1EDA2C6E89BC3E598C7EC9EC9EEA0C5EC9DC6ED9EC7EE9F
CCEE98CAEC96CEF09CD0F1A0C7E698C4E397CEECA2CAE89ECEE9A2D2EDA6CEE8A1D3EDA6
BCD68FD5EFA6C0D78FC6E393BFE689CAF395C6E997D3F1A9BAD392C7DCA3D5E9B6C9DAB6
5864567EA19D5FAEAB2E837E001309000B0098B177CFE39CD3DF9D737E3CAFBB79CCDB98
CBDC98D7EBA6C7DB9699AE69D5EAA5CCE19CCADF9AD5E9A4D2E6A1B7C884A5B672ACC079
D1EC9FB1D080CFF1A4DCFFB4BCE096C3E79FD4F1AFC5DE9DCFE1A7D9E6AE929F67CDDCA3
CADEA3CBE3A7D5F2B2DCF6B9EAFAC999A273E9F1C0DFE8B3D6DEA5DEE6ABA7AD719EA768
B5BF804F5B1D839257DCEEB4F7FFD6F4FFD8BBD5A5C9EAB1B1E197CBFAACCFECAAC9D49C
353102AFA0775F4E23807243C6C38CD4DD9CD1E59DC2DE91CBEA9CC6E599B7D389CFE49F
D4DF9DC7D08F8891505F6A286D7937D6E5A2C9DA96D4E8A3CCE19CD2ECA5CAE49DD6F4AC
CAE8A0D0F0A7C9EBA1CCECA1D7F1A8CDE59BCAE298CAE298D5EBA2D4EAA18FA55CC0D68D
C9DD95D5E9A1CFE099D8E9A2D0E19AD6E7A0CEDF986F7C369A9F5C7C7D3B9FA25FCED591
BBC88295A961ADC57BD1EDA2C8E79BDBFDB0C8ED9FBFE496CDF2A4C4E99BB8DD8FC6E69A
D9F5A8C3DE91C8E497CAEB9AC2E593C0E693BEE393C5EA9CC4E69ACEECA6C0D696B9C88F
4A511EEAECBDD6D3AACFCEA0D2E0A3D4E9A4C5D994D2E7A2D5EAA5C5DC9699B06AA5BC76
C5DF98D4EEA7CFEAA3C7E29BDBF6AFC4E29AD5F3ABCFE6A0B3B97BD3D397E1E6A4D7E39B
C9DE8FC8E593CAF09DC9F6A5B4E798C0DF9BC5B17FBB9F70D8DC9FC7DD95DAF0A5D4EC9E
CBEB9FC0E598C6EB9EC8EEA1C5EB9EC6EC9FC6EC9FC4ED9F
CDF197C1E58DC5E791CDEE9DC9E79DC8E6A0D6F1ACC6E19CD3ECA8C4DE97CAE199CEE59D
839951D8EEA6CCE19CD7F1A7D3F59EBCE088D2F1A5C8E39CD0EBA8DFF9B8C2DEA1D1E7B6
DAE6CE4D675C90D0CF39817E2D5C56000F00798D5CD4E4A3DFEBA985924D97A663D6E5A2
DAE9A8CCDB9AD7E6A58C9C5BD5E5A4D0E09FD2E2A1DBEFAAC6DA9392A65E98AC64D7EDA2
D1F0A2D1F4A4C4E999C3E89AC5EA9DCAECA2CAE8A2CFE8A6D2E7A6C5D5978B9B5DD6E8AA
DDF1B4BCD496CCE9A9CEE8ABCFE2AB64723DD4E1A9B0BB7FA0AA6BCED997A1AA69D7E0A1
BBC588C0CB91B5C28CF8FFD1CDE0A9CEE3ABD6EDB5C8E6A8C5EFA5B9E296CFE8A7D9E4AC
49451656491F6B5A2FE9DDADDCDAA1D0D998D7EBA3CAE699CDEC9ECDECA0B4D28ACCE39D
9DA967949A5ACCD594E3EEACD2DE9C939F5D717D3BDBE7A5D5E19FDBEAA7CBDA97D7EBA6
C5DF98CBE9A1C7E99FCBEBA0CAE49BCFE59CD9EFA6D6ECA3C9DD95D1E59EC8DC95758942
C1D28CCEDF99CDDE98DBECA5CEE29AD8ECA4CCE09854611BA29D5BE6E1A1D4DA9CD4E3A2
DFF0AAC3D58B98A85DCADF94CBE59CCCECA3BEE396BEE596C8EB9BC9EC9CCCEEA4C9EBA1
BDD98FDFFBAEC4E395CEEFA0CCEF9FC1E696D8FDADC4E99BD2F4A8C4E39DD4EDAC9DB176
F4FFCCFCFFD3FFFFD8FFFFD8FDFFD3FBFFD1CCDC9DCEE29BD7EDA4465E14ACC67DD1ECA5
CAE8A2CEECA6CEEEA5C5E59AC7E79BD2F2A6BEDE93CEE8A1959E5FAAAE71CBD491E0EDA5
D4EB9BC7E490C3E994BFEC99C5FAAABDDE97AC9C68927B49DAE5A3CEEDA1C9E898C5E695
C8ED9FBDE698C9F2A4C9F2A4C1EA9CC3EC9EC1EA9CC0E99B
C2EA89C7EC8FCBEC9BCDEBA3C4DEA1D9F0B8C8DDA5CCE1A6CEE3A2D3E7A2CFE197C8DA90
ACC176D0E49DD3E6A4CDE09ED1E99FC8DF97E2F7B6CEE4A3BEE096D0F7A8C8F29EBCDC91
D2DBAE2C361E80A4A231626613413F000C001D2808CDD5A2DBEFAAA8C376ABC27ADEF3AE
C7D798C6D497E1EFB48D9B60D4E2A7C8D699CCDF9FD6EBA6A5C073B0CD7BC7E792CEF09A
BEE491D0F7A6BEE594C2E797CAED9DCDEE9FC5E196CAE49ADBF1A8657932BED28BCFE49F
D2E7A4E0F6B5E4FDBBCDE6A5CFE5A5B3C887C2D890B2C77CA1B669C1D689D2E39CD4E4A3
D8E7ACCAD8A3AAB686EEFAC8CBD8A2C9D99BD6E5A0CCE098C4E095C8E299CFDD9FA6AB73
756E407F73496C6134E8E0AFDEDFA5CBD694D7EBA4D5EFA5A3BF74A6C47AA8C680CEE9A4
B5CA85C8DD98C4DB95D1EBA4C2DD96C8E29B9DB16CD0DF9CD9DF9FDBE1A1DFE5A5CFDE9B
C9E39CC4EA9FC0EFA1C4F0A1CDEBA1D5EDA3C5DB93C9DF97D9EDA6DBECA8C9DA969DAE6A
869A55B2C681D0E5A0D5ECA4CAE49ACFEBA0C3E2948FA157A59C59E4DC9EC6DEA4C8EFB0
C4E89ED3EB9D8F9847E1E89BC1D494CCE9A9D0F4AEB9DE91D3EF9BCCE594CAE4A3C3E0A0
DEF9B4BFDB91C5E399C8E89CD3F5A8B8DD8FC9EEA0CDF2A5C3E79DD1F5ADB8D99489A767
F2FFD3F3FFD3F5FFD6F8FFDCF0F7D6FFFFE1DCE7AFDAEBA4B0C77589A652CAEA9EC4E8A0
C6EBA6C1E6A1CAF0A3C2E998BAE08BD3F9A4CCEF9FC9E79DA6C0794D641EDCF4AACAE596
CFEC98C6E892C1E792C6F29DC6FAA8BEDD97C1B07CBBA671D1E29CC2E797C4EE98CBF7A0
C4F1A0B8E797BDEC9CC4F3A3BEEA9BBBE798C1EC9DC3EE9F
C9EE8ECAEE94CAEB9CC9E6A4C4DBA7DEF1C3D1E2B5D9E9B8C9D89FDEEEADD4E49DE2F4AA
95A65F889953D1E1A2D5E8A8D8EBA9BCCF8DD1DFA2D1E5A6C9EEA1BCEA92C2EF90D7F9A3
C7D0971B200299ADAB82A7AD81B1B1000E0500060031370BC9E09CBFDB8E91AB62C4DB95
D5E8A8DEEEB0CFDDA2AEBB838C975DD6E4A7CFE2A0D1E8A0547023C5E592D1F39CC6EA92
CAF09DC3EA99BEE393CDF0A0CDEE9FC6E295C3DE91D9F1A7BCD28970863DB2C782C3D895
D6EBAAF1FFC6F2FFC8D4EDABD4EBA7C2DC93D2EDA0C8E392BDD984D0EC98D2EA9ED0E7A3
CEE1A9F8FFD8DDEDBEAEBC8BEEFDC4D8E7A4D6E69BD6E797EEFFB8C7D892717B3E989862
393204B4A97C5E5628E0DDAADADEA3E5F1AFD1E59EB7D18794B066D3F1A9C6E49EC6E19C
C6DF9BD6F0A9D8F6AECBEBA2D1F3A9CDEBA3819852D4E3A0D3D999DFE1A2D1D696D4E09E
D7F1AAC5EBA0BBEE9FB9ED9BC2E497D1EC9FCEE89ED7EEA6D3E9A1CBDF9ACEE29DBED28D
C3D694CEE39ECEE59FD1EBA2C5E498C2E394D2F5A5D5EA9DA49A559B9557D4F3BAB2E0A2
D3FBB2CCE796969E49E4E79AE0F0B2B9D59ACBEBA8D6F6AABBD17CE1F4A3D3EBADCEE7AD
BCD291CEE39EDEF4ACC9E098C0DA91D8F4AAD6F2A8BEDC92CFEDA5B7D58DA0BD7ACDEAA8
C4E0A3DAF6BBBCD89DD2E5B7FBFFE8FFFFEAC1C99688985188A04CC8E690CBEB9FCCF0AA
BFE3A5C5ECABC0E99DD1FBA9C1E991C1E790C7EA9AC8E89DDEF9B4C2DB9779934AB0CB7E
D3EE9DCCE995CEED9DC3E898B5DF93E0F7B3C6AF7DBB9F6FE5F1AFCCEEA1C7EE9BB6E08C
C9F2A3C1EA9CC4ED9FC8EEA1C3E99CC8EDA0CEF3A6CCEEA2
C9EC90CAEC96C8E89FC9E5A8CBE1B2F0FFDAEDFDD8F8FFDEFBFFD8CBDAA1C6D697D2E39F
4D5E1A4A5D1BCDE0A0CFE4A3C8DD9ADDF0AEEEFCBFC7DC9BBEE596BDE992CBEF95CDE695
DEE7B0707758627571AED1D584B8B6B6E6DA000900020D00D6EAADD0EAA39FB670C8DD9A
CEE1A1D7E7A8D2E2A4D7E7A9919F61DAEAA9D5E9A4D0E79FC0DB8ED5F2A2B9D986CAEA97
C9EB97C9EB97D1F0A0C6E597C0DC91CDE79ED0E7A1CCE19EDFF4B3CFE2A2DEF2B5D1E5A8
D0E5AADBF3B7D5EDB1C1DB9CCEE7A3CAE69CD5F1A4D0ED9BD0ED99D6F3A1CCE89DCAE5A2
E5FDC3F5FFD8D5E9B8889C67C4DA9CCBE09BD0E799869D4D374D0297A862D3DDA0DDDDA7
221B0094895C554D1FE1DEABE2E6ABC8D492C6DA9397B167BEDA90C2E098D6F4AED7F2AD
CCE39FCFE6A0BFDA93C3E199B5D58CD3F1A9C7DE985869254F5817676D2D53591994A05E
D0E7A1C7E99FC0EFA1B6E595C4EB9ACBEC9BC9E89AD1EDA0C8E298C6DD95DDF4ACE0F6AE
92A762C4DA92D2E9A1CEE89ECDE89BCCE999CEED9DC5DA8BA19A54ABA768C8E4AAB3DB9D
BCDE94CDE693939D47565D0F8FA463CBE7AACAE7A4C2DC92E6F8A4C3D484CBE4A3C7DFA3
EEFABAC6CD8A99A05D909956909A55DAE5A0D4DF9AD9E6A0DDEAA5C7D693DBEAA98C9A5C
CFDDA2C3D098D8E5ADD4DDB0FFFFECFBFDE599A16EBAC984D5EB99D7F09DC0DB94CAE8A8
C8E7AECDECB1BADE98D4F9ABCEF4A1BCDF8DCBEDA1CBE9A3C8D89ACFDB9DA0AC6AE2EFA9
D3E098D9E99EC9DA93D3E9A1C9E49FD5DDA2805B318A6036E1DFA6C8DC97D4ECA0D8F0A4
D0E49CCCDD97D2E39DD7E8A2D3E49ED1E59ECEE29BC3D790
C9EA93CAE999C9E6A3CBE4ADD1E3B9F8FFE6F9FFE8F9FFE6E1EDC5F0FDCFD5E4ADC2D496
DFF2B2AFC4836D8241B5CB8AC7DE9ACDE29FA0AC6E5164226D9647AEDA83D0E995D3E196
E5EFBA707B5B61726CE9FFFF3E77708AC3B21D392006160062753EC3D798C7DB9CA8BB7B
CEE1A1CEE19FD1E4A2D1E5A08498539BAF6899AF67788E45D7EFA5D0E89ED6EEA4D9F4A7
D1EC9BC8E490CFEA9BD3EB9FCBE09BDDF2AFDBEDAFCADCA28FA069C4D59FD1E4ADCBDFAA
C8DFA7C5DEA5C7E0A6CEEAADC8E6A0CAE89EC8E799C4E393CCEC99CEED9DC6E49ACAE7A4
E3FFC4E4FFC8E0F8C4CAE3AC92AC6DABC67FCBE89895B05FB1C97DC7DB94ECF6B9C8CB94
362F01C6BB8E888052D9D6A3D9DDA298A4628FA35C819B51DFFBB1BFDD95C4E29CBED793
CDE09EE3F7B2CDE49EDAF5AECFEDA5BAD890DDF7B0BED28DDAE6A4CED7966871309BA765
D8EDA8CAE8A0CEF7ABC5F0A1CAF19EC5EB96BFE28EC8E998C6E597CCE89DD4EEA5B6D087
94AB63CEE59DD2EAA0C3DD93CAE598D1EE9ED3F2A2CDE293B7B46DA1A060D0E5ACDFFEC2
C2DE94D3E997DEEC95D2DF8F859E5A829F5FCAE39FCDE297DDE899DBE99AD0EBA8D0EAAB
C5D191AAAF6D929755B1B8749EA561DFE9A4C6D08BE2EDA8CED994E1EEA9D7E3A1748342
95A366D2E0A3DDEBB0D9E2B3FFFFE8F1F6D8A0AA76C1D08BD6E99AC8DD90D1E6A5D1E9AF
D0E8B4C1DCA5C0DD9BB3D38AD5F5A9C0E295D0F1ACCBE5A6D8E3A9E6EBB39BA165CED494
E2E9A5C5CF8AE4EDAACAD99691A566A4A46E774B26956541EEE4AFD8E4A4D6E7A1D1E19A
E7ECAAD6D696D4D695E1E3A2DFE4A2DCE3A0DEE7A4E0E9A6
CDEA96D0EC9FCCE6A5CAE1ADCDDEBAF6FFEAF2FEE8F7FFEBF9FFE8C1D0A9D1E1B2D3E6AF
CDE1A4D8EEADC3D998AEC7838FAA63C3DA94E3EFAFC9DD98B3DE8C9BC56F94A152E1E4A1
C3D09AD1E2C078887EE3FFFF49887D3F836EBBE1C8526844081900DBE9B4E9F8C15B6D31
D0E3A3D1E6A1CAE098CDE39AAEC47B8EA459AAC075D8EEA5D5E9A2D2E6A1D2E5A3BBCF88
C4D98A96AC5A8A9F52D7E8A2D8E8A9CDDAA2C8D6A1D3E1B0ABB88CF3FFD6F8FFDCF7FFDC
F4FFDAD1ECB5BFDCA2C9E7A9CAE9A3CEEEA3C4E596C4E596CAEB9AC7E79BC7E79ECBEAA7
CFEDB1E3FFC8D1EEB6DDFAC0B6D693C2E498C1E492D0F09DD5F0A3D2E69FD3DDA0E6E9B2
0C05009F9769544C1ED9D6A39EA267D5E19FD9EDA6DBF3A9C6E097CFEAA3CCE7A2E4FBB7
A9B8778F9B59C2D691CDE49ED1ECA5D9F7AFBFDA93D8EFA9DEEFABD4E09E626E2C99A865
CADE99BBD58EC9E9A0C6EB9DC0E892C3EB93C3EB95CAF09DCBEE9ED0F0A4BAD88E718D43
C8E299D7F1A8C9E39ACCE89DD3EFA4C1E092C7E698DCF3A5F1F4AD7B7D3CDCEBB0BED496
CEE29BE2F5A4CCDE88D1E794D5F3ABC2E19D7C904BE1EDA5CDD486D3DF93CFEDA7C6E6A3
566B26A9B873D5E59EE1F2ABA2B36CDAEFA4C7DC91D4E99ED7ECA1CCE299C1D890C9E39C
869F5BD5EEACCDE6A5C9DEA6DEEAC6A8AF8DD5E0A8D8E5A0E0F0A5DEEEA5CAD89DD5E3B0
C2D2A3B1C391DDF5B791AC67CEECA2C3E39ACDEDACC9E2A8CBD8A2E0E7B1AEB3799CA264
E2E9A6BAC3808E9756A0AF6ECCE0A3E0E0ACBD8F6D784625897D4BAAB477D0DF9CD6E19D
D8D797B0A8699B9656A39F5F9A99588F904E9C9F5CAFB471
CBE695D0EAA0CDE5A7CDE1B0D0E0BCF8FFEDF3FEEDF4FFEEF4FFE8D1DEC0D5E6BCD8ECB9
C3D89DC4DD9BE5FEBAB5D089C3E199C9E39CD5E19FDBEFA8CFFCA9B1D88562621AC4BC7E
D3E1ACD0E6C00A180B9AB8B087CCB9357F66B8E9CCD1EECF0F1F00949F74C3CF9D77864F
D4E8A9CDE49ED4ECA0D0EB9CCDE69595AE5D98AF61DAEEA6C9D998D0DEA0D7E2A8E0ECAE
ACB9718E9C51596621CAD698D4DDA8D6DFB0D7DFB6DCE6C1CCD6B3F2FFDCF8FFE1EBFFD3
F1FFD7D1EEB6C6E5A9CAEAA7CCECA3CFEEA2C8E79BCEED9FCBEA9EC3E197CEEBA8CCE9A9
CEEBB1CEEBB3B9D69CBBDA9ED6F7B2D5FAADC1E794C2E591CDE99CD2E8A0CCD89AE8EBB4
080400999163625A2CEBE8B5989C61D1DC9AD1E29CD1E99FC5DF96D8F3ACC1DC97A2B774
98A464909B59C7D693D4E9A4B6D089D4EFA8D4EFA8C7E19AC7DC97D7EBA6909F5CD6E7A3
EAFEB9CFE49FCFE9A2C9E89CC1E492C6EC95C9EF9ACAED9BC2E595D2F2A7C4E49B739149
BFDD95CEECA4C7E6A0CDEDA4D0F2A8C2E79AC1E699C1DD92BCC880A3AA67D1DCA0E1EFB2
CEDB95DBEE9FCFE793D2EF9BBEE396C2E19B8D9C57989F59B8BA71E4F0A6B9DA93CCF4AD
819F59C4DE95D2ECA3CBE59B9FB96FCCE89BD2EDA0C6E295D3EFA2C4E395D2F2A6D1F3A7
C9EBA1B7D891CAEBA4CCE8ABD6E7BB97A277CEDC9FD1DE98D8E69BCDD893D9E2ABD8E0B1
B5BE93B6C493F9FFCF8CA35FCAE69CC5E39DCDEBADCCE8AED9EAB4C6D39BD6E4A7919D5D
93A05BB4C37E7E8F4BD4E9A6CCE6A5CFD6A0BC9470784C29736D3981915293A86395A45F
9093507470307672329493529A9D5A949956A5AC68BCC681
CAE392CFE79DCEE4A4CEE0AED3E3BEF9FFECFBFFF1FBFFF3F4FFECF9FFECF2FFDDCBDFAE
D5EDB3C4DF9CCEEAA0D4F3A7C4E49BCFEAA3D3E29DCAE097B5E58FC6EC99665B1BEDD9A4
D6E7B39FB99239463490AC9E7BC4A93A8B6BB3EBCEC1E4C6000D00030B00687348D1DFAC
CBDFA0CFE69ED6F1A2C6E38FC9E590D6F29ED2EB9AC6DA92E1EFB1E5F0B6C1C996949B67
BEC788C8CE8E5F642AD4D8A5D9DFB3F8FCD7FFFFE4F9FDE2F2FBDEF6FFE1F8FFE1CBE1B2
CEE9B2C1DFA1C8E9A4C4E69CCCEB9FCBE79CC9E399D6F0A6C8E29BC3DC9ADFF7B9DAF2B8
D7F0B7C5DEA5D7F3B8CCEAAAC2E39EBDE295CFF5A2C4E795CAE699D0E69EDCE8AAD9DEA6
3531029C9466696133A8A572AAAE73CAD593DEEFA9D0E89ED3EDA4C3DD96C6DF9B95AA67
DBE5A6DCE5A4606C2A839450C3D893C2DC95C1DC95D3EEA7D2E9A3CFE6A0889C57C5D994
CCE09BC8DC97D0E49FCFE69ECFEB9EC9E898C8E799C9E89CBEDC92D0EFA9CFEEAA86A663
C4E4A1D1F4B0C8EDAABDE59FB8E19BC5F0A9D6FFBAC3E9A0E0F6AED4DF9B4C5418E1E7A9
D5DF9AC5D78BC6E693C6EC97C5EE9FD5F5AAD2DF9AB6B976A8A96389964EB0D48C507B33
D1F7AED1F3A9BCDE94CCEEA2C8EA9DBCDE91D1F2A3BFE292B7DA8AD3F6A6BEE395B7DD90
C7EDA095BE72ADD68ACEF1AD7D94609FB07AD5E4A1D2E095D7E397D3DD98CDD29C8B8E61
C1C69DCFD7A6F5FFC68FA35CC3DB91C9E49DCEECAECAE7ADC9E5AACAE7A7C7E4A1DAF5AE
C5E196C8E499D8F7ABBFE197C9F1AAC4D89BA58A5FA6865DD5DDA2C3E19BC5E59AC9E59A
DBEBA4CFDA95D7E29DE6F3ADDDEDA6CDDE97C9DD95CAE097
CDE695D1E99DCFE4A3CBDEA7D0DFB6F9FFE8F8FFECF7FFEDF9FFF1E5F3D9F8FFE4CBE1B2
CAE2A8D3EEA9BEDD8FC9E89ACBEBA2D1ECA5D7E8A1D7EFA3BCEE95D6F9A75B470CF3D9A8
D0E1ADADCA9E1F2D139DB9A278BF9D388A6493D0AFBFE6CB233319080F00424C27D8E6B5
94A86BC9E39AC9E694CFED97D4F29AC4E08BC8DF8FDEF2AACDDB9DCED7A2B5BB8D96996C
DCDFAAE0E3AE525425DEDFB7DADBB9EBEBCFF7F9E1FFFFECE9EED7EBF6D8F8FFE1CBE1B0
C7E3A6C2E19BD2F4A7C5E896D1EC9FCAE296C8DE95D8EDA8C5DA99C7DB9EF6FFD0F0FFCC
EAFCC8C6DBA3C8E0A4CFE9A8C3E19BCCECA1CFF2A0C6E997D2EEA1CCE39BD0DEA0DDE2AA
3935067F77495C5426B1AE7BB7B87ED9E4A2D0E19BD4EAA1C1D890DAF4ADCDE6A28EA15F
C7D192E7EDAD8F9A587D8C498DA15CCFE6A0D3EDA6CAE59ED4EEA7BCD68F768D47B7CC87
C8DC97DBECA8DBEAA7CDDE9AD6ECA4C7DE96CAE199D5EFA8CAE3A1CAE7A5BAD89A698B4E
CAEEB1BDE5A7BCE8A9CCFABABAEDABADE19FBDF1AFBBE8A5C7E4A1DBEAA94E5416B5B97C
DAE3A0D4E8A0D4F9A9BAE794BEE999D1F1A6D2DD99D7D998DDE2A096A7637AA259608E45
BDE29CCBECA7C7E8A1D1F1A8C0E0978CAA60CBEA9ED4F3A7D5F1A6C5E498C9E99DCBEDA0
C9EB9F6F9447BADE94CAEBA68EA66A879B5ED5E79DD5E696D9E599DAE3A09CA06DBBBE93
D7DAAFE0E7B4D0DC9C86984EB5CB80C8E299CDE9ACC0DEA2C5E5A4CCF0AACAEEA4B9DE90
D1F4A4C1E794C9F09FBFEA9ABAE89DDBF6B3988354967E4EDDEBADC2E69CC8EF9EC2E797
CDE79DCCE299CFE79DD0E89EC8E298CCE69CD3EFA4D0ECA1
D3EC99CBE395D6EBA6CBDFA2DCECBBF9FFE1F6FFE3F9FFEBF1FDE5F8FFECF2FFDED3E9BB
CBE3A9CFEAA5CDEC9ECDEC9CC5E39BD1ECA5D2E89FBFDC8CC2F49BD3F4A35F460EFFE3B5
DAEBB7C3E3B2000900405B3A8CD1A5004F24559270C2EACFD1E4CE2B351C000700A7B78A
889D6288A25BC3E08ED6F49EC9E58ECBE792D5EC9CC0D18BE7F5B88F9764666B42F7F9D1
FFFFD8E1E2B862623CE1E1BFFFFFE6FFFFEAF6F8E3FFFFEDD2D8BECAD5B3D0E1B5D5ECB4
C1DC99D5F6A7BADE86CCEF95C6DF8EDCF1A48697519FAF6EB7C58AEDFAC5F0FAC8DDE9B9
E0ECBACFDDA8D1E5AACEE4A3CEE8A1D4F0A5C9E89ACDEC9CD1EDA0CDE49C8795579FA76E
1D1B008F885A948C5ED8D5A2E0E1A7D2DD9BCBDC96E2F8AFBBD28AC5DF98D4EBA793A664
E5EFB0D4DD9CD1DC9A9BA76595A662CFE39ED0E7A1CDE7A0D1ECA5C8E39CAEC98292A963
809550DBECA8CCD896DAE6A4CFDB9BE5F1B1D3E1A3C9D99BD5E9AEABC3895E7B433F6029
6E955E88B57E90C18AB4E9B190CA90AAE6AAC7FFC8B0E6A8C5E8A8D0E2A49AA0629FA464
CAD694D2ECA5C7F3A6BAED9EBEEA9BD3F3A8D0DD98D6DC9CDAE4A7CAE0A0CDF7AFB6E49C
CFEDADBFD799CEE4A4D7ECABC6D9998F9F5E99A865909F5AD4E19CDDECA7C7D691DCEDA7
D3E4A090A45FCADD9BD5EAA7899E5DB1C681DEF3A4BFD280E2F0A157621EAFB883E6ECC0
E7EDC1E1EAB5D4E19C90A35490A757CBE399C7DFA1CFEBAEC8E9A4B8DE93C5EA9CCCF29F
C9EF98C9EF98BBE38DC5F19CC1F0A0CBE69F9F8B589A834FD1DE99C7EA9AD2F8A3C2E893
D4F4A8CAE89EC0DE94CFEDA3C6E49ABDDB91D9F7ADC9E79D
CFE897CAE294D5EDA3CCE1A0D7EAB2F4FFD5F8FFE0FBFFE8F8FFEBF9FFEAF1FFDFD0E2B8
C6DDA5C9E4A1C8E499C7E396C8E39ECFEAA5CBE699C8EB97BDF094C3E292725722EBCCA0
CCDDA9C2E3AE68794C000D00BDFDC9A1EBBA1E5734557D625C725D2C3A210008005E7144
CCE4AAD4EEA7CFEA9BC8E48FD3ED96D4ED99D4E99CC7D892CDDBA09FA977E0E7BDF3F8D0
FFFFDDF3F5CEACAD8BF7F8D9FFFFE8FFFFEAFFFFECFFFFEAD9E0C1D7E3BDD4E6B4BFD597
DDF9AFCBEB96BFE487D3F597DDF5A144560ACCDB96CBD799E8F1BCA6AC7EF5FBCFDBE1B5
E3EBBCC7D19CDAE8ADDBEEACC4DA92C6DE94C9E497C6E29587A358475E1696A667DDE5AC
070500847D4F8E8658E0DDAAECF0B5C8D391E6F5B0C5DB92DCF3ABD3EDA6C9E09CB4C986
CAD998C8D492E0ECAAC3CF8DB7C683D6E7A3CEE29DCFE6A0D4EFA8BBD991DEFCB4CAE59E
8EA55FCEE29DEDFCB9CED899DCE2A6CED399D4DCA3EFFAC2C4D59F4158220011000D2F00
0012000014003569384D8653609C68498A545B9C64C1FBC1C0E7AED6EBB0E5EFB27E8748
E0F3B3C4E4A1ADDF98B9EFA4C4F0A3CBEBA0D2E5A3DEECAFC6D9A1CEECB0AFDA95CCF9B4
CCEBAFD0E9B0CEE6ACC7DCA1EBFDC1CBDB9D8C985A555F20515C1ACED997E4EFADD7E3A1
D7E3A3849352E3F2B1617130DAEFAACEE69AC5DC8ADCF29FC9DC8D53621FD5E1AFE4EFC4
FCFFDAE4F1BBD4E59ED4E796879D4BD2E89DD8EEAEC8E0A4D3F0ADCEEEA3CFEEA0D1F19E
B6D780CEEF96CFF19BC8EB97B8E192F0FFBED0B683987A46DDE4A0D2EF9FC5E590C3E591
BEDD91CAE8A0DAF8B0BBD68FD4EFA8E9FFBCBBD58ECEE59F
CFEA9BCCE79AD2ECA2CAE19BCADE9FDAEDB6E3F2C7F3FFDDF5FFE4F9FFEAF0FFE0D4E6C0
CFE3B0D3EBADD0EAA3CCE69DCEE7A5CCE7A2CCED9EC1EC93BDEE93B6D182654B18E9CCA2
D8E6B1C4E3A8D8EDB46E8B5175AB6FA2E1ACB8ECC6022A0F556E583F533A00110095AC80
C6DDA597B06ED3EBA1D3EC9BC4DB89CBE18FD9EEA3E5F6B291A065E6F4C1E7F4C8FCFFDD
FEFFDDECF3CACBCFACC0C4A3D3D6B7E2E5C8FFFFE6FFFFE4E1E9C2CDDAACD6E7B0C8DD9A
CCE79AC6E48ED4F698A2C164455D07DCEFA0E2F1AEE4EFB5E2E8B8CCCEA6DBDDB6F6F8D0
DFE2B5DAE1ADD8E2A5D0DF9CD4E59EBDD28794AA5F95B063A3BF74C3DD94DDEDAECFD79E
3E3D0DCFCB9C80794BE2DFACD3D79CDCE7A5CCDB96C9DF96C1D890D7EEA89BB06DAEC380
D2E7A4D9EDA8D6E5A2929E5C8B9755D3DF9DDFEEABCCE09BCEE8A1C5E39BC3E199C6E49C
CCE69F92A7628D9E5ACDD798969C60E2E5ACD8E0A787915C889965D7EEBAD8F4C38BAF7F
588254C1F0C2C3F7C9A3DDADC5FFD071B17F448452457F4CA8D09CD9F2BBB4C2859DAD6E
739050568040CAFFC0B1E8A4BFEBA0C7E99FC8E1A0D7F0B6C0E1ACADD49D96C382B0DE9D
B8E1A7C5ECB5CDF0BAB1D29BBFDCA2CEE7ADD7EDAFD4E6A8849455DEEEAFC4D495CFDFA0
DBEBAC91A464D9ECAC859A57D4EBA5C9E195C8E18ED4ED9AD1E99FC1D598D2E3B6E7F8CE
F8FFDDD7EAB2DAF0A7C9E08EADC3717E93489EB074D5E6AFC7DC9BD2E8A0C7DC91CFE495
E3F6A4AFC36E92A856A4BB6BD1EDA2C6CD8AB2895BA17546E2DA9BCEDC91D0E191DBF0A1
DBF1A9D2E7A4CCDF9DD8EBA9D0E09FC3D291A3AF6F6E7A3A
D0ECA2CCE89ECDE99FCAE49DC7DD9CC9DDA2D0E0AFDFEEC5E8F6D5F9FFEAF5FFE8E2F1D0
E2F3C9E3F7C4D9EFB1D0E6A6D0E4A7C7E29FCEF8A4B2E387C8F79BC1D98B66511CF6DEB2
D9E6B0CAE8AACCE5A39AB774174401D0FFC7B0DDB4CBF2D54C6C54738F76274221536C42
DBF3BF8AA0623A5008D5EA9FE1F3A7D3E5997E8F4890A05FB4C68AE4F7C0F8FFDAEBFCCF
E5F2C4D7E3B5D6E1B69DA67BDBE3BAE4ECC5EDF5CCE2EBC0BECA9AD1DEA9D0E0A2D6EAA5
C1D98DD0EC98CEEC94829F45CCE48ED2E798BACB87D8E3ABE8EFC3747951FFFFDFFFFFDC
F5F6CAD3D8A2D6E0A3B5C27D81914A99AE63C2D88DC8E094C9E59ADDF7AED2E2A3D9E1A8
313000BBB788958E60E2DFACD3D79CE5EEADD6E5A0DAEEA6E3F9B1ABC27CB5CA87C4DB97
C7E29DD6F1AACFE39E8594517D8846CAD593E4F0AED0E19DD4EBA5D2EDA6CDEDA4D0F0A7
D4F2AAC1DB94CFE39ED9E8A5B4BD7E91995D959F63BECB93D4E7B0CEE6B2B4D2A093B787
3E6838B8E7B9AFE0B3BFF4C6ADE5B6B3EDBDB4EFC1013608365D30C8E4B3576B30B9D291
6E94572C5F24BBF6BCC0F8BBC6EFA9CBECA5BBDB9ACDF3BAAAD8A72F612E5C8A4C75A567
7DB27A8AC18A82B47FA3D29CCFF8C0C2E8AFC2E1A6BDD99E8DA76AD0E8AAD9F1B3C1D99B
D7EFB1BCD697C4DE9FD4EEADC1DA96D0E89ED9F4A7BEDA8F9BB574D2EDB6B8D1A9EFFFE3
E6FFD5E7FFCDCCE7A0D3EC9BD1E898C9DD9694A36CD7E4AFDBE9ACD6E5A2D4E19B97A55A
AAB768B1BE6FD8E69996A65D8FA55DD7D79BA7784E8F5C31E9DA9FEEF5AFD3DE92D2DE94
C1CD8BDBE9ABD2DDA1BECA8C7F894D9EA66AEAEFB5D1D79B
CCE9A9C7E4A2C6E3A0D4EFAAD7EEAACDE1A4D1E2AED8E7BCDBE6C6F6FFE8FBFFEFF3FFE7
F4FFE3F0FFD9DEEFC2D0E2AED1E2ABC9E4A1C3F39DB5ED8CCBF89BD5EC9CAC9C68C5B385
CCD79FCEE9A6D4F0A3C6E5956D8F454B6F3184A87CC3E6C644684C6F94755C7E5B69855C
BBD3A1ADC2879DB0708C9B56C7D48EBFCF88778641839656D3E7ACE4FBC3F4FFD8DEF7C0
D5EAB1CEE2A7D0E4A97F9157E0EFB8DEEDB6D2DFA9D8E5AF95A26ADDEBB0D1E1A2CCDF9D
E1F5AEC3D990AEC67AB1CA79D8F49FC5E18DD3E8A3D6E7B0E1ECC1C9CFABEEF2D1FCFFDB
DDE0B3F4FBC5CDD7987A8A43899B51CEE398DAF2A6D3EDA3D2F1A5BFDB91C4D797EAF3BA
272600BDB98AA7A072DEDBA8D7DBA0D3DC9BCEDD98D3E79FBCD28A91A661C6D997DFF6B2
C5E69FC5E79DCCE69FB7C884A6B16FBBC181CCD594D5E19FC1D691D4EFA8C1E198C0E298
C5E59CCFEDA5D2ECA5D3E8A3D3E49EB0C17DB0C381C9DF9FCFE9ACCBEAAFB9DAA392B984
69915FB9E5B4C2F0C1C1F0C2B1DFB1BFEEC0B6E5B91C471C1E421C81A07487A368B9DC9C
91C386427F46A0E0ACB4EDB6C5ECABC9E9A6BDE4A5BDEEB674B283104B1B699861AADCA1
377A443B844F0D521C5D9E68AFEAB2B1E4ACC6F3BAC3ECB08DB3766D915493B578A5C78A
D2F4B7CEF2B4B7DB9DD5F8B8D7F1B0D1EAA8C1DC97C9E6A488A76EC4E5B8D9FADBCBECCF
E4FFE3C8EAB8C8E8A5D3EFA4CBE198D3E3A2939F6FD1DAADC9D6A0DAE8ABB2BE7E727F3A
B1BD75D1DD95E3F0AAD3E29F4A5F1EA5A46C76441F7B4521AE9D69D2D797E4EBA7DCE6A1
E8F0B4AEB67B979F66A1A96EA6AE75B1B67C767B43858A50
CCE9B1C6E3A9C4E2A2DEFBB9E4FDBBCFE5A5CEE1AACFDEB3D0DBBDF2FBE6FBFFF4FBFFF4
FBFFF1F9FFECF1FFDCE6F5CADEEAB8D4EDACB4E991C0FC9ABBE88BD0E596F2E9B26D6131
CFD89FDCF6AFBDDD88C8E99091A95B6F8545476134C4E3C3BFE8C84E7A57052B04001300
001200CFE4ACCBDB9DD6E2A2A1AC6AB3BE7AD3E2A1D3E6A6C5DA9FE8FFC9CCEBB2D1F0B4
CFEDA7CCE89ECAE49B748B43C5DA95C7DB96C5D594E0EFAEABB97BB8C688D9E9AACCDC9D
DFEFB08FA262AFC282D4EBA3CFEF9ABEE08ADEF9B2CEE3AAC2D1A6CFD9B6BAC1A0FFFFE1
C7CFA089925BA8B474DFF0A9DCF1A6CBE397C0DA90BFDB90BFDE92DAF6ACD6E9A9C7D097
1413009F9B6C514A1CDBD8A5DFE3A8E1EAA9DBEAA5ADC1796B7F38B6CB86C5D896C8E19D
D0F6ADC6EFA3C9E79FCADE99C8D190C1C686A3A8687A8342D7E8A4BFD992D0F2A8E1FFBB
BBDF95C2E49ACEECA4CAE69CC8E499CEEA9DD2F0A6C6E59FC2E5A1D5F9B9BCE2A57AA168
0F37028BB37FC2E9BAB3DAABD7FCD0C3E7BBBEE2B60020000D2C0C5A7A53C6E7AEC6F0B0
71AE722F743E95D7A9A5DDACBEE2A5CFEFAEC0EEB079B47E18613478BD91B3E3AFD5FFCF
B9FFCB53A16F26703F91D5A2B5F1BEBEF4C097C690001300436930A8C990BFDEA599B87D
25440B9DBF83D8F9C0C2E1A6BED69CBDD59BB7D39696B57C80A474BFE5C0AFD7BF9EC5B0
A9D2B4ADD4A8CCF0B2B7D78EE0F7B3C9D89D858D6489916ABBCB9A8DA166A8BA7ED5E8A8
C7D894D6EAA5CFE2A0C7DD9CC6E0A1E2E6B38E61408B5A3AACA0709AA468879353929E5E
A8B276969E65ACB37DD3DCA38790595962294A551D768147
CBE9B7C8E6B2C7E4AAEBFFC8F0FFC8D1E7A9D1E4ADD2E1B6D5E0C2F5FEEBFCFFFAF8FFF8
F9FFF6FBFFF3FAFFECF7FFE0E8F1C4D2EBAAB6EE95B9FA96BDE88CC7DC8DF2EDB57D7544
DEE8ACCAE199D3F69AC5E788DDEF9DC9D5936B7C50597453B9E5C285B490001100001200
000F00D5E7B3D6E3ABD9E1A5D7DD9FD2DB9CDBE7A7C8DA9CDBF3B5BAD99DE7FFCEB7DE9B
C3E696C5E790D6F6A19CB965C1DC8BCFE897D0E598D0E298D3E29D889754C8D698C8D699
BAC78F8E9D66CEDCA7CEE4A4BDE08CD2FAA1BDDF95CAE6ABC8DDB2CFDFBB9BA686A5AF8A
757E4FAFBC84DBECA8C7DB93C3D98ED5F0A3D2EEA3D4F2A8C8E89CCAE69CC7DA9ADCE5AC
0605006B67384B4416F4F1BEDEE2A7C7D08FDBEAA596AA62A7BB74D1E6A1E9FCBAC1DC97
BAE69BC3F2A4CEEEA5D4E9A4E2E8A8E0E2A3A7A96A4E54149CAB68BCD68FD0F2A8ADD388
CBF1A6D4F8AEC1E198D1F1A6CEF4A1C1E993BCE390BCE596C2ECA0CAF5ADC1EAA8A7CF91
2C531A6F945EC3E5B3C3E3B2C7E2B5B4CEA1C4DBB1000E00000C008FB18CBAE1A8BEF1AF
78BE82145E2B70B388BDF2C6C5E6ADD5F4B8BCEFB44B905A002F0594E1B7BEF0BFABD7A4
A4E1B53A7F5358966DBAF3C8ABDCAFCCF7C99DC193000E00789060DEF2C1D7E9B7C8D9A5
5E6E3D9DAF7BD8EAB8CEE0AED5E7B5778E5A5C77423A5A299AC099ABD6BA4D796A4C7B6B
7DAA93D2FFD8BEE7ADC8EBA7C4DC9EE8F6C17A805E161F0082996B80A168CBEAAFC8E8A9
CBEAA7DBFAB7C5E4A1C1E4A4C0E6A9DEEEBD9B7A5B664124DFDEB0D4E9B0829A5C94AA6A
C4D39AE5F2BAC9D6A0A0AF76203100576B30CCE1A8C5DDA1
C5E3B1C7E3B2CDE5B3F5FFD8F9FFDAE2EFC3E7F3CDEAF5D5E6F0D7F9FFF1F9FFF3E7F2E1
E0ECD6E4F1D7E8F3D5EAF6D0E0EEBBC0DD9AC5FBA3AEE98BD5FDA5D1E89ACDD196E0E0AA
919B5EB2C67FD0EE98D0ED93DBE899D0D998D8E6B55D734C22441FB6DCB798B891001100
000C0098A975D5E2ACD8E1A8E1EBAECEDA9CD8E8A9D1E5A6C8E2A3D3F3B4ADD191D5FAB5
CEF19FBBDD86C6E79097B4609DB965CBE491E4F9AACCDE92D3E39C85944FA1B06FACBA7D
AEBD84C6D59EDDEBB6CEE4A6CCEF9FC4EB98C6EAA0C5E3A5D0EBB8CFE5B7DDF0C3F6FFD9
E0F5BCC9E2A0D3EDA4CEEA9DC4E093CAE99BC8E79BC7E399CCE49AD8E9A3727C3F979761
0B0300AA9F727E734696905E94955B606B29475811ABC377D3EFA4BFDD93C2DD96CAECA2
C0EC9DC1ED9EC6E89ED1E8A4D6E2A2DEE4A6E5E9ACD2D898CBD8937D9149CBE399D4EEA4
D4EEA5C3DA94D3E6A4CDE49EC4EA95C7F299CDF09EC8E89CC5E59AC6EAA2C3ECA8BBE7AA
001300001100001F00000E0045602B2F4A17000E005D7C538EAE87C2E7BBC7F4B9ADE9A9
59A46B003E0E71B792B5EDC8BFE6B7BAE2AEB6EFBA79BF8B08572A71B689C7F2BDC5EDB9
B9F6CD6FB59065A58291CBA3BEF0BFC9F4BF4868370012004356287C8C5B9EAC774E5C27
92A06F4D5B2884955E90A36B72865126420F678B5BB6E0B8BFEDD01D4C3834625792BDB3
E4FFFBCCF5D5BDE7B9C3EAB33E5F28000E0024330C000900456037254516CAE9B0BCDA9C
CEEEAFB3D598CAEFBBC3EABB92BB8F000B002411002E16006165339AAF77D1ECB5C5E0AB
CDE1AE97A97564774061763D667B40C6DEA0CBE5A4CEEBA9
C6E3A9D4ECB8CEDDB6FDFFE7FFFFF1FAF6EDF9F6EFFFFFF6FBFFF1F7FFEAF4FFE3D3EABC
C0D6A5D5E7B3D8E6B3CDDEA7C4E39FCCF5A7BAEA96B6E390D1F4A4D1EBA1C8D995D6E2A2
DAE6A64B5715C9DA93DAEAA3CFDC97DEEAAAD4E2A7D2E0AD65704868724FD4E0BA5C693E
000D00717F4CCEDDA6D3E5ABD3E7A8CDE3A2C7E09ECCE7A4CEEBA9C3E29FCDECA9D1F0AC
D0EEA6BBD78DCDE79ED3EBA18EA45B98AC64C8DC94DCEDA7D0DF9AD4E3A0D7E8A4D8E8A7
D3E6A6CEE2A3D0E4A5D0E9A8C0DF9993B46DBDDC98C9E8A4C8E5A3C7E6A3D6F7B2C1E59B
BFE89ACAF5A3C2EE99C3ED99C0E595D6F7A8C3DF94D7EBA3535A17A7A568E4DAA5EBDAAC
1500009A835A5C491FE6DCA9D8D99DDBEAA5CDE89BCBEE9CC6F09EC0ED9AC7F6A5B8E796
BEE894D4FBAABDDD92CCE7A4D7EDAFC5D79BD7E5A7DEE9A5D1DB92E8F0A34C5004606219
494603211800D9CB9ADFE0A6C0E190D4FAA5D4E3A0D4D599E1E3A2909F5C3B5F1F82B57D
1B512D85B696BEE3B7C3E1AB98B773002300356939BEF3C5C2EDB5B7E4A3BFF7B6A9EFB0
3E8C5800270001482879BA9CA4DDBDC6FED9A7E6BBB7F6C77DB9854B7B41CBE7AAC9EAB3
AEF2C96EBF9E408B6D6FB38AAFEDAAC6FAAF89B1720017009DB581D1E6AECAE09FD6ECAB
D5ECB6C3DAA2D8F4AAC2E296C9EAA57FA86E185023BBF8D93776634A82779EC6BE506F67
4E685BDEFBE7BDE6C881B08C57885B83B27EC3E9B0C6E2B1C2D7B8061700021000000C00
62783A506C3B5E7F64517363000D00001300595731554E1A0D0E005F6A32C9DEB5CDE7C2
5B744D000C00031B00BCD59BD6EFADC8E299CAE296D2EA9C
D9F6B4C2D9A1DEEAC4F8FAE5EAE0DEFFF5F9FFFCFFFFFFFAF3FFE9DEF4CDDEFBC3D0F0AF
C8E6A0D4EEA7D5E5A4CFE49FBEE094CEF7A8CDF2A4C5E599CEEAA0CBE29ACBE199E4F5B1
D7E6A3B8C784D9E8A5D8E9A5BED28DD2E6A1DFF4B1CEE0A2DDE5B64E532AA3AB82788358
091900000B00698151ABC794CFEDB7C5E6ADCBEFB2C0E4A6D2F6B6BBE09DC3E8A5B6D995
C8E8A5CBE8A5C9E6A3CEE9A496AF6B8CA35DC0D590C5D994E0F1ADD6E7A3CFE09CCFE39E
D2E7A2D0E5A0CCE39DCBE29E8DA66598B07291A767CEE5A1DBF2ACBDD78ED0EC9FC6E997
D5FCA9B3DD89B9E590D0F7A4C7E899CDE79D90A45D6C7B36D1DA97D6DB9BD3D099DFD5A4
120100AA976F625126D7CD9CE6E7ADCFDC97CAE296C8E799C5EA9AB9E091C5EEA0C5EE9F
C4EA97CEF4A1B9DE91C3E79FD2F2AFD1F0ADC5E09BCBE29AD6EB9ECAD889D8E192E3E79B
E4E3A0D2CC92ACA2719B9C63DDF8ABB6D182B2B67989844C929151BCC984C1E8A7A8DEAA
104B2B689F82C8F3C8CBEEB4BCDE94C2EAA447784B93C69BBFE9A9BFE9A1BBEDA8ACE2A4
5B96602F6A3C3B784F16522E18512E457F59B7F0C7B6EBBDB6E6B2001300698A51BAE6B3
A2ECC967BBA317654F74BC97C1FFC1B3EDA08EBF7E001A008BAB79C9E8AFC5E6A1BCDC99
C4E5AEC9EDB0C9F3A1C7F2A0C6F2B365996B001A0032756474B1AA4D7E7A000A00536356
3D48371A2B18C5E5D066927B073E2176AE89C5F9C8BDE8BBACC6AD000800899661E8F4B4
BCCE904D6436000B000015130007075361546A6C4457571BD8D898AEB67D596D4A213E22
0015007C9B72B4D1A1DAF9BEC3E19BD2F1A3D1EC9BC8E48F
BBDB92F4FFCDC0D0A1C0C5A7DFDBCFF9F2ECFFFEF8FAFEEFF6FFE4CBE5B5C8E8A7CAEEA4
CBEE9ECDEC9CCBE196D3E99EDBF5ABBDD78ED1E8A0DDF3ABC0D48CC9DD95DDEEA7C1D28B
D1E59DC4DA917E964CCFEBA0DFFEB2C3E495C3E598C8E89FCAE4A58BA26A253D0B5D7748
5572462E4E27A5C9A5436B4648724E73A2789CCDA0B5E7B4B3E6AEC0F4B6BFF6B3C8FBB8
BCE9A4C3ECA6C3EBA5BCE19CE0FFBCD0EEA89FBA738BA55EA0B76FCCE29ADCF2AACAE097
CBE198DCF2A9C5DB9296AA639BA96CC0CB9191995EC0C68ADEE4A6DAE19ED7E19CDDEAA2
CDDF95D3E99EE2FAB096AC635F6E29ABB674D1D598D8E4A4D9F9B0C4EAA1C1DE9EE2F3BC
050B00959468615C32EBE7B8D8D8A2CFD599E5F0AED0DC9AD4E09EDEEAAAE9F3B7CADD9B
CCED9EBBE591C5F0A0D1FDAEACDB8DC2F1A3C3F2A2C1EE9DCDF8A6BEE592C7ED9AC5E898
CBEBA2D2F1ADC2DEA1CBE4A3ADBD76B6C079EAF0B2E0E9AAD3E39CC5E197C8F5B2BEF5BE
0B442386BF9FACDDAED4FDC1C7E8A1B6CE9292A2853245278EAB71D4F2ACD7EAAAE0EEB1
E0EEB3CDE1A6D5F4B8B4DCA076A36A75A06BB7DDAECEF3C8C9F2CAA9D9B136754A78C09B
64B19D317F722D77686EB498A2E5B2B9F6BBC2F7C1AEDEAE487345ABD7A4DBFFCDC4F2B4
85B279BAEBAAB1E694B8F0A9A9E1BE7CB4A9276361083F42053235000B06697664FBFEE1
D8D5B47B7C5D000700517061012F25003429215E4F124B38001400CFEECECEE7AECEE3A0
BFD292D7EBB8C6DCC720352ED0DCD8EBEFE05550268D874DE8E6A9CCD5A0D7F0D0000D00
143917466D41628855BDE5A7C0E59FC1E899C9EC9AD1F59E
8AA85E859E5C697948B1B6969E9D8BFFFFF4F3F1E5FDFFEEF8FFE3CDE8B3C4E5A0C4E99B
C5E896C7E794C5E08FD2E99BC8DC94D6E7A1CDDE98D2E19CE8F8B1DFEFA8CCDD96D6EAA2
D8EDA2D9F1A57C984BAECF80C5EB98C3EA97C7F19DCEF5A6C0E19ADFFFC093B279274819
5D815B12391AAAD4BC8DBAA53A6955285C45457C5D4B835E81BA8D7CB88278B579619D5D
87BB7988B977C2F0AFB8E5A2B2DB97C9EEA9C3E49FB4D28C91AC6598B269B9D088DAF0A7
D1E79CAAC0759BB166A9BD75D3E1A3E0EAAEBABF859D9E64BDBD81EDEDAFD7D998DCE19E
CED995DCEBA6B7C88266753298A263EFF5B7D9DAA0DFEBADB7DF96C1F1A7CBF0ADD8F1B8
0009008E936A68693FD4D3A7ECEEBDC8CD97D8E0A5B6BE839CA46B90955FB6B887CCD59E
CEE3A0C9E59AC9E99DD5FCADADD888C1F09FC9F9A5C1F19DADDC8BCDFCABBDE99ACBF7AA
C0EEA5A9D890C7F9B2BFE9A1CFE69EC8D992C8DB99C4DB97C7E698C3E99CBDEAA5B8EBB3
002D094F8563B6ECBAB5E5A7C0E5A0E9FFC9D6DEC6101A027F9B68CBE8A8CBD99CC8CC91
E4E4A8DCDDA1D0DC9CD0E5A2CEE8A7CFE9ACDDF4BCBDD8A5C5E9B9ADDFAEA7EBB82A7648
75BC9A4F94757ABB99A2E1B6B7F3BDC0FABFADE2AABFF1BC3F6E4073A27499C9997DAD7B
23531FA5D89DB6EBA5B4EBB1ADE1CA74A6A5002E368AB2BA405F6200070080896CE6E7BD
E1DFAF78764D20260C07190B06292338696605403A00140700261182B18DC6E9AFCAE39F
E5F8B6C2CF9ADCE6CD1C2216D1D1C7DCD4C197885DA49760D2D296CBD9A4CBECCD000F00
658264879F7B7D9468C9E0AACDE3A3D0E69ED0E59AC6DB8E
D2EBA7D6ECAEFBFFDCFFFFE6FFFFF1949087EDEBDFFEFFEFF6FFE1D5EDB9D1F0ADCCEEA2
C9EA9BD1F0A0CFEA9DD5EBA0D5E69FE1F1AADDEDA6CAD791C8D58FDBEBA4D4E69CAFC479
859A4FA1B96DBFDA8BD1F0A0CFF2A0CAF09DBDE491C4EB9AC9EBA1CBEBA8C3E2A94C6D40
000E00001301D9FFF9A8D5D2ACDAD8B7E8E48BBFB3346B544079589CD9AD8BC99648854C
4B854875AD6E447A3C92C485C1EFAFC9F1B2B3D895C5E5A2BEDD9999B46F88A25994AC62
8CA4587E9648A1B96BDDF5A9CFE6A2CFE4A3CEDC9EA3AD6EB4BA7AD8DD9DE2E8A8D5DE9B
A2B16E384C078BA05DE1F6B3CADD9DC2D093CFD89FCFDEA3CFECA9D0EFACC3D89FC5D1A1
0B0D00ADAA8756522F615F394F52274C54235F6D38485B243F511D405220556639576333
3C3F0AC1C087D1D797CBDB94D8F0A2DBF8A6C1E291C1E494D0F2A6CCEDA6CCF0AAC0E5A0
BDE6A0C4F2A9BBEEA1BAEF9FBFF2A3C4F5A6C8F4A9CAF5A6BDE795D9FFB3B2DD98517E47
001400063511AADCA9AEE0A3BFECA9B4DBA4819B80334F388CB386ADD69EDFFDC7CDE4AE
C4D29DDCE3AFC4C792A3A36D696D32ECF2B4D4E09ED0E69ED1F1A5C9F2A3B0E491C2F9A6
C0F6AABAF0A29DD37FBAF09ABEF2A0ABDE91CCFBB3C3F1B0CDF8C2A2CB9F8EB6936C9471
70996FC3EDBDCAF4C4BDE6BCC9EDD387A7983E5855697F7D20332D000700495A2E536229
586426BAC38CD6DCB6707A61000700000B001D4A358AC2A9ABF0D34B8C621C4A0C496721
3F4B09E0E0AAE2DDBF716453B39D8FAD937CAE93686D5A22E7E8AEC7DEAAC7F6D60B351F
626554F4E3CFB9A88C9F9069A59564B4A36DAA975DAB975C
D3E2A7D8E5B0DBE1BBF9F9E1FFFFF4E8E1DBA09C93BABBABD8E2C0C7D7A8CFE5A7C9E39C
C5E197D0EAA1CBE29CC9DE99D3E49ED6E69FC2D28BCCDC95BAC98451601B4A5B15D2E39D
DAEEA7B6CA83DDF3ABCEE59DC9E39AD0EBA4C6E49CC8E39ECFE8A6C6DBA2CDE3B469815D
000B00001105000A09D6F9FDE4FFFFE3FFFFC6F0EE5C8A7D55876EB2E6C2C2F7CDACE2B1
B3E9B5ACE3ACC2F7BF00150081AE77C9F2BAC4E7ADCBEDB1C0DEA0CAE7A5CFEAA7CDE7A0
D0EAA1D7F2A5D1EC9FC2DE91C9E9A0D2F0AACFE6A2C1D28E9CA7655F68277D8846596523
D3E4A0C9DE9BD6EFADC8E19FD4EAAAE2F6B9E0F2B8CFDEA3D3E1A6D9E4AAE7EABBE4E1B8
0B0000625439504529C3BD9DD3D5AEE5F0C5C5DBAA97B3806481515D7D4E93B288C5D7AF
948F6756491D918C55E9EFAFD5E59CBBD282D2ED9CCEE99CC5DF98BBD594CFE9AAC5E3A3
C9ECA8D4FEB2B9EA98B9EF9BBBF6A6BCF2A4B5DF93C9E89CD1E89AC9DF96CFE7ABD3EFBE
BDDBB7D0EECC5774466B8852021F00001100000C0057755DD3EEC3BDD8A3D6F1BCCFE8B1
D6E7B3CCD3A0726C3C493D0D675B27474208DBE5A0C4D98CC7E38FD9FAA1C6E78CCAEB90
CAE88ED7F99BC9EC84D3F692D0F29EC0E296CDEFA5C1E29DC8E7AEBEDBAFCCE5C8C3DCBF
E0F9CF587242081F00000A0050643F000B000F15070002007A7D72CFD9C0000C00001100
283D00526022D8D9ADDCDBBCA3A78E5F6F5497B69498C6A1B3EACB0014000011008AA05F
AAB571484C1163643C0702000D0000261300462E0064531DDEDDA7C9DAADC2E9CE001100
333021A08B7A6551366F5B386C572A624C1A604913675118
D7DBA9DCDFB4D6D2B5FFFFEDFFF5F1FFFBFBFFFBF9BAB4A8A9A78E92976F97A16D94A265
92A2639AAA6C93A26992A1668A9B577C8D46778842899A54AFC07CD4E4A3DCECABD0E0A1
D4E2A5D2E0A3E5F0B8D4DFA7D1DBA6DBE5B1D1DBA79AA271D1D4A7DBDDB6A8AC8B20250E
050D0000040000040526383C02151B00070B324C4958766CCEEDDBBFE0C5C5E7C6C4E8C2
BCE6BECDFACFB4DFB4ADD6AA395E3235562969895A809C6CDAF6C3C5E0A9BDD99ECCE6A7
D1ECA9C7E29DC5E399D0F0A5BCE096CBEFA5CAE8A0E2F9B1C5D690929F5AA7B37193A25F
E4F7B5C8DF9BC3DE9BC7E4A1CDE7A6BDD597D6EBB0C9D49CE8E5B2B5A87B9C8865A58C6E
1B000072574465503BCFC3A97F80606D7C532842156084546A9162457043426C44637E5B
C7C6AA9F91749B9A6E59622994A861DDF8ABD1EDA0C6E297DBF1B0DAF0B2D2E6ABCDE3A5
C1DF99BADF8FC4F196C7FA9EB9EC9FC5EAA4D9E29FE4D999FFECAEA9935A968E5F999973
8083668A896D9F9572776942D1C59DA4A4829BAA958A987F848051B1A66ED3D49ABDC288
9DA2687B7843766537BBA679A694645F5822E2EAAECEE29DD7EFA5BDD388C1CD83777D33
D0D48ADCE191DEE78CD5DF89D4DD9ED7E0ABD5E0A4DBE6AAC9D29BAAB1856A6D50757455
6B6B352C2A00686232868253C6C8967B7C500B0000877A6A7E75666164491B2F00637D3E
819854636F31312D00A89B78867B5B44461F0118003F592919290F0005007B7E53EDF0B7
BEC78693A3628EA9720C28008CA274BFCB9B77743D4B420B6058276A6744313A29000600
000600798668929E7AD3DFB1C7D19CCFD99DECF5B6D9E2A1
DFDBACE8E3B9DFD4B8FFFBEAFFFAF6FFFAFAFDEEE9FFFCF1FFFDE4E2DDB7DCDCAAD8DBA2
D5DAA0D8E0A7D4DBA7D9E2ABE3EFAFD1DE99D2DE9CDAE9A8D4E2A4CCDC9ECFDCA4D3E0AA
D2DEACDBE4B5CAD1A7D2D8B2767A570105000304000A0600362C130E0300080000070100
03010064665BC3C8C1050C05000400121F16000600001000000A00D0E4C9CDE1C5EEFFE6
E7FFE5EDFFECE1FEDFC5E2C3CEE9C8CCE6C32B401F283E18C7DDB6D0E7BBD1EBBBCBE6B1
C6E3A9C9E7A9CBEBAAC9EAA5C9EBA1CAEA9FC9E39AD2E69FD1DE99E3ECABCCD594D6E0A1
D0DEA0D2E5A5D7EDACCDE3A3CDE3A5D7E9ADD5E4AB4E551F56502064552C6C5837674D34
180000785B4B1E07000D0000403C1FDAE1BFCBDDB5D6EFC5BBD7AFC9E7C1D4F3D1C8DBBF
372E1F100000D6D1B3A0A678495B1F879E58C7DC97DAEBA7D4DEA2C9CE96E2E2ACDFE0A6
DCE5A2DCED9DC1DB80CAE890C4E39DD7E5A8F1DEA4724E146A3B077D5728E4D5AC9A9774
D7DABB7B7658543D1D7857366A4B2C6652394D503F5B5F4867532E674B1B6955235D501B
5B501AA49760EEDAA5E7D29DAB9A64544911DAD89FE3E7ACD6D9A0E2E3AA9A935F605422
6C602CDFD59AE6DF97DFDA987B734E080100100B000804000B0400150B000E0000A8947C
6652206A541B7053291400002622001512001000005C443AE6CFC7E6DBC9D3DAB1D2E1AA
CFDA9EE4E4AEEDDBB5A58E6F675338A4A07BCBDFAAC5DBAAC8CAB2EFE7D2D8CCA6DCD5A1
F1F2B6D3E1A3526D36001200587443C1D3A1656831A49D67E8E0B2CDCAA7DBE3CE627361
283F23CAE4C1BFD8AED8F0BED2EAB0CAE0A0CEE3A2CDE29F
DBD09AEADEAEE3D5B2FFFDE4FFFCECFFFBEFFFFBEDFFF7E3FFF6D5F7EABEE4D8A4EAE1A8
DFDAA0DAD89FDDDBA8CDCD97DEDDA4DFDFA3DBDCA2D2D59EE2E9B3B1B986BFC899C9D4AA
8D97726E7758697257252D160D11000002000404000400000B00000F00000D0000302418
9E9787DEDCC763654DAAAE93343D200F1A000008005E6C4B1221000008002F3C1EACB99D
E5F3DAF8FFEFF8FFF1C1CEBAD7E3CDD4E0CACDD9C399A78E526046C7DABACFE5BFC7E2B7
CCE9BBCAEAB8BADDA7D2F1B6B9D290DBECA6D0DC9AE1E7A7E1E1A3D9D79CDDDBA2DAD9A0
CFD299E8EDB3D8E2A6D5DEA5D2D79FC3C6914F4D1AA3A3718F976499A074BFBF9BD9D2B6
0E0000432E1D24110251402E8B7F67B0A98CCBC8A7CFCFADD2D1B3D4D0B5D6D0B8DFD2C2
A08483140000918172B6B29580865A505924747941A19E67AC9C6BAC9464A18253B2935D
A68C4FB09E56A09845A1A050A3A269685C2A623F0982531D7B4D1BA8895B92926C465A35
152F0A23330E79714C3A22007D5E416D533C7C7362A29D8AA796828A70576745296F4D28
B19162CBB178A89654A39650796C2670611EC6AD74BB9C6DC3A37D8D70526D553B7C6A52
5C4C328275538075487A704C1B0E061F11102113060E00002C1B07442E2063454576534D
623F2189613D8759425D3D285E5F3F1C22060F0000A58A8FA6878DB0949096866DA79E77
9C8F63AB9870AE8B75A38273B59F928A897472906A44673F818E728A896D9D936FAEA174
9E9260A49E6C7A7D520F1700010600252600170F000B03007A794B6F7E55001400214627
00120060745162744A5B6D3B65773D5D6D2F6D7B3D697739
A29958645A1F514716CEC29CACA185BAAC92B2A288B2A281B6A57A90804C76672C645919
776F308983476A673064612C928855887C4C9D9264979064949269898E663E4621192404
071500000700354332313F32B0BDB4000400202926202221160D101A0C0C080000191104
0503003C401D5A6137404C1A74824D8E9F69A7B8849AAA79879969596A3E3F4E27000700
0307000A0B001617058A8D7CAFB1A39EA09294988AAAB1A14D564533402C14260C182F12
526D4A37552F45653CB4D1A173874C8D9959828A4E9A9D64CCCB9361602A84845091945F
CCD09DB3BC87929B666168349C9E6C3735046C64360705001A2A000F25001E2A04040700
0800002111012F1E0EB3A08FBAA890D1C1A7C0AF91BEAD8F927D62B89E87C9AA98E7C9BE
DCC2C3B5A5A50400007D856E80916D85986B9FAD7C868A585E5222745C2C73532065450C
A28647AE9A53A69E4D98944A908D56B5AB78AE965AA38547AA945BADA5761A2E09113413
719E7584A97D6D7F4F0405006A603D9E9375918F7621240F4249377B7C6AA49882A28D70
988158B39F6A988F4EABA75E9F994FA3944F72551B7753237D5A34745538A9957CABA188
9D997E979677565630030400040000241E22514A4293897D61534638241B422529B19290
421F0B936D563C100736180D050A00020F000B040016010833182135181A5E4B3A3C2B0D
3422004B32133A17044F2F24100000000400000E00001C000008000B0C003A300CC7B891
B2A37AC6BD968A87663033141213005F5C3B352C05211A006A70424960325583551E4F22
000E0050694162784A61784275894C7186457285455D6D2C
A1A050A1A157A5A565C6C78ED8DAABDDDBB2E1DEB3D6D0A0DFD49CD7CC8CE4DA93A29A52
9F9B54DAD998BCBD83928F5CBDAA82C9AE90D5C0A19D8E6FAEA78A45482B000600000700
0009005F78658EAA9C98B6ACC4E2DA122F2B243E3D000B0A040A0A0001000003006D755D
5D6C4593A571E4FABA93AD66A3BF74C7E69AD5F3A9CBE9A3CEE8A9CAE3AA96AC7B324118
0D10000E0A0006010035321FC6C3B4EEECDFFFFFF6ECEEE39DA0953F473A3B493A0B1E0B
0C240E072108628064C9E5BF8FA574ACBF878C9A65BBC893B4C08E94A07096A473869868
BBD1A2BDD5A5B6CC9B3C4E1E313A0D030600A29F767B7E537C9263789366000A00040A00
0601000C0100645444FFFCE8BFAE94C5B294B9A584C0A8869A7D5DC19E82D4AA94D9BAA8
FFFFF3DCECDF5777625C876B84BA968CC49784B484C4E9B393A66E969C609998589C9954
D3D48ED8E397D9EE9FD3EBA1D5E9AED0DFA4D6E499D4E597C7DA98C5E1AE234B28487B5C
B3EDC4BCF8C5A9DFA51D490E446432DCF6C97D946824441F2B5D42598F77C4ECD1CEEBCC
D8EAC4DAE6B6C8D19ADBDFA2EDECACD2CA8BA7995CA5965BA69962E6E1AADFE2ADDDEAB5
C7DEA8C7E2AD8CA7702E4519041600000600414D39727A633C3E280D0A000800006A5C53
130200442E201D04000D0000000700000A001C1E09060000180C0E0800000700000C0600
0C03000D00001702000E0000090300010C00496A355F80493F4A200604000B01008E815F
6A6142A5A488BDC7AE5B6A53202E159DA78C5152324C4C26D9E2B5DAF2C0B5E0A880B179
204A189DC390C6E9B1C1E5A7C8E9A4C5E69FCEEDA7C0E097
E2F09BDDEC9BD5E6A0C0D294E5F7C3C5D5A4CEDAA8DBE2AEDADB9FD1D08FE5E29DD5D28D
E8EAA9DEE4A8C3CD98E3E9BD85755B7D66545C4B37413924010300111A05233622657E69
DAF9E7E9FFFAB0D4C69AC0B3446A5F8DB0A9ADCDC8000A020007003B4A378B9E82D7EDC6
C4DFAACAE8A8CFF1A5C0E391C7ED96C9F097BCE28DCDF0A0C2E49AD2F1AECBE7ACCCE0AB
D4D9B0999673797859111000393722040300A4A296F2F2E8FFFFF8EBF0E9F9FFFAF1FEF4
ECFEF274897A445B495771565E7950708C5C849E71AFC99CC3DEB5C2DEB5C7E7BEC6EBC0
BCE5BBCDF6CA9CC1964160366C81581A2400A0A17F939772C3D4AADDEFC7808A68010400
524A37504332857663796952B4A5869A8C67A6996FA39568A79168A28961A483626E593C
A3A78EF1FFF19CC2A9699E826BAA8B5EA27D27643851834EC8EAAEC7DE9AD2DF99EDFAB2
D0E69DD2F1ABC0EBA4B2DF9EBFE2A8CCECABC8EB97CCF29DCDF5AF70986600110093C4AE
BDF5D2B3EEBEB4F0B4B7EFB065925B193E0A44612BC5EAB6B0EFC0317A4D4285592D6639
AAD8AAC1E2B3D6ECBDCDD9A9C8D09DF4FDC6C6D499D5E9AAC4DE9DC6E5A1BFE29EB8E09A
C5F3B2B4E5A4C9F6BD94BC8AA5C7A45E7B5C061F00162C085D6F49606F486D7754000600
050B00636649686753A3A689D8E7AEC5D79B65734F636F5B525E526D7B6E63715A7D8B6A
848E6B707652656849A6A98A9BA582CBDFAECEEEABD2F3AED6EBB3E7F3C540421B050400
1B1D05171E0C031507233B2D000900E5F3E2000400787D5DCBD8ACC1DDA3C6F8B3B8F0A9
54864BB1DEA5CCF8B9C4EFAAC0EAA0BDE698CAF3A5CEF4A7
CFF0A1BADC90B7DB9BD5FCC3BBE3B1CFF4C8CAE9BDC8E2B3CBDCA8E4EFB7E0E9B0DBE4AD
E3F1BE5A6D3F000C000009000003000D0D030107000005006B8071B3D0BEDDFFECE4FFFA
DFFFF6729D891F4A3600110086AB99B3D5C4BFE0CF001400000C00809B72D7F4C4C8E6B0
BEE1A1D0F6ADB7DE8FCAF4A0C6EE96C7EF97CFF7A1B6DC89C2E497BDDF95CBEAA6D0EAA9
CCDBA2EBF5C0D7DFAE51582E070D00000400000300000200E5E8DFFAFFF8FCFFFBF9FFFD
F5FFFAF7FFFBE1F1E7596E5D4F6D516C916F000F001B4321608B6DC2F3D3ABE1C1B9F5D3
A7E4C27FBC9A447C598DBC9AB1D4B4C3DABD3C462B4B4F34303111716C4EE0D6BD1A0B00
705A4C5A44365C4A36DFD1B6FFFFDBDCDBABE0E5ADD7DFA4E4EAAED9DCA3D7D69EA19F6E
4D4923CDD2B2D0E4C9E9FFF4DFFFFB3D755C0014005D8B5DC7E6ADD6EDA9CCDD96D0E49C
BAD996C0E9AFB0E6B4BAF2C1C5F2BBBFE6A3BFE78FC8EE99ADD0901D3B15001307BAD9D1
B4D7BFBDE6BEC4ECB7B9DFA6DEFAC7B9CD98DFEDB2C4D998C6F0A6A4DD90B1F1A521631C
3870335D8956C1DCB3D9EDC8DDF3CFB4D4AB5387563C804578C785A1F1A8A4EDA4C1FFBE
ACEDABB7F3B7B4ECBBB5E9BBAEDDAFACD6A8CBF1C2C0E2AFCDEFB2C6E7A2CAEA9ED0F0A5
C5E5A2C2E1A5CBEAB1C4E1A1D3EA9CBDD58BBEDCA8C4EAC3BBE6CABFECCF55825B82AC7E
C8ECBCB9DBA9C7E6BACAEABBC1DFABCDEDAECFF0A1B0D784BAEAA0D5FFC3C3E3B4617655
000D00000600243A381E36380006070004020C0F04525740DFF0C4C2E6A6AEE995B4F69F
AAE19DC3F4B3BCEBA5B9E79EC5F1A2C2ED9DC0E99ABDE697
B6E7A5C4F8B8C6FCC8ACE5B879B38D75AC8C84B597BCE5C3CCEAC687A0785C71481E320D
000B00000C002B503E22483D6B8A8469888397BAB3779F96406E6194C7B663988479B099
5F957D4F8166507C61769D82B8D9BE668065000A00000A007B9764C2E2A3CEEEADBCDF9B
C3E79FD1F7ACCAF1A2BEE594C1E696C7EC9CCAED9DC4E596CEEDA1DEFAAFCCE89ECEE89F
CCE69DCCE39DCFE4A3D6E7B0D2DFB1DCE8C2464F32000400000300787B74959792F5FAF6
FCFFFFF2F8F6F3F9F5F7FFFBDBF6E7DCFDEAD0F5E3C5EEDC86B5A3194E3A65A38E2A6E57
61A78F478B721B5940A5D6C0E8FFF5D5EAD7F3FBECF1EEDD766A52716046F3DDC8140000
6D5145725849B19F89FFF6D5EBECC0D2DFA7C7DC99CFE9A0C8E299D7F1A7D8EFA7CFDB9B
B6AC775D4F28B5BA9CDFF5E0C1E7D888B7A72B593F95BF99CDEEB5D5F0ADC9E399C3E199
E4FFD1A3DBAC87CDABB6FCD8B8EEBAB5E09BD8FFA8CCEF9B69884D000E001C413A88B1AD
ACD9C2B7E1BBDAFAC9C5D9A6C8D0A1E6E6B4E0DEA1E5E8A3D9EEA3C6E69ACDF7ADBAE9A3
A2D29475A06A6384576B8A61395C3400120066A47183CE933E8F4D61B26D6AB36C30762E
387B3652925583BE9064996D70A26DD2FFC8BFE7B3C4EBB4C9F0AFB1DA8CC5F297B6E48C
C1F0AA8CBE815C9052A3D493C0E5A0CBF2B1CBFFCE9DDAB188CAA60B4E252A623155884F
4E7C3E002C000A3B045E905BA4D6A1B5E7ACC2EDA8D3FFB6B3F0A0BAF8AFACDBA7B1D9B7
4D7163769D9A77A4A9568389547B8200080B000500687460CADBB1CCEBA8BDF298B7F294
C9FCB1C6F3B0BEE9A2C2ECA0CCF5A6CAF19EC6EC99CAF09D
B5F4C59ADDB176BD9B479176277160001E10001409477D708DB7A9000C00001707001E12
000B0500282A9FCED8BCF2FCD1FFFFCEFFFF367F76418A7F348171003F2B458F780E5438
4382633D7353CAF3D1B8D6B46273510009000E0F004D5327CCE19CCAE797CAE797D0EFA1
C5E399B8D88FC8E7A1CBE9A3D2EDA8C8E39EC5DE9AD7EEA8D3E7A0D2E39CB6C87EDCF3A3
CDEF98C2E891CDF0A0C3E19BCAE4A7D3E7B6BDCDA8CED8BD0004000B0E03030600898987
EDEDEDFFFFFFFFFFFFEAEEEDF3FFFFF2FFFFE1F6F7EBFFFFE7FFFF3E6864093E3858948C
003D32104C4245796DD2FAF1E3F8F1FBFFFDFFF9F7FFF7F0B49F8E765D475D4231190000
34180C6F5848B2A289D6D2ADDCE4B1D2E8A8CAEA9FC7EE9BC0EA94C1EB95C1EB97D0E598
907E3E7F63314C421FD9E2CDBEDACE638B80000F008FB995BCE2A9BEE29CCDF2A5BAE59E
9DD8A04C97702A836F2F846DABEBB9CBF9B1BCDE87B9D682C9EAB185B492397F74308276
32866573B88BB9DFAED6DFB0A1926B6A4F24604A0E675719272100A4A57BDCDFB4DFE8BB
BED0A0C5E1AEC5EBB2C0EDB2C2F4B5C5F5B7B4E0A1C4ECAECEF2B4B2D497D2F4B7C4EEAC
BBF5A9B3F0AB1D53220014004F7C41C9F1B5B7D9A7C8E9BAC6E9B3D8FFBEB7E396B3E59E
C0F3CA00130000150081BC9CB1E8C8B5F2D1A8F4DA2B7E643A8B6B458E639ED59BC8F5B0
C9F1A8C5F0A9C8FFC52B6A3B377D584A906EA7E4C2AAE5B5B1EDA5B0EA9ED1FFCE407654
458272074E4A2F8385277C812F7D810E4A4B000B07687B68DEEAC2B4C382E2FCA3CDEF91
BFE197C1E19EC7E8A1C7E79BC7E696C9E694CAE594D5F09F
65A0804F8B6F417C687CB9AA77B3AB8DC6C01F565100302A164741000F094A78758ABABA
ADDFE08ABDC0659A9E3C7E7D287F76308C7F56A69983CCBB6CB19C9BE0C4ABF2D0AAECC8
B3EBC4BEECC57E9E77677D56000B0062673F534F29DEE0AED8EAA0C4DD89D8F19ECAE294
C9E399D5EFA8CAE3A1D4EAA9B4CA8AA9BD7EE1F4B4C2D593DBECA691A15A9DAD64C9DE8F
AACC75C0E78EC8EB99C6E69ACAE5A2D0E5ACD0E1B4D6E1BFAEB69E787C6D000100040500
2F2D2E343233676566FDFDFFFCFFFFDEE6E9F7FFFFE8FAFCEEFFFFEAFFFF87ABAB5D8785
DFFFFFE2FFFFE7FFFFEEFFFFF8FFFFFCFAFDFFFBFFFFF9F7FFFBEDFAEAD3C4AF9C110000
4D382587775EC0B796DEDFB3D6E3ABC7E09ED1F3A7B3DD8BD3FEAEB7E292C6F1A2CEE69C
E2DA99B19D6879714DE9F1DADFFBEF91BBB164978880B297BEE8C0C5EDB9C5F2B777AD73
00380933836067BEAB2E806A45885D8FC58BCDF5AFD5F8B6B3DAADBDF2D4B2FCEDAEFFF0
358965125627A7C997474F1EA29166A78F5FAD995AA5975AA299707F7657574A2AABA17D
FCF9D0E2ECBACCE5ABC7ECA9C2EDA6C3EEA6C3E7A1CCE9A6D2E8A7CEE3A2D0E9A8C9E8A4
C9F5A6A2D48BD0FFC9A0CB9D69965FB3DEA9D3FCD4BBE3C03B653D396736B1E3A6B6ECB2
4D8361679D83B6EFCF0F4B29437E602B6C4E00280A0C5B3B59A47DA8E8B4CDFEBCC5EBA0
C3E495C8EEA3AFE2A0C4FFCA74B98C6CB38B2565424D885CB9F1B0BDF4B1AAE0AF83BF9D
397E6996E4D680DBCA78D3C470C0B32A695E000D043B5441B2C39FD4E8ADCAE793C2E58B
CEEEA3CAEBA4CCECA1C6E597CBE896D5F2A0CEE796C8E190
D0F3DD97B6A46F8579707F786C776F000500000F0132564843776A205F56488E8C569E9B
40867B5A998481BA9792D9B168C9A6005537B7EED7DEFEE7E0F9DBB3CFA7C9F3C3BCE8B5
BDE3B29CB98B000D00000F0067774AD2DEB0D2D8AADDE6B1CFE09CD1E79ED7EBA3CCE099
D5E9A2AFC37E788B49A3B674C9DC9ADEF1AF8EA15FB8CC87718641D9EFA7BBD189D8EEA6
B3C981859B53DFF5ACD0E69ECEE29DD5E5A6DBE8B3CDD8ADEDF4D5FFFFEFF4F6EBC2C3BE
848283777578323033000000000200293028798079A6B0A8F8FFFDF7FFFEF6FFFFF5FFFF
F3FFFFF5FFFFF0FAF9F4FAFAFEFFFFFCF8F9FFFCFEFFFEFAFFFFEFE6EAD1D4D4BA141100
65613E848158B6B887DEE5AFD4E4A6CFE5A4DBF8B6B7D794CDECB0CAE9AEC6E1ACCCE4B0
D7ECB3D1E2AE656F4C81937BA9D0BE336B5E3A7E7377BBB051837A49776A4B7F69326E52
458C6AB2F9D7AEE9CBAEE6CB41816647886A8DC6A59DD0AF4573594E7B66598A77001100
64906F6F92685F7747D5E3AED9E1A8F6FBBBBDC47EDFE8A5D1DBA7DFE5B9979469756C41
64572B5F552477743F949C60DBEEACC6E49CC8EDA0CFF8A9BDE697C1EA9BCDF6A7C1E698
CCED9ECAEAA1C4E8AB5A825078A77BBFF5D39BD5BD05432E60A0886CAB8E4A895E134F1C
001600A3D59AB8E7A3B6E3A085B27783B27BBEF1B8B9EAB2B2E2A6CBF5B5CBEFA9C6E49A
CBE79ABFDE90C5EA9DCEF8ACB9E79EB9E8A07DAB636694534D7E465F9365427856478060
3C7958B1F1CCB2F1C2B0EAB8C0F1C46F9774000B00526F5934593A1B4D1C87C67FC1FFAD
C6F7A5C1EB99C8EF9EBAE18EC8EE9BBEE491CDEE9DC6E796
465F492437210005001514000800000F0B00272F1795AF96BDEDD77FBEAB5FA9982B7963
135D3A57996BA2D99FB9FDC259BF90005531C2EDD2BAC7ABD1D5B2E8F1C4B3CE97CCEEB2
607B442135020009003F4B1DD9E9BADFEFBEA2AC7A6F7A42D3E3A4D2E39FCEDF9BD0E19D
D3E4A090A15DB9CA86DCEDA9DAEBA7D9EDA8BFD38E81965191A862BED58FE3FAB4D5EAA5
D9ECAA819150D6E7A3D2E39DB0C17BABBA77B7C58A9BA475D6DCBAFFFFECF8FAEDFFFFFB
FFFEFFF3F1F47D7B7E474546000200494F4300020041443BF7F9F4EBEDE8FFFFFFFAFAFA
FFFFFFEDEDEFFFFDFFFFFEFFE8E6E7FFFEFFFFFBFCFAFBF6FBFFF6E1ECDBD8DDC7070A00
73725384855DB0B386C4CC99D6E5AEC7DAA2CDE4AECEE6B4AAC195C6DCB5E8F9D7C7D9B3
C3D6A8DAE7B9AFAF8D4E513697AF994F7A673F75674A7D74000A070009042E4E41386348
558962A6D5A7D6F0C1CCE7BC97C9A628634562977B59876D00120002220B59725C5F735A
6D7B61404B2D939F7BFCFFDDD1DDAFBCCA97E3F2BBDAEBB5DDEEC1E7F2C8D9DAB2C5BC95
A99771A48E656251235D5620D3D99DCBE09BC8EA9EAAD585CBFBA7BCEC98BAE794CCF3A0
C6E190C8E396CAEBA6739C6062936469A37D3F806200290F8ED4BA95D8B975B38C154D1C
47773BBBE49EDFFFB2D1F2A3D3F3B0B9D99ACCECADC5E3A3DEFBBBBED897BDD694D7F0AC
D6F0A9D4EEA5C3DF94C7E899BADD8DCFF5A2B5DB88D1FAAEB3DEA6B6E5B798CBA088C093
68A16EB5EBB1BFEDADCDF4B5BAD7A16E855B000A00526F59B6E2C967A07D76C08BA4EBA7
B1E293C6EC99C9EF9CBCE191D8FBABC7EA9AC6E69ACFEFA3
698463647D55768451626B329D9E64D5D8A3D4DCB5D1E4C4BADFBEADDFBABDFBC8B6F8BA
ACEBA5C3FCB5CAF8B8AFEAB237966C389171C2EAD0DBE8CED4D8B79FA87D607B44001200
001500829460A0AE7BB4C28F7C8E5AC2D59E98A56F9BA66C889756D2E19ED5E4A1D3E29F
9BAC68B1C27ED0E19DC9DA96CADE99CBDF9AD2E7A2C4DB95D3EAA4CCE69FD0EAA3C4DB95
CCE19E93A762CBDF98B0C47CA8BC74C7D894D4E2A7AEBA88DCE4BFF0F5DEFCFEF1FFFFFA
F7F6F4FFFEFFEBE7E8FFFEFFFFFFFBF9FCF51D1E19000100353535000000A9A8ADF6F5FA
FAF9FEFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFEFFF6F6F6FBFFFFE3E7E8DBDAD6040000
7C7467514B353E3A1F0F10005B633E031200000D00000A00000F00000700000600030700
B0A77EEAD2A6ECC5A4A07D616453398C8B6FBDC7ACD6DEC6ECE1CDD2C4AAE1D9B5DADCAB
ABB7799DA45ECDC37CE0D995D2E7AC5F8049567241ACC397D7E7C2A4AF8F32361D61604C
C0BDACADAA9B211D110400000301000101000002000004000006005B654C717157AEA48B
D9C8AEF3DEC196846061582DCED39DEFFFC1C9E6A3D1F5ABD1FAACBBE496C5EC9DCDF09E
D4F4A1D1F39FD2F8ABAED99198CC8A8AC4897DB98375B380B1EFBEAFE9B7C0F2BFC0EBB5
C2E5ABC1DE9ECADF9EC7D99BCCE0ABD2E6B5C7DBAAD6EAB9C7D9A9D1E3B1E4F5C1C7DAA3
C0D39BD6EBB0CDE7AAD2F0B0CBEBAAD8FBB7B8DD98CCF4AECBF4B2C8F2B0C2F4ABB9EDA2
9DD284B8EBA0B8E19DC5E4A9E1F7C9D4E3C20A18016B806FC6E8D7BFEFD941806381BA8F
CFF2B2D5EBA0D3E99EC9DF96D4ECA2CCE49ACEE59DCAE49B
C7E5B1BCD89EC4D994E3F3A8D4DE95E0E7A4C8D19ADFEFBED6F1BEC3E6ACBEECA3BCED9B
B6E893BAE796C1E9A3BBF0B85BB38B26795DD3F9E2C6D2BAD4DAB8071000000E00001000
C1D99FCCDFA7CEDCA783945EDBF3B9CBE0A5EFFDC0C4D09297A363E0EFACD5E4A181904D
52611ECBDC98DBECA8DDF1ACD6EAA5D4E9A4C3DA94E6FFB9CFE9A2D9F3ACC3DD96D3EDA6
CAE19BBCD38DC0D88E96AC63C0D68DDEF2ADD3E3A5D5E1AFE7F1CC52583EFFFFF4FFFFFA
F6F5F3FCFAFBFFFEFFFAF6F5F9F8F6FDFCFAFFFEFFE6E6E6D7D5D800000408070D05040A
D0CFD5FFFEFFF2F1F6F6F7F9FDFDFFCDCFCE0001006E706F71727604030809050619110E
0A00001D1101070100040300101600CEDAB6000900D8E9C7C6D6B95C6A51000700030300
190B001800003B1300EBC2A4E2C9AA6255334E4A27585230654E2E755B383520003E3300
61611B5654074E3C00716018525413E2EBB26A713D4E51225C5A33544F2F564C33E3D8C6
0A000071645C08000011090603000011100E5E5E5C090E08010B02000400090900080000
0E00007C67543E2D13655B38E0E1B5CAD4A0CADFA4CBE8A6BDDC98C9E8A2D3F1A9C0DE94
C0E192BCE191BDE698C6F2A5C8F8AEBDF1A9B0E59FBEF2B0C6F6B8BDE9AEB4D79FCEEBB5
CCE0ADE4F0C0CED6A572784C6F7750616B48020C00000700000700E2ECC777815CDCE8C0
D3E2B7D2E3B7CEE4B5BFD9A9BEDCAAC5E6B1C3E6B0BCE0A3C2E29FB6DB8DC3F095C5F494
C1F392CBF9A1C5E9A3C6DEAAD0DEBAC3CBB359614C000C00D1ECD9B9E0CE7BB0A04D7D63
CDEAB4BED18FC7DC99CFE4A1C9DF9ED0E9A7D9F6B4C2E19E
D7F7ABD2F1A5C4DE94CDE199CEDE97DDE8A3E6F1ACC2CE86CADA8FD6EC9AD7F09CD6F49E
D1F39FC5E896C3E599BAECAF05553037816AC7E8D5A7B39D3B4221010C001C3500D0EEB2
DAEFB4CCDEA475844B92A66BCEE8A9CAE5A2C9DA96D2DE9C96A260C3CF8DE2EEAC92A15E
C4D390D5E6A2D1E29EC8DC97D4E9A4D7EEA8D1E8A2C0DA93C2DC95CEE9A2D3EEA7CCE7A0
CEE9A2AFCB81A6C174A5C073D6EEA2CCE29AB8CA8CE2F0BDEDF7D2FEFFEA9D9F92FDFCF7
FFFEFBFFFEFDFFFDFDFFFDFDFFFEFFFFFEFFEEE9EDFFFEFFF1ECF2DFDCE326232A020109
02010734353A37383C0C1011000100000200000200020701000100010100040000070000
0B0000463A2057512FE5E3BCC4CA9CDFEBBBCFDFAEF1FFD3F8FFDDF3FFDAFBFFE1FCFFE1
737C518688600B01000B01003B3B19ECF4CFD8E7C0B8C29D918D6AA39E78CCCB9DDFE8B3
C6D89ACBDB9AE8EDAB8F8D5260592B544B24564C284538168E7E64B4A48B1D0C00443323
0B0000413527FAF3E3FFFEEFF9FCEBFCFFF1F9FFF1ECF9E8F8FFFFA8B0B27B7B7B7B7371
0F00001907000E00000C000045421F4F5529EBF7C5D3E6AFCEE3A8D3E9ABC5D99CDDF3B3
D0F0ADCDF2ACBDE59EBEE89EC6F0A6C6F0A4C3ECA0C6ECA3B8D994DEF8B9DAEDB6A2AE80
5A5E390D0A00160F00080000040200030200141300080800030300020400010500080E00
000600000C00657656A3B897CAE4C1BCD8B2DCFAD4C6E3B5DBF5B8C7E494CCF28FBFE87E
BEE97EC7EE91CDEAA7D4E5B8DDE3C7DFE1CC6E70580006006A7E63B2D2BD5B857B000F00
BAD9AFCFEAB3CFECB4CCEDB4CBEEB6C2E9B0B6E2A7BEEEB2
CAE890BAD785E1FBB4D4EAAAB6C88C5260228B974F848D3C99A249D4DD82D8E48ECDDC8B
CFE59ACCEAA0CAEEA6B9EBB0074E2E064733BEDDCD1E2A140812006A774BCCE5ACC7E1A4
C3D599DAE8AB99A96BB6CC8CC6E59FDAF8B0D0E49CDAE7A1A5B06CC6D18FACB7759EAA68
E1F0ADCDDE9AD7EBA6D2E7A2C8DF99C9E39CD2ECA5CEE9A2D3EEA7CCE7A0C8E69EC1DF97
C8E69CA3C276B5D484C9E696D1EC9FD3EAA2D0E4A5D5E6B2E1EDC7F9FFE5F6F8EACFCFC7
EFEBE8FBF7F4F9F4F1F9F4F1FFF9FCEFE9EDFFFDFFFFFCFFFFFDFFFFFDFFFFFDFFFFFEFF
ECEBF0EDEEF0A2A6A55A5F5B727972FBFFFAF4FCF1F8FFF3FEFFF3FFFFEFF6F4DD0E0800
72694AAAA07CD9D5A8CCCC9ADAE2A9D5E3A6E8FABCC6DC9EDAEFB4D0E3ABC2D39DD3E5B1
C6E0B1D0EABDD9E8C13D4923011100000B00000B001F300C000700444929757F5D6B7D57
97B2895B764B6A7C54626A45312A104E3F284C3D280D00001102001001006E624C726751
FFFFE6FFFFE4E3E9C7C6D0ABD9EAC0C3D8ADC9E3B4F2FFE8F5FFFDEDF4FAFEFFFFFFFDFF
FFF6F4FCEDE63E3121281D070702000C0E000A0F003F481994A06ED9E5B3CED8A4CDDEAA
C4DFACCCEDB8CBECB3C3E2A6C3E1A3C1DE9CD6EFADCFE4A3516123000A00030600494623
0801004F4432EAD9CFFFF7EEFFFEEEFFFBE8EAE5D2ECE7D4F4F1DED3D0BD777662696B56
343722000500000900000700000800000D00859C80C7DDB9D0E0AFC3D694D2EE97CCF08C
C0E683C2E48ECDE5A9E1F0C7EFF1D9E9E7D279785A0006002535119DB89982A8931E462E
44684289AD7F668D5E4973435D89584779463066347BB680
C7DF87DAF2A4D0E8AEBDD3A586976DBECE9DCAD59397A04FA1A64CE9EC93E5E899CED891
D0E4A5C8E5ABC4ECAEB8ECBB418166002413BED9CA09150000080097A778C8E1A7D2EAAC
DFEDB0AAB678B8C889C7E09CCAEFA2C6E999C7DE90DFEDA2A7B26EC4CF8D96A15FB2BE7C
C3D28FD9EAA6D1E6A1CFE6A0D6F0A9CDE8A1BFDA93D7F5ADC6E49CCAE8A0C2E098D8F6AC
CFEFA3CAEB9CD9FAA9D3F2A2C7E396D7F1A8D8ECADC4D5A1E8F4CEFEFFEAFDFFF1C9C9C1
D4D0CDFFFEFBFFFAF8FFFDFBFFFBFFF2E7EBFFF7FBFFFCFFFFF9FDF7F2F6FFFEFFFAFAFA
FFFFFDFEFFFBFCFFF8FBFFF6F9FFF4DEEBD9F5FFEEF6FFEAE6EFD2FFFFE3F6F7D5060400
716C426D69398C8B55E4E8ABE0EDA8D1E59DACC478D8F3A6C7E197C4DE94DAF1A9CEE9A6
C1E8B1BDE5B3E7FFDA8BA67B37522959734C243C1A041700000700030B00000500000600
112B2200110C000805000D0A0001000300000301002E2C1F8382707A7964EAEDD0FEFFE3
F2FDD3F1FFD1C7E0A6D5F4B1C0E49AD3FCADB8E592CCF3B4E2F5E2F9FFFFEFF3F4E5E6E1
FFFEF8FFFEF3665D4C332B146C674A6764430606000305002E30086F7149B5B790D5DDB8
C8D9B9C6DEBED2E8C4BCCEA89AAA8366734878815461673B04050047431E362F12736852
827565B8AAA1988682AE9F98ABA492AEAC9583816A8F8D76999780918F7AADAC974D4C37
75776285887370755F39412A0E170200050035412B59634A7178596C774C99AD70CBE79D
D0F0A4D1EEABD2E8B7F1FFDBFFFFE8FFFFE78A87660106002737089BB585B9DCB293BD95
012B0535623B14421B03360D164B211750250F4C22579669
D7EA9BD0E49DD3E5B18D9F756F815BCCDDB1DCE7AD9AA15B9B9E4DDBDF8AD9DD90D7E29D
DDF5B9BEE3ADB5E5B5BBF3CC437D673F6F615F766600060062704CCCDEACDAF2B6C9DF9F
D6E0A3707A3BD3E6A4C6E19AC9F2A3C4EB98CFE895D4E295BBC681A7B06FC2CD8BCFDB99
D8E9A5DFF3AEC7DE98CCE69FC4DF98D0EBA4D0EEA6C3E199C4E29ACEECA4D0EEA6C6E49A
C3E397CFF2A2C6E796C1E090CDE99CCAE49BC2D697E0F1BDE7F1CEFBFFE9FAFBEDEDEAE3
B5B0ACFDF8F5FFF7F4FFFCFAFCF0F0FFFBFDFFFBFDF8EEEFFFFCFDFFFEFBFDF9F6FFFFFA
FFFFF6F9FFF1F5FEEBF9FFEDF3FFE7EBFCDCDDEECCCFDFBBDAE8C4CCD6B1D6DBB3080900
7372445A5A28979A61DDE6A7D0DF9ACDE59BDAF6A9CEEF9ECAE999CBEA9AD2EF9FBDDD92
C9F3B3B9E5AAC3EAB1D0F1BCC7E3B2D3EDBEC7D9B1D2E2BE757F66B8C1AEA8B4A8A8B7B2
7F9394CFE6ECD7EDF8F1FFFFEAF7EDE5F1DDCFDBC5D9E6CCCEDBBDCAD8B4E0F1C7BCD2A1
D1EAB1C1DF9FC8ECA4BEE798C6F39EC1F297B3E98BDFFFC2F4FFEDEAF4ECFBFFF8FCFFF4
F5F6E6EFEEDAB3AF96A9A4875F5A3C555030FFFBD87673505A5736060300060300050500
091200000600000600000500060800040200615B43766F55F5EBD2FFFEE6FFF6E0B4A794
6A5E4E5A4E407B71659F9886CECEB2D5D9B8DDE1C0E4E8C7F2F5D6FFFFE4C0C3A6686B4E
55553BEBEBD1FFFFE8EBEED3C9CBB3ABAD956E6E563C3B260302000004002F3E1796AC7D
BCD7A2C8E4B1C5DCB0EBFBD7EAEFD1FFFFE4828162070C00637140C3DCA5D1F4BAB6DFA7
BDE8BBBAE7C0B8E5BEC8F6CFB2E2BABEF3C9B7EEC4B4EDC2
C8D198EBF6BCADBF85465921B1C592BFD1A1D8E5B7636D39979D5FDCE69DD8E794C4DD8A
CEF4ABB2E3ABB8F2CC87C3AA3D70616288792538252F3C209BAC82C7DBA6D3E9ABCCDF9D
DBE1A1646A2ADBEFAAC1E196C3F09DC5F19ACAE691D8E999B2BD78CFDA98DDE9A7D1E09D
CADE99D7ECA7CEE8A1CAE59EC6E19AD1EFA7CEECA4BCDA92D4EFA8C2DD96C8E39CD6F2A8
CBEB9FCBEC9DBDDC8CC8E797D8F4A7C8E29BCFE3A6DAEAB9EBF5D3FDFFECFFFFF4F4F1EA
D4CFCBF9F1EFFCF2F0FFFDF8FFF4F2FFFCFAFFFCFAEDE3E1D0C9C3FAF6EDFFFDF1FBFDEF
FFFFEFFCFFECFBFFE8F9FFE4F6FFDFE3F6C9D5E8BACFE2B5D2E2BDCFDAB8E4EBC9010500
6B6D4652552A9BA171D1DEA8CFE3A6CBE5A4C8E9A2C8EEA3C9EDA3C6EB9EC7E99DC7E99D
C5EBA0C3ECA0C6EAA0C9E8A2CFE6A2D3E3A4D7E1A5D8DFABFFFFD7FEFFDEFDFFE5FBFFEC
F8FFF3F6FFFAF3FFFEF0FFF5E9FFD9DBFAC1CCE9AFC5E2A8C9E5AACDE9ACCAE8A8C7E6A3
C8E9A4C8ECA4C4ECA3C0EA9EBDE99ABFEE9EC9F8A8D6FDBCEBFFDDF9FFEFF9FFECFBFFEA
FCFFE6E5ECCAD2D6B1DFE1BAA3A17B514D289E9A77F1ECCCC4BFA1837E618B876C696750
62644F0102000605004643347E74688D8077FCEBE3F8E7DDFFFCEFE6D6C6A196827B745A
8380619C9E79BCC199DBE2B6D6E4B3CEDFABCFDDAADEECB9F6FFD2FAFFD4D8E1B4B3BA90
6F744CA0A07AA7A481E9E5C2E0DBBBFAF4D4E9E0C1C4BDA18E897571746149553F293B23
556E50D0EBC8CEE7C0CCDEB8DAE1C0EDF0D38A8A7201040068744EC1D9A5CEF3AEC0E9A5
CBEEB8C5E6B7C9EABBC2E3B4CAEFBCB7DCA9CEF4C1BCE2AF
E6EDB7D4DDA45B692BE9FCBCC4D89BDCEFB8E3F3C4596938B1C087D0E49FD2EE9AC2E891
BCECA0BCF6B96EB08C3D7B6484AF9E5672630007005C6A49DCEFC1C9E1A7C9DF9ED2E19E
A7A9689FA462D6EAA3C6E89BC0F29DC1F299C9E791D4E595DDEAA4D2DD9BD8E7A4CCDD99
E7FCB78CA35DD0EBA491AF6792B06886A45C85A35B8BA9618FAA63D6F0A9CDE7A0C8E299
BDD98EDAF9ABE6FFB3A2BE71CFE99FABC27EC5D79DCDDAAEF6FDDEEDF0DDFFFFF6FFFFFA
EFE7E58F8785C3B9B7FFFDF8FFFCF8FBF0EABAAFABB2A9A2CAC3B9C3BFB3DFDECCF8FBE6
FFFFEAE5EFCDCCD8B2C7D7AACEE0AED1E6AECEE3AAC9DEA6C8D9AFC7D5B1D6E0BB000600
787D55787E52B4BC8DD6E4AFCDE2A9C7E5A5C3E8A2C2EAA1C3ECA0C3EC9EC5EC9DC8ED9F
C5EC9DC5EC9DC3ED9BC6EB9BCDE899D4E499D8E29BDAE19DD6E2A0D4E2A5D4E1ACD4E0B2
D4DEB9D1DFBCCCE1C2C8E5B9D4F7B3CBF2A1C3E898C1E696C7EA9ACBEE9ECAEC9FC7E99C
C6E89CC9EB9FC8ECA4C6EAA2C3E7A1C3E8A2C9EEA9D1F0B5D9EBC1F6FFE1F3FFDDDEEFC5
DAEBBED2E2B3CCD8A6D7E1AFCFD2A3E5E4B8ADAA8168643F989375ACA88BBCBB9FE1E0C4
FFFBDE9A95788D856EBDB2A0BAAC9FB3A29AAB989297847D8271678A7F6D959073AFB088
CED6A3D9E7AAD4E8A3D5EBA3CCE5A1CEE7A5D1E7A7D1E7A7D5E9AAD9EBAFD4E3A8CCD79F
B1BA85969A67A4A3737B7748BEB78BD4CBA0FAECC5CFC5A1DCD7B9DFE1C98E97863A4B3B
000A001D3A1E5D7752D4E8C3D7E2C2FFFFEC8B8B7F000200363F2A95AA83B5D79ACBF0AA
BEE1A1C5E4A8CAE9ADCDEDAED2F0B2CBE9ABD0EEB0CBE9AB
D5DF9A89944FA9B46FD1E09BC6D695D4E6A8869A5F96AE72D5F2B0BBDD93BFEA9ACDFEAD
A8E298ACEDAD4488574E8A667DA08A526551111E04C6D5AED3EAB4C8E2A3CCE39DE0EDA8
636221DBDC9ACEE29BC8ED9FBCF09BBDEF98CAEA95D0E394D1E19AD0DF9CCCDD99E0F4AF
C4DB9594AE67DAF8B0B7D78ECBEBA2C2E299D2F0A8CBE69F7C964FD8EFA9CFE49FD2E9A1
CFE99FCEEA9DB7D28590A85CC2D890879A5ABCCA95FBFFDCF9FFE3FAFDECFFFFF8FFFEFB
FFFCFD978F8DC6BCBAFEF5F0FFFCF6FFFDF4AFA49EFFFCF3FFFFF1F9F6E5DAD9C4FFFFE8
FAFFDFE9F4CCDAE7B9D3E4AED1E5AAD1E7A6D3EAA6D6ECACD5E8B1D4E4B5D8E4B4000800
6066365D643198A16CCDDCA1CDE6A5C9E8A2C4EA9DC0EB9BC0EC97C3ED97C7EF97C7EE9B
C3ECA0C1EDA2BCEFA0BFEE9EC6EB9BCDE897D3E695D3E695CCE894C9E994CBE898CEE69C
CFE49FCCE5A1C5E9A3C2EB9DC5EC93C6EB8CC6E98BC7EA8CCAEB90CCED94CDEB95CDE995
C9E495CDE79DD2E9A3D1E7A6CEE4A4CBE0A5CCE1A8CFE1ADCFDCB0FBFFDCF5FFD7CEE2AD
C1DAA0C9E3A6CEE4A6D4E6A8D8E3A9D8DDA7D5D4A4DCDBAFD7D7B15C5D3B2B2F0E6F714C
4A48185A5424675E35615734605238584936675748DFD2C2FFF8E3FDFADBEAF0C2DEE9AD
DAEFA4D1EE94C4E783C3E785C8EA94CDEE9FCEEDA1C8E499C1DD92C5DF96D0E69ED7EBA6
E3F2AFD3DD9ED7DBA09D9C63A49F68D5CE98E9DDA9E5DBA8D9D5A6EAECC4CDD8BACFE1CB
5A735D001900000D005D734FD6E3C9EFF3E5D8D5DC6C6A75000306000600D1EDC4C3E7AA
CDF1A7CDF2A2C4E999BCE191BBDE8EC4E594BCDD8CCDEC9C
6A77278F9C4DCEDA92D3DE9AE8F4B2A8B877738A46C7E59FC2E7A1BCEAA2BEF3ADB0E8A7
64A0626EAB705E9D6690C4962F482B0A1600565F40E2F2C5BAD399C8E6A0D8EEA6CBD78F
474303EAE9A8CCE099C5EB9EB6ED99B8EE98CFEE9ECEE396D1E29CDBECA8D7EBA6C8DF99
86A059CCE7A0C0E097D6F6ADC9E9A0B9D990C9E79FD2EDA6A2B973CDE29DD3E7A2D9EDA6
D4EAA1C1D98D2C4200C2D88FCBDF9AC9D99BCDD9A7E5EDC8FAFEE7FFFFF4FBF7F4FFFCFC
FFFCFFEAE1E2D9CFCEFFF7F5F4EBE6FFFDF6C1B8B1FFFEF4FFFDF1FFFFEFD4D6C0FBFFE2
DAE0BCD8E1B6D8E4B2D9E8AFD3E6A6CCE19CCAE097CDE39BCFE1A3D3E2A9E6EFB8282F00
7F824B6B6E37979F64D9E7A9D0E7A3CDEBA1C8ED9DC2EC96C2ED94C5F094C8EF92C6EC95
C6EAA4C3EAA9BCEEA7BEEEA4C6EAA0CDE89BD3E599D1E795CBED96C8EF94CBEE94CEEC94
D3E996D1EA96C8EF96C5F096C7EC8FCBED8FCEED90CEED90CDEC8FCDEA90CFE992CFE894
CCE393CFE698D3E79FD5E6A2D3E1A3D1DFA2D0DDA5D0DDA8D1DAADFCFFDAF8FFD8D2EBB2
C5E3A3CAEBA6CCEAA4D1EBA4DCEDA9D0DA9BDEE3A9D7DCA6DEE4B4D9E0B4C5D0A68C9664
EBECB0C1BD7ED4CF97D2CC9CE1D9B2D6D0B0EDE6CAFFFFE5FFFFE3FEFFDBE6F3BDCCE29A
C7E38CC6EA86C7EF7FCCF68ACCEF93CBED99C8EA96C8E895C9E898CBEA9ACEE99CCFE79B
C8DE93DCEDA6CAD590AEB572595B1A707030524E0F585417A5A066D2D29EE6EEC5C8D9B7
BDD6B6DDFBD966815E000E00000700565654FFFBFFF0E8FFD1D0E0646E6F6F856ED8F5C7
C4EAA1C4EE98C9F39DC5ED97CEF49FD1F7A0C1E58ECDF19A
D8ED92E3F5A1DAE5A0DBE3A7D2DA9F707C3EACC37BC2E498BEECA4E0FFD8DAFFE590CDA4
51896276AB7FB2E3AC97BC88000D00080F00C9D1AAD5E6B2CAE7A5C6E49AD2E89DE6F0A7
6A6221DCD898D4E8A1C1EA9EB2EC98B6ED9AD1F1A5CEE29AD8ECA5CBDF9AD6EDA7829C55
97B26BDAFAB1B5D78DC8EAA0D8FAB0D0F0A7D6F4ACD4EEA7C6DB9680914DA7B673C9D895
D1E29C84954EE5F6B0C5D690DCEBAADBE6AE9EA77AA0A684FFFFEDFFFFF6F8F4F3FFFDFF
FFFCFFFAF1F4BBB3B1FFFDFBFFFDFAE7DFDCFFF8F2FFFBF3FFFFF4F9F7E8DADCC7F0F4D9
EAF0CED9E2B7CBD7A5CEDDA4D7EAA8DCF0A9D8EDA2D4E99ED7E49FCDD896CDD2920A0C00
6D6B306B692E9A9C5DD3DC9BD0E19BCEE99CCBEC9BC7EB94C5EC91C9F191CCF090C9EA93
CFE5A7CCE4B0C3E9AEC2EAABCAE7A7D1E4A4D7E1A2D4E39EC6E798C3E994C7E794CDE492
D5E091D3E291C9E791C5E992CEEA9DD0EAA0D1EC9FCFEA9BCCE796CDE695CFE895D1EA97
CEE593CFE696D1E697D1E699D2E39CD2E39DD4E39ED7E2A6D4DBAFFDFFDEF8FFDADEF9C2
D2F5B5CBF0AAC2E69CC7E79BC3DB8FD2E49AE3F0ABD6E19FDBE9ACCCDEA2CFE4ABCEE0A2
CFD990E3E79DDADD9ADBDFA2F6F9C4D3D6A9DBE0B7EEF5CCF1FCD1F8FFD7ECFFC4D5EFA6
CEEE99CBF090C3EC84C4EA85CCED94CBE896CBE896CCEC99D0F09DCFEF9CCBEA9AC7E696
D2EF9FD8F0A4D7EDA2DAEBA4D3E39CC6D38DD4DE99C3C885878343585417CED69DD2E0AD
D3EABCF1FFE3EDFFE3E9FBE30002000100050600103A2D47B0ABBF9DA0A90005005A7154
D2F6B9C8F2A6C6F0A4BAE498C4EDA1C4ED9FC4ED9FC8F1A3
D0E996C1D88AD7E3A1C2CA8EC2C78DC5CF93D2E6A7CBEDB0BAEBB4A0DBAF8BCAAD639E88
78A9939BC4A69FBE92283B0E000600737454E2E9BDA3B47D8EAC66B3D4857E9344B2BA6F
ABA25FD5D090DCF0ABC2ECA0B2ED9DB7F09FCDEDA2CFE39CC9DD98CBE09BC7E19A8AA55E
C2E299CBEDA3C3E79DD0F4AAB6D88EC5E59CCDEBA3C7E19ACBDF9A4D5C1994A05EDEEAA8
E1EEA9B6C37ED4E19CDDE9A7D3DFA1E2EBB6C2C99F797C5DFFFFF1FBF8F1FFFDFFFFF9FD
FFFCFFFDF4F7BBB2B3FFFDFBFFFCFDBFB6B7FFFDFBFFFEFAFFFFF8F5F3E7ADAE9CCDD1B8
FFFFE4F2FAD1DFEBB9D5E2AACEDE9DC9DD96CCE196D5E59CE0E9A8E4E8ADE8E6AD0A0500
695F2A69622EA8A570DEE1AAD5E0A4D5E8A6D1EBA4C8E79BC8E797CEEE99D0EE98CDE695
D3E3A5CFE4ABC3EAA9C2EBA7CAE7A7D1E3A5D6E2A4D1E5A0C8EEA1C5F0A0CBEE9ED2EA9C
DBE69ADAE798CFEC98CBEE9CCCE7A0CDE6A4CDE6A2CBE59EC9E59ACAE699CCE999CFEC9A
CCE997CBE896CCE796CBE697CCE79ACFE79DD1E99FD5E7A9DAE0BAFCFFE1F8FFDFE5FFCD
D9FFC1CAF3ADBDE69AC3E898CFEF9CD4ED9CD1E495BCCE82D5E9A1D7EEA6D2F0AAC8E49A
DCEFA0D5E293C4D088ECF8B6B5C388C7D69FE4F4C3CBDDADE6FAC9EEFFD1DEF7BDC1DE9C
BEDE93C6E997CAEE97CCEE98CBE695CEE698D1E99BD0EB9CCBE898C6E595C8E99ACEF1A1
C6E798BEDF90BCDB8DC8E497DEF8AEC3DB8FE2F8AFCCD993C1BC7C554B0EE6E8A9D4E0A2
CDE2A9F4FFDDF1FFE6F0FCEE8C8C8E4C445108000E18091E2D253428272F0C1212000600
E0F9D1DDFBC5CDEBB5D3F2B9BDDCA3BCDBA2CCEBB2C4E3A8
BCD89EDFF7BB8F9E5D9EA764939858DDE5ACCBDCB0E3FFE2B9E6D1437C6D76B4A783BDAF
BBE7D6C9E6D264715D0103006B674AE2E0BAB0B6869DAC7195B56AD8F9A88CA2507A8134
DBD08EE0DB9BD5E9A4C3EDA3B3F0A2BBF6A6C3E49DD1E6A1D0E5A0DFF6B0CBE69FBAD890
CBEDA3BCE096C4E89EC9EDA3D6F8AECFEFA6C4DF98CFE6A0DAEBA78692509EA967D3DC9B
B6BF7E9DA866CDD896CED899D2DCA0CFD6A2F9FED6EDEDD1F7F5E8FFFBF7FFFDFFF7F0F7
FFFBFFFFFCFFDBD2D5FEF5F6FFFCFFC9C3C7FFF9FBFFFDFCFCF8F5FFFFF8A7A89AEFF3DC
F1F6D8E8F0C9D4E0B0B8C58F9AA86A8B9C5897A861ADB9778D8F5EA19C74D9CCA9170800
7F6E505F4E30A49679E9E3C3EEF0CBEAF5CBDFF1C1CFE6B0CAE2A8CFE7A9D2E8A8CDE29D
D3E49DCDE899BFEF99BCF09BC5EC9BCCE89DD0E69ECAE89EBEEF9EBAF19EBFEE9EC8EA9E
D4E49DD3E49DC8EA9DC3EC9EC7E8A3C8E5A3C7E6A2C7E6A0C7E99FC6EB9EC5EA9CC4EB9A
C5EC9BC4EB9AC1EB99C2EB9CC3EC9EC6ECA1C6ECA3CBE7ADDAE1C2FFFFECF9FFE6DCF7CC
CFF6BDC5F2AFBEEA9DC5EF9DCCEE98C5E18CDFF5A2D7ED9AC8E18EBAD785CDF09EC7EA9A
C2DA8EE0F4ACC9DE99DBF0AFC5DA9FD7EEB6C5DDA9D0EBB8E3FFCEF1FFDCE7FFD2CEEAB7
CBE8B2D2EFB7CEEBB1CAE4A7D0E3A1D2E19CD1E59DD2E89FCBE59BC5E498C7E99CCDF2A4
C8EFA0CAF3A4CAF1A2D7FEAFC3E99CC6EB9DC7E99DCCE09B9E945F5D4C18F0ECADD6DF9C
C7DA9AF6FFD9F8FFEDFAFFFCFCF6FFFCEFFFFFF8FFB2A1A7443838040000050503000200
0004003235223D422E9FA48E80856FA9B199CFD9C0C9D3BA
CAE7BBA5BD8B92A2638C9651DBDE9BC9CE96D4E4C0EDFFF88BB8B31E5655B7F5F2B5EEE5
BAE2D7C7DDD033362D090100ACA589DBD7B1979B69B5C587CFEFA3B4D682DAF09E9BA255
EBE09EEEE9A9C8DB99C1ECA4B4F1A3BFF9ACBDDE97D4E9A6D4EBA5C2DC95C9E49DAECE85
CCEEA4C6EAA0D3F9AEB8DE93C1E399C9E9A0CCE7A0DEF5AFBECF8BA0AC6A9BA463D3D999
949D5CA2AB6AE1EAA9DAE3A4DDE5AAD6DDAAF3F5CEFEFEE4E5E1D5FFFBF8FFFAFEFFFCFF
FFFAFFFCF3F8DDD4D7FFFBFED6CFD6C5BEC5FFFDFFECE8E9FFFEFDFFFFF8B6B6AAFFFFED
FFFFE8ECF4CFC2CEA09FAC768B995C8A99569AAB64AFBB7B9E9B727D7254A7977E0F0000
88715F57422FAF9E8CFFFEEAFFFFE8FEFFE6F0FCD8D7E8BECDE0B2D0E4B1D2E3AFCCDEA0
D3E697CCEA90BCF292BAF394C2EE95C8EB99CDE89BC8EA9DB9F09FB4F29FBBEE9FC4EA9F
D0E49FD0E49FC4EA9DC1EB9FC8EBA7CAE9A6C9E9A6C8ECA4C9EDA5C4ED9FC1EA9CBCE797
C0ED9AC0ED9ABEED9DBFEE9EC0EEA3BFEDA2BDEBA3C2E3AAD5DBC1FFFFEEF6FFE9CCE7BE
BCE3AEBBEAA6BDEBA0C6F29DC7EB94CAE890D2EA92C5DD85D7F39CD0F399C3E992A3C974
8EAA60879E588BA462859F5EA9C386CFECB2C3E0AAC8E6B2DAFAC9E9FFD8DFFCD0C4E1B5
C3DEB3CDE8BDCAE3B9C5DBAAD9E7ACD2DE9CCEDD98D3E7A0D5EFA6D0EEA4C8EA9EC4EA9D
C1EA9CB9E495CDF9AABEEA9BB7E293CEF9AAC5EEA0D2E9A5A399686F5A2BDBD696DCE39D
D5E4A1F8FFD8F8FFEEFCFFFFFFFBFFFFF9FFFFF1FAFFEFEDB4A79F867F756E6D69000000
09010033292706000060585504000034312A69665D6E6E64
pop
P
% End of image
1 0 0 r
.03 w
.62821 .03859 Mdot
.62982 .07974 Mdot
.64678 .14871 Mdot
.64961 .20204 Mdot
.66172 .22812 Mdot
.65849 .26232 Mdot
.66495 .31622 Mdot
.66616 .36491 Mdot
.63992 .38288 Mdot
.61407 .41939 Mdot
.60802 .45475 Mdot
.60357 .50459 Mdot
.59631 .53531 Mdot
.59348 .57241 Mdot
.56521 .54574 Mdot
.52241 .56835 Mdot
.49495 .59037 Mdot
.44771 .61646 Mdot
.40935 .62979 Mdot
.37785 .62689 Mdot
.34595 .67094 Mdot
.33505 .62109 Mdot
.3621 .56835 Mdot
.31971 .57125 Mdot
.28215 .57473 Mdot
.27327 .62399 Mdot
.22683 .65645 Mdot
.21795 .68369 Mdot
.23895 .71441 Mdot
.23249 .74049 Mdot
.22239 .7602 Mdot
.18807 .77063 Mdot
.14527 .78164 Mdot
.13477 .82048 Mdot
.13598 .85757 Mdot
.16384 .85757 Mdot
.14527 .90974 Mdot
.14123 .9335 Mdot
.15819 .94277 Mdot
.18847 .96886 Mdot
.16223 .99088 Mdot
.13194 .97639 Mdot
.09035 .9022 Mdot
.07662 .85873 Mdot
.08429 .7944 Mdot
.08227 .74397 Mdot
.096 .69412 Mdot
.08954 .59211 Mdot
.12185 .40316 Mdot
.11094 .35563 Mdot
.06531 .27159 Mdot
.06168 .18523 Mdot
.08349 .13422 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.34127 0.984127 0.65873 1.30159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
B6B48DAEA981B6A77EB4AA799EA36990A45F91A86090A45C9D9B5E938A51EDEAB7CBD1A1
E4F7C9C6DDB3E3F0D2EBEAD6FFF7F3C2AFA99A9180A2A685BACB97CEE4A49CB26AA9BB71
8F9B5199A158B6B97281893ED5E396CBE490CBEE94C6ED94D4F4A8C0D995CCDEA279834E
030700888A59DEE0AF959D64DFEBADC7DB94C9E495CDEA98C3E292CDEC9CD5F1A6CCE89D
CEE8A1DAF2A88192429EAF5FCCE299C4E2A292BA884F8053A1D1A7BBE9B885A96B89A45D
ABC178DEF2AACEE3A2E4FABCF3FFC8EEFFC2839857AAC07FD9EFAFD0DDA892886564553E
FFFDEEFBFFF4EAFBE8D6E0C7EBDDC08A8253CBE199D3F6A4CBEBA0CBE99F8EAA60CBE59B
CFE6A0DAEDADE3F1BCBBC69CFFFFE8FFFFF1FAF9F4F7F6F4FFFFFFFFFFFFFCFCFCFFFFFB
FFFFF6FFFFF6FFFDFDFFFBFFFFF7FFFFFBFFFFFCFFFAF4F6FFFCF9FDF9F0FFFFF6FFFFF6
FFFEFBFFFDFFFDF5FFFFFCFFFFFEFAAAA899ADAF97CDD5B0DAE6B8C7D69FD0E0A2D9E9AA
D2DDA1DCE7ABD6E2A4CFDE9DD4E8A3D4ECA2CEE99ACAE699C4DB95E3F8BDF2FFD4E7F7D3
FBFFF1F5FCF4F7F9F8FFFEFFFFFEFFFFFEFFFFFEFBFEF9F3FFF7F2FFFDF6FCF3EEB6AEAB
DAD9D5F8F8F6FFFFFFFFFFFFFFFDFFFFFEFFFDF6FDFFFCFFFFFBFFBCB3B63C3336968E8C
FFFDFBFFFBF8FDF6F0FFFFF3C2C5AAB9BF9BD3D5B0B4B68EFFFFDACCCDA1DEDCB3C1BF98
8885647F7E60D9D7C2F7F8E6FFFFF4FCFFF6F6FBF4F8FFEDDDF5C1D2EBA9D1D99DDCDDA3
C8C68DD7DB9EC1D492D5F1A7D5F1A6C4DC90BBC5809B9E5B7373358D9355C8D899D2EAAC
D3EAB4C7E0A9C6DFA6CEE8ABCEE6AAC7DFA3D0E7AFE2F9C3
9CA2768B8C607870426F6C39929E60C8DF99C2DE9492A8609C9C5E716A33A29E6ED2D5A8
C9DAB0CEE2BDFBFFEAFFFFF1FFFAF6FFEDE9BAB3A1C7CDABD2E3AFCEE7A6DDF4ACC6DB90
E3EFA7D7DE98959B555D641ED0DE93D0E797C1E38CCEF19DBADA91DFF8B7D5E6AFD4DEAA
A9AC7F303105CFD1A2E4EBB78E9A5CCFE39CC9E497D6F3A3CAE999CDEC9EB9D58ACEEAA0
CCE69DD0E89ED5E897879A49D7EDA4D4F1B1B0D8A688B58A427248C7F5C4C4EBAC90B067
425A10C4DA91C5DA99D8ECAFCCE0A1CFE4A3BDD28FD4EAA9D3ECABCEDBA6B2A885FFF8E3
FFFFF1EBF3E4F5FFF3E2ECD3FFFFDF736B3CD1E79FC4E795CDEDA2CCE89E8BA75CCAE49A
CFE49FD2E5A5D0DDA89FA77EDDE1C6FBFCECFFFFFAFFFFFDFFFEFFFEFEFEF6F5F3FFFFFA
FDF9EEFCF8EDFFF8F6FFFDFFFEF4FDFFFBFFFFFBFFFFFDFFFFFEF8FFFFF4FDF7E9F6F2E6
FFFDF7FFFDFDFFF5FDDCD5DC73706BFFFFF3F9FBE5E6EDCBFEFFDAD6E3ADE0EEB3CFDDA0
E3EEB27B864A576528546425BED28DD9F1A7D4EFA2CEE99CC8DF97CFE5A5D8EAB8D9E7C3
FBFFEFFCFFF8FEFFFDF7F7F9FFFDFEFFFCFBFBF6F3FFFEF8FFFEF8A099938D847FFAF5F1
F9F5F2FFFFFDFDFCFAFFFDFEF5F1F2FFFDFFFEF8FCFFFCFFFFFCFF766D70887F80FFFDFB
F8F0EDFFFBF5FFFEF8757366E7EBD0D1D7B3A1A67EFFFFD9FFFFD8E5E6BAE3E4B893916A
CBC8A7787759EEEED6F3F4E2FEFFF3FCFFF4FBFFF4F6FFE9DEFAC0DCF5B1C5CF9266652C
DBD8A1E0E4A9D9ECAAC3DE97BDDC90577127BECB85E2E7A5D2D495F3F9BDCBDA9FD1E6AD
CDE4B0D0E8B6D4EDB6D3ECB3CEE6AACBE3A9D1E8B0D8EFB9
D8ECB7DAE8B3DEE2AFD2DAA1C4DB97CFEFA6D6F8ACCEE8A1D5D99CDBD4A05E5A2DE6E6C0
EEFCD9D0DEC4FFFFF1FFFAF1FFFAFAFFFAF5FFFFEDE2ECC9CBDFAACEE8A7D5EFA8D3E9A0
D7E49ECBD28EA3A866ABB26FDEEBA5D7ECA1D8F7A7BFDF93DCF9B7BAD199D1E1B0D5DEB3
B2B48F2A280281825AC9CF9F929D63849755CEE89EB3CF82D6F5A7C7E698CFEBA0CEE89F
CBE59CCDE599D2E895DFF5A240560BB8D593BADFACC5EEC4426F4672A06FC3EDADC2E89D
92B165DFF7ADD2E4A6D0E2A6DCF0B1A4BA79BBD08DCCE2A1CDE6A5CDDBA6837A59FFFDE8
FFFFF1F5FFF0F3FFF1FBFFECFFF9D9A79F6ED6EEA4C7ED98CAE99DC8E49A8AA45ACEE69C
D5E9A4D7E7A8CED8A3949B71F8FBDEFFFFEFF8F5EEF9F5F4F9F5F6FFFEFFFFFEFDFFFFFA
FFFFF1FFFFF1FFFCF7FFFCFFF6EAF4FFF8FFFEF3F9FFFAF8FBF3E8FFFFEDFFFFEAFFFFEC
F7EFE2DFD8D0D9CFD0B4AEB0F9F8F4FFFFF6FFFFEFFFFFE6FFFFDDC5CD9CD3DDA8D2DDA3
949F657F8D52B0BF848D9F6193A8657F964E8BA55BCAE598DCF4AAC7DE9AC8DBA4CCDBB0
F2FCE1FCFFF3FFFFFAF7F6F4FFFEFDF8F3F0FFFEFAFAF5EFB3AEA8CAC5C1FFFDFAFCF7F3
FFFEFBFAF6F3FBF7F4FEFAF9FFFDFDFFF8FBFFFCFFFFF9FDFFFBFF6A6061E6DDDEFFFDFB
FFFEFABDBAB377746BFFFFF1FEFFE8FCFFE1B4BC93E5ECC0C9CF9F989C6A727445DDDEB4
C9C9A5A6A788FAFCE4FFFFEDFCFFEDF5FFE9E5F3D9D6EBC4BFDFA0BEDC94CAD49746450D
D5D29DCED19AD4E6A88AA56090B065CBEA9EC3D48DD4DF9BDCE2A6BFC78ED4E5AFD7EBBA
CCE1B6DEF3C8EAFFD1EAFFCDEAFFC9F1FFD0F5FFD6F5FFD8
C6DFA5C2D79CD4DFA5E1EDAFD1EAA6C4E69CC5EA9DCFE9A2ECEFB6E3DBAC554D26D8D7B8
FBFFEAFBFFF1F2EFE6FFFCFAFFF9F9FFF8F0FFFFECE9F5CFC8E1AACEEBA9CAE8A2D0E79F
CFDE9BCED496B5B87FE7EAB3D8E1A8C7D69BDDF6B5BBD898CDE6AFD9ECBECFDBB3FFFFE3
A8A7896764459C9C78D2D5AAD9E3AEA9BC7CA8BF77D4F0A3CCE89BCFEBA0D0EAA1CBE59C
D2ECA2C9E193D7EF9BC8E08CBCD486849E5DCFEFBEBBE0B7709A721D4B1AC1EFAEC8F2A6
B1D386556F2591A365D9E8ADBED29391A864CCE19ED7EDACD0E9A8D3E1AC786F4EFFFDEA
FEFCEFF8FFF5EFFFEED4DEC5E9DCBCA09867D5EDA3C2E893C9E89CC9E39A8DA55BD0E69D
D8E9A3DAE8AAD1DAA5989D74D8D8BCFFFEECFFFEF8FFFEFBFDF7F9FFFEFFFFF9F9FFFBF5
C3BDADA29C8CA19A92F1E8E9DFD5DDD4CAD3D0C7CAFFFDF7FFFFEDECE8CDAFAC8DBCB99A
D0CCB3D7D1C1FFFCF6FFF9F9F9F9F7F8FBF4FEFFF2F3F7DEF5F9D6DCE2B6E1E8B5D6DFAA
939D68ABB882C3D49DCEE2A5CDE3A3D3EAA497B16887A255839B4D99B167D3E7AAD9E9BA
CFD9B7D0D5C1FBFBF1FFFEF9FDF8F4FFFEFACFCAC4A6A19BDCD7D3FFFEFBFEF9F6FFFEFB
F2EDE9FFFEFAF2EDE9C6BEBCBEB6B4FFFCFDFBF1F20700007B7172FAF0EFDDD5D3E0DBD7
737069E7E7DDFFFFF4E8EDD9F9FFE4C5D1A9E2EEC0D8E2AE6C753EBEC58FE0E4B1939667
9D9F78FEFFE1F4F9DBFCFFE8ECFAD9E4F4D0CDDFB7C0DBA6CBF0AAC5E59AA2AE705A5923
C0BD8A8D8D59839559CCE9A7CAEEA4BEE094E3F9B171803D697239E1EBB7CCDCADD2E4BA
E2F7D0E6FBD4E8FED0E4FAC9E1F8C0E2F9C1E2F9C1E2F9C3
D8F0B4D5E7ABDBE3A8D7E1A2CFE6A0D3F1A7CDEFA5C0D793D5D59FDED2A85C522FF7F3D8
FBFFEEF0F8EBFFFEFDF9EFF0FFF9F6FFFEF1D6DABFDCEDC3D0EBB4BCDC9BDEFDB9C3DC9A
CEDCA1E4EBB8A6A47BE1E1BBF3F7D2DDE7C2DAECC4D5ECC2B8CFA5DEF0CACED9B9FFFFE8
E2E0C9AEAA91B1AD90D4D6B1CDD7A5E6F8BC809751CAE69BCEEA9FBCD88DCBE59CCEE89F
D0EAA0D0EB9AC8E28BD1EB94EFFFB988A160CAE6B6C7E7C09BC49C1E4E1C95C885BDEE9F
D8FFB079954A87975987955A9BB06F98AF6BCCE39FCFE6A2C4DC9ED3E1AE8D8465FFF9E6
F8F6E9F9FFF6F4FFF4C1CDB5E0D5B5938D5BC8E094CDF09CD0ECA1D0E79F91A75ED0E49C
D2E19CD2DE9ECCD39F999B73FFFFE3FFFFEFFFFEF8FCF7F4FFFCFFFDF7F9F0E7E8DDD9D0
C5C2AFE4E2CDD6D2C7CFCAC7B0A9B0DFD8DFC6C0C0A19D92B1AF98B4B492A3A47CD8D9B1
FBFBD9F7F5DEFFFFF3FCFBF6F9FDFCFCFFFDEBEFE1FFFFEDFFFFE4D0D2ABE3E6B9AAB080
939D69D4E2ADD2E5AEDEF3B8CDE3A5D9F0ACD1E8A2C0D88CB4CD7A8DA6558FA4618C9D67
A2AC87CDD3B9FFFFF3FFFFF6E4DFD9B7B2ACBAB5AFE7E2DCF7F4EFF4F0EDF9F5F4FEFAF7
FFFDFAFBF4EE756E68675D5B5F5452796D6D7367677D7171BCB2B1FFFCFAF5EDEAAEA9A3
A0A094F8FAECFEFFF3FAFFEBDDEBC8D0E1B497A87287965B899555D0DA9BF1F9BD6F7640
B0B688FFFFDCF1F9D2F6FFDAD2E3B7D2E8B7CBE4ABCDECA9C3EC9ED2F4A7CEDD9C90905A
817B4BB6B585CBDCA5C2E0A0CBF1A8CDF3A8B3CD865E71316E7843D0DCAEDEEEC7BFD3AE
F2FFDFDFF1CBD1E4B7D2E6B3D1E6ADCADFA4C6DEA2CAE2A6
C9DB9FCED99DE1E2A6E3E8A8D0E19BC6E097CBE9A1D4E9A8E6E3B0EDDFB8BEB093FFFEE8
FBFFF3FBFFFBF7F2F8FFFBFFFFF8F2FFFFEDD2DCBADBF1C3CDEAB0BFE2A2C8E8A7CEE8AB
D8E6B5E4E9C1B7B396FFFCE8FFFFEFFEFFF3F8FFF3ECFEE8F5FFEAEAFBDBFBFFECF0F3DE
FFFFEFE0DBC8FFFCE3E5E6C6D4DBAFCFDEA5A5BB7AA0BA71A9C57BCEEA9FD3EDA4CEE89F
CEE89EC6E190D7F19ACFE992B6CE8091AA68ABC595D0EFC6C4EAC18DBD8B7BB26EC0F5A7
B3DE8EC8E89CD1E1A3DAE5ABD7ECABD5ECA8D6EDA7CEE7A3D3EBADEFFDCAB7AE8FFFF6E5
FFFFF4F9FFF8EEFFF0D8E4CCF5EACAB3AD7BCAE296D2F69FD0EB9ED1E79E93A85DD3E59B
D5E29DD5DFA0D0D4A19D9E76E3DFC4C1BBABA9A29CC5BDBBFFF7F8FFFCFDF6EEECDCD8CF
FFFFEAFDFFE7F4F5E7FFFFFBFBF9FCFFFEFFEDECE8E7E8DAD2D5B6E5EAC1D9E0ADDEE5B2
E0E5BCE5E8C9FFFFEDFEFFF5F5FBF9FBFFFFFEFFF8FCFDEBFDFCE0D7D7B3CCCDA5A1A779
B1BA8BD8E6B3C9DBA7CBE0A7CDE2A7B6CC8BDBF2AED4ECA0D1EB94C1DA86CDE39AB2C188
929D738C9173AEAF9DA9A79BC6C2B9D9D4CEF9F4EEFFFEF8FFFFFAFFFEFDFFFEFFFFFEFD
FFFDF7ACA39C9B928DC4B9B5DDCFCE908281D4C6C5EADCDB968B89B4ABA6D5D0CAFFFDF4
EFF1E3FEFFF1E9F0DEF2FFE5D5E7BFD4E8B5C2D69BDEF1AFE7F7B0D9E69EB9C480AFB879
E3EAB4DAE2B1F1FDCFE2F2C1C8DDA5CCE6A7CBE9A1CBF0A2BCE996C3E89AD3E2A1DADAA4
F8F1C3EFEEC0CBDCA6D4F2B4B4DC95E0FFBFCDEBA55C703174824FD1DEB3CFE0BEEBFEDE
F7FFE4DDEFC7C9DCAECFE3AED5EAAFD0E6A6CEE7A6D6EFAE
E7EFB4D8DCA1DED89EE5E1A4D7E29ECEE29BD2E9A3DAE8AAE0DAAAFFFEDABBAB92FFFBE9
FCFFF8F3F9F7FAF4FEFFFBFFFFFEF3FFFFE8CAD6B0C0D8A6B6D59AD3F7B7BAD99DE7FFC9
FBFFDFFAFDE0DAD4C6FFFEF8F6F2F3F6F5FAF9FFFFF7FFFFF1FFEFF7FFEDFBFFF1FDFFF1
F8F4E9B4AC9FFFFFECD3D4B5D9E0B6D9E8B1D0E6A6CBE59E7C984EDDF9AFC5DF98CDE49C
C6E096DFFAA9C7E48AC5E288DBF4A3DEF7B5768E5EC4E0B8BDE3BAB9E9B5548B47C2F8AA
B8E796CFF1A5C9D99BD7E2A8CADF9ED1EAA6D1E8A2C9E29EC4DC9ED9E7B4B6AD8EFFFDEC
FFFFF4E0EADFEEFFF0CDD9C1E1D6B6A49E6CD7EFA3BEE28BCCE79ACEE29A93A55BD6E69D
DCE7A3D9E2A3CCD09D91926AE0DCC1DFD8C8D5CCC5FFFCFBFFFBFDFFF9FAD2C8C7D9D5CA
FCFFE5FCFFE6FDFFF0FEFFFAFEFFFFFEFFFFFEFFFAF4F9E5FEFFE1EFF9C7D3DEA4C8D399
D5DFADECF4CDFCFFE8F8FEF0F9FFFFF0F9F8FEFFFAFDFEEEFFFEE59C9978585931DBDEB3
D3DCAFD8E6B5C3D7A4D3EAB2E1F9BFCDE3A3D1E7A6C8E094DAF49BCBE58CD6ECA1CCDC9E
CFDBADDDE2C2FFFFEDFFFFF1F6F2E7FFFEF6FFFFF6FFFEF8FFFFFAFFFBFAF4F2F5FFFCFD
FFFBF6080000F7ECE690837D5244418B7C79D3C4C1F7E9E6FFFCF8FFF6F1FFFFF6FBFBEF
FEFFF3FCFFF1F9FFF1CCDBBED2E8BAC3DBA1DAF0AFC2D88FC6D988D7E695BCC87CE3EEA9
E4EEB1BDC88EE1F0B9D6EAAFCAE3A1CCEB9FC5E791C0E88FC8F9A0B6DD8CDDEDACE5E5B1
FEF7CBFFFFD6EFFFCCC5E3A7C8F1ABB1DB93CEEFAA5D7537536332ECFBD4F7FFEAF1FFE8
F7FFE4E5F7CDD1E5B2CDE2A9CFE5A5CEE5A1C9E39CC9E39C
323E00525B1A656326534F12575B1E99A165D1DAA3DADDAEFFFEDAFAEAD0BAAD9CFFFFF3
F3F4EFFEFFFFFFFBFFFEF3F7FFFDEAFFFFE15E693F74865690A874C4DFAAD4ECBAE1F2C8
F4FBDAFFFFECD2CBC1F7EFECFFFDFFFFFDFFF1F4FDF9FFFFF9FFFAEEF6E9FEFFF6FFFFF6
FFFEF5D8D2C655523F838465656E43DBE9B4C9DD9ED4EBA5B0CA81859F56D2E9A1D1EBA1
D2F1A5BDDD8ACFED95CFE992D5EBA0CDE2A1A2B683D4EEBFC8EDBAB8E8AE31682593CB84
D0FFB9B4DC96CAE3A1D2E5A5D5EAA9CDE2A1CFE2A2D7EBACDAEFB6E1F1C2A9A88AFFFCEC
FEFFF8FBFFFAF9FFF6FFFFED7D7252A29F6AC8E092CAEC95D1E898CFE19793A05AD7E29E
DBE4A5D3D8A0BBBA8C75724FC9C3ABCCC3B4B4AAA1FFFCF8F1E5E5FDF3F4C9BFC0F0EBE5
FEFFEDFBFFEAFBFFF1F9FFF4F4FBF3F9FFF6FBFFF1EBF6D6D6E3B5CAD9A0D4E4A6D9E9AB
D4E3ACD0DDAFD8E4C0F7FFE9FCFFFAEEF0EFFBFAF5DAD8CCC6C3B4D9D7C2FFFFE6FCFFE1
F7FFDEF9FFE1F2FFD7F7FFDCD3E5B3DCEDB7C4D39CD9ECACCEE796C9E591D9F1A7CCE1A0
D0E1AAD8E5B7FAFFDFFEFFE6FFFFECFCFFECFDFEF0FEFEF4FDFAF5FFFEFDFFFDFFFFFAFC
736866796C66B9ABA8BAACA9FBEDECFEF3F1FEF3F1FFFCFAFFFEF8FFFFF6F0F2E4FEFFEF
EEF8DFE6F3D5DDECCBD5E7BDD3EAB4C9E2A1D5ECA6CCE297D6EC9A93A654B4C577CCDE94
CADB97E0F3B3C4D899CBE1A0C5E197CDEC9CC5E790C9F296C2EE97C4EB9CD2E7A2CED89B
EEF3BBE5EEB7C7DB9EC6E5A2C2EAA3C5EFA7C3E3A0627C3F6A7E4BD0E2B8D8EECAE5FAD9
DDF1CCDAECC4D1E4B6CCE0ABD3E8AFDFF4B9E1F7B9DAF2B4
C4E594DCF8ABD8E5A0D9DDA29A97645D542BF7EACAFFF9E2FFF6E7FFFCF3B8B1ABF7F3F0
FFFEFFFFFDFFFCEFF8FFFAF4D9D9B7575D2F99A074989F768D9371F3F8DAFEFFE6FFFFE8
FFFFECFFFFEDDAD4C4888274DBD7CCFFFFF6FAFBF5FDFDFBFFFEFFFFFEFFFFFEFFFFFEFB
F6F2E9FFFFF15C5E46DCE2C0697245D1E0A9DCECAED2E6A1CCE29950681CCBE196CAE699
C7EC9CC1E895C6E691D5EC9CD6E5A2EFFABEC5D499CDE3A3C3E79FC1EFA74E82447AAF7B
B7E8B9C2F1BBC6F0A6C5E79AC4DA9AD8E5ADDAE3ACCBD5A0D1DFAEEBFBD4C9D9BEF4FFF1
F8FFFDF3F8F4FFFDFAFFF3E55C4F2D9B9C63D5EE9BCBE98FD8EB99D7E59889934EE5EBAF
E4E6B4D4D2A9605A3AECE5CBFFFCE7AFA695FFFDF1FFF9F0FFFDF8ACA4A2FFFBFEFFFFFD
FBFFF6F8FFF3F6FFEFEFFDE6F8FFEAF8FFE4F0FFD5E5F7C3C4D89DD4E9A8D3E6A6D2E5A5
D9EBAFCEDFA8D4E4B3FBFFE0FFFFEFFFFAF4D3CBC8888380CFCDCEFFFFFDFCFFFBF9FFF6
F9FFF4ECF8E2FBFFEAFBFFE4EEF5D3D0D4B1DDDFBAD1D8ACDBF0B5BBD895D3F1ABCDEBA3
C8E89FC7E79EF0FFCAF2FFD1F4FFDAF7FFE3ECF9DFFCFFF3FFFFF8F7F3F2FFFDFF6B6066
0A0000FFFAFAD5C7C7E7DBDBFFFCFDEFE9EBFFFFFDF8F9F4FCFFF8EFFAE9F7FFEBF7FFE4
ECFFD6D0E6B5C8E1A8CCE4A6D7ECA9D3E9A1CBE198E1F7AE789044D0E89CD1E99DCBE59B
CEE89FCEE9A2CEE9A2CCEAA0CBEA9EC9E89AC8E797C6E796C8EA9DCCECA1C9E59ACAE596
D7EFA1D5F09FCAE797C6E798CAEFA2C1E59D5F7F3E001000CDE8B1C5E0ABD0ECBBCDE7B8
CFE3BECFE0BECEDFBBCADCB6D0E0BBE7F7D0F1FFDCE3F5CF
C0EA94B8DB89CBDF98D3D89EAAA1786A5739FFF7E7FFF5EDFFFAF6F6ECEBE9E3E3FFFFFD
F9F5F4FEF5F6FFFBFBFFFEEFB0B1859FA76ECED1A2A0A27B98977BF5F0DDFFFEF1FFF9EC
FFFEF1F8F1E1FFFFEFFFFCEBC9C8B6F6F4E5FFFFF4FFFDF8FFFCFFF6EFF6FFFAFCFFFFFA
FFFFF3FAFCE78D9274ABB18B4B54252E3B05C4D496DBECA8D2E69ECAE095799042C3E090
CAF1A0CAF4A2C7E794CDE496D3DF9FC3CD9199A5679EB46CCCEF9DBEEA9B9BCB9135683D
82B491A4D5A6CCFFB2BFEC99D9FCBCC2D9A3DFE8B9F8FBD0FCFCD8B3B69BD2DECAF5FFF8
F8FFFFFCFDFFFFF9FAB9ABA0615B3B8D945EC5E091CAEB92D5E896CCD88EE3ECAB474C16
7C7A518A8366FFF6E0D3C8B6FAEDDDFFF3E5FFF6E7FFF7ECE7E0DAC5C0BDFFFEFFEAEAEA
F9FFFAF0FEEDF7FFEFEAFBDBCCDEB6C5D9A8CDE2A9D5EBABD2E8A7CEE59FC9E09CC6DD99
C2D697C4DA9CDBEFB4FCFFD8C7C3AA958B7FE0D7D2FFFDFDFFFDFFF8FBFFFBFFFFF8FFFF
EFF8F3FBFFF6F2FAE5FAFFE8FFFFE7FFFFE8FFFFE8FFFFE3DFEFC2DDF6BDBBD898CDEDA4
CDEFA2C0E391CAEC9FC4E59EC1DFA3CCE3B5F8FFE8FCFFF1E1E1D9FFFBFBA99EA412060A
F1E3E3A99B9AFFFBFBFFFCFBE7E3E2FFFFFDF1F6F0FBFFF8F8FFF3E1F4D8DBF1CAE3FBCB
D8F4BACBE8A6CBE9A1D0EAA0CFE59CC6DB90D1E79E7E964CA4BC72CAE69BC3DF95D0EEA4
C8E89DC8E89DC7E79BC7E79BC8E79BC9E89CCAE99BCAE99DC5E59ACBEBA0C5E896C3E790
CAED93C8EB91C3E58EC6E796C4E49BC9E8A5627E44001100C5E0ADCCE4B2D2EAB6D3EABC
E5F6D4E3F1D7E5F3D9E3F1D7E3F1D7F2FEE6F9FFEDEFFBE3
C3E694E2FEB3CCDC9BECEFBAAEA17E5A462DBBA397FFF8F2FFEFEDAEA4A3F3EEEBFFFFFB
FAF7F0FFFDF4FFFDF4F1EBD1888D55D0D998E3E8B29B9E73A9A88AF9F4E1FFFEF3FFFDF4
FFFBF2FFFEF3FDF7EBEFEBDFC0BEB1FFFFF3FEFEF4F8F8F0FFFEFBFDFAF5FFFFF8F0F1E3
FFFFECF7FADFDEE4C28B9268E1EBB97D8A52576729CBDB9AD9EAA4CEE29ACADE96A0BB6E
BFE496BFE494D4F19FCADF92F0FABBD5DDA2C5CF927E924BC6E894CEF9AAC2EFB6629366
51805EC6F5C7B8EB9EBFF4A2AFE7A8C0EFBBE8FAD2F0EDCECAB5A0DDC5B9FFF3EFFCF3F4
F9F8FDFEFFFFFDFBFEA6A69CC3C9ADCADCACD3F2AEC9EB9ED3E99ECDDC97E3EEB4FFFFD8
ECE9C8FFFFEAFFFCEF85776EC2B1A9F6E8DFFFFCF3968D84DAD5CFF6F3EEFFFFFDFEFFFB
F9FFF4EBF9E0E0EFD2D8E8C4C8DBAED1E5B0D9EEB3C6DC9BD3ECA8CDE79ECCE69FD9F3AC
DFF6B2B8D18F839959647541AFB090FEF9E6FFFFF4E8E5E0FFFEFFFEFFFFEBEEF3FCFFFF
F0F5F1FCFFF6EFF3E2FFFFEDFFFFECB0AE9796917BE1E1C5EFFAD2D8E8B7D4E7AFCFE5A4
CFE9A2C7E398D5F0A9C7E1A0DAF1BBD3E4BAF8FFE7C3C5B78A857F43393A8D8185B5A6AB
E6DADAFCF2F0FFFCFAF6F1EBF5F5EDFEFFF6FBFFF3F6FFEAF2FFE3D5EAC1C8E0AECDE6AC
CBE6A3CBE79CCDEA9ACCE796D2E89DE3F7AFA6BC738FA75DC5DD93C7E398CDE99FCAE89E
CAEA9FC9E99EC7E79BC7E79BC8E79BC9E89CCDE99ECCEB9FC8ED9FCEF5A4CBF19CC7ED96
CCF098CAEC96C9E89AD3EEA7D2ECAFD1E8B4516339000D00DBE9C5CFDBB5C9D5ADFBFFE4
FBFFEDF4FFECF8FFF0F9FFF1F6FFEEFBFFF3FBFFF3FAFFF2
D6F2A7B9D08AE3EDB1D9D6A99E8F7068513FFFF0E9FFF8F6FFFAFA9A908FFFFDF9FFFFF6
FFFFF3FFFFEFECEAD5C7C7A19FA565D4DE95D6DCA094976AB8B799FFFFEDFFFBF1FFFDF8
FFFDF8FFFBF5FFFFF6F2EEE5C2C0B4EEEEE2FFFFF6FFFFF6F9FAECF4F5E5FFFFEFFFFFEC
FEFFE4D7DDB9E8EFC6969E6FDAE4B0C2CD93142200C1D190E3F4B0C9DA96CDDE98DCF3AB
BCDC91CCED9EC8E190E0F2A6C1CB8CD2DA9ECFD99A94A861C9E996C1E899BDE8B089B88C
5B8867AEDDB1B3E69BC3F9A5BCF7B3C5F4BDF7FFDCEAE6C1C4AF94FFF6E2FFF6E7FFFFF3
FDFFF7FBFFFAF1F7EB99A18CDEEAC4CDE2AAC3E49DBEE395D0ECA2CADF9EE3F1BCEDF3CD
FFFFE8F0E6DAFFFBF6937F7EC0ACABFFFAF8FFFCF6A79E95FFFFF6FFFFF6F4FAF0EEF6E7
EAF6DEF8FFE6EAFAD5D5E6BAC8DCA9CADFA6D1E7A9C3DC98BCD68DDCF6AC90AA61547026
78924B6B86416D8845CFE4A9D4DCB5FFFFE8FFFFEFF9F9EFFFFFFDFFFFFFF9F8FDFFFFFF
FFFFFBFFFFF8FFFFF3F2F3E1FFFFED82816DDFDCC9B9B9A1DEE2C1F1FACFEDF7C5CAD9A0
C6D697CFE2A0D7ECABCDE1A6C7D7A8D5DFBCF3F7E0424033060000564A4AB6A6A9837575
F8EEECFFFEF8FFFFF6FFFFF4FEFFF1EFF9E1E1EED0E7F7D2DEF4C5CEE5AFC9E3A4CCE7A2
C9E598CBE695CDE994C9E28FCDE398BFD38B98AE65DBF3A9CBE59BCBE79CD2F0A6C3E197
CCECA1CCECA1CBEB9FCAEA9ECBEA9ECAE99DCCE89DCAE99DC2E998C3ED99C0E892C0E691
C7EA98C4E498C4DF9ACEE6ACD6E7BAC2D0AC6770530F1300CBCDB5EDEDD5FFFFE6F0F2DA
FEFFF3F9FFF3FCFFF8FCFFF6FCFFF8FAFFF6FEFFF8FEFFF8
D3E7A2D7E5A7B2B683A49F77716046B39C8EFFF7F3FFF3F3FFF6F89E9492FFFFF6F9FAEA
F8FAE2C7CAABABAC8AB3B785D6E195D2DF8FD5DE9D949866B2B193FFFFEFFFF8F2FFFDFB
FFFCFDFFF7F5E9E4E0C0BBB5FDFAF1E7E7DBF7F7EBF7FAE9FFFFEADEE3C5E1E6C6E5EDC8
F7FED5CED7AACCD6A4B8C28D8C975FDDE8AC536123000B00CCDB9AF0FFBECEDC9EB3C684
8DA861A7C378D6EB9CD3E398DEE7A8D9E1A5EBF5B68B9C55AECB79C1E698B9E2AACAF5CA
79A58499C69BB6E69CBEEE98D1F7ACD0EBA8E9F5B5BDBE84E0DFA7F0F5BFE6F4C3DFF5C6
E5FCD2EBFDD5EFF7D0AEB687E1ECB0CADE96C7EB91D5FDA4BCDC91E2FABEE6F7CAFEFFE4
FFFFF1FFFAF6FFF9FDBEA7AFFFF7FDFFF9FB574946FFFAF0FFFFF3F0F7E5F9FFF1F8FFED
ECFCD8F1FFD7C0D1A4BFD19FDAEFB6C1D7999FB87690AA632943004B671AA6C277DCFBAF
CBE79CC5E399D2F0A8C3DD9CE2F2C1DCE6C1F8FEE2FEFFF1F9FAF2FDFCFAFFFEFFFFFBFC
F9F4F1F7F2ECFEFAEFFFFFF1656354FFFFF1FEFCEFE0DFCDB1AF96858563202100929868
F0F7C3C2CB94D9E3AED2DCAADAE2BBDBE0C23B3A26564F457A6F6BFDEFEEFFF5F5FFFBF8
FFFFF6E8ECDEFEFFF1FCFFEDF1FCDEE1F1CCC2D5A7D4EBB5CDE5A7CBE6A1D3EDA3D2ED9E
CAE692CFE894D3ED96CDE591ADC277657932CAE098D0E79FCFE9A0D1EDA3C5E498C9E99D
C8E89CC9E99DCBEBA0CCECA1CDEBA1CDE99FCDE79EC9E89CC5EC9BC2EC9ABEE592C4E999
D1F1A6CEEBA8CAE1A9D3E4B8D2DDBFDCDFCC6F6D610F0800FEF4EAFFFBEFFFF6E6FFFAEE
FFFFF8F8FAF5FEFEFCFFFFFBFDFDFBFCFDF8FFFFFBFFFFFB
C9D3969EA66D555426615935FFF1DBFFFAEFFFF7F6FFF1F3FDEDED6257535854484E503A
AEB492D4DBB1CFD7A6DCE6A9E4F1A1D0DD8BDEE7A69AA16EA5A589FFFFF1FFFEFBFFF8FB
F2E9ECFFFDFDB8B3AF555249FDFEF0FFFFEFFFFFEDFEFFE8EEF6D1DFEABFD7E0B3CBD7A7
DDE7B3DAE4AFCFDAA2D8E3A7BEC98DD0DC9ED8E6A8505E20E0EEB0B9C78AE6F4B7EDFDBF
DCF1AC8EA65C45570B4D5B10E4EDAECED69AC8D494D8E9A293AF5BD5F7AABEE4ABC4EDC3
517A5A8DB88DBDEDA3C2EC98C6DC93D6E19D868B49949B58D3E29FC8E19FD4FBB8C1EBAB
C1E7ACBDDAA2C8D5A0A2A76FDAE3A0CFE293C4E98CC2EA91D1F5ADBFDBA1D5E7BDFCFFEA
FFFFF6FFFAFDF7E1EDB79FADFFF6FFA58F92FFFBF8FEF8ECF7FAE5FBFFECF1FFE4EEFFDD
C4D5A8E0F1BDCDE0A9DBEFB4D1E5A88DA36292A965C1DB92C9E59AD3EFA2C1E092BDDC8E
D3F2A6CFEFA3C2E296D1EFA9CCE1A8F8FFDCFBFFE3E8F0D8F7F9ECFFFFFAFEF8F8FFF6F7
FFFCFBF6EDE8FFF9F2524B41CBC7BCFFFFF4F6F6ECF5F3E6FFF8E5FFFFE6DBD6B6D3D1AB
424317EEF1C2DBE1B5DCE1B9CDD0B10303007B7869ADA69CFFFCF8FFF5F2FFFBF6FFF8EF
E6E8DAF9FFEFF5FFE8D5E4C3D4E6BCD1E8B4CEE6AAC9E4A1C6E298CBE79AD3EE9DD1EA97
CAE390D3EA98D8EF9DCCE19293A75F81974FDAF1A9B9D38AD2EEA4CBE99FC7E69ACCECA0
C5E599C6E69AC8E89DCBE99FCDE99FCDE99FCDE79ECCE89ECAECA0C6EC9FC4E99CD2F1AB
E3FDBCDEF5BDD8E9BFDFEACCF0F3E2FFFFF8776F6D080000EEDFDCFFF6EFFFEEE2FFFCF3
FFFEFBFCFAFBFFFEFFFFFEFFFFFCFDFFFEFFFFFEFDFFFEFD
BABD86777947979268FFFFE1FFF5E3FFEEE5FFF7F5FFF9FAFFFAFADDD3CAE0DDCCCCCFB2
DAE1B8D8E2AED0DEA1D7E7A0D4E392CEDC8DD7E1A4B0B688B7B9A1FFFDF1FFFDFFFFFAFF
FFFDFFFFFDFDE8E5DC8485758E9078999E80CDD3B1A1A98098A472C8D79ED9E6AED6E5AA
D1DFA2CDDB9DD2E0A2DBEAA999A867697837D9E5A7D7E3A5CCD79BDCE7ADCCD79FC8D69B
CADA99D7EBA3DCECA1D6E39B4C5617B9C386E0ECAACFE1979EB763C9E89AC6E7B04E734A
062B0C79A278CAF8B0D2F4A7DFE7ABD9D6A152511BA5AD74D4ECB0B9E0A1BBF2B1B0EBAB
C3F5BAC7EAB4CEDCAB909461DDE2A8D6E7A3D0F2A5C2EB9DBDE29FC8E6B0EAFFD8FBFFEC
EBE8E1FFFAFFCEB7C7C8ADBEFFF1FD836D70988982DDD8C5EDF3D7E5F5D0D7EEC4E1FBCB
CBDEA6D1E3A5C4D698DAEFAEC3D8979AB16DBFD690D7F1AAC0DC92CDE99ED4F3A7D3F2A6
CAEA9EC4E498C5E599CAEA9FC4DE9FE1F8C2E3F4C8FBFFE6FFFFEFFFFFF6FFFAF7FFFBFB
FFF1F1FBEDECCFC4C0FEF5EEFFFEF8FFFEF7EFEEE97B7871433B2E160E000A0200ADA88A
9F9F7B64663FDBDCBAC6C9AA4C4E36040500757366FDF9F0FFFEF6F9F0E7FFF8EEFEF8E8
EEF8DFDFF3D0F5FFE3ECFFD5C5DEA7C9E6A6C5E39BCDECA0C8E797CAE795CDE897CBE395
CDE398D9EDA5D2E39FB4C581ABBF7AD0E5A0C8DF99CCE69FCEEAA0C8E69CD0EFA3C6E69A
D1F1A5CFEFA3CDEBA1CAE89ECBE69FCBE69FCDE7A0CEE7A3C5E09DC6E3A1CCE6A7DCF4BA
ECFECCE4F3CADDE6C9E7EAD9FFFFFAFFFDFD81767A080000726360E1D0C8FFFBEDF7E9DC
FFFDFBFFFCFFFFFDFFFFFDFFFFFBFDFFFDFFFFFDFDF5EFEF
9F9F6B535121A19C74FFFFE1FFF9E6FFF7EBFFFAF4FFEEEAFFF8F3FFFBEFFFFFEAFAFBD9
DAE2B1D7E5AAD9EAA4CCDE92D4E597D8E59FCDD8A0CDD4ABDEE0CBF8F8F0FFFDFFFFFDFF
FFF9FDFFFFFAFAFBEBFFFFE8FFFFE1DDE6BBDFE8B9D6E3ADD5E5A790A06150601F90A05F
D6E7A3D7E8A2DBEAA5C7D693D9E8A591A05DDAE6A6CEDA9CDEE9AF606B31C6D09BE1ECB4
D5E3A5D3E29DD8E69BCDDA92DEEAAA8E9A5C52611E8EA35890A955CEEA9DC6E3AD61815A
000D00CCF2C9B5E099C8EDA0CDDD9FE6EAB79B9D6B8A915ECCDEAACDEEB7B9EBB04C8349
497F4591BA82CFE6B28A9762E1EEB6C9DD9EC7EBA5BFE8A2C8EFB0C6E7B2DEF4CDFBFFED
FFFDF8FFFAFFAA93A3FEE3F2FFF4FFFFF8FAFFFCF1A49F89DDE4C2C3D4A8CDE7B7CEEAB0
CEE3A2D8ECA7D6EAA5D0E3A191A6638A9F5CD4E9A6CBE29EDDF6B2BED992C9E49DD0EEA6
BEDC92CCECA1DAFAAEBCDC91CEEBA8D3ECB2C3D6A8F8FFE3FFFFEDFCFAEEFFF8F6FFFBFB
EADADBA89A9AFFFBFAFFFCFAECE7E3010000070604BBBAB6E8DFD8FFFDF10D0600060100
090800E1E2C37E7E62363820141503BBBDAFFEFEF2FAFAEEFFFFF3FFFFF1FFFEEBF1F4D9
CDDFB9CBE5B6C7E4AEC5E3A7CBEAA7CDEDA4C9EA9BCBED99CBEB98C9E696C8E298CBE09B
D4E6A8DFEEB5C5D29D95A26CD8EAACC7DE9ACFE8A4CEE9A2CAE69CCEECA2C7E79BC3E397
E1FFB5DCFCB0D5F3A9CDEBA1CAE59ECAE49DCEE5A1D1E5A6D5E8B0DEEFBBE9F9C8FBFFDA
FCFFDFFDFFE5F5F8E3FFFFF4FFFCFBFCF6F839303307000082786F8C837281775EFFFFEA
FFFBF5FFFDFFFFFDFFFFFDFFFFF8F9FFFCFDFFF9F7E9E1DF
FAF8C5BBB989A4A178605A38635940E2D7C5FFFCF1FFF3EAFEF2E6FFFFECDEDABDCFD1A9
E7F0BBD1E09FCBDF97D6EB9ECDDE97DAE8AADCE5B6D3DAB9B9BBADFFFFFBFFFEFFFFFEFF
FCF8F7EDEDE1DEE0C8DFE5BFE7EFBEDEE9AFD4E2A4D9EAA6D6E7A3D0E49FD3E7A0778B44
83944DDAEBA4E1F2ABC4D58FD2E19CD3E29F798847D0DEA0D8E3A96873393A440FAFBA82
DAE6A8E2EFAAD5E398D4E49BD0E19DE1F1B0ADC17A8DA456B2CC75CBE697CAE3AC93AD88
3A583C94B691BCE7A2C1ED9EC8F3ACAED191BAC893ACAF80EBECC2E5ECC27E95671E4310
2E5B2479A66D6A8D536D8A50D7F3B6C2E2A1BFE7A1C3EEA9CAF0B3C9E7B3D2E8C1FBFFED
FFFFF8FAEEF2927C88CAB3BDFFF7FDFFEFECC7BAAAF4F0D3D2DAB1CCDEAECDE5B1CDE7AA
C6DB96D4E59ED4E8A1B5C984A1B472C3D897E1F5B6D3E9ABCEE4A6CCE4A6D3EBADC8E2A1
DAF5B2C8E6A0CCEAA2CCEAA2CCE9A6D6F0B3C4D8A7F9FFE3FFFFEDFFFFF3FFFCFAFFF5F7
CBBBBEC8BABAFFFBFBFFFCFB403B38B0AFADB0AEB1FFFDFEF8F3EFFFFEF6FFFFF3605F4D
1B1D07666A53656853666B57B5B9AAFDFFF3FEFFF6FCFFF2FFFFEFFAFEE7EDF0D3DEE8C3
CCE4B0C8E7ABC8E8A7C8E9A2C8EA9EC8EB9BC8EB97C9EB97D0EF9FD7F3A9C6DC9BD6E9B1
D2DFB1CCD7AFD7DEBD97A27AD1E2ABCDE4A0CDE6A2CFEAA3CCE89EC6E49AC9E99DD1F2A3
DEFFB0F0FFC4CAE89EC7E399D8F2ABCBE4A0CFE5A4D1E3A7D4DDB0DFE3BEFAFED9FFFFE1
F6F9DAFFFFEAFFFFF1F3F3E9AAA6A39A9997807C79080500E9E8D4FFFFE5EBEDC8DCDDBD
888479E1D8D9FFFAF8FFFBF9FFFDFBFFFDFAF9F0EBAAA19C
DDDDA9E9E9B7E7E6B8E3E1BA7B78573E3A1F908A74A79F8CBFB7A2ACA58B9A967398996D
8C945B96A260D4E8A0CEE29AD7EAA8D3E2A9E6F1C6F0F6DAB4B8AADEDFDAFFFEFFFFFEFF
FFFFF8ECEFDCD4DAB8D7E0B1E4EFB5DFEEA9D0E298C6D88ED3E7A0CADE97C6DA93D4E8A0
98A962869750C9DA93DDEEA7D6E5A0CDDC998D9C5B5A682AD0DEA1DDEBB0B6C189343F05
909C5ECAD694D8E89FD1E69BCFE49FC8DF9BD8EFA7CEE698D2EC95CCE496D0E7B1CAE0BC
748E738EAE89BFE8A4CAF9A8C4F9A9CEF9B1C8DDA2D7DDADF6F4CBF1F3CCCBDDB3C1E3B1
C0EFB8C0F2B5BBE8A731581796B977CEF1ADB8E29AC5EEAAC4E7ADCDE9B9ECFFDBFBFFED
F8F5EEFFFCFDAF9CA25A454A634D4FA4918AFFFEEAFFFCDDCFD6ADDFEFC0C2D6A3D3EBAF
DFF3ACC4D68C8EA25B91A560CBDD9FD7E9ADC2D59ECCDEAADAECB8D1E3AFCCE0ABC4D9A1
CAE2A6C8E0A2CFE8A7CFE8A6C0D998CAE2A8D2E3B6FBFFE4FFFFEFF4F1E8F9F1EFD9CDCF
F0E1E4FFFAFDFDF1F1FFFCFB050000FFFEFFEFEDF0FBF9FCFFFEFDEBE8E3FFFFF6FFFFF4
EAEDDCC2C6B58C9081A6AC9EFCFFF6FCFFF8F5FBEFE8EFDFF0F8E1EAF3D4D3DBB6D5E5B6
C9E7A9C6EAA2C6EAA0C6EB9DC6EC99C6EC97C8EB97C9EA99BEDD91C3DE9BD5EAB1F9FFDA
FCFFE3DBE1C7828572CAD0B4D2E4B0CDE6A4CDE8A5D0EBA6CDEBA3C8E79BC8E89CCDEE9F
CAEB9CCEEFA0CBE79DD3EEA7D1EAA6C6DC9BCEE3A2D7E6AFFFFFDDF6F5D6B1B0919A997A
C7C7ABC5C5ADB4B6A1DDDED0FFFFF6F9FAF2868A7C000500CAD3B6DDE8C0D5E1B1DAE2B9
DEDCCDFFFEFAEDE5E2BBB4AE9C9491B3ACA6EDE6DEFAF3EB
D8DBA4E3E8B0CBD29EEAF2C1A5AC804950276364423636144F4A2A534D295F5A32646232
545720465011A9BA74D9EDA8D6E8AAC7D5A0F4FFD8FCFFE8B6BAACC1C4BDFFFFFBFBFCF4
FBFEEDE7EBD0DCE3B9D5DFAAC7D695C7D98FD7EA9BDFF4A5D4E59FD8E8A7DFEFAECADB97
D4E5A19DAE68D7E8A2D3E49ED1E29CD8E9A3BCCD89849453A7B778DFEFB1D1DFA22E3C00
475315C8D794DBF0A5DBF3A7D0EBA4C9E49FCAE69BC9E493D0EA91C9E090CBDDA9CFE0BE
8AA1878BA683CFF3B3B9E492BBE792AACF7FAFC481ADBA82FCFFD8DBEEC0C0E6B3C0F3BA
ADE8A8ACE5A0D4FFBA234900214100C4E499C8EEA1C5EAA4C6E3ADE4F9D0F1FFE1F3FBE6
FFFFF8FFFCFBE8D9DCAC9A9A92807CCBBDB0FFFFE8FFFFE3F5F9D4E6F1C7EEFDD2DDEFBB
CADE9998AD628A9E57B1C484D6E8AEE1F2BEE4F4C7E8F7CEDAE9C2E2F1CAECFBD2F2FFD6
DDEDBED9EAB6D4E5AFCFE2AADAEEB3D7EAB3DDEABFEAF3D4F8FBEAD7D4CDE7E1E1CCC3C6
FFFBFFFFFCFDFFFCFBFFFDFB373131FEFAFBFDFBFEFFFEFFFFFFFFF9F9F7FFFFFBFEFFF8
FEFFF6FCFFF6E4EAE0DCE3DBFBFFFBF0F7EFFBFFF6FBFFF1FBFFEAEFFBD5D0DBB0D3E6AE
C9E8A2C5EC9DC5EC9BC5EC99C6EC97C6EC97C8EB99C9E99DD0EEA8CBE3A7D8EAB8FAFFE0
EBF1D7989B8AD5D5CBE2E7D1D4E6B4CDE6A5CBE6A3CEE9A4CDEBA3CAEA9EC8E89CC9EA9B
C6E798BADB8CC8E49ACAE59ECAE39FD6ECABD5E9AAD5E2ADE5E7C2B9B697D7D7B5F8F8D6
DADBB9E6EAC9FFFFE6E4EAD0F3FBE4FBFFEF758169000E00C7D7B0D6EAB9C3D89FCFDFB0
D6D9C4F9F6EFFFFEF8FFFFF6FFFEF8F9F5ECFFFFF6FFFFF4
D9E1A5D4DEA2D7E5AADCEBB2D5E6AFD7E8B2CCD8A6A9AF81E8E7BBDBD7AADDD6A8D5D29F
ACAC766B7337ADBB7DD1E4A4D0E2A6C8D9A3FBFFDDFBFFE6C5CDB8D6DACCFFFFF4FFFFF1
FFFFEAEAF2CDDAE3B4D7E5AAD3E4A0D5E79DD1E697C4D98CCEDE9FD4E3A8C4D295E1F1B2
CDDD9EA5B574485915D0E19DCFE09AD1E29CCBDC98DBEFAA93A664869957DDF0B0D9E9AA
9FAD6F869655D8F0A6C6E295BEDE95CAECA2CAEA9ED2F29FD0EA91D7EE9EDBECB8C5D4B3
7789715B7552C3E6A6C6EB9DC7E398F8FFC895A469C0D2A2EDFFDFC6EFC7B9F4C8AAF0BE
B5FCC4B8F5BAACD89BBCDA9C041D00D3ECAAC4E5A0CAE9ADE8FED0F9FFE6F8FFEAF7FBEC
FFFFFAFBF3F1FFF8F8F0E2E1FFF7EFFFF7E8FFFFEAFFFEE3FBFCDDFFFFE4FEFFE4FBFFDD
90A0618EA25AB6C987D6E8ACD2E3AFE3F2C7F9FFE4FBFFE8FBFFEAFCFFEAFBFFE7FCFFE6
EAF4D1EFFAD2DDE8BDD0DCACD0DCAAC5D1A1BDC5A0BFC5ABC9CBBDCCCBC6FEFAFBFFFDFF
FFFDFFFEF8FAF6F0F0FFFDFD030000FFFEFFF9F4F8FBF9FEFFFEFFFEFFFFF8FAF7FCFEF9
FDFFF9F8FDF6FCFFFBFCFFFDF5FAF6F8FDF7FCFFF6FCFFEFEEF7D8E1ECC2D6E3AEC7DB9C
C9E99DC5ED97C6EC97C6EC97C6EC97C8EB97C8EB9BC9E99EC3DD9CF5FFD3E7F9C9FBFFE3
FEFFEAA8A999FFFFF4F8FBE6D9EBBBCFE9AACAE4A3C8E6A0C9E9A0CAEA9ECAEB9CC9EA9B
D1F2A3CBEA9CD6F2A7D0EAA3EBFFBEF8FFCDDAECB0C4D39C92996FD1D6AED9DEB5CFD6AA
E6EEBFDCE5B8CBD6ACE6F2CCD2E0BDE3F2D15C6D4B000B009BB183D3EAB6D3ECB2F7FFDA
FEFFEDFAFAF0EFEFE7F8F8F0FFFFF8FFFFF8FFFFF6FFFFF6
D7E6A5C5D594D7ECA9C9E29EC5E09BD2EDAACEE2A3EDF8BCE1E4ABD5D29DF5EEBAE7DFAE
84814E686B36CDD8A0D0DFA4D1E3A5D9EBAFFBFFD8DAE6BECED7B8F8FFE8FDFFEBFEFFEA
F9FFDEF9FFD8FEFFD4FCFFCFF3FFC2E7F8B2DCF0A9D5E9A4D4E1ABDDE9B7D9E3AFD2DFA9
CDDBA0D1DFA2586829D6E6A5DAEEA9CDE19CD6EAA3D4EAA2BFD48F465B16CADF9AC5DA97
D8E8A9000F00D2ECA2CAEB9CD0F6ABCEF7ABB9E091C1E38DC3E084C8DE8CCFDDA8A2AD8B
3E4B37000A0065874AC8E69ED7DFA6CFD0A49298761B2F165F88764B8A792F816B2E866D
9EEFCFB2F2D0C1E4C3677B560007006D7951CBE2B6CAE3BBF0FADFECF1DDFFFFF3FFFFF8
FAF6F3FEF8F8FFFCFBA89E9CFFF6EDFFFEF1F0EBD8FFFFECFFFFEDFAF7E6FEFCEDA6AB8D
9DAA72C6DA95D5E7A9DDEEB8FBFFDDFBFFE4F4FEE5FCFFF1FEFFF4F9FDEFECEEE0FFFFEF
FFFFECF1F4D9949778484C275C6138888D65BEC1A4FEFFEBFFFFF6FFFFFDFCFCFEF3F2F7
FDFDFFFBFBFBFFFFFDFFFFFD030000FFFEFFFFFDFFFAF5FBFAF9FEFEFFFFFEFFFFFEFFFF
FEFFFDF5F7F4FCFEFDFEFFFFFEFFFFFEFFFBF3F6EBF2F7E1DCE3C1BDC697B3BE848B9C58
CAE999C6EC97C8EB97C8EB97C8EB99C8EB9BC9E99ECAE8A2CDE7A6EDFFC9ECFCCDFCFFDF
D2D7B7F5F7DFFFFEEAFCFFE3E5F7C5DBF5B6D1EBAAC9E6A3C7E79ECAEA9ECAEB9CC8E998
C5E494C7E698D0ECA1D5EFA8F7FFCCF4FFC9B0C286A7B97FD8E9B2D5E6AFD9EBB1D0E2A4
C1D494CCE0A1D5E9AEC5DAA2CBDFAEC6D9AC62774C000B00687E4FBFD7A5C5DEA7F7FFDD
FCFFEFFFFFF8FFFFFAFFFFFAFFFFFAFFFFFAFCFBF6FCFBF6
D4E8A1DDF3ABCAE69BC7E79BCDF0A0C3E696C6E096CADB94D4DB98E4E2A5D3C994B0A673
746E3E868555D6DEADDDEAB4CDE0A0D8EDAACDDFA5AAB887C0CBA3F1FBD8E1E8C7EDF4D2
E7EFC6FEFFDAFCFFD4DEEBB3B4C48693A56796AA6BB4C68CC5D1A18D966B98A1747E8856
AAB4807F8C5490A062C7D798C9DC9ACFE49FD6ECA4D0E79FE8FFB77F994FEFFFBECDE49E
CEE1A18499567D9C50BBE291C3EDA1A2CE81DCFFB5C6EC95D7F498D7ED9BD7E4AF8E9876
4D59450C1F01426125CCEAA4D3DEA6D7DCB38C95781E332238615975B2AD23746D2D8577
4C9D8A83C3AB7AA186293D21000700828D6B98AE88D0E3C3E6EAD9FAF7EEFFFFFAFEFAF7
FFFCFEFFFDFFFFFDFDADA8A4FFFFF6F0EADEFFFFF1FFFFF1FFF8EFFFFDF8BBB1B0A6A394
D3E0ABD5E8A6DAECB2E8F8C7FBFFE3FBFFECFAFFF1FEFFF8F4F5F0FFFFFBFFFFFAEDEAE1
BDB9ADA4A18E9D9B84B1B094ADAA89C7C4A3DFDDC6FFFFF1F6F5F0FEFFFFFCFFFFFCFFFF
FAFEFFFCFFFFF2F4F1828280636260EEE8E8FFFCFFFFFDFFF7F4FBFEFFFFFEFFFFF0F0F2
F2F2F4FFFEFFFFFEFFF6F4F7FDFBFEFFFFFBF8F8EEEEF0DACFD3B0A6AD7A9CA46893A35C
CCE999C8EB97C8EB97C8EB99C8EB9BC9E99DCAE8A0CCE7A4D9F1B3BBD097E0F1BDBFCB9D
878E65FDFFDEFFFFE3DBE1BBEDFFCBE4FEC1D8F5B5CDEAA7C7E79EC9E99DC9EA9BC7E897
C9E898C1E092C3DD93CEE8A1DAEFAEB5C98C99AB71BBCF92D1ECA9C0DE96C4E298D4F3A5
D2F1A1CAE999CAE69BC6E19CD6F0B3D2E9B391A7762A4012879D6FDBF1C2D1E7B6F8FFE1
EEF7E6F2F7F1FEFFFBF8FAF5F8FAF7FFFFFDFCFCFAFDFDFB
88A056D1EC9FC7E897BFE791C5F097C2EA92D8F8A3CFE495D8E097C7C685635A217B6F3D
B9B183E1DEB3D5DAB1D2DEACCADE99D0E69D95A866ACBB82C3CF9FD4DFB4D0D8AFD6DEB5
DBE4B7DBE5B3B4C18CA5B27CC5D49DCEDFA9CBDEA7E3F3C2CED6AFFDFFDFEDF4CBBFC89D
97A071B0BD88DCEBB2D8E8AAD4E7A5DCF1ACC0D68EBDD58B8DA75D87A356C5DF95CDE79E
C9DE9DD3ECAACAEC9FC1EC9AC1F0A2D6FFB8A4D17ED0F89FCDEC8FCCE290D6E0AC888F6E
78816E4454371C3A00B6DC91C8F0A7C2E6A81932081C3017C4DBD5CFF3F3D7FFFF498C83
71B9A525654A37664461815A9DB48AAAC092748E5EA3B490CBCBBFFFFCFDFFFCFFFEF8FC
FFFCFFFFFAFFF4F0F1D9D5D2FFFDF6FAF6EDFFFEF6FFFCF7EBDFDFD3C4CBEFDFECFFFCFA
D8E4B6BDD291CEDFA8DDEDC0D1DCBCE1EAD5FCFFF8F9FBF8FAF8FBFFFDFFEBE5E9D4CECE
FAF3EDFFFDF1FFFBEBFFFFEAFFFFE4FFFFE4FFFFEDFFFFF4F8F7F5F9FDFFF9FEFFF6FDFF
F8FFFFFBFFFF464B47040601ACABA7FFFDFDFFFBFFFCF3F8FFFDFFFBFAFFFCFBFFFFFEFF
FFFEFFFFFDFFFFFCFFFFFCFFFFFDFFFFFDFDFFFEF4C3BEAAA5A57FB1B381AFB474DEEAA2
CDE899C9EA99C9EA99C9EA9BC9E99DC9E99ECAE8A2CCE7A4BAD294E1F5BAD4E3AC929C68
CFD7A4F1F7C7EFF1C2D0D8A7DFF4BBDBF7BAD7F4B4CDEAA7C7E79EC9E99DCAEB9CC8E998
DCFBABCDEC9ECFE99FD3EDA6B1C6859DB174C4D69CDEF4B4C3E89AC5F19AC0EB8FC4ED8F
CBF494BEE686BCE088D5F6A5C3E19BC8E2A5687F4B0619007D8E64CADAB3D0DFB6F4FFE1
FBFFF6FBFFFDFCFFFFF5F9F8F8FCFDFEFFFFFDFEFFFEFFFF
8BA75ACBEA9CD4F4A8C6E89BC8EB9BC3E493CAE294D7E79EDADF9DA29D66574E23BCB28E
EAE5C5FBFADBE7EECCECF8CAD6E6A5D7E8A1839450D6E6A8E1EEB8CAD7A2D9E5B3D4E0AE
D5E2ACD3E2A9A3B27999A86FCDDFA5D8E9B2C3D49ED4E2ADDAE6B4FAFFD4FCFFD6F0FECB
F9FFD6D9EAB6C9DAA6CBD9A4CEDDA6D7E5AAD9E7AADCECAB96AB66C7E198CFEBA0CEEAA0
D4EDABC7E1A0C6EAA0C3EDA1C7F5AC7BA960D2FBADC1E490D0EA93C4D788E9F2B9B7BF96
ABB6984B5C3A000E00CBF0AABEED9CC3F2A473915D455A3B8C9C92BFD3D2DCFEFFE2FFFF
D0FFF06FA2837DAA83AAD1A4BDE1B3C1E7B8D0FBCEDBF8D977746DBFB0B5FFFCFFFFFDFF
F4EFF3FFFEFFFFFDFDC5C1BEFFFFF8FFFFF8FDF8F2C9BFBDD0C1C6CEBDC7FFF9FFFFFDFD
D2D9B8DEEEBDD4E1B6C8D2AFDAE3C8EEF2E1F9FAF2FFFFFDFFFDFFFFFCFFDCD2DABDB4B7
FFF8F6FFFDF8FFF9EEFFFFEFFFFEEDFBF4E4FFFDF4FDF8F4FFFEFFFEFFFFFCFFFFF5FAFF
E9EEF1A8ACAD00010081807EFFFEFDFAF1F2FFFBFFFFFBFFFFFCFFFEFBFFFFFDFFFDF8FE
FDF8FEFFFDFFFFF7FCFFFCFFFFF8F6FFF8F0FFFFEDA29E819A9B71D8DBA4AAAF6DCDDB90
CCE997C8EB97C8EB99C8EA9DC9E99EC9E9A0CAE8A2CCE7A4D2EBA9C9DF9FB0C284B3C385
D8E6A9DEE9ADCED99FD8E7ACC6E3A3C9ECAACDEDAAC9E8A2C6E69DCAE89ECFEBA0CEE99C
C8E094C5DB92D5EBA3D2E6A191A4649BAD6FE2F1B6C6DD99C5EB94C4F192C7F593C1ED8C
BBE788C6F195CDF59DC1E696C3E49DDAF7B7586F3B00100093A17DD1DCBCDCE5C8FAFFED
F6FDF6F1F7F7FBFFFFFBFFFFFAFDFFFEFFFFF9FAFFFEFFFF
A8C97ACAE89ED6F0AFC1D69DD7E8B1E3EEB6D0D59BD2D29EDFDAB05E5538D3CABBFFFFF6
FFFFF8F9FFF1F8FFEAF8FFDFD5DEA7313900909A5DDAE5A9C9D79AD0E0A2D3E5A7D3E8A7
D3E8A7CDE29FD1E6A3AFC4819BAE6C9CAF6DCEDE9FD6E7A1CAE08ECDE692CAE699CAE8A0
D5F3B5C7E2ABC7DAADF9FFDFFFFFE3FDFAD9D8D6B0909165D6E1A9D6EBAAC9E79DC6E89C
C2E19DDAF8B8BBDE9ECCF0B2C1E4AA3355198BA866DDF4AED7E79CD3DF959EA764B4BE82
D6E2B258693D132A0083A068C9EA99C9EB9793AF724359326677659FAEA9ECFCF9F4FFFD
F1FFF0D1E9C9C7E3BBB9DEB3C7F7CFB1EECC9AE3C86CA1915B595AB19CA1FFFDFDFCFDF8
F8F7F2FFFEF8FFFDF6A19A92FFFFF6CBCDC2D7D3CAC2B7B3FFF9FBFFF9FFF4EFF3FEFFFF
FEFFF4FEFFEFCDD0BDE7EAD7FFFFEFFEFCEDFFFFF4D8D3CDACA4A2D2C9CCD4CBD0FFFCFF
FFFAFBFDF8F4FFFEF8FCF7F1FFFEFDF9F5F6FFFDFFADA8AEBDBBC079767D6D6A7137353A
403B417E797DDFD9DDFDF4F7FFFBFFFFFBFFFFF8FFFCF1F9FFFAFFFFF9FFFFF8FFFFFCFF
FFFDFFFFFCFDFFFDFAFFFEF4FFFFEFC7C5AC9A9B79C6C99CDBE2ACB9C283798440D2E498
C6E892C8F097C1E794C9EEA0B9DB91CDECA6CDEAA7CFEAA5D3EEA7849E5588A259C9E39A
D3EDA4C5DF98CAE39FC5E4A0BFEAA2B5E599CDF7ADBFE59ACFEDA5CEE59FD3E49ED9E6A1
D7E09DE1EAA7D0D998757E3D8B9757CBDA99DFEFAECBE198CEEC92C6EA8AD2F69CCCF29D
BEE497C6EEA7C2E9A6C6EDACC9EDADC2E1A594AF7A34471A616C4AE2E7D0F6F7E7F7F8F0
FCFFFFF8FDFFFBFEFFFEFEFFFDFBFFFFFDFFFFFDFFFAF5FC
D1F0AABDDA9ADBEFBCF0FDD2E1E5C0F2F0CAEBE6BCFFFFD8FDF2D4554A38FFF8F6FEFCFF
F7FBFAF6FFF6DEF3D2E0F3C5CFD6A265682FB1B67CD5DFA2E3F2B1DDF0AED1E6A1C2DC93
CFE9A0C6E096DDF5ABCBE198A7BB7396A760DCECA5D7E99DD3ED94D0EE94C6EA93BEE395
C3E7A1C5E4A9D2E8B9F8FFDDFCFBDCF9F2D5B7AE8FCFCBA5EAF0C0C5D79DC7E4A2D2F2AF
C1DDA3C6E1ACC4E0B0D6F1C4CBE6BB607A4D7F9360BECD94E0ECAED6DF9E899251BDC98B
C6D4A18B9D73102808667F55D1E99FC5DC8CCBE5A6647E51657D65B5C7BBF8FFFAEFF5E9
FFFFEDD8DFC0DBEBC6CBE9C3B7EAC9ACF2D66BC4B22C74697A8E8CB2B4B1DBE8DFF8FFFA
FFFEF8FFFAF6FFF5F1AD9591E0D7CE827E73D1CAC2FFFBF8FFF6F7FAEAEBFFFFFDFBFFFF
F4F6F3FFFFFBDFDFD7F4F4E8FFFEEFFCF9EAFFFFF3A39C94B4AAA8E4DADBEEE5EAFFFCFF
FFFBFDFFFEFBFFFFFAFFFFFBFDFCFFFFFEFFE8E7ED2C2B302C2B30010002353034373236
D4CED0EFE9EBFBF2F5FFFCFFFFF8FCFFF7FBFFFBFFFFFBFFF0E6F1FCF4FFFFFBFFFFFDFF
FFF7F8FEF9F3FFFDF1FFFFEDC2C1A5A1A37EA9AF81D3DCA7D3DDA184904E707D38CDE496
CCEE98C6EE95C5EC9BC6EB9ED0F1ACD7F6B3BDDA98C9E4A1BDD8919CB86DABC77ACCEB9D
CDECA0C8E89DCEEEA5C6ECA3C0EFA1C2F3A4CAF4A8BEE298BCD790D1E6A1D1DD9BD6DF9E
DCE1A1A9AE6E9CA2629CA564D6E2A0E1F2AECDE19CC6DE92D3EF98CAE88ED3F39EC6E69A
BEE29CC7ECA9C7EBADCAEEB0C8EAADD0EFB492AA76283A106E795BECEFDEF0F0E8FFFFFD
FCFFFFF9FFFFFCFFFFFEFEFFFAF8FFFEFBFFFFFDFFFFFAFF
CFEAB3D2EABADCECC8FCFFE8FFFFE8FFFBDEFFFDD8FFF8D4C4B99B7B705CFFFEF8FFFFFB
F2F8EEF8FFEFCAE1B5CADFA7DCE5ACC4CA8CEDF6B7CDD997CADB95BDD38BC8E096D6F1A4
D6F1A4CEE99CCFE79BCCE297CBE0959AAC62D3E39AC5D68FCFE69ED0ECA2CFEFA6C8ECA4
C4E8A2CCEBA8D3EBADCFDCA6BBBD8CC7C396A8A379DAD9ADE7EFC0CDDDAEE2FDCAF2FFDC
F8FFE3F9FFE6F8FFEAE7F7DCF4FFECEEFFE3A5B591647146343D0EC4CE9AD2DCA89BA87A
D5EAC3B1CAAC73907A91AC8D8A9C60E6F7B3CEE7AEBDDCB09ABD9C32523A0B200D616C5B
D1D0BBFAF8DFFFFFE8E9FCE0D9FFE966AA93318C7A2782719FE4D2619885507F6F99B3A8
8E8381B68F94F0B8C3A16E75E2C4C4FFF0ECFFFBF8FFF5F2FFEBECFFFAFBFFFEFDF9FBF8
FFFFFDF5F6F1FCFCF4FFFFF4F9F5E9C6C3B4B7B1A5FCF5EDF5EBEAFFFBFFFFFBFFFFFBFF
F8F2F4FFFBFAFCF8F5FEFDF9F1F3F2333534535554BEC0BFFEFFFFEEEEECFFFFFDFFFFFB
FFFEFBFAF6F3FFFEFAF5F0ECF7EFECFFFDFAF0E8E6C4BBBCE4DEE0FFFEFFFFFDFDFBF8F3
FFFFF6FFFFF3F4F3DFCED1B6C3C7A6C4CBA1DBE3B2D5E0A8DDE9AB9AA966B8C782D6ECA1
C7E995C6EC97CEF3A6BEDF98CEEBA9CCE6A7C1DB9CDFF8B78DA662AAC47BC5E093C9E598
C6E297CAE89ECDEBA5C5E49EC4E89EC7EBA1C2E299CAE59ECEE59FF1FFC0CAD996B1BC7A
98A361A4B06EC6D592CBDC98D6EBA6C8E29BC5E099D8F6ACC8E799BDDC8EC5E498C4E498
CCECA1D4F6ACC6E7A0C3E49FCDEBABBAD39A667C4D031300606A52F9FDEFFFFFFBFFFFFD
FCFFF8F9FFF4FCFFFAFEFFFDFDFCFFFEFCFFFFFDFFFFFDFF
E6FAD5F7FFE8F5FEE9FDFFF1FFFFF1FFFAE7FFFFE1AB9E7C6D5F42D5CAB4FDF4EBFFFFF6
FAFFF1F8FFE6CCE3ADC9DF9F879152626828515A194F5C1797A861DBF1A6E0F8ACC8E394
BCD989DAF7A7D3EB9DCFE698DAEFA28A9C50C4D48BDAEBA5CAE0A0CAE4A7CEECACCFEFAC
C5E6A1CCEBA7CAE19D99A96A4C52168D8D57ECEAB9E1E3B4D8DFB3CCDCAFE3FACEF5FFE3
FDFFE9FFFFEDFDFFF0F8FFF0F2FDECF8FFEFF9FFEAFBFFE4646F45000900DBEBBE85976F
99B18FC5E3C984A69586A78CD1E3B17A8950CAE2AECCEDBEC1E7BEB8DCB8000B00D1DFC5
FFFFEAFFFEE8FFFFECF8FFF1C3E9D434715F0028182883713B88743A7B67001B0C001008
6D585DFFEFFBFFEAFAFFC6D2FFEBEEFFFBF8FFFCF6FBF8F3FEF2F2FFFDFBFEFFFDF7FCF8
FEFFFDFFFFFBFEFEF6EDEDE1B3AFA3AEAA9EFFF9EFFFFEF8FFFCFDFFFCFFFFFBFFFAF3FA
FEF9FDFFFFFDFCFBF7FFFFFAFCFFF80008005A6257FBFFF8FCFFF6EEF4E8F6F9EEFEFFF4
FFFFF6EFF1E4FFFFF4FFFFF4FFFFF4F8F6EAFFFFF487837AACA9A0EAEADEFFFFF3FDFEEE
FCFEE9EDEFD7DADFC1E2E8C4D2DAB1D3DCADE4EEB9C1CF94D7E5A795A662D4E59FBFD58C
C8E799C6E89BCCEBA5C1DE9CD1EBAEC7DFA5D6EBB2C6DC9E8CA160C4D994DCF4AAD0E89C
CEE89ED3EFA5CEE9A4C8E39ECDE6A2CAE49DCEE59FD3E8A3D1E5A0CFE09C899A565A6B27
97AB66C3D893DEF5AFCCE69FC7E59DCBEBA2C8ECA2C8ECA4CEEDAAD0EDAAD2F0AAD7F6AA
C5E494C8E797BCD88BD8F4AACFE8A7DCF0BBC0D0A95C694D7E8776FBFFF7FEFFFDFCFFFA
FBFFEDF3FDE2F8FFEDFCFFF6FCFEF9FEFEFEFFFEFFFEFCFF
F9FFF3FBFFF6FCFEFBFFFEFDF7EDECFFFCF3FFF2DD9C8E7396886DFFFEE8F4ECDFFFFFF3
F6FBE4EEFFD5D4EDACCEE59DDDE8A6DAE3A2D5E09EB4C37E94A65CC1D88ACAE392C5E08F
C6E391CDEA98CAE392D3EA9ACEE39694A65AD9E9A0D8E9A5D0E5ACC9E2ABC5E1A7CCEAAC
C4E2A2D0EAA9CEE4A38C9C5DE6EEB2D5D89FE4E4B0D2D6A4E6EFC0F9FFDCF4FFDFECFCD7
F8F6DFFFFEEFFFFCEDFFFFF1DBE2D0C5CFB7C4D1B3D1DFBBCFDCB1000E005F7244688157
4E6C48B4D9BA6C9680284F34D4EDC3728857C5E1B0BEDEACCCF0C0DAFBCCF2FFE37F8F6B
7D826480826A9EA38F5D6B5A001C0C7DB1A430776943877A61938A8FB2ACD6EFECFCFFFF
FFE4F0FFE8F9C98EA0B58792FFFBFBFAFFF8EDFDF2F5FFFBFBFFFBF3FAF3EAFBF3F5FFFD
F5FAF6FDFEF9F2F2EAA3A397C5C1B5FFFFF3F6EFE7FFFDFAFFF7F8FCF3F8FFFAFFFFF9FF
FFFDFFFFFEFFFAF9F5FAFDF2F6FFEE2E3C238B9980C8D6BDCFDBC3F9FFEDFAFFECF4FEE5
F1F9E2FEFFECEEF2DBFBFFE8FFFFECF9FBE5ACAE98FFFFECD3D7C0E6EAD1F5F9DEFFFFE6
FEFFE3C1C9A49FAA80C0CC9EE0ECBAD6E5AEFAFFCEF5FFC6FBFFCA899D58D4E8A1D7EDA5
D2EEA4C7E59DC1DB9AD9F1B5EFFFCEE4F6C2E9FAC683945DADBF81D4E7A5D9EDA6CADE96
D0E69ED2E9A3CAE19DCFE4A1DCEBAAD2DE9CCFDE9B9FAE6B8394507B8F4A9CB06BC5DC96
C8E29BCEECA4C6E69DCAECA2CAF0A5C4EDA1BEE79BC2EAA4BAD9A0CDE8B1C8E5A3BEDA8F
8DA9548DA7508CA450CADF94C6D59ADFECC0ADB89A3D4633777F74F4FBF4F3F9F5F5FDEE
F9FFE3E7F6CBE1ECCAE9F1D9EFF3E5FAFBF5FFFFFDFEFEFE
F4F9F3FEFFFFF5F2F9FFFBFFFFF4FBFFFBF8817060B4A48DFFF1DAFFFDEAFFFEF1FFFDEE
DFE5CBCFDFB2D3ECA8CEE499D4E09ECED798DAE6A4B6C58092A65ECEE597D3EE9DD0EB9A
DCF9A7BEDB89CDE695DAF1A39FB46992A35CE7F4AEC2D291CFE4A9CEE7AECAE6ACE1FDC2
E0FCC1E3FBC1E5F8C0A6B57E919A65949B67828654DEE5B2E0EAB8D7E8B4E4FBC7EEFED1
F6F1D4F9EED8ABA58DC3C3A9D4DBBCDDE9C5E5F4C9CADAABCFE0AAD7EAB35B723C8FAA77
97B68ACFF5CEC1EDCA00190089AC84B9D8AC516E3E4A6633CCE5AECFE4ACD4E5B1DDEABC
D6E2BCD6E3C5A7B9A1738C794B6D5D82AC9E74A69A4F7D73E4FCFCF5FFFFF4FFFFE0E5E9
FFF5FFFFF4FFCAA6B2FFF7FDF3F5F2F4FFFBF2FFFBDAEBE1F6FBF5F9FEF8F4FFFAF5FFFD
CFD4D0C2C3BEC8C8C0F7F4EBFCF8EDF9F5EAFFFEF8FEF6F3FFFCFFFFFBFFFFFCFFFFFDFF
FEFCFFF7F7F7FFFFFBEEF5E5BCCBAA21360DA1B68DCCDEB6DCEEC8DCECC7EBFBD6EBF9D5
EAF6D2E2EECABEC8A5A2AC89D4DBB9909775E9F0CEF0F8D3EAF2CDC9D4AC97A278889368
A5B284BCCA97C6D7A1D8EAB0CCDEA2CADC9EEAFDBDE8FBB9EBFFBA8CA05BCBDF98D3E8A3
CFE8A4CCE7A4C9E1A5EBFFC8F6FFD6F1FFD2F3FFD0919F6ACCDA9FD5E5A4CDDC97C6D790
D2E69FD1E6A1CEE3A0DDEDACA2AC6D828848909B59A1AD6BD9EAA6DDF2ADD3EAA4C4DF98
C6E69DD1F5ABC1E79CCAF3A7C2EB9FBAE498BCE69AC9F1ABCAE8B6D6F0C0D0EAABB4CE84
B9D17BBDD178ABBD6BB8C57FE5EDBAEDF3D1727665000300798079F9FFFAF6FFF4F8FFEC
F8FFD7DBECB6CEDBB0D6E1C1E2E9D7F3F6EDFFFFFFFFFFFF
FBF9FAFFFDFFFFFBFFFFF8FFFFF9FFFFF4F64F3D3192816DDDCEB9F6E9D8FFFEF3FEFCED
D4DAC0CBDAAFCDE3A2CFE59CDFEBABCBD599DFEBAD8FA05C94AA62CCE49AC8E396C0DD8D
C5E292CBE898DAF2A6CEE49B7F934C8B9C58D4E0A0D6E6A7CBE1A0D1ECA9D1EBACF4FFD3
F5FFD8EBFED0F7FFDBCDD9B18E966F7E855C454C22929C6A929F698A9C608BA16096A668
A09D70938B6459572E9FA577D7E4AFC3D59BC7DC9BCFE49FDBF1A9C2D89098AF69B7D28F
ADCC90C0E3ABBEE6B2001A00518157B2E1B5BDDFAD374C14D7E1A5D9DDA0EAEEB3D9E4AC
C8DEADB8D7AD466B4A6D957BC4EAD59BBCAB76918244554DFCFFFFEBEFF8F0FFFFEEFFFF
F5FFFFF3F8FBADAEB2FCFFFFF2FFFFDDF2E9F8FFFDFFFFFDFFEFF2FFF9FDFFFDFDF7F7F5
AFAEACD3D2CEFEFBF6FFFFF6FFFFF4FFFFF4F9F2ECFFFDFBFFFDFFFFF8FFFFFBFFFEF9FF
FDFBFEFFFFFDFEFFFAC9D3BBB2C89998B177CAE3AAC9E0A8C4DBA5C7DEA8DDF1BEC5D7A5
CEE0B0D1E1B2919E70A8B5879BA779D7E3B5CDD9A9D4E2AFCCDAA7E1EFBADBECB5C3D59B
C1D598D6EAABD8EEADC8DE9DCEE5A1D0E7A1D5ECA6CADF9AD1E6A1A5BA75CCE19CCDE29F
CAE09FD7EDAFE4F9C1F3FFD3F2FFD5F1FED2D8E4B6CDD9A7DDE8B0D9E7A9D7E3A1D9E8A3
DDECA7D1E29EC7D796CDDC9B7982438C9252B8C381C9D895D3E7A2D1E8A2C3E199C8EAA0
C2E69CD3F9AEB3DC90C0E99DC4EDA1D3F9AECBF1A6BCDF9BC8E6B4C5E0ADC7E09F7F954A
DCF09BE7F6A1D1DB928C9157E7E8C6FDFEECB1B2AD313332777E77F4FFF0E3F3D8E0F2C8
E6FABFCFE3A6CDDDACDFEBC7ECF3E1F6FBF4FEFFFFFDFEFF
FFFDFFF7F0F7FFF9FFFFF8FFFFF5FFFFF4F8D6C2B9887765564533D9CCBCF7EEE5FFFFF4
D9DEC8DCEBC4C8DC9FD3E8A5D1DFA4D4DFA7FCFFCF8B9B5CAFC481D1EBA2CEEAA0D1EDA2
CBE79AD6F2A79CB66D92A762AABD7DD9E7AAD0DBA1D6E6A8CFE6A2D2EDA8C5DF9EE4FCC2
E6FAC9DBECC2FBFFE3F0FBD9F4FEDCE9F3D0DDE8BEC6D2A2CEDDA4DBEEACCDE39BD1E29C
DBDEA5DDDDA9979C6297A365CBDF9AD5EDA1D3EE9DCDE693CDE591D6ED9BCCE395D0E69D
AEC783A6C381C9E9AA8BB47C0018009BD0A4B2D7A4DCEFB79EA061797633737430D3DE9C
CCE8AD577F4B19491FB9E8C4C2E6CCA8C1AB17221176776FF6EFF6FCFFFFEEFFFFDCFCF9
EAFFFFEAFFFF859797738684B3CCC6E6FBF4F1F7F5FFF9FAFFF7FDFFEAF06F63656C6867
EEEDEBFFFFFBFEFBF6FFFFF8FFFFF6FDF9F0FFFEF8F9F4F1FFFDFFFFFDFFFFFDFFFFFEFF
FFFFFFFEFFFAF4FAEE667355000E00CCEAA2CAE59ECDE8A3CDE8A5D8F2B1BFD799D6EBB0
D4E8ADCFE3A8B0C18AC2D49AE9F8BFCAD9A0E2F1B8C7D69BD5E7A9C4D998C9DE9DD7EEAA
D6EDA7CBE59CCAE49BCAE69CD1EDA2C7E197C7E197D2E9A1CFE6A09FB46FB1C681D2E7A4
D2E8A8DEF3B8F6FFD4F8FFDAFBFFDCFAFFDBAAB386D8E2B0D1DCA4D2DEA0D8E4A2DCE9A4
CDDC97AEBD7A93A3628A9958BCC785CCD795D5E4A1D7EBA6C6DD97D8F3ACC4E49BC8ECA2
BDE398CFF8ACB9DF94D1F7ACC8ECA2C5E79DC8E89FD0EFACCCE7B2CBE4ADD4EAA9485D12
CADC8AD5E293E3E9AB818258FFFFEDF9F5F2E5E2E977787C727971F5FFEAF5FFDFCBE2AA
D2E8A7C9DD9ED9E9B8F3FFDEFCFFF1FCFFFBFEFFFFF7F7FF
FFFDFAFFFCFDFFFAFFFFF3FFFFF3FFFFF9FBFFF0E7BDAC9C564436C3B5AAFFF5F3FFFBF8
D6D8CBCFDABCD0E0AFDCEEB4CCD9A4E4EEBACFDEA7A5B77DC3D999CEE7A3CFEAA5CAE8A0
D4F2AAC1DC958FA8667B8F50D2E4AAC6D39ED9E3B1D0DDA7C7DD9DD0EBA8D5EDAFC9DEA6
C8D8A9CEDBB0D2DEB8FBFFE3E3EFC9DAE6BED7E7BABECF9BDFF1B5D0E5A2C5D992DDEEA8
DCE6A7A7B1729BAA65B2C87DC9E694D0F19AC8E98ECEED90D1E991D0E693D8E99BCFDF96
BECD883E4E0D94A968CEEDB2154919689D71C8EDB9D4E8ADCED391CACA82A4A85E8D9A52
CEEDA983AC706B9B67BDEBBDCEEDCBD8EBCD898B73352F21F7F1F3FBFFFFE2FCFBE7FFFF
EAFFFF9DB6B34E5E5E223231556E6A9BB0ABF8FFFFFAF4F6C7B2B9CDB8BFACA8A7D6D8D5
FFFFFFFAF9F7FFFFFAFEFBF4FFFFF6FFFFF6F6F1EBFFFEFBFFFDFFF8F3F7FFFEFFFFFFFF
F2F4EFF0F6EA767D6B00090068833EBBDD87D1F19EC2E191C8E499CBE79DD1EBA4D0E9A5
DBF1B0C0D69593A768CEE3A2D6E9A9CDE09EDFEFAEC6D695CFE39ECEE39ECEE59FCEE89F
D0ECA1CDEC9ECAE99BC7E696C7E696DAF9A9BAD689D8F2A8DCF3AB849954849956D3E8A5
CCE2A2E3F9BBDBEEB7E1F3C1F8FFD9CFDCB0ACB588C8D2A0C8D39BE8F4B6D0DC9AD2DF99
DAE9A46C7B384A5A19CBDB9AD5E9A4D0E49FCAE19BCAE49DCEECA4D0F0A7CAEEA4C5EBA0
BDE197C4E89EC6E89EDEFEB5C4DF98D2ECA5DDF4AEC9DF9ECDE5A9CEE6AA899E5993A55B
E0EEA3D6DF9EDADCAD858166FFFDFAFFFCFFE2DEEC6B6C716D7868E0F2CCE6FFC3C7E29D
CEE4A3CEE2A7CBDBAEF9FFE8F7FDEFFCFEFDFFFEFFFFFDFF
FEF7EFFBF3F0FFFAFFFFF9FFFFF9FFFFF9FBFFFBF199887877675AFEEFE8FFFCFDFBF5F7
FFFFFAFCFFEFF4FFD8F3FFD0F5FFD1F6FFD299AA76D2E5ADDDF3B5CBE6A3C5E29FC2E09A
BAD892D3EEAB88A160BACE93D2E3ADF1FDCDE6EFC2EDF9CBEAFFC7E2FBC1DFF4BCD8EAB6
E0EEBBD3DFAFDCE8B8EAF8C7DCEDB9C0D29ED8EDB5D4E9B0CDE1A6CEE2A3E6F8BAD7E7A9
DFEDB0CCDC9DBDD28DC7E396CEF29BC6ED92C7EC8FCCED92CAE390DFF1A5D1DC97CDD695
C4CA8E787D431B2300A8BA86CBF2C629532BCCEEBCC0D79FDDECABCDD991C6D489566B20
B0CE86CAEDABC9EFB4C8EAB8C6DDB3F9FFE3E9EDCC98937FCAC0BFF8F5FCF5FFFFE0F6F4
90A2A22F3F3F293436A2B4B444655E000D06152E2AD1DBDAFFF9FEFFF7FBFFFDFEFDFFFC
F8F8F8FFFFFDFEFBF6FFFFF8FBF6F0F6F1EBFFFEFAE2DDDAFAF6F7FFFEFFECECECA9ABA6
0C120638412E7E886FCDDEB1BEDA8FDDFEA5D4F59ECCE995D1EE9ECDE79DCBE59CC5DC98
C7DD9CD6EBAAB6CB8ADDF0B0DAEDADCCDC9BD7E8A4D7E8A4D3E8A3D1E8A0CDE79ECAE69B
C7E698C7E897C9EB97CBED99D5F7A3C4E692CDEC9ECEEA9FC3DA92ACC17C718442CADF9E
CAE09FD2E8A8D2E7AEDBEDB9CEDEAF98A5779BA777E8F5C0D0DBA1C2D19097A45F8C9C55
95A55ECEDF99D6E7A3CFE4A1C5DF98CDE8A1D2F0A8CEEEA5C3E59BBDDF95BEE298C5E99F
C8EAA0D8F8AFC5E099C2DC95D3EAA4C2D691CBDC98E2F2B16F8344708445BACE89D7E6A1
CCD795CED59FDCDEB9CDCAB9FFFBFDFEF8FFE3E1EC696D6C65735AD0E6B7D4EFA8C4E095
D1E7A7D9EBB9D4E3BCFBFFECFCFFF8FEFFFFFFFDFFFFF9FF
FFFFF3FFFEF6FFFBFFFFFAFFFFFAFFFFF1F1FDEDE06C5C4CB9A99CFFF8F2FFFBFFFCF5FC
FFFFFDFCFFF1FBFFE3FBFFDAFBFFDC414E20BECF9BDFF4BBC4DC9ECDE8A5C8E5A2D0EFA9
CDEBA5DAF5B2859D5F8EA16998A673DBE7B9FAFFD9F9FFDCEBFFD7EEFFD9F7FFDCD5E6B2
D2DFA7C8D496DCEBA8CADB95D5EBA2C9E39ACBE6A1D1EAA9D3E8AFC4D5A1E9F6C8FCFFDA
C1CEA0DEF0BCCCE4A6CAE9A3CAF1A0B9E38DC6ED9ACCED9ED6F0A9CADA9CDCE3AF9D9C70
56532AF0EBC5F2EDC7363813C4D5B36C8663809D71D0EEBAC5E7AADAFBB6C4E49B4D691F
91A862C9DC9AD8E6ABC8D5A0D0D9AAFCFFDCFBFFDDE7EACFDBC7C69D88914E444C030106
0A050B545158797E82D7F0ED598F826FAF9FA3DDCFCEF8EEF5FFFFFFFEFFFFFEFFFAF6F7
FFFEFFFFFEFFF4F0EDD7D4CF8C8781908B85BAB5B1FFFAF7D6D2D1A3A2A0000100020500
69705EE3EDD2D1DFBCD9EDB8D3EEA1CDEB93BDDB85C9E493D2EDA0CEE89FD5ECA8D0E4A5
CADEA1DCEEB4C9DBA1F3FFC7F3FFC7D3E1A4C9D799DAEAABD3E8A5D1E8A2CEE89FCBE79C
C7E698C7E897C9EC98CCEF9BD2F5A1BBDD89D1F0A2D0ECA1BED58DD8EDAA8FA262C4D998
D1EAA6C5E09BC7DFA1D8EDB4C7D9A595A67294A26DC5D49B7280423243004C5C15D4E69C
D2E79CD3E9A0C5DA95D0EAA3CEEEA5C7EBA1C3E79DC2E69CC4E89ECCEEA4D4F4ABD8F8AF
D3F1A9C3DE97D7EEA8D5EAA5D8ECA7D8E7A4CFDB9964702E95A566CDDD9ED5E4A3CFDB9D
D5DEA5F4FCCDBDC0A3FAFBEDFFFFFFFDFCFFE7EBEC646C61586746C7DEA6CEEA9FD5EFA5
D6EBB3F2FFDBEDFADEFBFFF3FEFFFBFFFEFFFFFBFFFDF5FF
FBF9ECFDF9F0FEF5F6FFF8FEFFFBFFFFFBF8E9DBCE938675FDEFE2FFF2ECFFFBFFFFFCFF
FAF8F9F1F3E6FCFFE4F5FFD6778456DDEDBCC0D39CBED398D2EBAACDEBA5C7E79ECBEBA2
C6E49CBDD893D8F1B0D3E7AC7A8855A0AC7EEDF4CBFCFFE1F5FFE4DBF1CBECFDD1C5D3A0
D8E2A6DAE5A0E3F1A4CDE08ECEE891D8F5A1C3E296C2DF9CDFF4BCE4F4C7F2FCD7F4FBD9
AAB48FE4F5C8CAE3AAC2E29FC7EDA2B7E091CAF3A4CAEBA4BFD79BD3E1B0D3D7B2B4AF91
A59B82FEF2DAFFF5DB5952387A7D6265725421391525491D537F4A6F9F63CDF7B7B7D794
849755BEC786DEDEA2E9E6AFE1E3B1E4ECBDE3F4C8FCFFE6FFFAF6FFF1F791868A756F71
73686EFFFCFFC2C7CAD2EFEB84C2B32C7965539A8863958AF4FFFFFDF8FCFCEDF4FFFAFF
FFFDFFABA9AAACA8A7CBC7C4DBD6D2A8A39DEFEAE6ACA7A303000062615D43443C414838
A0AA91A5B3907182565C7138CFE99FC9E591C3DE8FD6EEA4D3EAA6C7DD9DD1E5AACBDCA6
DDEDBCE4F2C1CEDAAADAE6B6E1EABBF2FCCAEAF4C0DFECB4D3E7AAD0E6A5CDE6A2CBE99F
CCECA0CCEF9FC8EE9BC6EC97C6E995C8EB99C2E193D5F1A6CEE59FDBEEACC9D99AA9BC7C
D1EDA3C7E59BCBE6A1D1E9ABCFE4ABC3D69EB2C48AA0B276B6C987D3E79FD0E598DCF1A4
C8DF91DBF3A7CAE199C9E79FC5E99FC2E89DC4EA9FCAEEA4D0F2A8CCECA3C2DD96B7D18A
C7DE98CBE09BD2E6A1D5E6A2BECF8B81924E94A360B5C483E1ECB0C7D298E4EFB5E1EBB6
C7D19F8E966DB6BD9EF8FFEBF4FAF0F4FBF3F3FEEE76846B6C7E54D6EEB4CFE9A2CFE8A4
CEE1B3F9FFE8FBFFEFFCFFF6FBFBF9FEF9FFFFFBFFFFF5FF
FFFFF4FFFFF8FFFEFFFFFCFFFFF6F9FFFAF89B9185A39886FFFCEEFFFBF2FFFBFFFFFDFF
FAF6F3FFFFF1F5FDD8BFCB9B94A26FCCDDA6DDF1B6D6EFAEC8E39CC7E59BB9DA8BD3F4A5
C3E294D7F3A8BFD894D6EAABE0EFB8D8E4B482895FF4FFD7E7FCD5BED3ACDDEDC0727F49
535C1D6B752C9DAC5BD1E58EC9E68CC9EA93C8EB9BC8E7A1D7EFB5F9FFDCFBFFE0969B7B
BCC3A1F3FFD7D2E6B3C5E2A2CBF1A8C0E99BCEF7ABC3E6A2D0E9B2D5E4BBE2E7C9C2BDA9
8F8675FFFDEDFFFCEB9186740701002B2F186B7F64000E0025573200340A134311D2F5BD
D2E1A8BFC08482783D7B70389C9964D0D6A6DAECC2F7FFE7FFFFF3FDF8F4CED3CD7C8580
FEFFFFFCFFFFBFCBCB5E7E794987785AA392D2FFFFCBF0E9FFFEFFFFF7FFFFEAF8E2C2CF
C6B9C2EDE8ECF3EFF0403C391B16128E8983C0BBB5FFFEFAFFFFFAFFFFF8FEFFF4ECF4DF
FAFFE5F9FFDDF8FFD6BAD0928CA35D94AB639DB470B8CC8FC3D69FCBDBAADCEBC0D4E0B8
EAF4D1F5FFDDE7EECDBCC3A2A9AF8DF9FFDBFFFFE1FDFFDBE4F5C1D8EDB2CCE5A4C8E5A2
CBEBA2CDEFA2C8ED9DC2E996C3E996D0F3A1C3E294CEE89ED8EDA8C8DB99DAE8AA7C8F4D
C4E395C9EC9AD1F1A5C8E6A0C2DC9BD2EAACD7EDADC0D695C2D890DBF1A6D1EA99CDE695
D8F3A4D0EC9FC2DE94D2F2A7C2E69CC6ECA1CDEFA5CCECA3C9E49DC8E29BD1E6A1DAEBA7
D5E6A2C1D28E8B9A578D9E5AA1B570C3D893CFE6A0CDE0A0D1DAA5E7EDBFF9FFD1F4FBCF
C1CCA2FBFFDFF8FFE2E5F4D3D7E6C7D6E7C5D0E1BD586D42556B3AC5DCA4C9E1A5C9DDA8
C7D7B3F5FFEBFBFFF4FAFDF4FFFFFDFFFDFFFFFAFEE8D9DE
E1E2DAFDFEF9FAF8FDFFFDFFFFFAFFFFFDFB847C6FC5BDAAFFF8E7FFFDF2FBF2F3FBF5F7
FFFFF8FAFCE7949B718A9761ADBC83C6DA9DD8EEADBAD48DCCE89DC3E292E4FFB0BBDD87
CEEE99BCD989D9F3A9CEE3A0C8D79CD2DCA89DA576B3BF91EBFFD2849A6998A973939E64
A1AA698D944E859145C3D684C9E591C6E894C7E99CCAEBA4D7F1B4E8F8C7B9C198A0A47F
CFD0AEEEF5CCD2E3ADC6E09FCCEEA2C7EE9DCBF4A6C0E49EDFF8C1D9E9C2E7EDD3ECEBD7
DFD7CAF4EBDCFFFDEDBDB5A20800000A0C008D9E8C3C5D4C0F3E2A21563C022F0EC1E4BA
D7E8B4E5E6ACBDB376B6AC6F8F8A53999C6D98A780D1E0C3E8EBDAF9FBF0F7FFF8F5FFFA
EBF0ECFEFFFFA1A7A70C201E164138A8DBD2E2FFFFEDFFFFFEFDFFF5E5EFD3C2CCBAABB2
FBF1F9FFFDFFA09C9D4743408E8985FFFBF5F9F4EEFFFFF8F6F6EEFFFFF6F5F9EAFBFFEC
DAE9C2E2F4C2DDF2B7D5EBABCADE9FCDE1A6C3D49ECFDFAEE2F1C6EAF6D2ECF7D9DBE3CB
FAFFE9FBFEEBFFFFF1E8E9D7B2B49FD1D3BEE9E8D3FFFFE6F9FFDAE5FAC2D1E9AFC5E2A2
C5E4A0C6EAA0C6EB9DC3EA99C8ED9DC3E696D4F3A7C3DD94D6EBA8CFDFA0D2DDA1748843
C6E894C2E990C8EE9BCAEC9FC7E59FCEE9A6D4EFAAD1EBA4D7F1A7D0EB9CCBE793BDDA86
C1DE8CC8E797D0EFA3C3E398CDEFA5C8EAA0C5E59CC8E39CCFE49FD6E7A3D9E5A3D9E4A2
D1DC9A939F5D8D9C59DAEEA9C8DD98C7E19AD3F1A9D1EAA9DCE3B9CFCFADFFFFE1F9FFDB
959F7CF1FFD9E9FCCFECFFD1CAE2AECAE3ACBCD59C6780476C834DC7DEAAD8ECBBD8E8C1
DEECD3F1FCECFCFFF8F9FCF5FFFEFDFFFCFBFBEDECB0A19E
E9EBE8FEFFFFFEFEFFFFFDFFFFFAFFFFFCFC7A7265A8A18EFFFFEDFFFCF1FFF8F5FFFEFB
FCFAEEE8EBD06D7544A9B478DEF0B2E1F6B3C1D890EFFFBDD3F09EC7E891C2E589CDF094
D3F499C5E38DDAF5A4BED48BDDEDAEEAF5BBD3DCA78A9761688140A7C07ED8EBA9C8D494
DFE5A5F3F9B9CBD6948D9E5ACBE6A1CDEEA7C5E9A3C3E3A0D6F0AFC1D598858E57E4E6B4
DBDAAEE2E4B5DBE6AAD0E69DC8EA94C6ED94C7EF99C3E89BF2FFD1F7FFDCFCFFE4E6E8D0
DCDBC79D9B86F1ECD6F9F4DED6D6BE04080065756B91AAA64D6F6E49706B6085741C391B
3447195B642B787838E0DF9FD6D59DD4D5A9929777A0A38EAAA997A1A395D4E2D1CEDCCF
959691BEB4B57A69711C111980888BF2FFFFCCDEE08B9B9BC6D4D5CBDFDDA2CAC1BEE1DA
979FA2030004827E7FB7B3B0FFFEFAF5F0EAFFFFF8FFFCF5FEFEF6FFFFF4F9FEEAECF7D9
D8E7BCD3E6AFBCD292DEF4B3CFE0A9D6E6B7C6D3A8D7E3BFF9FFE6FCFFEDFCFFF3FEFFF6
FFFFF8FAF9F4FFFFFAFFFFFAE9E6DFC3C0B9A4A097FDFEECF6FFDCE9FDCCDBF2BECFE8AF
C6E4A4C3E7A1C5E99FC5EC9DC7EC9CC0E393D5F4A8C5DF96D4E7A5DCECADD2DDA1879B56
CDEF98C0E98BBFE78FCAF09DD1F3A7CAEAA1C3E199C5E197CBE79AC2DF8DCBE894DEFEA9
CAEA97CDEE9DCCECA0C5E59AC7E79EC4E29ACAE49DDAEFAAE3F2AFCFDA98A4AA6A7D8343
B5BB7BDAE5A3CEDD9ACDE29DD5F0A9C8EAA0BEE499CBE7AAFFFFE3FFFFECFFFFEC7A7E63
D3DCBDE1F2C8CEE7B0C1DE9EC1E198CEEEA2D7F7ACC3E19BCBE4AAEEFFD3F1FFDDECF8E0
F9FFF3F4FEF3FCFFFAFCFDF8FFFEFBFFFDF8FFF0E9A19088
E7E7E5FFFFFFFAF9FFFFFDFFFFFBFFFFFAFE97908AA09A8EFFFBEDFBF4EAFFFEF8FFFFF8
BFC0B2E3E9CF929A71D8E5ADCBDA97D5E59CFBFFC1D9F0A0CBE491D2EF9BC8E992CAEC95
C3E58FCFEF9ABCD989E3FEB1BDD38BCADD9BDCECADD4E7A5C8E49ADEFAAFC8DC95DDE9A7
D6DC9EA7AD6FA7B174A6B977CEE9A2C3E599D1F7AAC0E49AC1DF99DDF2B1A5AF73DADDA8
F0EDC0E9E8BAF0F9C0E5F6B2D0EB9ECBEB98C7E897CAEA9FDFF9BADDF1BCE2EFC4E2EAC5
DEE4C2B8BE9A828661FAFEDDF0EFDA0E1003000500677B7CA2BFC34E72723D625A40634F
547250455C2E111F006168357A7B4FE3DFBAD9D3B9EFE8D6F7F3E8F9FBF0F8FFF6CDD9CB
B5B6AE8C817D200307785D62ACA3A6C8CDD0E4EFF1889C9DC5E3E38CB6B23E776E497A74
203236888B92E4EAEAF8FFF8F9FFF5FEFFF4FFFFF4FBFCEEFFFFF3EEF2E1F9FFECD7E9C3
CDE3B2CEE8A9D5EFA6C8DF9BD2DFB3E4EBCAD2DBBEE3EBD3FCFFEFF6FCEEF4FAF0FCFFFA
FBFDF8FFFFFBF5F6F0E4E4DCF9F6EDE8E4D99C988CE4E6CEE6F3C7E6F8C4E5F8CADDF2C7
D0EABDC8E4B1C6E5A9C9EAA5C7E99DD0F0A4C8E49AD0E7A3CFE1A5D5E3AED5DEAF8F9E65
CAE699CBED96C7E995C3E493C6E798C6E597C7E698D1F0A0C3E292D7F7A4C0E28ECAED99
B9DC8AD5F8A6BEE393C7E99CCBE9A1CDE6A2CFE5A4D3E5A7D3E1A4C4D092ACB67799A460
D0DD95CADA8FD8EDA2D3EBA1C8E5A2BBDB9CD8FBC1C6E0B3F9FEE7FFFFF0D6D8C3D7DDC3
D2DEBACBDFACC6E09FCEEEA2CCEE98CAEC95C5E592CAE5A0D1E5B2DDECCBF6FFF0FBFFFA
FBFFFAF4F9F2FEFFFBFDFEF9FBF7F4FFFDFAFFFDF4BEB1A8
C2BDB7FFFEFAF6F0F2FFFBFFFFFBFFFFF7FFAAA0A8ACA6A8FFFCF9FFFFF8FDFEF6FEFFF6
E4EDDCDAE7D3DDEBD2B8C49CB0B572CACD7E9BA25466712394A459CADE96C7E19AD0EEA8
CEEDA7C9EAA3C3E39AC8E89DC6E597CDEC9CD9F6A4BBDB88CCED9EC7E59BD6EBA6CCDB9A
E5EFB2909A5B90A059C9E291C7EA90C4ED8DCEFA99BFE78EC5E496D4E9A6CDD6A1E3E6B9
F1F3CCFFFFDBFFFFDAF4FECCD5E4ADCFE3A6D6EAABCEE4A3CFE5A5D9EDB0D1E3A9D9EBB1
D1E0A7CAD9A0B1C085B6BF92FFFFEFCCC4C20002000009068AA9A3B9E2DA2A5C510B3F32
6B9B8BCCF5E3B3CEBB5E6B5732311C3327118B7560847162BDB7B7ADB1B4E9F2EDF9FFF8
F7FFF1FFFFEFCDB1A6FFE5DCFFFFF4F4FFFBE8FFFEBCE3E082B6B226595A395E641C3742
B4C4D3F2FFFFE9FFFFE3FFF5EEFFF4F4FFEFFCFFECFFFFECFFFFECFBFFEAE9FFDDD4F6C4
CAF0B3C3E9A0C5E494D3E8A3DDE2C2ECEADBE9E9DDFAFEF0F8FEF2FBFFF8F9FFF8EEFAEE
F9FFF6F3FEEDEBF3DED6DCC2D2D5B87475559A9A78A0A376B0BF7CCBDE9C8190695E6C55
617166859787E0F5D488A06C627D38627E339AB46DD1E7A9D3E3B6D0DBB9D5DFC4A0AA88
4D5A24D0E19DD3E49EDEF4A9CBE493C7E38FD4F29CCEF099C8EA96CDF09EBEE393CAF1A2
C0E798C3EC9DC3ED9BCAEFA1D1EBA4DCF1B0C6D9A1CDDFAB637744D9EEB6CFE5A4CBE699
D3F096CAE78AC4E386D2EF9DC7E1A4D1E8BEF4FFF3F1FFF4FBFFF6EDF4E2889279D9E7C3
CDDFADCDE6A5C5E194D4F29ACBEA8DC8E68EC7E295ECFFC6F1FFDCFBFFF4FCFFFFFAFAFF
FEFFFFFEFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFEFBFFFEFB
AFA99DFDF6ECFFFCFAFFFBFFFFF9FFFFF3FFBDB3BEABA4ABF7F3F2FFFFF8F7FBECF1F9E4
F2FEE8F7FFEFECFBE6F9FFE3D8DF9CDEE393D9E092E2ECA395A45F708343C6DC9ED2ECAF
B9D598D7F4B4C9E6A3CCEAA2DAF6A9C4DF8EC6E28DE1FEAACDEC9EC1DF95D3E8A5DBE9AC
BCC68A909A5DFBFFC5CAE390CDF092BBE581C0ED88C9F093DAF6A9C0D2946C744341431C
5C603B8E956CCBD3AAE2EBBED7E3B1D3E2ABD7E6ADCEE0A2C9DE9DBFD491D1E6A1CFE49F
D3E8A3CDE29DC2D792606D37DCD7C3EDE6DE0002000006000011004E7864AFE2D1669C8E
002B2296C3BCC0E3DDF1FFFDFBFFF69893800D0000615441040400000200656D62F9FFF4
F7FFEFFBFFE8FFE5D7E3C8BDFBFFF1DCF6E9E7FFFF93C4C13B7C78001210000810596D78
E6FFFFE7FFFFE5FFFFDAFDE9CCEBCBDCF5CEF4FFDADEE4BED2D8B4D4DEB9CEE3BAC9E6B6
C4E8ABBCE49ECCF2A5F3FFCEFFFFE86B675EBAB7AEFFFFF6F4FAECF8FFF2F8FFF3D4E3CC
D8E8CDECFBDCE1EFCCDFEAC2D2D9AF55582B7678498D925898A65B6F803C000800000400
000305000503D9E8D15F75475C7534CCE69D000E00CFE1ADD8E6C25E6B51000900000400
010600373B08CED89CBFCB89E4F6AAD0E795CDE994B6D780CEF09CC0E393BCE193CBF1A4
C1E79AC9F2A3CFF6A5C1E494C0D78FCCDF9FA2B57D425621D1E7B6CAE3ACC3E09DC8E998
C9ED8DCDF28BCCEE8DD3F09EC3DBA1CADBBBF5FFF9F8FFFFF7FFF1F9FFEA94A27FBCCDA1
D9EEB6BDD694E3FEB1BBD685CEEA96CDE597E3F8B7DCECBDFBFFECF0F5EFFFFDFFFFFCFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
BBB4A4F5EDE0FFFDF6FFFCFBFFFBFFFFFBFFE4D9DFAFA6A7FFFFF6FFFFF1FFFFECFBFFE5
EBF4D5ECFAD9D9E6C8ECFBD2D1E1A2CFE197DBEFA7C1D691CBE1A0BCD294758D538BA369
96AE74C1D69BB9CB8DA7B7769DAA658C9850A4AE65CAD88DCFE79DD4EEA7C9DC9CD0DEA3
F4FDC67E874ECEDC9EC6DC93C9E996C7EB93CAF198C3E694C9E29ED5E4ADE5EAC1FFFFDF
E2EBBEDEEAB8D9E5B3C2D19AA0AF76899B5D798C4C637835B5CA85E3F9B1C6DD95E2F9B1
C3D991DFF5ADCDE39BC8D79CCACEA99FA285B1B899ABBA9B000E00001A00335940A0CAB6
ACD5C7577F74698A7FA9C8B9E8FFECF4FFEDF8FFE6FBFFE3F0FAD7FCFFE370795C040E00
0008005B5E49654A418D74707C817B9EB8B581A4AA002227185A5844837BE4FFFFE7FFFF
C8FBF283B7AAA9D0BBD7F2D3CBDCB2E2EEBCFEFFD1F1FAC3DAE1AED6DCAED7D9B2DCE4BD
D7E8BCC2E0ACC4F0B3E9FFDBF5FEE3AFAC9DF0EFDDF1F4DFF0F8E0F7FFE6EFFFDBC6D6AF
EFFFD6F8FFDCEAFACBD7E3B1C9D1A0767A48060800787D43B3C07B000F002B3614B1BCAE
D5E0DC000D041C2C11677A4CB2C88AD3E9A86F824A68794CCBD9B8071100000500C7CDB3
7E7F5F04040096996AAAB37A8B9A579CB166E0F7A9E3FEAFCCE89BD4F3A7CCECA1C3E398
CFEFA4C7EA9AC0E190CBEB98D8F0A492A86091A665CFE5A7C2DA9EC9E3A4DBF9B1C5E592
C6E78CCEF091CAE88ECCE89BCAE2A8D1E3BDEFFCEAF9FFF3C9D3B0E5F0C58C996BDDEDBE
CEE0AEDEF3BBC1D69DCFE4A9CFE4A9E5FAC1ECFECEF8FFE3F9FFEFFCFFFBFAF8FFFFFDFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DFD8C5EAE3D1FFFEF3FBF2EBFFFCFBFFFCFBFFF9F8AFA69FF8F2E2F9F7DEF8F9D9FFFFDF
D9E0B7D3DBB2E1ECC2CDDAACC6DA9FD2E8A8D5EBABD8EEB0CEE6ACC4DCA2D7ECB4E8FDC5
F7FFD2E9F8BFDAE5ABD7E1A4D3D99BDCDE9DBBBC7A565B18B1C57ED8EFABCBDA9FD5DFAA
CBD1A1C5CD9CD2DFA9D0E2A6CBE6A1CDEDA4D0F0A7CEEBA8CFE4ABD0DCAEE2E6C5FFFFE1
E9F5C3D6E8AECEE0A4CEE0A2CFE4A1D8EDA8D8EEA6CAE098A5BB7293A9608EA65C9CB46A
E0F6ADCFE59DC2D890DBEEAED0DDA8E5EEBF8A966693A37497A87C344922001600627E65
9DBAA888A8995B7D6D3D62507EA68C8AB393C6F0C8B2D6A6D8F0B4C9D69ED2DEB0DCE8C4
D2E3C3737861B49E90614D44333D3504211F284A540026303E7E7ED1FFFFE2FFFDD2FCE6
AFE6CF3A70566D9070CDE4BAD8E9B2D7E7A6CFE59DC9E098D3E7A8D2DFA9D8D8B2EBE8C9
FAFDE0F3FFE2E6FFE3EEFFEAFCFFEDD5D2BFF1F3DBE2E7C9E4EEC9D9E9BCE4F4C35F723A
CBDFA4C6DA9DD7E6ABD6E4A9D2DBA49BA26C0E1000878C56D2DCA0818D5B050E00363E2F
69736A000600AAB998CDE1B0D8EDB280955A7587573F4E27B6C0A5333D24000600DADEC3
8A886F1B1A00D1D1ABDDE3B3D3DEA4B3C27F6B7F38C1D78EC8DF97D3EDA4CEE9A2BED992
D8F4AAD3EFA2C2DF8DD2EE9A8BA453DAF2A4C6DE94D0EAA1D2EDA6CDE8A1B9D88CC9E898
CBEB96CCE995C1DE8ECAE49DE3F8C0F0FFD7F6FFE7FBFFE6DBE5B1CFDA9E818E5894A271
E8F8CBD5E4BBF8FFE3E0F0CCE2F2CEF6FFE4EEFBDFFBFFEFF5FBEFFEFFFDECEDF2FFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DFDAC4D1CCB8FFFEF1F8EFE6FFFCF6FFFCF8FFFDF4A99F93FFFFE8F6F1D1EEECC3EDEFC0
D0D4A1DCE3AFD4DDA8D9E3AFECFAC9C1D3A1CADCAADAECBAC6D8A6CADCA8E0F1BBD8E9B3
FBFFD3E4F1B9D6DFA6DCE4A9E1E7ABF3F4B8CECE92575B1E8A9958C7D99BEAF7C1DDE5B4
DAE0B4C1C69DDDE6BBD7E7B8D6EAB5CDE6ADBED79EC3DAA6D6E5BADEE5C3EBEBD3F9FDDC
DDEEB7D0E9A5D2ECA5D1EBA2C9E098C7DF95CAE296C6DE92D7EFA3849C509EB66C89A157
C6DD95D4EBA3D6EDA7CFE4A1D7ECA9DBEEAEEEFEBFA7B57ACDD7A2A1AA7B131D00000700
5E705AC1D8C6C0E1D06D978123583A54926BAAEFC0BEFABEC3E599D2E79CDEEBB5C5D5A8
C8DDB6DAE5C3A3957AAFA38B9BAA95335348000912184451D2FFFFCDFFFFE0FFFA8AB194
69917650735394AD85CBE2ACCBE6A1C3E696B6E78EC9FEA6B4E596C8EBABDCE8C0F1EFD6
FFFDF1FFFCF6FFFEFBFFFFFAFDFBEEF3F2DDFFFFE6C9D1AAC8D4A4D0E2A8C5D896001300
D4EA9FD9EFA4BCCD87D5E4A19DA86C4E551F1B1F00484B1CC6CE9FDBE6BE707860000500
000500010F009DAE84CFE1ADD5E8B070824E25330F4A5739AEB8A06C755A242B09737957
393722040200EDECCEC8CDA4E8F1BCDAE8AB6777369FB36EE1F6B1BFD48FDAEFACDCF1AC
C2D890D0E69BC4DB8B9FB6649CB863DCF8A3D2EE9ABBD886D4F1A1C3E294CBEA9CC9E89C
D0ECA2CCE7A2CBE4A3D7ECB1F3FFD0FBFFDCF8FFDEF7FFD5DBE6A4D7E19ACAD498919A6B
C9D3B0FCFFECFBFFF3F6FFF5F9FFF8F1FBF0FBFFF8F3FAF2FCFFFBFEFFFDF7F8FAFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
BDB8A2BAB5A1FFFFEFFFFDF2FFFCF6FFF5ECFFFBF2A39886D4CAAFDAD5AFEEECBCDDDDA7
E8ECB1CAD0923C4206555C2633380F5B613DDFE5BFCAD1A8ACB58AF7FFD1F8FFCEF3FDC8
CCD9A1DCEAAFD3DEA2CCD79BCBD799CBD598D9E3A6D8E3A7A0AE71EBF9BEFDFFD2FEFFD8
D6DAB5919572D2D9B8F2FDDBECFCD7F7FFE1F7FFE1F8FFE4FCFFE8FCFFE9FFFFEFFFFFE6
E4F9BECBE99FC6E49ACDE99ECEEA9FD3EEA1DCF4A8DCF4A8CDE599D0E89EC9E0988BA25C
8FA660CBE29EC5DB9AD8EEADCAE19BD6ECA4CFDE9B9AA465F0F5BDD8DAA99797710F1200
0006007D8E7CDFFCEABDE7D1AEE7C7347B53004B1B8ED496C7F2A3CCE79ABFD398CADEAD
DEFACAC3D6A8ACAA7AB5B486CBE2B8C1E3CABEDCDC5C828BC9FEFFB2EBE473A089507554
8FB291BFDFB8D9F9C8C6E8ACC1E9A0C3F2A1B4EC95B9F09DB8EAA1DBFFC8F3FFE0F9FCEB
FFFBF9FFF9FFFFF1FFFFF0FAFFFEF69B9D87D3D8BACDD5ACDFECB7CDDD9CC6DB9099B05E
79913D95AB59AABC72859451DEE9AD666E3B373D1140441F9EA482C8CEB2000400060E00
E7F1D88C9A762F3F0E9AAD75A3B67FF8FFDC6B785C0005003D4530E1EACF626A43020900
73735B040300949778DCE3B9CFD9A4DEECAFCEDE9D8EA25DA6B977D8EBA9DBEEACC9DC9A
C9DD96C7DB9393A559BCD280D1ED96CDEE95BBD981D8F9A0D6F6A1C8E797BFDD93DCF7B4
C9E3A6CDE4AEE3F7C6E5F7C7E6F3C7EAF7C9E4F0C0EBF6BED0DA93D1D892E4ECB3CAD1A7
EAEED5FBFEF3FBFFFEF9FCFFF9FCFFF8FBFFFCFFFFFCFFFFE7E9E6FEFFFDFAFCF9FDFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A19C88B0AB98FFFEF1FFFDF4FFFCF6FFFCF6FFF9EE928574E0D5B7FFFCD5E5E2AFCDCC93
DCDC9EB0B3705A5C1B95945CFFFFDF67584154482EA89F805B55311A1700848655EFF6C0
D5DFA3D9E7AACEE1A1D3E9A8D4EDACCEE8A7D1EEACCAE2A4C0CD95FFFFD3EDF3C5FFFFDD
545837B6B99CE5EBD1FCFFECF3FDE5F9FFEDEFF9E1F1F9E4FDFFF2FEFEF2FFFFF6F7FBE4
E2FAC0C4E499BFDF94CEECA2D5F1A7D1EBA1C9E197BBD28AC6DC94E1F6B1C2D79692A667
DCF0B3D6EAAFC9DEA5C7DCA1CBDFA0D2E5A5CFDB9DA3AB70C8CB96D4D3A7F5F1CE3E3C23
0003006B7668F1FFFAA5CAB8C5FADE79B9963B865B4B9059C2F4AFC0E39FC6E1ACE1FBCC
AFD29CD6F4B6929D58BCC87ECBECA7CDF3C0EBFFF59BB9B94D797A8ABBB50F3623587D5E
C0E9C1C5F3C4A8DDA5AAE2A3C1FAB5BAEDA8BBE5A5CEEFB6D0EABBE7FDD9F2FFEDF6FFF9
FCFFFFFFFCFFFFF6FFFFF8FFFFF9F7848575DDE1C6E4ECC5CFDCA7D7E7A6C7DC914A600E
98AE5BD9EF9DBFD089DDEBADD6E0ACD9E0B7010500010400656952E7ECD80C1000000500
C4CFAD6A7A4D20320090A266677842000900D9E2CD020A00000400D0D6BC70774B111900
D5DABA6E735569714AD4E0AED6E5AACCDF9DDAEFAAC4DA9294A964839855C9DE9BE5FAB7
849853C7DB94E0F2A8D7EE9EC8E690BFE288E0FFA8BDDE85C8E893C3E294D5F0ADC1D8A0
D0E6B8D2E3BFF6FFE4F0FEDBD5E1B9D4E0B2D3DDA8DBE5A9E4EBA8E5EBAD76794AFFFFE3
F8F9EBFEFEFCFFFEFFF8F7FFF2F1FFFEFEFFFCFDFFE2E3E58D8F8EF6F8F5F4F6F3FEFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
999385AEA89CFFF9F2FBF2EDFFFCFAFFFBF8FFF7EE7A6F5DC0B599FFFFD8D7D4A1EFEFB3
DADA9A939651B2B570D7D49DFFFADDB09B8A7C6752766549B8A988A9A077585424949760
DFE7ACCCDA9CD3E8A7D5F0ADB8D794D4F7B3EDFFCFC6E4A6A1AE79DEE1B2E7ECC3C6CAA5
878B6A95997E6F745ED2D6C5D5DCCCFCFFF6FEFFF8FFFFF8FFFFFAFEFAF7FFFEFBFFFFEF
E1F8C4CAEBA6C9E8A4CEECA6C7E29DC4DD99D1E8A4DCF1B0DCEEB0C7D99D6B7C45BDD099
C2D4A0CCDEACCDDFAFD7E9B9D8E6B3CFD9A7C3CB988F9263E5E3BAF6F2CDFBF5DBFFFFED
6565590003006E7F75EDFFFBDDFFEFBCEED1B0E9C625603046793E98C487C0E1B2C3E4B5
C6F2B7C2EAA4B0C673BDD47CC5ED97C1E8A7F4FFECE1F5EA6C8F8928504597BBA1BDE3BE
BCEABCB7EDBBABEFB6C1FFCE81C48E1951205D815BE8FFE2F5FFEFF3FFF2E9FFF3EFFFFF
F5FFFFFBFEFFFFF2FFFFF8FFFFFCFCEAECDFB0B59F505A375C6A3988985AD7EBA4CADF94
D7EC9FC3D88DE2F2B1CFDEA7D2DDB3D5DCBDB3B6A15E6150AAAC9EFAFEEFFEFFF1ADB69B
29350D000D008FA260D5E8A66F804A2130090005003239316A7064D2D8BED7DFB0081200
657045000900A1B27EC8DC9FD2E9A3D1EBA1CDE89BD0EB9EB4CE85A7C17AA8BF7BB6CC8B
899E5BD6EBA6C3D790D5EDA1D2EF9DBDDF89D5F7A0BDDF89CFEEA0CFEAA5D4ECB2E6F9CC
E5F5D8DCEAD3F9FFF1FBFFECD5DFBCD5E1B3D4DFA7D5DFA3D9DEA68F9263F7F8D6F8F7E2
FFFFF8FFFEFFEBE7F5FFFDFFFFFCFFFFFDFFF6F5FA838486343633AEB0ABFAFCF9FEFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AFABA2FCF7F1FFFDFBFFFCFDFFF9FDFFF7F9FEF3EFB9B0A1675D428F8A64E7E4B1E5E5A9
979958585D1AD0D690E7E6ADFFFEDEFFFCE8DBC9B1FAE9CDFFFCDBF9EDC5E0DAAA5A5923
CED198DAE4A7DCEFAFCCE5A3BBDA97DEFFBDE1FFC5D5F3B78E9768E2E3BBDBDDB6D4D8B3
DFE5C3FDFFE7F7FCE6FBFFEECCCFC4FFFFFBF7F6F4FFFEFFF6F1F5FFFAFEFFFDFFFDFFF3
D6EDC1D6F5BAC6E3A9C4E0A5CAE2A8D1E6ADD7E8B1CFE0AA8B996652602F8F9C6ECFDFB2
CFDEB5D5E5BED4E4BFCDD8B6DADFC1E6E6CA747556CFCEB0DFDEC2E6E4CDFFFFEFFFFFF4
7C7D78050908000908697873EAFFF3CAE6D0C2E0C6BFE7C2184C1B0016005C8259BDE4B7
C3F5BAACDB9395B260C7E38CBBE58FCEF3ADF3FFDDF7FFEBF0FFF4EBFFF1C1E1BAB9DFB0
BAECBBADE9B6A8F0C0B1FCD175BB998FC9B3DFFFFCEDFFFFE9FCFFF1FFFFDFF9FAEDFFFF
F1FFFFF9FFFFFFF8FDFFF7FBFFFEFDFDFFF9FDFFF2D9E2C7D7E3BBCAD8A7D5E7ADCFE1A3
CFE1A3CDDFA3D1DFACD5E1B9D7E0C3DDE1D0ECEFE4FCFFF8F9FCF3FEFFF4FDFFF0FCFFE8
F3FFD2EDFFC3D5E9A1CEE49CCDE1A6CADAB335402FCAD1C9D5DBCFCAD3B8D7E0B1CBD99E
52652D8CA468C8E19FD6F2A7CBE896C2E38CC4E58EC6E892C9EA9BC9E99ECAE8A2CCE7A4
CDE6A4CDE6A4CFE6A2CDE79ECCEB9FC8E99ACAE99BCCEAA0CAE5A2CAE3A9DFF4C9F7FFEA
F8FFF3F9FFF8F9FFF8FBFFF3D2DBBCD5E0B5D7E2AADAE3AC9BA078CBCBAFFAF9E5FBF8EF
FFFEFDFDF8FEFFFCFFFFFDFFFFFDFFFAF8F9FBFAF8898A857C7D78F5F6F1FFFFFDFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D6D1CEFFFDFDFFFDFFFFFCFFFFFBFFFFFAFFFFFCFBE5DDD2B2AC94635F3A8D8C5C9FA368
555A1A6B722EF8FFBDC6CC90FFFFDBFFFFE2FFFFE3F9F3D1EBE3BFD5CEA4DBD4A89B9968
656531E6EBB3D1DCA2D8E7ACCFE5A7DAF4B7C9E7AB6A814B9EA079D6D2AFDADAB6FBFFDA
FDFFE0FCFFE4FCFFEAFEFFEFC5C7BCDBDAD6FFFDFFFCF5FCFFFBFFFFFCFFFFFAFFFEFFFA
EAFEDBC2DCADBED5A7E8FECFF8FFDCABBB8E6A754AB4BF95D8E0B9CCD4ADD9E3BEE9F3D0
FBFFE6F9FFE8EBF8DCFCFFEDFBF9EA958F83FFFFF1FFFFEFFFFFEFFFFDEEF7F7EDFFFFFA
FEFFFF23272804080B363C3A6E756DD0D8C9D8E1CEC7DEC1B1E0B691C698174016001100
35682FC5F8B570914AADCD82C4F0A5CFF3B3FEFFDDF4F7D8CCDDB9D0EDC1C4E2ACD4FBC2
B2E7B1BDF8C8A3E5BF468B6E408072A6E0E1DCFFFFDBFFFFC6E7F8E9FFFFEAFFFFE7FFFF
F4FFFFE7EEE6FFFFF6FFFEF6FEFFF9F8FDF6FCFFF4F2FAE5EFFADAD6E2BCD7E7BAD4E4B5
CEDEAFD8E8BBEBF7D3F9FFE6FBFFF0F5FBF1F5FAF6FBFFFCFDFFF7FCFFF3F1F9E4F3FEDE
DEEEBDDDF2B1CFE698CEE69AD1E5A6DFF0C4DFECD8E6F0E7EAF2E5DFE7CFDCE8BAD9E8AD
B5CE8DC4E29AD0EFA3CBED99C7EA90CAEF90CCF192C7EE93C6EC97C6EB9DC8E9A2C9E8A4
CAE7A5CAE7A4CCE7A4CCE7A0C7E59DC9E9A0CCEAA4CFE9AAD5EEB7E3F9CBF1FFE4F8FFF3
F2FCF3F9FFFBF8FFF7F7FFEFDEE7CAECF7CCE8F5BDE6F0BCC7CCACE7EAD9FFFFF6FFFEFA
FFFEFFFFFAFEFFFDFFFFFEFFFFFEFBF9F6F1FFFFF6F9F9EFFAFAF2FFFFFBF9F9F9F7F7F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F0ECEDFFFDFFFCF7FDFFFCFFFFFBFFFFF6FFFFFCFFFFFDF5FFFFEAEFEFCBA1A47590985F
B2BB7CBDC884D6E39ED4E4A6D0E1B4D4E6C0F4FFDCD8E3BBD0D5ADE4E6BEE2E0B7959267
4F4B1EFEFBCEF7F6C6E5E7B6CBCF9DD7DFAEE1EBB9A7AE82A5A080E7E2C5F4F4D2FFFFDF
F3FED4E1EDC5EFFBD7DEE7CCECEDDFE8E5E0FFFCFFFFF8FFFFFCFFFFFDFFF6F3FAFEFFFD
E6F4DDE0F3D3F7FFE6DBE9C8EDF6D7B7BE9DCBD0B0F6F9DAE4E4C8F2F5D8F4F8DDEBF1D7
FCFFECFBFFEDECF8E0FCFFF3908B87FFFCFBFFFEF8ECE8DFFFFFF4FFFFF6FEFFF8F7FCF6
F1F5F6FEFFFFB2B2B41311120400003C352B7A7064CBD3BBCEF7CFAFE3B5BFE4B8B4DAAB
1D4E1725561E224411AACA99B8E2B0B9DAABEDF1CCFFFED7CEDFABCEECACB4D88EB6E49B
B4EAB081B98C396B5064968A71A6AA99D3E173B4C83A7C924D8A9C457684E7FFFFF0FFFF
F9FFF5FFFFEFFFFFEAF8F8E0FEFFF3F7FFF2FBFFF4FBFFF1FBFFECE8F3D5E5F0D0E7F2D2
E6F1D3EBF5DAF4FEE6FBFFF1FBFFF6FBFFFBFBFFFDFBFFFBFCFFF4FBFFEFE6F0D7E0EECB
CBDCA8D1E6A3C9E291CDE897CDE4A0C5D9A6F8FFEDF4FFF1F9FFF4E1EBD3D1DEB3D2E3AC
DBF4B2D4F3A7C8E998BEE28AC1E687C9F190CAF492C4ED8FC5ED97C5EC9DC6EAA2C6EAA4
C8E8A5C9E8A4CAE7A4CAE8A2C9E7A1CCE9A7CCE5ABCBE3B1DDF2C9F7FFEAF8FFF3F8FFF7
F9FFFBFBFFFBFCFFF6FCFFEFFBFFE4FBFFDAE0EFB8C5D3A0E8F1D6F6FCEEFEFFF8F7F9F4
FFFFFDFFFEFCFFFEFDFFFEF9FFFDF4FEFCEFFFFFF3F8F9EBF5F5EBF8F7F3F6F4F5FFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F2F0F3FEFCFFF7F4FBFFFCFFFFFCFFFBF6FDFFFEFFFFFFF6FFFFECFFFFE1D1D9AACED99F
D5E4A3DBECA6D1E59ECDE6A4BEDCA8CDEDBEE6FFD4EFFFD9CAD9B2DDE3BFDEDEBCA7A282
676141B6AD8CFFFFDFFBF3CFDAD4B0DDDBB5E1DFB8FFFDDAC5BEA4FFFFE6FFFFDEFEFFDD
F4FFD1CFDFAED9E9BCCFD9B6EDEFD9F4F0E5E5DBDCFFFBFFFBF1FAFFFBFFFFFEFFFCFFFF
F9FFF6F1FDE9EEF7E2FEFFEFFFFFEDC1C0ABE4E2CDD4CFB9FFFFEAFFFCE8FFFFECFFFFED
F5FAE4FCFFEFFBFFF1F2F9E9DBD6D2C3BBB8FFFFF6FFFFF4F3F4E6FFFFF3FEFFF6F6FBF4
FEFFFDE7E7E7FBF9FA87827F716863190C030B0000ACAE98ACCEADC1EBC3D3F0C2D5F3C1
7CA76F78A4715E805B7B9C7DC1EDCCC9EBC8D4D8B3E7E6B6C7DA9ACCEEA2C0ED9CC3F9AB
9EDC9D09441690BEA43E675F5A858E3B6B7F35718979BACE82C0CF3A6B72E8FFFFF5FFF7
F7FAE5FFFFE6FCFFDFF7FFDDFBFFE8F7FFE9F9FFEBF9FFEBFAFFECF5FFE7F8FFECFBFFEF
FBFFF1F7FFEFF2FAEBF2FAEDF6FEF3F8FFF5F8FFF7F8FFF1FBFFEDF4FFE3DAE7C9D6E6C1
C6D8A4D0E7A3C8E490CCEA94CDE79DCAE2A8E9FAD8F8FFF1F8FFF3EAF6DEE9F7D3D6E8B6
C2DA9CC6E19CC8E799C8EA94C8ED90C7EF8FC5EE8EC3EC90C5ED97C5EC9DC5EBA0C6EAA4
C8E9A4C8E9A2C9E9A0CAE8A0CFEDA7CEE8A9C8E0ACCCE1BAE0F0D5F6FFF2F9FFFAFBFFFB
F9FFF8F6FEEFE1E9D2E2EDCDF2FFD4E1F2BEB0C18A95A672E3F1CEE5F1DBEBF4E3E2E8DC
FEFFFAFFFFFBFFFFFAFFFFF8FEFAEFFFFFF3FFFFF0FFFFF3FFFFF6FFFFFBFEFCFDFEFCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F6F6F6FFFFFFFFFEFFFFFDFFFFFDFFFFFDFFFFFEFFFCFEF3F5F9E2F0F8D1DBE9B6E1F3B7
BCD38FCCE69DD4EEA5C6E5A1CEF4B9B1D7A4E8FFD9F2FFE3E6F6D2E4EACEE8E8D0F0E9D6
B7AC9A625544FFF9E6FDF2DCFCF4DDF0ECD1E9E5C8FFFFE6E1D6C4FFFFEAEBECCAE9F2C5
F4FFCFCCE1A6CDE0A8D7E4B6ECF0CFEBE6D3E9DEDAFFFBFDFEF5FAFFFDFFFEFFFFFCFFFF
F7FCF6FEFFF8FEFEF4FFFFF4FFFCF0D4CCBFE5DCCDFFF3E3FFFDEDFFF6E5FEF9E6FFFFEB
F4F7E2FAFFE9FCFFEFFCFFF1FDFEEEE9EADA575944A3A58F92947EAFB19BE3E4D2FFFFF1
F9F9EFFFFFF7FFFFFAF9F4EEFFFEF47B7565090200020600637964C3DCBFD8E5BAC6D7A1
DAFCC0C5EBB887A68700200D36614D9CBEA3CFD6ADDEE1AACBE59CC8F5A4B8F2A5A9EFA6
42914F28733BC0F6D60C352783A2A7E3FFFFE6FFFFE2FFFFE7FFFFE7FFFEEBF9ECF0F8E0
FCFFE3D2E5B8D6F9C3DFFFCCE2F8C9ECFBD2E6F4D0DFEDCCE5EFD6FAFFEEFBFFF3FBFFF6
FBFFF8F9FFF6F8FFF5FBFFF6F9FFF3F9FFF1EDF9E3DDEACEE8F6D2E0F0C9CDDDB9D1E3BB
C9DDA8D4EDABCAE793C9EA91C7E492E2FDBAE4F9CEF7FFECEEFDE8F2FFE9F8FFE8E4F5CB
D4E8B7D4E9B1D3ECABD4F0A6D0EF9FCBED97C9ED95CBEF98C6EC99C6EB9DC6EAA0C8EAA0
C8EAA0C9E99ECAE99DCAE99DCFEAA5CAE2A6CEE4B6DEEED1EDF8EAF4FAF6F8FEFCFCFFFB
FCFFF4F5FDE5DCE8C2D7E4B6DDEEB8C2D69BB2C68BBFD49BD4E8B5D0E2B8D3E2C1D2DFC5
F9FFF0FEFFF8FFFFFAFFFFFAFFFEF8FFFFF6FFFBF0FFFFF6FFFEF8F0ECE9F7F3F4FFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFFFCFEFFFFFEFFFFFAFBFFFBFAFFFEFFFFFEFFFDFCFFF2F9FFE7F9FFDFD3E6AFC7E09F
D6F1AAD6F5A9B6D68AD3F4ADC8EEB3AED09EF0FFE1E6FAD5F9FFEAFFFFEFFFFCF0FFFDF6
FFFCF661544EFFF5ECFEF6EBFFFFF1F3F4E2FEFFECFDFFE9D9D0C1FFFFECFFFFE3CFDBAB
D1E7A9C8E19DCEE4A3D3E2A9E1E6BDC3BFA4FFFDF3FEF3F1FFFCFFFFFEFFF3F7FAF8FCFD
FFFFFFFFFEFDF6F1EEFFFCFA4E433DE0D3CBFFF9F1FFFCEFFFFCEDFFFDEDFFFDECFFFFEC
FFFFECFBFFE8F5FAE4FCFFECFCFFE8FCFFE6FEFFE3F4FAD6FFFFE1E9EACAB9B89A504E37
8A8776FFFFF3F7F3E8FFFFF4F6F7E7FFFFEDFEFFEA0006000005000004000C0A00DFE4AC
CAE3A2CAEBB28EAB8D395A471D4A3682A98CDFEBBDCFD99AC3E397C3F9AB98DF9D7AC88C
71BD7DB0F5BCA9E0B991BBA5D6F5F0EEFFFFE0F4FBF1FFFFEAFBF3F7FFF3F5FFE4E8F4CC
DBEDBDC7E2ABC4EAAFC3E7AACAE2A4DBEDB3D4E5B1D1E0B5D7E2C2FAFFEEFBFFF4F7FEF6
FAFFFAF9FFF8F9FFF6FBFFF3F9FFEDF9FFE8E6F4D1D3E4BAD1E3B3D3E6B8CADCB4D3E8BD
CAE1ADD3EDACC8E893C9EA8FCCED96C1DF95DDF5C1E2F6D3F3FFEDF0FFEAF8FFECF5FFE5
F7FFE2E1F0C7CDDDACC7DCA1C9E29ECAE69BC9E898CDEC9CC9EA9BC9E99DC9E99EC9E99E
CAE99DCAE99BCCE997CCE999CAE49DCEE3A8DEF0C6F5FFEAFBFFFBF7FCFFF7FBFCFCFFFA
E5EDD6D5DFBAD3E1ACCCDEA0BFD49396AC6BA4BA7CCBE3A5CFEAA7C9E3A2CCE3AFCFE1B9
F8FFECFCFFF4FFFFFBFCFBF9F3EFEEFFFDFDFFFEFAFEF9F5FFFBF7FFFEFBFFFEFDFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFAFCFFFBFCFFFFF8FCFDFAFBFFFCFFFFFCFFFAFBFFF3E6F3D5CEDFB3BED69CC6E3A0
C6E69BCFF2A2C4E999C3E79DC5E1A7E3F9CBF7FFE2FCFFE8FFFFEEFFFFF4FFFCFBFFFBFF
FFF8FF5F545AFFFEFFFFFFFBF9FFFAEDFEEEF2FFF3D6E3CFD2CCC0E4DBCAFFFFE0D2E0AD
C4DD9BCCE89DD9F1A7D2E5A3B3B989A19E7DFFFEEDF5EAE6FFFAFAFFFEFFF6FCFCFBFFFF
FFFEFFFEF5FAB5AAAEB3A5A5FFF8F5FFEEEAFFFAF3FFF7ECFEECDEFFFCECF7ECDAF1EBD5
ECEAD3DEE0C8ECF2D8EEF9D9EAFBCFCFE1AFEBF9C6EDF7C3E5E9B7F9F8CACFCAA4A29C7C
787157D7D0BDFFFFEFFAFDECDFEBD3DEEED3DFF7D5EDFFE940434C0D030B0E00006E6730
E3F4ADCEEBA8BBD5AE99BBA057886B3E6B44D8E9B2D2E19CBEE79B9DDA972776490A562F
A0D6A2C4EFBABDECC04F7C5B7DA48FEAFFFBECFFF6EFFFEEEFFFE2D1E3BBF4FFD8D1EDB3
AECA8FD1E9AFD7E8B4D1E0A7C9DD95D1E79CC9DC9CD2E3ADD7E3BDF8FFE9F8FFF1F7FEF6
FAFFFAFBFFFAF9FFF2F1FAE5E9F7D6E5F4CBDCEEBCD3E6AFD5E8B0E0F5BDDFF2C5E3F8CD
CCE4B2CCE9A9C4E491CBEE90D8FB9DB8D787CAE6ABD2E8C1F5FFEDF1FFEFF1FFE9F9FFEF
FCFFEFE9EED7D4DEBCD4E1B5D6E7B0D0E6A5CBE59ECCE69DCCE89ECCE89ECAE89ECAE99D
CCE999CCE995CDE992CDE995D3EBA1DDF3B5EEFED7F9FFF1FBFFFFFCFFFFFDFEFFFEFFF8
E5ECCDD1DDADE0F0AFDCF1A6CEE499A7BE76B8D18FCEE9A4CCEE97C7E992CBE9A1D0E7B1
F8FFE6FAFFF2FEFFFDFCFAFFFFFDFFF1EAF2CCC3C8B0A7AAC8C2C2FFFEFBFFFDFDF7F3F2
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBF9FAF5FFFEFFFFFFFFFFFEFFFFFFFDF9FCF3FCFFF1ECF7D9CBDCB2CFE6B0D4F0B3
C4E5A0C4E89EC7EDA0CCEDA6CEE1AAD4E0B2465129EAF1D0FFFFEAFAFBEBFFFEF8FFFAFB
FFFAFF554A50FFFCFFF3F2F0F5FCF4F5FFF6E9FFE9D7EBD0C6C6AE615E3F93996DCAD9A0
D9F0AAC9E399CBE29AD4E4A5C1C998D0D1AFFFFFEFFFFEF8FDF9FAFEFDFFFBFFFFFBFFFF
FFFFFDFFFFFA524E45FFFCF0FFFEEFFFFEEAE8DCC4756A4E655A3C544B2A56502E605D3A
494A28787E5AD3DDBACBDAAFC9DEA5D7EDADCEE0A2D7E5AADAE3AACED39DE9E8B8E0DFB3
CECCA5B5B591F6F7D5CED5B3DAE6C0D1E2B8CEE4B6F3FFE4FFFEFFFBF0F6110500080400
011000F5FFCFA4B992ADC8A9C7F0D0193F16C7DFA5D2EBA7C5F0A8ACE7A7478C6073B18A
C0E6B3C6E5ACB5DDA995C092557F57E3FFE2F1FFE6DBF2C8CCE3AFC6E0A3C9EAA5C8ECA4
D3F4ADC8E19FDBE9AED0DC9ED3E89BD0E89AC3D895D7E8B2DAE6C2F6FFEAF8FEF4FCFFFD
F6FAF9FCFFFDFCFFF8F7FEECE6EFD2DBE7C1D4E1B6CDDDACE8F9C5F8FFDAF8FFE3F7FFE6
D2E4BECAE0AFC5DE9AD2EF9FC3DF8ADFFAA9C9E2A0C6DAA7DAEBC7E7F5DBF4FFEBF2FBE8
FEFFF4F9FBEDFDFFE9FFFFE3FFFFDAE8F1BAD9E3A7D4E3A2D3E4A0D0E69ECFE69ECDE79D
CFE79BD0E797D1E795D1E69BE3F5B9F2FFD3F9FFE6F6FDEDF6FBF7FCFFFFFEFFFBFBFFF0
F1F8D6CBD7A5D1E1A2CDE19AD2E6A1C1D695D4E9AECFE8A6C8EB91C3E88BCAE99DCFE8AE
F7FFE2F9FFEFFEFFFBFEFDFFFEF8FFE9E1ECFEF7FFFEF5FADFD9DBDCD7D4F1ECE8FFFEFB
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3FAFFFBFFFFFAFFFAEFF3FFFBFFFFFCFBFFFEF8FFFEF1E3E6D1E1EACBC0D0A9D4EABB
C9E4ADC4E3A7C6EAAAC9E5A8ABB47DA4A67499A36F9AAA79D2E8BADFF4CDEFF9DEEFF0E0
FFFCF65F4D4DFFF9FAFFFAF8FFFEF2FAFFE9F7FFE8C7D9AFCDDAA5B8C286B1BD7FD1E09F
D0E19DD9ECAAD2E1A6E4F1BCDBE3BCE6ECD0FFFFF3FEFFFAFCFDFFF4F4FFFCFDFFF8FFFF
F6FFF2F3FFE396A4818F9B73929B6C909964949C61989E60959B5B969C5CDAE3A4D1DB9F
8B986094A26DC1D29ED8EBB3D6E9A7D3E7A0CFE2A0CDDFA1CFE1A7D1E2ABD2E1AACFDEA5
8A985DC5D094E4EEB1DBE4A5D2D89A979B5EA4A86BA2A674EAECD4F2F7E3D0D9BC041200
000B00768661CCD5B8B8C2A7CCDFC17590678FB27CC7EFB0BBEAA4BDEAA5C1E7AAC5E7AB
C2DEA1DFFCBCBADD9B84A8686A9150D4FBBAD6F9B7CFF3ADC8ECA2C8ED9FC7EC9CC6EC99
CBEE9CCFEEA0D4ECA0D0E89EC9E399D2EDA8C7DFA5E7F8CEECF8E0FBFFF7FEFFFFFAF9FF
FEFDFFFFFEFFFFFFFDFFFFFAF6F8EBEAEEDDE9EDDCEEF3DDF8FEE2FAFFE6FBFFF0F5FBED
EDF3E5E7EFD8DEE8C3D5E3B0D6E5A4D9E9A0D5E59ECDDC9BD5E2ADEBF6CEFBFFE7FCFFEF
FCFFF3FEFFF3F1EFDAFFFFE4FFFBD8FDF0C4E2D6A2E7E3A6D1D694DCE7A2D2E39CD8ECA4
D9EAA4D0DF9CE7F2B0CED5A1F1F4D9FEFFF1FFFFF4FFFFF6FEFFF6FEFFF3FCFFEDF3FCDF
EAF4CFCFDCB0D2DEAED6E2B2D4E0B2C1CCA1D6E1B7C6D7A3CFEBA1C6E796C5E39DD3EAB2
E9FBD3F9FFEDFCFFF8FEFFFFFFFDFFDCD7DEC6BFC6D5CFD3B5ACADF4ECE9FFFCF6FFFBF5
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FFFFF6FCFDEDF0FFFAFDFFFAFBFFFBFAFFF6F0FFFFF3FDFCEAEFF3DAD3DEBECFDFB8
DCF3C5D8F4C1E4FFCED6EFB5BBC088CDCE94DEE9AD95AB6DD4F0B5D2EEBBC9DBB3E8EED2
FFFDF15B4643FFF6F8FFF8F6FFF9EEFFFEE9F5FFE2CFE2B4D8E8A777873E8E9D58D8E7A6
E2F0B3CFDCA6D4E0B2E5EFCAB9C2A5FCFFEDEAF0E2FCFFFAF5F9FAFCFFFFFBFEFFF9FFFD
F5FFE6F2FFDAC2D9A3CEE3AAD3E7A8D3E6A4DAE9A4D6E69FD5E29AD8E89F9AAA6394A55F
8DA060CCDEA0E1F5BAC5D99CD1E1A2D0E0A1D3E5ABD9ECB5D7EBB8CDE3B2C9E0ACCBE2AA
BCD29297AB669AA7618A944DABAE69AEAD6CDED89A817F46DCDFB2C7D4A9D2E7BCB4CDA3
000A00253310E8EBCED9D9BDD2DCBAC1D8AE0A350071A567B7ECA8C4F1ACD0EFABCAE19D
C9E29ED0EBA6CAE8A0C1E196B1D387D7FCAEC4EB9AC8F29EC1EB95C4EC96C5EB96C7EA96
C9EB97CAEA97CCE997CAE797CCEB9FCFECA9C6DDA7EBFDD7F2FEE8FBFFFAFEFFFFFFFEFF
FFFEFFFFFEFFFFFFFDFFFFFAFFFFF8FAFCF1FBFDF2FEFFF4FAFCEEFFFFF4FFFFFAFFFFFF
FEFEFFFFFFFDFEFFF2FAFFE1D4DCADD8E3A7D5E19FD0DC9ED9E3B1EDF5D0FCFFEBFCFFF6
F3FBF0FEFFF8FFFBEFFFF8E86D57405D442668522BA09263CEC992DFE3A8CCD79BD6E4A9
CBD8A2F6FECBFFFFD8FFFFE3FFFCF3FFFEFDFFFFFAFCFCF2FAFEEDF9FFE9EEF7D8DDE9C5
D0DCB4D4E1B6FBFFDFFCFFDFFAFFDFA2A987FEFFE3FBFFDCCDE8A3C8E89CC8E5A2D0E9B0
DEF1C4ECFBDCF8FFEEFCFFFAFFFFFFFFFEFFFFFDFFF3EDEFBFB6B7FFFDFAFFFDF8FFFEF8
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCF6F5E8E2FFFCF6FFFCF6F6E9E3897C74B5ABA1F8F0E3FDFAE7F3F5DDD6DFC0DEECC8
F7FFDFF4FFDDF2FFDCF7FFD4A6AF70E1E6A3D3E29D92A965CCE9A7CFEBB1C4D5A9F3F6D9
FFFCEE533B39FFF7FAFFF5F5FFF7EEFCFFEEE3F3D8D4E9BEC3D3955D6A25919D5FC7D29A
D6DFB0E0E8C3F1F7DBCCD1BBE1E5D4FEFFF4FEFFF4F1F5E6FEFFF3F1F5E4F3F8E4E1ECCC
DFF6C0E4FFBFC8E1A0D8EEAED3E7A8CEE0A2D6E4A9C9D79CD7E5AAD6E4A75E6C31B5C587
CDDFA3D2E4A8CCE0A3D7EAB2E9F6CAE3EFC9E1EFCCE3F2D1E0F1D1D9ECCCDDF3CDE8FDD2
D8ECB9A7BA829AA86D949C61DCDFA6DBDAA49D976783804DCFD599E9F8B7CEE4A4D5EDB1
0F2200000A00878961D8DAB3D8E3BBCCE7BA93C28C2662266EAC6BB7F2B0BFECABBADD9B
D0EEA8C6E298CCEAA0D2F2A6CEF0A3C9EE9EBCE390CAF19EC6ED9AC6ED9AC8EE9BCAED9B
C9EA9BC9E89ACCE89DCEEA9FC8E79BCFEDA7CFE6AEF7FFDFF8FFECFBFFF6FAFCF7FAFAF8
FEFFFAFCFDF7FCFEF1FEFFF3FEFFF1FCFFEFFCFFEFFCFFF1FEFFF6FFFFFBFFFEFFFFFDFF
FFFDFFFFFDFFFEFFFDFEFFF3D6DDBED8E3B9D7E3B5D3DEB4D9E2C5E9F0E0F3F7F6F3F8FC
F9FFFFF5F9FCFFFDFFFFF6F34F38308F7568CAB19B514024786F4E94946EAEB48EB4BB99
CBD2B3FFFFE8FEFCE7FFFEF0FFFFF8FFFFFBFFFFF8FDFFF3FCFFEFFAFFE9E4F2CFCCDBB4
D4E3B8CADAADF9FFDDF9FFDDFAFFDCB6C199FCFFE1EEFECFCCE7A0CAEB9CCBE9A1CCE6A7
D2E6B3DCECC5EDF7DCF8FFEFF7FAF1FFFFFBFFFEFDB9B5B4827C7CF3EEEBFFFAF7FFFDFA
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
42362A52483C463A2E584C40867A6E766C60776D61BDB6A6FFFFEDFFFFECDCE0C5EAF3D4
F9FFE3EFFFD6C9DEB3F6FFD49CA763DCE89C84994CA0B86EBDD893C8E0A4D1DEB2EEEFD0
FFF8EB705856FFF7FAFFF8FAFFF7F0EFF3E4D3E7CEBED4ADD8E7AEA7B373D4DDA8DDE6B9
DBE0C0FEFFEDFFFFF4BBBEB7FFFFFAFEFFF8FBFDEFF2F7E0FAFFDEFEFFDCE3EBBADEEDB6
CDE6A5CFEAA7C4DD9BD2E8A7CDE1A2CDDFA1DEEDB2D4E2A7CCD9A1E4F1B97C8B54CBDAA3
D9EAB4D2E3ADD2E5AEE5F6C9F9FFE8F9FFEFF8FFF1F6FFF0F4FFF0F4FFEFF4FFEAF4FFE3
F5FFDCBED09CCAD9A2DDE6AFD3D7A5D9D8AA635E36D4D1A8D9DCADD3DDA9CCDEACCDE1B0
000900060E00706F50E0DFC1F0FAD8CBE5BEA3D5A44C8D554E965792D796B8F0B1C3F0AF
CCEDA6C8E499CDECA0C0E192C8EB9BBFE494C5EB98C4EB98C9EF9CC8ED9DC8ED9FCAEC9F
C8E89DC7E59DCCE7A2D1ECA5C3E197D1ECA5CEE6AAF3FFD8F5FFE5F9FFEFF6FCEEF1F7EB
FEFFF4FEFFF1F9FFE9FBFFE7FBFFE6FBFFE6F9FFE6FBFFECFBFEF3FFFFFDFFFEFFFDFBFF
FAF7FFFAF9FFFBFCFFF8FDF6FBFFECFBFFE6FAFFE3F4FFE3F5FFEFF9FFFDF9FFFFF9FFFF
F9FFFFFCFFFFF8F3FAFFFAFFD0BBBA6F5651C8B2A7FFFCECFBF0DCBCB7A39EA08B4D503D
A4A597FFFFF6FFFDFAFEF6F3FFFEF9FFFFF8FEFFF4FCFFF1FBFFECF9FFE6E5F5CECDE0B3
CBDEB0C9DDACF7FFDAF3FFD5B7C79ACDDDB0D2DFB4D7E9B5CBE79DCAEB9ACBEA9ECAE5A0
CAE2A8D1E5B4DFEDC9EBF5DAFCFFEFFCFFF2F9F9F17F7B785A5655F1EBEBFFFCFCFFFDFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E8DFCEB7B09EFFFEEDFFF9E8FFFEEFFFF9EAFFFDEE4A43339A9582FFFFECFFFFEAE9EDD2
FEFFE6FCFFE3D3DFBBDBE9B8D1E19AD6E9978BA250CEE99ACFE9A0D1E7A9E1EABDF1EECF
B3A193553D39F6DCDFFFEFEFFFFAF4F6FEEFF1FFF1D1EBC6C6D49FCCD59EE5EBBFFFFFE4
F6F7E5FFFFFAFFFEFFE4E3E8FFFEFFF1F2ECEEEFDFE9EFCDE7EEBBCAD593D9E498CFDF94
D4EAACCEE7AECCE4AAD0E6A8CEE3A2CDE19CDDEEA8D6E7A1CFE09CCCDC9B9FAE73D9E7B2
F9FFDCF9FFDFF8FFE3F7FFE9EAF7E3F4FFF0F5FFF4EFFFEEF4FFF2F4FFEFE7FCDBCBE2B8
D0E6B5E5FAC2CCDEA4D0DBA3D9E0ADD3D6A957552EFFFFE6FFFFF4F9FBF8F9FFFDF8FFFD
0002000B0B094C4243DFD7D4F8FBF0EDFFEDB7EBC541875547955B67B675ADEFAFB5ECA8
C1E59DC9E598D3F2A4C5E494D3F4A3C4E795CFF2A0BFE592C9EC9CC5E79AC4E69AC7E6A0
C7E4A1C4E1A1C8E2A5CEE8A7C7E399D2EEA4C1D99BD3E7B4D7E7C0F2FFE1F9FFECFBFFEC
E1EBD0D8E3C3D0DFB8D0DFB4D1E2B5CFE0B3CCDFB1CEDCB8F0F4E3FBFAF6FFFEFFFFFDFF
FEFCFFFEFEFFFEFFFFFCFFFBFBFFF1F9FFEAF7FFE7F3FFE7F1FFF0F3FFFBF3FEFFF1FBFF
E3EAF2FCFFFFFFFAFEFFF6F7FFFAFABEA9A698847DFFF2E8FFFDF1FFFAEFFFFFF48A8A82
96928FF6F0F2FEF3FBFFFCFFFFFFF8FCFFF3F7FFEBF3FFE6F2FFE2ECFED8DEF4C6D1E7B6
D7EEB8D5ECB4F0FFCFEAFFC9A6BA85D7EBB6C6D8A6D2E7ACC9E89AC8EA94C9E898C8E79B
CAE5A0CDE5A9D4E8B5D8E9BFFBFFE6F8FFE8FEFFF381827A676662F8F4F5FCF7FDFFFDFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F3E3FFFAEAFFFFEFFFFFEFF8F1E1FFFEF1FFF9ECB5ADA05F5949504B3856543F85856D
FFFFE7FCFFE2CDD2B2CFD8ABD3E49E9BB35FAEC774CAE596CBE29ACADCA0D5DBAFEEE9CB
CFBCAE8F7672FFF8F8FFFBF8FFFFF6F6FFF1F0FFEDC6E2BC8E9B6DD5DBADDDE1BEFFFFEC
FCFCF2FFFEFFFFFDFFE5E2EBFFFEFFF8F7F2E7E9D3CACFA7D2DA9E7C8739D8E58BD8E792
D2E7A6CBE4ABCEE6ACC9DEA3D4E8ABCCE0A1CFE1A3CCDC9EDCECAEBDCC93B6C58ED5E3B0
F8FFDBF3FFD9F9FFE1F8FFE4F8FFEDF7FFEFF5FFF1EEFFE8F4FFECF4FFE6EAFFD9CEE9B4
BDD599CAE0A0D0E3A3DFEDAFD4DDA6DCE3B0B1B288BDBDA1E2E1DDFEFEFFF9FFFFF1F8FE
9EA1A80500072F1F29E2D3DAFFFFFBF4FFF8B4E2C5A7EABF9DEAB603511796DAA1BCF2B4
C7EDA4C8E497C9E89ACAE999D8F7A7BFE08FD0F1A0CBEE9ECCECA0C6E69BC7E6A0CFEEAB
D2EEB1CDE9AFCCE5AECFE9ACC8E49AD4F0A5C4DD9BD5EDB3D6E9BBEAFAD3F4FFDFF4FFDF
DEEFC5D6E7BAD0E4AFD1E6ADD1E9AFCFE7ADCCE5ABD1E4B6ECF1DAF9F9EFFFFFFBFFFFFF
FFFEFFFEFFFFFCFFFDFBFFF6F9FFECF8FFE6F7FFE4F5FFE6F5FFEDF4FFF6F4FFFDF5FFFF
F8FFFDE8EDE6FFFFF8FFFEF4EDE0D7E9D9CC78685BFFFAEAFFFBEDFFFEF1FCF5EB99948E
7A7172FFFCFFFFFAFFFFFCFDFEFFF3F5FFE8E7F4D8DBEAC9D4E6BED1E7B9CFE7B3CDE9AF
E6FFC5E0FDBDC9E6A6DDF7B8C5DFA2B2CA8ECEE6AAC8E19FC9E898C7E992C8E893C9E996
CCE89BCDE8A1CDE5A7CEE2ADD5E4B9E5F0CEFCFFED8387796C6D68EAE8EBF5EFF9FFFDFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF4F7F3E8FFFDF2FEF7EDFFFEF4FFFBF4FFFDF6FCF3EAF7EFE4FFFEF1FFFFEFADA894
76715BCDC9AEECEBCFD9DEB6D9ECACAEC67AD8F2A8D7EEA6D8EDACF0FDC7FEFFD7FFFFE4
B8A597765F59FFF1ECFFFDF4F9FCEBE3F3D8CCEAC4BBD7AE939F77FFFFE1FFFFE8FFFFF1
FFFEF7FFFEFFFFFDFFA19CA2A39F9EC0BEB29E9E82AAAD808E9456899144879138CFDF86
CBE196CBE4A0D5EBADD1E6ADF8FFDAF8FFDDF7FFDFF9FFE3F9FFE3F9FFE1DEEBC0ABB88A
AAB883AEC086D2E4A6DBEFB2F8FFDCE4F6CCCEE3BAC7DCB1CBE3B3D0E9B2CCE8ABC8E6A0
CEE99CDEF6A8CEE595C6D88EDAE6A4D9E2A9868D5AA6AB83F4FAE0EBF4E1F8FFF3F5FFF1
FAFEF0110D041A06055C4847CBC2BBE8F3E5C7EDD4CBFFE0A1E4BB82C5994982579FCD9C
CBEEAACDE99CC2DE91C6E597CDEC9CBCDB8BD0EFA1CEEFA0CEECA2C9E79FCEEBA8DEFBBB
E7FFC7DDF5C1D1E9B7CEE7AECAE49BD2EDA0CEE7A3F3FFCDEAFFCBDEF2C1D3E7B6D3E7B4
D2E9B1CDE5A9C9E4A1CBE6A1CAE8A2C7E59FC7E4A1CDE5ABEDF4D2FDFCE8FFFFF3FFFFF4
FEFFF5FBFFF1F9FFECF7FFE4E0EFC8DFF1C1DDF4C0DDF5C1DEF6C6DBF4CADBF3D1DDF2D3
E0EDCFE9F2D3FFFFE6F9F8DAFDF8DAF8EFD24A4124F7EDD2ECE2C9FFFFEAFFFFEDB0A89B
5D544BFFFCF7FFF8F8FFFCF3F4FCE4E5F5D1D8E8C3CEE0B6C8DEADC7E0A9C6E2A7C7E5A5
C9E8A4E1FFBAD3F2ACD4F2ACC4E29C87A25DC5E09BD4F0A6C9E996CAEB94CAEB94CAEB94
CAEA95CBE898CBE79DCCE5A4C7DCA4E4F5C9F8FFE57A81716C6D68E6E5EAFFFCFFFFFCFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCF9FFFEFBFFFEFBFFFCF9F8F3F0FFFDFBFFFDFAFFFCFAFFFDF6FFFAF1FEF6E9FDF4E3
524A35BAB29BD4CDB3DBDBB7D4E5AED6EFAECAE0A0CEE2A5C2D19AF1F9CAFFFFDFFFFAE2
BEAB9D6C584FFFF9F1FFFFEFFAFFE6E8FCD7C1E1B2CAE7B9939D7BFFFFE7FFFFECFFFFF3
FFFFF6F9F6F1FFFFFA77746D9E9C90BBBAA5E9EAC8CBCE9FDEE3A9E6EDA770782BD4E094
D1E4A4D0E5ADD2E6B1C8DCABF8FFDFF8FFE3F4FFDFF9FFE4F9FFE3F9FFDFCFDCB0CEDCA9
C0CF967E8E509EAF6BE6F9B7F7FFCFDEF3BACBE3A9D2EAB0D2ECAFC7E1A0C7E399D3F0A0
D2EE99C2DC85D7EF9BDBEE9FCAD994C0CB8F1D26009FA87BE8F4CEF5FFE3ECFFDFF7FFEA
FBFFE96964510F00001A010081726BFFFFF4C4E0CAA2CDB2CAFDDE7BAE8F001C01799C74
C0DEA2D4F0A6C9E59BCDE99ECDE99CC6E597D3EFA2BFDE92CBE79DC5E39DD1EBAAE7FFC4
F0FFD2E2FAC8D0E8B8C8E1AACDE79EC9E497C9E39CF5FFCDF2FFCED2EBB2C3DCA2CEE8AB
D0EBA8CBE9A1CAE99DCCEB9DCAEB9CC7E79BC7E79CCFE7ABEBF3CEFBFAE5FFFFEFFFFFF1
FEFFF0FBFFECFCFFE8F9FFE1D2E2B3CFE4ABCDE5A7CEE8A7CCE9A7CBE7AAC9E6ACCEE7B0
D1DFAEEDF6C9FEFFD9EFF2C7D6D7ADB4B1885F5A34DED8B4E8DFC0FFF6DBFFFEE8A59D8A
5F5647FFF5EBFFFDF4FBF8E9E0EAC8D5E6BACFE2B5CEE4B3D2E9B1CEEAADCAE7A5C5E4A0
C4E69CD1F3A7C8E89DBADA8EC8E79BB7D68AC4E095CDE99CCBE896CBEC95CDEE97CBEC95
C8E992C7E792CBE898CEE9A2CBE3A5EDFFD0F2FFDD717A676C6E69E6E5EBFFFBFFFAF6FF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAF7FEFFFDFFFCF9FFFFFDFFFFFCFFFFFDFFFFFDFFFFFAFBFFFCFAFFFDF6FFFBF1FFF6E8
615644B8AD97FFF3DBFFFFE3D5E2B7C7DBAAD2E4B4E6F6C7F7FFD5FFFFDFFFFFE4FFFAE7
917F73B4A298FFFCEFFFFFEAFEFFE4DCEFC2C9E8AFF1FFDAD3DCC1FFFDF0FFFEF1FFFFF1
FFFFF1FFFFEEFFFFECD4D4BCE0E0C4CBCCAADCDEB7E1E4B7AEB182959966B5BA84D1D9AA
E4F1D5F7FFF1EDFDE3F7FFE8F7FFE1F7FFDACFE2ABD0E4A7D6EAABC4D998CDE0A0DDEFB1
CAD9A096A56E8B9964D0E2A8D0E6A5D2EBA7D3ECA8D0E9A5CAE39FC8E29BCCE69CD1EC9B
D5F19CCCE591D5EC9AA4B96C8F9F5EBBC890C7D0A1DDE8BED1E1BACBE1BAC7E0B9D0E4C1
DDE6CBFFFDEACAB4A9150000110000CCC3BAF8FFF6EDFFF5E8FFF3E3FFEC4D5F4F243419
CAE1ADD2EDAACEE7A3C9E39CD5EFA6CEEAA0C5DF96C5E197CAE49DD3EEA9C9E1A3DCF4BA
F5FFD6E8FECDF4FFDDCFE8B1CDE79ECDE899CCE89ECCE7A2CCE6A5CAE7A7CAE7A5CAE8A2
CBEA9EC9EA99CAEC98CDEF9BCCED9CC7E899C6E69BCCE4AAEFF6D7FAF8E9FFFFF3FFFFF3
FFFFF1F9FFEAFAFFE6F9FFE1D8E8B7CDE2A7C6DF9BC9E59BCBEA9ECAE99BC8E89CCFE9A2
D3E1A4D3DCA5EFF6C0D3DAA65B5F2D5B5D2EA09F73E7E3BDF1EBC9FFFFE3FFFFE6CDC2AE
716555F5ECDDFFFDF1FFFFEDE5EFCAD7E9B9CCE0AFCBE2ACD8F0B6DEFBBBD6F3B0C7E6A0
CDEFA3C0E295CBEC9DD0F1A2C7E696ACCB7BA7C472D1EE9CCCE997C8E593D5F29ECBE993
CAEB94CBEB96BEDD8DD7F3A9D5EEADD6EAB7F3FFDD828B7661635EE4E3E9FFFCFFFDF9FF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFDFFF8F7FFFFFEFFFBFAFFFFFDFFF4F1F8FFFDFFFFFAFCFFFAF8FFFDF8FFFDF4FFFDF1
7D7060A69986FFFDE8FFFDE3CFD8B9DAE9C8CAD5B3ECF6D4FFFFE4FEFDE1FFFFEAF0E4D4
514338B0A297FFFBEAFFFFE8FEFFE1DCEEBCE1FDC0E2FAC6DCE1CDFFFFFAFBF9EDF7F5E6
FCFBE6F4F5D6FEFFDDE8EAC2CFD2A7E7EABFEEF1C6C1C39B979974B0B18FDADBBCDCE0C9
E7EFE4F8FFFAF7FFF3F7FFEDF5FFE2ECFFD1D0E3ABD6EAABC1D691D1E79FD9EDA8D1E4A2
C5D5979AA96E929F69DDECB3C9DE9DC6DF9BC8E19FCBE4A3D0E6A6CFE8A7D0E6A5CEE59F
C6DE94CCE299DCF0A995A866A5B47BD4E2B1D9E4BCC7D3AFCFE0C0C8E0C0C8E1C1D4E8CC
E4EED6FFFFEFE5CEC844272333171681726DFCFFF4F7FFF6F3FFF6EFFBEF54544C111200
9FB084B3CC92D6EEB2CAE2A4B6CF8DDCF3AFDBF2ACCEE59FD2E9A3D6EDA9CDE3A3E3FBBF
F5FFD4F5FFD8F0FFD8C7E0A9CDE79ECCE999CCE89DCAE8A0CAE8A2C9E8A4C9E9A0C9E99D
C4E594C3E58FC5E791C7E993C6E796C6E599CAE8A2D4EBB5F3F8E4FDFAF5FFFFFAFFFFFA
FEFFF7FBFFF1FAFFEBFBFFE6CFDEB5CFE1ADD2EAACD7F2ADD5F1A6CBEA9AC8E895D0E89C
E0EAADD9DEA6BABF89666D39A4AA7A95986BB8B991FFFFDEFFF8DBFFFEE6FFF9E6FEF1E1
968A7CCAC0B4FFFEF3F6F5E1E3EDCAD6E7BACFE1B1D5E9B6E5FCC4EDFFCADFFCBCCCEBA7
D1F0AAC7E79CCBEB9FCCEB9DCDEC9EBCD98999B6669CB768CAE598D7F2A5C7E293CEEB99
D7F4A2C4E491D9F8AAC0DC92C8E0A2EBFFCCF8FFE37C85706D726BE6E5EBFCF8FFFFFCFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFF1F2F6DDDEE2CFCED3F2F2F4FFFFFFEEECEDFFFEFBFFF7F4FFFAF4FFFCF3
A09285887869FFFCECFFFFECFAFDEAFBFFF1FDFFEEFFFFECFDFCE8CBC6B38A807452483E
695F56F8F0E5FFFFEFF1F1D7C2CAA3D8E9B5B5CB8DDEF0BEB2B6A8FFFFFDFFFFF8FFFFEF
FFFFE6E9EEC6DCE2B2D5DCA8C4CB95949B68979D71DCE0BDFFFFEAFFFFF1F5F5EDFDFEF6
F6FEEFF8FFF1F7FFEEF3FFE7D3E4C4CFE0BCC6D8AED2E5B7D3E7B2DEF2B7D2E4A697AA68
91A25EB2C17CC7D48ED0E19DD5E9ACD4E9B1D9EDBAE7FACCF7FFDCF7FFDDF8FFDCF6FFD8
F8FFD6D0E1ABCEDFABACBA89ECF9CEFBFFE3FCFFE8FBFFEDF7FFF6F1FFF9F0FFFAF2FFFA
F6FFF7FFFEFAE0CACC64454A2A0D110E0000FFFFF8E9EFE5FEFFF6FFFFF68A77730F0100
1924024D6436516736B9D09AE2F7BEC6DA9DC0D594D5EAA7CBE09BD0E5A2C9DE9DCCE2A4
C6DEA2CEE5ADCDE6AFCBE4AACCE89ECCE89BCCE89DCAE89ECAE8A0C9E9A0C9E99EC8EB9B
C8EB97C8EC95CBED97CCED9CCBEA9ED0EBA6DDF7B8EEFFD6F8FAF5FEFBFFFFFDFFFFFEFF
FEFDFFFBFDFCFBFFF9FBFFF4E9F5DDDEEDCCD3E6B9CDE4AECBE3A5C8E39ECAE69CD2E5A3
C5C996F1EEC15A5B2F70754CDDE3BDD4DAB8E9E9CDFFFFEAFFFEEDFFF4E9FFF0E9FDEBE7
F5E7E49B928DFFFDFAFFFFF4F3FCDDE7F6CDE0EFC6E5F6CAF3FFD6F4FFD5E0F9C0C6E2A5
C6E3A3C6E3A1C9E7A1C3DE97CEEAA0CFE99FA9C3799AB26890A5608BA05BCFE49FCFE69E
D1EBA1CBE79CC6E298C9E4A1CDE5ABDFF2C4F8FFE67C85702C2F28AFAEB3FFFCFFFFFBFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFFF7D0D3CA7F8279FEFFF8B9BCB5FEFFFAEAECE7FFFFFBF9F6F1FFFEF8FFFDF6FFFDF4
DDCFC69D8C8287776A1E1206EAE8DCF7F9EEFBF9ED8D897D4E483C585045696057CBC2BB
FFF9F3FFFFF6EBE9DCEAECD6DFE6C4E7F3C5CAD79FDDE8BD9FA196F6F6F8FFFFF8FFFFEF
F5F8D9DDE4B8D0D7A3C0C9908A9259D5DEA9FFFFDCFAFFDFFBFCECFFFFFAFFFEFFF8F9FB
FBFFF8F9FFF1F6FFEDF5FFE7D2E3C1D1E3BBCADDAFCCE0ABD8EDB4C6DC9EC7DC9B8C9F5F
839352C8D796F4FFC0CBD99ECFDFB0CEDEB7D3E2C1E1F0D3F1FFE6F9FFEDF9FFECF4FFE5
F9FFE4CEDAB4D1DDB7CFDBB5FBFFE3F5FFE0F0F9DEFBFFEAF1FFE6EBFFE3F0FFEBF1FFEC
F2FFE7FFFFEEE8D8CB9D847DA9928C0D00001C1A0EFCFEF1F7F7EDFCF1EBC6A8A8533B37
000400000A004A5E3932441A203200D2E5ADDBEDB1CEE1A1C8DC97D5E9A4DBEEACDCF1B0
C5DB9BD1E9ABC5DEA4D2ECADCCE89ECAE99BCAE89EC9E99EC9E9A0C8EAA0C8EA9EC8EB9B
C5E894C6E995C8E998C7E69AC6E19ECDE5A9E2F6C3F8FFE7FDFEFFFFFBFFFFFCFFFFFDFF
FDFBFFFCFCFFFEFFFFFCFFFDFBFFF8EFFAE9D4E2C8C9D9B4CDE0B2D2E7AFD1E7A9D2DFA7
EBE8BDD7CFAA3F3D17A2A381CACFAFEFF5D9FFFFEDFFFFF1FFFDF4FFFBF6FFF9FAFFFAFA
FFFBFB584E4DD8D4D1FFFFF8FEFFEDFBFFE7F5FFE2F4FFE1F8FFE3F6FFE0E1F7C9CDE3B4
CAE0AFD0E7B1D4EBB3C5DDA1CFE5A7D9EFAFC9DD9EC9DD9E87995D64763ACADC9ECEE2A3
CEE4A3CDE6A4BED796D9F3B6D3EAB6D5E7BDF8FFE87A8370050801929095FFFBFFFCF6FF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
9EA886BBC4A5F5FEDFEBF4D7C0C8B0AFB7A2F3FAE8F9FDEFFFFFF6FFFFF6FAF3EBFFFDF6
F2E5DF90817C64524E86777277706A58534D5D564E5C534AB9AFA6FFFCF6FEF5F0FFFDFA
FEFAF7FFFFFBFFFFF8E2E4D6DDE1C8D7DBB8D3D9AB4E522FD6D7CFFAFBFDFEFFF7E2E7D3
D0D5B5DAE3B8E0E8B5BDC890FFFFD3FBFFD3F9FFD9FEFFE8FFFFF4F6F8F5F1F0F8FDFDFF
F9FEFFF7FFF9F4FFEFF8FFE8EFFFD4EFFFC9D8F2ABC9E495CEEA96CBE493E0F6ADBED191
C9D7A2E7F2C7FEFFE1FDFFE5F9FFE8F6FFECF6FFF1F9FFF8F9FFFBFBFFFDFBFFFBFBFFF6
EFF8E5FCFFEAF5FEDF9DA784959F7AD4DEB9E9F3CED2E0AFD5E9A4CCE594CAE999C7E79B
CBE4A0DBE9ACD6D2A3BBAF89D8CDAD5F5A3D0004006A715FF6F6ECFFF6F365444B7C6265
A6A99E2A3D2965775DADBE9C6E7F555262313E4D14DDEDAEDAEBA7D4E8A1CBDF98CFE59D
C7DE98DDF6B2CBE6A3CDE8A3CAE89ECAE99DCAE89EC9E9A0C9E8A2C8EAA0C8EA9EC6EB9B
C8EB99CAEB9ACCEB9FCBE6A1CADFA6D0E2B2E6F5CEFBFFEFFEFFFFFFFCFFFFFCFFFFFDFF
FDFBFFFCFCFFFEFEFFFCFFFFFCFFFFF6FCF8EAF2E5E5F1DBE9F6D8ECFBD4E6F6C7E4ECBD
F9F1CC817454AAA585C5C6A7E4E8CDFEFFECFAFDECFDFBEFFBF0EAFFFAFADBC7C8A18E90
716664ADA5A2FFFFFAFEFFFAFEFFF5FFFFF3FEFFF3FBFFF0FBFFEFF9FFEDF3FFE7E8F9D9
E6F7D5E5F7D1E9FBD3E0F1C7E2F2C5E0F0C1D2E0AFDDEBBAD3DFADB8C492BCCA95CDDEA8
D5EAB2CFE6AEEBFFCCD2E8B7C9DEB3E9FAD6F9FFEC777E6E292A24A4A2A5FFFBFFFFFBFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DAE7B1CBD8A3CFDBA9EAF7C9D2DFB4C3CFABCAD5B7BAC2ABA0A493FFFFF4FFFFF6F3ECE6
FFFCFAFFFBFBFFEFF0FFF4F5EFE4E2FFFCF8FFFCF6FFFCF6FFFCF6FFF6F2FFF9F7FDF9F8
FFFFFFF5F6F8FEFFFDF4F7EEE9EADAEAE8CFB1AC8CFFFFE6FFFFFAFCFEFDF9FCF3EBEFDE
E1E7CBEDF5CEDCE5B8A8B280F1FACBF1FACFF6FDDBFAFFE8FCFFF2FEFFFDFEFFFFFCFFFF
FBFFFFF8FFF9E1EFD8E8F8D3E2F7BFE7FFBAD1ED99C9E68CC3E084D7F39CC6DC91859759
C5D2A6E7F0D1F4F7E4FDFFF2FBFFF4F9FFF6F9FFFBFAFFFFF7FCFFF8FBFFFAFEFFFCFFFD
FCFFF4E4ECD5DFE9C7F1FCD2DDE9B9C3D09BAEBB86AAB87AD6E894CFE789CFEE90C5E68B
C6E28EC4D98EADB174A2A06DD3D2A6DEE2BD000A000006000D1103FFF9F4AC8D935A3F46
F4F6F3F4FFFA53615034442A9EAC8BD0DFB49CAA7569793BD1E29ED8E9A2D2E69ED5EBA0
CFE59CD0EAA0CDE79EC8E49ACAE89ECAE89EC9E9A0C8EAA0C8E9A2C8EAA0C6EB9EC6EB9D
CBEE9ECDEDA1D1ECA5D0E8AACEE0AED3E2BBE7F1D6FCFFF4FEFFFFFFFDFFFFFEFFFEFDFF
FEFDFFFEFDFFFEFFFFFEFFFFF9FAFFFCFFFFFCFFFDFCFFF6F9FFECFCFFE6FCFFE1FFFFDC
9B8E6B847453FFF8D7FFFFE0FFFFE6F4FDE2FAFDEAFFFFF3E0D6CD7768636F5D59CBB9B5
C5BAB4FFFDF2FEFFF4F0F6EAFDFCF8FFFEFFFFFFFDFDFFFAFBFFFAFBFFF8F9FFF8F9FFF4
F9FFF3F1FDE7F6FFEAF9FFEAFBFFE8F4FEDCD3DDBBD7DFBAE7EFC6E4EDC2D3DEB3D0DDAF
CFE0B3EAFDCFF5FFDDD9EEC5CFE3BEE6F6D9F9FFEF797F7112130D888485FFF6FEFFFCFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D3E398DCECA3D0E19BC3D392CAD9A0DDEEBAE5F4CBBAC5A38B937BFEFFF1FFFFF6FFFCF8
FDF3F4FFF4F9FFF8FFFFF9FFFFFBF8FFFBF4FAE9E2FFF8F1FFFBF4FFF5F1FFFDFBFDFBFE
F4F5FAF8FBFFFCFFFFFEFFFFFFFFF8FFFEF1958A76FFFFECFFFEF9F8FDF9FCFFF8FCFFF3
FCFFECE9F3D1BEC9A1A8B389CFDAB0D2DCB7ECF5D6FCFFECFAFFF2FCFFFAFCFFFFF0F5F1
FBFFF6F7FFEBCEDDBCC8D9ACC8DEA0D1EBA2C2DE8ACCEA92D8F49DC5E08FB9CE89889962
CAD6AEF2FBE0FFFFF3FEFFF8FCFFF6FAFFF9FAFFFEFAFDFFFBFEFFFEFEFFFEFFFFFEFFFD
FCFFF1E0E6CADDE5BCD4DEA9D7E3A5E2EFA9D7E79E8E9C51D1DD95D0E097D7EFA5D1EDA3
DCF7B4D9EDB0B7C08BB5B88BDCE1B9C8D4B07A8D6D000900000700E2DED3D3B9BA7A6467
CACBCDF0FFFDC4D1C842503F435034C7D6AFBAC8954F5D228F9E5BB5C67FC7DC8FD6ED9F
D7EEA0C0DB8CD4EFA2CAE69BCAE99DCAE89EC9E9A0C8E9A2C8E9A2C6EAA0C6EB9EC6EB9E
C5E79AC7E79ECCE7A4CFE4ACCEDDB2D3DEC0E4E8D7F3F6EBFEFFF7FEFFF9FEFFF9FEFFF9
FFFFFAFFFFFBFFFFFDFEFEFEFDFDFFFEFFFFFEFFFDFDFFF7FAFEEDF7FDE1EFF6D4EBECC4
605128D5C39BF1E8BFFFFED7EAF0CCE5EFCDFFFFE8FFFFEBA9A2907D7060C0B0A1E9D9C9
EDE5D2FCFCE4FCFFEAFCFFF1FFFEFFFFFCFFFFFCFFFEFBFFFBFBFFFCFFFFFCFFFFF8FEFC
FBFFFDF6FDF5FBFFF8FCFFF4FCFFF3FEFFEFE7ECD8E7EBD2DBE1BFE1E7C1DFE7C0E5F0C8
D8E7C0F7FFE1EAFED9EFFFE0E8F8DBDBE9D0EFF8E575786D0100007A7474FFFBFFFFF8FD
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C9E08ED6ED9BC9E090E2FAACCBE29ACBE1A0CDE0A9D9E8BDC3CEAEFCFFEFF0F1E9FFFEFD
FFFCFFF9EEF6FFFAFFFFF4FBFFFCFAFFF6EFFFFCF6FFFDF6FFF8F1FEF9F3FFFEFAFEFFFF
FCFFFFF6FBFFF7FCFFF7FBFCF5F4F2A69F99FFFDF3FFFCF1FFFFF8FEFFF8FBFFF1F9FFEA
F8FFE2C8D4ACABB88AD6E7B3DBECB8C4D4A3D7E7BAF1FFD9E3F1D0E0EAD1EBF4DFE8F0D9
E6ECD0F3FBD6D6DFB4D2E0ABD7E9ABDBF1A9C7DE90D9F2A1A9C271536B1F9DB26FD3E4AD
DEEBBFCAD6B2F4FDE2E9F1DCFCFFF1FCFFF4FDFFF9FDFFFEFEFFFFFEFFFFFEFFFFFCFFF6
FEFFEDC8CFADD5E1B1D5E5A7D7E99FBDD381DAF199B0C371D6E2A0D2DDA1CEE2A5C4D9A0
DBEFBAE6F8C8D0D8AFDDE3C1E4EBCCF1FBE0F7FFED6D7F690914046B685FFFEDECFFECEE
5959599DA6A3E4E7E0BBBDB07B7E699BA283D6E2BACFDFAE465A1F556A29495D1855661F
77893F819649CCE395D0E89CD0E69ED0E5A0CCE7A0CAE89ECAE89ECCE89ECCE89ECCE7A0
D8F7B3DAF6B9E0F7C3E6F5CCEAF0D4ECEFDCF7F9ECFFFFF6FDFEF6FCFEF3FDFFF4FEFFF5
FFFFF6FFFFF8FFFFFAFDFEF9FEFEFCFDFEF9FCFDF7FFFFF4FFFFEFF1F4D9C7CBAAA3A47A
5C5926DBD8A3DEDDADD4D7ACD2D6B3FDFFE1F7F7DBA9A88C726D50E9E2C5FFFFE1DBD7B4
D3D5B0FEFFDFEEFED7F9FFECFEFEFEFFFBFFFDF9FFFAF8FFFDFDFFFEFEFFFCFFFFF9FCFF
FCFFFFFCFFFFFEFFFFF5F7F2FDFEF9FFFFFAFAFBF3FFFFF3FFFFE9FFFFE6BABCA4FEFFEC
FBFFEDEDF9E1F7FFEDF7FFEDF5FFEAE9F9DECCD9BF6169543C4032B1B0ABFFFEFFFFFEFD
FCFFFAFBFFF6FBFFF6FBFFF6FCFFF6FCFFF6FCFFF8FCFFF6
CCEEA4BFE195C8EB99D1F39FC1E38DC1E090D7F2ABC6DBA2D1E1BAD0DAC2FCFFFAFFFFFF
FAF7FEFFFCFFFFFAFFFFFEFFFCFFFFF4FAF8FAFFFCFBFFFDFBFFFBF5FCF5F6FDF6F7FDF9
F7FFFBF5FEFBFBFFFFF5F9F8AFB1B0C6C6C4F9F8F6FFFFFAFAF7EEF9F7E8FFFFEAF9FFDE
A5B284A0B278D2E9A3CCE79ACFEC9CC5E292DBF7ACC8E39CCAE3A2D4E9B0CEE2AFD4E2B1
E1E3B4979565A8A675C1C48DCCD296EDF6B7D3E09B9AA9648FA05A90A45DC2D691D7EAAA
DAEEB1C6DA9FDCEFB8E1F1C2FBFFE2FCFFE8FFFFECFFFFEFF5F7E9FDFFF1FEFFF1FDFFEC
FAFFE4DEEAC2D1E4ADC8DE9DCBE699D1EF99C5E789CDEB93A3B674DBE8B2D1DFAAD0DDAF
DAE6BEFCFFE4E2E6CDE7EAD7FFFFF3FFFFF6FFFFFAB7B8B36A6967474141A7989BFCF0F0
7A786C5A5748DFCEC4F2DED5D3C2B85B544497A48ACEE6C47E9A7197B3838EA06E6F7A42
494F113A410095A3588F9C54B7B97AE7EBAED9EAA3D0E799CDE08FD9E79AD2DD98DAE8AB
E9FFCDEBFFDCF7FFECF9FDEEFFFEF4FFFDF6FCFCF2FCFFF6FEFFFDF7F9F8FDFFFEFEFFFD
F8FAF7FEFFFBF5F7F2FCFFF8F8F9F1FFFFF4F9FAEAF3F2DEF7F5DCD7D6B8E8E5C453592B
91A661CEE59DD5E6AFD1D9B0D6D6BCF3ECD9FFFEEC5349309E9A75E5E7B6EBF4BBD7E7A9
CDE3A5E1FAC1DDF9C6F4FFE6F4FEF5FAFBFFFEFFFFFEFFFFFBFFFFFCFFFFFDFEFFFEFFFF
FEFFFFFEFFFFFBFBFDFFFFFFFFFEFFECEAEDFFFEFFFFFBF8F7EDE3FFFDF39B9390FFFEFF
F9F8FDFCFFFFF4FEF6F7FFF4F5FFE8E8FDD6C0D2A87F8F68222F11ABB6A5FBFFFBD7E1D8
E2F6DAE0F9D2DCF4D0F3FFE5F5FFE6F6FFE5F2FFE3E4F3D2
C2E7A4C6EBA5C0E597C7EA96D4F69FCBEB96C8E298CFE5A7E9F8CDA5AF96FBFEF5FDFDFF
F0EFF5F2EFF6FFFEFFFBFBFDFEFFFFF7FBFAF7FBFAFDFFFCF9FBF6FDFFF9FFFFFAFFFFF8
FFFFFAFFFFFAD6D3CEA5A19EFDF7F7FBF5F7FAF4F6FFFDFBFFFEF3F8F3DFDEDDC1CED3AB
C4CE9AD1E4A4E2F8ADC6E28EC8E68EC6E48CC7E58FD0ED9BCAE49AD0E7A1C9DE9DD5E5A7
B0B4799C9C608F9054959A5A8F95558C95549BA8639EAD68B3C47ECFE39CC5DB93C3DA92
D6F0A7CEEAA0C0DA93DEF4B4E6F6C5E8F5CAE2ECC7E5EFCDF0F9DCEBF5DAE6F0D7F2FCE3
F6FFE5E3F3CFDDF3C5CFE8B1C8E5A5CEEDA7CFF1A4E3FFB7B3C289C0C698E1E6BDF1F5D2
FFFFE6FDFCE7E5E3D6E4E1D8FFFCF9FBF5F5FFFDFFFFFAFEFBF5F9403A3E0600024D4543
EBE5D9ABA291675348DCC4BAEDD9D0453D30303C2858715491B08EC0DFB6D0E7BBC6D6A5
D9E2ABB4BA7E9FAA68959B5B837E46ACA76FDFE5A5D8E39E9BA25EC0C783E1E7A9D4DDA6
D3E3B4E7F7D2E6F0D7F1F4E1F9F3E7FFF9EFFFFFF4FFFFF8FFFEFFFFFDFFFFFEFFFFFDFF
F6F2F3FFFEFDFAF7F2FFFFF6FFFFF3F8F3E0F6F0DAF6F0D6DBD4B7A19B7959512D6C7340
CCEAA0C5EA9CC9E1A7E4EFC7EDE8D4E6DACEFFF4E7675843B2AD87DADFA9D7E6A5D4EBA5
C7E4A1C6E6A7C4E5B0F1FFE6F8FFF8FAFEFFFCFFFFFEFFFFFEFFFFFEFFFFFBFBFDFEFEFF
FFFEFFF1EFF2FFFEFFFBF7F8F3EFF0FFFEFFFFFDFFE9E0E1B7A9A6372928DED2D6FEF4FD
FFFDFFF3F3FBFBFFFFF8FFF8EDFDE3F0FFDDD4E6BC7B8E61000F007F8E6FF3FFE9D3E3C8
C1DBACCAE8B2CCE9B3E3FECBF3FFD9EFFFD6EAFDCFD5E6B9
C0E3A3D2F5B1D0F2A8C8E799C7E38FCAE392CCE099E0EEB3DFE7BE7B7F66FFFFF4FFFEFB
FFFEFFFFFEFFF7F3F2FFFDFAFFFBFBFFFAFAFFFAFAFFF9F8FFF8F4FFFAF4FFF8F2FDEAE3
FFF9F4CDB8B3C6B1ACFFF9F6FFE9E9FFF7FAFFF7FAFFF4F3FFFBF1D6CBB9A0997FBCB996
E0E3B6D2DDA5CEDD9CCEE29ACFE59ADCF3A5DBF1A6B8CC84E7F8B4D5E5A6DAE8AD475517
84914CD9E79CDCECA1D6E99ADCF1A2D2E999D2EA9CBBD687D5F2A2C9E696CBEA9ADBFCAB
B6D788D2F5A5D7F8A9BFDF94BAD996D1EDB2D2EBB4CFE7B7D2E8C1C1D4B4CEE0C6F7FFF1
F5FFF4F1FFF0EFFFECD7EED4C4DDBFC7E1BECDE9C1EBFFD7EAEAC6847B5AFFF8DBFFFBE2
FFFCEAFFFDF1D6CBC5D9CFCEFFFCFDFFFDFFF3EDF1FFFDFFFFFDFF9590940100000B0706
807973FFFDF4D6CCC28C8278E2DCCED0D1BFE6F0D72D4022000D002F4E24C3E3B4E7FFD3
C3DAA6C2D39FE0EAB6DDE1AE9B9B675653205C51235E5628737246424818000900DCE6B1
C9CE98F0F3BED2D9A6D9E1B2E4EEC9FCFFE8FFFFEFFFF8F3FBF0F6FFFAFFFDF0F9FEEFF6
FFF9FFFFFAFBAB999557443D675547695645FCEAD2FBEACCAC9C7A60512A7C6F45FFFFD0
D3EEA7BFE39BC1D8A2D7E1BEFEF9E6FFFCF3FFFBF1655545B0AA8AD3D5A6CFDAA0D1E5A6
C9E1A7C6E1ACC6E1B4F4FFECFBFFFDFAFAFFFCFDFFFFFEFFFBFAFFFAFAFCFFFEFFFFFEFF
FAF6F5FFFEFBFFFFFAF0EBE54C483FA09C93FFFEF4FFFEF6FFF5F3FFFAFAFFFCFDFFF9F9
FFFEFCFEFFFBFBFFFBEDF7EEF8FFF6E1EEDCC5D3BA72816000090059683DD3E0B2CBDCA6
D1E7A9D4EDACCBE1A3D3E7ACDAEBB4DAE8B3DDEAB5CDD9A7
D8E6B1C4D39ACBD799E2EBA8DFE59FEBEAA7DED89CDDD3A2FBEDCAEFDDC7E9D3C8FFF8F6
FFF9F8FFECEBFFFAF6FFF9F4FFEAE7FFEDEAFFF5F2FFF4EFFFF1EAFFF7EDFFF3E9FBDDD3
C3A299CDACA3FAD9D2FFE7E0FFEFEAFFF5F3FFF4F4FFEEE9FFF7EAEADBC8C7BBA3E5DFBF
ECEAC3CACE9CD4DDA6E2EEB0C7D695D8E7A4D6E5A2D0DC9CE5EFB2CCD499888D55CBD398
D7E49FD9E9A0BFD187CDDF95DCF1A6C4DA8FCAE097E2FAB0C5DC94DCF3ABD8F2ABE1FBB4
DEF9B4DBF6B1C4DF9AC8E39ED8F6AECEECA4C2DC9DC4DBA3D1E4B7D3E3BFDBE8CEF1FCEB
F7FFF4F2F9F1F6FFF8E6F0E8DBE5DCE1EDE1E9F5E7FEFFF1FFF0DBE0CAB3C8B19FFFFAEC
FFEDE2FFFAF4FFF1F1F3E4E7FFF8FCFFFAFDFFFCFFFFFEFFF6F6F6E7E7E54D4F4A000100
403634827974FFFDF47A7C6F676E5CF0F8E1E2EBD0CEDCBB9EB48E4C6B41355C2D6E9866
BFE3B5D3EDC0C7D1ACD4D9B0BEC58FA1A269A49669A5966F837F597F865C62703F6E7941
929256949053797A3E959E67D9EABDE3F2D3E6E4D7FFFCFBFFFBFFFFFCFFFFFBFFFFF8FC
FFFAFDFFF6F3B8A7A09F8D81F2DFCEB19F895A4B2E5548255A4E26F6EEC0FFFFD3EBF0B8
C4DF9AD7F7B6E4F7C9E8EFD0FFFFF1FFFBF6F8E7E05C4E41A9A288E2E2BCDEE8B6CBDCA8
C8DCABDDF2C7D8EDCCEDFCE9F7FBFCFFFDFFFFFEFFFFFEFFFAF8FDFFFEFFFFFEFDF6F3EE
FFFDF7FFFFF4ACA99A7D7A67FFFFECFFFFE9FFFFEAFBF6E3FFFDF6FFF9F7FFFEF8FFFEF5
FFFFF4F3F6EBFCFFF8FBFFFAF9FFFBDFE9DEC9D2C16E785D00080066733EDDE9A9D6E5A2
D2E1A6D0E1AAC7D5A0D1DEA9D2DBACCBD3A4D7DCB3D8DDB4
250F00755F38AC9468AD8E5F9C7846BF9565BD8E64DAA583C58D76D99D92D59895F5B9BB
F8BDC1E6AEB1EFB9B9E2B2AED7AEA8D6B1A8D6B1A8CDA99DCAA497D8B4A4DCB8A8CCA996
EDCAB7F4D1BEF8D7C6FFE5D6FFF6EAFFE7DBFFDFD6FFF7EAFFEFDEFFEFD9E3D3BAE2D4B7
D9D1ADE0DDB4F2F4C5BAC18DDCE3ADDBE3AACCD49BDCE1A7DFDFA99C9C66AFAE78D7D7A1
D9DCA3D9DEA4E7ECB2D5DAA2D0D7A1E6EDB7D8DFABC6CD9ACED4A4E4EABCFFFFD9FFFFDA
FFFFDCE7ECC3D9DEB6E2EAB9D3E29DC7D78CDAE6A4E4EEB2D9DFAFF0F0CCFFFFE6FFFAE8
FFFDF4FFFCF8FFFBFAFFFBFBFFF8F8FFFBFBFFF8F6FFFBF4FFEBE0FFF6EAFFF3E9B4938C
FFF4F0FAE0DFFFF8FAC5B2B4CBBCBF8077788985826E6F6A878A81838B7E768171444A3E
0E0402060000797F754B594823321D546249ABB197FEFFE6D3E3BFD1EDC583B183437749
52815791B390A2AF9572785499A769C7D18AEFE9ADDDD39EE6E4B3E0E7B375824A909A5D
807C3F9C93587E7D44252B006474507986727573748380877F898ADDECE9F8FFFFFBFFFD
FEFFFAFFFFF4999687494430E2DEC3E5E2C3D5D5AFD9DFB3F2FCCACBDAA3CDDFA5CBE1A3
C3E0A0DCF8BEF0FFD9FFFFEAFFF8EFC4B5B29583815E4F48CCC4B1FFFFE4F9FFDADAE6BE
D5E3BFF3FFE3EDFAE6F6FFF5FCFDFFFFFDFFFFFDFFFFFEFFFFFDFFFFFEFBFEFBF4B3B1A5
4E4B3A82806BEDECD0FFFFE3D8D5B2E5E3BDD7D5AEE7E4C3F9F7E2FFFFF1F8F5E4FFFFEF
FDFEEEFFFFF4F7FAF1FCFFFAEEF3EDE7EDE3DDE1D0676D510007006D773BD8E29BCDD695
D3DAAED9DEBEE4E7CAFFFFE6FFFFEAF6F4DDFFFEEBFFFFED
40300E64522E654F2672572C89683BA0764C70431AA57352A66E55BC83708B5346AA746A
A8766D7B4B41FFD7CAB48D7E8F6E5B987964A88974B1937BBB9D83D2B79AE2C7AAD9C0A2
C3AA8CCAB193C6AE92CDB599A1896FDAC2AAD8BFA9AA947CB09B80CCB99BC5B496C0B393
968E6A95906AD4D2A9C1C2969B9E6F7D814FAEB07EA8A874D5D29D4F4915ABA66FD8D29E
D8D6A5A1A070BCBB8DBFBE929E9B729D9973B1AB89DDD7B7B9B295AEA489E6DCC3F7ECD6
E4D9C3C6BBA7DED3BFD0CAA89A9A5EA1A45DD3D393D5D39AA1996AA69A72C9BA9BBCAA92
B29D8CB29A8EBFA79DBCA49ABEA69CC1ABA0B09A8DB09689E0BFB0A88275D2ADA4D5B3AA
B0928ACFB3AF8D78755F4D492B201A140D050101000003000C1500000600000700000800
0905000400000712040007000E200A00070071745FEEF2DBE0EDD3D8F1D3CAF8D3B4E8C2
5486633257382B3A2700060099AD6EE8FDB2C8D38ED9E09DDFEAA8D2DE9CD1DD9BBFC887
B8B87AE1DFA6C1C090090B000006000003000A0809000004000702697F73A0B1A77F8B7F
6E74669093825C594628240B6662477877586B6D486B74494B582A738752627943647D44
607B446B81527B8664949681756C6554444434242431241E6E67578E8E76797E60687152
66705777806D757D72929791FEFFFFFFFFFFF6F6F6FFFFFDFFFEF9FDFDF1D8D9C7656751
1D1D017A7B5BFFFFDDFFFFDAD4D7A8C9CD9AE1E4AFCDD19FFFFFDD6B6F4E9EA1867A7C66
72756482847783857A76786D86887B676A576D7055373B16141700797E46CFD396E3E6AF
CACAA8CDCBB6D3D1BCF0EDDAF3EEDBDED8C8E9E2D2F4ECDF
3353228EAC7AB4CC9A7C8E5A626C37E1E6B0ECEAB7DCD6A6F6EDC2E8DFB8FFF9D4F1EBC9
EBE8C5D6D8B3FFFFDFD9DBB6E2DCB8EAE0BCF3E9C5F0E7C0E2D9B0DFD8ACDED7ABD0CC9D
D1CD9EC5C393DDDCAED1D0A4EAE8BFD8D6ADEDEEC6E9E5BFFDF1C9D6C7A0958961CAC19A
F8F3CBEFECC3FFFFD8E7EABFE4E7BAEAEDBEE1E3B1777743CECB96FAF5BE746D36ECE7B0
F0EEBEEAEBBFF4F2C9D9D5B0B5AF8DC5BC9FE2D6BEE6DAC4CBBBABE9D7C9EAD8CCE9D7CD
FFEEE4EDDAD3E2CFC8FFEFDBEFE3B3D4CA8FD5CA92D0C38EAA9A6996835888724B634B27
6E56327C64409B835DA58E65AE986FBAA578B19C6DB29D72A2876AB1927DBA9E89CDB29F
8E7765F5E2D3FFFCED0A00004C45329E9E8670745987907187957192A3797A8D6098A780
7B7D65BDBEAC000800000600000600323A2BB9B9ADFCFCF2F2FAEDF2FFF6E4FFF3C7F3D8
BBE6CAA4C6AD394C38000D00CAE2B0C4E4A3BFE59ACFF4A4C9E591DAED9BD9E496D9E39C
E0ECAECED8A6DEE2BDC7C5AC918A786A6456EAEBDDFBFFF4B3BFB18A9786737B6C848776
878473837A6950412E45331FA4927C76664D968C718984667C805F747C5787966F6C7D53
6A7D5073825B8B9175918E7D3C312B786868908080897C768E867B9F9E8A8B8E798C917B
8C938391948B8C8E8BB2B4B1FCFFF8FBFFF3F1F5E6FEFFF1EEF3DDDFE5CBCBD2B16B734E
333B12BFC899C6D09CE3EEB6CFDA9EE0ECAEE3EDAEE0ECACC5D094DEE8B381876193977C
A0A392E5E7DCE6E6DAB0B19FD3D3B79B9D76969869777947797848B9B88CDEDCB6F5F2D1
EFEBCEF0ECD1E4E0C5EAE6CBEAE6CBDFDBBEE3DFC2DBD7BA
54865135662F9EC993CCF1BB4F6D37849D66C3D69FDFEDB8D1DEA9DBE8B3E7F5C2DFF0BC
E4FBC7ECFFD0D0EDB7E4FCC8EBF7C5EBF2BFECF3C0E3ECB7D2DBA4D0DBA1D8E3A9D6E4A7
D9E7ACDCEBB0D2E4A8D3E5ABC8D9A2DFF0BAE1F4BDE3F0BBEDEAB7E9E2AEA29C6AC8C695
FFFED0E6E7BBEEF4C6EDF5C6F2F8CAEBF2BFDBDFACECEFB8E3E2AAD4D297B0AC6FECECB0
E6EFB6F0FDC8E3EDBBECF4C5ECF1C8EAEAC6FFFCDDF1EBD1F5EDD6F7ECD8F4E9D7FFF3E3
E9DDCDFDF1E1FAEEE0F0E6CDFCF3C8E0D6A1CBBF8DC2B684AC9E6D897B4A70602F645423
A69663B9AC77DDD398E2D89AE1D998E5E19ADBD98FE1DC9ADCCFA2D1C19F8879588C7F5D
93886AECE3C4F7F2D40603007C7D5BE8EEC8D1DAAFD5E3B2D5E6B0D0E4A9D1E5A8CADBA4
EDF8CEDEE3C3373D210005000809006E6E66B8B4B1FFFEFFFBFFFFE7F6F3EEFFFDEAFFF9
D4F4DFE1FDE65F735A000C00AACCA9C6F4C5B3EEACBAF4A7BAE691CBE894D5E698D4E49D
D2EAACBFD6A2D2DCB7EDECCE7C6E54554A2EFFFFDAE1EBC6F4FEE3F6FFE8FFFFECFFFFEA
FFFBE6FFF5E0B5A08D735C4AFFE8D6FFFBEAFFFAE8FFFCEAFFFFEDFBFEE9FCFFEFE4EED5
D4DFBFDEE8C6FFFFEAFFFBEB584B43B2A3A0FFF5F2FFFCF6FAF4E8FFFFF1FEFFEFFEFFF1
FEFFF6FFFFFAF0EEEFFFFFFBFAFFECF9FFE6F7FFE2F9FFE3E1EDC7C7D6ABDAEABDA5B584
92A36DA8BA80C5D799889B5998AC67B3C780C8DC94CDE199D5E79DD6E6A5D3DFADD9E0BE
DADDC8E4E5D5FFFFEDEDECCEDBDCB0DDDDA9E0E1A79998629C996EF1ECCEFFFFEFFFFBED
FDF9E0FFFFE4FEFDDEFFFEDFFFFFE1FFFFDFFDFDD7DBDDB5
BFE9B781A9772C511E294616B0C898CADEAD52632FCBD8A3D5DFAADFEAB2D2DDA3D4E3A8
CADCA2C5DA9FDAF2B8C9E1A7D6EBB0C7DB9EDBF1B1CBE1A0C6DC9BD5EEAAC4DD99CAE59E
CAE5A0CBE9A3CBEAA4C5E4A0CBECA7C8E8A5BDDD9CD3ECABE2EBACABAD6EAAAE71D6DCA0
DBE3AAD1DCA4D2DFAACFDDA8CCD9A4D2DFA9D9E2ABE1E9AEDBDFA2818342E5E6A4DCE6A1
CCE89DC6EB9EC7E99FCBEAA6CAE4A5CEE6ACD2E4B0D8E8B7CFDCAEDEE9BED5E0B6D6E1B7
CFDCB1D0DDB2DDECC3C4CFA4DCE2B44E5021999B6AB5B786DEE0AED1D49FDEE1A8D5DB9F
D8E1A0D8E39EDDEBA0D1E493D7ED98C4DE85C9E68AD8F09CD2DC9DD9DEA8DBDFACDEE2AF
D7DDADD3D9A9DCE4B3010B006A7440D2DFA9D5E4A9D3E6A6D1E59ED4E99ED2E79AD1E79E
CCE0A1D1DDABFFFFDD322B112214090A00003B313AFFFDFFF6FAFFF8FFFFF7FFFFF7FFFF
F2FFF1F5FFEFF3FFE75D7C5D4D79687DB8A26FB78FB7FDC7BAF2B1BDE8A3D9F6B3C7E29F
D1F1B0C5E3A7C6D9A2E5E9B6F2E8B361571AAAAD66DBE6A2D0DCAED1DBB8D0D6B4E6E5C6
E0D9BCD9CDB3705E48D6C1AEFFFAECFFFAEFFFFBF3FFFCF6FFFFFAFEFFFDFBFFFFFBFFFA
FEFFEDFAFDE297957EB5AE9C6A5E52B7AAA1E6DCD2F9F3E7FFFFF1FFFFEFF9FFEEFCFFF3
FEFFF6FCFDF7FFFCFBFFFFF6E9F7D3D0E7B3C5DCA6CEE5AFD5EAB2CCE4AAC9E1A5CFE7A9
CCE5A4C8E19DD2EBA7DBF5AEC4DE95A3BD73A7C177C6E194BBD3858DA35B8EA066CFDBAD
FEFFE1F3F7D6D2D2AEDFDEB0E4E3ABDEDEA0DCDCA0B2B07DEFEACAFFFDEDFFFCFFFFFAFD
FBFAE8FFFFE6FFFFE4C9CDACD8DEB8E0E7BDCBD3A49AA472
BBDDABDAFCCAC1DEB0000D005E7348CDE0B2CADAA995A36ED1DEA6D8E6A9CFDE9DD2E1A0
D6E6A7D3E5A7D2E6A9C5DB9DCBE1A1CDE6A4C0DB96D2EDA6E0FBB4C6E49AC4E298D7F7AB
CCECA0C8EA9EC4E69AD1F3A9C6EAA0C6EAA2D9FDB7C3E19BC4D48D6E783189944FD7E6A1
D1E1A0CADD9DDFF3B6D0E4A9DCF0B5CDDFA3DDEDAFCCD89A9DA866D5DC99D4D996D2DF97
CCEF9FBAE794BEE999CCF2A7CDEEA9C7E5A5C4DDA3C1D8A0C6DAA5CFE3B0C6DAA7C9E0AC
CCE4B0DEF7C0F2FFD6E9FFCACCD8AAD7DEB2565E2F242C00D4DEAAE5EFBADBE8B0D5E5A7
D7EAAAC9E09AB9D38AD3F2A4B8DB89D3FBA5C5F097C1E794CDE79ED1E6A3D0E5A2D2E7A6
CDE1A2CADEA1D2E6A9000D00627436CCDF9DCFE39CCEE398CDE293CFE590CEE58DCEE690
D2EEA1E1F4B4FFFFD65041243C241A1900040E000D01000EFCFDFFFCFDFFF3F0FBE9E5E6
FFFFF4F4FCE4F0FFDFC3E7C37FB6A3387D6B438C716CB48EAAE9BABDF3BFBCE9B2C4ECB0
C3EAABC9E9AAD0E6A6D5E19FE6E7A1B3B16660620FD6DD90D0DDA5D7E7B8DCE7BCC7CEA5
DADCB5928F6CA0997CEDE3CAFFFEECFFFDF1FFFEF8FFFEFDFEFFFFF9FFFFF8FFFFF9FFFF
FFFFF19B977E59533DA69E89FFFDECF9EEDCCFC8B5FFFFECF7FBE4FCFFECFBFFEDFBFFEF
FCFFF3FFFFF6FFFFFAF6F9E8D9EBBBCBE5A6C9E3A4CEEBA9D2ECABC9E6A3C5E29FC7E6A0
D0EEA8C6E69DBFDF96C6E69BD4F4A9C6E69A8DAD61547327718D42D4EEA7C4D899AFBE85
2F39055C63303C3F0A5A5921C7C58AF0EEB3DBD8A38F8A62F4EED6FFFEF6FFFBFFFFFCFF
FDFEF0FDFFE8EEF2D7DDE4C3DAE4BFCDDAAE414F1ED7E8B2
ACC895C1DDACCDE9B9CFE9BC2B42169AB082DAF0BF91A66E82985AB6CB88E0F4ADDAEEA7
D0E19DC6D695C9D99BEBFDBFDBEEACC7DC97DEF3AECFE69EBBD28AD3EBA1D2EA9EC1DC8F
C3DE91D1EDA0D4F0A5C3DF95C4E096CCE7A0C4E29ACDE79EB4C97CB3C677C1D689D4EA9F
D4EBA3C9E49DCAE5A2CEE9A6C8E2A1C8E1A0C3D897D6E6A7667232E0EBA9DBE4A3D5E4A1
D2F2A9C1E79ECAEBA6CEECACCBE4AAC8DFA9D7EBB8DEEFC2D3E3B6D7E7BACFE0B3CFE2B4
CEE4B3DCF4C0ECFFD0DEF5BFD4E0B2D6DDB1D1D8ACD2DAAB98A0716B7543CFDBA9C9D7A2
C9DAA4D4E9B1E7FFC7C5E2A8D6F7BEBCDFA5C9EFB4C6EDACCAEEA4C9EB9EC6E69BC9E9A0
C9E8A2C9E7A1D0EDAA001000657E3AD0E79FD2EAA0D2E999CFE793D2EA92D3EA90D2EC91
C1E38DC9E197D4D39D8C7857CBADA28D6F71513F4B04000C0000103E3A4BFFF9FFFFFAFD
FFF8EEFFFFE5F7FFE1C2E9BCAFF0C8AEF8D578B99B57937743846687C8A6A5E3BAB6ECBB
C0E7B0CBE9A9DAF1ABC9DE93C7D78CDFE79E65601ED8D797DCEBB0C1DAA1CCE3ADD6EAB5
CADAA99DAA7EA4AF87FCFFE4FBFFE9FAFFF0F8FFF9F6FFFFF3FFFFF0FFFFF1FFFFF5FFFF
FDFBEE61573ED3C7AFFCF0D6FFF6DCF6EDD0EEEBCCC8CCABDDE7C5F2FFDFF8FFE8F0FFE2
F4FEE6FEFFEFFAFBEDE0E6CCD0E4AFCDEAA8CDEAA8CAE9A5C8E5A2C7E6A2C9E8A4CBECA5
C1E09ACDEFA5CCEEA4BEE096BEE096CBEDA1C3E89BB2D48ACBEAA7DBF5B4CDE3A2D8EBA9
A2AF6A9BA4618C8E4DA5A5676D6A33D3CC9EE6E0BEBBB39CEAE2D5FFFEF8F4F0EFFFFFFD
FAFCEFDDE4D2D8E0C9DBE5CACAD8B590A177DFF2C4D4EBB7
8AA36C7F9763CBE3B3D7F1C4597248000D00CAE6B5B6D399BFDC9A9DBB73809A50789044
ADC179C1D28E8C9A5C8391538B9B5ADCF0ABBFD08CCADE97E3F7AFCEE29AD7ECA1ADC275
DFF6A8B7CD82DAF0A7DFF5ACC8DC95E4FAB2CFE49F889E56A7BD72D9F1A3DCF4A6C6E194
CCEB9FCAEA9FC1E198D1F0AAC9E7A1D9F4B1ADC382506323B3C184C5CF92EDF5B9CED99F
B9CC94C7DEA8DCEEBCD1E1B4E7F2CAFEFFE1FFFFE3ECF1D1FCFFE1FFFFE4FCFFE3FBFFE1
F7FFDEF7FFDDF5FFDCE4F8C7DDE9B9EBF3C4FFFFD8FFFFD8FFFFD6FCFFD3D2DAA9A9B283
8E9A6CA6B387C1D2A6F4FFDCECFFDBCBE4BDC0DAB5F0FFDDD4F9B3CDF4A5C4EA9DC7EBA1
C7EBA3C9EAA5D0EFAC0011005F7C39CAE5A0CCE69DCCE498CAE392CDE692CEE690CCE891
D2F8A3D5F1A6DEE1A8A4956E9276619B7E78E2CECFC2B5BC6B646C2B212A1C0B110D0000
807468AAA88FC6D4B0C7EBBBBAF6C0ACF1BBB8ECC6D8FFEDD8FFFB2065494D9474B3F1CA
BCE6B8C4E2ACE4FEBFF4FFC9E5FEBAE2F0B2B3AB7A938958BFC891F1FFC9DFF1B7EDFEC7
D3E4AE566733CCD9ABC9D8AFF9FFE6F9FFEDF8FFF6F7FFFFF5FFFFF2FFFFF1FEFFF7FEFF
E7DFD275674DFFF5D8FFF8D8EFE5C1EBE6BEE3E4BACAD3A6CBDBAEDEF4C6E6FDD3DDF2CB
DFEECDECF7D9E9EDD4D3DAB9DBEFBCDDF6BCD6F2B7C6E2A5BFDB9EC8E4A7D5F3B3DDFCB9
CFEEABC5E6A1C2E39CCAEBA4CDEEA7C9EDA3CBEFA5D2F6B0C9E9AAB9D799CAE5A2C4D994
EAFAB3CFD994DDDFA0BAB981D6CFA3F0E7C6ECE4CDF3ECDADFD9CBFFFFF3E7E8DAEFF2DF
E8EED4C7D0B1CFDAB876855E697A4DD0E7B3C1DAA0C1DB9E
BBCF94869B63BDD4A0D6F0C1638054002000A4C995D4FCBEC4ECA6C5EB9ECAED9DC6E393
DCF2A9CADB97838F51788246879557A1B26EDDECA9DCEDA7CADB94DDEEA7C4D48B85954C
8B9B52DCECA3CBDB94C9D992CEDB96C3D28FBAC9885A6B27D1E79FBFD98FC7E197D2EEA3
C9E89CC8E89CCFEFA4C9E9A0CAE8A2BED996B2C88846581C818E56DEE7B2C8CF9BDDE0B3
F0F1D1D5D5BBD3D1BAE1DCC8FFFEEFFFF9EDFFFBF2FFFCF3FFF9F0FFF9EDFFFFEDFFFFEA
FAFEE3FCFFE4F7FFDFEAF7CCCFDBABDFE7B4FFFFD3F6FDC9F1F5C2FFFFD3F6F8C7D6D8A9
BCBD917D7F57A5A782FFFFE3F7FCDEDEE4CAE4E9D2F1FFDCE1FDC0D3F7ADC7EBA3C8E9A4
C8E8A7C8E6A8CDEBAF000F00607C41CBE5A8CEE8A9CDE6A5CBE4A0CEE89FCFE79DCDE99E
AFD487D0EFA9D5E0A6D7D3A4AF9F7E68523B887264FFFBF1F6E8DF7A6D65140700110700
06000035341FEEF7DCC5DCB2B8E7A3B8EBA6BAE1ACE7FFE8DDFFF41C5B40094F33A6E7C9
CBF8D7C8EAC5D0F0C1EFFFDBDEFAC9C8D9ADDBD5B56859387F7749FDFAC5FFFFCFFFFFC9
91915D6E703EDADDAEEFF5C9FEFFDDFEFFE4FFFFEEFFFFF6FFFEFDFFFDFFFFFCFFFFFBFF
B3A393937F64FFFEDDECDEB7F3E8BBDEDBA8D8DDA5DFEDB2CBE0A7CCE8AECFECB6CCE8B7
CEE4B6D3E4BAD8E3BBD5DFBAEAFAD3EFFFD9E8FAD0D3E6B9C8DEAFD4EAB9E4FCC8ECFFCE
E3FFC5C7E3A6BDDA9ACFEEABD8F7B3C8E7A1BBDA94BEDF9ABADD99D7F7B6D5F2B0CEE4A4
CEDC9FDEE5AFDCDBAF9C9873FFFFE4FFFEEAFFFCEBFAF5E2E8E8D0EBF0D2D6DEB9D6E2B4
DCE6B1DEECAFA8B879879B56B5CB83CBE699D3F09ECCEC97
BACA8C95A96E95AC76B8D4A3C6E7BA5F8657002500B7E8A7C2F2A8C6F3A2C5EC99C2E392
D1E99DD1E29EC5CF93D3DDA1DAE8AAC5D89697AA68CBDF9AD8E9A38B9C5598A962C6D68D
D2E2997B8B42CFDC96EEFBB6D2DE9CCAD694A6B272CEDD9CDCF1AED8F2ABD3EDA6CCE89E
CAE89EC9E99EC8E89DC8E89FC6E49ED9F4B1D4E8ABC7D8A1DAE4B2CED6A7ECEFC4FFFFDF
F9F5DCFFFFEDFFFEEFF7EBDFFFFBF4FFF2EBFFF4F0FFFAF6FFFBF4FFF8EFFFFEEBEBEBD3
D3DABBD4E0BCCEDDB4CCDFB1D6EBB3D6EBB0CBDFA2D1E3A7DCEAADCFDA9EC7CF96E5ECB6
DBDFACE0E3B4BBBC9290906ADFDFBDD4D3B5DBDBBFFEFFE1DEF3BBD0EDADC5E1A4C6E2A7
C9E4ADCDE8B3D6F0C00012005C7646C6E1AECAE5B0CBE6AFC9E5ABCCE8ABCCE6A7C9E7A7
D7FABAC5E5A6C4D9A0E2ECB7E1DEB1E1D3AC9682615E462ABBA78EF1E3C9FFFFE8C2C1AC
393B26000300000300000600A0B87EBEDB99D7F2BDD0EFC5B9E5C4DCFFF8003D26447F69
C8FCE6E2FFF5E7FFEFEDFFEAD7F1CCDAE8C4EBEBC9CFC7A2B9AE815D5320A9A26E5E5B24
B2B179C5C891CFD6A0CAD29FE8F1C4E8F0C9ECF1D3F6F8E3FFFFF4FFFDFAFFFCFDFFF5F2
D1BCA98C7758FFF2CDC9BB8EA59B6689874CC3CC8BD7E8A4CFEAA5C5E5A2C2E5A5C7E6AB
C8E3ACCBDFAAD7E5B4E5F0C6F3FDE2F7FFEDF5FFE9E9F6DAE2EFD1E6F6D2EFFFD8F1FFD7
DEF1C3D4EBB5CCE4AAC6E0A1C4DE9DC5E09DCDEBA5D8F8AFCDF2A5C7EBA1B7D492D3E8B0
E4F1C6F3F8DAEDE8D4A49D8DEFE3D7FFFCEDFFFFECC3C2A4EFF4CCD1DAABCDDCA5D5E5A6
AFBC778E9C5192A355E2F5A4C3DA88D0E995D0EE96D0F196
ADBC7B92A466B0C78FD2EEBDC2E8B9BFEBBA15480F84BB78B1E79BBBEF9CBFEC97CDF39E
D2EDA0CEDF9BDBE5A9DFEAB0DBEFB0CCE5A1CCE5A18FA962869D55CCE49ADEF4ABD4EAA1
D6EAA2C5D99141520C23340053621F8B9A59E1EFB1D2E2A3B5C98AD8F1B0D0E9A7BBD691
C8E69ECAEAA1C2E299D3F3AAC9E49FCEE7A6CFE0A9CBD9A6FAFFD5FFFFDD767654FBF7DA
FEFEE2FAFAE0FFFFEAFFFFECFFFFED82796A5C5344A69F8FFFFFECF8F8E0FEFFE4E9F8CF
CEE4B5CDE8B1C4E3A7C5E9A9BFECA9C7F6B0B5E099BBE39AD3F7ADCCECA1D4EEA5C5DC94
D1E59ECEDF9BC2CE90ABB579646B35BAC18DF9FFCDF2FCCAE4F5BFDBEDB9CFE3B0CFE3B2
CFE2B5D0E5BADCF1CA0015005D734DC6DFB8CCE5BDCDE8BDCCE7BACEEAB9CBE9B5CAE8B4
BADAA8CAEBB6CCEDB4CEE7ADD6E1A7DBD8A1ECD8A6E9CE9F634B1F74653CCACAA4EFFADA
F9FFEDD6DECF0F0C07070000080100E4E6BECDDEB4B9D5ADB5D7B6E5FFF2E2FFFB538677
4D877B87C1B3E0FFFFEAFFF4DDEECED7E2B7C2CD93E3EBAFE3E3AD9D9B689C9F68A7AF74
CAD89BC3D798CFE8A7D3EDAECBE7ACCCE4B0D2E8BAE3F3CEF7FFE6FEFFEDFAFDECF7F0DE
E5D1B95F4627675128574714756C31575613515B12CBE093CDECA0C4E89EC3E8A2C6EBA8
CBE9A9D0E8ACE1F3B9F3FED3F9FFF0FDFFFCFDFFFAF9FFF5F7FDEFF7FFEBF7FFE8F5FFE2
E0EFC8D8E9BCCFE1ADCEE1A9D5EBADDAF0AFD0E7A3BFDB8EC1E88DC5ED95D5F4B1C8DDB4
F7FFF0F4F4F6FFFBFFADA1ABFFFBFBFFFEEFFBF8D99DA071D5DEA5D8E7A6D9EDA8CFE39C
99A45F9AA45DD9E69EC8D88DEBFFB3BFD688C7E295CBE898
65833B728F4DCEE9B4CCE9B9BAE0AFBDECB8689D6767A166BAF6B0BDF3A5B8E48FD0F29E
D2EAA0C8DC97DBECA8CBE09DCAE8A2BFE099C9E8A2C9E79FD0ECA2CFEBA1C2DC92D3EDA3
D1EBA1CCE69CDBF5ABCCE39BCBE29AD9EEA9C9DD98D0E5A2DFF8B7BAD493C4DE9DDDFAB7
D1EFA9C6E59FCBEBA2C5E39DE8FFBEF0FFC6E6F9C1D3E1B0D6DEB5C7CDA9E6E6CA909078
92947EF9FBE5F2F4DE92947CDBDEC3F5F6D7E8E9C9CCD0AD9B9F7AA2AA81CCD9ABD0E2AE
C6E0A3CCECA9C2E7A1C5EFA5B9E99FB3E79CCAFDB0C0EFA1BCE899BBE495CFF4A4C8E998
C9E598D3EEA1DBF1A8CCDD97C1D08D98A766BAC686FCFFCFFCFFD6F5FFD6E5F2C7DAE9C2
D1DFBCCBDABBD2E2C50008007E9076EBFEE2F1FFE7F2FFE8F2FFE4F2FFE1EFFFDDEEFFDC
F1FFE1EEFFDEF0FFDDDAF5C0D5E3AEDDDDA7F0E0AC69541F6B561F554A14949866D3E0B5
C4D1B3EAF3E0FCF9F4ACA19D1406000701000007009AAF8ED2EBCECDE9D0C7E3CDB2D9C7
25615541847BBBF7EDDAFFF2EDFFD9DDEAB4C9DF9ED5ECA8D0DEA3CED99FDFEDB0D2E5A5
CCE39FD2EDA6CAEAA1C1E29BC9E9A6C6E5A9CCE8B5E0F7CBF6FFE3F8FFE8F6FFE5EDF2D4
E4DBBAA2966EA09567AEA971CDCD8DF1F7B178863BD2E79ACAE49ACAE8A0CBEAA7CDE9AC
D4E9B0E0EFB8F0FAC6FDFFDCFFFFF4FFFBFDFFFAFAFFFDFAFFFFFAFFFFF6FEFFF3FCFFEF
F0FAE1E9F4D4E5F1CDE6F2CAE5F2C6E3F0C2E7F3C3E9FDC2CFEEA0C5E599D8EFB9E7F4D6
FEFFFBF0EDF8FFFBFFB3A8B8FFF7FBFFFBF1FFFEE1D8D5A8B6B980D2DD99D8ECA4CDE496
94A257D7E399D3E196D7E7A0C3D490D7EAAADCF0B3DCF1B6
B5F09EB5E9A1CBF1C0CAE9BFBCDEACC2EDB8B0E4B61D562979B27DBEF0B1D6F8ACC9E193
D1E4A2D5EAA5CCEC97C0E890C7F2A2B2DC90CCF2A7C2E498C9E79DD4F0A6C8E49ACDE99F
CDEDA2C4E699CCEEA1C9EC9CC5E697CEED9FD0EB9ECEEA9DCBEBA0C0E298C7E8A1CCEDA8
C4E5A0CBEAA6D3F2ACCBE9A3E8FFBEEAFFC1E5FBBDD6E9B2CCD9AED1DDB9E9F2D7FEFFF1
FFFFFAD6D5D0B8BAACF7FFE5F6FFDCFBFFD8D5E4ADD6E4A9D6E4A7DAE5A98E9C5EDFEFB0
CEE3A0CBE69FBFDF94CBEDA1CAEFA2BFE497C8EEA1CBF1A4B6DD8ECEF5A6C8ED9FC8ED9D
CDEFA2C6E69AC4E397D1EBA1DCF3ABBAD08862762F112100FBFFD6FBFFDCDAE4BFD8E3C1
DFE9CECFD9C1D3DFCB000B007A8574ECF9E5F8FFEDF7FFEAE3F4D0F7FFDFEFFFD4F7FFDC
F3FFDDF7FFE4F0FFDCDEECC9E1E9C4E6E8C1CDC99CA69F6B5E581E999558E5E6AAD7DCA6
E0E5BCE7EACDF7F5E6FFFFF4FFFFF4686F5F0005000006005A6B58D5E7D1C9D7B6CAE3C5
C4FBE883CDC02E7E7347896EDCF9C3D0E3A1D0F2B6C3E7AAC7E5A5CBE6A3C8E39ED2EDA6
CDE99ECAE699D6F3A3CAE69BCBE6A3CEE7ADD5EBBCE0F5CEEFFFE0F7FFE6EFFFDCE2F3C9
CFDFAECCDAA5E2F1B8CDDD9FD2E2A1DFF0ACBACB87C6D793D0E0A1D5E3A8DFE9B5DBE1B3
DADAB4FBF7D4FFFFE3FFF5E0FFFAEFFFF5EFFFF5EEFFFCF4FFFDF5FFFFF8FEFFF8F7FCF5
FBFFFAFBFFF8FBFFF8FCFFF6FFFFF6FFFFF4FFFFF4FFFFEFCCDCB8CADAB3FEFFE6F2F1DD
FFFFF6FFFEFDF5F5F7B8B7BCFBF5F7FFFCF8FBE7DCC0AC94A3956EDCDBA3D4E59FB1CA79
99AF5AD5E994C7DA8BDDEEA8CAD99ED4E2B1D3DFBBFBFFE6
97D98FB0EBA9BAE4B4C3E4B9C4E5B0C1E8B3C8F9CC22572D386B40C4EEBCB2CF8FD4E7A5
E1F1B3C3D991CAEF92CCFA98C3F39DC5F1A2C1E79ACAECA0D2F0A6C1DD93C5E197D7F5AB
C8EA9EC6EC9FC9F0A1C1E897C1E696CAEB9AC7E494C0DF8FC7EA9ACCF1A3C9EDA3C6E7A0
C6E7A2C4E39FBFDD97C0DE96D2EDA6D3ECA8D3E9A9CEE3AACDDEB1D6E4C0E7F4D8F6FEEF
FEFCFDFDFBFEF2F5EAFBFFECD5E6BCD1E6AEC5D99AD9ECAACFE09CCCDB9899A565C0CF8E
D8ECA7DAF1ABCDEBA1C8E79BC8E499D8F4A9C4E397C4E498DBFDB0C2E799BBE092C9F0A1
C4E99BC6EB9DC8E89CC9E89CD3EFA4D7F1A7C7DF95B1C681A2B178A7B381B8C398D8E3BB
CDD7B5E2EBD0E1EBD300050087907BFBFFEDC7D1B6C3D1AED5E1B9DFEFC0CCDAA5D8E9B3
DAECBCD9EABEDBE9C5E2EDCDEDF3D7ECEFD2D7D8B6C2C099868654828149C9C890DFDDAA
D9D7AEF6F3D2FFFFEAFAFBEBFAFFF3B9C1B4828678000300050B079BA398D8DAC2D3E3C8
CAFBE6ADF4E42F827268AF9185A870F5FFCFC2E6B8C1E8B9C4E8A8C8EAA0C5E79DCEEEA3
CBE79AC7E293D4EC9EC8E096CCE2A2CEE2ADDDEEC4F0FFDFF7FFE8ECFFDDDFF4CDD7EEC0
D4ECB8CAE3AAC7E0A6D3EBAFECFFC6DBF1B18FA3645A692EAEB981D1D8A5E0DEB5DAD4B0
FBEFD5FFFDE8F2DFD08C766961463B63483DBCA59DFFF7EFFFF8EFFEFBF4FFFFFBF2F8F4
FBFFFFF9FFFFFCFFFFFEFFFFFFFDFFFFFCFFFFFBFFFFFDFDDAE0D2F4FBE9FFFFF0FFFEF1
FFFCF3FFFDF7DDDFDAACAEABFFFEFFFDF1F1FFF7F4BD9F94BFAA8BE1DBABCEDD9A869E50
B9D07EE3F8A9CDE199E8FABCE4F2C1EFFBD7E4ECD5FAFFF1
44794553834F466C39BEE1ABC6E7B0BFE5ACAFDAA5AFDDAC6C956914370DD9F0C4E0F0BF
C3D395D2E89DD2F096BBE081B5DC89C6ED9EC6E89BC9E89CC5DF96E6FFB7B9D58BD2F0A6
C0E296C9EFA2C7EE9FC3EA9BCFF1A4D4F3A5D4EFA2D3EEA1BEDF90CEF0A3C5E79DBCDB95
C9E8A4CDECA8CBE9A3D6F4ACC8E39CC9E39CCDE3A2D2E7ACDBEFBCE7F7D0F0FFE0F8FFEE
FDFCFAFFFEFFFEFFF6F9FFEDC6D8B2CCE2B1C9DEA6D1E5AAD4E3AAD1DEA6B8C38BA2B075
D2E4A6D3E9A8C9E7A1C2E096D2EEA4C6E297C9E89CD1F1A5C9EB9EB7DC8EDDFFB4B9DE90
C5EA9CCEF3A5D1F1A5C6E599C1DD92C6E096D0E89ED4EAA1C3D48DD2E39DC1D192505F24
B2C08BC9D6A8DEEBC0000C005A643FFCFFDFD9E4B9D5E3B2D1DEA8CAD99ED5E3A5CBDE9C
CAE59EC0DD9BCBE2ACE7F9CFF9FFE8F6FEE6EEF0DBEBEBD3FBF7DAABA7846C684278734D
B8B290FFFBDEFFFFE6FEFCE5FFFFEDF3F6E5FFFEF8ADA7AB38324001000B676362E1EDE3
DDFFF6B2EDD9BBFFE9185836365C2DD8F1C7DDF9E2C4E2C6C5E7ABC9EB9FC7E79CD0EEA4
CBE79CC8E298D8EFA7D0E5A4D5E8B1D6E7BAE8F6D3F8FFE8F8FFEADEEFCFCFE0BCD0E5BA
CAE0B1D1E8B4C8DFA9E5FAC2F7FFD3EBFFC7BED1998D9C659CA9748D95668686608F8A6A
8F846E837363948274C2ACA1FFF8EDFFF8ED523E358A7971FFFCF6F5F2EDF7F8F3FBFFFD
FBFFFFF9FFFFFCFFFFFEFFFFFFFEFFFFFDFFFFFBFFFFFDFDFEFFF6EFF3E4FBF5E9FFFDF4
FFFCF6928A87BFBFBDFEFFFFE9E4E8FFFBFDFFF7F6B2948AA69176F4EDBFD2E0A2D2E9A3
B4C986D8EAAECCDDA7F1FFD2FAFFE2FBFFECF4FDECFBFFF6
3A61447AA27D2F561F8AAE71CDF0B6D3F6BCB8DEA3A2C58F739266000C005D6F558C9D79
D2E6ABC7DE90CEE891D3EF98D7F8A7C7E79BD5F1A6B7D187D2E9A1CEE59DD1EBA2BDDB91
C7E99DCEF4A7C2E99AC1E899C9E99DC2DE93C7DD94CDE398C6E597CFF0A1D0F0A5CBEBA2
CDEBA5CCEAA4C4E29ABCDA90CDE99FCCE89ECFE8A4D8EEB0E3F7C2EEFFD4F6FFE3F9FFED
FDFEF8FFFFFBF1F7E9EDF9E1D0E1BDDDF3C5D7EBBACFE1AFCAD8A7CEDAAACFD8A99DA977
C5D69FC9DFA1C3E09DD4F2AAC7E399D6F0A6D2EEA3C5E498BFDF93C9EB9ED5F7AAC8ED9F
C2E799CBEDA0CFEFA3CCECA0CBEA9ECDE99ECAE49AC7DF93E3F9A7D8EE9CC9DB8F899A53
6F7F3ED4E3A8E4F2BD000A00737F4FF3FFCFD0DCAADBE8B2D0DEA3CEDA9CE3EFADCFE39B
CDED9AC3E696CAE9A6E3FBC7F6FFE3F8FFECFCFFEFFFFFF3FFFFEFEBE6D0A59F858E876B
968C71B3A98EA79F88B7B197A9AA8ACBCAAEE5DBCFFFF7F7B5A5B00800091D161DB2BBB6
D7F6E4C1F2D4ACE6BE4B8459264F254F6E4CDFF6E4CAE2C8C7E4AACAEA9FC8E79BD1EDA2
CDE79DD1E8A2E9FDBEE6F7C0E6F5CAEAF8D5F5FFE4F5FFE8E7F4DAD2E1C4CDDCBBD3E3BE
DDEDC6E8F9CFE5F6CAE1F2C5E1F3C3D8EAB8D2E2B1D6E3B5CCD7ACDCE3BADEDFBFDDD9BE
DFD7C4D8CABDE9D8D0FFFAF1FFF1E7FFE7DD68544BD3C5BCFFFDF6FFFFFAFEFFFBF8FDF9
FBFFFFFBFFFFFCFFFFFEFFFFFFFEFFFFFDFFFFFCFFFFFDFDFDFFF9F2F4E9FFFDF6FFF9F3
FEF0EDB8B0ADE0E0DEF9FBFAFFFDFFFDF1F3FFF5F7E9CBC39D876FD7CEA5D0DBA1D6EAAD
A1B180C7D6ADCCDAB6F5FFE2FBFFEDFBFFF1F5FDF0FBFFF8
769085607E64B8DFA8628B47C1E7ACEEFFD6D0EDADB1CA90A3B88D73866A000700384B35
A1B97FA1B96B899F4DB2C876CBE397D2EAA0BCD289F6FFC2CBDF97CBE198E1F9AFBFDE92
C8EA9EC9EFA2BCE295C9EEA1D0EEA4C6DD95D6E7A1D9EAA3D5F0A3C2E193C6E49AC7E59D
C0DB96CCE7A2DBF6AFCFEBA1CCE89DCDE99ECEE8A1D0E9A8D6EDB5E0F6C7EDFFD9F8FFEA
FEFFF3FEFFF4FBFFF1F8FFEADFF3CEE0F7CDE1F6CBE4F6CCF1FFD9EEFAD4EBF6CEB7C498
B2C291A3B87F809D5B93B16B8EA85F829C52A3BD73B4D0858CAB5FBBDB8FB2D286C5E79A
C9EB9EC8EA9DC7E79BC7E79BCDECA0D5F1A6D5F1A6D2ED9ECBE38DC2DA82D1E794E3F8AB
72863FD0E3A3CFDEA5000A00636F3DEBF7C5D2DCA8D4DEA9CDD8A0CAD39AC5CF92D9EAA4
CBED97C6EE96C7EBA1CEEDB1DEF5C9EFFFE0FBFFEFFEFFF1F4F5E5FFFFECFFFFECFFFEE8
B7AF9AB3AB98B7AB9B9B947AA9A87A9A98687C724FD3C1ABFFF9EF7D6A640400006B7666
D3EDCACFF3C3ACD79FB6E5AE5485566A926DDDF6D8CBE0B9CAE7A7CBEB9FC7E698CFEB9E
CBE59CD4EAA9F5FFD0FAFFDCF5FFE2FBFFEDFBFFEEE5EED9D4DEC6D4E1C7DEEBCFE4F1D3
F9FFE6F4FFE1F9FFE4DDEBC7D2E1BAD4E3BCC4D0AAE0ECC6CFD9B6FFFFE6FFFFE8FAF7E4
FFFEF1FFFDF4FFF9F3FAE9E2D1BAB2776156E5D3C9FFFBF4ECE3DCFFFFFAF3F5F0FAFFFB
FBFFFFFBFFFFFCFFFFFEFFFFFFFFFFFFFDFFFFFCFFFFFDFFFEFFFAFFFFFAFFFCFAEFE1DE
AD9F9EFFF5F4FFFFFDFEFFFFF9F4F8FFFBFDFFEFF1BB9C97D5BCA6E2D8B4DAE4AFC1D39F
C2CFB1D8E4D0DAE5D4F8FFF2FBFFF6F7FFF2F5FDF2F8FFF7
596C6A000A00C1E8B1C1EEABE4FFD3EEFFD6C0D89A96A86E909D72C5D3B900070047604B
8AA76F87A358E1F3A991A158C9DA93DAEBA4D5E59ED6E69F7F8F48D1E59DCDE59BD2EEA3
C7E99DC6EC9FBBE194D1F3A7D6F0A9D3E7A2E3EFADC4D18CD6ECA1C7E494D2ECA2D9F5AB
CCE69FC6E19ACCE7A0C9E59AC9E598CAE699CBE59CCAE39FCBE3A7D4EBB7E3F9CBF1FFDE
FCFFECF9FFEAF9FFEAF7FFE6F0FFDFEDFFDAF0FFDFF5FFE1F9FFE4F6FFDFFCFFE4F7FFDB
EFFFD0E9FEC5C3E09EC9E79FC2DC93E6FEB4C7E197C2DC92CBE79CBEDD91517024C8E89C
CDEDA1CDEDA1CBEB9FC6E69AC3E296C3E296C6E599CBE79ACDE693DBF4A0D5EC9CC7DD92
8EA360D3E5A7D7E6AF021000697547D1DCB1E6EFC4D3DCB152592D8A9263A6AC7C445217
C4E498C7EE9BC7EBA1C2E2A1CCE7B2E5FACFF4FFE0F7FFE3FFFFE8FFFFE8FFFEE5FFFFEA
FCF7E4FFFFEFFFFDF2DAD4BECECE9CE9E8AFC9BF8E725F35C5AB86EAD5B8060500000700
E8FAD0C6DFA8E6FFC6BFE6AD84BB91D4FFE2ECFFDCC8DDA5CEE9A6CEECA2CAE699CEE99C
C9E098D2E6A9F8FFDAFCFFE8FBFFF0FCFFF6FCFFF2DEE5D5D3DBC6E3EBD4F5FDE6FBFFEC
FCFFEDF3FBE4FCFFECE3EBD3D6DFC4DEE9CBCCD7B9F6FFE2FEFFEAFFFFECFFFFEFFFFFF3
FFF8F0FAF1ECFFFBFBFFFBF8BBA7A0644D45FFFAF3FFF4ECFFFEF6FFFFFAFBFDF8FCFFFD
FBFFFFFBFFFFFCFFFFFEFFFFFFFFFFFFFEFFFFFDFFFFFEFFF7F5F6F5F1F0FFFBFBFFFAFA
E2D4D3FFF8F6F6F7F2FEFFFDFFFEFFFFF8FAFFF2F3F9DAD5FDE4D0FFFFDDD3DDA946572A
F9FFF3F5FFF7E8F2EAF9FFFAFBFFF8FBFFF8FBFFF6FBFFF4
A8B7B0344C3646703EBAEAACB4E1AAB9DEA8E6FBC25D6A3599A178D5E2C499B29C557659
86AD74BEDE9BB9CC8C919D5DDBE7A5DEEBA6DAE5A07A854079864093A45DC8DE93D2EEA1
CCEEA1D0F5A8C1E699CAEAA1C4DB97C9D998C6CF9066712F84994E99B465AAC278BBD58C
CDE49EB7D18AB4CE87DCF6ACCCE79ACDE89BCCE89BCAE59ECAE4A3CFE8AFD7EFBDE1F4C7
ECF8D2E2EECAE1F1CAE4F9CEE4FECFE9FFD6ECFFD9E1F5D0E0EFCEE2EDCDFBFFE3F5FFDB
E5F7C5DCF4B8D1EEABC2E096C9E399D1E99FCCE49AD8F2A8D0EAA0D5F1A698B469D8F7AB
C5E498C9E99DCFEFA3D1F1A5CDEDA1CAEA9ECCECA0D1F0A4C9E39AC9E39CC4DB97E2F8B8
80935CCBDDABDEEDC20008005D6647EFF8DB898F759B9F86ADAF97F3F6DBDADAC0B2BA95
C6DEA4CAE9A5CCEAAAC7E4A4CBE5A8DAF2B8E6F9C1E6F7C1DFEBB9F7FFD1E5EDC4E7ECCC
FFFFECFFFFF1F6F6EEE1E2D0DCDFB2E5E6ACEBE5A9675719836A28DBC88E3D421A000900
EBF8CDE3F1C0B9CA94D6F8C67FBC9DBBF8D6DCFFC5CFE6A0CBE69FCDEBA1CCE89BD0EB9E
CADF9AD2E3ACF7FFE0FCFFF1FEFFFBFEFFFDFCFDF7ECEFE4E6EADBF0F4E3FEFFF1FEFFF3
FFFFF4FEFFF3FEFFF3E9EDDEDADECDD7DECCD7DFCAFBFFEEF7FBEAF8FAECFEFEF4FFFFF8
FFFDFAFFFCFBFFFBFFF8EAEAA7928D725E55FFFBF3FFF6EEFFFEF6E9E6E1FFFFFBEFF4F0
FBFFFFFBFFFFFCFFFFFEFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFDF7FBF7E8EBC2AFB1
FFF8F8FFFDF8FFFFFAF0F5EEF8F7F3FFFCFAFFF2F1FCDFD9BAA48FBFB494BFC899F8FFE1
F9FFF8F9FFFFF3FCF9F9FFFBFBFFF6F0F9E8F8FFEAF2FCE3
C5D7C157725382AD7FBFF1BCBBEBB9BAE0AFCDE0B296A176929A73CFDFBAC8E8C180AB7E
618E57D0F8BCB8CF9999A871657133CEDB96505B17DDE8A3D1DE9899A962CDE297CCE79A
C1E195CFF1A4C8EA9ECEECA4CCE39FE7F6B5D9E1A54C5514D2E79CD1E99B859D514D641C
546B273E5511567029C5DF95CFEA9DCEE99ACDE99CCDE99ECCE7A4CCE6A9CBE4ADCCE3AF
D2E2B1D1E1B0D4E8B3C8E1AAC2DFA9C9E5B2D0EABBC6DBB2CCDCB8D6E4C1FBFFE3E6F3C8
CCDEAAC0D998DAF8B0C6E599D2ECA2D1E99FD2EAA0D1E99FB9D389D5EFA5CDE99EC5E196
D0ECA1CAE99DC7E69AC7E79BC8E89CC7E79BC6E69AC7E59BCCE7A4CEE6A8D5EDB1C5DCA4
B7CB9A57683C889873000E00687259A5AD964D5140F4F7E6F8FAECFCFDEFFFFFF3FEFFEB
CADAADCEE3AAD2E7ACD1E7A9CEE4A3CEE59FD1E6A1D2E7A2D7EAA8C6D89AD3E4AEECFCCF
F9FFE4EFFCE2F9FFF3D3DDC5D5DDB4DCE3ADDEDCA15A4F0D6D570EF7E8A7C4CCA3000E00
E4EBCAFFFFE1FCFFDDC7E5C367A797ADF3DBD1FAC2D1ECA5C5E29FCCEAA4CEE99CD6EEA2
CEE39ED7E5B2FAFFE8FEFFFAFFFEFFFEFDFFFEFEFCFEFFF7FAFCEEF7F9EBFAFCF1FFFFF8
FFFFFAFFFFFAF9F8F3FDFEF6FFFFF8F7FAEFFCFFF4FCFFF4FEFFF6FBFCF4FFFFFAFFFEFB
FAF4F4FEF5F8FFFBFFFFF9FC917E7A87736CFFFBF4FFFAF4FFFEF8FFFFFAF5F6F1FEFFFD
FCFFFFFBFFFFFCFFFFFCFFFFFEFFFFFFFFFDFFFFFDFFFEFFF4F2F5FFFDFFDFCFD2BBA9A9
FFFBF8FBF4ECFEFFF4FCFFF4FFFFF6FEF5EEFFF9F3BFA499A6917CDAD1B0E6EFC0EBFBD4
F3FDF2F6FFFEF9FFFBF9FFF6EDF6E3CFD9BED9E5C1D6E2BA
000D001F40139AC99F1C5127699C7189B28897AC8BDEE9C995A17BA8BE8FBFE9AAB1E5A5
6598604B7746B7D4A6DBEFBED2E4A8D9E8A5CDD997DDEAA5A4B16BC9D992BACF84D5EDA1
C7E396D4F4A8D6F6ABCCEAA2CBE29ECBD99B9FA76CD2DC9DD2E49AC8DF91CDE39AD3E9A1
CDE4A0D3EAA6CEE59F8CA35BC2DD90D7F2A3CEE99AC9E399D9F4ADBDD796CDE6ACCBE3A9
CEE2A5D0E4A5CDE6A5C9E6A4C6E6A5C6E6A7CAE7AFD0E8B6D8EBBEE8F7CEEBF8CDDEEEBD
D3E7ACC4DE97C1E092CEEE9BC9E598D2ECA2C5DF95CFE99FD0EAA0D3EDA38BA55BC4DE94
D3EDA3CBE79CD0ECA1C4E397CBEA9ECCEB9FC8E79BC4E29ACAE7A5C8E1A7D0E9B0D2E9B3
BCD2A3D8EAC0B2C29D0412004A573BADB79FFCFFF1FEFFF3F6FAECFCFEF1FFFFF6F9FCE9
ABB18BE2ECBAD9E6AEC9D79ADBECA8D0E49CC3DA8CD2E99BCEE69AD1EBA4D1EBAAD1EAB1
D6F1BEDEF8CBD8F1C9CDE3BDD6E6C1CFDAB0D9DCAD9E99626B5B1FE1D5A1D0D9BE2C3A2B
2C3021797A6AFEFFEFCFE9DC7ABBBF004642B2E0BCC7E8B1C0DDA3CFECAABFD98FD6EEA2
D0E5A2CBD9A8FCFFEFFEFFFFFFFDFFFFFCFFFFFEFFFFFFF8FFFFF3FFFFF4FFFFFAFFFFFD
FFFEFFFFFFFDFFFFFDFFFFFBFFFFFBFEFFFAFEFFFAFEFFFAFFFFFBF9FAF5FAF9F7FFFEFF
FFFBFDF3EAEFFFFBFFFFF3F5917F7BCAB7B0FFF6EFFFFCF6FFF8F2FFFFFAFCFBF7FEFFFD
FCFFFFFCFFFFF9FDFCFBFFFEFEFFFFFFFFFDFFFFFDFEFDFBFFFDFFFCF3F8D0C0C1FFF7F5
FFFBF2FFFFF1FCFFEFFBFFEFFBFFEEFFFFEFCFBDAFAE9787A08F75DED8B4D6E2B2EDFED2
F6FFEEFAFFF7F7FFEFF7FFE9FBFFE4D9E6BBC7D8A4D2E3AC
CFF0ABCAF0B558865F75A887B2E2BCB8E0BE697F6ACDDBC4C8D8B491AC77CAF8ADB3EC9F
72A97037663AA5C8A0C9E4B7BFD89EDAF0AFE0F3B1D3E29FD9E8A385954EF1FFB9C8DD92
D8F3A6BAD689BAD98DC7E399D0E7A3D5E5A6636F31D8E4A4D4E99ED5EC9EE1F7AFCDE29D
D0E6A5C9DF9EDBF2AEA9C0788CA75A89A455C3DE8FC0DB8ED2ECA3CCE7A4CAE2A4D6EEB0
CFE4A1CFE69ECCE89EC9E99EC5E99FC4E8A0C6E6A5C8E4A9F7FFD8F0FFD2D6E6B5CADBA4
D3E8A7D3EDA3CCEC97CDEF99C4E093CFEBA0CAE69BCFE99FC4DE94D1EBA1A2BC72DBF5AB
C3DD93C2DC92D1EBA1C6E297D3EFA4D3EFA4D6F2A7C7E59BC1DE9BC6E3A3CAE6A9D3ECB2
C7E0A9D3EAB6E7FACCBDCFA5BFCFAAE2F0CDFBFFEAFBFFECFBFFECFCFFEFFEFFF1FFFFEA
8A8C649CA06DA6AB71E0EAABD5E29DDEEFA8DDF2A7C9E197CCE89ECBE9A3CBEAA7CAEAAB
CCEEB1CFF3B5CDF1B3CAE9B0CBE5B5C6D9ACE0ECBEA6A877716736AEA57ECBD2C0C0CCC2
0F1106010200A8AC9DEEFFFFC6FFFF387D82A0D4BEE9FFE8EEFFDFF2FFD4CFEBA1D4EFA2
D1E6A3CCDCADFCFFF3F8F9FEFFFCFFFFFCFFFFFEFFFFFFF6FFFFF3FFFFF4FFFEFFFFFEFF
FFFDFFFFFDFFFFFEFFFFFEFFFFFFFFFFFFFDFEFFFDFEFFFDFFFFFDF7F7F5FFFEFFFEFAFB
F1EBEDFFFCFFE4D9DF6F6365CFC0BBFFF9F2FFFCF6F5EAE6FFFBF8FFFEFBFCFBF9FBFDFA
FEFFFFFBFFFEFAFEFDF9FEFAFCFEFBFCFEF9FDFEF9FEFDFBFFFEFFFDF4F5C1B2AFFFFBF3
FFFDEDFFFFEAF2FDDFDDECCDCBD6B8DBDBC1AE9F88DAC6AED4C5A6CFCCA3E8F4C2F7FFDA
F9FFE8EDF7DFFBFFE8D3DFBBBDCA9ED1DFAAE1F3B5D1E4A2
B4DE88C7F2AB38653CA6D4B8DCFFE7C7EBD16F877AD6E8DAF4FFEA95B37DB5E591C8FFAB
9FD49C25552DA4CEA8B9DEB2CEF1B7C6E4A4C1DB9AD8EDACD1E29E909F5ACEDE97D5E79D
C7DE90CEE99CA2BE7398B46A8AA45D92A7649AAA6BD5E5A4C7DD94D1E99DB7CE88CDE4A0
DDF3B3CDE3A3C3D998DCF3ADAEC67C728A3E93AB5DA0B86CC1D890C3DC98D4EAAABED494
CDE49CCBE699C9E898C8EB99C6ED9AC6ED9CC6E89EC5E4A0E1F9BDDFF2BACFE0A9C7D99D
CDE29DCBE697C2E48DC6E891CCED9CC1E094C3E296DAF6ABCAE49AC6E0969DB56BC7DF95
D1E99FDEF6ACC9E197E1F9AFB8D086D9F3A9CAE49ACFEBA0CDEBA1D0F0A5BEDE95C4E29A
CBE9A3BED996C7E1A0DCF4B6DCF1B8D6EBB3D7E9B9DFF0C3E7F6CDE5F4CDE1EFCBE2EDC2
BCBF888E90518B8D4CD8DF9CCED995C1D08DCFE3A4D2EAAECAE6ACC6E3ABC3E4ABC2E6A8
C0E59FB9E294B9E38FBEE594BFE197EBFFC8D6E9B1E9F2C3ACA882706B4EC8CABCE3E7D9
6867534242282E3718F0FFF1D5FFFF38797569A194DCFFF2E7FFE8EFFFDAC2E09AC7E398
CBE29CCCDEACFBFFF4FEFEFFFFFCFFFFFCFFFFFEFDFFFFF4FFFFF1FFFFF6FFFDFFFFFDFF
FFFDFFFFFDFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFAF6F5
FFFDFDD4CBCE9C91958C8080F5E6E1FFFBF4FFF2ECFFFDF8FFFDFAFFFEFBF8F7F5FEFFFD
FEFFFFFCFFFFFCFFFDFCFFFDFAFFFBFCFEF9FDFFFAFFFFFBFFFFFDFFFDFAB2A59DFFFDED
FFFFE5FFFFE3F8FFDFE7FCD1D9EAC0CFD5AFD1C8A7BFB08FCBBF99D6D5A7C5D49DF7FFD4
F5FFDBF9FFDFFBFFDDD2E0AFD5E4ADDBEBADCDE19CC5D991
CBFA9CB0DC8D3D6739000F009EC2A6BEDEC7A2B9AF465C5089A2859CBC8AB9E495C7F8A9
BBECB5A5D4AA1544184D7B4AC2EFB6B6E0A0CBEEAECAE4A3C4D79575844194A15BE1EEA6
E2F4A8859C4EC1DC8FC1DD92CBE79DCAE49DD3EAA6D6EDA7D9F0A8C6E096DCF3AFCFE5A4
D2E8AACAE0A2ECFFC2B9D08CD9F0A8C3DB8FCCE498C4DA8F778D44D2E7A2D7EBACD9EFAE
CCE69DC9E696C6E894C4EA93C6EE96C6F09AC8ED9DC9E99EC5DE9CD2E8A8D4E8A9D3E8A7
D5ECA4CEE99AC6E891CDF199CCEF9DC3E598C6E69AD3F2A6C9E59ACFE99F96AE647D934A
8AA05795AB62CBDF97D2E89FDFF5ACBDD58BD9F1A7C8E298CAE99BD0F1A0C1E291C3E493
D6F7A6CEED9DBEDD8FC2DE91C6E298C3DE97C9E2A0D4ECAED8EDB2CFE4ABCCE0ABD3E5AB
D1D895E1E49DDAE098A2A963B2BF7ADCECABD9EDB2C0D7A3CBE5B6C7E2B5CAE7B7D0F1BA
CEF1ADC5EA9CC5ED95CCF599C6ED94F1FFC1F5FFCAEDFEC7FFFFDCC7C6A867654ED9D7BE
E1DEBFA1A37C68734BBFD9B4D2FFE87EB7A675B2A3B4EADAD3F6DEF0FFE4CEECACD0EFA3
D2ECA5CEE0AEFBFFF4FBFEFFFEFDFFFFFDFFFFFFFAFFFFF1FFFFEFFFFFF6FFFDFFFFFCFF
FFFCFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFDFEFEFCFFFFFDFFFBF8FFFEFB
FFFDFB756B6AAEA2A2FFFBFAFFFCF6FFFCF6FFFCF8FFF6F1FBF3F1F9F5F2FFFFFDF5F5F3
FEFFFFFCFFFFFCFFFDFCFFFDFCFFFBFCFFFBFEFFFAFDFFF9F4F3EEFFFFF6A69A8CFFF7E1
DEDAB7D2D9ADD4E8B3C4DFA8D1E8B28B9767F1ECC2D9CDA3B9B183E3E6B1D1E5A8CDE5A9
CCDDA9E5F3C2B9C794DCEBB4DAEAAC94A4638DA15A91A55D
BCED91C5F2A18EB17BD0EBC8364E34000A001F372AE1FCEDEEFFEF9FBE94B7D99DC6EAAC
BAE1ACBDE9B67EB07B184F1679B174C1F8B7BDE9AACDF0B0E1F7B7BACB87B6C17CD4E098
D1DF948FA155DCF4A6CCE89BCAE99DC6E49AD6F4ACC2DD96C1DD93D7F3A9C5DE9CC9E2A1
D2EAAECBE3A7C9DFA1D1E7A6C1D691D6ECA3E3F9AECFE49942560ED6EAA5BACD8DD2E7A6
D0EAA3CBEA9EC7EA98C3EB93C2ED93C4EF95C8EE99CAED9BCAE69CCFE6A2CADF9ECADF9C
D4EBA3D1EDA0C9EB95C8EE97BDE292D0F7A8D1F6A8BDDD91B9D88CE4FEB4B5CD83687E35
4D6119596D2584954EC8DC94D5E9A1D2E69EDDF1A9C7DF93C5E494C6E995CDF19AC9ED96
C5E991CEF099D0F399CFF099CCED96CFEF9CD0EF9FCCEB9FC6E49AC6E49CCBE8A5D7EEA8
E5F1A9D6DE93D3DE928A984B829249C7DB96C4D99EEEFFD3F4FFE1F0FFE2F0FFE4F2FFE1
E9FFCDD6F3B1CCE89DC9EA93C4EA87BBE080D3F09CD0E7A1D9E6B1E3E4B8473E13AA9D71
E1DAAED6D8A9101D00C0DAADBDDEB3B8E6C134745AB7F4E2CEF5E3EEFFECCBEAAECAEA9F
D2EEA4D2E6B1F9FFF3FAFDFFFEFDFFFFFDFFFFFFF6FFFFEDFFFFEDFFFFF8FFFCFFFFFBFF
FFFDFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFAF9F5FFFEFAFFFAF7
AEA5A0A19692FFF6F0FFFCF6FFF5EFFFFCF6FFF5F1FFFDF8FFFDFBFFFEFBF9F8F6FFFFFF
FBFDFCFBFDFCF9FEFAFCFFFDFCFFFBFCFFFBFCFFFAFAFDF4FDFDF3FFFFF1AEA691FFFFE1
E0E1B5D2DFA9D2ECADC3E29FBDD7969EB074D0D09CD7D19DE2DFA8D3D99DCEE5A1CFEAA7
D8EAB0CDDAA4E0EFB6D6E5AAD3E3A57C8C4DD7EAAAC9DC9A
BFF198C1EC9CAFCD8F95A87BACB99F0006005A7161DBF6E5B8D6BE446142E0F9D2CEE8BB
C3E1ADC8F0B4C4F8BA76B473438545A9EAAAC1F5B5BBE3A4BBD596E0F0AF8C975379833C
465208A4B567C9E092D0ED9DC7E899C2E497D3F5A9C3E59BC2E096E7FFBBCAE5A2C1DB9C
D5EDB3C8E0A6C5DA9FDCF2B2D7ECA9D3E9A1CADE96D5E79DB3C47E8C9D59DFEDAFD5E7A9
D0E9A7CDEBA3CBEE9EC5ED97C0EB91BEEB90C3EB92C8EB97CAE69BD4EBA5D2E7A4CFE4A1
D2E9A3CAE69BC2E392C4EA97C2EC9AC5EE9FC5EC9DC2E497C2E195D8F2A8D0E89EB6CA82
D9EAA3C9DA93E4F5AE99AA638A9A5351621BCFE099DCF2A9D3F2A4BADD8DCAED9BCCF099
BCE088BEE288C3E78DC7EC8FC7EB91C9ED95C7EB94C2E591C3E696C7E99CC7E99DC4E298
CBDF98CEDE97DCECA194A758576E1ED7EFA3D3ECAAD8F1B8F5FFDFF5FFE6F5FFEAF7FFE8
F7FFE2E8F8CBD4E5AFC5DC98D9FCA2B9DE7FC8E893DFF9B0C6D89ED4D9A375642EA38D5B
E4D7ADE6E3C0000A00C1D5B2D9ECBEC3E7B961A2848ACDBBD0F8EDEDFFF3BDDEA5B8D88F
CDE99FD6EBB3F9FFF1FAFFFFFCFEFFFEFEFFFFFFF4FFFFECFFFFECFFFFF8FFFBFFFFFBFF
FFFDFFFFFFFDFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFBFFFEFAFFFFFAFFFCF6C0B7B0
544943FFF7EFFFFBF4FFF3ECFEF1EBFFFCF6FFF6F1F0E8E5FFFCFAFFFEFBE7E5E6FFFFFF
FEFFFFFEFFFFFCFFFDFCFFFDFCFFFBFCFFFAFCFFFAFCFFF8FFFFF3FFFEEA9D987BE9E5BF
D3D7A4D0E0A1CFEDA5C2E79ACAE89EBED38EDBDFA2B8B67BD5D597DEE7A4C2DC93D5F3A9
C7DA9ADCEAADC6D698B6C688859459CBDA9FCBDDA3E4F6BC
BDEE9FCCF5A9C9E098D4E1AB0004003A4032A2B5A1C8E4CDA2BFA9000E00000600D4E1C7
D2E9B5B6D995B7ECA4ACF0A7418C494B9353B5F1B1B4E2A2D0EDADDEF1AFCFD895D6DD97
DCE69DCEDC8FD3EA9AC4E191CEEFA0D2F7A99FC578D8FEB1CBEDA3B8D690DBF8B6577336
001300061D00C4D9A0C9DFA1CCE19ECDE19AC5D68FD0E298E7F6B14D5C19CEDA9CC8D89A
C4DC9EC6E5A1C9EEA1C6F09EC0EC93BDEA8FC1E990C8EC95CEEA9DD5ECA4D0E5A2CCE1A0
D0E7A3CCE7A0C9E99DCEF3A5CBF4A5BAE595B7E091CDF2A4D2F2A6C3DF94D0E89EE7FBB3
D0E19ACDDD96CDDD96D6E69FDDEAA4D4E49DDCECA57E944CD0EEA8B9DA93C6E89ECCEEA1
CFF2A2D4F7A5C7EB94CAF099C3E992C3E994C5EB98CAEF9FCEF3A5CDF2A5C6ECA3C4E5A0
CDE7A8C2D898DFF6AED0EB9AC2DE89D3F19BC9E696C6E19CC5DCA6C9DBB3D3E0C4E6EFDA
FDFFF0FFFFEFF8FAE4E1EBC6CCE6A9CEEEA5DBF9AFB2CB87DBEFB4E2E5AC674F13A78756
FFFBE3756C63000104D3DED6CBD1AFD0E6BF6DAC9173B7A8C1EAE4EDFFF8CEEFBAC4E59E
D1EFA5D1E9AFF4FFEBF6FBFEFCFEFFFEFFFFFFFFF1FFFFE8FFFFEAFFFFF8FFFCFFFFFBFF
FFFEFFFFFFFBFFFFFDFEFFFBFEFFFBFEFFFBFFFFFBFFFFFAFBFAF5FFFFF8FFF9F1ABA299
574A41FFFCF1F9E8DEFFFBF3FFFCF4FFFCF6FFF8F36B63609D9593F4F0EDFFFEFFEFEFEF
FEFFFFFEFFFFFCFFFDFBFFFCF2F9F2F2F9F1FAFFF9FCFFF6FFFFF1F6F6DEA9A484E2DFB4
D7DCA2D2E39DCCED9EC3EA97C8E998829A4EE2E9A5BEBF7D919451DBE79FD9F5A8B9D88C
D9ECAAD0DEA1E0F0B27A894ECAD9A2D0DEA9D0E0AFC7D7A8
C5F1A4C1E79AC8E094D8E8A9CFD9B4D8E6CD7B957AB4D6BDC4E7D3E9FFF9596C66475846
C7DFAFCCECA9C5F3A8BAF0A5BAF2B1467E4113490DC0F0B6C3E6ACC8E1A7D6E6A8D6E19F
D5E199D3E494D1E995C0E18AD0F39FC1E696D0F5A8C0E298CBEAA465823F000F0080985C
869D65A1B67E2D40082F4105CEE1A1D8E9A5D7EBA4CEE29AC6DA93D3E7A295A86696A969
B8CC8DC4D899CDE7A0D0ECA1CAE999C6E691C9E996CFEC9AD7EFA3BBD18995A86690A363
B2C583CBE09DCEE59FCBE79DBFE695CAF6A1C5EF9DC3E898CDEDA1CBE79CCCE69CC8DE96
D0E49DD8E9A3D7E6A1CCDB96D5E49FD4E39ED3E29D51651EC7E59FCCEDA6D2F3ACBDDF95
C5E79DD1F3A9BEE094CCEEA2CCF1A4C6EB9EC6EB9EC9EEA1C7E99DBEE396C2E69CCFF0AB
C7E1A2D2EAACC9E59B829F4DDCFDA4B8DB7FD7F9A2C5E695CAE7A5CEE5B1D3E3BEE0EDD1
FAFFEBFFFFF1F4F5E5D7DCC5D4E5BBC4DDA4C9E3A4D3EEABCDE6A4CCD795EADB9A735725
FFF0DBFFFAFB3A3343010009C3BAABF3FBE3DDFFFA609C90629491BBE7DABBE6BBC2EAAE
CCEFAFC7E2ADF3FFE9F8FFFDF9FFFFFBFFFFFBFFF4FCFFEDFCFFEDFEFFF4FFFEFFFFFDFF
FFFFFFFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFAFFFFFAFFFFF8F7F4EDFFFFF6D6CFC5
7E746AEBDDD2FFF3E9FFFBF1E1D0C8958880776C66B0A5A151423FFFFBFAFFF7F5FFFFFB
F8FDF7FBFFFAFBFFF8EDF8EADBEAD7DAE9D4EEF7E2FCFFEC9FA88BA4AA888F9068D6D8A7
D8E2A5D1E59DC7EA98C5ED97C2E593B5CD819299567B7B3D87874B8C95569FB874D2F0AA
C4D998B1C183B0BF84CBDAA3D9E7B6F5FFD7FBFFE3FBFFE4
C0E794CFF5A2C8E998CBEBA2D1F0B5BBDCAF46704C709E823464542C5C5048726887AD98
7DA076B4D398C1E09ACFE9A2D8E6ABC4D59F001400001700001300C3EDBFCDE9B8CDE0A8
D3E29DD6E997D0EF92C9EE8EC2EB8FC3E994CBE79DCEE7A590A86A223A005E7338D6E9B1
D2E1AAD1DEA6D5E2AA000D00A9B779CADA99D3E7A2CFE6A0C6E298CAE89EC9E9A0A9C37C
96A0617071356365265658174D500D7F853F707733545F1A8E9B5595A45FCCDB9AE3EFAF
CBD397868C50494D12DBE6A2CEEE9BC7EF96C6EC95C7EA96C8E99AC9E89CCDE99FCFE9A2
D0E7A3DBF0ADC4D795DDEDACCADB976C7B389AA966CCE099C1E092D7FAAAC4E69ACFF0A9
C1E09DCEECAECBE9AD27440A001900BFDBA0C2DEA1D1EEACC1DC97D5F1A7D0ECA1CDE89B
C4DB93DEF6ACCAE596B4D47FD4F79DC3EA8FCBF498C5ED95C6ED9CC7EBA3C8E6A8C6E1AC
D1E4B7E3F3CEF7FFE0FCFFE6FEFFE4F9FFDCF7FFD3D1ECA7C2E193D8F0A2D0DA9177723A
CAB99DFFF8F4876B79110009453039EFE6E7F4FFFFDEFFFF5E9F9B559E9372B298CFFFDF
AFD8ACCBEAC1EBFFE5F4FFF4F5FFFDF5FFFFF5FFFFE9F9EFF8FFF4F7FFEDFFFFF1FEFEF2
FFFFFBFFFFFDFFFBFAFDF9F8FFFDFAFDF9F6FDFAF5FFFFFAFFFFF8FEFFF8FEFFF5FAF8EC
F1EAE0867970E6D3CCFFF2EA8B75689B897BFFFDF1FFEEE6987474D0AEAFFBECE7FFFFF6
F7FFF4EBFDE7F8FFECF7FFE8BFE0B5BFDFAEF6FFD9E3ECBFC0CD9FD3E1B0D9E0ADD1D9A0
D3E2A1D3EAA2C7EC9EC4EB9ACEF0A3C4D9949DA06797915FB6AF83DDDEB6C9D8ADE3F9C8
E4F9BED3E7A8CDE0A8D4E4B3D3DFB7F9FFE5FBFFECFEFFF3
CFF19DC4E793C6E997C3E89BC1E9A3B6E2A75180549FD5B559907D30685B003326B6E3CE
769C776B8C57DEF7B5D1DE99DFDAA0F2F2BE000D000015000C3E1843754F8EB187C6E1AE
CFE4A1CFE696C7E88DC4E98AC6ED94CCEF9FD0E9A7CEE2A76B7E463A4D169BAC75D3E2AB
CFD9A4E0E9B2D3DCA32B3400D1DB9FD6E4A6D2E5A3D5EEAACBE9A1C3E599CFF5A8D1EFA5
D6DF9EBFBD809A9659A6A0629F995BC4C081BDBD7D9FA462E4EFABD1E09DCAD996D6E2A2
EBF4B5B0B177807E45DEE3A3CCE594C7EB93CBED97CDEF9BCEEFA0CEEDA1CEEAA0CEE8A1
D4EDA9B3CA86EAFFBCBCD08B8B9F5A7A8B47CCDD97D1E79ECBEA9CCCED9EBADA8FCDEDA4
C8E5A2C8E5A5B9D298395219001700DCF3BBE0F5BDC6DBA2D9EEB3C4DA9AD0E5A4D1E6A3
D3E7A2D4EAA2C4DC92BAD787D3F5A1C5EB94BAE28AC2ED94C2EC96C6EFA0C9EDA5CBEBAA
D5EEB5E4FAC9F3FFD8FBFFE3FFFFE8FFFFE4F8FFD6CEECA6C3E694CAEC96CBE294969E63
928563D2B7ACFFF4FB1900070F00057F727BC1C3C2ECFFFE9EDECE267764327B67D2FFFB
CAFFE9A9D9BFE6FFF6DAFCE4E6FFEEF1FFF8E3F5E7F7FFF8F5FFF0FCFFF3FFFFF1FFFFF4
F9FAF5FCFCFCFFFCFDFFFDFDFFFCFDFFFEFBFFFEFBF8F7F2F9FCF5F9FFF5FEFFF8FFFFF6
F6EFE7897C74A99690AA938BA78F83F7E4D5FFF2E5FFFAF1885E5FCDA5A5FFFBF3F4F6E8
EFFFE9F2FFECF7FFE6E8FFD3C9F0B7C9F0B1CCDEA2D9E4A8AEC285CCE0A1DCE8AAD3DF9F
D1E29ECEE89FC5EA9DC0E99BCEEDA7D0E4A5DADAA8E2D9B2FAEFD1F6F0D6DCE5CAF2FFDF
EDFFCBD5EEADCADFA6CFE1B1D2E0BCFCFFECFDFFF3FEFFF8
D2F1A1B8D787D0EF9FBDDF92D1F7AED1FBBC27552478AA85A7DDC5AAE1CEC4F7E44D7B61
426843325221B1C98BD2E19EE7E8ACC4CC93011C00587F5200130020502A042802CFECBC
D3EBAFCFE69EC8E595CAE999CDEDA2CDEAA8CCE3ADCCE0AD2C3E0AD4E5AFE5F3BECEDBA5
CDD6A1D3DAA4CDD59C5F672E9FA96DE0ECAED6E6A5C1D894D2EDA6CCECA3BEE298C3E199
D4E3A2DBE1A3CED295E1E3A4E5E5A7D6D899E7EDADCAD694C3D490D2E7A2D7ECA7D0E49F
C4D39097A06165662AD4DD9CCCE39BC7E79BCAE99DCAE99DC9E89CC9E59BC7E399C6E097
C2DC93E5FCB4CFE79D91A75ED2E89FCCE196BED388E6FEB4CDE8A1C6E49CC5E39BD4F2A8
D1EDA2D3EFA4DAF4AAB5CF86D0E7A3D5EAA9F6FFCEDAEBB560704198A77CD5E1BBE4F0C8
79875683945D475B1E93AC6ACEECA4C1E397D9FEB0C3EA99C0E798C5EA9DC8E9A4C6E4A4
CAE1A9D1E5B2D6E7BAD9E5BFD6DCC0D3DCBDD2E9B5BCDD98C5EC9BC9EF98DAF5A6D5E1A3
9C97717B6653BFA1A1F8DBE0C6B3B7060000171D13A3BDA4B7E9C39ADBB33F85694E9887
59A69E74BFBA93D7CC8FC8B5C6F2D1EEFFE4D9EBC1E2E9C7E8EAD5F6F6EEF5F3FEFCFBFF
FCFFFFFEFFFFFFFEFFFFFEFFFDF7F9FFFDFDFFFEFBFAF9F4FFFFFAFAFDF4FEFFF8FFFFF6
FFFBF3C4B9B3C2B0ACBAA69FFFF0E5FFFBEFFFFAEDE1CDC4775553FFE2DFFFFCF3FFFFF0
F0FFE6E1F6D5E1F6CFD7F1C1D0F3B9C3E3A4C9DB9DDFEEAD9CB36BC5DD93DDEDA4D4E49B
CEE29ACEE89EC6EAA0C1E9A0C3E1A1DCEFB8ECEAC1F2E4C7E8D9C2F5EEDBE2EAD5F7FFE6
F4FFD4D6F3B1C5DEA4C9DFAED0E2BAF9FFEAFBFFF1FCFFF6
BED98CDBF6A9CDEA9AD5F4A6ADCF83C5ECA990BB831D4E2174AA88C2F8DE001100406E52
B6DCB76D8D5E4C642ADEF1B1CCD898D8E6AB839E6B55794D9FC9A54B77542C542F001000
BBDAA1D8F2B3D9F2AEC9E29ED2EAACCAE3AC6C8355000D00839563D5E3AEC9D6A1CDD7A3
CBD29E535A26595E28686D35222A0097A165D6E4A6D8EBA9CEE7A3C9E79FCFEFA6CAE8A2
D8EDAAD1E1A0DEEAACCFD99AE1EBACC1CB8CE4F3B2D6EAA5CFE6A0D1ECA5D2EDA6DBF5AE
CFE39ECCDB986D7635D9E3A4D6EBAAD0EBA8CEE7A5CCE5A1CBE59ECCE69DCEE89FCFE99F
C7E295C3DE9188A354BBD385DEF6A8DFF7A9CDE597C3DD93D3EEA9CBE6A1D0EBA4CEEA9F
C5E091C6DF8ECFE895E0F7A7CBE198CBDE9CAAB980919D6FE1EBC6C8D1B6FCFFEDFEFFED
D9E0BFDCE7BDCCD9ABDDEFBBD0E8AEC4E1A1B9D894D3F4ADC8E9A2CCEDA6CDECA9CAE4A7
C8DFA9CBDDABCCDCAFCBD7B1C7CFB7D4E1C5D5EDBDBCDF9DC7F0A1BFE693CAE99BD8E8A7
DDDCB0E0D2B8614B404B3631EADDD5D4D2C5060F0000110020431BB9E7C0ACE4C910503F
2A736A004A42327C6F41856E87BF9CA4CFA4D9F8CECEE2BFD4E2CBE2EDE5F7FFFFF3FDFF
F7FFFFFBFFFFFEFFFFFFFEFFF8F2F6FCF6F8FFFEFDFFFFFBFFFFFBFAFDF6FBFEF7FFFFF8
FFFEF8FFFCF6FFF5F2FFF9F5FFFBF3F2E1D7FFFBF16E5A538E7570FFF9F3FEF2E6FCFEE9
EAF7DBCAE0BAC3DDB0D3F0BAC8E6AABED897E6F9B7BDCE8799B561C1DD88D8EE9BD1E493
CFE497D0ECA1C8EEA5C6EBA8C6E3ABF6FFD9F4EFCFEBDCC5C1B1A1FFFEEFF9FDEEF7FFEA
EBFFCDD3F2AEC4E2A4C7E2ADCEE3B8F7FFE8F9FFEFFBFFF3
DDF3ABCEE49BC1D98DD0EB9CD7F6A8C1E59B679151B6E5AFBDF0C75F9271487A5D8BB899
CFF5D094B3876A814BC9DDA0DAF0AFCFE7A9B8D39E6281578AAD8C2C543277A37F3D683D
688E5B4C6B3251662D6C7D465B6C382B3E112B441D5B714AD1E1B2E4F1BCD7E1ADCFD7A4
444B17E6EAB78D905B5E632B070C00353D02879256C7D798C4D998C4DD99DAF5B0C2E09A
C6E3A0BCD794D7EDADD1E6A5CEE1A1D4E7A7CEE4A3C6DF9BD3F1ABCCEEA4ADCF85BEDE93
CDE79EBED28B92A15CD0DF9ECEE0A6CCDFA7CBDFA4CBDFA0CBE1A0CCE39DCEE69CD0E89A
D3EE9D8EAA568EA958DFFCAAB7D482BDDA8ADEFBABC3DF94CFEBA1C5DF96CBE59BC9E497
D0E998D2EB98C3DA8AC8DD90DAEBA5DCEAADD8E5B08D956C91977BFEFFEFFFFFF6FEFEF4
FEFFEDFFFFEABBC0A2DDE7C2DDECC1CBDFACE0F8BEBBD598C7E4A4CCE9A9CFE9ACCDE4AC
CEE2AFD2E3B6D5E4B9D6E1BFDAE6D0F3FFE9EDFFDDC5E9ACCBF5ABBFE899C4E498CDE29F
DFE3B1F5ECCBFFF5E0685848ABA491E6E8D0616F4E000900000700687C7054715DDDFFE7
D8FFE7BDF3D1A8E4C25E9D7E28664D17523E9ED4C6C0F3E4AFDECEC9F4E1E6FFF8E9FFF7
EAFFFAEEFAFAF9FEFFFEFFFFFFFEFFFFFCFFFFFCFFFFFDFEFCFCFAFAFBF6FEFFFBFFFFFA
FFFDF8FFFDF8FFF9F8FFFBF8FFFAF4FFFBF4FFF9F4645049F4E3DBFFF8ECFFFFEFFFFFEA
E0EBCBCADFB4D3F1BDC7E6AACCE5A4CDE19CCCDD96869D4DAACC6DC5E786D4ED92CDE38E
CFE696D0ECA2C7ECA7C5E8AEC5E1B1EEFCD8FFFFE8F7E5D7DCCAC0FFFCF4FEFFF6E2F2D7
D9F7BBCAEEA6C7E7A6CAE7AFCCE3B5F5FFE6F8FFEDF9FFF1
CCDC9BE0F1ADCADE96D1E89AD4EF9ECCED9E8AB26BC1EFAFB0E2AF8DC097BCEECB7DAB87
83A982D0EFC5D2E8B7C4DCA2B9D797CDEDAED3EEBB001500577553B2D5B55B8964B8E7BD
C4F0BDB7DAA4AABE89ABB785BECA9CD5E4BBDDF6CFDEF7CFEDFDCED2DCA8EBF3C0949B68
535724E6EAB7DFE2AD7F824DECF1B9A8B0772731001F2D0096A969D8EDACD1EAA8C6E19E
CCECA9D1F1AED0EEAECBE5A4677F4190A968607A395A7734B6D792DFFFBBC4E89ECBEDA1
D3EFA48CA45ACEDF98DCEBA8D6E5AED7E5B2D7E6AFD5E7ABD3E6A6D0E69ECDE398CBE493
C2DE8A92AE5AC8E593C3E390D1F0A2C6E599C5E399D9F7ADC6E295C6E295D0EC9FCFEA9D
D3EEA1E2FAB0E4FAB2EAFDBBE7F6BBD8E5B0E7F2C7F1F9D4FEFFE8A1A48FCFD1C3FFFFF3
FFFFF3FFFDECFEFFEAE3E7CCD1DBB8E7F6CBE1F3C3ECFFCBD9F0B8DEF5BDE2F6C1DFF3C2
DFF0C4E3F2CBE7F3CFE5F0D2E2EDDCF7FFF3EEFFE3C2E2B0C8EFACC7EDA4CFEEA8D2E8A7
EDF4C1F4F0CAA2997C61573CC9C5A8CBD1ADEBFACFD8E9C79CA79F222B2A000700344229
536744D4EEC9BADDBCB2DEC3B4EADA76B4A952958E3A8076256A573E83644B8C62B0E6C2
EAFFFDF2FFFFF1FCFEF4F9FDFFFEFFFFFDFFFFFAFFFFFCFFF8F6F7FEFEFCFEFFFDFFFFFB
FCF8F5FFFDFAFFF5F5FFF9F7F5ECE7FFFCF6E4CCC858433EFFFFF3FAF9E7FFFFEAF8F8DC
F0F8D3C7DAACD1F2B9B9D998E0F0AFBCC9838C9E52A6BF6BC2E684CDF28BD0EB8ECBE38F
CEE69ACCE7A4C3E7AAC6E8B5CDE6BFD4DEC3FFFEEFF9E5DCFCE7E2FFF8F0FFFFF4C5D5B8
CBE9ADC6EAA2CBEBAACEEAB0CBE2B4F7FFE4F9FFECFBFFEF
CFDDA2D4E2A4D8E7A2CBDD91D1E995C9E6925F8436BEE9A2BAEAB07FB180B8E8C0BBE8C1
83A781C1DDB4CCE3B5CCE7B0C7EEAFC7EFB0BED8A8172D06526A4AD2F1D169977298CC9E
B6E6B4BADFABC6D8A4D1D9A8D8E0B1DDEABEDFFACDEBFFD7F2FFCFFFFFD3E3ECB7B2B985
636734C5C996D8DBA6B1B47FA8AD75EBF3BAA2AC705A65296F7F415B6E2E5A6F2E9CB774
5679375C813E4E6E2F547131001600526A2C526C2D35521091B26DC9EDA5C1E59BCAECA0
BEDA8FA3BB6FDBEDA3C7D691D1DEA6D0DDA8CEDBA3CCDC9DCEDF9BD1E59DD5EC9ED7F09D
AAC672829D4CD7F4A4C2E195CFEDA5C9E8A4CAE8A8BDDC96CBED99CFF099D2F29FCFEBA0
BFDA95C6DEA2E4F8C3EFFFD1F7FFDEF9FFE1F6FFDEF2FCD9FBFFE2F1F8D6BDC4A2CFD4B6
F7F4E1FFF9EBFFFFECFDFFE5FFFFE4FCFFE1FBFFDDEFFFD2F5FFD7F8FFDCF8FFDDF9FFE1
F9FFE6FBFFE8FBFFECFAFFF0F6FFF5F7FFF8F1FFEAC9E4BBCBECB5C7E7A8CCE9A9C8DC9F
EBF3C0BFBD94615B37918B69E7E7C1E3EAC0CBD7A7BBCBA4CEDCCDAEB9B3000100040000
120B00ABA693FBFDEFDEEEE1D1F2E7C2F6E95C9F8E408E785AAE8C51A87D257C47539A6E
BEEADBEDFFFFF2FFFFE8F3F5FEFFFFFFFEFFFCF7FDFFFDFFFFFDFFFFFFFFFEFFFFFCFCFA
FFFFFDFFFEFBFFFCFDFFFDFBFFFEF8FFFCF6DFC7C35D4A43FFFFF1FBFFEDF0F3D8F2F3D3
ECF3CACDDFABBCE0A0C0E19CDFEAA68B934A97AA5BD7F39CCBF090CBF090CBE790CDE496
D0E7A3C8E1A7C3E3B1D1F0C7ECFFE2E6EED9FFFCF3FCE5DFE9D2CCFFF5EAFFFFF1CFDEBD
C8E4A9C8E7A3CDEAAAD1E8B2CDE0B2F9FFE3FCFFEAFEFFED
D9E3AED9E4AAD2DE9CDEEEA3899F4A8EA851B2D480C0E99BC7F5B493C48D93C1938EB890
7DA078CCE8BF7E95698BA774719D5EB5E1A2D0EABA000A00627653C7E2C199C69D366A3A
BDEFBAC6EDB6D3E6AFD6DFAAD3DAA6D3E0ABD5F2BAE1FEC4E1F2BBF8FFCADCE5B0D5DCA6
484F1BF5FAC4E0E5AFDEE3AB9CA169B5BD84D2DCA0E0EBAFADBB7E7080426D8040748D4C
6B8E4C688C4C6D8D4E8EAA6D8BA367D0E5AAD2EAAE5872337A9956B4D590CFF1A7CEEEA3
8BA55BD4EA9FD0E095DFECA698A466939E648D9B5D909F5C9CAD66AFC477C5DA8BD3EA9A
97B05FA5C073C6E298CCE9A6CEEAADBEDBA1CEEBB5C8E7ABCCECA0C5E793C2E296D2F0AA
CBE7ACCCE4B2E6FBD0DDF2CBE5F6D4E4F5D3E4F4D0F0FFD8E7F6CBD6E6B5F7FFD0EFF8CB
9E9D81B3AE9AFFFFEAF8F8DCEEF2D1E9EFC9DEE9BFECF9CDE7F4C9EDFCD3F7FFDFF9FFE6
FAFFECFBFFF1FCFFF3F9FFF5FBFFFDF7FFF9F3FFF1DEF3D2E4FED1DAF5C0DFF6BED7E8B1
D4DCA9D6D7AB5E5B3255512BA5A67CCBD1A3E3EBBAD4E1B6E3F2DBF5FFF6FEFFFA413E39
0A0000352929ABA3A1FFFFFBF5FFFBEBFFFAC1F1D7B9F6D4CCFFEABEFFDDA8FDC61C673C
558877CDEFEEEEFFFFEFFEFFFBFFFFFFFEFFF6F1F8FFFCFFFFFDFFFFFEFFFCFCFEF8FAF9
FFFFFFF9F8F6FFFEFDF9F4F1F8F3EFFFFCF6E4CCC8716056F0FAE2EBFEE0E9F0CFD8DCB7
C3CB9CE9FCC4C0E5A0D5F7ADC7D18A6D7127DEF1A0C4E28CC6ED92C3E992C6E194CFE4A1
D3E6AEC8DEAFC8E4BCDFFADBF2FFECFEFFF3FFF4EBFDE4DFB59D93FFFCEDFFFFEBD3E1BD
CEE5ADCCE6A7D1E6ADD2E4B2D1DEB3FEFFE4FFFFEAFFFFED
D5DFADDAE4AFB8C28359671C9CB05BD5ED95C2E38CD1F8A7B9E79FBEEEB254804F3A6337
84A77DC5E1B890A77B4C6837214F1184B274C7E1B1001100697955C3DBB7BEE7BB4F814E
B8E9B1C7EFB1D0E6A8D5E1A3D5DE9FD4E3A2D4F2AACEEDA7D3E5A7D5E0A6E7F2BAE6EFB6
4B541DF8FFC7E6EEB5D2DA9FC0C88D919B5FE1EBAFBDC88CE1EFB1D6E6A7D3E6A6CFE5A5
CBEBAAC3E6A4CBE7AACFE7ABCCDFA7D1E3A9CFE1A7617538A2BA7CBED897CBE9A3C7E29B
AEC67C95AA5F97A55A94A056919E5894A15C96A65F97A75C95A75B99AE5FAEC374C1D88A
B2CA80C2DB97CCE4A6D4EDB4C3DDADD4EDC3D0E9C2C7E2B5CEEEAFCAEBA6C4E4A3C2DFA5
C6E2AFCCE7BACEE7BFC7E0B9C9DFB9D2E8C1C0D7ABD9EFBEC4DBA3C7DFA1DAF1ADCBDDA1
B1B38CA8A586A2A280E6E8C3E1E6BDE4EBBFC7D0A3D9E5B7D2DDB3E9F5CFFCFFE6FAFFEB
FBFFF2FCFFF8FEFFFBFAFCF9FCFFFFF7FDF9F9FFF6F7FFEDF4FFE1F7FFDDF3FFD5CFDDAA
DEE4B4D8DAAB9F9E726360357F7E52DADCADFFFFD1E0E9BCE9FAD6EEFFE9F3FFF9BCCACA
7A848E00000E4A4A56B2B0B3FFFBF2FFFFECDBE5C2D5EABFDCFFD2C0F1C2A2DFB3A3E0BE
4A7F6F9EC7C3EAFFFFEFFFFFF9FFFFF1F0F6FFFDFFFFFCFFFFFDFFFFFEFFFFFFFFFEFFFF
FEFFFFFFFFFFFFFFFDFFFEFBFFFEF8FFF8EFECD5CF5C4E41F0FFE2F2FFE4ECF8D0CAD3A6
D2DCA8D7EBAEC2E69EC8E89CE0EAA1878B41DAED9CC9E996C9EEA0CEF2AABFD799D6E7B3
EFFED3D8E9C7E1FADDEBFFEBF4FFF1FFFFF4FFF9F2FFF7EED7BDB0FFF7E3FFFFE4D2DEB6
D2E3AFD2E3ADD7E5B4E1ECC1F0F6D2FDFDE1FFFFECFFFFEF
7C885AE3EDB9707C3EE0EDA5CFE38ED4EC94CCEA92B8DE8BCBF6AEC4F2B2B6E2ADCBF2C5
C7E8BDCCE7BC566C3E000E009CCA8CD3FFC3C1DDAA0C1D002C3B12DEF3CAB0D4A4001300
517E43BAE2A3DFF8B7C8D995D0DD97DAEA9FCBE896C1DD90D0E5A2D7E7A9E6F4B7BECC8F
BBC68AF5FFC4D6E1A5CEDA9CD1DCA0ACB87A6F7D40DCEAACD4E4A5D5E8A8C4D797CFE5A4
C3E09EC7E5A5C8E0A2DDF1B6CEDDA6CEDBA5A6B37D4B5A21CDDFA5D6ECAED7EDACCFE6A0
C3D790BCCC83C0CC82BECA7ED6E497D2E395D1E495D1E493CEE192CBE091D1E79CDAF0A8
D8EEADD0E5AAE2F6C3CEE4B6EAFED9D7ECCDE5F9DED7EFCFCCE7BADAF8C6E0FCCBE1FDCD
D5F0C3C7E2B5CDE8BB91AC7F91AB7CCEE9B6C5E0A9D2EEB1C9E6A4C6E49ECCEAA0D0E7A3
E8F0BDECEFC4B2B88A979D6D868E5BCED6A3DAE4B0DCE6B4DBE7B9D3DEB6E2EBCCF7FFE8
FBFFF3F1F6EFF4F6F5FEFFFFFEFFFDFAFFF8FBFFF4F9FFEDF2FFDFE9F8CFE6F3C7E0ECBC
CED6A5E1E5B3F5F7C8EBEABCB5B486949665C4C695FFFFDAFCFFE3F3FFE8F4FFF7EDFFFC
F2FFFFC3D1DA272E36000002736A61FFFEEAD9D0B1DADBB3C7D4A9E6FFD3C3EABDB4E3BF
1A4F3D44756FDEFFFFEBFFFFF7FFFFF7F8FDFFFDFFFFFBFFFFFCFFFFFDFFFFFFFFFEFFFF
FEFFFFFEFFFFFEFFFDFFFFFBFFFBF3FFF2E97B675CB6AE99F6FFE5EBFFDBE9FDCCD8E6B1
D6E5AAD7ECABC6E89CC8E7994D570EC7CF84C7DD8BD2F1A3C0E3A3C4E2ACE1F2C5D1DDB7
FBFFE8EEFCE5F4FFF4E8FAEAF3FEF0FFFFF6FFEFE8F3D7CCD2B6A8FFFDE4FFFFE1CBD6AC
CAD6A8D5DEB1E0E7BEF2F6D3FFFFE6FFFFECD7CEBF9B9185
8C996EC9D7A6869459E6F5B0D4E796CAE28CCCEA94CDF2A2C5EFA7C6F2B3AAD59FBFE6B7
BEDFB26681540F250088A36CC4EEAFB4E0A1C9E6AE192D00000A00DAEDBFC5E3B1628751
0019004E7536C8E5A3D6EDA5D4E99EDDF3A1C2DC85D7F09DCEE49CC7DA9AC3D69693A666
DCEFAFD2E5A5D1E1A2DCECABD8E8A9DCECAB90A363CDE09ECDE09EC9DE9BD7ECA9D2E8A7
DBF6B3CCE6A5D0E4A5849358E1EAB3E1E8B4242B008E9762D6E3ADC5D79DCADC9EDDF0AE
E2F3AFD1E19ACDD98FD8E498D9EC9AD2E893D1E794D6EC9AD7EC9DD3E99ECFE49FCFE3A4
C3D69ED7E9B9E3F3CCF8FFE6F8FFECF8FFF1EFFCEBF7FFF4F4FFF1F2FFEFF0FFEAE4FCD8
DEF7CDD2ECBCBEDAA0001A005E7D3AC9E8A2C7E6A0C7E79ECCEBA5CCEBA5C6E59FCEE9A6
FBFFCFFEFFCFCED99FB6C1859FAA6ECCD79BD1DFA2D7E4ACD4E1ACD3DEB3D9E3C0ECF5DA
FCFFF3FCFFF8FEFFFDF9FBF8FBFFF7F8FFF0FAFFEEFBFFEAF1FCDAD7E3BBD9E6BAF6FFD1
EFF9C5D4DDA8D2D9A3ECF0BDDEE2AF9FA170646635514F28524B38DBD7CCFFFFF4F3F9EB
F9FFF6F8FFF6616B60080D06000100030000EEEADEFFFFECF5F9D8E5EEC1CAD9A2D3F0C0
457962144C43E2FFFFEAFFFFF5FFFFFCFFFFFFFBFFFFFBFFFFFBFFFFFDFFFFFEFFFEFFFF
FCFFFFFCFFFDFCFFFDFFFFFAFFFDF3F1E1D2574835FFFEE3E9FBD3CAE6B5C7E0A7CAE0A2
CFE4A3BED58FDAF6AB90AB5E536018CCDA8FD2E99BBEDC96C7E3B2D5EDC9EBF5DAFEFFED
F1F5E4FBFFF6F7FFF8F7FFFAFAFFF8FFFBF3DEC7C19A7C728A6E60E1CFB7FFFFDFDAE2BB
E3E9C5FFFFE3FFFFE4C7C5AC9D9683B9B0A1F4E7DEFFFCF4
AEBE97ADBE91D6E5ACC7D894D5EA9BD5EE9AC2E28FC7EC9EC9F1ABAED899D1FCC6C4EAB9
7A9A69799363A2B68194AD73CDF4B3BDE4A1D6F4B6E3F8BF9EAF7964754189A06C89A46F
00100062864985A56681A05CA5BF75BED585CDE390D6EC9AAAC077A9C07AB3CA84C5DC96
CDE49EC7DE98CFE49FCCE19CC7DC97D1E6A1D1E8A2879E5893AA66869D578CA35F859C58
7E9753879D5C90A363BEC98DBDC48E393D0ACBCF9DD0D7A4D6E0ACDCEBB4DAECB0C1D494
C6D695E3F2ADE3EFA7D5E396CAE28CC6E087C7E08CCDE695D0E89ECDE4A0CADEA1CADDA6
D9EABDF3FFDBE5F3D2FBFFECEFF8E3FBFFF3F0F8E9FBFFF6F4FFF6F3FFF4E7F6E1F7FFEA
EDFFD9C4DBA7C9E1A30C270059752AC8E799C9EA9BC4E498C7E79ECFF0A9CAEBA6C6E3A1
E8FDBCDCEFADCCE09BDDEEAABDCE88A4B56F87985490A05F8D9C61B6C38ECED9AED9E3C0
E1E9D1EFF6E4FBFEF3EAF0E2E3EFD7E8F5D7E6F4D3E8F6D2E5F4CBCEDEB1CFE0ACF5FFCF
D9EBAFD8EAACD6E6A7D5E3A6DBE4ABD7DEA8C3C794B0AD84B1A58F6F5F50A49786DBD3BE
F8F3DDFFFFECFFFFF1BBC1B3828982000400353C34F0F7E7FDFFE5F5FAD1E3E8B2BFD3A2
A9DEC41B594CDDFFFFE6FFFFEDFFFFFCFFFFFDF8FEFFFCFFFFFCFFFFFDFFFFFEFFFEFFFD
FBFFFDF9FFFDF9FFFDFFFFF8EDE0D0B4A38FA1977CFAFEDBDAEDBFC6E3ABC3E0A0D2EFAC
D6F0A9D7EEA6B8D086879D52D4E59EC9DD95E8FFB8CBE5A6CDE6BFC8D7C2FEFFF3FFFFF4
FFFFF7EBEEE7EFF9F1F9FFFBADAEA9D9CECAECD0CDB5948FA5877CD1BFABCDCDB1A1A889
AEB098CDCCB7D9D6C3D1CBBBDDD5CAFFF9F0FFFBF8FFFBF8
BFD4ADCBE1B3D1E4ADD4E9A8CFE59AD7F2A1CFEEA0BFE497BEE5A2CEF7BB80A873426835
A7C795D3EEB7DAEFB47C9252BCDB95CFF1A7C0DE98C0D997C3D79A6C7B446F7B49667647
B6CC9D63814FADD098A2C88B83A360B0CA8396A65D8F9F56B1C97FBAD68CBCD88EEBFFBD
BBD78DCCE89ED2EEA4CBE79DD2EEA4C6E298DAF6ACBFDB91CFE9A2DCF6ADBDD790DDF7B0
D9F3ACCFE6A0C3D3949CA66ADEE3AD212300D3D5A4DFE3B1D4DEAACDDCA5DAEEB3D3E7A8
D0E5A4D6EAA5CCDC95D3E599D2EE99CEEF98CEEE9BD1EDA2CEE9A4CBE3A7CEE2AFD4E5BB
E6F4D0EEF9DBF9FFE9FCFFEBFEFFEFFFFFEFFCFFEEF0F2E4FDFFF5FEFFF6FEFFEFFAFFE6
D9E5BDCDDBA8CFE1A50C21006E863CCAE596D5F1A4D3F2A6C3E197CBEAA4D2F1ADC2E19D
C4DF9ACCE69DCCE69CD9F1A7CEE69AD3EA9CCCE395D2E79C99AD6695A56689985FAFBD8C
DCE7BFEDF7D5F3FCE1DBE6C8CDDFB5D3E9BACDE3B2CCE3AFD6EAB5CDE2A9C7DFA1D8F3B0
E0FBB4D2EEA4C5E197C7DE98CFE2A0D7E5A8D9E2ABD9DBA9E6DDB2EAD8B4FFFCDD765C43
785C47D5BEAEFFF5E8FFFFF3E9F5E9E5FAEB000A00001A01687D5ECBD9B5DEE3BAD9EDC8
C0FAE21D6152DBFFFFE0FFFFECFFFFFBFFFFF8F3F9FFFBFFFFFBFFFFFCFFFFFEFFFEFFFD
FBFFFDF8FFFBF8FFFBFFFFF4E4D3C1907C63EAE6C3DDE6B9D5E8B1CEE8A9C9EAA5D0F4AA
C2E296D9F3A957691FA8B972D0E79FC4DF98BFDA93CCE5ACF5FFECE2EDDFFFFFF8FFFDF7
FBF3F1E8E4E1D2D4D1CDD2CCF6F2EFFFFBFAFFF6F8EFCBCDDEBFBCFFF1E8FFFFEFF3F8E4
FBFDEFFFFFF4FFFFF4FFFFF6FFFCF9FFFCFBFFFCFBFEF2F4
EBFFDCE2F9CDC8DFA9CEE4A4C9E098CAE598CCEB9FCDF1A9CEF5B6AED79D1B430F0A3000
BDDBA7C1DDA3D2E6A7BFD48FDDF8ABBDDC8CCFEEA0D0ECA1E4FBB7B3C2874D54217E8458
EBF7CF4F683E96BC8DC5F0BBB6DCA3C0DCA18E995D929D5BD0E89ED8F9AAC4E498CCED9E
BEDE92CAEB9CC8E89CD0F0A4CCECA0C7E79BC3E397CFEDA3D0EEA4C7E399BBD78DC6E298
BBD58CDDF4ACCEDE9D939D60E1E4AD414311CCCE9DD2D8A8DBE5B1C6D7A1D5EAB1CCE4A6
CCE2A1D3E8A5C6DA93D9EFA4C9EB97C6EC97C9EC9CC9E8A2C6E2A5C7DFABD2E7BEE1F0CF
F4FFE5FBFFECFEFFEFFFFFEFF6F8E3FDFCE7F7F5DEF8F6DFF8F5E2FFFFEAF2F0D7ECEDCD
D3D8B0E3EBBCC6D09B2937008B9B5AC9DE99C9E098D5EFA6C5E197C5E399CFEDA5C9E79F
CFEFA6D2F2A7CEEDA1CAE99BC4E18FCAE692CDE692D1E896D5EC9CBBD08585965295A567
C7D49FE6F2C4F2FDD3C9D9AAC8E4A9CBE9A9C5E3A3C3E0A0CEE8A7CEEBA8C7E79EC2E497
AFD582C0E892D2F8A3D6F7A6D0ECA2CDE29FD3E3A5DDE5AAD9DB9CE5DFA3FFFFCFC7B48C
93795EA58A77DAC6BBFFFBF1FFFFF6F8FFF683968300090067795FD3E2C5CDD8B8C2DCBF
A3E1CA28715EC8FFF4DCFFFCF0FFFFFBFFFFF7F2F6FFFBFFFFFBFFFFFCFDFFFFFDFEFFFB
F9FFFBF8FFFAF7FFFAFFFFF3ECD7C2917C5DD5D6ACCFDDAAD5E4ABCAE3A1C4E89EBDE697
D0F5A5B8D386909D55D4E19BD3EEA7CDEEA7CBE8A5D1E8B4F4FFEBFCFFFAFFFEFAFFF6F4
B5A9A9D0C7C8CFCFCDF8F8F6FFFEFBFFF4F5FFF4FBFED9E1EBCBD0FFF9F8FFFFF8FBFFF7
FFFFFAF8F9F4F2F1EDF8F4F3FFFDFFFFFDFFFFFCFFFFF6FB
F1FFE4DAF5C8E1F9C5C9E1A3D9F3ACCCE89EB9D990C7EBA5C1E7AAC9F0B98AB27E8CB27F
D2F0BAC7E3A6D1E6A3C1D68BA9C06ED4F099BEDF88CAEA97CDE59BC7D597B7B6866F6D46
444A28C3D6B621472226552BBBE5B7BDD9A9E0E8B9DBE2ACC6E097CCEF9DCDF0A0C6E997
D3F8A8CCF29FBCE191C2E797BDE090C9EC9CCDF0A0CBEB9FCFEFA3C1E094DDFCB0CAE99D
D2EEA3D6EEA48E9F5BB1BD7FD3D8A07274424E52200911002735023E511A445C220E2800
395312B9D28EDAF1ABCBE79DC5E898C2E998C4E8A0C7EAA8CBE8B2D2ECBFE4F8D5F6FFEA
F5FEE9D2D6C5A8AB98D9D8C4929079BAB69BB8B395D5CFADC5BD98A79F78B9B18CE3DEB8
ADA9847D7B553E4019353A11AEB788C2CF9A8F9E63A8BD7CCDE49CCDE89BC7E291CFEE9E
C1E397BCE096C5E79AD0F3A3D3F5A1CAEB94CDE992D7F198C6DE88E3F9A6C9DC8DB1C27B
95A56492A264CBD8A0D3E7AACCEEA2C2EC9AC7EC9EC9EEA1C8EA9DCBEE9EC9F09DBEE990
CAF99BCBFA9AC4F194BAE58BC0E391CEEA9FD0E5A2C7DB94D4E795E1F5A0C3D088E6EEB3
EAEBBF9891748E7E6EA8948DFFEFECFFEFEEFAEBE68F8880282A1D2A362272856FB7DFC5
A1E7CF46937F8AC7B8B4DFD5F0FFFFF9FFFFFFFAFEFFFAFEFFFBFFFFFCFDFFFFFDFEFFFB
F9FFFBF7FFFAF5FFFAFFFFF1E6CEB6927B59999F6FCADBA4D5E3A6D6EBA6C9F0A1C8F5A0
C9F09D7D9A4AE2ECA5CAD591D6F5AFBADF99D3F1B1BDD3A2F4FFEAE2E3DDC8BEBCC1B3B2
F4E6E5FFFBFAFFFFFBFFFFFBFFFCFDFFECF0FFEEF9FCD3E1D1AFBDFFF7FFFFFDFFFBFFFF
FCFFFFFEFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F4FFD9F5FFD6CEE3AACADE9FCBE09DD0E7A3CFE8A7D6F2B5D8F5BFE2FFCED6F4C2DCF8C5
C4DDA4D2E8AAD1E29EB8CA80D4EC98D4F099CDEE97C8E998CAE49BDCECADD9DDAA35360C
565C38DBECCA5074500025006F9D76B8DEB7CEE4C0CBDEB0D2F2A9BCE28DC8EF9CC2E998
BEE596CBF0A2D7F7ABE6FFB9D4F3A5C6E597C1E492CEF3A3B9DE90CAEC9FC9E99ECAE69C
D5EFA5BED48B536420D7E3A3D8E2A6E2EAB1757E476B7540A0AF7887995F8A9F64758E4D
96B16ED4EFAACDE8A1CCECA1C8EEA1C3ECA0C6E9A7CBEAB1D1EBBCDCF1CAEDFCDDF9FFEA
EEF8DF949D828B9273D9DFBDE1E7C1EDF3C7E5E8BBCFD1A08487508B8E55B1B47FD3D7A5
C1C497D3D8AF767D546A7148CAD3A8B7C3934C5B24718142D1E59EDBF2A4C0D785D4F09C
CBEDA0CEF2A8CFF1A5C4E596C5E592CBE894D0EC97CBE58ECDE790D5EE9AC6DF8CD4EB9D
ABC178768A43AABD7BD9EEA9CBEC9DBCE28DC7EA98D0F1A2C3E495C1E492C8F09AC2ED93
C8F799BAE98BBAE78ACAF59CD1F7A4C9E89CCAE39FD4EEA4CBED8FBEE081D9FAA3C2DC93
C5D79DDBE2B8CFC8AC8C7668BD9E99FFF5F4FFF6F4FFF9F6857E760B1306000A00507A62
BDF9DF64A58D44836E71A696E3FFFEEDFFFFEEFFFFF1FFFFFBFFFFFFFFFDFFFFFBFFFFFA
FCFFFAF7FFFAF1FFFAF9FFF1F7E6C8A7946A989F69CCDEA0D2E1A0D8EEA6BAE190C6F29D
C8EF9C86A257E4EDACD8E0A5C4D9A0D6EEBAD0E0B3D5DCBBDADCCFEAE7E2C9BFBDFFF4F2
FFFBF9FFFDFAF4F3EFFFFEFAFFFCFDFFF2F6FFF5FFFDDCE7B99BA7FFEFFAFFFDFFFCFFFF
F6F7FBFEFFFFFEFFFFFEFEFFFBFBFDFFFFFFFEFFFFFBFCFE
7581394D58135F6A254752106A74379CA76D717E49849060B2BF93FBFFDCF3FFD2E7F3C1
E0EBB3B5BF836A73327C8943CCE496D6F6A3BDDE8FCFEFA4D4F1AEC9DFA1B3C289303D08
909E6B798F60CCEBBF94BF940B3F19417A59A9E4C8BBF2C8C7F1A7C4EB92C7F39EBEEA9B
C3EBA2C8E7A3F9FFCAFAFFC4D6E39DD0E799C8EB97C2EE99C1EE9BC2ED9EC8E9A2CDE6A4
C9D9989DAC693E4D0ADAEBA7D7E7A6D9E9A8D5E3A5CAD89ADAE6A6D4E0A0D2E1A0D8E9A5
D2E7A2C8E299C3E197CEF0A4CEF6ADB4DB98C7E6ADD1E9B9DBEBC4F9FFE1FCFFE4FBFFE2
58673CCFE1B1CCE1A9C6DBA0DEF4B4C6DD99C7DE9AD1E8A2C7E399CBE99FD7F5ADBFDD97
C3DD9CDBF3B761763D051A00687B43C4D69CDAEAACB3C3824C5B16829249E8F6ABC3D88B
CDECA0C7E99DC7E69AD0EAA0BFD78BD7EDA2D6ED9FCEE698C8E595CDEC9CCAEB9CC5E697
CBEA9ECCE89DB3CA8290A65E72863F6D81394D631AD5EBA2C6E096DCF8ABC0E190C1E492
C4EA97C5EC99C8ED9DC9EB9EC8E89FC8E6A0CAE5A2C8E69CBADE84D9FFA1C1E88FC9EC9C
D8F3AED2E1AAD0D1A7D0C2A5684F3BFFF7ECFFEEE6FFF2E9FFFEF4A4AC9D233827000F00
BEDFC0CCF8D786C7A962A69178ABA45C949170C2B6CBFFFFE6FFFFE9F4F0FFFEF9FFFEF8
F7F7EFF8FFF8EAFFFBE4FFE7FFFFD9B9AF7C94985DDDE9A7C9DA93CEE99CCFF2A0C5EC99
CBEDA0839E5BDCE9B3D2D4ACFFFFE6FFFEEEF9E7E3E4D0D1E8DCDCF9F1EFFFFDFBFFFEFB
FBFAF6FAFBF6FFFFFBFFFFFBFFF9F7FFFBFBFDE9EBEDD9DBB5A2A4FFF6F8FFFAFAFFFFFD
FFFCFBFEFDFBFDFCFAF9FAF5FFFFFBF4F6F1FCFFFAFBFFFA
D8E192DDE89AC4CC83E9F2AFE0E8ACCAD39CCFD7A6CCD3A7838A60C2C99DDDE5B4E1E8B4
1018009CA468E1E7A7CAD792D7F2A5B4D586D7F7ACCAE9A3CFECAAD1EBACC6DBA064783D
CADDA598AD75C3DFAECFF6C96A9E7844856579C3AA9CE3BBBFF1AAC1EB95C6F3A2C8F4A7
CDF2ACB9D895D7EBACD9E7A9D6E2A2D3E49ECCE89DC8EB9BC3ED9BC3EC9DC5EB9ECAE8A0
CFE09C98A263657431C3D792CCE19CC8DD98C9DD98E9FAB6C6D18DE6F1ADD3DE9A465510
92A65FCFE9A0D4F4A8C3E89BBBE39CCEF5B4DEFBC3F7FFDCFCFFE1FEFFE3D3D9B550582F
D2E0ADD5EAAFCFEAA5D2F0A6C2E296C8E799E0FFB1BCDD8EC9EE9EBDE493C9F0A1C5EA9D
C7E8A1CBEAA66E8B4B587233D8F0B2D6EAADCADD9DD0E09FD0E19BCBDB94808D45566B20
4D6C20BBDD90C6E297D9F1A7DBEFA7D1E59DD3E79FD2EAA0CBEA9EC3E598C2E799C8ED9F
C8EA9DC1E094C4E095D0E69DD4E3A0DBE7A5828F4AD7E8A2D3E9A0C3DD93D1EDA0DBFAAC
C8E89CC7E99CC7E79EC7E79EC8E5A2C8E5A2CAE4A3C8E6A0CDF2A2B9E18BBFE494D6F6AD
B3CC8BD9E6B1F5F6CE9A8F718A7361FFF5E8FFF5EEFFFBF4FFFEF8CFD4CD627268000A00
000800C4DFBEB2E9CA69A79259838212484A25857A8DEBDDD4FFFDF4FFFFF7F3F0FFFDF8
FFFEF8FCFFFADDF7ECF0FFF3FFFFDDA3A16E969B61DFEBABD8EDA8DAF6ABBEE191BCE193
CBEDA3C7E1A2B5C594CCD2B0FFFEEDEFDBDA8E737CECD0DEFFEFF5FFFBFCFFFEFBFFFFFB
FCFEF9FBFFFAFEFFFBFFFFFBFFFDFBFFF9F9FFFBFBFFF7F6E9DBDBFFF9F7FFFEFBFFFEFD
FFFAFEFFFDFFFFFEFFFAFAF8FEFFFAFAFFF6F9FFF4ECF7E6
CFDD92CEDE93DEEBA5CBDA97D6E4A7CCDBA2E1EFBACCDAA7CFDDACB8C69393A16C919E68
E0EEB3D7E5A7CDD999DDEEA8BDD78DD2F1A5D5F3ABB9D693BCD695D3EBAD6F834898AA70
D1E3A9A1B47DD1E9B5D1F5C7DAFFE299D5B30F54384C906BB3EBACBDEDA3BEE89EC8EEA3
D5F9AFBBDF95C3E7A1C5E5A2CCE6A9D0E4A9D4E2A7D4E3A2D0E69DC9EB97C1F092C2EF94
D9EFA6D2DE9CC1D28E8B9F5A849B5596AD678196517F934E7D8A45495611AFBC77D0DF9A
93A961C1DD93C6E69BC3E89BC2EAA1C7ECA7DEFABFEEFFCFFCFFDDF7FDD79A9E79C6CFA4
D6E4AFCADEA1C7E29DCDEBA1C9E89CC8E799CEEA9FC5E194D2EEA1C7E396CFEBA0CFEAA3
D0EBA8BFD8975E7638637B3FC3D89DD0E6A8DEF2B3D0E5A4BED38EDBF1A8D6EBA0CCE498
D1F0A47D9D516A863BC6DE94D3E79FCCE098D0E49CC5DD93C7E69AC9EB9EC3E89ABEE395
C7E99CD6F5A9D7F1A7CFE59CC9D895EFFBB9A3B06BC0D18BCEE49BD1EBA1C4E093C0DF91
CCECA0C9E99DC5E59CC6E69DC9E6A3CBE8A5CCE6A5C8E5A3CDECA9CDEBABD5EEB4C8DAA6
D8E3B89C9D7D7C745D574738D2BEB7FFF7F6FFF8FDFFF9FEFFFCFFF7F8FCBAC2C5242F29
5A664E5D7054D2F5DFD5F6EDF3FBFFF1FFFF73B3B3CBFFFFDAFFFFEBF9FAF9F7F8FFFCFB
FFFCFAEAE2E0FFFFFFCDD3C7C5C8A99BA1758D9765C7D8A1BCD498BDDA98DAFBB4CAEEA6
CEEFAAC1DE9ED5E9B6CAD5AD8E8E76E2DACFFFFAFAFFF9FCFFFBFDFFFCFDFFFEFDFDFDFB
FBFFFCFCFFFDFEFFFDFEFDFBFFFAFBFFF7F9FFFAFDFFF7F7EADBDEFFF9F8FFFDFDFFFAFE
FEF7FFFFFAFFFFFCFFFBFAFFFCFFFDF8FFF3F9FFEFD7E5CB
E2F6AFC4D891CEE29DD8EBA9C5D99ADFF3B6C7DBA0DAEDB5D8EBB3C8DBA3CCE0A5D4E8AB
DCEEB0BED191C5D896DBF2ACD8F2A9CBE99FC8E6A0DBF6B3CAE4A5C5DDA1617339D6E5AC
DEEBB37A8952C4D8A3C3E0B0C8F1C7DFFFEF7DBA9B36775599DCA9B9F5B9BCE6A7BDDE99
D2EEA3CDEC9ECCF3A4C6EEA5C5E9A9C9E6ACD1E2ACD4E2A7D3E49ECDE995C5EF8BC5EF8D
CDE496CEDF9BE0F4AFBBD08BC8E29BD4EEA7C4DB95DFF4AFCDDC97DCEBA6E0EDA873843E
B0C77FD0EEA4C4E69AC9EFA2C3E99EC8ECA4CDE7A8C7DAA3D4DDB0E2E9C08E936AEBF3C4
D7E6AFD3E7A8CCE7A0C4E397CDECA0CDE99EC5DF95DCF4AAD2E89FD4E8A0D0E49DC3D792
D5EAA9D4E8AB687C415A6F34CDE2A7CCE1A6B7CD8FDAF3B1D3EDA6C0DA91DAF4AAC4E095
C7E79BCDEDA1BCD88D6A82386C8038D1E59DCCE299E3FBB1D6F5A9C6E89BC2E497CDEFA2
D1F1A5C8E79BC8E096CEE29AD0DF9CCBD795D2E19C5B6C26ACC279CBE59BE0FBAEC6E295
CCEB9FC7E79BC5E59CCAEAA1D5F2AFDDFAB7E2FCBBE1FBBCE2FBC4CDE3B2F1FFD4808660
9894777F7460C9B9ACFFF0E9FFF6F4FFFAFDFFFBFFFAF3FAFFFDFFFFFEFFF5F5FD6E7271
080D00333F27BFD6C4E5F4F1FCF1FFFEFCFF7AA5AE93C8CCE7FFFFF5FFFFFFFEFFFBF0F4
F9EAEDFFFAFFF6EBF1E4E1DCD8DEC486926C99A87FD6E9BCD4ECBACEEBB3C4E3A7DDFDBC
C3E1A1D5F1B6D3EAB6CAD9B0FEFFE8FFFFEFFFFEF8FCF4F2FFFDFDFFFEFDFBFBF9F9FBF8
FAFFFCFBFFFDFCFFFDFEFEFCFFF7F8FFFBFDFBECF1F0DFE5BBACB1FFFBFFFFFBFDFFFBFF
FDF6FFFFFBFFFFFDFFFBFCFEFCFFF8E6F2DCE5F4D3CBDDB5
C4DD9CD0E9A8D3ECABCDE6A5CCE5A4D2EBAACFE7A9B7CF91CCE4A6E0F9B8C4DD9CCDE6A5
C3DC9AE1FAB8C7E09ECAE5A0C6E099CAE59EC8E3A0C0DA99DEF6BA6A7F443F4E15D1DEA6
D5E0A6B8C389B6C790D2EAB6D2F3C6E4FFEABAF0CE17583866B796ACF8D1C6F6C6C5E1A6
CEDB95D6E594D1ED98C0E794BEEEA4BCEDABC2EAAEC8E7ABCFE6A2D1E697D1E98BD3E88B
CCDE92D6EAA3D5EBA3CCE69DD1EDA3D6F2A8C5DF96D5ECA4D1E29EC5D692C9D8958FA35E
CDE49EC5E39BCEF2A8C2E89BC5EC9DD2F4A8C0DB98ECFFC5ACB6849DA375BBC193C1C998
D5E4ABC1D695CDE7A0D4F0A5D1EDA2D7F1A7CFE69EC3D790CEDB96DCE7A3DEEAA8CEDA9A
DEECAFDAE9AE5B6D33374A129FB47BDFF4B9BED698C2DC9BE0FEB8C2E098C5E59ACBEB9F
C3E598CDEDA1DAF6ABA5BD738AA057B2C67E99AF66C6E096B6D589CEF0A3D9FBAEC9EB9E
BEDD91C7E398D4EAA1D4E8A0E2F1AED3E29FD6E5A061752E6F853CB6D086D8F3A6CDE99C
C7E69AC5E498C7E59DD1EFA7E0FDBAEDFFC7F4FFCDF4FFD1F7FFD8F2FFD6FBFFDA3D381A
605039C6B0A2FFF2E7FFFBF4FFFDF8FFFFFAFEFFFDF4F8F7FCFFFFFFFFFFFFFDFFBAB6B3
030400212914C2D0C3F9FFFFFCEBFEFFFAFF91B5C143747BB1CFD7E8F6FFFFFEFFFFFBFF
FFF4FAFFFBFFFFFCFFCDCEC9C8D4BE93A688809373CCE2BECBE4BDC5DEB4E2FECDF1FFD8
F2FFD4D2EBB4C2D9A5C6D9ACF8FFE6E7F3DBFCFFF6FEFFFAFDFCFAFCFAFBFBFDFCFAFFFE
F8FFFEF8FFFEFCFFFFFFFFFFFFFCFFFFFBFFFFEEF6F5E4ECC0B1B8FFFBFFFFFDFFFFFDFF
FFFEFFFDFBFEFEFFFAFCFFF3FBFFEAD0E1B7D4E8B3CBE3A7
C4E0A6CCE8ADD2ECAFCAE4A5B9D394DDF7B6C2DD9AEAFFC2D5EEAAB9D48FD1ECA7CBE6A1
D6F1AEC6E19ED8F5B2C4DF9CD2EBA7D7F0ACCEE7A69BB375384D122F420AA0AF76D9E4AA
C8D095DEE8AC93A16692A56EC8E4B3C4E9BDBDEAC3A5E2C340958089DDC6BAF0CED3F3C1
D0DF9CD7E293D5E992C5E88EBCF09DB7F1A5B7F0ABBCEDABC8E9A4D3E59BDDE290DDE28E
CCDA8FE0F6AECAE49BC6E298BEDC92D7F5ABCDE99FC2D991CBDF9AEEFFBBD5E6A2B2C782
D4EEA7CDEDA4BEE499CFF5A8C8EE9BD0F1A0C4DE97D4E7A79AA46FA2A976D6DDAAECF5C0
D1E1A3D3E8A5C7E198C5E196CBE59BC8DF97D0E5A0E4F5B1DFEAA8CFD897BBC48598A265
8D985E818E561C2B000F20002A3D0698AD74E5FDC1C5DF9EC4E19ECCEAA4C7E79ECAEA9F
D9FBAEC5E599BAD68BD8F0A6C6DC93D0E69DBBD188708A409BBA6EAED083C0E295C4E699
CBEA9ED7EFA5D7EBA3CFE099CADB97D8E9A5CCDD97B2C67F8CA25999B167C9E497C6E295
CCE89DC9E89CC9E79FCEECA4D6F3B0DDFAB7E2FCBBE3FBBDD8ECB7F7FFD5FFFFDC897C5C
897157FFEAD5FFFAEAFEF1E0FFFEECF8FFF0E4F5E2DCEFDCEAF7E6EEF2E4FFFFF4FBF3E8
0A07002B2F1E29392EB4C0C0FFFBFFD5DAED75A0A995CAD0E3FFFFE9FDFFFEFEFFFFFBFF
F7F6FCEFF4F7F2FCFD96A69C2C422B0720020F260A8EA589B8CCB0DBF0CFE3F7D2F5FFDF
CBDEB0D3E7B6D8EBBDD2E4BAEDFEDEECFBE4F7FFF6F8FFFBFCFEFBFEFEFEFCFFFFF9FFFF
F8FFFFF5FEFBF9FDFCFFFEFFFFFCFFFFF7FEFFF9FFFFF8FFF0E0EAFFFBFFFFFCFFFDF8FC
FFFFFDFBFCF4FDFFF0FCFFE8F9FFDFC8DAA6CDE6A4D0ECA2
CAE5B2D9F4BFBDD69FC3DCA2041C00011A00000F00C4DE97C9E098D1EBA2D8F2ABD5EFA8
BFDA95CBE6A3CFECA9CDE8A5DAF1ADB8CF8B031900001100233800BCCF97E7F6BDC4CF95
E2EAAEDFE5A9CDD79BC4D199C8DFA9C5E2B2BBE0B4BBEDD057A09959A8A274B29BBDECC0
CFECACD5E899D8E792D6EF94C3EE95B8F29DB0F5A2B3F3A5BFEDA4D0E5A0E4DD99E6DC97
E6F2AAC4DC92BEDA90D7F7ACCEEEA3C7E79CC5E399DCF6ADDAEFAAC9DD98C8DC97738843
E5FFB8C4E49BC1E79EC6EC9FBEE48FD3F59FCEE89E82965197A268EEF5BFCFD8A1C8D399
CEDE9FE2F7B2D0EAA0D4F0A3B9D389677E36465A154859157E8A488A9553BBC586D8E4A6
E6F1B7E0EDB57785505A6B35D5E6B2A7BA83BED297C7DD9FD1EAA9D1EAA6D5F0A9C6E49A
A9C97DE2FFB5C0DC91D5EDA3DCF2A9C8DE95C5DB92CAE49AC3E3978BAD6087A95CC5E599
E3FFB4C7DD94BFD089DBEBA4D9EAA6CDE19CE1F5AEB6CC84DEF6AC8BA359D3EEA1CDE99C
CEEA9FCDE99ECCE7A0CCE7A0CBE6A3CAE5A2C9E3A2CAE3A2DAF0B0CCDA9FFFFFD1E4D6A9
6F562E836644FFFDDAFFFFDDF8FFDCE7FFD6C7EBBDC4E8BAC6DFB5DDECC5FEFEDCFFFFE4
0401000E1406778F82DDFAF5DDF2F79ABBC439797BCAFFFFD6FFFFDDFBFFFCFEFFFDFBFF
EEFDFFEAFFFF000E02204B373152331E3918132C0F0B1F063E503AF8FFEFF9FFECF4FFDF
F2FED8D2DEB6CBDAB1DFEFCAF4FFE9F5FFF3F0FFF7EBFAF5FBFFFFFEFFFFFBFFFFF9FFFF
F8FFFFF5FEFBFAFCFBFFFEFFFFFAFFFFF4FBFFF9FFFFF3FBECDDE4FFFBFFFFFBFFFAF6F7
FFFFF8FDFFF1FDFFEBFBFFE3F8FFDACDE3A5CFEBA1CBEA9A
D3EBBBA1B9872D44100015005A6F34596E2D738845667C34687C35647A3161772F95AC64
A3BD7691AA66607B38637C3A596E2B768B4A2339005E7436A2B77ED1E5AAD5E4ABDAE5A9
D1D799FFFFCACBD193BECA8CDAECB2C5DEA7CEEBBBBDE6C492CBC440817D296A5494CEA6
BEEEB4C4E9A4C7E197D2EA9CC8EB99BFEE9DB5F3A0B5F2A2BFEDA2CDE7A0E1DD9EE4DC9D
DBE8A2C2DC92D7F5ABC7E99DBDDF93CCEEA2CAEA9FC9E59BCADF9AC3D792EAFEB996AB66
B2CD86D6F6ADCBF1A8C2E89BCCF29BC8E992C9E193A0B46D9AA668C5CF93DDE7ABDDE9AB
D6E7A38CA25A748F42A6C2758EA85E8DA35BD7EBA6CEDE9DD9EAA6CCDD99D9E9AAD0E0A2
C9D89DCDDCA566743F35461298A673AABB8596A770AABC80D8EAACC0D391DAEFACCDE49C
D6F4AAC8E79BC7E398D9F1A7C8DE95D6ECA3D1E99FCCE69CD2F2A6C6E89BA6C87B8CAB5F
A1BB71D0E49CE0F0A9D2DF99D1E29ED9EEA9C4DA92D7EDA5D2EAA0C9E1978FAA5DADC87B
C8E298CAE69BCCE7A0CDE8A1CCE7A4CCE7A4CDE7A6CEE9A6CBE59ED3E4A0F1F1B5FEF1BC
FCE4B47A6234EDDCAEFAFAC8EAFFC7D3F9BCBDEBABC6F4B3BADEA0DDF2B9F3F7C4F1EFC6
FFFFEC95A0922642349EC3BBC0E4E274A4A459A4A0C7FFFFD1FFFFE3FFFFECF3FFFAFEFF
E9FFFF9ECEC00847325A9577B9E2BACDE7C04B6343F3FFEDB1BCAC62685ACBCEBDFFFFED
F1F4D7E8EECCEDF4D3DCE5C8F9FFF1F7FFFAEFFFFEF5FFFFFBFFFFFBFDFCF6FCFAF8FFFE
F9FFFFF8FEFCFCFCFCFFFEFFFFFBFFFFF9FFFDEAF0F1DEE4BDAEB3FFFBFFFFFDFFFFFDFE
FFFFFDFEFFF8FBFFF0F7FFE4F6FFDBD2EAB0D3EEA9C2E195
8BA173233608677949CFE2ABD4E6ACCEDEA0D2E1A0DAE9A4D9E6A1C8D891D5E69F8EA25B
8BA05B4B601DD9EFAEC4DA99D7EAA8D9ECAAC2D697DAF0B2C0D89ED9EEB3C9DBA1D8E6A9
DAE3A4FCFFC05E652296A15FD9E9ABCDE2A9CCE7B0C3E2B8D3F4DFE3FFFBBCF8DC3B825A
418B5AA4E7B1BBEAB4CCEDB4D2EAB0C4DD9CD7F6B2C8ECA2C9EBA1C7E59BDEEFA8C8D891
CFE79BCCE89BC9E99DC8EA9DC6EB9DC6EB9DC9E99ECAE89ED0E7A1D0E5A0D5E8A68EA360
C6E19CBFDE98D4F9B3C4EA9DC1E58ED1F29BCDE5978A9E57DCE8A8D1DB9EDCE6A9CAD998
4B5F188EA65AC7E396D0EC9FCBE59BD3E9A1D6E9A7CEE19FCDE7A0C1DC95D4EDABC9E2A1
CCE2A4C9DCA463763F000B0064723FCEDBA6D3E0AA97A268697438C3CF8FD8E2A3D8E9A3
C6E298C5E498C3DD93DBF3A9CCE299CEE49BD1E99FD1EDA2CDEDA1BDDF92BFDF93D7F6AA
8BA359394A03E0EBA6D6E19CCEE29DD6EDA7C9E098D0E79FCDE59BCCE49A556D21CAE296
C8E096D4EEA4C8E29BD9F3ACC1DC99C7E29FDDF7B6C4DF9CCFEAA3D0E69EDEE3A1DDD499
EDD9A464501DF2E6B2D7DCA2D1EEAEBFEAA3B4E89EC4F8ADBEE8A0CFEDA7DAE6A6DFE6B3
F8FDE6808E81000A0053796EE6FFFFC5F6F33077733B8A85367C7C9ECFD4F2FFFFE9F6FE
E3FFFF0015003C8567A9ECC3C2EAB8D1EBBB4256314D5A40909486080800827B73FFFEF3
FFFFECFFFFE8F6F4DDFFFFEDF8FBF0FBFFFFF8FFFFF8FFFFFCFFFFFAFCF9F5FAF6FBFFFD
E4EAE6FCFFFDFFFFFDFCF3F4FFFAFDFEEBEFFFF9FBEBD8DAB5A7A7FFFCFBF5F1EEFFFEFF
FFFDFFFEFDFFEFF3F6F9FFF8F6FFEBCCE1B8CAE3AACDEAA8
A0B1845769399FAF7ED4E2ADC2CF97D9E4A8DCE6A9D0D998DAE3A0E0EBA7DFECA7D0DF9A
D7E8A2CEE29DC5DA97D8EDAAC3D792C9DD98D1E5A6D9EFB1D2EAAECBE3A7C8DC9FCDDD9E
DCE7A5E7F1AC61682498A15ED1E09FD3E5A7E3FBC1F2FFD8DBF5C8CCEFC5C6FAD372B48E
35815D5DA78697CFB2D3FCDEEBFFE2F8FFDFC7D5A2C2D496D8F2A9C4E395BCDF8DDDFFAC
CAE999CAE99BC9E99DC6EB9DC6EB9DC6EB9DC8EA9ECAE89ECFE6A0CCE19C718442B5CA87
D6EFABC7E6A0C7EBA5BFE59AC7EB94CFF099CBE39595A9618F9E5D8D995BA2AE6E98A965
9AB067BDD889D5F4A4CFEE9EC8E396CEE59DD4E7A5CEE3A0CBE9A1C1E399CCEBA5C4E19E
D0EAABD5EDB1859A622F420B9EAC79E4F1BCE1EAB3C0C88F878F549BA163949A5AB1BC78
D6F0A6D7F6AACEE89ECFE79DC9DF96CFE79DCEE89EC8E499CAEA9ECCEEA1D7F7ABBEDA8F
D6ECA3BFCF88A4AE69848F4AD9EDA8BFD690D2E9A1DDF4ACCCE49AD9F1A7B3CB7F98B064
D4ECA2C4DC92DEF5AFBBD58EDCF5B3C8E3A0BED897CBE5A4C9E6A3CCE2A1E6EEB2BDB881
645423756534C1B988DFE6B0C9E3A6C2EBA7BEF2A8C1F5AAB7E29AC4E59ED9ECAAE7F4BF
E7F1D9ACB9AF000800000900DCF5F2DCFEFDB4EBE862A7A464AAA880B8B9E0F6FFF1FFFF
79A79C57957CCBFFEAB1ECBEC8EEB3C3DCA2E4F5CBDCE6CB66665C4B4341584D4BBDAEA9
D6C8BBFFFEECFFFFECFFFFF1FFFFFAF1F0F6F9FAFFF1F2FFF8F7FCFFFFFDFFFFFDE5E7E4
FEFFFBFFFFFBF5F0EDFFFCFAFFF5F5FFF9F8FEE9E8FFFAF6EBDED8F4EBE4FFFFF6FDFDFB
F3F0FFFEFCFFF8FBFFF8FEFCF8FFF4E9FADADBF2C4C2DDA6
E1F1C0A9B988142200616E39D8E1AADAE2A9E7ECB291955A909457A9AF6F848D4C99A460
96A5608E9F59C5D99492A65F9CAD678CA05992A766768F4E8AA46788A265BAD092D2E5A5
C2CE8CC4CF8A7B853EB3BF77D3E29DCDE09ED0E6A6E0FDBAD9FBAEBBE196C8F1B9DCFFE5
C4F9E55C958E174F505E9091E1FFFFE6FDEDF1FCDEEEF7C8D4E4A3D2EF9DC5F293B4E383
C8EC95CAE999C9EA9BC6EB9BC6EB9DC6EB9DC9E99ECCE89EC9DE99DFF3AE879756D4E7A5
C8DE9DD2EFACC7E7A4BFE399C5E894C5E791CEE99AC9DF9793A362ADBD7ECADA99C6DC94
CBE699D0EF9FD0F1A0C7E897C6E295CCE69DD3E8A5D2E9A5CDEFA5C5EBA0C5E9A1BDDE99
CAE8A8C6E2A57C945A33480F98A973D1DEA8D4DDA6E7EFB4DBE1A5C4C88B8E9051969F5C
BDD58BC7E398D1EBA1D1E99FD6ECA3CFE79DCCE69CD0EFA3C3E397C4E699C0E094CEEA9F
D2E89FCDDD96D0D793A0AA658BA05BCFE9A2D0EAA1CDE79ED0E89EDBF3A9D8EEA3ACC277
71873EACC47AD0E7A1C9E39CBED795ECFFC3C9E3A2CEE8A9CAE6ACC7DEAAD1DAABA19F76
514821F0E3C0F4EFC9DEE3BAD7EBBAC4E5B0BEE7ADC0ECAFC6ECAFC3E2A6CBE0A5D0E1B4
CFDEC95A675E171D19000100757074FCFFFFDCF5F9DFFFFF7DBFBD91CDCBEBFFFFA8C0C0
61907E8AC1A2E3FFEDC0E6B5C8E6A6D2EBAAE8F8CBFAFFE8FFFCF3DBD1D20A0000988686
77645DBAAA9BFFF9E8FFF4E6FFFCFAFFFCFFFFFAFFFFFBFFFFFCFFFBF7F4FDF9F6FFFFFB
FFFFFAE6E3DCE4DDD7F4E7E1B8A5A16A5550B9A29CFFFBF1E7DBCDF2EBDBFFFFEFF4F6EB
F6F5FAFEFEFFFCFFFFF5FCF4F9FFF3F8FFECF1FFE0D4EBBF
C7D8A1D2E3AC404F18071400707942CBD29CDCDFAA999963ADAE7585894E9BA163A3AE6C
909F5A81924CB2C67ECADE96CBDC95C9DD95E0F5B0C8E19FC6E3A399B6769BB57493AA66
94A55F9DAD649AA85DCFDD92DCEDA6DCF2AAD1E7A6D6F5A9BDE686CFFA9ECAEAA7CBE7BF
EBFFFDD4F7FD5583923566777EAAB5BBDFDFF2FFF8E0F0CCD3E7ACD6F2A5B5E484C5F794
C8EC95CAE999C9EA9BC8EB9BC6EB9DC6EB9DC9E99ECDE79ECEE39EBBCC88DCECABD7EAA8
C2D796D4EFACC7E6A3C7E8A1CCEF9DC5E793CCE89BE5FCB4BCCF8DD7EAAADEF1AFD4EBA3
CDE99CC6E796C3E692C5E896C9E89ACDE79ED1E6A3D1E8A4C5E79BC4EA9DC4E89EC7E8A1
D6F5B2C6E3A3748E51253A0196A971DCEBB2CFDAA0D1DB9FE1EAABE2E8A8B4B977AAB570
DAF2A8CCE89DCCE69CCCE49ADDF3AAD2EAA0C2DC92C9E89CD3F3A7D5F7AAD0F0A4CBE79C
C8DC94DCE9A3D0D592E3EDA8576C27E6FFBAC6E298C4DE95CBE399D8F0A6C4DA8FD8EEA3
879D5493A960AFC47FD7EEA8DDF6B4B4CD8BCEE8A7C9E5AAC8E2B2DBF0C7D9E5BFA0A483
5E593BA69D80E2DBBFEEEDCEE5EFCCEBFDD5E6FFD3D4F1C1DEFCCAE5FFCEE9FFCDE0F5CC
DBECDA3039342E2A290A0000A18C91FFFAFFF4F9FDE8FFFF4F8D888BC9C4EAFFFF90A6A3
2A5740AEE0BDD0F0C7CBE6B1BFDA95D6ECABE6F6C9FBFFE9FFFFFACDC4C95B4B55FFEFF2
A19088AB9A8AFFFDEAFFFDECFFF5EFFFFAFFFFF2FFFAEDFFFFFBFFFFFCFBFFFBF9FFFEFA
ECE7E1867F77998F86A1938A655148675146CDB7AAEDDACBC3B8A4D3CFB6F2F5DAF8FCE5
FEFFF3FFFFF8F4F7ECE3EADAE3ECD7E2EFD5E1F2D2E2F3D1
C6DA9BDBEFB0CBDDA192A166566129707743A5A7767A7C4AB0B280E1E6B0E0E8ADDBE7A7
D1E29ED9EDA5C4DA8FE8FFB1D9EB9FD3E59BD0E79FC8E39EC6E5A2BEDE9DC5E4A1CDE8A3
CEE59DD1E69BD6E99ADBEE9FC9DE93CDE59BC0D995B9DB8EBEF08DC3F091CCE69FCAD5AA
EEF2E1F8FFFFE6FFFF9AC3D52D616F61969CBEEBE4E7FFF4CEEEBFC5E5A2C0E691D1F59B
CAEA97CAE999C9EA99C8EB99C6EB9BC8EA9DCAE89ECDE79ED7EBA66A7936D9E8A7E6F6B7
E5F7B9CCE5A4C3E09ECCEDA6CCEF9FC7EA98C3E296D2ECA5D1E6A5D4E9A8C6DD99BFDA93
CCED9EC3E996C4EA95CBF19CCEEFA0CAE69CCAE19DCDE4A0CAE89EC9EB9EC6E69BCBEBA2
D4F1AEBCD697647C4000150071864BDBEFB4D9EBAFC6D697CCDD99D6E5A0CBD892C4D58E
B5CD8397B368859F557E964CA5BB72D5EDA3D0EAA0CBEA9EBDDD91C7E99CB2D286E2FCB2
CBDC95DCE7A2E9ECA989904C9AB16BCCEAA2C7E399D5EFA6C2DA90D7EFA5CDE398CFE499
D4E8A0CBE198889D58ADC47ECAE3A1CCE5A3C5DF9ED4F0B6CCE3B9E5F6D4FBFFE6FFFFE8
D5D3BA7E765FB3A894FFFEE7FFF9E1FDFCE0F7FDDBFBFFE1F7FFDFF2FFDBE7FFCFF4FFE4
E5F6E6727876F7EDEC7E6A6B856B6EFFF9FBFAF5F9C5DEDB2C68605F9C94DDF5F590A39D
4C775BBFEEC4D1EEBECAE2A8D6F0A9CFE8A7DAEBBFF0FAE2F5F5F3ECE6F0EAE0E9F7EBEF
B1A49BCDC0ADFFFEE4FFF5DEFFF4E7FFFBF8FFF8FFFFF8FFFFF1F7FFF8F7FDF2F0FFF9F5
776C66C6B9B1FFFCF1FFFBEFF1DBCD594232FDE7D2FFFCE4BFB699E8E5C4D7DDB7FEFFE1
FBFFDFFFFFE4FCFFE2DAE3C4CDD8BAD3E0C4DEEBD1EEFCE2
D4EEA7D5ECA6CADF9ECFE1A35360280008006D70419A9D7096996ADAE1AED2DBA4C6D496
D7EBA6CEE49BE0F8AAB7D07FD5E899D4E69AC7DF95D0EEA6C7E7A4CCEFABC5E6A1CAEAA1
C8E499CDE597D6EB9CCEE394C3DA8CD5EFA5D8F6AED4F6AACBF5A1BFE592CFE2A0EFF7C6
FFFFE4FDFFF3EAFCFCDFFFFF7CAEB94883893A7573D4FFFAB5E3BFBEE4B1E0FFBCBBD78C
CCE999CAE999C9EA99C8EB99C8EB9BC8EB9BCAE89ECFE69ECCDD9973823FC2CE90FCFFCC
F6FFCACCE2A2CFE9A8CBEAA6C1E698CCEEA1C6E49CC5E09BDAF0B0D4EAAACAE3A1D4F2AA
CCEF9FC4EC96C4EC96C8F09ACCED9EC9E59BCCE39FD0E7A3D1EBA1CDE99CC7E398CFE9A2
CFE8A6C0D998778F51001700627A3EC5DD9FD0E9A8D1E7A6DAF1ABD4ECA2D1E99DC7DF93
CEE89ED0ECA1C9E1979CB46A8AA057D4ECA2D0EAA0C0DF93CCECA0D6F8ABDBFBAFBCD68C
D3E49DD2DC9750510F626925D3EAA4B7D78ED1EFA5D2EEA4CDE79DC9E197D8EDA2CDE297
D3E79FDBEFA7C9DE99425913DAF0AFD0EBA8D4EEADDCF5BCEEFFDAEBFAD9F9FFE4FEFFE8
FFFFE8A7A1894D402D665541705E4AD5C5AEF8EDD1E5E2C1C2C8A2D3E4B8D6EEBEEAFFDC
0006005A5C5BFFFBFAA08E8C0D00008A7F7DBDBDBBDDF6F03A766A2D675B889B99D2DFD6
83AF8CBEF3BFB4DA9FCFEEABBCDA94D0EAABEAFCD4F8FFF3F2F6F9FFFDFFFAF4FFDDD7DB
81796ED6CFB5DED3B3EADFBFFFFDE6FFF4EAFFF7F9FFF4FBFFF9FBFFFAFAFFFAF7C1B2AD
594A43FFF8EDFFFBEFFFEADC604635BEA58FFFFBE3E8D7B97F775398996FD1D8ACD4E0B2
DBE3BAFFFFDFFEFFE1D9E0BFCFD8BDEDF7DFF7FFEDFBFFF3
CAE99BC2DE93D0EAA3D3E7A8D6E5ACD6E2B0A4AC7D686E428B9165757D4ED9E3AECEDEA0
DBF0ABC0DA90C4E191DCF8A4D0E694D0E394C4DC90CCEAA0C5E6A1C8EDA7C2E6A0C8EAA0
C8E79BCDE899D3EC9BCFE897C7E293C8E497C8E89DC3E09DC3D49DE1EFBADAECB2D5E7AD
E6F7C1EAFBCFE4F7DBDEF9EAE4FFFFBDEEF23F7D7C508F879DD7C1CCF9D8DDFACEE0F8BE
CDE79ECCE997CAE999C8EB99C8EB9BC9EA9BCCE89ECFE69EC6D793BFCE8BC9D597F6FFC4
E5F5B7D1E7A7D0EAABCCEBA7C6EAA0D0F5A8C9E8A2C7E29FCBE4A3CCE5A4C6E19ECEEEA5
C7EC9CC0EA94BEE892C0EA94C7EA98C9E89CCEE7A3D3E8A5CCE098CADF94CEE29ADAF0A8
D6EBA8DEF4B3B1C98B30480A9CB677D0EDADC3E09DC1E09ACBEBA0C2E296D0F1A2C5E697
B9D88CCEEA9FE3FBB1C8E096869C53D2EAA0CFEBA0CCECA0BBDD90BFE194C3E397D7F1A7
D5E59EBFC984A2A36199A05CCBE29CC6E69DCDEBA1C6E298D8F2A8C3DB91D1E69BDAEFA4
D2E69ED5E9A1CCE19C8DA45ECFE5A4C5E09DBAD493E4FDC3F8FFDCFBFFE1FCFFE1F7FEDC
FCFFDFFFFFE1B8AA90B9A38BAC8E768E6E55604528A69674C6C39AD6E2B2B6CF98E3FCD2
051002797B7AFFFEFB7F7C7536392E6874685E7267E7FFFF5090800F4538798382E6ECE2
B7E4BD7EBB80B5EDA6BEEEA4D5F9B3B7D399DBF1CDF7FFF8E0E9F0FBFEFFFEFDFFE7E6EB
8C8A7B888467B4AF87D8D1A7FFFFDFFFF3DEFFFAF3FFF8FAFFF6F8FFF8FAD3BFBE584642
D1C0B8FFF0E4FFEFE2FFFAE8674C37B79D84FFFCDDFFF7D3918A60B2B485D5DFABD2DEAE
D1D8B6EEF2D7FCFFE9DADFC9DDE1D2FCFFF6F8FDF6FBFFFA
C6E297D9F5AAC2DC95D8EFABC9DE9DD0E2A6D1DEA92A3402000700939C6DD3DFADDDECB3
CCE1A0D3EDA4C1E090CAEA97D1E99DCEE49BCAE69BCBEBA0CAECA2C5E99FC4E89EC8EA9E
C9E89CCAE699CAE596D2ED9ED3EFA2C6E597CBEBA0CDE8A5D6E4B1CDDBAAE3FFC4F1FFCF
CDE3A3C7DBA0DFF2C4C2DCB9EAFFFAE2FFFFD9FFFF3E7F7781C8B8D9FFFDF0FFF4DFEDCC
CDE5A9CCE89ECAE8A0C9E9A0C9E9A0CAE8A0CDE6A2D0E5A2D7E7A6DEEDACBFCD8FC9D799
D6E9A9D5EBAABAD592D2F1ABC4E99CC6EB9EC1E198CEECA6C3DE9BD7F0AECEE9A4C8E69E
CEEEA2CAED9DC7EA98C8E99ACEEA9FD2E9A1D1E4A4CFDF9ED5E6A0D1E399D4E69CD6EAA2
BFD38CC7DC9BA4B97E182D008DA46CCAE4A7CCE9A6CEEEA3CAEC9FBCDF8FD4F9A9C8EA9D
D8F7ABBFDB90C7E197D4ECA28DA35AD5EDA3C7E197D0ECA1D0EFA3D4F3A7C2DE93D3EBA1
D3E39CD0DB96BFC48157611CCBE29AD6F4AABDD98ED0ECA1CEE89ED2EAA0D3EB9FCCE498
CBE399CFE69EC9E098CCE39DC5DC98D8F1ADF5FFCCDAF2B4CADFA7D4E6B4C9D9A8D7E5B4
CFD8A9DEE1B4E3DEB6F7E9C4FFF4D1FFFDD8B29C7762532A555122D7DBA8D8E5ADD2E0AF
0004006F7062CACEBFE1E7D900040004120597B09DE4FFFA3A7A6ABAEEE1838D84D8DBC8
B8DFB385BF824B8A43B2EEA6B1E1A3CEEFC2E9FAE7F8FFFFF7FFFFEDFDFFEEFFFFF0FFFF
B7C6B300050059512D63532F6A5739614C375F4B405F4A47664C4D6850505B4947FFFBF6
FFFBF4FFFAF3FFFBEDFFEFDF6C503AAE9577D9CBA6F5ECC1B9AE80C4C490D1E5A8F5FFD6
FCFFE4FFFFEDFFFFEFF7F9EBFDFFF5FEFFFAF6F8F5FEFFFD
AABF7ED2E9A5CFE9A0CDE89BD0EB9CCFE79BB9CD88E7F7B96B7541313A0B929B6E909C6C
D8E9B2CDE6A4C2E195C9E99DCAE7A4CAE7A5C9E8A2C9E9A0C8EA9DC8EB9BC8EB9BC9E99D
CAE89ECAE89ECCE7A0CCE7A0CCE89ECCE89DCAE99DCAE89EC7E4A1C7ECA7C2F6ABC8F6AD
D7E9ABDAE3ACD0E4AFC9E6B8D8F6D4DCFEE5E4FFFD4781725BB4A0CAFFFFEDFFFFFAFAF8
EDFFDBC9E6AEC6E1AACAE5AEC8E1A8C9E1A7D2E5ADE1F3B9E0F2B6E3F5B75E7131D8EBA9
D2E9A3C2DC93CBE79CC4E596C6E999C7ED9AD6F9A9BBDB8FDAF6ABC4DE95DAF1A9CEE59D
D0E69ED3E9A1D0E19DD1E09DDDE9A9DDE5A9D3D89ECED69BD0DF9ED8ECA5D2E79AC9DE8F
D8ECA4C9DC9C495A263C4C1FADBE92CDE1ACD0E9A7D0ECA1C9E996CAE999C3E398CBEBA2
C8E89DCCEB9FCCE89DC0DA90B5CD83B5CB82C4D890D3E79FD4E8A0D9EDA5D1E59DCCDD96
D4E59ED9E9A2D4E49DD3E49D74893EC2D98BD7EFA1CDE597D0EB9EC7E396C9E89CCCEB9F
C6E49AD3F1A7D0ECA287A158A8BF79D3E8A3F8FFC6DDF4AEC6E3A1D0EFACC3E09DDCF6AF
D2E9A3C8DC97DDEDACEAF6B8FFFFCFFCFFCDFFFFD3BBBB897D7B48625D26827B44E2D9A2
736D39080A00D3E3BEDCE8D0655B590A02006D7F65E6FFF1437F7363978B90A086AFB58F
CDE5B595BE8697D39551955C417F566C9881F8FFFFFAF9FFEBF8FFE6FFFFCDFFFF71B3A5
76A38C35472DB2A28BC7A490B59080BA988CC2ABA5B8A3A09A7C7C967C7BCCBEBDFFF9F7
FFFBFAFFFBF8FFFBF3FFFBEC795A469A8363E0E4B2EBF2BCD9CC98E9E4ACBFE39DE8FFD3
EFFEDDFFFFEFFFFFF1FFFFF3FFFFF6FDFEF6FFFFFBFDFEF9
B6C58A687B3BD2E9A1CAE596D4F19DCEEA96DBF3A7BDD28DD9E8AF959E6F6B74497C8558
8A9863B8CC8FD0EAA3D1EFA7C9E7A7C8E8A9C8E9A4C8EA9EC9EA9BC9EA99C9EA99C9EA9B
CAE89ECAE8A0CAE8A2CAE8A2CCE7A0CCE89ECCE89BCAE99BC3E89BC1EDA0BBF6A4C3F3A7
D6E6A7D8E0A5CFE4A9C9E6B0D1EEC0B4D2AEEAFFF389C0AB003E28C4FFFFE9FFFFEEF0FC
EDFFE8D8F3C8D6EFC5D5ECC0D1E4B7D1E2B5D6E6B5DDEEBAF7FFD1CADCA0B1C484D2E7A2
CFE69EE9FFB7C7E396D0EF9FD0F3A1C7EA98B2D382D4F5A4C2DE91C9E399CDE49CCCE099
AABB779BAA67959F609CA468999E648B8E55AAAB72E1E6ACD8E6A8ADC17C8FA455CFE593
AFC177D3E3A496A375101C004A59328A9A6B849958E1F9ADC0DC88DAF7A5CAE8A0CAE9A3
C0E095CAEA9ED6F5A9D6F2A7C7DF95ADC37A99AA638D9D5689995295A55EB5C57ED5E69F
DEEFA8D1E59DC9DF96CCE297A4B66C95A75BA5BA6DD8EEA3CDE89BD1EDA2DAFAAFC0E095
C8E89DC5E59AC5E09995AF66B6CC84C6DA93E3F4AEC7DD95CBECA5C0E69BD3F5A9C0DF91
C1DC8BD8F3A2C3DE91CAE49BC6DF9DC9DFA1D6E8AECAD59DCACA945D561FA5945EE6D79C
E4E0A0353D01586E3FBECDB08B7E760A0000334022B3D6B690C8BD78ADA3BBD8BC8D9E74
A9BB8BC7E4AEB8EDB57DBD8B9FDFBDD1FDF0F3FAFFFEFCFFF1FFFF8AB9C362B8AD1E7761
29684BC3E0C2FFFEE8FFE8D6FFF8EAFFFAEFF2E7E3FFFCFAFFF7F5FFF8F6FFFDFAFBFAF6
FFFAFBFFFBFAFFF8F0FFF7E9DCBDA9735F3ED7E4AED8E6A9C9B582CCC38AC3EBA2BCEFAD
DAEECBFCFFEFFAFEEFFDFFF3FEFFF6FCFFF6FFFFFBFDFFFA
D7E5AA8C9C5DC7DD95CAE596C7E490C0DD89D7F2A5D0E7A1CDDFA59CAA770D1600697243
86935E7B8A4FE4F8B3BFD690CAE7A5C8E8A5C8EAA0C8EA9DC8EB99C8EB97C9EB97C9EA99
C9E99DC9E9A0CAE8A2CAE8A2CAE8A0CAE99DCCE999CAE99BC6E69BC4EA9FC2EEA1C6ECA1
D0E49FD4E0A0CDE3A3C9E5AAD1EDBAC5E6BBE1FFE5BEF3D935806C5CA29AD3F5FFF1FFFF
F0FFF3EEFFE4E3F9D5D2E6C1CBDDB5D6E7BDE7F7CAF0FECDFBFFD4CBDDA3B5C789C7DC99
C5DC94CAE598CDE89BCAE797C2E191C4E596DDFCAECFEB9EBBD78CD6F0A6DEF5ADD3E7A0
7C8D497B8A4789955599A364858D51575F235E64288E985B9AAD6D627732B1C878DAF19F
C6DB90D5E8A8ABB88A0008005A69427A8A5B4A5F1EC8E094C4E08CC4E18FBDDB93CFEEA8
CFEFA4CBEB9FC8E79BC8E499CAE49ACDE59BCFE39BCFE099DAEBA490A15A73843D96AA62
BBD188D0E89ED7EFA5D1E79ED5E69FA2B26B869751D1E59ED1E8A0BED88FBAD58ED2F0A8
C8E69ECDE8A1DAF3AFB1C882A6BA7595A662C4D390DEF2ADC2E19DCAEEA6C0E097D1F0A4
CBE697DFF7A9CFE99FC8E29BCAE4A3CEE6AAD1E4ACD8E5AFD0D39E59541DA99C67E1D89F
CFD99A364A0F768B60D5E3C2939071342F1130351588A086B0E3D45F998D9CC8B79FC0A3
92A578C5DCA6C0E9B1B7E9B8CBFAD8EAFFFBFBFFFFF7FAFFE0FAFF4A8184459D8D036043
8BCFAAB3D9B2FEFFE3FFFBDDFCFBE6FBFFF4EEFFFDF2FEFEFCF2F1FFFBF8FFFFFBF7FCF8
FFFEFDFFFCFAFFF8EFFFFCECFADBC6735F3CDAE3AED8E2A6BEA775DDCE97D3F4AFB4E0A3
CDE0C2F4FAECF8FEF2FCFFF8FCFFFAF9FEF8FEFFFDFAFFFB
CFDAA0DDEDAEB4C881D4ECA0E0FBAAC4E18FC6E295CCE69FD0E6A8CDDEA88D9969535C2D
BEC693A3AC73909A5BD3E4A0CCE7A2C8E9A2C8EA9DC8EB99C8EC95C8EC95C9EB97C9EA99
C9E99DC9E9A0CAE8A2CAE8A2CAE8A0CAE99DCCE999CCE999C9E79DC9E79FC8E89DC8E79B
CEE49BCFE39BCCE69DC9E6A3C5E3A7C9EBB9E9FFE8E2FFF4A7E0CD5C958E427276A8CBCD
DAF2E4F4FFEFEDFFE5DAEACDD6E5C6E5F3D0FBFFDFFBFFDCF8FFD5DAE9B28E9D62D8EBA9
D6ECA4BFD78DD4ECA0D3EEA1C5E093DEFAADC4DE94D0EAA0E3FBB1BFD78D9FB56D40560E
CDE19CDAEBA7DDEDACDFEEADDBEAA9CFDB9BCBD799D7E5A7C9DE9DCDE7A0CBE493D0E795
DAF0A5BED191D2E2B33D49238E9D76EDFDCEBCD19063792EE9FFAFC0DB8AD7F2ABCDEBA5
C9EB9FC5E79AC4E498C7E69ACEEA9FD4EEA4D8F0A6D8EEA5CBDF97CEE29AE6FCB3CCE299
70883E4E681E93AD63DBF3A9D0DF9CCCD896A4B372CCDF9DCCE19EE1FAB6D2EBA7CDE8A3
CDE8A3C9E49FDCF3AFCFE4A1C2D69193A25F8E9A58899958A9C68490B16CCAE8A0C1DD92
CEE69AC5DD91BAD48BE2FDB8D1EBACCBE5A8D1E6AECCDDA69FA672908F59CAC18AEBEAB1
DDF1B493AE77ADC29BDEEDC6BEC6935C602D11130019270EB6E1D03B776B246058AFE0CD
A3BC94C2D4A0D2F0BCC6E7BAE1FEDFF5FFF6F9F7FAFCFFFFE0FDFF8EC6C34B9F8887DEBB
A2E3B8BAE5B7D4EBBFD5E7C1EBFFECE4FFF8DBFFFFEAFFFFFBFDFCFFFDF9F3F9F5F7FFFB
FDFDFBFCF7F3FFFDF3FFFCEC6C5038927E5BE1E8B4DADFA5907645D2BE8BBFD897CEF4BB
CEE1C5F9FFF4FBFFF8FBFFFAFCFFFBF8FDF9FCFFFFFAFEFD
D3DDA1D2E0A29AAB65BAD085BFDA89D5F2A0DAF9ABBCDA92D0EAABCBE0A7D1E2AE626C3A
6D7440C9CC95A4A36A9CA564CDE7A0C6EB9DC6EC99C6EC95C8EC94C8EC94C8EC95C8EB99
C9E99EC9E9A0CAE8A2CAE8A2CAE8A0CAE99DCAEA97CCE999CEE89FCFE6A0CEE49BCDE599
CDE695CCE796CCE997C9EA9BCFF0A9C0E2A6C6E7BABEE1C1E7FFFBD1FEF77DB5B4386A69
ADC7BEF3FFF4F8FFF4F5FFEFF6FFEAF9FFE8FBFFE4ECF7CFD9E5B7CFDDA8748348DBEEAE
DAEEA9DFF5ACC2D88DD7EDA2D2E89FCAE097CAE098D3E9A1C1D78FD8EEA690A65EDFF5AD
CADF9AD3E8A3CADF9ABFD48FCADF9AD8ECA7D7EAA8D3E8A5C3DC9ACEE9A2CEE998CBE793
C6DE92E2F7B66373441B2A03909F78CDDDAED5E8A8E5FBB0C1DA87D7F2A1C9E39CB7D58F
C4E69AC6E89BC9EB9ECBEB9FCAE99DC7E398C2DC92BFD98FD5EDA3BDD58BC7E197DAF4AA
CFEBA0D0ECA1D7F3A8CAE19995A4634551134E5C1ED8E8A9CBE09FC3DC9AC8E19FCDE8A5
D3EEA9C8E39ECEE5A1CBE09DD9E9A8D4E3A2E1EDADE3F3B2C8E2A1C0DF9C47621DD0EAA1
C7DF95EDFFB9D1EBA2B6D18CCEEBABBFDB9EC8E1A8C7DAA2909A65A8AB74E2E0A5D5DB9F
B7D599D0F3BD2B3F1A7F9064CDE39B708039706E47E1E5CECBEEDA6DA99D388281AFF1E7
96B48E7E8F5BBFD5A4CBDDB5D8DDC6FFFFF4FFFBFBF0EBEFEEFFFFDFFFFF7AC1A3B7FFD7
B7EFBED5FFCEB3D9A8B7E2B7DCFFF4ABE8D8BEF8FAE2FFFFF7FFFFFCFEFBF5FFFBF7FFFD
F6FCF8FFFFF7FFFDF1D6C5B35B4327C2B38CC5CC96D5D89FAC9162FFEFBED9EBAFC3E1AD
D3E2CBF9FFFAFBFFFAFBFFFBFCFFFDF7FBFAFEFFFFFEFFFF
DAE4A8D4E0A0D5E6A051671ED7F2A3B9D686C3E397D4F4ABBAD795DCF6B9D7EAB3D4DEAA
30320086834E9A905B57571BCFE79DC6EC99C6EC95C6ED94C8EC92C8EC94C8EB97C8EB9B
C9E9A0C9E8A2CAE7A5CAE7A4CAE8A2CAE99DCAE999CCE999D1E8A2D0E5A0CFE39BCFE698
CDE994CBEC93CAED93C8EC95B0D587DCFCB9D2EABABACDADF4FFF6E9FFFFCCFFFF447F7B
9FB8B5F7FFFDFBFFFBFBFFF8FBFFF4FCFFEFFCFFE8E6F0CDD0DBB0DFEBB96E7B43D0E0A1
C9DA96D4E8A0D0E49CC7DB93D8ECA5BFD08AE2F3AFC8DC95CFE39CDEF2AB829850C7DD95
CFE49FD5ECA6D3EAA4D0EAA3D3EDA6CBE59CC2DC95C3DE97CCEAA4D7F5ADBEDE8BD2EF9B
C7E295CCE2A18EA0700E1D0074835CD9E9BAD0E3A37B9045BCD381D8F1A0D4EBA5D3EEA9
CBEDA1C8ED9FC8EA9DC4E699C4E498C9E89CD1F0A4D8F7ABCBE79CC9E59AD3EFA4CDECA0
BAD98DBDDD91CCEB9FC9E39AD3E3A4D2E0A3C9D79AE6F9B9CEE4A3DDF6B2DAF5B0BDDB95
BFDD95CCE7A0D9F3ACD6EDA7D2E6A1CBDC98CEDA98CADA99D1EAA9C5DF9EC6DF9BB0C77F
CBE198A4BC70D7F1A8D4EFAACCEBA8C9E7A9CDE9AECDE5AB98A76E656D32CCCE8FCAD394
CCE8ADCCEAB8000E00617446D9F6A691A8580807004C4C34D3F0DA53897C1565645DA99F
B4DCB99CB283B6C89EB3BD9BD3CCBCEFDCD6FFEBE8FFFCF8F3FFF2EAFFF395C7A2619668
9DC795B4DCAAB7E9B88AC79E00422561AB9E4A858B527A86E6F5F8F0F9F6F4FFFEF5FFFF
F2FCF4FFFFF8FFFCF07E6C58796646D2C69CD8E1A8DDE0A7A78C5DC8B283D5E4ABC2DEAD
D1DFC8FAFFF7FCFFFAFAFFF9FBFDFAFAFCF9FFFFFFFFFFFF
DFEBADC6D292DBECA6D0E49C80984EDCF8ADC6E69AB8DA90D2F3AED4F1AFB7CC91D7E4AE
D8D8A4EBE3B28C7C4B8E8750D0E69BC8EC95C8EC94C8EC92C8EC92C8EC94C9EB97C9E99D
CAE8A2CAE7A5CAE6A9CAE7A7CCE7A4CCE7A0CCE89BCDE89BD0E7A1CEE5A1CBE59BCCE796
CEEA93CCEE90C6EE8EC1ED8ED3FBA5CDE8A1C7CD9DDEDDBFF9FDEEEAFFFB38716A09413E
A7BCBFFCFFFFFCFFFFF6FBF7FCFFF8F9FDEEFEFFECECF3D2E1E9C0C7D3A19AA76FD5E5A7
CFE09CC9DA93EBFCB5CEDF98D1E09DDBEAA78796555465215667233F530ED3E8A3D7ECA7
CEE59DCDE79EC6E298C4E298C9E79DC3E397C6E69BD6F6ABCFEEA8B1D188E1FFAFC7E792
CDE89BD1E7A6BCCE9E0D1D00697851C3D3A4C5D898A4B96EDAF19FC8DF8FCCE19CCBE4A0
C5E59AC5EA9CC9EEA0CCEEA1CAEC9FC7E79BC4E498C2E296CCEB9FCAE99DC9E89CC9E99D
CDEDA1D2F4A7D1F1A5CBE99FC3D897E4F6B8CADD9DC4DB97C9E29EBFDD95C0E095D9F9AE
DCFCB0CBEB9FBAD88EBDD78ECEE59DDDF3ABDFF0AAD4E8A3C7DD9CD7EDACD3E8A3BFD58C
CCE1967E9449D2EAA0C6E19ABFDE9AC5E5A4C8E8A9D2ECAFADC182586424979E5BE2E8A8
D4E3AAC8DAA866764F536938C9EC9CC4E1910307000C0F00E0F8E2B6E4D773BCB56FBCAC
C2F6D0C3E7BBC1DBB8D0D9C4B8ABA5A78F8FA28682FFFBEDF9F9DDF9FFE1D8F0C0D1EDBC
D1EBBCC3E7BBC4FCD50041203D917AB8FFFAA5D4DE1F3948E0EDF3F8FFFFF7FFFFEFFBF7
E7F1E9FFFFF6F9E9DC66513CD6C8A5E1DDAEDBE6ACE5EAB0DBC596DECC9EDBECB6C7E1B2
D2DCC4FCFEF3FFFFF8FCFDF5FEFDF8FFFEFAFFFEFBFFFDFA
D0DF9EDEEDAACEDF9B8CA059C4DB93C9E59BCBEBA0CFF3A9C0E49CC1E29DD5EFAED0DFA4
DADDA87B7140AD986D9E925ED1E69BC8EC94C9EB94C8EC92C9EB94C9EB95C9EA9BCAE8A2
CAE7A7CAE6ABCCE5AECCE5ACCCE6A9CCE7A4CDE79ECDE79ECFE6A2CBE4A0C5E79BC8EA96
D0EA93CFEC90C2EE8CBBED8ACAF29AC6DC94F1E6B8F0DCC1C1BEAD283C3101332A1A4B48
A4B3BAFFFDFFFFFEFFFDFFFEFEFFFAFAFEEFFCFFEAE6EDCCD0D8AF586432D4E1A9D6E4A7
D8E9A5D9EAA4CBDC95D5E69F98A4628D9959B1C07FDAE9A8CCDD99CDE19CDFF4AFC2D993
CBE59CD3EFA5CCEAA0C7E79CCEF0A3CCF1A3C3E89AC1E699C9EAA3C8EAA0C1E38FCEEE99
C8E497D1EAA8D2E6B50009005F6E47D5E5B6DCEFAF879C518FA654839A4ADFF4AFC8E19D
CBEBA0C8EA9DC6E89BC6E89BC8EA9DC9EB9ECAEC9FC9EB9EC7E79BCBEB9FCAEA9EC8E89C
C9EB9EC3E598C2E497CEECA2D4EBA7CCE2A1C8DF9BD4EFA8D3F1A7C8EA9DCEF3A5BEE393
BEE491C5EB98CCEF9FD3F2A4CDE99ECAE49ACBE199D1E6A1D9EEADC4D998CBDF9ADFF3AB
DCEEA4B2C77AB3CB7FC9E59BD0EFA9C5E8A4C3E3A2D6F3B1CAE19D8FA05A525C15CACF8C
DCDBA2DCE0AE637247000D00CEF2ACCCECA329380000080061745ED1F5E76CA99A428870
75B38CDEFFE8E9FFF3F0FFF6FFFDFFFFFAFFFFF8F153432AFFFBCECFD29BDCE4A9D5E2AA
E3F4C8EAFFEA36795A358B7229867487D2CDE6FFFFE2EFFFA2ADB3ECF7F9F8FFFFF8FFFF
F8FFFBF9FBF0DBC9BB604A32E3DBB4E2E6B3CEDEA0DFE9ADF7E6B8FBEEC2C7D9A7D0EABD
D7DCC6FFFFF3FFFFF4FFFEF3FFFEF6FFFEF8FFFDF8FFF8F3
D2E39FD8E9A5ADBE7A8FA35ED3E8A3C0DA91CAEA9FCCF1A4C4EA9FC9EFA4C6E59FD3E7A8
AAAF773B3304553E15584A19D2E49ACCEE97C8E992C9EB94C2E28DD4F3A5C5E39BC9E3A4
CAE3ACD0E8B6E4FACCF2FFD9E5FCC6CCE4A8C9DF9ED3ECA8CFE8A6C3E29CC1ED9ECAF4A0
D0E693CCE389C4F491C5FB99BEE68EE2EFAACDB0886C4933827F6E5E72661639321B3B3A
9EA5AFFFFCFFFFFDFFFFFFFFFFFFF8FFFFF1FEFFEAECF3D1D2DDB25B6735C6D39BD5E5A6
D8E9A5CDDE98D8E9A2B1C27CD6E2A0D6E2A2D4E3A2D4E3A2D3E4A0D1E5A0D0E5A0CFE6A0
D0ECA2C6E49AC8E89DCBEDA1C6EB9DC8EFA0CBF2A3C3E99CCAEEA6C8EAA0CDEF9BC5E590
C6E295D0E9A7566A39000E00687851D4E6B6CFE4A3CDE398D7EE9CD8EF9F9EB56FD9F2AE
CEECA2CCECA0C6E69AC6E69AC8E89CC1E195C1E396D1F3A6C6E89BCBEDA0CBEDA0C4E699
C1E396C4E699C8E89CC7E59BCEE9A2C6E19AC9E59BD2F2A6D0F3A3C1E895C0EA96CBF7A0
C2EE97C6F09AC6ED9AD0F3A1D1F2A3C7E698C2DC92D1E8A0CBE09DC9DC9ADAEBA5D2E49A
DAEA9FCBDD91A1B86AA1BD72CCECA3C2E39EC5E6A1D1EEABD7EEA8CBDC95C7D1886C6C26
A39058EDDDAC6A76482F4919BBD9A5D1F0B52E4809000D002B3A23CCE3D3CBF3D8619974
1A61357CC09BACDCCCC3E3E2E9FFFFF7FFFFF4F5E7DCD8B3C8C68BE5E59DDEDE96D9DFA1
F1FFD6C2EDCF33856E58BDAB9AFFF138807CEBFFFFF8F8FF8A939CEAF5FBEEF7FCF9FFFF
F5FFFAF6F8EBA69082F2DDC2F3F0C5EAF7BFD6EAABECFABDB4AA79D8D1A5D0E3B5DEF5CB
F5F4DFFFFEEFFFFAEEFFFAEEFFFCF3FFFCF3DACBC4B4A59E
D9EEA9BDD28D97AB66DAEAA9CFE2A0DDF4AEC1DC95C4E69AC1EA9CC3EC9ECEF0A6C3DC98
7780472F29007E6843918356CEDE97D0ED99C9E692CDEA98C7E396CFEAA3C5DD9FD9F0BC
D2E7BCD7E9C3E2F3CFEDFFD9E8FBCED7E9B7CBDEA6C9DFA1C8E2A3C4E8A2BBEC9DBDE795
D5E394DAEC9ABEF091ABE284CEF1A1D8DC9FB38A6A6E4833C5CAB6203B2A5C736D273639
B1B1BBFFFCFFFFFAFFFFFFFBFFFFF6FEFFEDF6FCE0E7F1CCC8D4A691A069CDDCA1D5E5A4
D2E39FD9EAA4C6D79094A55FD4E3A0D4E3A0D3E3A2D3E4A0D1E5A0D0E5A0CFE6A0CDE7A0
CDE99FC5E59AC7E79CC8EA9EC3E89BC5EC9DC7EDA0C2E89BC7EBA3C1E399C9EB97CDED98
D1EDA0CEE9A66C804F03150071815AD7E9B9D4E9A8CEE499CDE492C4DD8C8198529EB773
BED88FD1EDA2D1F0A4CAE99DD1F0A4D4F4A8C8E89CBDDF92C5E599C8EA9DCCECA0CDEDA1
D1F1A5D4F4A8D0EFA3C7E69ACEE9A2CBE69FC7E59BC5E79AC3E898C1E895BEEA93BEEC92
BAE68DC5F19AC2EA94BBE18EC4E498CDEBA1D1EDA3D6F0A9E1F5B6CEDE9FD7E6A3D1E19A
C4D189D9EB9FC5DB90ABC57BC9E7A1CDEEA9C7E7A4C3E09DD3EAA6D4E59FCBD58C6A6521
6F501AF3D7A8646A3A21380AD9F4CBC7E7B686AB65001D00000D00C7D2C2CEE2BF85AE82
4B9266408B6C346C639DCAD0D0FFFFC9F0F5D6EDD9ADBA8EB7BE78D9DE8CE3E697CED794
CEE5B9D9FFED1B746059C3B593FCEE38817AD9EBEDFAF7FE6C7981F2FFFFF8FFFFF8FFFF
F4FFFCD1D5C78F7866F2DBBCFEFFD0F8FFCFECFFC1E2F0B3817B4BC7C298DFF0C4F7FFE4
F3EED8FFFCEDFFFCEFFFF6E9FFF3E9EDDBD1A5928B5F4C45
BEDA90E7FFB87B904DCEDE9FD9E7A9D8EBABD2E9A3C2E297C6ED9EBBE593BDE495D8F6AE
D0DEA1999767B9A783CDC094B9C681CEE99AC6E192CEE89ECDE6A2CFE7A9CFE3B0F5FFDF
F1FFE2F3FFE8F6FFEBF8FFECF8FFE6F5FFDDE2F2C3D1E4ADC6E2A5CEF1ADC5F1A6C1E397
D9DF99DBE59CC4F19CC3F5A0D6EFABC9C391673E22FFF5E2B3C7AE668975A9B4B0807F84
CAC5CBFFFDFFFCF8F7FFFFF6FBFEEDEDF3D7DDE7C4D4E1B59DAB76C7D99DD7EAAAD6EAA5
C8DC95D4E8A1B5C67F92A35CD1E59ED1E59ED1E5A0D0E69ED0E69ECFE69ECDE79ECCE89E
CBE9A1C9E9A0C9E9A0C9EBA1C6EAA0C7EC9FC7EBA1C6EAA0C6EAA2C6E89ECCEE9AC8E893
CDE99CCDE8A590A4730113006A7A53CBDDADCFE5A4CEE69ACDE693CEE99899B36C9EB773
D8EFA7CEE69CC6E096CEE89ECCE89DBBD78CBEDD91DCFCB0CAE99DCEEEA2CEEDA1C5E498
BEDD91C0DF93C9E59ACEEA9FCCE69FCFEAA3CBE99FC5E599C8EB9BCFF6A3D0FAA4CAF69F
C9F39DC9F39DCBF2A1CDF2A4D6F6ADC8E6A0C4DF9CCFE5A5D3E4ADFAFFCFDAE5A9DCE8A8
E5F0AEAEBD78657934B4CD89C7E4A2D4F2B2C8E6A8BEDB9BD3E8A7D4E3A0DAE49F9D9556
795521D0AF82D5D4A695A77DA6BB9AC3E2B6C5F4A6B7DF980A1700616252BDBF9ACDE3B5
C7FFDC9DE7CC8FC5C577ADB7357F887CC4C0C1F3D8E1FFD3B1CB814E620BC6D886ECFFBC
ECFFDFA7DEC1419D8850BCAC8DF6E572BEB18BA09BFEFFFFE9FEFFEBFFFFECFBFFF5FFFF
E6FAF17982716A543FF3DCBCE6EFBADDF6B4E0F6B5E5F0B4877F51A49C75CDD7B2F7FFE2
FFFFEAFFFCECFFF2E4C9B7A9766458645047B19D96FFF5EE
C7E99CC2E297D8EFAB546425C9D498D6E1A5D5E8A6D2EEA4C5EA9AD0FCA7B6E08EC3E599
D3E7A88286547B6E4BDDD4AB9BA767CFE59CC9DF97CDE29FCFE3A6D1E3AFD4E3BCF9FFEA
F9FFF1F9FFF6FBFFF6FBFFF4FBFFEFFBFFE8E9F3D0CEDEB1C5DEA4CAE9A6C9E6A4CFE2A0
E0DEA3D3D898BAE097C6F0A8D6E1A9AE9F78724E36FFF4E090B79A3C69528388849A8E92
D5CDCBFFFEFAFCF9F0FFFFF1FDFFE8E4EECBD3E0B4CDDEAA4F6125C3D897CEE29DD2E69F
CEE29BC2D68FC4D58ED2E69ED0E69DCFE79DCFE69ECFE69ECDE79ECDE79ECCE89ECCE89E
CAE8A0CDEBA3C9E9A0C8EAA0CCEEA4CAECA2C7E8A1C9EAA3C5E6A1D0F0A7D1F19EBFDF8A
C5E194D4EDABB9CD9C051700697952C4D8A7CEE4A3CAE598CCE894DEFBA9CAE59EC6DF9B
8B9F58C5D68FE0F4ACD4EAA1D0E89ED5EFA5D0ECA1C7E398BFDB90C8E499D1EDA2D5F1A6
D4EEA4D1EBA1D1E99FD0E79FCCE19ECFE6A2CEE7A3C9E49DC3E296C0E393BEE393BEE393
C8ED9DC1E698C1E399BCDB97D1EBACCCE4A8DAEFB6ECFDC9FBFFDAF1FACBFFFFD4F0F9C2
5862267D884CCADA9CD8EEB0C9E2A9D4EFB8CDE8B1CFE8AFDCEDB6CCD79BE8EEB2DFD69D
66471892754BEEE9C1676F4A546440CFEDBBBBEC9BC8F4A7606E4D0C07006F6444D9E1BA
C9F8D6D6FFFFDFFFFF497F8B2B8083287F76D5FFFAD5FFD5C4ECA6CBEA9C97AF65C1DA99
BCD9ADB9E7CA216F573693803E9B882F7364D5EAE1F8FFFFE7FFFFD5FCFFEDFFFFEDFFFF
EDFFFB93A08C867059F1DAB8D7E5AABED994DEF3B0DDE5AA978A5E968664DDDCBEFFFFEA
FFF5E4B09E905F4D4152403499877DFFEFE8FFFAF4FFF1EB
C9F3A1C0E597D1EAA68D9D5F868F56DDE5AAC5D493D4EBA3BBDE8CCCF8A1BCEA92C3EA9B
D5EFAE96A36E726E49C5C19B8C975BD5E9A4D1E4A4D1E3A7D0E1ADD3E2B7D8E3C5EEF7E4
F7FEF6FBFFFFFCFFFFF7FCF8F8FEF2F8FFEDEBF0D9D4E0BAC8DFA7D1E7A9DFE4ACE9E3AF
F0E4B2E4E4B0C8E6AAC6E1AABDB8907B6649E8D3BEF8FFE88CC9A71D593DC4C6C1735F61
C8BFB8FFFFF1FDFCE8FFFFE8FEFFE3E9F4C9D7E8B4D3E7AA758A49E0F7B1DEF4ABD5EBA2
CEE49B83995099AD66C6DC93CDE79DCAE99BCAE99DCAE99DCAE99DCAE99DCAE89ECAE89E
C6E49CCDEBA3C8E6A0C6E59FD2F1ABCEEDA7C5E4A0C9E8A4C6E5A1CAE8A0CAEA97CCE995
CFEA9DD3ECAABDD1A0081A0073855DCEE2B1D4EDABC8E497C0E08BCEF09CCFEFA6CAE5A0
72833DA1AE68BFCF88C9DA93D2E69ED6ECA3D0E89ECBE59BD9F3A9D0EAA0C8E298C9E399
D2EAA0D3EBA1CEE49BC8DC97D2E0A3D5E3A8DFEFB1E6FBBADEF5B1CDE7A0CBE69FD3F1A9
C5E39DCFEAA7D9F1B3CADFA7E0F0BFD9E6BAE4EFC5E3EDC8CAD1AF929977808660CFD5A9
C9CF9FD8E0AFD0DCAAD7E9B7CBE1B3DEF5C9E0F7CBE6F9CCECF9CDCED6A5DEDDADC5BF8F
695D33A0926DEADCBF645F3FECF9CBCAE8AAC1F39EB9E397B0BC980700000D0000E6E4CD
DBF7DEE4FFF9EBFFFFE0FFFF1E6D6832897986C6AEE0FFEDE3FFDBCDF1B4BEDA9FCCE3AD
C9DBB1D3EECDBBEDD05D9D8300402893C9B9F1FFFFEEFFFFCAFCFD7FB9BB567E804E716D
7FA8968298815A462DF1DBB6D7E7A9C7E29BD5E4A1E3E0A9BEA77EE3C5A9F3E1CBE3D6C5
7666597B6A60BEADA5FFFBF4FFFBF6FFF7F4FFF3F2FFF6F5
C1F19DC9F2A3C5E09BC2D294DAE1AB9EA36BBCC689C9DD96D3F6A2BCE88FC1F299CCF7A5
D0EFABBFD19D5256310A0C008C975FD7E7A9D7E6ABE6F4BFE6F2C4E9F3D0F0F8E1F7FDF3
FEFFFFFEFEFFFEFEFFFEFFFFFEFEFCFFFFF8F8FBEAEAF3D4DAEEBBDDE8B0E5D3A5C7AB83
9E8B6193906391A5748E9D725D472FAB907DD9D7C2DBFCDF69B9926EB595E0E5DF8E7978
B5AB9FFFFFEAFDFDE1FDFFE1EDF6CBDCEAB7CFE1A5C6DC9B8BA25AC8E096C8E094CBE397
D8EEA581974EAFC37CD9F1A7CAE99BC8EB9BC8EB9BC8EB9BC8EA9DC9E99DC9E99ECAE89E
C9E79FD2F0A8CAE8A2CCEAA4E0FDBADCF9B6CDE8A5CEEBA8D3EEABC3DE97C2DF8DDDFAA6
D5F0A3BFD89693A776000A006B7D55CBE1B0D5F0ADC7E698C3E58FC2E591CBEDA3C7E29D
CFDE99A3AD6889944FA3B06AB4C47DA0B46CA9BF76D6EEA4C8E096CCE49AD0E89ED1E79E
CBE198C9DD95D3E49DE0EFACD8DFA9DAE1AEE9F2BDF9FFCCEEFCC1D2E4A6C9DD9ED1E7A7
D9EDB0C2D59DD2E2B1DCE9BDEEF6D1B7BC9CC0C3A8DEE0C8EDF0DBFFFFECD1D4B9D3D7B6
DCE0BDE8EEC8CED9B1CBDAB3D3E4C0EEFFDFF5FFE8F3FFE1F8FFDFE0E4BFCDC9A3727049
454D26F2F6D5A89680504122596428CEED9FBCEA92C9F2A6A2AD83130C001507009C938C
E9F2E1F4FFF5F8FFFFDCF7FE5190870C5542366D5AD1FDE6E7FFEFDBFDD88EA97ED7E6BB
EAEAC4CACBA9CCDBBA84A38419432BE7FFFDF3FFFF96AFB34B8B8B1E68678EC4C4D8FFFE
2559431F3D2146361CE7D4ACCADC9ED1ECA5C9D291E8DCA8957350A67D677D5C4D73584F
E3D0C9FDEEE7FFFCF6FFF9F6F8ECECFFFAFBFFFBFFFFFCFF
C1F5A0B8E594D2F1ABD4E6A8ECF1BBCED19A7B8347DCEDA7C9EB97B3E085CAFBA0C6F3A0
BADE98D6EDB76B734C0006009DA772D3E1A6D5E2ACFCFFD8FCFFDDF5FBDFFEFFF3FEFFFD
FCFAFFFDFBFFFCF9FFFBF9FFFCFAFFFCFBF9FAFAF0F6FCE2E8FACAB3B681B08562A06F4F
68502C58562F6B774F757958C4A394EACCC1CDDAC6B4EDCC2283589BEBC8FBFFFBB49F9C
9E9683FDFEDFFCFDDBECF3C9D3DFADCDDFA5C8DD9CBCD38BB3CD83CBE699CBE697CDE899
CCE4988AA258BDD38BCDE79DC9EA99C6EC99C6EC99C6EC99C6EB9BC8EA9DC8EA9EC9E99E
CAE8A0D4F2AACCE7A2D0EBA8EDFFC6E8FFC1D1EAA9D1EBAAD4EDABC9E39CC4DF8EDBF7A3
CDE599C5DB9A7F9362000A005B7047C4DAA9CFEAA7C8E799D0F49DC2E893CCF0A6CDEBA5
DEEBA6D8DD9AB8BF7BA1AC67ABB872B7C780B1C57DACC27992A85FA7BD74C5DB92D9EDA5
DAEBA4D0E19AD0E099DAE4A5DEDDADE5E2B9F3F2C6FEFFD2F9FFCDE6EFBAD3E0AACCDAA5
CFDBA9A8B486B9BF99C9CDACE5E3CAB2AD9AD6CEC1FFFFF3FFFFF6FFFFF4DCDDCDF0EFDA
F6F6DEE3E6CBE3E9CDEFF9DEE6F4DBF6FFEEF7FFF1F9FFEFFFFFECF3F1D8DCD5B8646847
86A480C9DDC1B9A396583E23ADB86CC4E685CBF69DC1E59BA6AF822F281513080E6A5F67
F1E7DEFFF5ECFFFBFFF9FFFF95BDB26898887FA097CAE5E0D8F6ECEEFFFA83957DB8B89C
DCC5A5CAA986B39D78B3AA89929C83E4F4E9F5FCFF95B0B9034F4F47A09CACEEEACFFFFF
74B0973B60414A3C1FBEAB81CDE0A0DFF9B0E0E2A3DFCB998C614187524092615AC7A19E
FFF8F4FFF9F7FFFAF9FFFCFBFFFCFFFFF9FDF8F3FAFFFDFF
CBF8A7B1DA8CD3F1ABD7E9ABC7CF96DFE4AC9BA367CDDE98CDE99CC5EB98CFF9A5BEE799
C2E2A1DAF1BB5C6840060E00B3BD8BD1DEA8CFDBA9FCFFD8FCFFDDE6F0CEF5FAE6F6F9F0
FFFEFFFFFCFFFFF8FFFFFCFFFFFDFFFFFEFFFFFFFAFBFFEFE4FDD36C754A6F4B33C19884
D1CEAFD7E8C8F1FFEDFFFFF3FFF6F1FFF4E8DAEFD0A1E0B53C9D70B7FFE2DEEAD6AF9E8E
8A8065F8F5D2F8FED2E2ECB8C8DA9CD0E7A3D3EDA4C7E396BDD88BCDE89BD7EFA5D8EEA3
BED4899AB266D1E99BD0ED9DC8EB99C6EC99C6EB9BC8EA9DC9E99DC9E99ECAE8A0CCE7A0
C5E09BD1EAA6C4DF9CCAE5A2EBFFC3E4FFBEC8E5A2C8E5A2C7E29DD4F0A6CBE896CCE997
C1DC8FE4FDB998AF7700130063794ACAE3ACCDE8A5C5E496D5F6A5BFE290C7E99FCBE6A1
CDDD9CDEE9A7D7E3A1CCD994D1E19AD9EBA1D3E89DCFE497C5DA8FA6B86E899A53889851
97A3619DA866969F6091945F625A35776C4E918B69ADAB85C6C8A0D2D9ADCCD8AABECB9D
ADBA8ECCD8B0FEFFE6F5F7E1FFFFF1FCF5EDFFFCFAFFFAF9FBF7F4FFFFFAFBFDF2FFFFF4
FFFFF3FAFEEDFBFFF3F1FCEBF9FFF6F4FFF1FCFFF6FFFFF4FFFFF1FBF4E2FDF2DE9C9C84
CAE7C8ECFFE88A7A6B1E0B00D6E29AC0DE86D5F7AAC8E5A3A0A879F9F5DA6158590A0007
402E2AFFF6F2FFF1FBF9FAFFBDD9CBC8EFDC6F8D83E2FBF8EEFFFFF1FFFFC7D5BEBBBB97
756238E3C69CFFF7D5FFFBE1FFFFEA9C9F94D3DDDF86A9AB96E6D928837176B9A8B1E8D3
9FD4B63B5A38867B5B6D5B33575F26535B206256246B4D27CDA188FFD9CAFFF5EDFFF7F2
FFFAF7FFFEFAFFFEFBF6F2EFFFFEFFFFFEFFFDFCFFFEFDFF
C9E59BD2ECA5CEE59FC8DB99DBEAA9CFDE9DB0BF7EB1C580D9EEA9C6E099D9F2B0C8E0A2
D0E5ADCADCAA6A7A4D313C12BBC499CCD5A6DAE8B7F9FFD6F5FFD5D7E8BBD4E2BEF9FFE7
FFFFF3FFFDF8FEF8FAFFF9FFFFFBFFFFFEFFECECEAF7FFF8E9FFF17D9E814F4C439C9D95
82AE9582B7A3C9E8EDF7FFFFFFFBFBFFFAE5D8EAB8ADDFA4217746A7F2C7C8D9AFA79B75
736946F1ECC4D6DDA9DBEEACC8E497CCEF9BC8EB97BBDC8BA8C278D0E49FC0D08FE3F2AF
CBDF9799B261C8E68ECAED93CAED9DC8EA9EC8E89FCAE59ECBE4A0CEE3A2CEE1A1CDDFA1
D4E6A8D1E5A6CFE5A4CCE7A2CAEAA1C8EDA0C6ED9EC4EB9CC7EA9ACAED9BC4E795D2F5A3
C0E192C7E79CADCA870C29007C9657C6E09FCEE9A4CBE79DCDE79DD5EFA5C5DF96CFE8A4
C9E3A4C9E3A6CCE5A4CDE7A0CFE79DCFE799D0E795D3E694D3E494D4E295E1EBA4DFE6A3
B5B87F9D9D69A5A373B7AF8AB6A68FE1D0C0E1D5BFFFFFE6FFFFE3FCFFE1CEDEB7CADFB6
E4F9D2E1F5D2F8FFEDF2FBEAFFFFFAFFFEFFFFF9FFFFFBFFF1F0EEFEFFFBFAFFF9F9FFFB
EFFAF2F7FFFBF3FFF9F7FFFCF8FDF9FAF9F7FFFEFBFFFCFAFFF9F3FFF7F0FFFBF1A9A08F
F2F8DEECF5D828260D626343DDEBBACBE0A8CDE4ACCEE0ACCDD5A6DBDBB7B2AD99342C21
0E0500ACA1A5F6EEFDFBFFFFDEFAEEBEE5D0426E57DDFFF5EFFFFFF2FEFADCE8C2D1DFA2
B7C681E4EDB4FFFAE3FFFBF3FCECDF8B897CE0F7ED80B19EA6F4CD6BBD8F7BB38CC2E8C3
D0EAC5929C77B3AB87AC9C7897876387704ED1AD93D1AB96DCBBACFFEFE0FFFFF1F4FFEE
FCFFF2FFFFF4FFFFF6FFFFF8F5F6F0FFFFFBFEFFFDEDEFEE
D2E7A2CDE39BC3D991DFF5ADC6DC94C8DE96ACC27AAFC47FC5DA97C2D796D1E5A8CCE0A5
DCEFB8D3E5B16476460A1700878F669BA279E8F4C6DAEBB7E5F9C4C8DCA9D3E4B8FBFFE3
FFFFEDFBF9EDFFFDFBFFFDFFFFFBFFF3F2F7FCFFFFF0FFFDBFEAD7002715000502435350
3965542D60571E3F528292A9FEFFFFFCFFE7D0E5ACB6E4A4479968ACF3C7D6E7B3A59967
61532CF6EFC5D3DBA2CEE49CCCEE98C5ED94CCF49BC6E997849B55A3B3759EA96FC1CD8F
BDCE88A2BB6AC7E88DCAEF92C9EC9CC6E69DC6E49CCFE8A4DCF2B1E7F9BBECFCBEEDFBC0
DCEBB0D6E8AAD0E6A5CBE69FC9E99EC7EC9EC4EE9CC4EE9AC9EC9AC3E493C6E796CBEC9D
CDECA0CFEDA3CEE9A2C5E099BAD38FD4EDA9CAE49DD0EAA3C6E097D1EBA2CFE9A0CEE9A2
CBEBA8CBEBA8CCEBA5CBEBA0CEEB9BCEEA96D0E894D1E7942A3B008490469FA5658E9158
DAD9A9E4E0BAEAE4C4FFFEE6FFF3E7FFFBF1FFF5E7FFFFEBF6FCE2E6F4D3D2E6C1D8EEC8
F2FFE8EEFFE8DBEDD7F8FFF6FCFFFDE6E5EAFFFCFFFFFBFFFFFEFFFEFFFBF9FFFBEFFAF6
F5FFFFF3FFFFF5FFFFEFF9F8FEFFFFFFFEFFFFF5F7FDEDEDFFFAF8EFDCD88D7A73B5A79C
FBF6E34E5038BDC7A5F0FFD8E0F3C5D4E8B5D2E4B2DBE9B8EFF6CAABAB87DAD6BDCAC2B5
403835040003928F9AF3F6FDF4FFFBEBFFF654846A447560E6FFFFEDFFFEBED1A3DDF1AA
C7DF93EFFFC8FFFFEFFFFCFAFFFDEF8A8D78DCF9E381B99CADF9D2A4F1C5104920B9E2BA
BED7AFB3C49AD2DDB2FFFFD9FFFFDDFFF8DEFFF6E6F8D2C9EED2CEF8EFEAF1FEF7F1FFFB
F5FFF0FAFFEFFAFFEFF7FEEEFEFFF6FEFFF8E5E7E2FEFFFB
CCE39BCCE49AE4FCB2B5CD83CAE298F7FFC5395107CFE79DCFE69ED6EDA7D1E7A6C5DB9D
CDE2A7BED39A647843031300666C46424621FEFFDCDCE9BBCEE0B0CDDEB1CEDDB6FAFFE5
FFFFF1FFFCF5FFFEFFFFFDFFFCF9FFF5F5FDF9FFFFE3F7F5133C2E779D90EBF7F5FFFFFF
AFB0AA3C4446EDFFFF4F6678F2FAFCF6FFECC8E8B6B8F2B862B88B8DD4AADBE5B3A3915F
5E4F26F5EEC2DAE2A7C9DF97D3F5A1BFE78ECBF39DCAED9DCCE2A1D6E5ACD2DCA7DCE7AF
D7E7A8C8E096CFEF9ACCF098CAED9DC5E59AC4E29ACFEAA5E1FAB6F0FFC5F6FFCBF6FFCB
DCF0B1D7EDADCFE8A6CBE69FC8E89DC8EA9DC7EC9CCAED9DD5F0A3BFD58ADDF3A8CEE49B
C3D790D6EAA5CADF9ADBF0ADDFF4B1DAF1ADC3DD96D4EFA8C1E196C8EA9ECFF1A4C5EA9C
CBEE9ECAED99CAEC98C9EB95CBE993CCE893CEE794CFE6984F6019AFBD7FC2CB96969C70
FBFCDAFFFEE5FDF8E4FFFEF1FFFEF3FFFEF3F2EFE0D6D9C4DBE5CCCFDEC1F1FFE4F4FFE8
EFFFE5F4FFEDF5FFF1F4FFF4F3F9F5FEFFFFFFFDFFFDF7FFFBF6FAFCFCFAFCFFFFEAF3F0
F7FFFFE9F5F3F7FFFFF9FFFFF4F6F5FEFAF9FFF8F6FFF6F3FFF2EE6B5A528D7C72F3E7DB
0F0D01CBD0BCE3EFCBCFE1AFCFE8A7C8E29BD5EBAACFE1A7E8EFC6FFFFEAD3CCC2FFFCFB
FBF2F5040000030000595854F8F3EFF8FFF87AAA9240816966A59CDCFFFFC3E4B5CDDFA1
D3DC9DF6F8C7FFFBEBF9F5ECFFFFEC839474C6E5C588BDA18AD7C3A9FCEA3F836EDBFFF8
E0FFEDAFDEB0BDECB6BCE5ADC5DDABFFFFDFFFFDE8F3D7D3F4DAE3FFEFFFF3F1FFF9FFFF
FBFFF4D3DDC2D6E0C8C1CAB5D2D9C9FCFFF6F4F9F3FCFFFD
CCE69CAAC67B6E893CA1BD70597427839F52CCE79AC7E396CAE49AD8F4AACEE7A3C7E29F
D0E8AAD5EFB2C2DAA096A8742E320DEDEECCAEB58CBFCA9FDBEBBEC5D6AAD1DFBBFBFFEA
F8FCEDFFFFFAFFFEFFFBFAFFFCFFFFF9FFFFE3EEF2788C8BA3C0BCEDFFFFF8FFFFF7EEEF
FFF5F4A8989B3B535D6C8D96DCE8E8FBFFF4DDF7D2CEFFD673C5A1579D78D2DEACA1945F
605126CFC89ADDE5AACAE098CFF19DBFE78FC3EA97CAECA0D1E7A9D2E0ABD6DFB0D2DCAA
CFDEA5CEE5A1C5E496C4E795CAED9DC8E89CC6E69BCBE9A1D4F2AADEF9B4E0FBB8E0F9B7
D5EEACD1ECA9CDE8A3CBE69FCAE89ECBE99FCBEA9ECEE99CD3E59BE3F0AADBE8A2CFDC97
F7FFC0CED9977A8445A6B272B6C685D3E8A5C2DC95D3F1A9C9EB9FC2EB9CC3EE9EBFEB96
C7EE95C8EC92C8EB91C8EB91C9EA93CCE995CEE99AD1E8A0C2D595D4E3ACE4F0C2CCD4AD
F2F7D9F3F5DFFFFFEFF5F6E6F6F9E8FEFFEDE5EAD3C4CFB1D1DFBED0E1BDF5FFE3EEFFDC
F5FFE4EEFFDDF8FFECF2FEEAEFF5E9FEFFFBF3F3F3FFFEFFFFFBFCFFFEFFFFFFFFFCFFFF
F9FFFFF9FFFFF2FBF8F6FCFAFEFFFDFFFFFAFFFEF8FFFDF4FFF3EA6A5C4F756556483F30
020200F6FFEAE7F8CECAE2A6D6F2A7D4F19FC5E093C5D99AEFF7D0F6F8E3F9F1EEC1B6BA
F4EBEEDFDAD7030000171308E6DBD7EFF2EBD2F9E674B39E50988CB7FAE8BCEBBFC3DFA5
D9E0AAF6F3CAFFFEEFF7F3E7FAFFE5A5BC92B3D4A9B2E0BB65A38A3D7D6C5F9983D0FFEA
DCFFEF9CD9ADA8EBB59FE0A888BA87E8FFDEFCFFE7E3D7CBE3D1D1FFF3F9FFFDFFFEFFFB
F1FCDCCAD7ABDCE8C0D3DFBBD5E0C0FCFFECFCFFF1F4FAEC
ADC97CBFDE90BAD689CDEC9EC3E090CCEB9BD3F0A0CFEEA0C7E396CDECA0C6E298C3E199
C6E19EC9E6A4D7F1B2D6E9B2A1A37E181500747651B9C297E3F0C4D9E8BDCAD8B4F9FFE8
FCFFF3FEFFFBF8F9FDEFF2F9F9FFFFF5FFFFA3B5B9596B6FDFE8EFF7FCFFF9FFFDFEF4F2
FFF3F3927A7A163A386EA09DDBE7E5FFFFFAF7FEEEEDFFF685C9B4367958CCE7B09E9F63
5B53249B9565D5DDA1CDE39BC7E995C7EF99BEE596D1F2ADCDE2AACDDAAEDCE4BDD7DFB6
D4E2B1D8EDB4CCE9A6D2F4A8C7E899C9EA9BCBEC9DC9EB9EC8EA9EC7E99FC7E99FC8E7A1
C9E8A2C8E7A1C9E7A1CCE7A0CFE9A0CFE9A0CFE79DCFE39BD8E39ECAD18E8E93515F6424
686A2B939458AAAB718F93586E763AD3E2A1CAE19BCCEAA2CDF2A5BEEB9AB6E795C1F19B
C9F097CCEF95CBEE94CAEC95CBEA9ACDE99ECDE8A1CFE8A7D6EBB2C2D4A2D0E0B3DDE9C3
E0EBC9F7FFE3FCFFEAFBFFE8F8FFE4F7FFE1E3F5CBD3E6B8D3E7B6C9DDA8DBEEB7C5D8A1
CDDEAADDEBBAC8D5AAE2ECC7FBFFE3FDFFEBFEFFEFF5F5E9FFFEFBF6EDF2FFFDFFFFFEFF
F7F9F8F7FBFAF5FAF6FCFFFBFCFFF8F8FAEFF9F5EAFFFFF1FFF7E6A297853225127D7761
FDFFEDCDDABED7EDBCBBD896C3E493BEE089D5F4A4E1FAB6F0FDD1EFF3DAFDF9F0FFF8F6
9F9795E7E3DAFFFFF1302E1F05020030352FB3CBBEBCE6D84A867E478A7985C39AC4F3BF
D1E4B6E9EBC6FFFDEFF8F1E1E4ECC7CAE1AD93B67ED0F6BDBFDFADC3E0B2D1ECC3C7E5BF
BBE5BFD7FFE8ACF4CC65B2887CBE98BCEECBE1F8DBDADEC3D0CBADDCD6B2E6E9BECDD7A2
CBDC98D5E9A1CBDF9ACEE0A2D7E8B1C6D4A3CEDAB2FBFFE3
C3DF94DFFBB0DFFBB0C4E095DBF7AAD3EFA2BFDB8EC9E598CDE99ECCE89DD0ECA2D0EBA4
CDE8A5C8E3A0C3DD9CCADDA5A0A07A070200A7A781979E72C9D6A8BDCDA0EAF9D2F2FFE1
FBFFF1F8FFF5F1F7F5F7FFFFF5FFFFEEFFFF7F9797617375FEFEFFFFFCFFEEF0EDFFFCF6
FFF2EE79655E54847469A697E2F5EFFFFEFDFEF5F8F7FFFF8BC0B828674CCBF1B692A15E
625F2C9F9969D7DFA3D6ECA3C7E897CEF5A2BCE295D6F6B5E3F7C4E4F0CAEEF5D4E8EFCE
DAE6BECCE0AFBEDA9FC3E49FC3E397C8E998CCEF9FCAEF9FC5EA9CC1E79AC2E89DC4EA9F
C2E69CC4E69CC7E79ECDE8A1D2E9A1D4E8A1D3E49ED3E09BD9E09DE3E5A6939556929256
CDCB90E9E4ACEAE5ADA8A66D4A4E13DAE4A7D1E4A2C7E29BCCEEA2BCE797B6E893C6F6A0
C7ED98CBED99CCEB9BCBEA9ECAE8A0C9E6A3C9E3A4C8E1A7CAE1ABD3EAB6CDE1B0CEE1B3
DCEDC0F3FFD7F4FFD8EFFFD5F2FFE1E3FED5E5FCD0CDE3B5CCE0AFCADAA9D8E6B3CED8A6
D2DAA9D4DBAFD8DDB5D6DAB7FCFFE3FDFFE8EFF2DDBBBCAEBAB1B292878DE6DDE2F4EEF0
FFFEFFFFFFFDFEFFFBF9FCF3FEFFF6FBFFF0F9FAE8FFFFECFFFCE67770560D0300908B6D
F2F9D8DEF0C6C6DFA6C7E6A2DBFFB0CAF09BC1E293C0DB96D9E9B8FEFFE3FFFFEDF6F0E4
DFD8CEC8C4B8FFFFF1B5B6A80A1006060D06697069CDE0DA749B98477F72549672B5F0C4
CEEDC4E4EDD0FFFDEDF0EBD7CBD3AAD8EBB37E9859CFE8A4D7EBA4D9E9A8C0D19BD5EEC4
C8F1D385C0AA56A79464BCAC9CEFDF9EE1CFC9F3DDD7EFCFE8F4C4D6E0A1D4E798C8DE8B
D7EE9CE2F9ABD2E89FD0E49FCFE1A5CDDEA8E4F4C7F0FFD6
CCE5A1CAE39FCBE59EBED891C7E198C5DF96D4EEA4D2ECA2C6E097C5DF98DBF5AECEE7A3
C9E2A0D3ECABC7DFA1D9E8B1DFDDB46F6A4458592D939B6AD3E1AEE0F0BFD2E3B6F5FFDF
F1FEE4F2FDECF8FFFAF7FFFDF2FFFFD6F0E77492882A403DDFE1EDFFFCFFFFFFFAEFE7DA
FFF7EC6A6351CDFFE72C6E53E9FFF7FAFAFAFFF0FFFFFCFF81A6AC1E533FC6EFB5859F58
62612BD3CD9BD8E1A2D6ECA3CCED9CCBF2A1BDE39ADBFBBCF7FFDDFBFFE4FEFFEAFEFFEA
F5FFE0D8EAC0CFEAB5D0F0AFC5E59AC8E998C9EC9AC8ED9DC4ED9EC4ED9EC4EFA0C5F0A1
C2EB9DC5E99FC8E89FCCE7A0D3E7A2D6E5A2D7E2A0D6DF9EE1EAA9767C3E65662ADCDBA2
EBE9B0CFCA93DFD8A28F8A5356531CDCE0A5D4E0A0CEE39ECBE79DC0E597C6F09EC4ED9E
C6E69DC9E6A3CEE8A7CEEBABCFEBB0CEEAB0CDE8B3CCE7B2C6DFA8D6EFB8CFE8AEBBD596
D5F0ADD5F0A9CFEBA1CCE8ABE4FFDAE1FBE2F2FFEF7F91777C896DA0A98CCACDB0B2B195
B3AF945B553F78715F736D5F8F8B825D5A555A5653938D8DC5BAC073666D8D81854F4448
716967B7B2AEFFFFF8E0E2D5D0D4C3D4DCC5E4EAD08B90726D6C4E211C00514827B9B68D
D7E4AFC6DEA0CAE7A7D3F3B0B8DD97D2FAB3B6DA94DAF9B6E1F6BBBFCD9ADCE1B8D9D8B9
C7C2ACC5C2B1FBF7ECF9FCF3AFBFB47A877E060000130A0DA4AFB1B2D3CC569077D8FFF3
DFFFEAF2FFEFFBFFF1EFF5DBCFDCAEDFEDB2929B5AC8D289CAE08DD6F1A4C6E2A7B4D8B2
98CEBE39838432909C46ADC09FFFFF72C6D17CB7B56E9882BFDFAEC1E196BEE886CEF693
C0DC91BED496D3E8ADD1E3AFC9DAADDFEFC8C2D1B277856B
D7EBAEC3D798D2E6A7DFF4B3D0E5A4CADF9CD4E9A6C6DB96D6EBA8CEE3A0D3E8A792A766
667A3B6A7E41566A2F6D7A4469683A1713007C7E4C8D965FE0EFB4C8DCA1CADDA6F8FFDC
F8FFE4F8FFECF6FFF0EBFEEBEFFFF5E5FFF0CAEDD74F705FE4F4F4F1F6F9FFFFF4FFFEED
B19E8D696853D3FFE3448461E4FFF4F3FFFCFFFAFFFEFBFF7592A0164034C5EAB4889F59
4C4B15F7F1BDCBD495C9DF96CDEE9FC5EC9DC1E6A0E2FFC6F7FFE1FBFFE8F9FEE8FEFFED
F7FFE6D0E2BCC8E2B2C5E4A8CDEBA3C9EA9BC5E898C3EA99C3EC9DC4EF9FC4EFA0C3EE9F
C8F1A3C8EDA0C9E9A0CCE69FD3E4A0D7E3A1DBE1A1D8E1A0AEB8797B87478E965ADBDFA4
D3D49BDDDAA3F2EDB689824C6A652ED6D59DD2D89CDCE8A8CFE39ECAE49BD7F6AABEDE93
C9E3A2CDE7AAD4ECB2DAF3BCDEF6C2DEF9C6DDF7C7DCF7C4E0FBC6CFEBB1DBF8B8C5E39D
D8F7ABBEDE8BCDEE97C3E39ADCF8D0EEFFF1F4FFF10F1D06000500363820716D54352D16
5245321707000D00000B00002F24201006049A9192FDF4F7FFF7FBFFF6FBFFFAFD756767
100503837A73FBF7EBF3F6E3DBE3CB5D684A646F4D3D4722656A426D6B44484019C8C696
D9E8A7CFE69ECFEDA7C4E4A1C1E8A5B7DE9BD3F8B5C1E19EC3DC9BDDEFB3CDD6A1E8EBBE
C6C6A4D4D2BBFFFFF1FEFFF6F7FFF8F2F9F10F00000D00002A2C29D6EDE341725FD0FFEE
E8FFF9F0FFF8ECFFEBDCEFD1CAE0AFCFDDA0A29A5BB6B26BD1E89ABEE49BCAEFB9C2EECD
79B1A657A0A63E99AB3797B059B0CB3B8497447379264536BBD0A9DCF1B0C9E58ED0EE94
D5EEAACDE2A9D9EDB8C7DBAAD7E8BCCADAB56F7E5F536245
D1DEA9D6E3AEBAC7928E9B655C69318694597B894CB0BE81A6B4775C6A2D3B490E2C3A00
4A571F606D356B78423D46113D3D0B565421B9BE84929E5ED3E7A2CFE6A0CBE1A0F7FFD3
F2FFD5F7FFE1F5FFE6EFFFE7F0FFECEBFFECDAFFDDBEEBCA719D8C608073A9AC99A79B85
594E3AD7DBC2BCE0BAB3EAC0D6FFE9D7FFF2F0FFFFF2FFFF88A5B788A7A1D5E8BA90995A
9B9561EEE8B4D8E1A2CFE59CC8E99AC4EA9DC2E7A2E5FFCBF1FFDDFBFFECF2F7E3FEFFEF
FAFFE9CCDDB9CEE8B9C7E6ABCEECA6CAEA9EC6E89BC4E99BC5EC9DC3EE9EC1EC9CBFEA9A
C2EB9DC4E99CCAE89ED3EAA2D3E29FE1ECAAD2D797B3BC7B516422809753DCEFAFC0CE90
E9F1B6E4E7B0CECD97D5D29D97915D4D4A135C5D249EA267D5DE9FD2DE9CDCEBA8CEE29D
D5EBABC3DB9FD9EEB5EDFFCEF4FFD9F4FFDCEEFFD7F3FFDBEFFFD7F2FFD4DCF9B9C7E59D
C9EA9BCDEF99C7EA90CFF0A1D1EDBACEE4BED2E2BD040E007E825FFFFBD8BAB08DB3A483
BBA88ABDA990B7A38BB19F8BBAAA9ABFB1A4A3998D7F756C7065638F8181584848A2938E
EEDFD8CBBFB3847F6C72745C6D785890A07B92A379E1F1C4CCD5A6B9BB8C959164686731
D8E39FD0E59AD0EAA3C8E7A1E6FFC6E9FFCBDFFFBFC2E29FCEE9A6CCE1A0D2E0A5DEE6B3
D0D5ACACB08FACAE96D1D2C0CFD0C2FFFEF4C5B6AF8C8278121D0C05200D000C0064837D
ABBBBBF5FFFFEEFFF4CEF0CDBEE0AEDEEDB4A38D54C1AE74F2FFD4B5E4B07CA67E5B866A
4D7D6D558E870448477CBDC190C5CBCDEEF5A8ACAF5A4B469B806FFFF6D8F7E5B7E5E0A8
E9F7B9F0FFC6DDF3B5D3E8AFD2E4B08B9D6B68794CD0E1B5
525B2EA1AA7BD2DBACD9E3B158622E111B00000A00010C00000A003F4A10BAC58DE7F2BA
DCE6B1C7D19CDDE7B3D8E1ACEDF0B942460B9EA967DFEFA8D2E89DC0DB8EE0FAB0C1DA96
CFE7ADD0E7B3CDE3B5C6E0B3C8E5B9C9EDBDC0EBB6AFE0B177B3915F8B70D4DABE534E31
D8DCC5D4E4C7D8F7CDABDBA73E854D84C8A3E6FFFFB6CBE6526D80BED7D3C9D5AD9A9D64
8D8652EDE8B1CED798CEE49CCEEEA2C5EB9EC7ECA9C2E0AACDDEBAFBFFECF6FBE7FEFFEF
FBFFEAF7FFE3F1FFDBC8E7ACC7E4A1CBE9A1CDEDA4CAECA0C3E89BBFE598C3EA9BC7EE9F
BFE497DEFEB3C5DF96C5DB93E0ECAA8D96555E632356611FC7E09CBCDA94D5EEACD1E6A5
C0D092D4DFA5EAEFB9040700070500F0EFB94C4B1554531BD1D097E3E3A7EAEBAFCCD294
CEDE9DCFE4A3CDE1A4D0E5ACD4E8B3D1E7B6D0E6B7CBE3B3CFE7B7EDFFD1EFFFCFC9E6A6
C9E6A3D1F1A6CFEFA3BAD892BED4A5D8E8C4FBFFE30006008F8C6BE2D9BA625336645035
654F375B452E644D3B6E584A5B473C4D3C327E7067C6B9B1FFF4EEFFFCF6FFFBF467564E
5A4A3DDACDBCFFFFE8EFF3D2CBDAB1D6ECBDC2DAA6CFE3AED4E3ACD9E0AAC9C6936D6A33
D7DD9DDEEDA8D3E9A1CBE79DD0F2A6E2FFBBDCFFB7CFF3ABD1EEACD4EAACD2E1AAD5DFAD
DAE3B6DBE3BAEBF3CCFFFFE48F8472AA9A8DFFFDEDF3F1DC849777D2F1D2001306000707
6F7782E2EBF0F0FFF8DBFADAC2E3B8D0DEADD2BC8AE9DBAADBFFD1AFEABE5C8E69001200
B0DEC198CDB17EB69BD9FFF4E6FFF7EFFFF09F91865E3D347C5246C19686FCDCC5DECEAD
EEF6C7F7FFD8D4E8B5CDDFAFE3F4C8627349CEDFB5D3E3BC
BAC398C4CDA2B9C2957D8657303A08606A366E79417D8850A1AC72ADB87ED7E2A8DDE8AE
D4DFA7CFDAA2DFE9B4D4DDA6D6DEA2CCD594DCECA5C3D88BCBE793C7E792C9E996C8E79B
CDE6A2CBE3A5C8DFA7C5E0A9C6E5ACC4EAADC3EDADBDEFB2A5DDAE93BD9769754D808863
8AA4875174535E804E1D4D0F6DB97191D9A7E0FFFF283E56354F60CCE2DFD7E5C1999D6A
635D2BDED9A2D4DD9ED5EBA3C9E99DBBE196D0F5B2C0DEA8CCDEB8FBFFEAFEFFEDF9FEE8
FAFFE5F4FFDCEEFFD4C6E6A7C9E6A6CCE9A6CDECA8CCEBA5C8E9A2C7E99FC9EB9FCDEDA2
CAE89EC3DD94D5EBA3D3E49ED8E4A24B54138B9153B6C282D5F0A9D3F5ABC1E09AD9F6B3
D5EEADCCE0A3EEFDC41924004F5620C6C994E0DEAB6865309E9763DED49FDCD09CCEC98F
9DA863D2E69ED3E7A2CFE2A2D0E2A8CBDDA9D7E9B9CCDFB2E6F8CEDBF0C5E6FBD0CDE4B8
CDE4B6BED6A6D3EBB9D2E7BCE2EFD3C1C5B4EFF0DE040100676050BCAEA1675549F0D9D1
FFF8F3FFF4F0FFF2F3FFF7FBFFF7FFFFF6FFFFF8FFFFFAFFFFFEF8FFFFF3F3E7D9FFFCED
5E4F3CBAAE94FDF8D8FFFFDDEEFFD0F2FFD6F1FFD3CFEBAECEE0A4CDD79BE9E8B097925B
5F5D2ACCD197DDECA7CEE595D3F49DE0FFACBDE38EC0E598D5F3B5EDFFD0F7FFDCF9FFDD
FBFFDCF3FFCEDDECB1D5DCA8DDCEB1CFBAA7FFF9E1FFFFE1B8D4A1B0D7AA254C39000909
0002121016225F6960F2FFE9F0FFE5E2ECC9F8F1C58D9564609665337B4B478556B2EAB9
B8EDB979B0777AB67AAEE6A9C3ECB497AD7EB9B38FE7D2B77C624B5E4833FFFEE8FFFFEA
EAF3DEF0FDE9F8FFF1E0EBDA6C77667D8878F7FFF2F9FFF4
646F44636F41000A005D6937D5E2ADDFECB6D9E6AED8E6ABD2E0A3C9D79ACFDDA0D3E1A4
D5E3A6DBE9AEDDEBB0CBD99CC9D597E6F5B2D6EBA0C2DD8CCFF099D0F399C8EA93C9EB97
CCE89ECCE5A1CEE7A6D1EBACCDEBABC4E9A4C0EAA0C3EEA9B9E0AB4161307789575B7143
5D8668558462B6DFA7B9EBA2B3FBA7ADF1B4C0E4E000051A637F8BE1FCF7F5FFE8AAB384
635F2FC6C08CDAE3A4D5EBA3C4E498BDE398CEF3B0CBE9B3D1E3BDFBFFE8FEFFECFEFFEA
F0FCD8D0E3B5CCE8ADC9E9A8CAE8AAC6E2A5C3DFA2C5E2A2C9E6A4CEE9A4CCE7A0C9E39A
CDE49CDFF5ADD2E39DDBEAA54A5614A0AB69E4EDAED2E19EC3DE97CFF1A7BFE197BAD993
D3F2AECAE7A5F0FFCAE1F5BAD5E4ADDEE7B2F4F6C4B4B0805C5423736536574515766B35
525916BECD88D4E3A2D2E2A4D1E0A9C6D4A3D8E8BBCDDCB5B4C4A0C6D5B6DAEACD9AAA8F
97A78C98A88D9BAE9259674D696E586C6B5733301DA39E8BFFF9E884786A8E7D73FFFAF3
FFF5EFFFFAF6FFF9FBFFF3F7FFF1FCFFF8FFFFF9FFF0E5EBFFFFF4FDFCE7FFFFEAE3D7BF
54462BCABF9FFFFFDAE1E9B8EBFFC9D3F3B4D6F9B5C9E8A4D7EEAAD1DB9CE5E5A7A09963
4F4719A7A373D4DA9ACBDC8CC7E488C3E787BEE58CCDF2A4D4F2B6E6FDCFE8FAD4E2F2CB
E6F8C8E3F7BCD1E99FCCD896FFF7CECAB99BD5CFABF2FBCCD7F6B3C7F0B46B977C769A9A
ACC3D3556171000200000200000200717662DFE7C2E0F7CB518255084315AFDEB2BDE7B9
CBF3BFA8D09B5B8B4F57834896B47EEAFACBF1EBC9F3E2C8E4CFBCB8AB9AD2D3C1F0FBEA
F0FAEFF2FCF3D7E1D8B7C1B88E9890FBFFFBFBFFFBF3FAF3
000C00000E0071834FDAEDB5C7DBA0CCE0A3D1E5A6CADF9ED2E7A4D8EDA8DBF0ABD5EAA5
C5DA95C9DE9BD3E8A5D9ECAADDF0B0C7DC99BCD68CD6F5A5C9ED95C5EC91CDF49BBDDF8B
CCE89BCCE69DCFE6A2D0E9A5CAE8A2C3E59BC0E798C8E89F8C975D727B44B5CF907EA570
1E4B2EA1D2B4B0E2A5C4FBA8AFEF91BBF3ACBDDBCF142B396D9096E6FFFFEAFFE8E1F2C5
9B986BB1AB77D5DE9FC9DF97C8E89CCFF5AAC0E5A0CAE9B0D2E4BCEFFADAFDFFE7FEFFE6
F1FED3CBE0A8C2DF9CCDEEA9C6E4A8CBE6AFCDE9AFCFE8AECCE4A8CCE2A2CEE19FD1E29E
D8E7A2D9E8A3CAD792BECB864A5614ACB876C5D18FD8E9A5D1EBA1CBEA9ED7F7ACBDDF95
BFE09BD2F5B1E7FFC6E3FFC3BFD89ED9ECB5C3CB98D4D6A5999264A39469B29F74948659
6A6D38D1DCA4E0EAB6DEE8B6DEE7BCD1DCB4E1EBC8D1DABB7B856C6D76616D7867364131
394338313B32323C330004000708001C1A00302E08E6E4BEACA883625E3BFCF6D6FFF9DD
FFF9E2FFFBE6FFFEEFFFFEF1FFFAF3FFF9F4FFFDFAFFFFF6FFFFECF8FDDFFFFCDFB7AE8F
625533D9D0A7D9D8A8DCE7AFD5EFAEBDE19BBFE59CCBEFA5D1E8A0D2DF9ADEDD9DC1B680
76643C61522797955ABDC87CDCF39BC1E083D2F49DC5E79BCAE8ACCCE6B6C6DDB3C3D8AD
CBE2ACCEE7A5D0ED9BDEF5A7DBE0AADFDCB1999D6BC7D296C0DB8CCEF3AD9BC8A7477572
4C7684C2DFED040E0D0100000B050714150F677E6495B590D1EBC690A481677053D3D7BC
CED4BA9FA9903D4F37768973F9FFF1FDFBEEFFFAF4FFF2EEDDC5C3FFF3EDCBCEC3BFCBBD
CAD5C5C5CEBDEAF2E3757D6E9CA497F7FDF1FCFFF6FCFFF6
8AA169D1E9AFC0D89CC3DB9DC9E2A1C6DF9BDDF7B0CDE79EC2DC92C8E396C6E194D1EC9F
D0EB9ED8F3A6C9E399C1DB92C8DE9DD9F2B0CCECA3C2E797BDE58DC0E88FC8F097CAED99
D1EDA0D2ECA2D1E8A2CEE59FCAE69CC9E99DCAF09DD6EEA0A19C5CB0AC6FBDDE9789B67B
001400B0CDB7C7F7B9B4EC93BEFB94C2F7A7E6FFF5294C506C9D9AE0FFFFE3FFE4FBFFE1
B4AF859F9967D9E1A5CADF9AC6E69BCFF5AABDE29DDAF9C0F7FFDFFBFFE4F8FFE0E5ECCA
DDEABCD4EAACC9E79DC7E99FCEEBB1E3FECBF4FFD8F2FFD3DFF2BAD2E1A6D7E2A6E1EBAC
CCD594DEE7A4C9D28F364100A0AC6ACAD996D3E29FDFF0AAD0E69DCAE296CDE99ECEEEA5
C6EAA2C7EFA9CDF4B1AAD192D2F4B8BFDAA3DFF0BCE2E8B8D7D4A9F7EBC1F1DEB68C7C58
D8D5B2FFFFE3FBFEDFF4F9DBFBFFE4F9FFE5FFFFECF1F6E0EEF2E1B1B5A7A9AFA3BCC1BA
E3E8E2D7DBDAF5F9FAFFFFF4EDEDC9DDDBAA9C9B6B53522277794AD4D5A9F6F8D0F5F7D2
FFFFE3FEFEE2F7F9E1FFFFEDFFFFF1FFFFF3F3F3E9EEF1E0ECF5D8EDF5D0EEEECA59512C
62562EDFD7A9EFEFB9D2E0A2C0DE98CBF1A6CAF5A6CFF6A7C1DB91D7E49EE3E2A1EBDFA5
F6DFB3CBB689887D45585B18CFE092CFE897CCEB9DCCECA3C6E4A6C9E6AECAE5B2D2EBB4
D4F1B1C7E59DBEE08CCBE898D7E5A8D2DCA7C6D89A98B066A6C065C5E697E9FFECA7D1CD
60919F34626FBFDCD8F2FFFC5F5F6723262B0009002D4A2CCADAB3D9E0B6E3E0BDE0DBBE
DAD5BFF5F8E5DBE8D7E0EEE1EEF5EDFCF7F4FFF2F4FFE7EBF3D9DAFFF7F2A1A396F9FFF3
FAFFF2DCE5D4C0C9B80004007D8377FCFFF6FAFFF6F1F7ED
CEECACC3E1A1D5F4B1CEEDA9D6F6ADD2F2A7B4D586D2F3A2D1F39FD8FAA4C7E993C6E892
BCDE88CBED97C7E995D1F2A3DDFAB8B6D494BFE09BC9EFA2C5EF9BC1ED94CBF39BC8EB97
C8E497CEE89ECEE59FC7DE96C6E096C9E89AC8EB97CBE18F8E813B928B45C7F0A1ACD59B
5F5A56EEE7E1BDDEA5BEF598B4EF81B2EE94D5FFEB39756B85C9BEDAFFFFF1FFEEFFFEE0
AEA57E999361DCE4A8D3E8A3C5E59AC2E89DC4E9A4E0FFC4F7FFDDFBFFE3EEF5D3CCD4AD
C9D7A4D2E8A7C8E797C3E598D0EDB5E8FFD3F4FFDCF7FFD8ECFAC5D5E0A8CBD39ACDD196
E6EBABB0B5756B722F5B6421CFDC97EAF9B4BED28DD7EBA4D7E79ED2E49AC7DF95C8E69C
C0E49CB6DF99C2EFAAD5FFC1B7DFA1DCFDC4AFC692DEECBBDDDEB4EDE6BC82734C7A6B4E
FFFEF4FFFFFBFFFCF7FDFCF7FFFFF8FFFFF6FFFFF6FFFFF4FFFFF4FFFFF6FFFFF8F8F9F1
FEFFFAFEFFFBFEFFFDF8F9EBF1EFC9C3C1906C6B3B979968C0C394CBD2A6DBE3BAD5DFBA
FCFFE4FBFFE8FBFFEDF3FCE9F2F8EAFCFFF6FCFFFAF9FFF0D3E1C0C4D1A6DFE1B99F9A70
51491BF0EAB8B8BC81DCEBA8CDEDA2CAF3A4B8E592BCE694D0EC9FE2EFA7C6C582C2B477
A08751C5AB788778414F4A12D6E0A4DFF3B4C1DB9ACAE9A6CBEAA7CBEAA6C6E49EC7E59D
CEEEA5CAECA0C6EB9ED3F3AAC4D899DAF3B2C0E99DABD77EB3D66E7E9841F2FFE1DFF7F7
ABDCEB215F6A67A598B2E4D8DEF7FE9EAAB6000706000B006C834DCCE19ED7E5AAC6D09E
DDEABFEDFEDAF0FFECBFDCC0BED1BDFEFFF4FFF4EBE7CEC7FFE5DCFFFBECB7B29CF4F8E1
EFF6E6F6FCF2696F65343932C2C4BFFEFFFFFEFFFFFEFFFF
D1EEACBDDC99CDEAA7C5E49EC4E29ACEEEA2CCEB9DC8E998C1E090D0F29EC7E794D0F29E
CAEA97D3F5A1C3E390C8E799C2DD9AD2ECABD6F5AFB7DC8FCEF8A6C4EE9AB3DD89C8EE9B
C4E397D2ECA3D7EEA8D2E8A0D3E7A0D8EDA2CFE59AC6D2867C742CE2E298D5F8A4ADD08C
EEECD3D2CDB7C5E2A8C2F1A0B8EA89C4FFAD83CFA945948168AA8FBBE9CCE1F0D3E5E2C1
B4AB849F9969D2D79DD6E6A7D0EBA4C4E59EC9ECA8C4E3A7C3DBA9D3E4B7D9E8BDCEDEAF
D0E1AAD2E9A5C7E396CAEAA1C3DFACD3EAC0E8F9CFF1FCD1E9ECBFD0CE9EB3AD7B9F9A63
9C9A617C7D41A3A96BDBE5A6C5D395D1E1A3E3F5B7C6D89AD4E2A4D1DFA1F9FFCDF3FFCF
C5E2A8CDEEB7C3E8B4CDF2BFEDFFDEE7FFD7F7FFE1F4FED9FFFFDFF4EECA675A38AFA389
FFFFF6F2F2F2FFFFFFFFFFFFFEFEFEF8F8F8F5F5F5FFFFFDF5F6F1FFFFFAFDFFF9F9FCF3
FCFFF6FCFFF4F7FEEEFFFFEAF0EEC5999565555322E7E9B7D0D7A3D7E1ADDAE6B4CBDBAC
E0F1C5E1F3CDE4F5D3EBFBE0F7FFEFF8FFF3F2FFEEDEECD5D1E1BCDAE7BBDDE4B8CED0A1
5B5B2953531DC8CE92D0DC9ACADE97D1EBA1CFEBA0CFE79DD5E69FB2BC778383438B8345
B8A970BFB079D8D19ADCDCA6E2EDB5C5D79DCAE2A6D2ECABCBE6A1D0EBA4CAE69BC8E499
D2EEA3D0EEA4C5E59AC4E19ED1E9AFC4E0A3C0EC9FD3FFA4C2E678D7EF8F66703EE3F1E0
D6FEFEB3EAED88C7BC38746884ADB1B3D4DBA7C7C23D5D450010000010006B8047D7E7B6
CDD9B1F7FFE6EAFFE5DCF9DDDBF5DCF8FFF0FFFCF0FFF8EFDDBDB2D7BCABFFF6DDFFFFE8
C4C6B800020071746DFEFFFBF1F1F3FCFBFFFFFDFFFBF8FF
D1E7A6C8E19FCCE2A1CFE8A6CAE19DDEF7B3C9E09AC4DE97C9E09ACFE9A2D5ECA6CDE7A0
CAE19BCBE59ED1E8A2D2E9A1D1E29CD4E8A0CCE49AC6E295CDEE9FCEF3A3C6ED9CC3EA9B
CCEEA1BEDC92D3EAA4D8E9A5D9E4A2D9DE9EDEDEA00608009FA964C3D186DAEE99D0EA93
C2E394C6EAA4CBEDB1C8E7AEC2DF9DCBFCC48BE5C93791774F7E50BFD6A0D7E9B9EEF7CA
ADA97CA8A071E1E1ADD6DFA6CADCA0D1EAA9D0EFACC5E5A4BFDFA0D5F3B7D1EDB2C7E3A6
B8D092D5EEACCAE39FC9E1A3CBE5B8C8D9B5FDFFE2F8F4D1E9D9B59B855E5F481F645126
5F5524D7D5A2DDE4AEDFEEB7C6D7A3C8DAA8DFEFC2D0DDB1C9D6ABDFEBC3F9FFE1F1FFDF
D0DEC4CCDBC4CCDBC8EAF7E6F6FFF3F4FAECFFFFF3FFFFEDFFFFEAE2D8BF6D6246A49F81
FCFFEAF8FFEFF4FFEFF4FFF1F9FFFDFBFFFFFCFFFFF9FCFFFBFFFFFBFFFFF9FFFBF6FFF4
F5FFEDF7FFE8F5FFE3F8FFDCEBEDBCD2CF9A85844ED8DBA2DEE7A8D7E3A3D4E4A3D1E6A5
D7EDADC5DDA1D4EDB6CEE6B6F3FFE0F4FFE4F1FFE5E3F7D4D5E4BBD3DEB3D4E1B3D8E6B3
C9D6A09CA76D646C3143440AE7E2A8E7DEA5D6CB93F8EFB8DDD69F56531C61612BFFFFCD
FFFFD1D6E1A9C5D398D3E3A5D5E8A8D5EAA7D3EAA6CBE29ED0E7A3D6EBA8CCE19ED1E4A2
D0E49DCADE96D2E89DCCE2A1D3E9BBC1DBACC3E49FD6FB9EBEE070D0EC7EDFF19D8D9F63
CCE3C6DBF9EDDEFFFF93C1C155888965A29AB0FAE1A2E5C2578360000C00021500D7E1C9
D0CEBFFFFDF0FCFFF4F0FFF1F0FFF4E9FAE8FFFEF3FFF2ECA67B75E8C2B9FFFCEAD2D0B9
6567527E8170F9F9EFFFFFFBFFFDFFFFF8FFFFFBFFA99DA7
D7E0A1DFE8A98E9758E3ECADDAE3A4C1CA8B90995A636C2D5D66276B7435889152A7B071
B3BC7DA9B27399A263919C5AD9E49FD2E299D5EA9FD9F1A5C9E598B7D78BBCE193CFF4A7
CDEFA3C5E399D0E7A1C9D895EBF1B3DCDCA07F78415B5B1FB2C681C7DD92DCEA95D1E98B
BAED86BBF295C4EBACC6E0B0D1E5B0B7E2B56AC9B12B896EB3D8A4DEEAACD9ECB4C6D7A1
9C9C6894915CD9DAA1DBE5A9D2E5A5CDE6A4C7E6A0BDE197CAF0A5B8E195BEE499CEF2A8
E1FFB8C6E19CBCD591D6ECAEC2D4A4BBC79F92946C756D4688764EA38C62EDD5A9EFD9AA
EFDFAEA099658B8B57B9C28DD2E0ADD4E6B4F7FFDCF7FFDFF8FFE4ECF9DBF4FFE7F8FFF0
FBFFF6FCFFFBFEFFFFF2F2F4FFFEFFFFFEFFFFF9F6FFF7F0FFFEEFFFFEEA5C5038B5B092
EFF9D4DDEDC9DCEBCEEFFBE5FBFFF8FAFFFBF7F8FCF8F9FEFCFDFFF8FCFDF0F8EDE4F0DC
E0EFCEE2F4CAE3FAC6E5F8C1EAEFB9D0CF97A6AA6F63692B86914FCEDD98CFE09AD7EDA5
CEE8A1C3DE9BCEE8ABC7E0A7EDFFD5F0FFDBDEF7CDD4EBBFD0E2B0CBE0A7CCE4A8D0EDAD
CBE8A6B4CD8998A766878C4C6D642BD8C791DCC694A18F5D807643757340A2AB74E8F9C2
D6EFB6E6FFC8E1FEBECFEDA7CCE89EC6E297C5DF95D1EBA2C9E09AD2E9A5CDE3A2D6EBA8
D6ECA4CFE59AD7EC9DCFE6A0D3EABEC9E2B8D3F0AEC2DF8BD7F38FC8E37CD4E98C85954C
C7D4A6EBFAE3F0FFFFC8EBED7DB4AF3F877961B9A09FEED1D4FFEB64796A000500696A64
B7A9A8FFFAFAF4EFEBFBFFF8DDF6E3F2FFF4FFFFF3CEB6ACB88F89FFEFE6ABA08C303419
A1A58AF0F4DBFDFEEEF5F5EBFFFDFDFFF7FCCBC0C6CEC3C9
C9BA8183743B8D7E45AA9B625142097C6D348E7F46BDAE75E3D49BD8C990A899606B5C23
5D4E1576672E7D6E35675F2170793695A65FC6DA92D3EBA1CAE69BD7F5ABDDFDB2C5E59C
D0EEA6C3DE97DCF1AEC7D796838C4D85894C76763AD9DFA1CBE199CEE69AD7E695CFE78F
BDEF8EBBF297C2E9A6C7E3A9D1E6ABB0DBAD46A58D2E8C74D2F7CBCDDAA4CEE2ADCBDEA6
7D8647818844D4E098DEF0A6CBE697C0E190C8EE99D1FBA5BFEB94C8F69EC2EE97B7DF89
C5EB96C9EA99C9E898CEE49BEDF7BA686D335B6026B7BB80D0D094D5D194EFE7A997884D
604D13B1A166B8AC70555114DAE4A7E0F6B6D2F2AFDCFBC0E3F5CDDAE7CBFBFFEDFBFFF1
F9FFF3F4F9F3FEFFFFC0C0C27F7D80FFFBFCFFFDFBFFFDF6FFFAEE998E7C988C76D7D0B4
EBEDC8D1D7B1D6D9BAFBFBE3FFFFEFFFFFF4FDF8F2FFFEFAFFFEFAFFFDF1EEEFDDDCE1C3
D3DBB4D3DFAFD5E4ADD7E5AAD5DDA4D2DA9FE3EBAF4F5B1D96A564DFEFAECEE19FC7DC9B
D5EBABD4ECB0D4EBB3CDE4B0F7FFDCF7FFDFD8EAC4D0E6B7C9E8A4C1E897BFE997C5F19C
C9F5A0C6EE98C2E28FC3D88B7A813B70712F514D0E767439BFC48AD6E4A9D3E8ADCCE8AB
C3E6A6E9FFCBD8FCB6BBE093CDF2A2D1F7A2C0E693C7EC9CCAEC9FCDEFA3C1E399C4E499
C3E397BEDF8ECAEB94C6E597C2DEA4D1E9B7D1EBAEB8D28BE5FEADD0E694C7D78C97A363
939F6FE0EECDECFFEEE9FFFFDDFFFF84C5BD49998E74B8ADE9FFFDFBFFFAAFB0AB060000
4C3639F9E0E4FFFCFAFEFFF8F1FFF6F2FFF3A1A493978A7A886C6033210D727B5CCBDFBA
CDDCB5D6E0BDE3E9CFD4D9C5DDDDD3E3E2DDFFFFFAFFFEFB
AFA367514709C4B87CA19759605418A2985AACA064EFE5A7DDD195EAE0A2D6CA8EAAA062
A99D61C8BE80C8BC80A19D5E697432596D288BA05BCBE29CD0EAA3C5E099C8E39CC2DD96
C8E29BAAC17B93A8659CAC6B4F5B1B6F793AB3BC7DD1DD9BD1EBA1CCE79AD1E196CFE897
C0F09ABCF09DC3EBA2CBEAA7CCE2A1BBE7B42C8A7259B4A2C1E7C2C6D6A7CAE1ADDDF2B9
A0AB67929A4FCDDB8ED2E594CEEA96CDEE97C4EB92B7E084C4EF93C1EC92C0E88FD8FFA6
C8EA94CAEA95D1EC9BD4E69A9197515253119BA25ED3DD96D0DA95E9F0AAC5C481655C1B
806E30FBE5ABFFFFC5685E21D5DC99BCD18CC8EEA3CBEFAFCDE2B9D1DEC2FBFFEDF6FDED
FCFFF8FEFFFBEFEFEF3331342C272BFFFDFFFDF3F2FFF8F4FFFCF36F6355EEE1D0F9F2D8
E4E6BFD0D7ADD6DCB6F9FDDCFFFFE8FFFFEAFFFFEBFFFFEDFFFFECFFFFE8EFF5D3DBE3BA
CEDAA8CEDDA4CFE2A2D1E1A0DBE7A9D8E4A6D6E2A44856189AAA6CC7D99DD3E5ABD0E3AB
C6D9A2D1E3AFCCDEAECADAADF8FFDEFAFFE0CFDBB7CDDFAFCCECA0C3EE92BEED8DBFEE8E
C1F092C5F094CDEF98D6ED9BA5B1679CA15E9A9A5CC0C187D4DCA3CCDBA4CEE5ADCBE8AE
CAECAFE5FFC7DBFFB9C3E89BC5EA9AC1E794BBE090CAEFA1C3E89BC8ECA2C1E59DCDF1A7
D4F6AACDF0A0CFF39CC3E493DAF4B3D8F0B6DFF7BDEDFFC7E3F7BCE2F4B8DAE5ABBCC58E
8A9261E2EFC4D8ECC9DBF9E1E2FFFFD8FFFF7ABDC3578E93ECFFFFF4F9F5F4F4F4080000
0F0000BAA1A5FFFAFAFFFFF7F0FFF1EDFFECBABDA8A199842513000A0000D5EAC3C6E3B5
D9EDBCC9D6A8CAD6B0CFD8BBECF1DBF1F5E4FFFFF4EEF0E3
697D359DB368CFE39BCBE196DAEEA6D2E89DC4D890CFE59ADDF1A9D2E89DCDE199CFE59A
D1E59DCCE297CDE199D1E79FDCF1AEC2D796A4BB777B924E647B3789A05CA3BA76899E5B
899E5BA1B67376894791A462B4C883C4D893E2F3AFCFE59DCEEA9DCAE699D0E49CD0EAA3
C2EEA3BBEC9DC3EA9BCDEE9FD1E99FBDEAB126826B8EE8DCD2F9DEEDFDD6E2FACAD5EAB1
8F9857959B53DFE79EDDEB9ED3E695D5EE9AD6F49ECCED96CDEF98C0E28CC7E792CCE796
C4DB8DCBDD93E4F1ABADB770595C159C9D57D1D990D9E39CDCE7A2ADB673727232A79E63
EFDEA6D0BB868B77426B6028E4EAACDCF1ACCEF2A8C0E4A4C1D6AFCFDCC2FBFFEFE7EEDE
F5F8EFFDFEF9FFFFFD383435817B7DFFF6F9FFFBFBFFFBFA5D5048AC9E93FFFCEFE9E3CB
D3DEB4CCE0ADD2E6B5DFF2C4E6F7CBE4F5CBE8F9CFF0FFD7F1FFD6ECFFCFDFF6C0D0EAAD
C8E5A3C9E9A0CBEBA0CDE99EC5D692CDD999CDD99B5361248E9D64D3E4AED8E9B5CEDEAF
CCDCAFDCE9BED6E2BAD7E1BCFEFFE1FFFFE3D6DAB9D7E3B3D0EB9CCCF090C8ED8EC4E98A
C2E78AC6E790CEE593D6E499E0E5A2E2E0A3E1DCA5E9E3B1DEDDAFD9DFB3DEE9BEC1D2A5
D1E9B5BFDBA0C0DD9DCDEAA7CEECA4CAE89ECDEBA3D0EEA8CCE9A7CEEBABC3E1A3CBE9A9
CDECA8BEDE95B5D589A1C074C1DB92A2B877C0D59CD2E4B4BAC9A2E1EDC7EAF1C8A4AA7C
9DA470DFE9B4D8E8B7D6EFC8DCFEEDE0FFFF96CBDD437286DEF5FBF6FFFFE2EBEA6D6D6F
0E00058A7379FFF0F2FDF6F0F9FFF4E3F0DCB8B7A2BAAF994C3B21ACA686BFD6A8CAEBB6
5C743A495A231C2C007E8D647D8868F4FEE3ECF4DDFCFFED
75974AD3F5A8C3E598D2F4A7C7E99CC8EA9DD1F3A6D0F2A5C3E598C2E497C7E99CD1F3A6
D0F2A5C8EA9DC6E89BCBEBA0D3EEABBDD695CAE0A0DFF5B5D4E8A9C6D999CDDD9ED3E3A4
C5D596DEF1AFD6E9A7C2D794E2F9B3CAE49DBAD58EC7E59BC9EA99CAE999D1E8A4CDEAAA
C2EAABBAE8A0C1E895C9EB94D4ED9CB9E5AA378F799FF6EDE6FFFAF5FFEAF4FFDFDAECB8
A4A76EA6A265E7E7A9E0E2A1CAD48FC9D68ECEE096CDE297CEE398D8ECA4ECFDB6CCD994
EAF0B2CFD398D3D29A626128505513D4DB97DCE3A0DBE1A3DADFA5ABAB759D9A67D4CC9D
E2D3A8A8996E6D6235CBC798D6DDA9D2E4AAB6D295D1ECB5DCEDCBD8E2CAFCFFF1FEFFF3
FFFFF8FFFFFAF1EDEC040000060000FAF0F1FFFBFBE3D3D363544FFFFBF4FDECE2FBF6E0
CCDDB1CBE8B0CDEAB2C9E6AEC7E2ADC9E4ADCDE9AFCFEBB0CFEDAFCFEFAECCEDA8C4E89E
C2E89BC4ED9EC5EF9DCAEB9CE2F1ACDDE6A7DCE4A84C551C575F2CEBF4C5FCFFDCFCFFDF
F5FFDCFEFFE3F7FEDDF6FBDBFFFFE3FFFFE3DAD9BAD8E0B1CCE79ACAEF92CBEF95C7EB93
C6E894CBE898CFE59CD2E19CDCE2A6D6D6A0E3E1B1FFFFD7FFFFDCF4FAD4F6FFDDE0ECC6
E0EDC2CDDAACD9E6B1E6F5BCD7E6ABCFDEA3D5E4A9D0E1AAF3FFD0DEEEBDB1C393A0B280
A0B37CACC085CADE9FD1E6A1C1D78CD0E49DD1E2ABCCDBB2F6FFE35F684D444929E4E9C0
C9CE96CED69AD8E3A9F2FFD7EBFFEEDCFEFFA2CAE3466E88CBE8F0EEFFFFEBFFFFF4FFFF
7A787D080000847477FFFAF6FEFFF3A8AB989A927D66563D8B73596D6340081800000F00
00140081935598A973C1D1A4C6D4B00B1600CAD5B7D7E1C6
D0F0A5CBEBA0CAEA9FCBEBA0B7D78CD4F4A9C5E59ABBDB90CAEA9FD2F2A7CCECA1BBDB90
BADA8FCAEA9FD1F1A6CCEAA4C6E3A3D3EDB0D4ECB0C9DDA0C5D79BD5E5A7DDEBAEDAE6A8
DCEAACC0D091D0E3A1C4DB97CBE69FCFEFA6CEF0A6D2F7A9C7EA96CAEB9ACEE8A7C8E5AD
C1E6B3C1E9ABC5EB96C6E98BD0E995BDE9AC3D917A99EBE5E3FFFFE8FEE7E4FDD5E4F4C5
B9B28876643C85764B918658B3AD7BD3D29CE6E6B0EAEDB6DBDEA7DEDEAAC8C695E7E0B2
FFF6CEA797738A7655827650D9E3AEDAE9B0CBD29FE9E8BC9F9571493A1B7D6D53F9EBD1
C5BEA446442B6B7052FCFFE4D7E3BFF2FED8F3FFD7E8F4D0E0EAD1E7F0DDF7FEECF5F9EB
F5F5EBF6F3EEFFFCFD6A6061473B3DFFFAFDFFF0F1A39191665450FFFBF4FFFAF3F0EBD7
CEE1B4CBEAB1CBEAB1C6E5AAC3E2A6C4E4A5C6E6A5C6E7A2C1E59DC3E99EC4EB9CC0EA98
BFEA98C3EE9CC3EF9AC7E899D0D793D8D497EDEBB2A2A06D767547D8D9B1FFFFDFF4F8D7
FFFFE6FFFFE8FFFFE6FFFFE5FBFCDDFFFFE1D9D9B7D1DDAFC5E6A1C3F09FC3EFA0C1EC9D
C3EBA2C9EEA8CDEBABCCE5ABD3E6AFD1E1B0D9E6BBF6FFDEF8FFE3F7FFE6F4FFE8CCDBBA
CFCEAFEBE5C3EAE2BDC2BD93A19D709895689C99709F9B75AFAC8BCECBACE7E6C8FFFFE3
FFFFDFF1F3CBE6E9BACFD89FDEEEA7C9DA93E5F4BDD0DCB4F9FFE8EEF6DEE4E9C9D0D3A8
F3F6BDDADF9FDBE3A7ECF8C8EFFFE9E8FFFFCCE8FF6E90AB759EA4B9E7E4DDFFFFDEFFFF
BED0D00000022E2327C5B7B6F6EFE5D8D1C1AC9786EACEB9452109260D004D4E22687740
9FAF71E3F3B4E6F5BECEDBADE0ECC66A7555000700D4DEC3
CFE6A2C6DD99D4EBA7C4DB97E3FAB6CEE5A1C3DA96DBF2AECDE4A0C9E09CCCE39FD6EDA9
D8EFABD0E7A3CAE19DC8E19FCEE8ABCBE7ACCBE3A7D2E6ABDBEDB1D6E4A9CFDA9ED4DEA2
D7E3A5D3E1A3DAEDABD9F2AEC7E59DC0E49AC4EDA1BAE394C4EA95C8EB9BC7E5A5C3E1AF
C4E2BCCBEDBBCDF09CC9EB8CCDE692C5EEB231806A9AEBE5E2FFFFF0FFF3C1DAB3D7E4B9
EBE1BE8E795A7C69485E502B544820625B2F9B9768D8D4A5D9D5A8EBE4B85C532A685A37
635030594429674C37E1D3B8D8E5B9CAE0AFD5DDB4D6D1B1A3937C7863526E5B4DDDCFC2
817F70A0A797F8FFF1F7FFEFF8FFEDFBFFECF4F8DFFFFFECF8FFEBFCFFF3FEFFF4FFFFF4
FFFFF6FFFEFAFCF2F10C0000695B5BFFF8F9FFFAFABAA8A66A5753FFECE6FFFAF3F7EFDC
D4E0B8CBE2AECAE1ABCEE6ACD0E8ACCEE7A6CDE6A4CEE9A2CDE99FCFEEA2CFEEA0CBEC9D
C9EA9BCBEC9DC9EA9BCDE297E9E5A5E6D59DE4D4A0EFE3B3A0946AA19974FFFFE1FFFFE4
FEFCE3FFFFE7FFFFE8FFFFE4FFFFE0FFFFE1F3F5D0EFF8CBCBE5A8CAEBA6C9E9A6C5E3A3
C8E4A7CFE8AED3E8B0CFE1ADD9E7B6C9D4A9D6E1B7FCFFDFF4FFDCC7D5B1DAE8C5FDFFE3
FFFFE1FFFEDDD3C3A1A69770E1D2A9FFFFD8E9DBB8B3A686E9DEC2FEF2DAFFF7DEFFFAE1
F1EACDDDD7B3E3DEB6E0E0AECFDA98D5E4A1D5E2ACD4E1B5F9FFE2FCFFE6D2D8B2DCE2B4
D4D79EEBECB0FFFFCDF9FFD2FBFFEDF5FFFFE4F7FF6E8A9F4B787D47807AB6F5EDD2FFFF
E0FFFF505C5C0B0509F7E9E9FFFCF6FFFBF18A6E606744317F564067482BCDC69CAFB683
EAF4B8C5D096CCD6A4E2EAC1E5ECCBACB296020A00E5EDD6
6E773E6C753C6A733A6871386871386A733A6C753C6D763D6C753C6B743B697239687138
6972396B743B6D763D6C7A3F587034607C412E460A63783D65773B6C7A3F333E02677135
717D3F5D6B2D64793694AF6AC1E399CAF0A5C1EB9FBEE99AC1E794CAEC9FCFF2B21F3C0E
5A7356E4FED7CFF0A1C4E386D2E99BBFE4AE39846D43908859847B001100000C0068774C
635E3E483A1D0B0000241C00645F373F3C0F171600191B00706F3F3633061611001F1500
3D30104A391D513D2571674C61714A687F53656F4C5F5E423A2D1A1E0E003224172F271C
111306545F4F5A6B596275615C6B5669755F686B58696A585F63546E74665F625768685E
746F696A635D776C6A0F0000190705FFF5F4FFF0EFA6938F5D4845F8E5DFFFFAF3EADDCD
CFCAAAEDEEC4D0D3A4CBCF9DDADFA9D1D69CD6DCA0D4DD9CD4DD9ADEE8A3D2DC97D1DB96
CED893DCE6A1D5DF9A9A9958C4AF76DABC88EED2A2C7AF83806A43584826EADCBFF9F2D6
EAE4CADFDEC2C4C5A6CED2B1C5CBA7C5CCA3AEB58BB9BF91B1B582A1A46F969662BAB885
9E98689F986AAAA274A0986AB7AE839A9166AEA57CA59C73B0A77EADA47BAAA178978B63
8A7B52A7966BC7B68AD3C596CEC08FCEC292E5D8ACFEF2CCCAC09DDED3B5D5CCAFB1A889
A9A17DBDB88EBBB7889E9E6ABBC086A0A970B2BF89BFCD9A869365B0BD8FD5DFADBDC490
D0D39CE0E0ACEFEEBEF2F4CFE9EED8DFE9E0DAE8EBD5EEF57CA5A7467E7B10564E32736B
90BAB6768A893A353B140407EDDEDBDDCAC3C2A69A9B7A699D77629D7F6399916A9FA273
ACB07D8F9361A9AB83C9CAAAD3D5BD6263517C7D6FCACBBD
6A753D69763E6B763E6B7840717C447481497A854D7B8850758048727F47737E46707D45
727D45727F4776814973854B728C4F789457657F4283995B8FA165829254606E31828E50
8694567A8A4B7F96529FBD77BDE197C6EFA3C5F1A4C8F3A4CCEF9FD0F2A6B9DD9D001100
C9DCC9EEFFE5CCE7A0D6F29EC7DB96CDEDBEA6ECD4317B6E5C8A7D76937D637B5775865A
898D688E8E686F7149848A5C9DA5727B855076844994A2677C874D6E793F787F4B898D5B
9F9D7497936D77714F747651617045768B60838F69868D6B7474586B69507E7E6670725C
5C644D89957D7B8A7375856B627258647259626C53656D5883897B84877E7A7B7385857D
8B86807F7470AA9B968A78747C6963D7C2BDFEE9E487726D67534CFAE6DFF1DDD4FFF2E2
F4EBCCF3EEC6E3DFB2ECEABAF2EFBCD4D39DC9C890D5D49BDBDB9FA6A668939154858444
D1CD90ACA86BB2AE7160541A6D4F1B724E1C63431474572B866D4565512EA89978ADA483
B9B494B1B2909B9F7AA7AF86A1AC81A3AF81939F6DA2AA77AFAD7A78713D9E9461796D3B
AA9A69D6C695C8B789CABC8BA59967625825908955C3BE87BEB7818D864F9D945DC2B982
D3CD93D8D298DED89CDCD899D1CD8EC8C487CBC891D6D3A0DBD8ABE4E2B9E1DFB8D2D3A9
D4D3A5DFE2ADE1E5AAD6DBA1DDE1AFD0D6A6D7E1AFE1EFBAC5D69FD1E3A9FCFFD1E3EEB6
D6DAA8D7D8ACDFDCB9EAE9CDF7F8E6FEFFF6F8FFFAEDFFFEE6FFFFDFFFFF91D2CC43847C
9DCBC84E66660500064F3E44F2E2E2F3E2DBF7E1D6D8BEAFC0A48FF5E1C6D9D9B3C8CFA3
E2E5BAD7D8B0E0DDBEC8C6AF7976676C6960FFFEF8FFFFFA
C7E5A9C5E4A8C5E3A7C4E3A7C6E4A8C7E6AACAE8ACCAE9ADC9E7ABC7E6AAC6E4A8C5E4A8
C6E4A8C6E5A9C9E7ABCAE8AAC6E4A4C6E3A1D2ECABCFE8A7E4F8B9CADD9DCCDC9DD5E5A6
D3E6A6CCE19EC7E09CC8E6A0C7EBA1C2EB9FC0EA9EC2EB9FCCECA1C8E7A1BAE19E5F7F50
EEFCEFF7FFF1CFE4A9CFE59DDEEBB6CEE8C3C2FFE7397E6B8BBAA6CCECD4C7E0B9CCE2B4
C9DDACCCE3ADC2DAA0CDE7A8D1EEABBEDE95C5E599D5F8A8CBEC9DCCEB9DCEECA2C7E29B
D3E9A9DAEEB1C9DAA3CDDEA8CDD9A7E0EEBBE2F4C2DCF3BFCDE5B3CCE4B2D3E9B8BFD0A3
E2EDC2FCFFDBEAF0CAE6EEC7D6E2BCD1E3BBCEE7BFD4E9C8F0FBEBFEFFFBFFFFFBF6F3EE
FFFBF5FFF5EFFFFBF4E1CDC6E9D2CAFFF9F1FFF0E5978176654F44FFFAEFFCE8DDFFFDE8
FFFFDDEFF1C2EAECBDEDF1BFEAECBAD6DBA5C7CC94D7DCA4DBDEA5EAEBB1C6C58CAFAD74
E2DDA3E8E3A9D2CC925D50196347157957276A4B1C6F54275F4A1D6A5B30CEC59AEEEBC0
DADBB1D8DEB2CAD3A4D2E0ADD1E2ACD1E4ACC8DBA3D9E8ADDCE7A5929956EBEDACB5B575
9B9758C2BE7FD8D89AE2E7A5818C48A3B36CCEE096C5DA8DD6E99ADAEB9DD5E293D7E495
DAE798D4E392D2E18ED7E693DBEA97D8E999D7E79ED8E7A2D2E2A3CEDDA2CEDDA4D0E2A6
D4E4A5D0E49DD1E699D8E9A5DAE0B4D9DDBACDD6A9D0DEA9D6EAABCEE3A2F9FFCDE5F2BA
DCE2B6DEDFBDE4E2CBF2EFDEFFFFF2FFFFF4FCFFF4F9FFFBF7FFFFEAFFFFC7F9F838716B
57817F71898B3E39402C1D247A6B6EFFFCF8F7EDE3C7BBABB9AE9AC8C7ABD5E3BFE3F3CC
E2E6C3D3CFB2E8E2CC413B2D3F3832FFFBFBFFFCFFF4EEF0
CFF3B3CBF2B1CBEFAFC6EDACC5E9A9C2E9A8C3E7A7C1E8A7C7EBABC4EBAAC6EAAAC3EAA9
C5E9A9C4EBAAC7EBABC8EDAACBEAA7C3E09DD3F1ABC4DF9AD2EBA7C3DA96D8EDAAD3EAA6
D6EDA9D6EFABD3EEA9CBE9A3C5E79DC4EA9FC6ECA1C7EBA1C9E7A1C1E09CC7EFA9D7F7C6
E8EFE8FDFFF9E2F2C3D0E2A8CFD7B0CFE3C8CDFFEA53957A77A88BBBDEBEE4FDD6C6DDAF
CBE8B2C6E8ACC5E8A8C7ECA6C2EB9FBEE997BFEB94B7E489BDEA8FC3EE94C8F29CBCE390
C0E597CAECA2C6E5A1DAF3B2DEEBB3DAE7B1CFE7ABC9E9AAC1E8A5C7EFA9CFF2AEC6E3A1
C7D99BD6E1A7CED59FD8E0ADD4E2AFC8DFABC7E8B3C9E5BDF6FFF4FEFFFFFFFFFDFBF6F3
FFFDF8FFFBF4FFF4EDCEB7AFF3DBCFDCC5B74B3124AD9688FFEBDDFFFAECFFFBECFFFEE4
F5FBCDD8E5AFE0EFB8D5E4ADD0DFA8DAE9B2CCDBA4D0DDA7C3D098E9F2BBCED69DE2E5AC
DFE0A7E4E3AAD8D69DB1A871685421F7E0AEEDD9A7DCCC99EBDFABE3DDA9D7D7A1E7ECB6
D7E0A9D7E4ACCEE0A4D0E4A7D2E8AACDE6A5CBE1A1D8EDAAD1E19AA3AD64D2D892DADD98
DBDA99D1D290949956A3AE69D2E69EC8E396CDEE9DC6E894CCEC97CAE892C8E08CDBF39D
CEE891C6E389C5E288CBE88ED0ED93CDE994C9E495C7E198D1ECA9CAE4A5CBE5A8D1EBAC
D1ECA9C9E59BC8E595D2E9A5FFFFE3FEFEE6DDE5C0CCDAA9D2E6ABC8DE9EDDF1B4CDDEA8
D6DEB7E8EBD0FCFAEBFFFFF6FFFFF6FCFCF2FBFFF0FEFFF8EDEAF3F7FFFFE2FFFFB2E6E2
416E6B849E9F0000070C0008706569F7EFEDEBE7DEFFFFF3C2C1AFFEFFECEFFFE5ECFFDF
6E73553B36204D4739BFB8B0F9F3F3FFFDFFF9F2F9FFFCFF
C5E4A0C4E5A0C5E4A0C4E5A0C6E5A1C5E6A1C7E6A2C6E7A2C8E7A3C7E8A3C7E6A2C6E7A2
C7E6A2C6E7A2C7E6A2C8E7A3CFEDA7C5E39BCDEBA3C6E49CC8E39CCAE59ED8F3ACCEE9A2
C2DD96C6E49CC7E59FC2E19BC4E39DC9EAA3CCEDA6CAE9A3CEE8A7CFECAAC1E9A2BADAA8
FEFFFDFFFBFCF8FFDFF6FFD6FFFFEDF0FEEDBEF3D5B4F4D1437550BEE2BCB5CBA4D5EBBD
CAE6B3D5F6BDEAFFCFDEFFBEC3ECA0C3EE9CCBF7A0C8F79BBDEC8EBEEB8EC9F69BC6F09A
C8EF9EC6ED9EC8ECA2EDFFC7EFFFC7CFE1A7BFDC9CC0E59FBEEA9DBFEE9DC5F09ECDF3A0
D3EE9FD7E99FD5E29DDCEBAAD8ECAFC5DEA4C7EBAEC3E0B4F8FFF8F4F5F7FCFAFBF8F3F0
FFF9F5FFF5EEFFFAF1FAE2D6FFEDDE634938DFC4B3FFF5E1FFFBE6FFFBE6FFFAE4ECE6C4
D2E5ADBADB96CEEEABC7E7A6C4E4A5D1F0B4C5E2A8C9E6ACD2EBB2D3EAB2CDE0A8C8D79E
D6E1A5D4DEA1E2EBACCCD0935A5720D0CD96E4E3ABDFE0A6CCD294E7F2B0DFEEABBACE87
D1E79FD4EBA3D0EAA1CBE79DD2ECA5C9E49DC9E39CD5EBA3E1EDA581843DE5E4A1ECE7A7
E7DFA1E7E1A5D6D698D1DA9BD7EAA8C1DC97CEEFA8CCF0A6BDDF95CFEDA3D1E8A0C2DA8E
D1F0A0CFF19DCFF19DCEF09CC9EA99C5E599CAE9A3D2F0B0C6E3ABC7E3B0C9E3B3CBE6B3
CDE8B1CDE9ACCDEBA5D1E6ADFFFFEAFAF8E9E4EACED0DCB6CDE1B0DAF1BBBBD29ECADDB0
D6E1C1ECF1DDFFFFF6FFFEFBFFFEFAFAF9F5FDFFF7FFFFFBFFFBFFE7EBF6E0FFFFA1DAD3
4E817C6382840000090E040F040004FFFEFFFFFFFBF9FAF2E9E9DDF8FCEDF5FFF1C2D4BA
070C00FFFFEDF8F6EAFAF6F3FFFDFFF6F1F8FFFCFFF4EEF8
CCE7A0CBE99FCEE9A2CCEAA0CFEAA3CEECA2D1ECA5CFEDA3CFEAA3CDEBA1CFEAA3CDEBA1
CFEAA3CCEAA0CEE9A2CEEAA0CCE89EC8E499C9E89CCEEDA1CAE99DCFEFA4CEEEA3C4E49B
CEF0A6CFF1A7CEEDA7CBEAA4CAE9A3CBE9A3C8E6A0C5E09DCCE1A6D9F3B4C4ECA3B5D39F
FFFEFFFFF7FFFEFFEBFEFFE6F4F1EAF8FFFBB6E7C9003C1204380AD8FDD1BFD6ACCDDEB4
D0E5BADDF7C8F2FFDADDFAC0BFDF9EC0E49AC2E799C3EB95CEF49DC2E891C4EA95C1E794
C1E397BEE096CAE9A5F2FFCFF5FFD4D1E8B0C6E4A6C9EEA8C6EFA1BFEB96B7E38AC5ED94
D1F39CC9E692C8E394CCE69DCBE5A4BDD99CD3F2B9CEE7BFF9FFFAFEFDFFFFFEFFFFFBFC
FFFBF8FFFBF4FFFAEFBFA596CDB2A1AA8F7AFFE7D2FFF8E1FFF7DFBBA58DB29E85CCC8A2
D8F1B0C2E89BC5EBA0C7ECA6C5EAA7C3E7A7CAECB0E8FFCEEFFFD3D3EAB4D0E3ACCFDEA5
CFDA9EDEE6AAA0A666555B1D5A6529D2E1A6D7EAAACFE4A1D5ECA4D4EFA2C3E090DDFDAA
C8E893CAEC96CCEE98C4E491D0EF9FC8E497CAE69BD1E99FCEDE97F5FFBA4F5110E4E2A7
C9C48DE7E6B0E9EDBACCDAA5C5E0A9C9EFB4B9E5AAB4E4A8C9F5B8D3FBBFB9DAA1D8F6BA
C2E0A0C5E4A1C9E8A5C9E8A5C7E4A4CDE9AEE2FDC8F2FFDFEEFFE0F4FFE8F4FFECF3FFE8
F4FFE3F5FFDFF5FFDAF7FFDDFFFFF3FFFBF5FFFFF1F2FFE3EEFFDCF2FFE1CCE5BBE8FEDA
F0FEE5F5FDEEFBFEF7FFFDFEFFFDFFFFFFFFFEFFFDFFFFFFFFFBFFF9FFFFD9FFFF0E5046
3C7971CEF8F6A7B2B8030009FCF7FEFBF6FCF8F6F7FFFEFBF0E8E5FFFFF8D4DACE030C00
EEF3DFF3F6E5FFFFF8FFFFFDF3F2F8FFFEFFFFFDFFFFFDFF
CEE99CCDEA9ACEE99CCDEA9ACDE89BCBE898CBE699C9E696CBE699CAE797CBE699CAE797
CAE598C8E595C9E497C8E396CBE699C8E497CAE99BCAE99BCEEFA0C8EA9DC5EA9CC3E89B
C0E598BEE396C1E399C6E69DCAE8A2CBE6A1CBE6A3CCE5A4C8DBA3D3EDB0D4FDB1EDFFD3
F8F4F5FFF9FFFCFDEDFEFFEEFFFDFFE9F2F1C5F2D30018005D8F5AB4DAA7F3FFDDFBFFE3
FBFFE9FCFFEAFCFFE6E6F2CCD8E5B7DEEFB8CEE2A5CDE4A0D1E6A1CDE29DD9EEA9DCF1AE
DAEEB1D1E5AAD0E3ACF2FFD5E8FFD7C0E2B0C6E4AECCEAAECEEBA8D2F1A5C7E995CEF49D
C6F197BBE98FC1EE9BC2ECA2CAEDADCBE6AFF5FFDCF6FFE5F5FAF6FFFEFFFFFDFFFFFCFD
FFF9F6FFFAF3FFECE0674D3C634835DEC2ACFFE8D0A0866D5F472D7B664B59452A60592F
CADE99D3F2A2C8E99AC7E79ECAE7A4C1DDA0D6EFB6F6FFD5F9FFD875814F5A622F616630
4F4E166560264C4608595B1CC9E1A3CAEDABC4E9A3C9EFA4B7E18FBDE791C2ED93B9E586
C5EE8EC7F090CCF396C1E58BD6F7A0CCE997CFEC9CD0EAA0CFE8A4B7CD8DACBB82D8E5B0
DCE5B6D1DCB2D1E6BDC3E2B9C2EFC6B5ECC279B88D4B8C62609D74AEE6BFB5E7C2BFE7C2
CDE6BFD2E4BCD4E6BED2E4BCCEDEBAD0DFC0E0ECD4F1FCECF9FFFAFBFFFDFBFFFFFCFFFF
FCFFFAFBFFF3FCFFEDFDFFEFFFFEFAFFFDFAFFFFF8F2FDECEEFFE9EAFFE5C5DEC0D3EACE
F7FFF3F9FFF6F9FEF8FCFCFEFFFEFFFFFEFFFDFDFFF9F9FFFBFBFFF1FFFF84C2B7398A79
61ADA0BFF6F062777C0A0A14CFC9D5FFFBFFFFF7FFFFFBFFEFDADFFFF9FB0A0000FEF7EF
FEFFF3FBFFF3FBFFF8FBFFFDF8FBFFFCFFFFEDEDF7FEFEFF
CDE693CBE793CCE796CDE897CDEA98CDEA9ACDEA9ACDEA9ACDEA9ACDEA98CDEA98CDEA96
CDEA96CDE994CCE893CAE793CFEC9CC8E799CDECA0BFDF93CFF1A4BEE093C5EA9DCBF0A3
C9EDA3C5E99FC7E8A1CCEBA7CCE9A6C9E3A2CAE4A5D1E9ABCEE3A8CEE8A9D9FFBBF1FFDC
FFFCFAFFF9FFFFFFF5FCFFF6F7FBFEF0FFFBC2EECABCF6C43E7649C5F3CEF0FFEDF8FFF1
F9FDEFFEFFF1FFFFEDDDE7C5D1DEB2D8E9B3C9DD9ED4EBA7D2E7A2CDE29DD3E8A7CDE1A4
CEDFA8CEE0ACD2E4B4F1FFD9EAFFD7C7EDB4CEEDB4C7E3A8C7E09FD3EDA6C5E496C6EC97
C1EE93B8E98EC3F39FC1EDA2C8EAAECBE2B4F9FFE6FBFFEEFFFFFDFDFAFFFCFAFFFFFEFF
FDF3F1FEF1E9FFFBEC9C866F664E32AA96739B8C6360542AA2996ED8CFA6A59C75797747
909D57D1E697D2E79CCDE19CD6E4A7CFD9A4D9E1B2DAE0B4D7D9B1797A50EAECBDD1D19D
E8E9AFD2D495E2E5A0DAE7A1C5EAA4C2F1A9BFEEA0C3F09DC3F197C5F295C9F594C5EF8D
C5ED8CC7EC8DCCF194BDE187D2F69FC5E894C8EB99C7E69ACEE1A1DDEAB24D5E2AE4F7CA
F0FFE3E0FFE1E3FFF1DDFFF4D9FFF6064228154F3797CEB96BA28D88C3AFCAFFF7D9FFFC
F1FFF8FBFFF4FBFFF3FBFFF4FBFFF6F8FFF7FAFEFDFCFFFFFCFFFFF8FAFFF8FAFFFCFEFF
FCFFFFFAFEFFFDFFFEFFFFFDFFF7FAFFFCFCFEFFFBF3FFF3F5FFF4EFFFEEF7FFF1F8FFF3
F5FFF2F9FFF8F9FFFFFBFFFFFCFFFFFEFEFFFDFAFFFCF9FFFAFDFFF0FFFFD0FFFA3B7F72
569C91D6FFFFE6FFFF00040B62656EFFF9FFFFF2FCFEE9F2C4AAB3E1C8CEBAA5AAFFF8F6
F9FBF0FBFFF6FAFFF9FBFFFFFCFFFFFCFFFFFEFEFFFBFCFF
CCE490D8F19DC2DE8ACCE997D5F4A4C3E495D2F2A6C9EB9EC8EB9BC6E997CBED97C7E992
CAEB90D5F496D0F08FC7E88DCAEB9CB9DB91CAEBA4CEF0A6C3E59BC1E399C8EAA0D1F2AB
C1E29DCFEEAAC9E8A5C4E1A1CEEAAFCBE7ACC4E0A6CFE9ACDBF5AEB1CE8BDEFECCF5FFE8
FEF0E3FFF5EEFFFFFAF4FFFBEDFFFDE7FFF4BFEEC2B2E9BF5A9B877AB5B1E4FFFFEDFFFF
F7FFFFF6F9F2F8FFEEE5FAD3C8E5ABC0E49CC2E998C9F19BC9EF9AC7EA9AC9E9A0CDECA9
CBE7ADC5E1AEC7E3B3CEECB6C4E59EC5E79AC8E89FCAE9A5CAE9A6CAE9A6C7E99FC5EA9A
C6EC95C2E990D1F4A2C6E49ECAE1ADCFDEBDF7FDEFFFFFFBFFFCFCFFFEFFF9FDFEF7FDFB
FCFEF9FFFFF4FFFDEACEBFA0CABD90A4A267949F5AC3D58BDCF2AAD2E5A5CED7A0BAC289
6C76312D37009499579B9A62A8A1739C906A7B6C4D605036645639CBC2A1F5F3CAD7DEAA
D0E0A1D3EDA4CBEA9AC5ED97C2F3A2BCF29EBDEE95C0ED90C7EC8CCAED89CFEA89CEE789
C4DC84CBE38FDAF5A4C3E495BFE697CBF6A7B9E898ABCB80A09A5E665623DADBB1E7FDD7
D3FFE1D2FFF784D4B9398B74002E1A85B9ACE4FFFDF1FFFFD9F5F85D8D8F97E6E3CDFFFF
EAFFFFF9F8FEFEFEFFFCFCFFF3F3FBFCFFFFFBFFFFF9FFFFF9FFFFF8FFFFF7FFFFF7FFFF
F5FFFFE7F3FFF5FFFFF9FFFFFFFCFFF6F2F3F9FFFAF5FFF4F5FFF1F9FFF1FFFFF3FEF7ED
FFFEFAFEFFFDF7FFFFF4FFFFF7FFFFFEFFFFFFFAFFFFFBFFFDFFFCF6FFFEF4FFFFECFFFF
64908F83BBB8D3FFFF00100E0005091411180D00021800051C070C0E0002070000040000
35343084858071726DFBFBF9FFFFFFFDFDFDFBFBFDFFFFFF
D4F19FB3D080E1FFB4C7E99FC0E39FC1E5A5C2E8ADBEE6AABFE7A9B7DFA0D4FDB7C7F0A2
B7DE8BC7EE95C7EC8DD1F7A0D2F9B8BCE3AAC0E6ADC2E5ABCEF0B3C5E5A6CDEBABBBDA97
CEEBA9CDEAA7D2EFACCFECA9C7E6A3D0F0ADD2F2AFBFDE98CCE69CCDE6A5DFF8D1E7F0DB
FFFCEDFFF4EBFDF9F8F7FFFFE0FBECE5FFECC3E6BEC9F5D471AEA73E7D86DBFFFFE9FFFF
F8FFFFFEFFFBF6FFECDEEECACCE5AECFEEAACDEE9FC2E591C3E493C8E99AC6E49CC0DD9B
C3E1A3CEEBB1CCE9B3C1DFA1CAEB9ACBEC95CAEB9ACAEA9FCAEBA6CAEBA6C9EDA3CBEDA0
CBED99C8E893D1EC9FCAE09FDEEEC1E0EAD1F6F9F2FEFCFDFFFBFCFFFDFDFAFFFFF7FFFF
F8FFFDFCFFF4F6EED9C0B692C1BB87CED390CBE290CCEE97C1E792C1E196D7EBACD3E1A4
C1CA87919653A5A46B7B7543594B267F6C4E9E856FBDA792BCAA94F2E7CBF7F5CFD4E0AE
CCE4A6C8ECA2BFEA98C1F19BBFEB9CC0EB9CC3EA9BC8E998CDE897D0E795D3E695D3E494
E5F5AACEDF98CFE39ED5EBAACAE6A9CBEAAFC3E6AEB0C78FAEA972918553D2D7AFCBE4C4
9CCEB373BBA52479642576656CA59CCAEAE7F8FDFFFFFDFFF2FFFF5A89933B9699B7FFFF
E3FFFFE8F9FFD4E5EFE7F9FFE4F6FFD6EAF5E9FFFFEAFFFFE6FFFFDBF9FFE5FFFFDEFFFF
CBF0F9ACD1DA94B9C2D9F4FDFCFFFFFAF8FBF9FFFBF6FFF7F2FDEDF6F8EAFFFCF4FFFBF6
FFFBFBFFFEFFF5FFFFF2FFFFF5FFFFFCFFFFFFFAFFFFFAFBFEFFFAF7FEF7FFFEFFFBFFFF
AFCED378AEAE99DED914514C000809706F758F78807A5F66917E808B8180888485868485
6564623B3A3842413F6A69678B8A886C6B69969593F1F0EE
C5EBA2D1F9B3C1E9ABB0D8A4E7FFE6E4FFED517D642A5740628F78C4F2D6B4E4BEA7D7A7
C6F6BAC1F3ACBDEE9FAFE19CB1E1B7E2FFF3E2FFEDE3FFE8EBFFE6F0FFDFEEFFD6D4EDB3
D3ECABC9E59BC2DE91C2E48EC1E88FBAE589BEEB8CCFF69DC6DC94E5F2BDDDEACCD4D6C8
FFFBF4FFF9F8FFF9FFFEF5FAFFFFFAFEFFF3F4FEE3F2FFF1C8F5EE30676A95CBD5D6FEFF
F5FFFFFFFFF8FFFFF1FFFFE7F5F7D2EAEDBEE3E8B2D9E1A6D5DFA2E1EFB1DDEDAECDE0A0
D9EEADF5FFC7F2FFC4D4EEA5CBEB98C9EB95C8E998C7E899C6E89CC8EA9EC9EB9ECAED9D
CBEC9BCCEB9DCDE7A0CDE0A8F8FFDCF7FFE7FAFDF2FDFCFAFFFCFFFFFAFEF8FEFEF7FFFF
F8FFFFF0F6EAE8E1CEB9AF8CCFC997E3EAA7D8F1A0CAEE97BEE592C4E69AD7F0AFD2E2A4
CFDB99D8E1A0DEE3ABE7E6B6D3CBA6FFFCE0FFF6DFFFFCE7FFF8E2FFFFE6EEEFCDCFDCB0
CDE4ACC7E7A4BCE599C9EDA3CBE1A0D1E0A7D4E2AFD4E1B3D1E0B5D0DFB4CEE0B0CFE0AC
CFE1A7C6D59AE6F3BBECF4C3E6EAC7D9D9C1B1AFA3D4D9C5C2D8A9D2EFB76A8359294627
8AB49E9ACDBCD9FFFFDCFFFFF1FFFFFAFBFFFFFAFFFBF3FFE3F9FFABE4EB43A5A6268F8B
39807C49827C37706A45807A46837E3A787365A6A089CCC5C9FFFFCEFFFFCBFFFF70BBB4
2E7974317E780A575179B4B2F2FFFFFEFFFFF9FDFCFCFFFBFFFFF6FEFAEFFFFAF4FFF9F6
FFFBFDFFFEFFF8FFFFF5FFFFF8FFFFFCFFFFFFFCFDFFFCFBFCFFFAFBFFFBFFFCFFF8FDFF
D6F5FA4E8182397E7946837E000B0C727177FFECF4FFEEF5FFF9FBFAF0EFFFFEFFF2F0F1
F8F7F5FEFDFBF9F8F6FBFAF8FFFFFD757472838280636260
B5E3A3B8E8AEB6E6B4C7F7D1CBFBE1D4FFF651847D477B771549457FB7AEA6DDCAC2FADD
BBF4C9A6E1ABC6FFC3B2EEB876B59A427F6F477C6AE2FFFBE3FFEEF0FFEDF2FFE3C4D3AA
D2E2B1CDE0A8D5EEADD4F4ABC2EB9CBCEE99BCF49BB6EC98C5ECA9BFDDABB3CEADCDE2CF
F0F7F0FAF8FBFFFBFFFFF7FEFFFAF9FFFBF2FFFEEFECF8EAE9FFFF57898863A0A3D9FFFF
EBFFFCFBFFF5FBFCEEFFFFEDFFFFE8F1EACEE3DEBEDADBB3CCD3A7D8E6B1D4E8ADC7DD9C
D4EBA5F2FFBEF2FFB9D8F19ECBE898C8E998C8E998C7E897C6E999C7EA9AC8EB9BC9E99D
C5E399CCE7A4CBE0A7CDDDAEFCFFE4FEFFEDFDFFF2FFFFFAFFFCFFFFFCFFF6FCFCF7FFFF
F4FFF9F5FBEFEDE6D3B4AB8AD1CE9BD9DF9FC5DD8FC3E994C6F09EC2E89BCCE7A4C7DC9B
D4E4A3E1EFB1C3CE94D8DEAEDFE1BAFFFFE3FFFFE6FFFFEAFFFFEAFFFFE8E6EDCBD1E0B5
D3EAB6CEECB0C6E6A3CBE8A6D3E2A7D9E2ADD9E3B1D4E1B3CEDFB3CAE0B2C9E1B1CBE3AF
D9F0B8D3E8B0FBFFD6F7FED4FFFFE6FFFFEFA1948EDFE6D6BCEEBD73B075001100C4E2C6
BFE0CDE0FFF4D5F6EDF1FFFFFFFBFFFFF7FFFFF6FFFFFBFFE4FFFF92D1D624838550B2B1
9EE7E0C5FFFAD5FFFFB8F7EED2FFFFD0FFFF2F756B31796E3C857A2672682B786E247469
72C2B7C7FFFF88D9D07ABBB7E5FFFFF9FFFFF3F8FCFCFEFDFFFEFBFFFCFAFFFBFAFFF8F8
FFFCFFFFFEFFFCFFFFFBFFFFFBFFFFFEFFFFFFFEFBFFFFFAEEF6EBF7FEF7FFFDFFFBFFFF
EAFFFF84B7B8529792BDFAF500080976777CFFF0F7AA8F96FFF4F5FFFDFBF8F4F5FFFEFF
FFFFFDFFFFFDFFFFFDF5F4F2FFFFFDFFFFFDFFFFFDFBFAF8
B7EDB9C6FCCB477E567BB493AFE9D30B453965A09C19555500313099DAD67EBDB42C6D59
5C9F808ACEA773B88B3B865D398D7573C6B652998996CCBFDAFEF4F1FFFBFBFFF8FFFFF4
FDFBECF3F6E1F9FFECF1FFEAD7FFDBDDFFE8D5FFE8AEF9C1AFFDBF90DBA08ACFA08FCFAD
C1F7E9BFE8E4E5F9FAF7FBFCFFF7F6FFFCFAFFFFFAF8FFFDEBFFFF85B7AE468E8B71B6B1
DDFFF6F2FFF6EFFBEDF6FCEEFFFFF4FFFFF3F6FBE7DAE8CEC4DEB9C6EABAC3ECB0BAE59E
BFE89AD1F59ED6F49ACCE891CAE99DCAEAA1CAEA9ECBEC9BCAEC98CAEC98C9EA99C9E79D
C6E09FD0E7B1D1E2B8D1DCBCFEFFEDFEFFF0F9FBEDFFFFF8FFFBFBFFFEFFF8FFFFF5FFFD
F7FFFAFCFFF4F2EDD7A59C7BB2AE7ED2DB9CCEE99CC8EF9CC5F09EBBE495C8E6A0CEE7A3
C6DD99DCF1B0D2E4A8DCEDB7E2EFC3DEE8C3DFE9C7E0E9CCE8F1D4F4FFDFF1FFDCE6F7CD
E3F9C8E2FBC4D5F1B6CAE6A9CFE7A9D1E7A6CEE89FC9E898C6EA92C4EC93C4EE98C6EFA0
B6DB95BFE1A5E3FECBE7F9CFD9E5BDE9EFC9C4C69FE4FFD2A2F2B7166B3487B591CDE6D0
C2D9C9E4F8EDF4FFFDE6E8E5FFEDF4FFF1FCFFEAF6FFFCFFBDE0E458999B4DA0A4C4FFFF
DFFFFFE9FFFFD8F8F7E7FFFFDFFFFFD8FCFAE4FFFF61898888B2B07CA8A7A3D1CFAEDFDC
D1FFFFDCFFFFADDFDE628E91D9F7FFF1FFFFF8FFFFFFFEFFFFF7FCFFFBFDFFFBFCFFF8F9
FFFDFFFFFEFFFFFDFFFFFEFFFFFEFFFFFFFDFEFFFAFCFFF8F9FFF8FCFFFBFFFDFFF4F9FF
E0FDFF95C8C930757087C4BF000F1024252AFFF8FFCCB1B8FFFAFBFFFDFBEEEAEBFFFFFF
FFFFFDEDECEAFCFBF9FFFFFDFFFFFDFEFDFBF9F8F6FFFFFD
2F673A175023326C440016008BC7AB09492F74B3A052958343867571B6A4094E3B3D836B
68AE92509A79A5EFCC76C3A382D4BD92E1CE559C8A548E7FBBE6DCCCEBE3DFF4EFF7FFFF
F8FFFFF7FFFFEBFEFCE9FFFFE6FFFFA3D0C950857B4B8C7404542136874C4B945F003811
71B5A6BAF1EEEAFFFFF8FFFFFFFEFDFFFDFFEBF3F6EFFFFFE8FFFDD5FFFD9FF0EA327F79
92BBADF4FFF8F9FFFAFBFDF8FFFEFDFFFFFBFCFFFAEAFCECDBFCDFD7FFD9CEFFC8C4F5B4
C2EAA1C7E698D0E392D0E296CCE5A4C8E6A6C7E6A0C7E79BC7E995C8E895C7E69ACAE5A2
D9F0BCE3F3CCEAF4DBE3EADAFFFFF4F9FBEEFDFDF1FFFFF6FEF9F6FFFFFDF8FFFBF4FFF9
F7FFF6FCFFEFECE8CD908B659A9764D6DFA0D5F1A6C0EA96C0ED98C4EF9DCDEFA3CAE59E
C8E39CCBE69FCAE5A2C6E0A3D1E8B2BFD5A6D2E7BCE1F6CDD4E9C2EDFFDBF5FFE1F5FFDD
EDFFD2EDFFCEE1F9BFCAE7A7C6EAA2C3EA9BC1E991C0EC8BC3F089C6F38CC6F290C6F197
D5FEB0CDF2AFB5D69FD0EEBC7F9B6A8AA572BFD8A17FAF752C854D257C4FC4ECD1C7D5C6
C9D5C9DDE9DFF7FFFAFFFFFAFFF6FAFFF1F9FFEEF6FBFFFF8EBAB976B3B4BCF8FFD3FFFF
EFFFFFF3FDFFF8FFFFF4FFFFEDF8FAF5FFFFF4FFFFF2FFFFEFFFFFE7FCFFEEFFFFE9FFFF
EDFFFFEDFFFFE0FCFF6F8E933A626C5E8290E1F3FFF0F2FFF6EEF9FFFCFFFFFEFFFFFFFF
FEFFFFFFFEFFFFFCFFFFFBFFFFFDFFFFFFFBFBFFF8F8FFF6F9FFF8FCFFFBFEF9FDFCFFFF
EAFFFFD5FFFF599E997BB8B3C5E1E2000005FFEBF2FFE9EFFFFBFBFFFEFBFFFEFFF1F1F1
FFFFFDFFFFFDFDFCFAFFFFFDFBFAF8A4A3A1DCDBD9D1D0CE
3B7046255D30A1D9AA0E4816185420001B006EAF7750955E0036003E8452001D0030774F
70B69231785897DDC1AAECD1397158BEF4DA8AC0A6286047508A718CC6AE92CBB8C2F8EA
8CBFB6A9D7D4B1DADEDAFCFFEAFFFF8DA3BA4D5E7A879FA947745592C290A0C494123514
54837BD9FFFFF1FFFFF3F8FBF8F8FAF9FFFFEBFFFFE3FFFFE0FFFFC5FFF579D3D1075756
799692F2F1EDFFFBFFFFF6FDFFF3FEFBEBF5FFFDFFF1FCF4E9FFEFE5FFE9DBFFD8CEF3C0
CDE4AED8DFA9E5DBA6E0DAA8D7E7B8CDE8B5C9E5A8C6E49EC5E498C9E59ACEE7A3D2E7AF
EDFDD8F0FCE6FCFFFAF8FAF7FFFFFDFBFAF5FFFFF6FFFFF4FFFDF4FEFFF6F2FFEFEDFFEA
F0FFE6F9FFE4E2DFBC908C5FA3A06BD5DE9DCAE699B9E38FC6F39EC8F5A0C9EE9EC3E495
D0F1A2C4E596CDEFA2CAECA2D2F5B1C6E8ABC2E3AABFE0A9CCEDB8DBF9C5E8FFCFE7FFC9
DFF6BEE3F8BFDFF3B8C8E6A0BEF097B6EF8EB7ED8DBDEE92C6F198C9EF98C6E894C0E190
C2E296A8CA8080A560BAE2A398C58AB9EAB2C6FBC560A06E388D63B7FEDED5E9DDF1EEE9
F9FCF3E8F4E8E3FAE8F6FFF5FFF7F1FFF9FAFFFFFDECFFFE9ED1CC84BABCCCEBFDF4FFFF
FCFFFFFFFBFFFCF7FDF2F0F5FFFEFFFFFEFFF3F4F9FCFFFFF5F8FFFBFFFFF9FFFFF5FCFF
F5FEFFF8FFFFF7FFFF9DB6BD508690437D89E7FFFFF4FFFFFEFEFFFFFEFFF0F5F8F2FCFD
F8FFFFFCFFFFFFFCFFFFFAFFFFFBFFFFFEFBF9FFF6F7FFF6F9FFF8F3F5F0FFFCFFFCFFFF
EAFFFFD1FFFF5FA19D72ADA945616204050AFFF8FFECD3D9FFF4F4FBF6F3FFFEFFFFFFFF
F7F6F4EFEBE8FFFEFBFAF6F3F1EDEACFCBC8FCF8F5FFFEFB
C5F4C6AFDFADBAEDB5BDF1B3B1E8A4AFE99FC7FFB7B4F3A4BBFBAF8BCD867ABA7D95D5A1
B7F5CC8CCCAA4584694781684F8166B5E6C8AAE0C085BE9D2461407CBD9B72B5947EBEA3
83C1A869A08D8CBCB085ACA7365255495D66AAB8C5C9DBDBC3E6C5C6EDB8C8DFAB7F9871
4E766DD9FFFFE6FBFEF5FFFFF5FFFFE7FFFFCAF6FF6496A154817C4E837B4893989FE2EA
D7EFF1FFFDFFFDF0F9FFF6FFFFF5FFFFEDFDFFFAFFFFFFFDF4FFF6EEFFF1ECFFE9DDF7D2
E1ECCAF5F2D3FFEFD6F9E9D0E8F1D4DAF0CAD3EBBBCDE6ACCEE7A5D2EBA9DBF0B7E1F2C6
F0FCE4F0F7EFFEFFFFFFFEFFFFFEFFF9F7F8FFFFF6FFFFF0FFFFF1F8FFE9E4F7DBE1F9D5
E1F6CFE8F5CADDDCB09F9967B3B178D5DE9BC8E499C4EE9ACCFAA2B9E78FBFE590D4F6A2
CFF39CC0E68FCAF29CC0EA96BBE495C6F0A4C1EBA3C3ECA6C5EEAAC1E6A3C6E6A5C9E6A6
C9E1A3D1E5A6D6E8AAC8E49AC2F397BAF28DBBEC90C5EC99CDEDA1CDE7A0C4D994B9CD86
8DA35BAFC982C4E5A0D5FEBCB3E5A8B9F2BB73B18061A47BA4EBCDDFFFFFF9F9F7FFF2F4
FFFEFAF2FDEFEDFFF6F0FFF4FFFFF6F4F3EEF4FFFDDCFFF977B3AB96C8C9F5FFFFF8EEFF
F6EEF9FFFDFFFFFCFFFFFDFFFFFDFFFCF7FBFFFDFFFEFDFFFDFCFFFEFFFFF5F6FBFCFFFF
F7FAFFF7FCFFF5FAFFEBFFFF83C8CF317E88DCFFFFDEF8FFF5FFFFF8FFFFEAFCFCF1FFFF
F2FFFFF8FFFFFFFCFFFFFAFFFFFAFFFFFDFBF9FFF8F7FFF6F9FFF8F4F6F1FFFDFFFEFEFF
DFFAFF95C7C83678745D9894627E7F26272CFFF3FADFC6CCFFF8F8FFFDFAFFFFFFF7F7F5
FFFFFBFFFEFBF3EFECFFFEFBF0ECE9B8B4B1FFFEFBFDF9F6
C6ECB3C6ECB1C1E8A9C9F2ACBAE498C5F29FC0ED98BAEA94BBEC9AC8FBAEBFF1ACBDEFB4
C9FACBAADCB683B4967EB59878B798A9ECC9ADEFCB5D9B74457D56C2F7CDB3E2B6BFEABD
BFE9BBC9F0C1C2E8B7B2D8A77AA26E86AE7AB1DCA7CCFBC5B5EDB0BEF2B2C2E5A5587849
265543C0F1EDE7FFFFEAFFFFE0FFFFDFFFFF84C2D13D778554777B9DBAC0B1D7EADFFFFF
EEFFFFF8FFFFD5D2DBFCEEFDFFF5FFFFF5FFFFF3FCFFFCFBFBFFF1F8FFF1F4FFEDECFEE6
FBFFF3FFFFF8FEEFF2FFFCFBF6FEF3F5FFEFE2F6D3CDE0B3CDDFABCFE1ADE1F0C5FBFFE8
FCFFF6FAFBFFFDFDFFFFFDFFFCFAFFFBFBFDFFFFF8FFFFEFFEFFE8F4FFDED5ECC0C4E0AF
CEE6B2CBDAA3E4E4AEB9B47CCFCB8EDDE4A1C9E399C3EA99C7F49FC5F19ACCF099C4E68F
C6EB8EC4EB8EC4ED8FC4EF93C1EF95BEEF96BEEE98C0F09CBEEB9AC8F1A2C3E89BC3E39A
D7F1AAC8DD98DEF2ADC9DF96C3E38ECFF19ADBF6A7CDE199CEDA9AB7BF8492955CA1A46B
B4BC81DAE8ABD3E8ADC6E5ACBFE7B34F7E5010471DB1E8C8DFFFFFEEFFFFFFF9FFFFF5FD
FFFCFAFBFFF6EDFFF6EBFFF6F2FEF2F5FFFBE6FFFED8FFFF87CBC08CBCBCFEFCFFFFEDFF
FFFCFFFFFFFDFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFBFFFFFBFFFFF9FFFF
F9FFFFF8FFFFF8FFFFE6FFFF71C2C5318C91D0FFFFE0FFFFEBFFFFE6FBFEEAFFFFE9FFFF
EDFFFFF4FFFFFFFDFFFFF7FFFEEFF6FFFDFBF5FBF1F5FFF3F6FEF3FEFFFAFFFCFFFEFEFF
DFFAFF83B5B61759557EB9B500080934353AFFF9FFCAB3B9FFFBFBFDF9F6FFFFFFFEFFFD
FFFEFBFFFCF8FFFCF8FDF8F4C8C3BFE3DEDAFEF9F5FDF8F4
C3E0A0C7E4A2C7E4A1CCEAA4C7E59DCEECA2CDEDA2D1F1A8C0E19ACFF2B0CAECB0CAECB9
DAFED2D0F4CEC1E4C3C6F3D688C7AC367B5F5A9B7DCFFFE7D6FFE5B0DAB2C9EDBFC7E8B3
BEDBA1D0EEAEC7E8A1CDF3A6C0EB99C1F19BCAFFA5B4EB97B6EEA5C2F3B1CAE8A8C4E2B0
39654E5382787FAAA1C3F2EAD8FFFFBCFFFF67B9C43A8791609094DAFBFFE6FFFF83A4B5
4F7373B0CFCACEE0E2989BA4827684FCE8F4FFF8FFFFFAFAFFFFF3FFFFEFFBFFEFF6FFF2
F6FFFCF4FDFFEFF5FFF9FFFFF7FFFFF8FFF6EFFDE6E6F3D5F2FED8F1FDD7EAF3D6F1F8E6
FEFFFBFFFEFFFFFDFFFFFDFFFFFEFFFEFFFFFEFFF6FEFFECE7F1CCDFF1BFCDEAB2C8E8A9
D2ECABCFDF9EDDDDA1999357B1AB6FD7DC9CD1E8A2C2E79ABEE798BCE692CBED99CAEA95
C7EB91C7EE91C8F193C7F394C4F194C1F092C1F094C2F195BFEB92C4EE98C8EE9BC2E193
D6F0A6C8E096D9EDA6D3E7A0CEE29BC6DA93A5B672BCC8889CA66990985DDFE6B0D0D9A4
E4F0BECBDBACC1D7A9D7F4C873966C153E165F8D68D4FFE3E9FFFFF8FFFFFFF6FFFFF4FD
FFFAFAFEFFF6F1FFF6EEFFF8F5FFFAF1FFFDDAFFFD4C8A7D226A5EA1D3D0FFFDFFFFF7FF
FFFCFFFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFBFFFFFBFFFF
F9FFFFF9FFFFF9FFFFE7FFFF5FB3B5207F83C9FFFFDBFFFFE6FFFFE9FFFFE2FFFFE4FFFF
E0FFFFF0FFFFF1F5FEFFFCFFFFF6FEFBF5F7FCFFFAF9FFF8FCFFF8FFFFFBFFF8FDFEFEFF
EBFFFF90C2C33E807CC3FEFA000809090A0FFFF9FFFCE5EBFBEFEFFFFEFBFEFFFFF1F3F0
F8F4F1FFFEFAFDF8F4B2ADA9E3DEDAE8E3DFFFFEFAFFFEFA
D4EAA2D8EDA8D5E8A8CEE0A4D2E3ACCBDBAACBD8ADCEDDB6C7D5B1F1FFDDF8FFE6F7FFE8
F5FFE8DDF3CFCEE4C0D5F3D74E7E70538880C5F7EBE0FFFDD1FBE3CCF1D0BBDBB2D0EEBC
D4F0B5CEEBA8B8D78BC2E591CDF499BBE484BEED87BEE98DC7EBA3C7E0A6DEEDB6C9D8AD
E0FEE6D9FFF40010045391869EEEE3A6FFFD88F5F21A817E6EBBB595D3CE0E4548144C4B
4989792D6B5655847A9EBCBAF0FBFFEAE7EEFFF7F9FFF8F3FFF9ECF6EFDCFFFFEDF8FFF4
F0FFFFE9FFFFE2FFFFE4FFFFF5FFFFFBFFFAFCFFF4EFF6E4F7FCE6FDFFECFFFFF1FFFFF6
F5F5F3FFFFFFFFFEFFF7F6FBFEFFFDFBFFF7F6FDEDFBFFE8D4E4B5CBE3A5C6E6A3C8ECA2
CFEEA2D3E49DDCDD9B82793EA69D66D9D8A0D7E9ADC8E7A4C6EAA4C4E89ECFEBA0CEE99C
C5E592C7EB94CAEE96C8EF96C4EC93C2EA91C2EB8FC3EB92C7EF96C6EC95CCED9CC3E294
CFE99FCCE39BC6DB96D2E4A6E2F0BD84926192A36CC2D697C5DE9AC9E6A3C8E6A8C9EAB3
DEFFD4EBFFECE0FFE9B0D2BA2042275B7E5EC8EAC5DDFBDFF0FFFFFBFFFFFFF7FFFFF5FD
FFFAFAFFFFF6F9FFF8F7FFFAF1F7F5F2FFFFE0FFFF498B8160AA9DD9FFFFF8FFFFFDF0FA
FFFBFFFFFDFBFFFCFDFFFCFDFFFDFDFFFDFDFFFDFFFFFDFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFEEFFFF6AB4B72E8889CCFFFFD9FFFFDAFFFFDAFFFC90B8B082AAA2
C3E5E4E5FFFFEAF7FDFBFFFFFFFEFFF3F3F5F6FBF7EAEFE8FCFFFAFFFFFBFFF7FDFFFEFF
EDFFFF95C5C73D7F7B8EC9C5001A1B000005FFF5FBE9D2D8DED2D2FCF8F5FEFFFFFEFFFD
FEFAF7FFFEFAFFFEFACFCAC6FFFEFAFEF9F5FFFEFAFBF6F2
D0E19BD1E1A0D0DEA3D3DFADEDF5CEEDF1D6ECEFDCF3F3E7EDEFE4F6F7EFF2F4E9F0F4E5
FAFFEDF6FFE5E9F4D4DEF4DDE3FFFF9CCCCC6F9C99E5FFFFEBFFFDE2F9E5DAEDD1EAF8D4
D5E2B6EAF8C3EEFFC3C5DF98C8E89CCEF4A1BFE993C7EC9CC7DD9DD9E3B1DEE4B8CED5B3
F7FFEFEBFFF7E5FFFF9FD4CE39807A3C8E8A247F7A004842165C54164F461D4A45417165
5493784C8D6F053A269BC3BAEEFFFF9AA4A6F4F0F1FFF8F5FFFBEFFFFAE8FFFFEAFFFFEF
E7F8EEEAFFFFE2FFFFDFFFFFE6F4F4F5F8F1FCFDF5FFFFF6FFFFF6F3F3E9B6B3AA817E77
C3C2BDFAF9F4FFFFFAF7FAEFFCFFF3FAFFEEE8F2D9E5F5D0D2E7AFC5E39DC4EA9DC5EC9B
C7E794D3E599E6E5A4857A42B6A877DFD8AAD4E0B0D1E9B5DFFCC2D6F4B8D0E6A6CBE09F
CDE8A3CFEDA5D1EFA5CDEDA1CBEC9DCCED9CCFF19DCFF19DC8E998C2E392C5E498D6F1AA
CFE8A4D6EFAE99AF7191A87271865FACC29EC9E4BBC7E8B9C0E6B3C0ECB9C4F4C4B7E7BF
AAD8BB8DBAA5628B7D001A0F8BAB9EB9D5C7CEE7D4D2E6DAF5FFFFFCFFFFFFFAFFFFF9FB
FFFBF8FFFEF8FFFFFAFEFFFDFEFFFFF1FFFF97C3C238776F83CBBFCFFFFEF5FFFFFFFBFF
FFFDFDFFFEFBFFFCFDFFFDFDFFFDFDFFFEFDFFFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFF2FFFF74AEB23E858984C0C16B9D9C446E6A648C846D928B9FC4BD
6D908C7D9B9BE8FFFFF2FFFFEFFAFEF9FFFFFCFFFFFCFFFDF4F7F0FFFFFBFFFBFFFEFDFF
EDFFFFCFFFFF7CBEBA55908C000809000005FFF9FFE0CBD0FFFCFBFFFFFBF4F8F7F7FCF8
FFFEFBFAF5F1DFDAD6EDE8E4FFFEFAFFFEFAF9F4F0FFFEFA
D8EAACD4E3AAD2DEAEE3EBC6F9FDE6FFFFF4FFFCFBFFFCFFFFFCFFFFFDFFFFFDFFFFFFFD
FFFFF8FEFFF1FCFFEBF4FFF4D9FFFF7CB0AE749E9CEAFFFFE8F8F7FEFFFDFFFEF8F8EAE1
FFFCEFF3E8D4F7F6DAD4DEBCC7E0B8BCE0B28AB685C9EFBCA7B4866769423237173A4026
000300676F62F4FFFFE2FBFFE7FFFFD9FBFFE9FFFFEBFFFFE7FFFDEFFFFAFCFFF6ABB49F
83A17FD4F9D70013009DBFB1EDFFFFEBFDFFF5F9FCC5BBBA958178A98D7FEDD2BDFFFCE6
FFFFEDFBFFF6EAFFFAEBFFFBFBFFFAFFFFF6FFFFFAFFFBF8F6F0F0F6F0F0F8F3F0F7F2EC
A3A194ECEED9FFFFEAFEFFE6FBFFE4F5FFE0D8E8C4CBDEB1D0E8ACC7E79EC7F19FC4EE98
C2E48ED1E495ECEBAB948753BFAD85E3D9B6D7DDBBDEEFCBF3FFE2DFF6CAD1E1B2D5E3B2
CADEABCBE2AECAE1A9C8DDA4C8DEA0CDE3A3CFE5A4CDE4A0C8DF9BD8EEADD6EEB0D1E9AD
8299639DB5818DA575B3D2A6CAF4CE98C6A989B9A18EC1B0A4DACD8CC4BB427B72306A5E
578D805C8E82B5E3D8E1FFFFE7FFFFEEFFFFF1FFFFF5FFFFF8FFFFFCFFFFFFFEFFFFFEFB
FFFFF8FFFFF8FFFDFDFFFCFFFCF9FFF5FFFF94BBC079B1B0CDFFFFD9FFFFF4FFFFFDFDFB
FEFFFDFCFFFDFEFFFDFCFFFDFCFFFDFBFFFDFCFFFFFBFFFFFBFFFFFBFFFFFBFFFFF9FFFF
F9FFFFF9FFFFF9FFFFF4FFFFE6FFFFB2DDE495BEC293BBBAA3C8C1D9FAF3EAFFFFEBFFFF
EAFFFF304F51698B8DE2FFFFDEF6FAE5F4F7F4FCFFFEFFFFFFFFFBFFFBF8FFFBFFFEFDFF
E6FFFFDDFFFFC5FFFF48837F000E0F000005FFF1F7D6C1C6FEF4F3FFFFFBFAFEFDFCFFFD
F9F6F1FFFEF8D0C9C3EEE7E1FFFEF8EDE6E0AAA39DF3ECE6
E0F2C0DAEBBEDCEBC4FCFFE8F2F6E5FFFFF8FFFDFEFFFCFFFFFAFFFAF2FDFDF6FEFFFDFF
FFFFFDFDFEF6FAFCF1F7FFFABADDD94F777694B4B3EAFFFEF9FFFFE3E1E2BCB0B0CCBABA
F2DFDB8D7E77746D636B6D5F5E6D5A5D755F17371F577154313616040300020B002B3423
151604070700DEE6E8F7FFFFF8FFFFF9FBFFFFFBFFF4EBECFDFFFCFEFFF6E4E0C5BAB892
8A9368E7F9D1122F117BA08ECFFAF1D0FAF8E0FFFFF2FFFFEDEEE0C5B9A3D3BEA1F8E1C2
FFF0D1F0ECCFEAF2DAFBFFEFF8F9E7F9F5E9FFFBF5FDF4F5E5DBE3E2D9DEFCF2F3FFFEF6
D1CFBAF1F5D4F7FED4E7F3C3E4F4C3DEF0C0CDE0B2C6DDA9C6E3A1C7E99DC7F39EC6F09A
C7E993CFE195E8E6A9A08F61BAA586F2E2CBF0EFDBEFFBE5F5FFEDE7F7DAE1EBC9F3FAD9
D4E2C1D6E5C4D4E2BFD0DFB8D5E2B7DCE8BAD9E5B3D0DDA8D6E4AFD4E2AFC9DBA9BDD0A2
72895FA5BE97C6E0BBDBFFDCAFE9C35194714F9078074536003933437B7A1D505121524F
83AEA7C8F0E7E8FFFFE8FFFFF1FFFFDEEBFCF7FEFFF1F5FFFEFEFFFEFFFFFBFFFDF9FFFA
FBFFF8FEFFFAFFFDFFFFFBFFF6F5FFF4FFFF90B6C17DB0B3C1F3F0E1FFFFF8FFFBFFFFFA
FCFFFBFBFFFDFBFFFDFBFFFDFBFFFDF9FFFDF9FFFFF9FFFFF9FFFFF9FFFFF9FFFFF8FFFF
F9FFFFF8FFFFF9FFFFF8FFFFEAF4FFF0FEFFEDFFFFEDFFFFEBFFFFE7FFF9EDFFFEE3F9F6
EDFFFF486A6B133D3CA0CCCDE6FFFFEDFFFFEBF4FBFBFCFFFFFFFBF8F4F1FFFBFFFFFEFF
DAF3FADBFFFFCCFFFF3A7571000809000005C6B5BBEBD6DBE8DEDDFFFFFBFCFFFFF2F7F3
FCF9F4FFFEF8FDF6F0FFFEF8FFFEF8E8E1DBB4ADA7C7C0BA
ECFFDEE5F8D8DDEDD0E8F5DB8A937E82867771736872716CB3AFAC635F5E262223272324
3432332B2B2B101012000102030D0E000A0A000302000400040D08000300000300040700
000200000200090B0025281D3B3E339FA599848A8077796B7F7A64F7F6E2E2F3E9F1FFFA
F1F5E4292B1D050D109CA2B2FDFAFFFFF9FFFFECEEFFFAF3F8FBF0D9EBD1E7F9C7D2DDA1
929159E2E8B8617D57568B6F9BE5D43B8F8234867A397E6CE2FFF6C1D9B7B3B88FC5BF8F
DDD3A2DAD4A4D6D8A9FDFFD7DAD6B9BAB5A2C3BAB3EDE3E4FFFAFFFFFBFFFFFBFDFCF4E9
FCFBDDDADDB2C3CC93CDDC9BD8EBABD1E7A9C9E0A8CDE6ACC3E29EC6EB9EC2EE99C2EE97
CEF09CCEE096E4DFA7A9976FB69D87FFF1E6FFFFF6F6FBF4F8FFF8F5FFF1F5F8E5FFFFEF
F8FEF0FAFFF5F9FFF0F8FDE9FEFFE9FFFFE4F6FAD7E4E8C3DDE3BDABB38EB1BD99CCDDBB
E4F8DCF1FFEFF0FFF376A185468F646BC1907CCB9EB3F7CEBDF6D3B1DEC1E4FFF0EAFFF1
EDFAF1FBFFFDE8EAE7FFFFFFFAFAFAFFFFFFFFFFFFFFFEFFFFFCFFFFFEFFF7FFFBF1FFF8
F2FFF8F7FFFBFEFFFFFFFDFFF4FBFFD3E8FB668D9C96C2CBD8FEFFF0FFFFFDFEF8FFFEF6
FFFFFBFFFFFDFFFFFDFFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFF
FEFFFFFCFFFFFEFFFFFFFDFFFFF8FFFFF9FFFBFEFFEAF8F8F1FFFEF2FFFDF7FFFFF5FFFF
E5FAFBE7FFFF8BBBBB487B7C508080D7F9FBF5FFFFFEFFFFF7F8F3F8F4F1FFFAFFFFFDFF
EDFFFFDDFFFFD1FFFF49848019353603060B503F459E898ECDC3C2F9FAF5FCFFFFFCFFFD
FFFFFAFDF6F0FFFEF8FFFEF8F4EDE7FFFAF4FFFEF8FCF5EF
536A4E5B6F5462745A77856C0006000005000003000305003C3930080500030000010000
0604070000040000070201070100040100000C0C0C0003000003006A766A6A766A728071
798675818C7C747C6FBBBEB3A1A199D3CEC8E1D9D6F6EDE6F6EADAEDEEDEDCF1ECEEFFFF
FAFFEFB8BAAC01080E2B2E3FFFF9FFFFE9FBFFF3F4FFF8ECF8FFEFF1FFE8BCD89BD6EAA2
A59F63DAD8A557734A5D98789BF4DE2D9685339E8C2F8C77CCFFF2D2FCD4C4D6A6A2A26C
9C965CABA267BEBC83F3F1BED0CCA9C3BDA7E4DAD1FFFBFDFFFAFFFBEEF8FCF0F2FDF5E8
ECE9CAA4A876929D5BCBDB92EDFFBBDDF6B2CDE5A7CCE9A9C9E8A4C9EFA2BBE792BCE891
D1F39FCEDF98E2DDA6B39F7CB39988FFF9F2FFFDFBECF1EDF9FFFDF9FFF8FDFDF1FBFBEF
FEFFFBFBFFFDFEFFFAFFFFF4FFFFF1FFFFECF6F5D9DCDDBECECFB0AAAF91DEE9CBE8F6DC
F4FFF1EAFFEDEEFFF84D7B612E8052A4FFCBAAFFC89BE4ADBEF6C5C9F2C6E6FEDEF9FFEF
FFFFF4FEF4F2FFFBFBFCF0F0FEF3F1FFFEF6FFFAECFFFFF3FFFAFDFFFDFFF4FFFAEDFFF8
EEFFF8F2FFFBFCFFFFFCFEFFF5FFFFABC4D8173E4FA6D1DAE9FFFFEEFEFBFFFDF7FFFDF4
FFFEFBFFFFFDFFFFFDFFFFFDFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFBFFFFF2FFFFEFFFFFFCFFEEF7F6F7FFFDF5FFFBF3F9F7F6FFFF
F2FFFFD9FBFCDBFFFF99D4D236696AD0F6F9F3FFFFF9FCFFFDFDFBFFFEFBFFF7FEF4F1FA
EDFFFFDDFFFFCBFFFF44817C1B37380002070B0000614C51FFF5F4FFFFFBF3F7F6FAFFFB
F8F5F0FFFEF8FFFBF5FFFEF8FFF9F3FFFEF8FFFBF5FFFEF8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.65873 0.984127 0.97619 1.30159 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37257e-018 0.00502513 -0.00502513 0.00502513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00503 translate
1.00503 1.00503 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
8CCDC93B827A328978347E6795B8A2D6EECEC0E1B2C1E6B39FB891F1FFF145695F3C6665
4A7A7A95BDBCF1FFFFF8FFFEF4F9FCFFFEFFFFFCFFFFF6F94846476F7170EBF1F1AECCCA
39807CB1FFFFD7FFFFE6FDFFFFFCFFFFFAFDFFFCF1FFF7E7D9D2CAFFFFF4FCFFEBE3F1CD
DFF3C2C2DBA2BDD69CEEFFCDF8FFDCF7FFDBFCFFE3FCFFE3F9FFDEF9FFDDF4FFD5CAE3AC
CEE7B0C6DEAED4E3C2F1FAE5FEFFF8FCFFF8FBFEF3FBFFEFE3F2D1CFE1B7D0E6B7CBDEB1
E3F0D2FCFFF1FCFDF7FAFCF7F9FFF4F7FFEADBEBBEC7D8A2B0BE8BE4F2BFD6E3B5F5FFD0
CEE0A4CCE0A1D1E5AADFF6BEE4FDC6CDEBADC2E296D3EEA1B7C089CECFA7E8E7C9AEAD99
E0E0D8FFFFFADCD9D20E0C000B0A008E916660652B6E79358FA059B3C980C2DE94C9E89C
C8E893C7E891C5E791C6E796C7EA9AC8EB9BC5EA9AC3E994C0E48CCAEE94DCFDA6B8D883
D6F0A6CEE8A1C2D697E0EDC1747065877E83EDE3ECFFFDFFFFF9FFFFFDFFFBFBFFFBFFFF
F5FAF6FCFFF4FCFFEAE5F0C8F3FCC7FAFFC5B1BB7447540C819550C9E09CD0E7A1CEE69C
D3EEA1C9E495CDE79DCDE79E97B06ED8F0B4D4E6B2C7D8ABE7F5D1F5FFE0F8FFE5F9FFEB
F9FFF4F7FFF6F7FFF1F4FFE8DFFDCBD7FBBDDBFFB8D7FFB2DEFFB7D5F9B1CAE4A7C5D7A7
DCE6C4F3F5E0FFFEF4FFFEF6FFFFF4F9FAF2FFFEFFFFFDFFF8F4FFFFFCFFFDF5F2B8B2A4
FAF4E4FFFFF3FBFAF6EBF1F1C9DDDC496F62D0FFEEA9E5BF000E005F744DC9DDA0CCE19C
C7DD9DD0E0A1989B56C6B776D2AE7AD5B28A0E0100616E40C5EFA3B7E88FC9EA9BD8F0A6
D2ECA3CFE9A0C5E197CBE79DD6F4ACC8E69EC2E19BE2FFBB
7EBCB13F83742B7D66A9EFD3EBFFEFC1D7B3D4F6C4CAEFBB8CA67F4D674C5F7F729FC6C3
CBF9F7E3FFFFF1FFFFF3FEFAF8FDFFF8F9FDFFFCFFF3EDF1A2A0A1080A09525657EEFFFF
33746E408A89D9FFFFE0FCFFFDFBFFFFFAFDF9EDDFFFFFECDBD5C9FFFEF1FEFFECDAE8C4
C8DFABD0E9AFD5EFB2D5EDB3F8FFD8FAFFDBFCFFDFFCFFDFF7FFD9F9FFDAF4FFD3D8EFB9
C9E1ADD1E6BBE1F0D1F3FCE9FFFFFAFFFFFBFCFFF6FAFFEFE6F3D5D4E6C0D8EAC0D3E5BD
E6F0D5FEFFF3FDFCF8FFFFFBF0FCE8EDFEDCCEE0B0C6D7A1CDDBA6FBFFD4DEECB9C7D5A0
D6E5AACEE0A2CCE0A5DCF4BAF0FFD0E3FFC0CCECA0C9E59A8F9A60676941CCCFB0FCFEE9
F9F9F1FCFBF6F6F3EC0301000B0C00D2D5AAD3DDA1D7E49FD0E49CDAF2A8D8F4AACEEDA1
CCEC97CCED96CCEC99CBEC9BCCECA0CBEDA0CAED9DCAED9BD7F9A3C3E58FBEDE89D9F6A6
CCE69DC7DD9CE6FABFBDC8A08B877EF9EEF6FFFBFFF2EDF4FDFAFFF7F6FCECF0F3FBFFFF
F9FFF6FBFFEFFBFFE6EDF8CDD2DDA5BEC987BAC67EBECB83899E59C9E09CCFE6A0CDE59B
D2ED9EC9E495CDE89BCEE89F90A967D2E7ACD2E4B0CEDFB2EFFED5F9FFE3FBFFE3FBFFE8
F8FFF0F8FFF3F7FFEDEFFFDFD2EEBDC6E5A9C8ECA6C7EDA0CAEEA4CBECA5D6F0B397AB7A
ABB592FFFFECF1EFE0F9F5E9FFFFF1FBFBF1FEFFFFFEFEFFF7F3FFFFFBFFFBF3F0C4BEB0
AEAD9BFFFFF3FFFEFBFCFFFFF4FFFF50746AB0EFD2B8F8D5AED2B6001000778C51C8DF9B
DFF7B9CBDE9ED3D691675A16684410B592680D00006B784AC7F2A3BBEC91BEDF8ED1EBA1
8AA45BCBE79DD5F1A7CFEBA1CAE8A0CCEAA2D4F3ADB9D892
97CDB51E5A3E7FC5A0B5F2C9B5D4ABCBE1B3C4E5B0B8DDA7729167678263B8D3C2DDFCF4
E2FFFFDBFFFDE3F9F7F7FFFFF9FFFFF0F4F5F7F2F8FFFCFFFCFAFD6666664746449FAFAC
CEFFFA347473BFF8FFE6FFFFFEFDFFFFF6F9FFFFECB5B498CFCCBBF6F5E3FEFFE8EDFCD3
CBE2AEE2FCBFF4FFCFE1F9BBCFE3A8CBD9A4D1DDABD4E0AECEDCA9CEE1AAD2E7AECAE1AB
D3E9BBE7F8D4F7FFEBFCFFF6FFFFFBFFFFFDFFFFFBF9FCF1FBFFEDEFFCDEF2FFE0EFFEDF
F7FFEAFFFFF6FFFBFAFFFFFAF8FFECF5FFE1E3F7C4CCDFA7B4C68CE1F0B7D3E0A8D3E0A8
D3E1A6E0EFB4E2F6BBE2F7BEE3FBBFD6F3B0C9E99DCAE99DD8EAAED0DCAEF9FFDFF9FEE8
F9F9F1F0EFEAEBEBE3010200020500D3DBACDEECAFDBEFA8CAE097C8E298C6E298C1E094
C9E692C8E893C8E797C7E698C6E49AC5E59AC6E69BC8E89CBEDD8FDAF6A9C6E194D2E9A1
D1E5A6D0E1AAA3B1800B1200BCB4B1FFFAFFFFFBFFFFFDFFFFFFFFFEFFFDFBFFFBEAF5E7
F9FFEFEBF9D8DEEDC2DFEDBADEECAFCEDB96B2C0759CAC63A0B572CCE5A3D0EAA1CCE79A
D1EC9BCAE594CEE69AD1E8A0849A59CDE2A7DEF0BCDCEEBEE7F7CAE0F0C3DDEDC0DEEDC4
EAF7DBEBF9DFF1FFE0E7FCD3CEE6B2C3DFA4C7E6A2C7E79EBAD993D2EFACD3EDB0C9DDAA
D6E5BCB3BC9DF0F5DEFFFFEDFFFFECFEFFF1FEFFFFFCFCFFFFFBFFFFFBFFFFFBF7E0DECF
DBDEC9F0F3E2FFFEFBFFFDFFEBF2F876938F8FD0BAA9EED1D5FFE5C0DBB81C380057722F
BBD79AD9EFAFD8E097877A3674511BA785588E815E5C6A39B4DF8DD4FFA9D1F39FBCD78A
6C883DCAE89EC8E69EC7E59DCDEBA3BCDA92CEEDA7CAE9A3
C9F9D3CCFFD592CE9BB1E6B0E0FBC8CADEA9C1E0A52C4F17000F006F8D69DDF3DCEEFFFA
E4FFFFE4FFFFE4FDFAEDFDFCD3DED8FBFFFDF7F5FAFFFDFFFFFEFFD6D2D3C4BCBA666C68
DFFFFF275F5C74AFB5D7FFFFECEEFBFEF2F2FFFFE64D532FD5D5BBE5E7CFF0FAD7DFEFC2
C8DFA7D4EEAFE3FEBBDCF5B3D2E6A7CDDFA3D2E1AAD7E5B0D3E1AED0E2AED9EDB8E2F8C7
E7F9D3F7FFEAFCFFF3FFFFFAFFFDFEFFFBFFFFFDFEFEFFF9FEFFF3FBFFEFF9FFECFBFFED
FEFFF4FFFFFAFFF9FDFFFFFADFEECDD2EAB8C8DFA7D7EBAEC9DB9DDBEBACD4E2A5DBE9AC
D4E2A7F0FFC6F5FFCDE1F6BBD0E9A8C5E39DC4E498CBEBA0C1D99BD3E5B5CCD7B5DCE4CD
FFFFF6D5D4CFC8C8C0141704383E1CDAE6B6C7D99BD1E8A0CFE99FCFEB9ECEEDA1D5F4A8
D0ED9DD0ED9DD0ECA1CCEAA2CBE6A1CAE7A4CFEAA7D3EEABCCE7A2C3DC98D6ECABC1D598
D9E7B4717C512F3614FFFFEDFFFBF9FFFBFFBDB4B9CDC9C8FFFFFAF2F8ECF9FFF1EFFDE3
F4FFE0E3F5CBD3E5B3CFE0A9D7E7A9DBEAA7D3E39CC7D892BCD291D3ECAAD4EEA5CEE99C
D0EB9ACCE894CCE496D1E99F839958D2E7ACF2FFD0F1FFD1E6F6C5D0E1ADD3E4ADDFF0BC
BDCCA5D8E6C2F8FFDFF8FFDCDDEFBBC8DDA2CCE2A2D1E7A6CDE3A2D3E9A9BBD097E1F3BF
C6D6A9E4F3CC848F6D969D7EFCFCE2FAF9E7FCFFFFF6F9FFFFFBFFFFFBFFFFFEFAFBFCEC
DCE4CDB4B8A7FFFDFBFFFBFFFAF8FFD9F2F66AAF9D9AE6CCC0EFDBCDEED1BBDCA7082800
597B3FC4DE9FE4EEA9C1B674694813B7946A726542697746C0EB9BBFF295AED07CE9FFB7
A2BE73B6D288BCD790D2EDA6D1ECA5C7E29BD3EEA9C2E09A
C0E8B3B8E5ACC7FBB9B4E19EBFD897DDEFB1BFDC9C3C6023173C08708F65C6D9BDF4FFF4
CFF4E2E4FFFFA0BAB7899C9AA7B4ABFBFFFBFFFEFFF3EEF5FFFDFFC1BBBDAB9D9A3D3A33
EAFFFE60918D478489ABDAE4F9FFFFFFFDFAF0FAD7414E20D9DDBAE5E9C6D8E3B8C8D9A5
CCE4A8CEEBA8C7E59FC7E29DD0E6A6D0E2A6D1DFAAD5E3B2D4E1B5CDDEB2D2E7BCE5FAD3
F4FFE8F8FFF0FEFFFAFFFEFFFFF9FFFBF4FCFFF9FFFFFFFDFEFFF7FAFFF2F7FEEEFCFFF4
FFFFF8FDF9F8FFF9FFFFFDF8D8E8C1D0E9AFCFE7ABE0F6B6CEE29DD2E39DD2E19ED0DC9C
CAD59BE4F1B9EAF9C0D9EDB0D1EAA8CEECA4C9E99DC6E69BD7F4B4DAF0BFE9F9D4FBFFED
FEFFF6DEDFD7E9EBE0010400303A17D4E2B1C2D897CDE99ECDEC9EC9EA9BC3E397C4E499
CCE69CCCE69DCCE5A1CAE4A3CAE2A8CAE3AACDE4ACCFE6AECFE7ADD7ECB4D4E5B1D5E2B6
ADB49261674BCED1BEFFFFF4FFFDFAE2DAD8B2ADA7D8D8CCFEFFEFF7FFE8F5FFE3F0FFDC
ECFFD3D5ECB8CBE0A8D0E5AACFE3A6C7D99BD3E3A5E8FABCCFE5A7CFE9A8D1EBA4CDE89B
D0E996D0E995CDE494D3E9A06C8140B2C68BDAEDB6EAFCC8E4F7BFC9DDA0C5DA99C7D99B
D7E5B4D8E5B9E3EFBFE3EFBDD8E2AED5E0A8D9E4AAD6E1A5D9E4AACBD69EE6F3BDCBD9A4
EEFECDE6F6C7CCDDB1CEDAB2F2F3D3EBEAD6FCFFFDF2F5FEFFFBFFFFFBFFFFFEFAFFFFF1
E6F3D9D8E0CBFFF8F7FFF4FFFFFAFFF0FFFF1A62565DAE9BCDFFF5B6DCC7CFF3C7001100
6A8F5BBFDAA3CDD798E5DB9E6E4E1DB4926CDFD2B2A1AE80CAF5A6C9FCA0CAEB9AC3DD93
D5ECA47F9650A0B771D0E7A1C5DC96D4EBA5DDF4AECEE59F
CFF2B0B8E09AB7E396CDF4A5CFE59A68793367823FCFF2B2EAFFD8C0DFB34A593AD4E3CC
E3FFF0D8FFF16D8A88576B6AD2E2D7F3FDF4FFFEFFFDF8FFFFFDFFD9CED2887571493E38
607169C9F2EE4D8A8D7BADB6F8FFFFFFFFFAE0F1C76378408B9467C2C89CDCE8B6DCF0B5
E0FAB9DBF9B3CCEAA4CCE7A2CFE5A5D5E7ADD8E6B5DFECC1E8F6D2E6F5D4E7FADCF5FFED
F8FFF3F9FFF5FCFCFAFFFDFFFFFBFFFFF7FFFFFBFFFFFDFFFFFFFBFEFFF8FDFFF7FBFEF5
FAF9F7FCF6FAFFFAFFFFFEFACADBAFD0EDABCAE4A3B9D08C97AB6499AB619DAA6475813F
9FAA6EC7D49CDCEBB2D3E7AACCE5A1C9E79DC8E89CCBEDA3C4E4A3D5F1BEF5FFE3EEFBE1
E8EEE2F8F9F1FFFFF60004000A1600D4E6B4DBF4B2D7F6AAC8E99ACAED9DCBEDA0C9E99E
C6E099CAE09FCEE3A8D0E7AFD3E9B8D2E8B9CEE4B5CCDFB1C5D8AABDCEA2E0ECC6D0D9BA
FDFFEBFFFFF3F0EFEAEFEBE8D6CFC9BEB7ADF2EFE0FFFFECF5FEDFF7FFDFF7FFDCDDF6BF
D1EAB1CDE7AAC8E2A5CBE3A9D8EDB4DDF0B9D0E1ADBECF99D8F0B6C7E1A0CBE59EC9E495
CDE692D1EB94CCE391D5EBA09FB473A4B87D8B9E6783965F889C5F8EA360A8BE75B6CA83
9DAA72B7C18DDBE4AFE3EAB6D2D4A2CDCD99DCDCA8E8E6B3E1E1ADDFE1AFD7DEAAF0F9C4
FCFFD4EDFECAF8FFD6F2FFD1EEF0CBDADAC2FCFFFBF6F9FFFFFBFFFFF7FFFFFCF8FFFFF1
EAF8DEE3ECD7D9CDCDFEEAF6FFF9FFF1FFFF448D86368C7FB7F0EAB5DFD3C9EFCA547A49
3E6435DAF8C6C5D096F3EAB1745326BA9976110600677449B5DF95B9EB94C6E69AD2E9A1
D1E6A1D7EBA6C1D590667A356E823DB8CC87C0D18DD9EAA6
BEDC92CCED9ED8FEA9CCEE97CFE290C6D789DAF4ADCDEDACB3DB9FC8E8B7545F3DDBE8CE
CBEDD577A090A5C2C0F1FFFFF4FFFAF4FFF4FEFFFFFFFDFFF8F3FAEBDFE1EDD5D1E9D8D1
C8D2CAE6FFFF0643464D848BF7FFFFE6E6DED1E7B9BAD4975E6833888F5BC6D499EBFFC0
E3FEB9D4F2ACCFEDA7CBE6A3C4DA9CD3E4AED6E3B7E0ECC8F4FFE7F6FFF0F0FFEFF5FFF8
F9FFF8FEFFFBFFFEFFFFFCFFFFFAFFFFF9FFFFF5FFF4EDF5EFEBECFFFFFBFFFFFBFFFFFB
FFFCFDFFF7FFFFF9FFFFFEFAD2E4B4CCEAA4C6E19CCEE59FD1E69BD7E99DBFCD82626F29
9EA96DC4D19BDBEAB1D2E6A7C7E19AC0DF93C4E498CDF1A7CDF0AED9F7C1F4FFE3F8FFEC
FCFFF6F7FAF1E9EBE0000400010D00C9DDA8CAE7A4C6E89BBBDE8EC1E696C7EC9ECAEAA1
D1EAA9D8EDB2E3F7C2EFFFD2F7FFDFF2FFDEE3F5CFD6E7C3F8FFE4F3FFE0CFD8BDEEF3DF
F0F0E6FFFEFDFFFDFFFFFDFFBCB5ABFFFEE9FFFFE8E0E6C4DCE7BCD1E3AFC1D99FD3F0B0
B9D694D3F0AED6F2B5C5DEA5CEE2AFF3FFD7F9FFDFF3FFD7E7FEC8C8E2A3CCE69FCBE697
CEE793D3ED96CAE18FD3EA9CD6E9A7D8EAAECDDEA7D7E8B1DAEEAFCCE29AC8DF8FBED386
D9E3A49DA26A62652E4F4E185A54226B6332695C2F504316564B1D696333ECEAB9CDD19E
D9E2ADDBEAB3D7EAB2D2E0ABE4E6BEC5C5ABFCFFFAFBFEFFFFFCFFFFF7FFFFFEFAFEFFF0
F7FFECEDF9E3EEE0E0FFF0FFFFF8FFEFFFFF81CCC72F867D3E7A7BB9E6E1E2FFEDE3FFE2
4D764E5C7B4FD9E6B1E3DCA86F4F28A98869CBBFA7798861C1EAA4BFF09EDAFAAFCDE49E
C6D793DAE9A6DBEAA7DAE9A6E8F4B294A05E4A55139BA664
DFF7ADBCD488CFEC9AC4DD8ADAEB9BD8E89DC2D993CAE8A8C6E9AFA6C3938D9B78C5D3B9
8FAC96729486C7E1E0F0FFFFEEFFFDEAFFF7EDFFFFE6F8F8FEFFFFAB9FA1FFF5F9FFF9FB
000100A8C1BB8BC0BA4C84839EC4C7DFFDF3D2F2C9CAE5AEAFB987828956A5B27AE9FDBE
E6FFBDD3F0ADD2EFACC2DC9DD3E8B0E4F4C7E5F1CDECF5DAFBFFF1F8FFF6F3FFF7F7FFFC
F6FBF7FFFFFFFFFDFFFDF6FEFFF7FFFFF9FFF3E6F0D5CAD0BEB8B8EFEBE8FDFCF8FFFFFB
FFFDFFFFF9FFFFFAFFFDFAF5D2E4B4CBE6A1CCE5A1D8EFA9D1E699D1E493DBED9BA5B668
CEDD98DAE8AAD5E8A8CDE2A1D0EAA3D1ECA5C9E7A1C7E5A5C8E5AFDEF7CDF7FFEAEAF6E2
FCFFF8FEFFFAF4F7EE0005002E3C19CFE3B0BDDA98CDEDA4D1F3A6CFF2A2C7E99CC8E69E
CCE0A1D5E6B0E5F5C6F8FFE0F9FFE6F8FFECE2EED8CFDBC7FBFFEFA8AF9D070B00B9B9AD
FFFFFAFFFDFFFFF8FFD7D1D1BCBEA9FFFFE3FEFFDFE1EEC0D1E4ACD1E7A7D2EDA8C3E199
D1F1A8C8E5A2C2DEA3CBE3B1DEF0C8EFFEDFF9FFEDF8FFECF8FFE3D2E6B5D4E9B0D2E9A5
D0E89AD4ED9AC7E08DCFE897CCE39BCFE6A2C7DD9DD2E8A8D2E9A5CAE298D8F1A0DCF1A4
CEDB96DFE7ABF7FAC3F7F7C5E1DAB0D7CEA7E3D5B2E8DAB5A79B737972447B7B47E3EBB0
CCDA9CD7ECA9C5DE9AD1E5A6D2DAA9AFB090FAFFF1FBFDFAFFFBFFFFF4FFFFFDFDFBFDF2
F6FFF0FAFFF3FFF5F4CDBBC7FFF7FFF7FFFFD2FFFFCEFFFF6E9EA04C7675ABE0CCDFFFF8
62856F43573C969E75E5DAAD6F4B27714E30DFD8BC2D3C15CCE5ABCCEAA4C2DC95D0E7A1
D8ECA5D2E69FD1E29CCBDC96CBDC96DAEBA5CCDB9698A762
D1DCA0DDEBADD2E2A1D0E09FE5F6B2CEE19FC9DF9FD1EAB08AA7713F5A2DC7DABA5F735A
000F00D3EAE4F1FFFFEAFFFFE4FFFFD9FFFF95E2CEA8E7D4A3B4AAFFFAFEFFF6FFFFF0FF
FFFDFF000600E2FFEFBFF8E73A8F8C71C4BCBDEFD2CBE5BEDAE0BEEDEDC9DBE2B6E2F0BB
C5DDA1CFE9AAD3EFB2C9E2A9C9DCAFECFAD7F5FDE5FDFFF2FCFFF6FAFFF9F9FFFBFBFFFF
FFFEFFFFFDFFFFFCFFFAF1F6FFFCFDB5A9A9D8CDCBFFFCF8B7AEA7FFFBF3FEF9F3FFFDF9
FFFEFFF7F5F8FFFDFFFEFFFACDDDB6CDE5A9C8DE9ED2E9A3D2E99BDAF09BC4DB8151650C
DDF19ABBD17EDAEFA2E0F6AECBE1A0CBE3A5CDE4ACDFF2C5FBFFE8FCFFF1FDFFF5F9FBF6
FFFFFFF7F9F8F1F4ED010800000B00C6D9ACCDE5ABCEE9A6C9E79FD1F0A4CBEB9FCEE89F
D2E2A3DCE6B1E0E9BEFEFFE4FEFFF1F1F7EDFEFFFFFEFFFFF4F6F5030301FFFFFAFCF7F1
FFFEF8FAF3EDFFFDF85B594AF9FFE4DFF5C6CEE5AFCCE6A9C9E49FCAE99DCCEB9BC6E796
D3F2A6C4E19ECBE4ADE7FCD3F7FFEDF5FFF5F3FCFBF9FFFFFAFFF8F6FFECFBFFE6CDDFAF
CCE0A1CFE99FD1EC9BCEEB97CAEA95CAE999CAE99DCAE89ECAE89ECAE89ECCE89DCDE79D
D2E69FD1DFA1FEFFD4FFFFDDFFFFE6FFFFEAF6F1DBFFFFE6DFDFB9909764566524C6DC91
D7F2A1C9EB95BBE18AD5F6A7CFDEA3939A70FFFFE6FBF9ECFFFCFDFFF5FDFFFAFFFFFCFF
F9F9FBFFFFFFFFFDFEACA6A8FDF7F9FFFEFFF9FFFDEBFCF6EFFFFF4E7574448B87C9FFFF
DEF4FF00010367674FD2C2A0774927A8805D53552EC6D5ACE3DEB6E9E3B3D1DD9DD3EBA1
C9E598CFEEA0CAE699CEEA9DCEEA9DC5E194D1EDA2C8E499
F6FFC8E0E9B0DDE8AED0E0A2C6D89ABAD090BCD59487A16487A26BD8F4C494AE877D9679
DAF1DFEBFFF7F2FFFFE3FFFFA1D6CE71BBAC308C77438C78000D01FFFBFCFFF7FFFFF7FF
FDF6FD32382EEBFFE6E0FFFA368C8B47A3A2B0EBD7D5F4D5E5EBCFB6B596C4CBA2E7F5C4
D6EBB3BAD399D2EBB4D4EAB9E0F0CBEFFCE0F6FDEDFEFFF8FEFFFAF3F5F0FBFFFAF9FBF8
FEFCFFF5EEF5FFFCFFEAE1E2BFB5B3BBB0AAFFFCF4FEF1E8CEC4BAFFFDF4FFFDF6FFFEFA
FFFEFDF8F6F7FFFFFFF8FDF6E9F7D6E7F8CBD8EBB4B1C586E3F9B1C3DA8C748C38D1E991
D4EC96D2E997D2E89FC6DB9AC6D8A4D0E1B5D8E8C3F1FBE0F9FBEDFFFFF8FFFEFDFAF8F9
F8F6F9FDFDFDFEFFFB000400303D21D9EAC0D6EBB3CBE4A3D4EEA7B9D58AD8F4A9C4DB93
C8D494E4EBB7E8EDC5FFFFE8F2F2E8FFFFFFF6F5FD7674810A0710F4F2F7FFFEFDFCF7F1
FFFEF4FFF8EBFFFAEAA9A98FF6FFDCD8F5BDCCEAACCCEBA7CBEBA0CEEFA0D1F19ECBEA9A
C5E197C4DE9FCDE3B2E3F4D2F8FFF4F9FFFFFBFFFFFCFEFFFEFEFFFFFFFDF8FFEFD9E4C4
DAECBACAE0A0C7E399C7E696C9EA99C8EB99C9E99DC9E9A0C9E8A2CAE7A4CAE7A4CDE6A4
CCE1A0D3E2ABFCFFDDEBF2D3F1F2E2FFFFF4F5F3E7B3B29EA2A8869AA6749BAE6ED7F2A5
CFEF9CC9ED96BAE28AC2E595D2E6A9A9B283FAFEDDFFFFECFFFCFAFFF9FFFFFAFFF2EAF9
FFFCFFFFFEFFFFFFFFCDCDCBDCD9D4D8D1CBFFFCF6FFFCFAFEFFFFB9D8DA2D7B7DC8FFFF
D6F1FFAFB3BF3C4333968B6B724121D1A58295986D4651274F3C1CC0AE86C7D393CEED9F
C6E798C3E696C5E898CBEE9EC7EA9AC2E595CAED9DC8EB9B
F7FFC8DCEAAFD9E9ABCEE1A1DFF4B1DBF4B086A15CC2E19DB6D49639581F94B181C3DFB7
EEFFEBEEFFF1F0FFF7C6ECDD408978287A6C7CC5BCC5F6F03F4A42B5ABACFFF7FFFCF3FF
F9FCFF9AA79EA1B09DE9FFF6446F782A5E69A7E0D1E3FFF3F9FFE8C7C8A6B1B88FDAE6B6
C4D6A2C8DFA9CAE0AFE8FAD0F9FFE8FBFFEFFEFFF4FDFEF8F3F4EFFEFFFBFEFFFBFCFDF8
FFFEFBFFFDFAB0A8A6ADA5A2FFFDF8FFFDF6F9EFE6DED4CBD9CFC6FFFDF6FFF9F4FFFBF7
FFFEFBFAF9F7FFFFFFFDFFF9FBFFEFF6FFE3C9D8B1DFF0C3F8FFD4B1C789CFE6A2CBE29C
C5DC98DBF1B1CFE3AEDDEEC2F8FFE8F9FFEFF0FBEBF6FCF2FDFDF3F6F3ECFCF8F5FFFEFF
FFFEFFF7F7F7FAFDF6050C004A5537C8D7ACD4E7AFBED493D0EAA3DDF7ADB8D288BCD28A
9FA96C989C6AE1E3BEFCFEE8FFFFFAB3B1B695939E42404DFFFEFFFFFEFFFAF9F5FEFCF0
F3F0DFFFFFEAD9D5BCC6CAA7DAEEBDC5E3A7C3DFA2C7E4A2C4E29CC5E39BC8E39CC1DC97
CFE7A9EAFEC9F8FFDFF8FFE9EFF7E8F2F9F2FCFFFFFEFEFFF3F2FAFFFFFFFEFFF6FAFFEA
F8FFDECBDFAAC8E0A4D2ECABCBE8A6CAE9A6CBE7AACBE7ACCBE7ACCDE6ACCDE6ACD0E5AC
C3D19EE9F1C8F2F6DBFFFFEEC0BDB6C5C0BD96918DD5D1C5FFFFE5EBF2C9E1EEB9D1E5A6
C6DF9BD3F2ACD3F4ADD3F2AFCCE1A9B9C499E3E8C8DDDCCAFFFDFAFFFBFFEADFEDFFFCFF
F6F3FEFBFCFFFEFFFFFEFFFBF4F3EEC5C0BAF3EAE3FEF4F2FBF5F7EAFFFF61A8AA5AA9AE
DAFFFFEBFFFF587860656D48764B2BBE8D6CD5D0A8939870594B280A0300A6C17CBFE899
CEF0A3C1E195C9E99DCFEFA3C5E599C8E89CC5E599CBEB9F
FCFFD1EAF9C0D6E8ACD0E5A4BCD38F7F9A53B6D48CD2F3AC93B46F4B6E2ED1F2B9DFFFCE
D4F3C9E2FFDCE7FFE67AA68D49947F409286A0E0E0DBFFFFADB8B4857D7BFDEDFAFFFAFF
F9FFFFE5F4EF253324B3C0B7CEDBEB688291A9DCD5C5F5DFDBEBCEDEE2BDD1D8AED3DFB1
D3E3B2E8FACADCEDC3F8FFE3FBFFEDECF3E3F1F4EBFFFFFBFFFFFBF8F9F4FDFEF8E6E6DE
DDDAD3ADA9A0B5AEA6FFF9F1FFFDF6FFFDF6EEE3DDCBC0BAE9DEDAFFFDF8FFF7F4FDF8F4
FFFEFBFDFCF8FFFFFBFFFFFAFEFFF3EFF7E0E4EFD1C8D6B2E4F7CAAEC591D5ECB4C7E0A6
C9E2A9D9EFBEC9DEB5E6F6D9F9FFF3F9FFF8FCFFFFFFFFFFFFFFFAFFFEF8FFFEFBFEFAF9
FAF6F7FFFFFDFFFFF800040070795AC6D3A7D1E3A9E1F6B3C0D78FCEE69CE3FBAF788C45
6F773C797B4CFFFFE1FFFFEDFEFDF97C798000000BA8A6B3FCFBFFFCFCFCFFFFF8FFFFEE
FFFFE8F7F8D89D9D79DDE4B8CCE3ABC4E2A4CBE8A8CFECACCCE6A7CFE9AAD6EEB2D5EAB2
D4E6B6E6F5CCF9FFE4FCFFEDFEFFF4FEFFFAFFFFFDF7F6FBFAF7FEFFFEFFFFFFFAF8FFED
FBFFE8D0E0B9CBDEB0CBE1B0CBE3B3CBE3B3CBE2B4CBE2B6CCE2B4CCE2B3CCE2B1CFE0B3
DEE8C3CFD3B8FFFFEFC5C2B9B6B0B0D9D3D5FFFDFBFFFFF6FFFFEDDFE3C2E0E9BEC1D29E
C6DBA3C9E2A9C1DEA6C2DDA6D1E5B2EBF8CDABB293C4C5B3FFFEFAFFFCFFFFFBFFFEFBFF
FCFBFFFCFFFFF5FAF6F9FEF7FFFFF8DCD9D0D3CCC4FFFDF8FFFCFFF0FFFF73B0B3256F72
A8DDE5D1FEFB5B8D705B754E5A391ACFA283DAD5ADA0A77D928F66787F4B5B7F37C2EF9E
D0F4AAC7E79ECEECA4D1F1A8C5E39BCFEFA6C2E098CAEA9F
DCEAB7DDEBB68A9B647A9052627B39D8F6B0D0F0A7BEE09684A860C9EEA8C7EBABB7DB9E
CEF1BBBCDDAEC4E5BA77A3808ECFBBB0F9F2397A80DDFFFFF4FFFF211C1898838AEAD9E3
EAEDF4F4FFFF1E2E24626D67F9F8FF727B8C71999BE3FFFFD7EACCC5CCA3D6DFB4D3DFB1
E0EBC0DAE6BEF1FCDAF7FFE6FCFFF3FEFFF8FEFEFCFAFAFAF3F2F0FFFFFBFEFEF6BBB9AD
959185EAE6DAFFFAEEFFFEF4FFFAF3FFFDF8978D8BD4CAC8FFF9F8FFFDFBFFFDFBFFFEFB
FFFEFBFEFDF9FFFFFBFCFDF5FEFEF2FFFFF1FCFFECF5FFE29DAF878BA173C5E0ADD1ECB9
C9E3B3E0FACDEDFFDEF7FFEDF3FEF0EFF4F0FFFEFFE7E2E8A79F9CA69F99EDE5E3EDE7E7
8C86887D7978FFFFF6FEFFECFEFFE4CEDAACCEDDA4DDF0AEBCD0899AB0657D9348CBDC96
EBF0BA838158F7F3D6FCF9EAF9F5F4737079F8F6FFFEFEFFF3F4F9FEFFFDF4F8E9FBFFE7
CCD2AED5DCB0BCC390D0DDA5CAE3A2C6E3A1CEE8A9D0EAADCEE5ADDCF0BFF0FFD5F6FFE0
FBFFE6FCFFECFBFFECF6F8EAF4F4E8F6F6ECFFFDF6FFFEFBFFFCFFFFFEFFF7F7F5EAEDE2
FCFFF1FBFFECF9FFEAF7FFE9F7FFECF5FFECF5FFEDF5FFECF7FFE8F7FFE4F7FFE1F9FFE3
FEFFECFBFCECFFFFF6C8C4C1F4EEF0FFF6F9FCF4F2FFFDF4FFFFEFEFF2D5FEFFE1E9F6CB
DEEFC3C9DEB3C6DFB5D0EABDD6E9BBDDECC1FCFFE6E5E8D5C9C6BFFFFBFCFFFDFFFFFEFF
FEFFFFFBFFFBF9FFF8F1F9ECFEFFF4FFFFF3D0CCC0FFFDF5FFFCFBF5FFFFD4FFFF9EDDE2
82B4BB457A7428694B648E66938060FFDFBEC9CBA37A8C5CCFDBABD1E3A94F752A001600
B4D58ECCE9A6CDE8A5CFECA9C6E19CD5F3ADC5E09BC9E79F
FCFFDFFBFFDD516132D3E5B1D6EBB2D0EAABB6D390D3F4ADD4F5B0CAEEA8C6E9A7CDEFB2
C5E6ADC6E7B2C5E5B38DB38C5085739DDBDA4C929AB3E9F3DFF2F07D7670FAE2E2837072
F8FFFFE7FAFE808F8C030907FFFDFF7C8290466872E3FFFFC0D4B86B764C657045EAF3C8
EFF7D0FEFFE3FEFFEAFEFFF1C6C9C0F0F2EFFFFFFFFFFFFFFFFCFDFFFEFBEFEBE2938F83
DDDACBFFFFF1FFFFF3FEF7EDFFF8F3FFFCFA9B9192CEC5C6FFFCFFFFFDFFFFFDFFFFFEFF
FFFFFDFFFFFBFFFFFBFFFFF8FFFFF4F5F4E2FFFFECFBFFE6798962D0E7B9C4DFACCAE7B1
C7E3B0DDF7C8F4FFE3F8FFE8F7FFEBFFFFF6FFFEFBBAB5B2B1A8A3E5DCD7847C7A4B4243
AEA5A8BAB5B2A5A299FBFDE8FFFFE3D4DDB0DAE7AFC7D796EEFFB9576C21879B53CEDD9A
D1D3A1534F2AE7E1C9FFFCF0FFFEFFFEFBFFFFFDFFFAFAFFFCFFFFF7FEF6FCFFEDFCFFE3
C8D4A699A66E8E9A5CD7E7A6CCE69FC6E19CC8E2A3CBE2AAD1E4B6E8F6D2FBFFE8FCFFED
FEFFF3FFFFF4FFFFF6FFFFF6FFFFF4FFFFF3FFFFF3FFFEF5F7F3F4FCF7FDFFFFFDFFFFFA
FEFFF6F9FFF1F5FDEEF1FCECF7FFF7F7FFF9F7FFF7F7FFF5F8FFF0F8FFEBF8FFE5FAFFE7
F9FEEAFFFFF4F6F6ECCDCDC5898681FFFDF7FFFFF4FFFFEFFFFFE9F7FCDCFEFFE1E0ECC4
D2E2BBC8DDB6D1EAC3CDE6BEC0D6A7E9FCCEF9FFE3FCFFECD6D7C9B8B7B2F7F6F2FCFEF9
FBFFF8E5F0E0F8FFF1F5FFECEDF5E0FFFFEFDBDAC8E3E1D5FEFFFBE1EFF0E6FFFFD0FDFF
DDFFFF79AAA64C917500330D635E40DECEACCDDDB0D5F3BD748D54C3DD9ECBEBA2CEEEA5
738D4CCBE5A6C8E0A2CAE4A3C5DE9DD7F2AFCAE3A1CCE7A2
A8AD96B8BEA4E5EECFD6E4C0D2E3B7B9CD9CE5FCC6C3DFA4B9D598D2F0B2C7E7A8CBEAAE
C4E3AAC3E1ABC3DFAC5F7D5789AD9FB1E4E56BB8C001414AF4FFFFD6C9C3B29E97C6BDB6
E0F5F6EBFFFFDDE7E98C8D91BDC1C4E2F1F82C525FDCFFFFD1EBCE90A1755F6C41E6F1C9
FFFFE3EDF1D6D4D5C3BDBDB3FFFFFDDEDDE2C5C4CADEDDE3E3DFE0CFCAC7E4DDD5FCF6EA
FFFFF1FEF8EAFFF9EDFFFEF6FFFDFAFAF1F2E7DEE3FFFCFFFFF8FFF9F2FAFFFAFFFFFDFF
FEFCFDFFFFFDFFFFFBFFFFF8FEF8EAFFFEEAA0A388B0B795ABBC90D4EBB7D1EFB3C8E8A9
CFEFB0CAE8ACCBE2ACC2D4A4DAE2BBFAFEDDEBE7CEC6BFADFFFEF3FFFDF8FFFCFBFFFCFD
FFFAFBE8E3E0B3B0A7FFFFEDFFFFE3DFE6BAD3DCA5B2BE8044500ECDDD96DDECA7D7E1A4
DAD9AB5B5437F7F0DDFFFEF6FFFDFFEBE8F1FEFCFFFCFFFFF9FFFDEEF9E9CDD8BAD5E2B6
D9E8AF849453D0E19AD1E69BD8F0A6CEE7A3D4EAACE1F3C1EFFED7FCFFEAFEFFF3EFF0E8
E8E7E5C8C4C59C9394837B78918881A79F92A19A888A8476AEA9A6ABA7A8FFFFFDFFFFFB
F9FAF4FEFFFAFEFFFDFCFFFFFBFFFFFBFFFFFBFFFFFBFFFDFBFFF6FBFFF1FBFFEAFBFFE8
FCFFEDF7FFEAFEFFEFD7DCC8D9DCC7D6DAC3C6CAAFD0D6B4D6DEB7D7E2B7DFECC0E4F5C8
F0FFD8F2FFDDF2FFE1D5EFC2DAF5C0C3DAA6D0E1B7E1ECCAFFFFECEFF2E1C4C8B9E4EBD9
F9FFEFF0FFE5F7FFE8D1E2C2CBD6B8E0E6CAC9CBB3C0C5B1F0FDF3EBFEFCF1FFFFF0FFFF
F0FFFFE3FFFF7EBCA7164C2C1E270AE2E3C1BFE1AEBBEBADAAD1927C9957B7CB86CFDE9D
283C00CAE2A8CBE0A5CCE4A8C8DDA2D2EAACCFE5A5CDE6A4
DAD7D0FFFFF4F5F7E9FEFFEDF7FFE6F9FFE4DFF0C6D5E8BADAF1BDBED7A0D5EEB7C8E3AC
CCE4B0D5EDBBE1F9C9D5EFCA8DA99ADCFFFF72B9BD39747AFBFFFF968480D8CABDFCFFF3
E4FFFFDCFFFFF8FFFF838087DEDEDEF2FFFF7BADB8A4DCDDC2E4C9C6DDB391A17A737D5A
FFFFE6AEAD98F4F2E6FFFEFBFAF8FDFFFEFFFFFDFFF9F8FFFBF9FCFCF7F3FFFDF6FFFEF3
FFFFF1FFFFF3FFFEF4FFF9F3FFFDFBD3CDCFFFF9FFFFFCFFFFFBFFFEF8FFFFFCFFFFFDFF
FFFEFFFFFEFFFFFFFDFFFFFAFFFEF3867F6DD3D3B9D4DBB9D3E2B7CAE1ADBEDA9FCDEDAA
C3E29FC5E29FD4EDACD3E5A9E0EAB5D6DAA8BDBA8FE1DBBBFFFDEDFFFDF8FFF9F8FFF7F8
FFFCFDFFFDFBA8A49BFFFFECFCFDDEDADFB6D8DFAB96A064E3EDAED1DD9DD3DF9FDAE2A9
DBD7B15F583E867D6EF0E9E3FFFBFFFFFDFFFDFCFFF7FBFEF4FBF3F9FFEDD7E6BFC9DCA5
D2E7A694AA5FD9F0A0C5DC8CCCE49AC7DE9AD2E5ADEAFACDFCFFE6FFFFF1E8E7E2BEBABB
8D838CD2C8D1FFFBFFFFFBFDFFF6F0FFFCF0FFFFECFFFFEFF7F2ECBAB6B3FEFDF8FEFDF8
FEFFFAFFFFFDF9F9FBFCFDFFFEFEFFFEFEFFFEFEFFFCFFFFFCFFFAFCFFF3FCFFECFCFFE8
F4FFE3F9FFE6FBFFE4A6B28E8B976FCBD8ACE3EFBFD4E2AFD7E6AFD0E1AAC7DCA3E6FDC5
F4FFD6EEFFD4F1FFDAE2FFC9C8E6AAC8E1A7DCEEBCDAE7BCFCFFE2FEFFE6FAFFE6D8E3C3
EDFDD9F5FFE1EFFFD9C3D5ABE0EFC8CAD4B1959A7A828A72F3FFF6F5FFFFFBFFFFF4F6FF
FBFFFFEBFFFF91C7B97BB19900090060704CCCF7C1AADE9CBFECA7D4F3AF889351DBE1A3
000B00CEE3ABD1E6ADD2E7AEC9DEA3CFE4A9CFE5A7CFE5A5
FFFAFFFFFBFFFFFCFEFFFFFAFFFFF4F9FEEAE7F1D6D8E6C5CDDDB8D1E2B8D4E5B9D0E3B6
D1E2B6D9EABEEAFBD1F4FFE688A591588278295F5F8CB2B5999498FFFAF6FEFFEB6F8B72
3D7A6B69A19EE1EEF7EBE3EE453C3D99ABAB72B5BB307F7AB5E3C7D0ECC6C5D9B6E4EFD1
FFFFEBFFFFF1FEF7EFFFFAFAFBF8FFFFFDFFFEFEFFFCFCFFF9F7FAFFFAF6FFFDF6FFFCF2
FFF6EDFFFEF6FEF9F3FFFEFBFFFDFFADA7ABFFFCFFF9F3FDFFFCFFFFFDFFF8F5FEFFFCFF
F8F6FBF5F3F6FFFEFFD1CDCAD1C8C3EBE2D9FFFEECFEFFEAF9FFE3F6FFDCF4FFD6F1FFD1
D2EFADC4DF9CCBE29ED3E6A4DCE8A87B8145AAA970EDE8BEFFFFEDFFFBF9FFFCFDFFFCFF
FDF4F7FFFDFBAEAAA1FAF9E7FFFFE6B7BC94434919CAD39CD7E0A7CFD89FD3DCA5D5DBAB
7C7757080000BEB4AAFFFEF8F8F3F7FFFEFFF2F3F5FBFFFBF4FFEEF8FFE6CBDDADC8DEA0
DAF1A990A958C6DF8BD3EC99D2E8A0C9DD9ECEDFABF2FED6F9FEE7EBEBDF8A8484DAD0D9
FFF9FFFFF3FFFFF4FDFFFAFFFFF9F6FFF7EBF2EAD7BDB6A4B1AFA3CDCDC5F3F3E9FFFFF8
FFFFFAFFFFFBFEFCFFFCFBFFFFFDFFFFFDFFFFFEFFFAFBFFFEFFFAFEFFF3EDF3D9D4DFBD
C7D8ACD9F0BCC9DDA8D2E7AC8FA5658CA35FC9DE99D2E9A1D1E8A0CCE69DCBE69FCBE9A3
C9E8A4C5E5A2C9ECAAD2F5B1EFFFCADEFBB8D8EDB2CBDCA8D9E5B7DEE9BFBDC89EDFEFC2
D0E4B1CDE4AED0E7B1F2FFD3F8FFDADFECC1C1C9A4A0A68CEFFBEDF2F8F6FFFBFFFFF6FF
FCF6FFE8F7FE80AFA784B7A6000900617657C2EDB8BDEEACC1EAA4CAE5A0B9BF7F9FA066
5C6B3262773F5D723A5D723980955A95AA6FBAD092D2E8AA
FFF7FFFFF6FFFFF7FFFFFDFFFFFEFBFFFFF6FBFFEEF4FCE4F8FFE5F8FFE3F9FFE3F6FFDE
F3FFDBF3FFD9F7FFDFF5FFE6E2FFE4E9FFFAE0FFFBEAFFFF7F7F7DA7A49BC1CDB5EAFFF1
D4FFFF89C4BEB6CDD5E3E3EF140A0B788686A8F4F4257F767DB39BCFF0D1ECFFE6F9FFED
FFFFEFFFFDF3FFF5F3FFFCFFFDFAFFFEFEFFFCFEFFFCFFFFFFFEFFFFFEFBFFFCF6FFFDF4
FFFDF8FCF4F1F0EBE8B3AEABA7A1A3FFFEFFF9F4FAFFFEFFFFFDFFFEFBFFFFFEFFFFFEFF
FFFEFFFFFEFFFEFCFDADA9AAFDF4F9FFFCFFFFFFFAFFFFF4F9FFEBF7FFE7F5FFE1F4FFDA
C8DFA9D6EEB2D7EBAE819153B1BB7EE1E7ABDCDDA3EFECBFFFFFEDFEF6F3FFF7F8FFF6F9
FFF7FAFFFDFD87827C151304282810D1D2B0EAEFC6C3C999DEE6B5DBE3B2EFF7C87D7F58
3B351D261D0EF4EBE2F2EAE7FCF8F7FFFFFDFCFFFBF2FAEBE5F4D7ECFED4D8EDB5D0E7A3
BCD78A8EAA56CBE490D5EE9DCFE4A1D1E2ABDCE9BDDBE2C0FFFFEDC8C4BBFFF7FBFFFAFF
FFF9FFFFF8FFFFF9FFFBECF1D4C6C39D9389D2C9BAFAF4E4F8F6E9FBFBEFFFFFF3FFFFF4
FDFDF5FDFCF7FFFEFFFFFEFFFFFDFFFFFCFFFFFCFFFCFCFEFFFFFAFEFFF3EBF1D7D1DDB7
D5E9B4C3DD9EC7E29FCEEAA0CBE699B6D381DDFAA6C8E591CDEA98C8E797C7E79BC9EB9F
C5EA9DC3E79DC7EDA2D0F5A8E0FFB6CFEDA3D0E6A5C9DB9FDEEDB6C7D49FB2C08B889962
CEE4A6CFE7A9CDE7A8E0F8BCE2F4C0D4E1B3E0E8C1E5E9CEBFC2B7FFFEFDFFF3F9FFF9FF
FFFBFFF5FFFF9FC9C767968E000E014F664AC5E5B4C7EBADCBECA5C2DC93E9F4B2C9D195
85975D73884F6378405A6F36182D003F55178EA46692A86A
FFF7FFFFF8FFFFF8FFFFF9FFFFFCFEFFFFFAFFFFF4FCFFEFFBFFECFBFFE8FBFFE4FBFFE3
FBFFE1FBFFE1FBFFDFF7FFE3F1FFE8EEFFEDE8FFE8F0FFF4BCD7C8243C2C43523BA1B9A3
E2FFFFC8FBF45B8488CDE4EA48444544504ECEFFFF2C837A76B19DD7FFE7F0FFF4F8FFF4
F9F9EDFEF7EFFCF2F1FFFCFFFFFDFFFCFCFFF9FDFFFBFFFFFFFFFFFFFEFBFFFDF6FFFCF6
FFFCFAFFFDFB918C89CCC7C4FFFEFBFFFEFBE3E2DEFFFFFBFFFFFBF9FAF5FFFFFDF3F3F1
FFFFFDF6F5F3E7E6E4EAE8EBFFFBFFFFFBFFFFFCFFFBFAFFFAFFFBFBFFF8F9FFF1F8FFEC
CFDDBACEDDB6A4B186A0AC7ECED6A7CED4A6D5D7A8F5F5D1F7F4E5FFFEFBFFFDFFFFF9FD
FFFDFFF9F3F587827F0301005E5D49DBDEC1D9DDBAE0E5BDD3DAB1C4CAA4B0B6943B3E21
97927F40382DFFFEF6FFFEF8FFFFFAF8FBF2E7F0DFF9FFECCDDDB6CDE1ACD1E7A7B9D38A
A1BC6D95B05FC7E291C7DF95DEEFB8CCD7ACC5CDA8FFFFE8FDFCEAC8C1B9FFFAFAFFF4FB
FEEDF7FDECF6FFFAFFFFFAFDB7ACAACBC2BBFFFDF2FFFFF3FFFFF4FFFFF4FFFFF4FFFFF4
FFFFF4FFFFF8FFFEFDFFFDFFFFFCFFFFFDFFFEFBFFFDFDFDFFFFF8FFFFF1E9EFD5CEDAB2
D1E9AFBBD991C9E89CC1E18EBBD983ABCC73CAEB92C8E992CBEB98C8E99AC8E89DC9EB9F
C6EB9EC5EA9DC8ED9DCDF2A2CFF2A2C4E397CAE19BDCEFAFD9E9ABCAD89D768648AEC181
CDE4A0CDE6A2C6E19ED1E9ABD0E3ACCCD9ADEDF5D0FFFFEAC4B9B3FFF9FBFFEEF1FFFAFD
F8F9FDEBFEFF90BCBD305E5C00140E6A7B68CAD9B0DAECB2D5E9A4C3D78FDBF0ABD7ECAB
DDF3B5C8DDA2C1D69DB4C98E586D32394F11C2D89ACAE0A0
FFF9FFFFFAFFFFFBFFFFFDFFFFFCF9FDFFF4FEFFF1FBFFEDFBFFE8EAF8D5D8E6C2CEDDB4
CEDDB2CFDFB2CDDDB0C9DAAECADFB6C4DBB1CBE1B3C5E4BB336548123F2800070011190A
A8C0B38AAFA831626671989DA3A7A829322FA8E0DD0020197BB7ABE2FFFFEAFFFCF2FFF7
FFFFF8FFFDF8FFFBFBFFFAFEFFFEFFFBFEFFF7FEFFF9FFFFFCFFFFFDFCFAFFFAF5FFFCF8
FFFBFBDAD2D0F1E9E6FFFEF8F9F6EDF6F6EAFFFFF3FEFFF1FEFFF1FBFFEEFFFFF3FFFFF4
F7F7EDFFFFF6D2D2CAC5C3C4FFFCFFFEF9FFFCF7FFFDFBFFFEFEFFFEFFFFFEFFFBF9FFF3
EBEFDEE4E9D3B5BBA1E2E8CCF3F8DAE5E8C9ECF0CFF0F2DAFFFFF6EEEAE9FFFDFFFFFDFF
F6EFF6FFFDFFF4F0EF080800010200EAECD6F0F3D6EAEDCEF1F6D874785D757962E5E6D4
BCB8ADFFFEF6FBF6F0F9F6EFFCFEF3FDFFF0FBFFEAD5E5BED1E5B0C9DF9FD0EAA19FBA6D
BAD586BCD788D7F2A5CCE1A0DEEBBFF9FFDFF3F8DAECEBD6ADA797F4EBE2FFF5F2FFFAFB
FFF4F8FFF9FFEBDCDFB0A4A6FFF5F4FFFCF9FFFEF8FFFFF8F7FAEFF7FAEFFAFEF0FFFFF4
FFFFF4FFFFF6FFFFFAFCF8F9FFFDFFFFFCFFFDFBFFFFFDFEFFFFF8FEFFF1E9EED7CFDBB5
CEE3AAD2EDA8D6F2A7C8E59598B561ADCB75BADA85D5F4A4C8E69CC8E5A2C7E5A5C7E5A5
C7E6A3C5E69FC7E79CC9EA9BCBEC9DBEDD91D8EFA9D5E8A6A6B677586628B2C082D7EAA8
D2E9A3D0EAA3CCE5A3E2FABEECFECCE6F2CAF7FEDFFFFFEDE6D7D2937D7FFFF9F8FFFCFA
FCFFFFF0FFFFBEE5EC0C3539000907233525DFE7C0CBD098DAE49FE2F4AAC1DC95CCEBA7
CDE7A6CEE4A6DAF0B2CBE1A3BAD090091F00C3D999D8EEAD
FFFCFEFFFDFDFFFEFBFFFFF6FDFFF1F6FEE7F5FFE4F4FFE0F8FFE1EEFFD4D8EEBDCDE4B0
D1E5B0D4E9B1D3E8B0D0E3ACD8E8B7C8DBA4D1ECA9BBE9A86BB789BBFBE0D8E8DB060000
030000A2B2AFD4FFFFDDFFFFF0FCFC9EA7A4597976A8D9D53D746FC9FAF6E9FFFFF4FFFF
FFFFFBFFFCFAFFFCFAFFFBFAFFFEFFFBFFFFF8FFFFF8FFFFFAFFFFFCFBF9FFFBF9FFFCFA
FFFBFB9B9390FFFEF6FFFFF3FEFDEBFFFFEAFDFFE4F5FCDBF1F8D6FCFFE4F2F9DAFFFFE8
FFFFECAEB09B494738FFFFFAFEFEFFFEFCFFFEFDFFFFFDFFFFFDFFFFFDFFFDFBFEFDFCFA
FFFEFBD1D1C9D7D7CDF3F3E7F1F3E5FEFFF3FEFFF1FBFFF1FCFBF7FFFEFFFFFDFFECE9F0
FFFCFFFFFDFFFFFEFF0201000B0B01F6F9E8FFFFEDE3E6D10003005C5F4EEFF1E4FFFFF8
FFFFFAF1EEE9FDFAF3FFFFF6FDFFF0F3FCE1E7F6CFD2E4B2D3E9A9CEE89FD0EB9C86A152
D9F1A5D0E89ED8EFABD0E3ACFCFFE4F9FDE6FDFCE8B9B6A3D1CABAFFFDF1FFFCF3FFFBF4
FEECE8F1E2DF8F8180B4AAA9FBF2F3FFFEFDEBE9EAFFFFFDFCFFFBFBFFFAFBFFF7FBFEF3
FCFEF3FEFEF4FFFFFAFFFEFDFFFDFFFFFBFFFEFCFFFFFEFFFFFFF8FEFFF3EDF2DCD8E3C1
CCDCADD7EBB0CFE5A4BED58FA3BD74C9E39ACBE4A0CFE7A9CDE6AFCDE5B5CDE4B8CDE4B6
CDE5B3CEE7AECEE6A8CBE6A1C2E096CEEAA0C7DE9ACFE2A2D4E2A4E7F5B78A985A869655
CCE19ECAE3A1CDE5A7EFFFCCF8FFDDF8FFE3FEFFECFEFAEFFFFBF8FFFBF8958880FFFEF6
EEF2F1F0FFFFD1EDFB224652C4EAEB557464000800D7DCA2E9EFA9D3E398BBDD93CCF4AD
C3E09DCCE5A3D4EDABCEE7A5DEF7B5000F00C2DB99CAE39F
FFFFF4FFFFF3FEFFF1F6FEE7EAF5D7DDEBC8D6E8C0D2E8B9D0E8B6C8E4AAC2DEA3C3E0A0
C9E6A4D0EBA8CFEAA7CDE6A4D1E3A7C7DC99CAEC95B6EB993D8D58B1F6D9B3C7BCA9A4A1
FFFCF8F7F9F8E6FFFFE4FFFF717C7E000100F4FFFF6E8C8A225556BCF2F4DFFFFFF1FFFF
FCFCFCFFF5F4FFF8F6FFF6F4FCFCFAF9FFFFF7FFFFF7FFFFF9FFFFFFFFFDFFFCFBFFFCFA
A59A98FDF6F0FFFFF3FCFBE7FCFFE2FAFFDCEDF6CBD7E3B3DBE7B5CBD7A7CDD6A9D4DCB3
909473DEE1C4E6E6CEFFFFF3FCFFFFFBFFFFFCFFFFFFFEFFFFFBFFFEF7FEFFFBFFFFFCFF
FDF4F7CBC2C3D7D1D1FFFEFBF6F7F2F8FDF7F6FDF5FBFFFBFCFCFCF1EFF2FFFDFFFFFDFF
F4F1FCEBE8F1FFFEFF000000000100FFFFF4ECEEE085877983857AC5C6BEFFFFFDF3F3F1
FAF9F7FFFFFBFCFCF4EFF1E4FCFFEDD6E1BFD3E3B4D6EBB0C8E299D1EC9DC8E4907F9A49
DBF3A7C5DC96C8DEA0D1E1B2FEFFECE9EADCD0CCC0C3BDAFFFFDEEFFF4E4FFF1E2FFFAEB
EADACDAD9F94C9BCB4F4EAE8FFFDFDF2F0F3FFFEFFF1F4F9FBFFFFF9FFFFFBFFFBFCFFFA
FBFEF5FCFDF5FFFFFAFFFEFBFFFEFFFFFCFFFFFDFFFFFFFFFFFFFAFDFFF3F1F9E4E8F1D6
E4F0CAE3F0C4D5E3B0ABBC85BDCF95CEE1A9E9FBC9DCEDC3E3F2D1E4F4D9E4F3DCE3F1D8
E4F3D2E5F5CEE2F4C4DCF1B8D4EFACCEE9A4D1E7A6D3E5A7D2E0A5BBC68AEFFABEACBC7E
D1E6A5D4EAAAD5EDB3F2FFD5F8FFE3F6FFE7FFFFF6FFFFFAFFFEFAFFFFF6D8D2C6A7A398
FFFFFDFBFFFFDFEEFF90ADBF49797BBEEDD9001100B2BE80C2C880D6E497CFF3A9B8E29A
C9E8A2CCE69FC7E09CD2ECA5C3DC98294200CCE5A1CDE6A2
FCFFE8FCFFE8F2FDDDE3F1CDD4E6BCC9DFB0C1DCA7BEDCA0CFEDAFCEEFAACDEEA7CBF0A3
CAEFA1C9EC9CC4E797C1E195CBE69FD3F2A4CBF48CC3F99B8CCF9A255F472A483E98A39D
FFFFF6FFFEFBF8FFFFF3FBFFF3F3FD666465DEE0DD96A9A7497A7FD7FFFFE2FFFFF0FFFF
FEFFFFFFFCFBFFFCF8FFFDF8FAFBF5F9FFFBF5FFFFF3FFFDF9FFFFFFFFFDFFF9F8EFE4E2
F0E5E1F0E9DFF6F0E0FBFBE1E5E9C4EFF7C8DDE8B0D4E2A5DAE8AACEDC9EE6F1B7D8E2AE
8E9468CED2ADF3F4D4F7FBE2F9FFF2F4FEF5F6FDF5FDFEF8FFFDF8FFF9F6FFFCFAFFFBFB
D2C4C4FFF8F8FFF6F7FFFEFDFCFCFAF0F6F2F9FFFFEEF7F4FEFFFFFAFAFCEFEEF4FCFBFF
FFFDFFF7F5FFEDECF209090B0D0E09F8FBF2F8FBF0FEFFF8E9EBE6F5F7F4FDFEFFFFFEFF
FFFEFFF4F3EFFFFFF8EEF2E3E3ECD1D8E7C0CEE1AAD4EBA7D0EB9CD4F09BBAD6819AB662
D8F0A6CEE4A3D1E4ACD7E6BFF6F8EAFFFFFAF0ECE3B7AFA48C807284776691826D988773
F7E8D3FFFDECFCF2E6FFFEF8FFFCFDFFFEFFF5F8FFFBFFFFF2F9FFF6FEFFFBFFFFFCFFFB
FEFFFAFFFFF8FFFEF9FFFCF9FFFEFFFFFDFFFFFEFFFFFFFFFFFFFBFDFFF7F9FFF0F8FFEB
FEFFEAFEFFE6DFE7C2C4CFA5D8E3B9D8E3BBFCFFE6FBFFEDF7FFF4FAFFFCFAFFFEF8FDF7
FAFFF2FCFFEDF7FFDFEEFBCFCBE3A7C8E1A0C4D89BDDECB1D7E2AADBE6AEC9D49CD2E0A5
CDDFA3CCE1A6CCE3ADEBFDD3F9FFEAF8FFEFFFFFFDFFFFFFF9FFFAE3EEE0FFFFF1FFFFF3
ECDCDFFFF3FFFEFBFF677D943C7878B2F6DDBEECBB5F7A37A6B268DAE69ABEDE95D1F7AE
CEECA4CBE79DC9E49DD2EEA4C1DC9567823B92AD66C5E099
F9FFEAF1FFE1E4F4D0D8EAC2D0E6B8CEE6B2CEEAB0D0EEB0C2E0A0C5E4A1C8E9A4CAEBA6
C9EAA5C9E9A6CBEAA7CEEBABD8F2B5BDD893CAEB94CAEFA1BDE6BC9EC3B1809A8FB0BDB4
FEFEF4FFFBF8FFFAFFFFF9FFACAAB52E3235EBF4F1D2EBE846777ED9FFFFE7FFFFF4FFFF
FFFEFFFCF3F4FFFDFAFFFFF8F8FDF6F9FFFAF8FFFDF3FCF7FEFFFFFFFEFFF7EDEED3C9C7
D4D0C5FFFFEDFFFFE6CFD3AED1D9A6E1EDAFD5E49FD1E19880924886975091A160919F64
B0BA86DDE4B8EFF3CEF8FDDFFBFFF1F8FFF5FBFFF5FFFFF6FFFFF6FFFDF6FFF8F4FFF8F7
DCCECEFFF5F5FFFBFFF1EDEEFFFFFFFCFFFFEEF7F4F9FFFFFBFDFCFFFFFFFFFEFFF6F7FC
FBFBFFFCFCFFF6F7FC000002000100FEFFFBF9FCF5FDFFF9FFFFFDFFFFFFFEFCFFFFFDFF
E6E4E7FFFEFFE6E7E2FEFFF4F0F8E1D0DCB8D0E1ADCBE09FD0E89CC4DD899AB45DA5C16D
C7DF93D3EAA6D2E7ACCBDCB0E0E8D1F6F8EDFCFCF0EDE9DDE3DBCEE4DACEDED2C4D7CBBD
FFF6E8FFFDF1FFFEF4FDFAF5FFFFFFFEFFFFFBFFFFF6FDFFF9FFFFF9FFFFFBFFFFFAFFFB
FCFEF9FFFFFAFFFFFBFFFFFDFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFAFEFFF8FEFFF4
FCFAEBFCFBE7C2C2AAE1E4C9E9ECD1ECF0D9FCFFEEFAFDF4FCFDFFFEFFFFFEFEFFFEFDFF
FFFFFDFFFFF8FDFFEFF2F9DAE5F6C9E6FDC7E5F7C3ECFDC9E2EEBCD5E2ADE3F0B8ACBB80
97AB6E93A86D96AD75C3D6A8E4F4D0E7F1D8EBEFE0DEE7D6E3F7DBE0F6D2F4FEDCFFFBE5
F7E6DFFFF8FFFFFAFF7E8FA110484771B6A1BDF1CA7FA6712E4207A2B176CFE8AFC2DFA5
C7E4A1C6E49ACDEBA1BFDD93D6F2A86D88411E390094AF6A
F5FFF6F3FFF1E2F4DCCBDEC0C5DAB3CFE5B6D1E8B4C9E0A8CBE2AAD0E7B1DFF3C2E2F4CA
DBECC8E1F1D4E9F7DEE4F2D9E7F6D5D7E3BDEBF2C9EBECCAF6F8E2CBCDBFBBC1B5FEFFF6
FFFFF8F5F0EDFFFBFFFAF4FE7E8389000607DDFFFF1A4B475F9295E0FFFFEEFFFFEEF7FE
FFFEFFFFFEFFF9FAF5FBFFFAF9FFFAFAFFF9FFFFFAFDF5F3FFFBFDFAEBF0C0B5BBFDFAF5
FBFFEDD0E0BBF0FDD1D6E3ADD5E19FCFDD907A8C3A687B29C8DE8CCDE398D4E9A4D3E7AA
D0DEA9D3DFB1E9F0C6FFFFE5FBFEF7FBFCFEFBFBF9FFFEFBFFFEF8FFF9F3FFFDF8FFF5F5
DFD3D5F8EDF1FFFBFFFFFDFFFEFEFFFDFFFCFCFFFBFCFFFBFEFFFBFEFFFDF7F9F6FCFFFF
FBFFFFFBFFFFEEF4F4000301333937F3F8F4FEFFFDFEFFFAFCF8F5FEF8F8FFFCFDDBD2D5
DFDAE0F8F3F9FBF9FAFFFFFBEDEFE2C6CAB3E4ECC5D7E4AFD4E4A3A4B96C91A955CBE490
C8E392CBE79ACFEAA3D3EBAFCDE0B3EAF7D9FBFFEDFBFFF2F6F7EFFCFBF9FFFDFFFFFCFF
FFFDFFFFFEFFFFFEFFFFFFFFFCFFFFFBFFFFFBFFFFF9FFFFF9FFFFFBFFFFFBFFFFFBFFFF
FCFFFFFEFFFFFEFFFFFEFEFEFEFEFFFFFEFFFFFEFFFEFCFFFAF8FBFFFDFEFEFDFBFFFCF7
FFFAF1D6CCC0BFB7AAE7E1D3FFFFF3FEFBF2F7F4EFFFFFFDFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFBFFFFF4F9FFECF7FFE6F8FFE3F8FFDFEFFFD2DCEDB9D0E1AACDE1A2
CCE2A1D1EAA6C8E19FC0D998A4BC82C4D8A3CCE0ADD1E8B0CAE7A4CCE5A1D8E6ABFFFFD8
DFD5BAE6DCD2FFFEFFDBEAEF5A818042756E84B4A6DDFFF4D9F9E261796194A690CDE1BE
C5E3A7CAECA2CAEAA1C8E89FC8E69EC5E09B68813F2C4503
F5FFFBEEFEF1E4F5E3D9EBD1CFE0BEC8DAB2CBDCAFD2E4B4CADAADD9E8BDF6FFDEFBFFEA
FBFFF1FBFFF8FCFFFDF4FBF4F9FFF3F9FEEAFFFFEFFFFCF1FCEBE1D2C6BAD5D1C5FFFFF4
FCFCF4FFFEFBFFFBFFFFFDFF78818600090CBBEFEB0A474070A4A2E3FFFFF2FFFFFCFFFF
FFFDFFFFFDFFF6FBF7F8FFFBF6FFF8FCFFFAFFF9F6FFFAFAF0DBE0E6D3D7D0C5C9ECEDE5
EBFBDEDFF6C8C2D4A0D1E1A2DAEAA1BBCA796E802AB1C56ED4EB99D1EC9FD0E9A5CCE4A6
CBDDA9D4E1B3ECF5CAFFFFE8FFFFFDFEFDFFFFFEFFF7F3F2FFFEFAF9F2ECFEF4F2B6ACAB
ECE1E5FFF5FDFFFCFFFFFDFFFCFAFDFDFFFEFEFFFBFCFFFAF9FBF6FEFFFBFEFFFBF6FBF5
FBFFFDF9FFFD5C6562080E0C363C3AF2F6F5FFFFFDFFFFFDFFFEFBFFFDFBD4C8C89D9394
F0EAEEFFFDFFFFFDFFFDFCF8F7F7EDECEFDAE0E6C4CCD5A6D1E1A29EB368C7DE8CE2FBA7
CBE793C5E290C9E89AC8E6A0CDE4ACE7FACDF8FFE6F9FFEFFBFFFAFCFFFFFFFEFFFDFBFF
FFFDFFFFFEFFFEFFFFFEFFFFFCFFFFFBFFFFFBFFFFF9FFFFFBFFFFFBFFFFFBFFFFFBFFFF
FCFFFFFCFFFFFEFFFFFEFFFFF1F1F3FCFCFEFFFEFFFFFEFFFFFEFFFFFEFFFFFDFFFFFBFC
FFFCF6CABDB4ECE2D9FFFDF6FFFDFAFFFEFBFCF8F7FFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFDFFFFFDFFFFFDFFFFFFFDF5FDF0F8FFF1F9FFEDECFBDCD8E8C3CBDCAFCBDEA7CFE5A7
CEE4A3CBE59ED3EAA4DEF8B1F2FFC5A3BE79C7E09CD6F2A8CCEC99C4DF8EEEFDB8F2F5C0
FBF5D1BDB7A1F3F3E9CCD7D3CBE8E66087864C7A77DAFFFFDFFFFF9AB5B02F3E39E2F1DC
CCE7B2D5F4B0B1D08CC8E7A1D5F2AFD4F1AEBFDA979CB774
F8FFF9F9FFF8F0FBEBE3EFD9E8F2D7F2FDDBEFF9D4E0EBC3E4ECC7F1F8D6FEFFE8FEFFED
F5F7E9F4F5EDFFFFFDFEFFFBF1FCECFCFFF1F6F0E2FFFCF3B1A098FFF6EEFFFFF4FAFCF1
F5F6F0FFFEFDFEF5FAFDF8FF818A91000C0FB2E6E2427F787CB1ABE0FFFFF1FFFFFEFEFF
FFFCFFFFFBFFFEFFFFF9FFFDF3FEF6FCFFFAFFF9F6FFFAFAD6C4C4E7D7D7FBF3F0F8FCED
EFFFE0C6DCAED4E6B2D3E3A5CDDD969AA85BC1D282E7FDABD2EB9ACEE89ECBE6A3C9E2A8
CADEADD3E2B7E9F4CCFEFFEAFEFEFCFCFBFFFFFEFFF7F3F0E6E1DBEEEAE1BCB5AFD2CAC7
FDF4F7FFFBFFFFFBFFFFFBFFFBF8FFFDFEFFFEFFFFFCFFFDF7F9F4FEFFFAFEFFFBF7FCF6
F7FCF8686E6A797F7D000200000302FEFFFFFBFBF9FFFDFCF7F2EFE6DEDCEADFDDF8EEED
FFFEFDFFFFFDFFFFFDF9F9F1FFFFF3FFFFECE8F0CBD8E4B2D1E1A0B0C57AD2EB98BFDB86
D9F6A2D3F0A0B9D88CD1EFA9D4ECB0DEF2C1EAFAD3F3FFE4F9FFF2FCFFFBFFFFFFFFFEFF
FFFEFFFFFFFFFEFFFFFEFFFDFCFFFFFBFFFFFBFFFFFBFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFDFEFAF6F7FFFCFDFFFEFFF5F1F2FCF6F8FFFDFB
FFFCF6DBD1C7E5DBD2F9F0E9FFFBF7FFFEFBFFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFFFFFEFFF9FEFAF9FFFAFBFFF6E9F5E1DCE9CDD9E7C3D7E7BAD1E4AD
D1E5A8CEE4A3C6DB96DAF1ABCFE6A0849E57D2E9A3C4DE95CBEA9EC8E299CDDB9ED7D9A8
DFD9B7AFA792DEDACFF3FAF3F0FFFFDBFEFA78A39C6F9A93D8FDF6D7F4EFC5D8D20F200E
63794BBFD89EE2FCBFCEEBABC1DE9CD6F5B1C3E49FCBECA5
FAFFF8FCFFF8FCFFF4F6FDEBFCFFEBFEFFEAFFFFE8FBFFE4FFFFE8FAFCE4F5F7E2FBFCEC
FFFFF4FFFFF8FFFEFDF3F4EFFBFFF6F1F7E9979086B6A9A1FFFBF6FFFCF6F5F5EDFEFFF8
FEFFFBFFFFFDFFFCFFF0EBF27F888F00080C689C9A39746E99CCC5E2FFFFECFAFDFFFEFF
FFF8FFFFF9FFFFFEFFFBFFFFF5FEF9FCFFFBFFFDFAFEF0EDDAC8C4FBEEE6FFFFF3FCFFED
E7F9D3CBE1B2DBEDB9CEDDA2E0ECAAD5E29ADEEEA3C0D588CAE296C9E49DCAE7A5CBE7AD
CCE2B3D3E5BBE6F4D0FBFFEBF7F9F4FFFFFFFFFEFCFFFFF8AFACA3DCD8CDE1DDD4FFFEF8
FFFCFDFFFCFFFFFCFFFEFBFFFBFAFFFFFEFFFEFFFFFEFFFFFFFFFBFFFFFAEDEEE9FEFFFB
FEFFFD000200C7CBCA070B0A000100FFFFFFFFFEFCFEFAF9FFFEFBD3CBC8FBF1EFFFFCF9
FFFFFAF7F6F1FCFCF4FEFFF3FBFEEBFCFFE6ECF7CDD3E2ABCBDF9A9DB466CBE793CAE892
BFDC8AD0EFA1D5F5ACC5E29FD2EAACD3E8B0D9EABEE7F5D4F4FDE8F9FFF3FDFFFAFFFFFD
FFFFFDFFFFFBFEFFFAFEFFFAFEFFFBFCFFFDFCFFFFFCFFFFFCFFFFFEFFFDFDFFFEFDFFFC
FDFFFEFFFFFDFFFFFFFFFFFDF6F4F5FFFFFDFFFEFFF2EEEDFFFEFFFFFEFDFFFDFFF6EEEC
FFFDF6FFFDF4BFB6AFD1CAC4FFFFFAF6F5F1FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFFFFFEFFFEFFFFFBFFFFFBFFFEF3FBF0F9FFEFFBFFEAECF8D2D0E0B1
D3E4AED9EBAFD2E5A5CDE29FC5DA9592A762D9EEA9CCE69FC8E5A2DBF3B5CBD8A3E8E9BF
E0D7B8ADA28EAAA297DADDD4E8F9F1E6FFFCE4FFFF7CA59D80A59DDDFCF6E8FFF9F2FFF8
122601E3F9C8C8E0ACBBD69FD1EFB3BEDE9DC6E9A5C9EEA8
FEFEF6FBFBF1FFFFF4FFFFF3FFFFF3F5F3E4FAF8E9FFFFF1FDFAEBFFFFF3FFFEF4EBE4DC
B6AFA9ACA4A1CBC3C1E1DDDAE4E9E2EAEDE4C4BDB7FFFBF8F8EAE7FFFCF7F2F3EDFCFFFB
FCFFFDFCFCFCFFFCFFFEFBFF8790990A262A3F7170205953C0EFE7E9FFFFF5FFFFFFFDFF
FFF9FFFFF8FFFFFEFFF4F9FCF8FFFFFAFFFBFFFDFAD7CAC2E7DBCFFFFEECFDFFE8FAFFE3
E2F5C8D0E4B1C6D7A1D1E0A53C4808BBC883D0E099D2E69ECCE69DCCEAA4CDEDACCBEAAF
C8E2B2CFE4BBE5F5D1FBFFECFBFFF5FEFFFBF8F9F1FFFFF3B4B5A5C6C5B3FFFFF1FBF8EF
FFFEFBFFFDFFFFFDFFFEFBFFFEFDFFFFFEFFFEFFFFFBFCFEFFFFFBFFFFFAFFFFFBF5F6F1
393937696B6AFEFFFF000002050507E7E7E7FFFFFDFAF6F5A49F9CB7AFACFEF4F2FFFEF8
FFFFF6FFFFF4FFFFF3FEFFEFF4FCE4ECF8D4F3FFD4A7BB7E9BB26AC6E192CBE793D1EE9A
D2EF9FCBE99FBCDB97D1EEACCCE2A1CDE1A6D5E5B6E6F4D0F5FFE6FAFFF1FDFFF7FEFFFA
FFFFFAFFFFF8FFFFF6FEFFF6FEFFF8FCFFFAFCFFFBFCFFFDFEFFFDFFFFFBFEFEFCFEFFFA
FEFEFCFFFFFBFFFFFDFFFEFBFFFEFDFCF8F5FFFDFDFFFEFBFFFDFDF7F2EFFFFDFDFFFEFA
F8F1E9FFFEF4C7C3BAD7D4CDFFFFFAF9FAF5FFFFFFFBFDFCFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFDFDFFFCFEFFFDFDFFF9FDFEFCFFF8FCFFF1F8FFE4DCE8C2
CDDAACC7D5A0DDECB3C4D698D6E9A9A9BC7ABFD290D3E9A9C1DDA3D0E8B6CED9AED5D5B1
E4D8BEA6978495897BB6B4A8F8FFF8F0FFFBE4FFFAC3E9DE496E667FA099CDEAE5F0FFFB
A7BEA2495F395E744DCFE9BCD2EEBBCBEAB1C8EBABC0E39F
FFFDF4FFFFF6FFFFF6FBF8EFFFFFF6FFFFF6FFFEF8F3EEE8C9C1BEC8C0BDD0C6C4D5CBC9
DBD1CFF1E7E6FFFCFBFFFEFBF2F7F1FEFFFBFFFDFBF3E5E5FFFBFBFFFDFBFEFFFBE9EFEB
F5FBF9FBFCFEFFFBFFFFFDFF7F8891566F746393933A716CBEECE2EAFFFFF3FDFEFFFDFF
FFF8FFFFF8FFFFFDFFF7FAFFFBFFFFF6FBF7FFFEF8C4BAAEF8F0DDFFFFE6F2F9D7F5FFDA
E9FDC8C1D69DD2E4AA849255DFEBABD1DD9BD8E7A2CDE39BD1EDA3CDECA6C9E9A8C2E4A8
C1DDAAC8E2B5E0F5CEF7FFE7FCFFF1F9FDEEFEFFEFFFFFECEBEFD4E8EBD0B6B8A2FDFEEC
FFFDF4FEFDF9FFFDFFFFFDFFFFFEFFFFFEFFFEFFFFFCFCFEFEFAF7FEFBF6FBF7F4F6F5F3
383637F8F8F8FFFEFFF7F7F9FEFCFFFFFEFFFFFEFDFBF7F4797470FFFCF6FFFEF6F9F5EA
F9FAEAFEFFEFF5FAE4FCFFEADFEACAD3E2B9D3E5B1687E3EBED88EC8E593CAE793E3FFAE
BDDC90CAE8A2D3F1B1C2DEA1CCE2A2CBDFA2CBDBAAD1DDB7DCE5CAEAF1DFF9FCF1FEFFF8
FFFFF8FFFFF6FFFFF6FFFFF6FEFFF8FEFFFAFEFFFBFEFFFBFFFFFBFFFFFBFFFFFBFFFFFB
FFFEFBFFFDFAFFFCF9FFFBF8FFFEFBF8F4F1FFFEFBFFFEFBF0EBE8A9A4A1B3AEABCFCAC6
CCC8BFC8C4B9EEEBE2FAFAF2FAFBF6FEFFFDFEFFFFF5F9F8FCFFFFFCFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFF8F6FFFFFCFFFFFDFFFFFEFFFDFDFBFEFFF6FEFFEFF9FFE3
FEFFE1D2DDB2DDE9B9CBD9A47E8B55D5E4ABD8E7ACD0E3ACE6FFD1F4FFE3E6F0CEFAF9DD
F7E8D3EEDDCBC6B6A7D2CABDE2E6D8E1F1E4E1FCEDCEF0E2E7FFFF85A8A16C8B86D4F2EA
E7FFED7F977D001900647F5CC1DCB3C5E2B2CFEDB7C5E4A9
FFFFF4FFFFF6FFFFF6F9F4EEFFFAF6FFFEFBF7EEEFD7CED1A49BA0BBB2B7E3DADDFEF5F6
FFFBFCFFFDFBFFFDFBF5F1EEFEFFFDF5F7F4FFFCFDFFFAFDF3E7E9FDF7F7FBFFFDF8FFFD
F9FFFFF9FDFFFCF7FEF7F4FF6B727C2B42486E9A9B3F746EA0CBC1E9FFFDF0F8FAFFFCFF
FFF6FFFFF5FFFFFDFFFCFFFFFBFFFFF9FEF8F9F7EBCFC8B6F3EED1FBFDD8EBF8CAEAFFC7
D2E8A8A2B77692A263ACBA7CC5D191D3DF9DD6E7A3D4EAA2D0ECA2C7E99FC3E7A1C6E9A9
CCEBB2D4F0BFE3FACEF1FFDEFBFFEAF8FFE6FCFFE6FEFFE3FEFFDFFFFFDF7D8361FFFFE8
FFFFEEFEFFF5FFFFFBFFFFFFFFFEFFFFFEFFFEFDFFFEFEFEFFFEFBFFFEFAFFFEFBF3EFEE
696566EEECEFFFFCFFFFFEFFFFFEFFF5F1F2FFFEFBFCF9F4ABA89FFFFFF4FFFFF3FFFFEE
FFFFEAFEFFE8FAFFE4FBFFE4ECFBD4D3E5B5C2D79C98B16DD5F1A4D7F7A4C4E491BAD989
CEECA2D6F3B1C2DEA4D0E9B0D0E4A9D6E7B0D7E4B6D0DCB8D5DDC5E7EEDEFAFDF2FEFFF8
FEFFF8FEFFF6FFFFF6FFFFF6FFFFFAFFFFFBFFFFFFFFFFFDFFFDFAFFFFFAFFFFFAFFFFFA
FFFEFAFFFDF9FEF9F5FCF7F3FFFAF6FFFDF9F2EDE99A9591938B8899918ECAC2BFC8C3BF
CECAC1BFBCB3FFFFF7FFFFF8F3F4EFFEFFFDFBFFFEFAFFFEFBFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFDF9FFFFFCFFFFFCFFFFFDFFFDFBFCFBFCF6FFFFF3FFFFED
FFFFE8D4DBBACBD3AE949F754E572CD7E2B7DFEBBDC1D0A7E2F7D8F5FFEDF1F9E2FFFFEC
F9E9D9FFFBECBDAC9C938777E4E2D3CCD7C6CEE3D4C3DFD1E9FFFED5F6EF71918E89A9A4
B1D1C6B6D5C56F8F7A2D4B33567355C4DFBCCCE5BDCCE3B7
FFFFF4F5F2E9FFFDF7FFFFFAF5EFEFB0AAACA8A1A8D5CED6FFFAFFFFFAFFFFFCFFFFFDFF
FFFAFCFFFEFBFFFEFBFFFDFAF7F9F6FFFFFFFFF9FDF9EAEFFFFBFDFFFEFDE4EAE6F7FFFD
F8FFFFECF0F1FFFDFFFFFCFF82869100050B77A1A04C7D7792BEB1EBFFFFF7FFFFFFFCFF
FFF7FFFFF2FFFFF9FFFCFFFFFBFFFFFCFFFAE7E5D6D8D6BDD6D6B2D4DCADD5E8B0C9E2A0
D0E79FA5BB728A9B55D5E19FD9E3A4D5E1A1E0F0AFC6DB96CCE89EC5E79BC7EBA1D5FAB4
E6FFC7EDFFD2EDFFD7F2FFDAD0DFB8DCE7BFD3DEB3D0DCACD0DCAAD7E1AFDBE4B7BAC29B
FEFFE6FFFFEFFFFFF6FFFFFBFFFFFFFEFEFEFEFEFEFFFFFDFFFEFBFEF9F6FFFDFDFFFDFD
F5EFF3FFFDFFFEF9FDFFFBFFFBF7F8FFFEFDFAF7F2EBEBE1FFFFF3F4F5E3FFFFEDFBFFE6
E6EBCBD8E2BDD0DAB5D3E2B7D4E5B8A4B9818DA665C7E29BC9E898BADA87DDFCACBFDE92
CCE9A6CFEBB0C0DBA8D2E8B9CDDFABE8F6C5FAFFDEFAFFE5FAFFEDFCFFF6FEFFFAF9FBF6
FEFFFAFEFFFAFFFFF8FFFFFAFFFFFBFFFFFFFFFFFFFFFEFFFFFDFAFFFEFAFFFEFAFFFEFA
FFFEFAFFFCF8FDF8F4FAF5F1C6C1BDB3AEAADAD5D1F2EDE9FFFDFAF6EEEBFFFBF8FFFEFA
FFFFF8FFFFF6FFFFF8FFFFFAFEFFFBF8FDF9FAFFFEFBFFFFFBFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFFFFFDFFFFFDFFFEFFFFFCFFFFF9FFFEF8FFFFFDFFFFFEFDFFFEF9FDFDF3FEFFF1
FFFFEFFDFFEAFFFFEA878D71FEFFE8FAFFE4F6FDDEFBFFECF1FFF0EEFFEFFEFFF4F6F2E6
FFFCEFFFFBEDF0DDCE9C8C7CEBE4D2ECEFDEE4F2E1D8EEE1EDFFFDEAFFFFA5C5C29DC0BC
496C666B8E8792B3A8BFDFD09BB8A45672595B7256CADFC0
FCFAEEFFFFF6FFFDF6FEFDF9FFFEFF837E82CEC9D0FFFCFFFFFBFFFEF8FFFFFBFFFFFDFF
FFFEFFFDFCF8FEFDF9FFFFFBFEFFFFF9F7FAFAEFF3FFFAFFFFFBFDFFFEFDF3FCF7F5FFFB
F7FFFEFCFFFFFFFDFFFFFAFF777A81000D1185A9A94E7D7578A497EAFFFFF1FBFAFFFDFF
FFF8FFFFF7FFFFFCFFFCFFFFF7FFFBFBFFF6E8EAD5D6D7B8E2E8BCD2DFA9C5DE9CD0EEA4
CEE796B5CB79D1E399D4E19CDAE4A5D4DEA1D7E5A7D2E7A2C7E399CEEFA0C7EC9EC2E89B
EEFFCAF0FFD0F4FFD8E3F7C6CDDDAEE0EEBBD2E1AAC9D89DDBEBADD7E5A8C3D098C8D4A2
FCFFDFF0F6DAFEFFEFFEFFF6FFFFFAECEDE8FFFFFBF7F6F2FFFEFBFFF7F5FFF7F8FFFDFD
FFFCFFF5EFF3FFFDFFFFFCFEF4F0EFFFFFFAF3F3E9E0E2D4FDFFEBF0F4DBFEFFE8FAFFDF
E9F1C8DAE5BAD3DEB3D2E2B1D0E2AE869B608BA460D0ECA1D0EF9FC2E490CCEB9DC4E29A
CEE8A9CAE2AED7EEC4D1E3BDD9E8BFE9F4CCF9FFE3FCFFEDFCFFF6F9FEF8FBFFFEFCFFFF
FEFFFDFAFCF9F9FAF5FBFBF9FFFDFEFFFEFFFAF7FFFAF7FEFFFAFAFFFAF7FFF8F5FFFDFA
FFFEFAFFFEFACFCAC6B5B0ACE4DFDBF7F2EEFFFEFAFFFEFAFEF9F5FEF9F5FFFEFAFFFEFA
FFFFF8FFFFF8FFFFFAFFFFFAFEFFFBFCFFFDFBFFFFFBFFFFFBFFFFFBFFFFF7FBFAFAFCFB
FFFFFFFEFEFCFAF9F7FFFDFCFFFCFEFBF5F7FFFDFDFFFEFBF4F1ECFFFFF8FFFFF8FBFBF1
FFFFF4C8C8BCB1B1A5D9DBCEFFFFF4FFFFF4F9FBF0FCFFF8F8FFFDF7FFFCFEFFFAFCF8EF
FFFCF3FFFBEFFFEDDFB1A090B4A898F7F6E4FCFFF3F5FFF8E5FAF1EDFFFFDFFDFBE9FFFF
94B8B686ADAA5074708CAFA8B6D6CBD3EFE15D75655A715F
FAFAEEFBFBF1FFFFF8A09F9BC9C7C8FFFEFFFCF9FFFFFDFFFFFDFFFFFDFFFFFCFFFFFEFF
FFFFFFFFFFFDFDFEF9F8F9F4FEFEFEFFFEFFFFFBFFFFF7FAFAEEF0FFFEFBF9FFFBF5FFFB
F4FFF9F1F6F2FBF5F7FFFCFFBAB9BE2B393AC0E0DD00100780AEA3E7FFFFEFFBFBF7F4FB
FFF7FFFFFAFFFFFEFFF0F6F4F6FFF5EFFBE7CCD0B5C6CAA5E0E8B5DAEAACC9E79FCBEC9B
D7F39C9AB05BCFE195E8F5B0CED89CD1DAA1E6F4B9C1D494CCE69DD3F2A4CDF09EC2E797
D2F4AABFDC9ACEE5ADCADEA9CDDEA8CFDEA5CEDE9FD8ECA7D4E59FA5B9729CAC6BC7D69D
D0DDAFEEF8D5C3CBB3E8ECDBFFFFF6FFFFF8FEFDF8FFFFFAFFFAF7D8D0CEFFFBFCFFFCFF
FFFDFFFFFDFFFEF8FCFFF9FBFFFEFBF4F4ECFFFFF3949983FCFFE8EEF8D5D3DFB7CED9AE
D9E2B3CDD7A5B7C391455620B2C68BCCE5A4DBF6AFC2E193C9E996C5E793D2F1A5C6E19E
C8E1A8C8DEB0E8F9D7F3FFE5EDF8D8F6FFE2FCFFEDFCFFF4FCFFFBF9FDFEFAFEFFFCFFFF
F4F5F7FAFCFBFFFFFFFFFFFFFFFDFFF4F1F8FCF9FFFFFCFFFFFDFFFFFBF8FFFDFAFDF5F2
F5F0ECB9B4B0E5E0DCFAF5F1F9F4F0FFFDF9FFFEFAFFFFFAFFFCF8FFFEF9FFFFFAFFFFFA
FFFFFAFFFFF8FFFFFAFFFFFBFEFFFDFCFFFFFCFFFFFBFFFFF7FDFDFBFFFFFEFFFFFFFFFF
FFFFFDFFFFFBFFFEFBFFFEFAFFFEFAFFFEF8FDF8F2FFFCF6FFFCF5F6F3ECFAF7F0FFFFF8
CECDC8CAC9C4DAD9D5F9F8F6FFFFFDFFFFFFFBFBFDFEFFFFF9FFFFF9FFFFFFFFFFFDF8F4
FFFCF6FFF9F1FFF2E6C0AEA0B3A797B3AD9DFDFFF1F0F8EDEDFCF5F1FFFFEEFFFFEBFFFF
E7FFFFE6FFFFD5F7F82B4B4A789792EBFFFFCAE5DE48635A
FFFFF6F3F0E7DAD7D0BFBBB8E4E0DFFFFEFFFCFAFDF8F6FBFCFBFFFFFEFFFEFDFFF9F9FB
F6F6F6F8FAF7FDFFFAFFFFFBFCFBF9FFF7F8FFF9FCFFF9FBFFFBFBFFFAF6F3FDF4F1FFF6
F8FFFAFAFFF8FFFDFBFFFCFDFFFCFD78837FC9E7DF000E0478A79DE4FFFFF4FFFFFBFCFF
FFFBFFFFFCFFFFFFFFF9FFFAF8FFF3F2FFE4C5CDA8C7CFA0DDE8B0D6EBA8C7E99CC4EA93
BCD97F98AE59C7D78ED7E3A3D2DBA6DCE4B3FEFFD6F9FFD1CAE19DC8E499BFE08FC6E796
DBFAAECAE5A2D5EAB1D5E8B1D3E5ABC9DB9DDBEFAAC3D990899E539BB166D2E69FD1E3A5
CADBA7CDD9B1DAE3C6F0F5E1FAFCEFFFFFF6F9F9F1FFFEF99893905C5656767072FFFDFF
EBE5E9FFFDFFFFFDFFFFFBFBFCF9F4FFFFF3ADB29CFCFFE8F7FFDDBDCDA0CFE1ADCBDCA5
D3DDA8DFEAB2C1CE96BDCC93DCF0B1CFE8A4BBD78DD3F2A4C9E996C8E797D5F1A7C9E3A4
D6EAB9D9E9C5F7FFEBFBFFF1FEFFEFFEFFEFFEFFF4FEFFFBFCFFFFFAFDFFFBFEFFFCFFFF
FCFFFFFEFFFFFFFFFFF6F6F8FFFCFFFFFCFFFFFCFFFBF3FEFFFDFFFFFEFBFCF7F4B5B0AD
B5B0ADFFFEFBFFFEFBFFFCF9FFFEFBFFFEFBFFFEFBFEFDF9FFFDFAFFFFFBFFFFFBFEFDF8
FFFFFAFFFFFAFFFFFBFFFFFBFEFFFDFCFFFFFCFFFFFCFFFFFCFFFFFEFFFFFEFFFFF9F9F9
F0EFEDF6F2EFFFFCF9FFFBF5F7F3E8FFFFF3FFFFF3FFFFF4FEFCF0FFFFF6FAF7F057544F
D8D7D3EEECEDFFFEFFFFFEFFFEFDFFFDFCFFFFFDFFFEFEFFF8FBFFFCFFFFFFFFFFFFFBFA
FFFCFAFFFCF4FFFCF3D8CABFFFFDF1D3CBBEFBF7ECFFFFF8F6FFFAF4FFFFE7F9F9E1F6F9
EEFFFFD7F3F7EBFFFF6C888B284646B6D4D2D5F5F0789893
FAF3EDE1DCD6B3AEA8FFFEFAFFFEFBF2EDEAFFFAFAFFFEFDFCF8F7FFFEFFFFFEFFFFFEFF
FFFFFDFFFFFDFFFFFDF8F7F3FFFDFDFFFCFBFEEBEDFFF9FAFFF5F2FFFEF8F4FCEFF6FFF5
F5FFF3FBFFF5FFFBF5FFF4F0F1ECE890958F61796C4B74664C7E75C4F1ECF0FFFFF9FEFF
FFFCFFFFFBFDF6F9F2F8FFF3F5FFECF2FFDFC4CFA4D2DCA7D6E4A6CBE29AC3E996C5ED95
E2FFA8AEC4724C5B184C551EC5CAA18F936E575F36C0CE9DD4E8ADD7F1AAC7E698C9E898
D3EDA4C7DD9CCEDFA8CFDDA8D4E5AEC7DB9EA5BA779FB56CBAD085BED68AC1D78FDBF0AF
DDEFBBEAF9D0FBFFE8F7FFEAFEFFF6EDEDE5F5F2EDFFFEFB807C7B221C1CFFFDFFFFFBFD
FFFDFFF3EDF1FFFDFF0C08054242387F8271F4FDE2C2D1AAD7E9B9C1D69DD2EBAAD8EDAC
D5E0A4DAE4A8919C60E1F1B3C7DC9BCCE69FC3DF94CEED9DD0EF9FCAE699CDE8A3CDE5AB
F0FFD7F3FFE4FBFFF4F8FEF4FFFFF4FEFFF3FDFEF8FCFEFDFBFEFFFCFFFFFCFFFFFCFFFF
FCFFFFF4F8FBF8F8FAFFFEFFFFFDFFF0EAF4FFF7FFFFFBFFFFFCFEDDD8D5A49E9EF2EDEA
FFFAFAF5F1EEFFFDFCFFFEFBFFFEFDFFFFFBFCFBF9FAFBF6FEFEFCFFFFFBFFFFFDFEFFFA
FFFFFBFFFFFAFFFFFBFFFFFDFFFFFFFEFFFFFEFFFFFEFFFFF9FAFCF7F7F9FFFFFFFFFFFD
FFFEFBFFFEFAFFFDFAFFFEF6FFFFF3F6F3E4F4F0E4FFFFF3A3A195737067D7D4CFFEFDF9
FDFCFAFFFEFFFFFEFFFDFCFFF8F7FFFEFCFFFFFDFFFFFDFFFBFBFFFFFEFFFFFEFFFFFBFC
FFFEFBFFFDF7FFFCF6D9CCC4FFF8EFE1D7CEB4ABA4FDFAF5FAFAF8FBFFFFF8FFFFF5FFFF
F4FFFFF2FFFFEEFFFFEFFFFF97AFAF97B4B066858081A19C
E5D7D6F8EDE9FFFBF7FFFCF8FCF1EDFFFDF8FFF8F3FFFEF8FFFEF8FFFDFAF6F1EEF7F2EF
FFFEFDFFFEFDFFFBFAEFE9E9ABA3A1DED0CFBFAAA9BAA5A2AE9F98FFFBF0FAFFF2F7FFF3
F3FFECFEFFF1FFFEF3FFFCF4FFFDF4D0D2C76B806FE7FFFD51867E96C6C6E7FFFFF8FFFF
FFFEFFFBFAF6F4FCEDF7FFEDDEF4D0D7EDBFABB986CFDDA2D2E39FC9E399C7EE9BC3ED97
C0DD89CFE59CE6F4B9D4DBB1F4F7DAFFFFEAE1E5CAB0BA9795A574C2D89ACDE7A0D2ECA3
CDE29DCEDEA0E0EAB6E9F2C36E7F4B8FA26ABACE8FCBE29ECAE298CFE99FDBF2ACDBF1B3
E1F5C4F8FFE3FBFFECFBFFF2FEFFFAFFFFFBFFFEFD625E5DB3AFB0F7F3F4FBF6FAFFFAFE
FFFDFFFFFEFFFFFEFD030000000200FEFFEDFBFFE4CEDFB2C8DDA4D4EFACC5E399C6E096
CCD89890985C98A466C1D08FD5E8A6CEE59DE4FFB2C1DE8ED2EF9FCBE79DCAE3A2CFE3B0
F9FFE4FBFFEFFEFFFAF5F5F3FDFEF6FCFDF5FBFBF9FCFDFFFCFFFFFCFFFFFBFFFFF9FEFF
F3F7FAFCFFFFFFFFFDF9F8F6FFFEFFFFFCFFFFFBFFF4EAF3C2BCC0CAC4C4FFFEFFFAF6F5
FFFEFFFFFEFDF9F5F6FFFEFCFDFBFCFBFBF9FCFCFCFDFFFCFDFFFEFDFFFCFEFFFFFEFFFD
FFFFFBFFFFFBFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFDFDFBFCFFFEFD
FFFBF9FFF5F3FFF6F4FFFAF3FFFFF4F1EFE2A09E92BDBAB1FFFFF6FFFFF8FFFFFAFFFFFB
FDFCFAFBFBFBFBFBFDFEFDFFFFFEFFFEFFFFFDFEFFFAF9FFFFFDFFFFFCFFFFFEFFFAF8FB
FEFDFBF8F4F1FBF3F0C3BAB5FFFCF8FFFCF8CBC0BEE7DDDCFFFAFAF9F7F8F7F9F8F0F4F7
F6FBFFF9FFFFF3FCFFF7FFFFF4FFFFE5F8F4A2BBB5223D34
E3D1D1FFF4F4FFFAF8FFF7F2FFF4EFFFFBF4FFF2E9FFF6EDFDF0E8FFF6EDFFFCF8FFFCFA
FFFCFBEDE4E5D0C7CAC0B6B7928785CBBCB9BAA2A0BCA4A0A5948CDCD6C8D8E1CEF6FFED
F9FFEFFFFFEDFFFAEBFFFCEFFFFCF0CFD0C0798A77D7F9E98CC3BE6C9FA2C1DEE4F5FFFF
FEFFFFFFFFF8F9FFF1F2FFE5D8EFC5C7DFAD91A369CCDC9DD3E7A0D0EC9FC9F39FBAE490
D6F5A7C6DB98CCD8A8D7DCBCFFFFEFFCFAEED9DACCD6DBC4636F47A0B37CBCD292DAEFAC
DCECAEDBE6AECDD3A5BCC3994E5B2FCBDFACE9FEC5C1DA99CDE6A2D0EAA3D0E9A7F5FFD3
F1FFD6F0FFDEF9FFEFFCFFF8F9FBF8FBF9FC8681853A3539FFFEFFF7F5F6FFFDFFFFFDFF
EAE5E9FFFEFFFEFAF90101000F1201F6FFE4EBFAD3CCE0ABD6F0AFD0EFA3BEE18DDCF9A7
C1CE894B54159EA8699DAC69AEC27D9DB46CBFDA8DDAF7A7CBE79ACEE8A1CFE5A7CEE0B0
FBFFE8FCFFF4FFFFFFFFFEFFFFFFFAFFFFFAFFFFFDFEFFFFFEFEFFFCFFFFFBFFFFF8FDFF
F8FCFBFCFFFBFFFFFAEFEEE9FFFEFBF7F1F3FFF8FFCCC2CAD6D0D4FFFCFDFFFEFFFFFEFF
FFFEFFF1EFF0FFFEFFFAFAFAFDFDFDFDFFFEFEFFFFFCFFFFFCFFFFF8FCFBF9FDFCFEFFFF
FFFFFDFFFEFBFFFFFDFFFFFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFCFDFFFEFB
FFFCFBFFF5F3FFF5F1FFFDF8BFBBB2D8D5CCC2BFB8DFDCD5FFFFFAF8F7F2F4F3EFFFFFFD
FDFDFBFBFBFBFCFCFCFFFFFFFEFFFFFBFDFCFBFDFCFFFFFFFFFCFFFFFAFFFFFDFFFCFAFD
FFFFFFFDFDFBFCFBF7C6C1BEFFF6F5FFFBFBFFFBFBCABCBCFFFBFDFFFCFDF8F4F5FFFEFF
FFFEFFF6F5FAFEFFFFFAFEFDEEF4F0F3FDF5F4FFF7000E03
FFF7FBFFF7FAFEE6E6FFF0EDFFFAF3B2A096CCBAAECEBEAFA7978A97897E93847DA39592
BAACABD4C5C8FAEBF0FFFAFDFFF2F1FFFAF6FFF7F3FFF8F3FFF0E6DAD4C4BBC5ADDDEBD1
D1DEC4CACEB7DCD0C0FFEFE0FFFCEFF2F1DFA7B6A1CFF1E0AAE2DF2A616688A9B0E9F8FD
FBFFFFFCFFF4F3FFE8D3E9C3D8F2C3C8E1A88FA165D3E3A2D2E69ECDE99CCAF4A0B8E391
C4E29AD1E5AAFCFFDFFFFFECFFFFF8FDF9F8FFFFFAFFFFF3FCFFE6EDFDD0A1B37987995B
85925AA7AF7EC3C59ED1D5B2FBFFE1DEF1C4D1E5B2D2EAB0CDE5A7C2DC9BC9E3A6D9F0BA
F0FFD8F8FFEAF8FFF2F3F8F2FFFFFF7E7B82030007FFFCFFF2F0F5FFFFFFFFFEFFEDEBEE
FFFDFFFBF7F8FFFFFB0002003A3F2BE4EFD1F1FFD6CDE5ABC1DF97CEF19FC1E88DC0E18A
99A660838949C4CD8CD0DC9AD4E5A1D9EFA6D0E89CC4DF90C7E396D0EAA3D1E6ABCEDEB1
FCFFEAFBFEF3FEFCFFFFFDFFFFFEFBFFFFFAFFFFFDFEFFFFFEFFFFFCFFFFFBFFFFFBFFFF
FCFFFBEFF5EBFDFFF4FFFFF6F7F4ED86817DC1B8B9FFF9FCFFFDFFFFFDFFF7F2F6FCFAFD
EEECEFFFFEFFF8F6F9FFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFF7FDFDF7FDFDFCFFFF
FFFFFDFFFEFBFFFEFDFFFFFDFFFEFFFFFEFFFFFEFFFFFEFFF9F7FAFFFEFFFFFDFFFFFDFB
F7EDECB4A9A7958784BAAFABFFFEFAF8F4F1FFFFFDFFFFFDFAF9F7F9F8F6FFFFFDFFFFFD
FFFFFDFFFFFDFEFFFBFCFEF9F9FBF6FBFEF7FCFFFAFFFFFBFFFCFFFFF6FEFFFDFFFEFEFF
FEFFFFFCFFFFFEFFFFD2D0D1FFF7F8FFFAFCFFFAFDAD9DA0FFFAFDFFF8FBF5EBECFFFCFF
F2ECEEFFFEFFF9F5F4FFFEFBFFFFFAFFFFF6FFFFF4BAB8AB
C0ACAED2BEC0B5A1A2BAA6A5FDEBE7B6A59DFAECE1FFF8EDF2E4DBC9BCB3B9ACA6DBD0CC
FFFBFBFFFBFDFFFAFFFFF4FBFFF9FDFFFAFBFFF9F8FFF2EAFFFEEFDFDFC7BFCDACC5D7B1
D8E8C1D3DDBADFDBBEFDF6DCFFF9E3FBFAE685917BC2DDCAB8E8DA0639326E9698EBFFFF
FCFFFFFCFDEFF9FFE0D0E4B1CBE8AEC3E1A392A667D7EAA8C7DF95BFDF93CAF5A6C5EFA7
C7E0A7D3E2B9FCFFEAF8FCEDFFFFFBFEFEFEFCFDF8F7FBEDFBFFEAF6FFDCC9DBA7D4E7AF
D5E4ADE4F0BEF0F7CBFEFFDFF9FFE6E2F3D1D3E5BDCFE3B2CBE2AAD0E8AED4EBB3D1E5B4
C8D8B1F9FFEAF6FDEDFDFFFAFAF8FB716C73837984FFFAFFFFFEFFFFFFFFFAFAF8F8F7F3
FFFFFBFBF7F4B9B8B3010300090E00D9E5C1C7D9A5D1EAA8C8E99AC6EC95BAE289D3F4A3
B4C483DFE9ADD1DFA1D7E8A4CCE29A9FB76DD1EC9FCDE99CCBE59CD1EAA8CFE1ADD0DCB6
FEFFEDFFFFF8FCF6FAFFF8FFFFFCF9FFFDF9FFFDFCFEFCFDFCFBFFFEFDFFFEFFFFFEFFFF
FDFEF8FFFFF6FFFFF4F1EFE3CFCBC2807875D3CACBFFFCFFFFFBFCFCFAFBFFFEFFFFFEFF
FFFEFFF5F3F4FFFFFFFEFEFEFEFFFFFBFCFEF9FAFCFBFFFFFCFFFFF8FEFEF9FDFEFEFFFF
FFFEFBFFFEFBFFFEFBFFFDFDFFFEFDFFFEFDFFFEFFFFFEFFFFFCFDFFFDFFF3EDEFE8DFE0
DFD7D5ADA3A2B2A6A6FFFCFBFFFEFDFEFCFDFFFEFFFEFCFDFFFEFFFFFEFFF9F9F9FEFEFC
F9F9F7FDFDFBFCFDF8FAFBF5FFFFFAFFFFFAFEFFF8F5F6F0FFFDFDFFFAFDFFFDFFFEFAFB
FFFEFFFAF9F7FFFDFECFCBCAFFFCFDFFFCFDF6EAECA4989AFFF3F5FFFBFFFFFBFFFFFCF9
FFFFF8FFFFF4FEFCEFF8F6E7FFFFEDF0F0D8F0F0D4D9DABB
FFFCFDFFFCFDFFFDFDFFFDFDFFFEFBFFFEFBFFFEFAFFFFFAFCF8F5FFFEFBFFFEFDFBFAF8
FFFEFFFFFEFFFFFEFFF5F2F9FFFBFFFCF4FFFEF8FAFFFFF6FAFFE87D8963C8DFABCCE5AB
CEE8ABC4D99ED6E7B3E5F0C6FEFFE4F4F9E26A715FD1E0C9C2DDBA5B84640A3D36D8FDFF
F7F6FBFFFDEDFDFDCBD8E7A2CFF3ABBCE19B92A868C4D998CAE89EC2E89DC5F0ABBEE3AF
E0F0D3F5FCECFCFFF6F0F6ECFCFFFAFCFFFAF9FFF4F9FFF1DDECCFD6E8C2D0E6B7D1E8B2
D2EAB0D7EFB3E0F8BCEBFFCEF5FFEAF2FFEDEEFCE2DFEFCBC2D2A5D7E7B6D5E5B4E1EEC0
E9F3CEFEFFE8E9EADACECBC28E89862B2225FFFAFFFFFCFFFEFEFFFEFFFDFEFFF6FFFFF3
FFFFF3FFFFF37E7E7400020060664CDEEBBFC8DD9CC7E293D0F29BC5EB94BDE396CAEDA9
C7DEA8D7EBB6CFE4A9C7E09CCDE99E809F51D6F3A3C4E095CDE6A2DEF1B9E1EEC3E5ECCD
FFFFEFFFFBF3FFF8F8FFFBFBFFFCF8FFFBF6FFF9F8FFFCFDFFFCFFFFFAFFFFFCFEFFFEFB
FFFEF8ECE8DDB1AB9FC6BFB5E1DAD4FFFDFBFFFCFFFBF5F7FFFFFBFFFFFAFFFFFAFFFFFA
FFFFFBFFFFFBFFFFFDFFFFFDFBFBF9FEFFFFF7F8FAF2F3F5FEFFFFFCFFFFF6F7FBFFFFFF
FEF9F6FFFCFAFFF8F5FFFDFBFBF3F1FFFDFBFFFDFDFFFDFDEFE9E9CEC8CACCC6C8F2EEEF
FFFEFFFFFCFDFDF9FAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAF8F9FFFEFFFDFCFAFFFFFDF9F8F6FFFFFBFAF9F5FFFFFBFFFFFBF7F3F0FFFDFAFFFCFA
FFF5F4FFFBF8FFF4F3998E8C4137359B9692AAA6A3FFFFFDFEFEFEFEFEFFFFFFFFF7FAF3
F9FFE9FAFFE1FBFFDFFBFFDDF4FFD3E1F2BED3E4ADCDE1A6
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF3F4F6F1F2F4F4F5F7
FEFFFFFBFCFEFCFFFFFEFFFFFFFBFFFFFAFFFFFEFFC6C9BE8C967BE5F6CAD3EAB2C3DD9C
CFEAA7CEE7A6D6EBB3E5F6CAF8FFE3FEFFEF2C2E23CACDBAD6DFB2CFE8BE41706680A8AA
F2F0F3FDEEDBFFFFCACBDE8DBAE593C4F3A5BFD896E2F5B5D6F4ACBEDF98CCEBB0CFE8C0
E7EFE0FEFFFDE8EAE5FCFFFBF9FEF7F9FFF4F9FFF3E9F7E0CDDCBFCCDDB9CADFB6C8E0B0
C5DEA7C4E0A5D1EEAEE1F9C7F8FFF3F8FFF8E8F1E0E9F3DADCE8C4D6E1B9CBD6ACFEFFDF
FEFFE3DDDFC9A3A192625E55070000A79D9EFFFBFDF8EFF2FFFFFFFCFFFBFCFFF3FEFFED
FFFFEDFFFFEF848478090C005D6347EEFBCDCFE59DD2EE99CFF097BFE58ED5FAB4C0E4A6
CCE9B3C1DCA5C7E4A4D0EEA6B5D486A7C774BBDA8ACBE79DD4EAACBDCD9CFCFFE4FFFFEC
FFFBEFFFFDF8FFF3F2FFF1F0F5EAE6FFFCFAFFFCFBFBF1F2FFFAFEFFFBFFBBB3B14C453F
B9B2A8E9E3D5FBF5E7FFFFF3FCF8EFF5F0ECFFFAFCFFFEFFFFFFFBFFFFF8FFFFFAFFFFFA
FFFFFAFFFFFAFFFFFBFFFFFBFFFFFDFAFAF8FEFFFFFEFFFFFEFFFFEFF0F2F5F5F7FFFEFF
FFF9F7FFFDF8FFFCFAFFFCFAFFFCFAFFFBF8ECE4E2DDD8D5C4BEBEF5F1F0FFFEFFFFFDFE
F6F4F7FFFEFFFFFEFFF6F5FAFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFCF8F9FFFBFCFFFEFDFFFEFDFAF6F5FCFBF7F7F6F2FFFFFAFFFDF8FFF1EE
FFF9F88D7875B09D99CDBEB9F1E6E2FFFFF8F4F5F0FCFFFDF5FBF9F0F6F6FCFFFFF6FBF4
D2DDBDCFDFB2D1E3B1D7EAB3D7ECB3D2E8AACEE7A5CEE9A4
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFFFFFEFFFF
FCFDFFFEFFFFEFF0F2F6F5FAFFF8FFFFFBFFB6AEACA4A295EDF1D8E0EAC5CCDCABDBEEB7
C9DCA5CFE1AFD0DFB6E5EECFF3F8E4FFFFF8363231766F65DAD0ACB4B691446258536F70
CDCCC8E8E0C9D6E2A2D1F19CBFF59FC7FCAA87A25D829253CFE39ED4E4A5E2ECBAFFFFE4
FDFFF2F0F0EEFFFFFBEFF1ECFBFEF7F9FFF5FCFFF4FBFFF1E8F4DCEAF9DAEBFBD7E1F3C9
D2E5B7C8DFABD3EAB2E5F7CDFBFFF6FBFFFCFCFFF8F9FFEEE1EACFEFF6D7E6EDCCF8FDDF
EBEDD7D9D7C8DAD6CDBDB8B4C0B6B7AAA0A1FFFCFDFFFDFDF9FBF8F4FBF3EDF4E2E8EDD6
E5E9D2E6E9D67375680003004F5539C1CD9FCEE29BD6F29DC9EA91C1E58ECFF3ADBFE3A3
C4E4A3DAF9B5C6E69BC7E696DEFEA973903CD1EC9DD7EEA8D0E1ABCFDCB1FEFFEAFFFFF0
FFFCF3E5DDDBC5BBBCE1D7D8EBE3E1CCC7C4D7D1D1F7F1F1DAD4D69F9A97B2ADA7FAF6EB
F2F1DFFFFFECF8F7E2FFFFEDFFFFF0FFFFF6FFFEFBFFFFFDFFFFFBFEFFFAFEFFFBFEFFFB
FEFFFBFEFFFBFFFFFDFFFFFDF9F9F7FFFFFDFDFDFDF4F4F4FFFFFFFFFFFFFFFEFFFFFDFE
FFFDFBFFF8F5FFF9F6FBF3F0F9F1EFDED9D6C4BFBCAAA6A3EAE6E5FFFFFDFFFEFFFFFEFF
FAF8FBFFFFFFFFFFFFFBFBFDFEFFFFFEFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFBFAFCF8F7FFFEFDFFFEFDFFFCFBFFFFFBFFFFFBFCFBF6FFF8F6FFFBF8
BBA7A6FFF9F8FFEFEBCBBCB7FFFCF8FFFFF8FCFDF8FAFFFBF5F9F8F5F9FAFEFFFFFCFFFA
D9E3C8CFDEB5C7D8ACC8DAAACBDDABCBE0A8CDE2A7CFE7A9
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFDCDDDFFEFFFF
FEFFFFF0F1F3FEFFFFFFFEFFFFF8FAFFFBFBC3B8B2BCB6A8B3B39BF3F8D8E9F4CCDEEBC0
E7F3CBE8F4D0ECF2D8FAFDEAFFFFF8FFFAFCB2A8B1190B08BDA889796F4C36463B000C0A
29261FE8E4C9CCDC9DC7EA96B0E891B6EA98CCE7A2D1DD9FD8E2A3D8DDA3FFFFD8F6F0D6
FFFFF6FFFFFDFBFAF6FFFFFBFCFDF8F6F9F2FEFFF8FCFFF4FBFFF1FBFFEDF9FFE8EEFCD9
DBEBC4CEDFB3D3E6B8E1EFCCF6F9F2FFFFFFFFFFFBFFFFF4FAFDECFFFFEDCCCEB9B3B4A2
CCCABEFFFFF8F9F4F1FFFDFDFFFCFD797071FEF4F2FFFFFAFCFFFBF6FFF5E9F2DDDCE5CA
D5DBC1DADDC86D6F610003004E5438748052CBDF98D6EF9BC9E78FD0F29CB3D791CEF1AD
BCE194C3E694CCEE98C5E68FA2C06894B05CC5DB92D6E8AACEDAAAE7EECDF4F6E1FFFFF6
FFFFFAC7C1C1DAD4D4FFFDFDFFFFFDFFFFFBFCFBF9FBFCF7FFFFFAFFFFF8FDFEF0EFF2DD
FFFFE8FFFFE4FDFFE2FFFFE6F5F9E2FFFFF1FFFFF8FCFEF9FEFFFBFEFFFBFEFFFDFEFFFB
FEFFFDFEFFFDFFFFFDFFFFFDFFFFFDF8F8F6FBFBF9FFFFFDFEFCFDF2F1EFFAF6F7FFFEFD
FFFCF9FFFEFAFFFDFAD2CDC9BFBAB7BAB6B3E8E4E1FEFDF9FFFFFDFBFAF8EEECEDFBFBFB
FFFFFFFDFDFFFBFBFDFFFFFFFEFFFFFEFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFEFFFFFEFF
FCFAFBFFFEFFFFFEFDFFFEFDFFFBFAFFFEFDFFFEFDFFFEFBFFFFFBFFFFFAFFFDFA887A79
FFEDECFFF9F8FFF4F0EBD9D5FFF4F0F8F3EDFFFFFBF6FBF5FCFFFFFCFFFFFEFFFFFAFFF9
FBFFEDEAF8D7DAEAC6D3E3BCD2E3B7D0E1B4D0E2B0D1E5B2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F1F1FFFFFFFFFFFFFFFFFF
F8F8F8F9F9F9F8F8F8F3EFEEFFF3F0FFFBF4FFF4EBE6DFCFB3AE9BDEDEC6FFFFE8FFFFEA
FEFFECFEFFEFFFFFF4FFFFFAFFFDFFF8EEF9FFF9FF200D11CEB4995E4B2A454B3D000400
211D12C8C4A7CBD99EC0DF93C3F09FC7F1A5C3D897ADB57AC8CB92D3D1A0F8EFCEFFF4E0
E3DAD3B5AFAFDFD9D9FAF6F5FFFEFDFDFCF8FBFAF5FBFCF4FEFFF6FCFFF1FAFFEDF6FEE6
EDF8DAE6F1CFE9F5D1F2FBE0FFFEFAFFFDFFF7F3F2FFFCF7FFFFF6F1EFE3B2B0A4B3B0A9
E7E2DFF2ECEEFDF7FBFFFDFFEDE7E7898480FFFEF6FFFFF6F9FFF8F4FFF1E3F1D7D3E0C2
CED7BAD6DBC46D6F61020500676D516B7749D0E19BD5ED99CAE68FD7F7A2BBDA96D3F4AD
C9F19BB6DD80D0F596CBED8F8CA94FA7BE6EE4F5B1D0DAA5F1F5D0EAEAD2FDFBEEFFFFFA
DEDDDBBDBCBAFFFFFDFFFFFDFBFFF9F8FFF7F9FFF5FBFFF6FCFFF4FBFFEFFCFFEAFBFFE3
DCE9BEEAF7CBEAF7CBECF8D0E1ECCCF7FFE9F5FDEEFBFFFAFCFFFDFCFFFDFCFFFFFCFFFD
FEFFFFFEFFFDFFFFFDFFFFFDFFFFFDF2F1EFFDFCFAFFFEFBFFFCFBFFFEFBFFFDFDF7F3F0
E6E1DDDEDBD6D8D3D0C1BDBAE8E4E1FFFFFBFFFFFDFFFFFDFFFFFDFEFEFCFFFFFFFEFFFF
FEFFFFFEFFFFFCFEFDFCFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
F8F4F3FFFEFDFFFBFAFFFEFDFCF7F4FFFEFBF3EEEBECE8E5F3F4EFFCFBF7CBC3C0E0D2D1
FFF9F8FFF8F7FFF9F6BEACA8FFFCF8FFFCF6FFFFFBF9FBF6FEFFFFFAFCFBFCFCFEFDFFFC
EFF8E7DFEBD3D2DFC5CEDBBFCEDCBBCDDBB8CDDBB7CEDEB7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFF5F5F5
FFFFFFFFFFFDCFCDCEAAA5A2FFFCF6FFF7EFFFF9EDB3A99DC1B9ACC5C2B3FFFFF3FFFFF3
FCFEF3FEFFF9FEFDFBFBF6FCFFF5FFFFF4FFFFF5FF97868C2E18006051307679680F170C
4842364D492EE2EAB7D7ECABD0EEA8BDD893E8F3B7DCDFAA999B6AA2A077D5CFB5BAB3A3
C6BDB8E3DADB615859FFFDFDF8F2F2FDF9F8FFFEFDF9F8F4FFFFFAFFFFF8FFFFF4FFFFF3
FEFFEFFEFFEDFEFFECFFFFF1FFFEFDF9F0F5FFFCFFFFFDFBBBB3B0E8E0DDFFFDFBFFF8F9
8A8186958E96FEF7FFFAF4F8FFFEFB89857CF9F7E8FDFFEFF6FFF1EDFFE7E1F2D2D8E8C4
D6E1C1DDE6CB7175640306007B826397A375D2E39DD0E894C7E38CCCE997D6F3B0C2E39C
CBF39AD3FD9BC3E888D0EF92D2EB97697B31B3BD81EBEEC1FFFFE4FCF9E8FFFFF6E6E3DE
C7C8C3D5D7D2F5FAF3F4FCEFF4FFEEF8FFF1F8FFEFF7FFECF8FFEAF8FFE4EAFBCFD4E6B4
DAEDB6D2E5ADC5D8A1C7D9A9D2E2BDF8FFECF8FFF4F9FFFAFBFFFFFCFFFFFCFFFFFCFFFF
FEFFFFFEFFFFFFFFFDFFFFFDF5F4F2FFFFFBFAF6F3F5F1EEFFFEFBE9E4E0C5C0BDECE7E3
B2AFAADDDCD7FFFEFBFCFBF7FDFCF8FFFFFBFFFFFDF2F2F0F7F7F5FFFFFDFEFFFFFEFFFF
FEFFFFFEFFFFFEFFFFFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FEFAF9FFFEFDF9F5F4FFFEFDFFFCF9FDF8F5D5D0CDC7C3C0949590E9EAE5FBF3F1FFFCFA
FEEAEBFEE9E8FFF9F8D6C4C0FFF8F5F8F1EBFFFFFAF4F6F1FEFFFDF8F8F8FFFFFFFEFFFD
FBFFF8F9FFF4F6FFF0F7FFEFFBFFEFFBFFEDFBFFECFBFFEA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDF7F6F4FFFFFDE6E5E3FFFFFD
FFFEFC777672F4F0EFFFFEFABBB1A84F4239BFB2AAFFFDF6FAF3EDFFFEFAEEEAE7FFFEFF
FDFDFFFFFEFFFFFDFFFFF9FFFFFBFFFFFAFFFCF1FFFFFAFBCCC2A9333011A7AF9A2A3024
6D695D8F88754A4822D5D9A7D6DFA8D0D89FD1D19DDEDDAFECEEC6FFFFE3FCFFEFF4F7EC
FFFEFAFFFBFAB3A9AAFCF3F4FFFCFFFFFAFDFFFCFFFFFCFEFFFDFDFFFBF8FFFDF8FFFFF8
FFFFF5FBFBEFFAFBEDFFFCF3FFFCFDF3E8ECFFFCFDF3E9E8ABA1A0FBF1F0FFFCFDC4B9BF
6F636DDCD2DBFFFCFFFFFDFFFAF7F0D0CEBFFFFFECFEFFEAF7FFEDF5FFEAF5FFE1F4FFDD
F6FFDEF8FFE48186720A0F0072795A97A375D0E19BCEE491CAE48DC7E291D5F2AFBEDF98
BFE78ECCF595BADF82D1EF99CADF9295A1615A5E2CEEEBC8FFF9E3FFF8EDFFFAF4E2DFDA
F6F7EFFCFFF4F9FFF1F7FFECD0E4C1CCE2BBCCE3B9CEE5B9CFE5B6CDE4AED3EBAFDBF4B3
C4DD99CCE5A3D7EDAFD5E9B4D3E5BDF7FFECEFFDEEF8FFFBF9FFFFFBFFFFFCFFFFFCFFFF
FEFFFFFEFFFFFFFFFDFFFFFDF8F7F3FFFEFBFFFBF8FFFEFAFBF3F08D86807D7572FFFCF8
FDFCF7FFFFFBFFFFFBFFFFFBF9F9F7FEFFFDFFFFFDFEFFFDFEFFFDFCFEFBF7F9F6FEFFFD
FEFFFDFEFFFDFDFFFCFEFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFD
FFFEFDF9F5F4FFFEFBFFFEFBFFFEFBD0CBC8CCC7C4DDD9D6FFFFFDF6F7F2FFFDFBFFF6F4
FFF9FAFFF9F8FFEFEEF7E5E3FFF9F6FFFBF5FFFFFAFFFFFBFFFFFDFBFBF9FFFEFFFFFFFF
FCFFFBFAFFF9F9FFF8FBFFF8FCFFF6F9FFF1F9FFF1FCFFF3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFEFDFBFFFFFDC8C4C1
E1DDDAD8D4D1FFFEFBFFFAF6FFFCF5FFFDF6FFFAF5FEF6F4FFFDFFF9F4F8FFFDFFF1F0F8
FFFEFFFEFEFFFFFDFFFAF7FFFFFDFFFFFAFFF9F2F9FFFFFA6D6C571C1F0468705B555C4C
505044B2B19F59583CC8C5A2F2EFC4F9F5C6F8F4C7FDFBD2EAF0CEFBFFECEEFEF1F8FFFB
FDF9F6FFF3F3ECE2E3FAF0F1FFFBFFFFFBFFFBF2F7FFFCFFFFF9FDFFFAFCFFFDFDFFFEFD
FFFEFBFFFDF8FFFEF9FFFEFAFFFCFAFAF0EFC3B8B6C3B8B6FFFBF9FFFBFB776B6F0F0209
FDF0FAFFFAFFFFFBFFF6F0F0ADAB9FFFFFECFFFFE4F0FAD7F5FFE4F4FFE6F7FFDFF8FFDD
F9FFDFFBFFE67C816B0004006168496E7A4CD4E39ED1E795D4EC98D1EC9BC1DC99CFEEAA
C3EA99CDF59FCAEB9ACBE59BD7E7A8D2DBA6D8D6B0A8A288FFFDEEE3DAD3DAD3CDFFFFF6
FEFFF3EAF4DCF8FFE8CFE4BBC8E3AECAE6ACC9E5AAC8E4A7CBE8A8D0EBA8CDE8A1C5E196
D3EFA4CDE99FCAE3A2C4DBA5CADFB8F5FFEDF1FFF4F7FFFFF9FFFFFCFFFFFCFFFFFCFFFF
FEFFFFFEFFFFFFFFFFFFFFFDFFFEFBF4F0EDFFFEFAFFFBF7D2CBC5F1EAE4FFFEF8F7F2EE
FFFFFBFEFFFAF3F4EFFFFFFBFBFDFAFEFFFDF9FBF8FEFFFDF9FBF8FEFFFDFEFFFDFDFFFC
FAFCF9FEFFFDFEFFFDF8FAF7FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFDFFFEFD
FFFEFDF0ECEBFFFEFBFFFAF7FFFEFBA6A19ED6D1CEFFFEFBFFFFFDF5F5F3FFFDFDFFF9F9
FFF9FAFFECEEFFF1F0B6A2A1FFFBF8FFFEF8F8F5F0FFFFFAFFFFFBFAF9F7FFFEFFFEFCFD
FEFFFFFBFFFEFCFFFDFCFFFDFCFFFBFBFDF8FDFFFAFEFFFA
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFBF7F4FFFBF8FFFEFBDFDAD6
FFFEFAFFFEFAF3EEEAFFFEFAFFFEFAFFFEFBFFFDFFFFFDFFFFFDFFFFFDFFFDFDFFFAFCFF
F5F7FFFCFEFFFEFEFFFEFFFFF3F4F6FEFFFDFFFFFAFEFFF5E3E6D3393E28282B18A7AB9C
6B7666F9FFF4444B39ABAD95FFFEDBFFFED6FFFFDAFFFFDCFCFFEAF8FFF4E8FBF7F5FFFF
FFFFFDEAE0DEFFFCFBAFA5A6FFF8FCFFF6FAFFFCFFFFF9FFE1D7DFFFFBFFFAF1F6FFFDFF
FAF4F6FFFCFCFFFDFD847F7C58504DC0B7B2FFFCF6FFF8F2FFF9F6FFFBFA130407FFF7FB
FFFAFFF6EBF1FFFCFFB2AFA89B9C8AFFFFE6FEFFDFD3E0B5CADCB4C4DBB1E4F8C7CADCAA
DAE9BEFBFFE3797E67050A0061684798A474DAE9A6CCE290BFD783CFEA99D8F3B0CBE9A9
C6E9A5C8E8A5C9E6A6CCE1A8D0DCAAD2D7AFD6D2B7D8CFBEB1A79E99908BEFE8E2FFFFF3
F4F9E2EBF9D6C7DAADC8E1A8CCEBA5C8E89CC7E79CCAEA9ECCECA0CBEA9CCAE999CCEB9B
C8E595CCE89EC9E2A1C6DDA9D6EAC5F0FFECF7FFFBF5FFFEF6FBFEFEFFFFF4F5F7FEFFFF
FFFFFFF7F7F7FFFEFFFDFCFAFFFEFBFDF9F6FFFEFAFFFEFA7C7771FCF7F1FFFEF8FFFEFA
FFFFFBFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFBFDFAFEFFFDFEFFFDFEFFFD
FFFFFBFFFFFBFAFBF6FEFEFCFFFEFFFAF8F9F4F2F3FFFEFFFFFEFFF5F1F0FFFEFDFDF9F8
FFFEFBFFFEFBFFFEFBF7F2EF5C5451FFFDFAFFF7F4FAF6F3FFFFFDFFFFFDFDF7F7FEF2F2
FFF9FAFFF6F8F5E0DFF5E1E0FFFBF8FFFDF8FCF7F3FFFFFAFEFDF9FFFFFBFBF7F6FFFEFF
FFFFFFF6F7F9FEFFFFECEDEFFEFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFEFBFDFAF5ADA8A49F9A96
F4EFEBFFFBF5FFFEF8FCF4F1FFFCF9FEFCFDFFFDFFFEFDFFFCFCFFFDFDFFFBFDFFFBFDFF
FBFFFFFBFFFFF0F3F8F9FDFEF0F5EFFCFFF8FCFFF4F9FDEE96968A1D1B0E524D3AB3B6A3
62756285A08F5A71618C9B86F6F9DAF2F3CBEDF3C7E6EEC7F6FEE7F9FFFAF2FFFFF8FFFF
F9F8F6FFFDFAF5EBE9EFE7E5ABA1A2F0E7EAABA2A7D7CDD5AFA5AEA9A2AAC6BCC4FFFCFF
F2ECF0A6A0A4B5AFB1A59F9FEFE8E2F1E8E1FFFDF4FDF3EAC8BEB54437319A8C8BFFFAFD
FFFBFFFEF3F7F5EDEBACA9A0B3B5A0FEFFE4F3FED4D2E2B3E3F6C9C1D7A8BFD49CD6E9B2
E8F5C7F7FFDC80866C0004007A8160D8E4B4455612DFF5A3D5EE9ACFEA99C9E6A3BBD89E
CBE7B4CCE6B6D0E6B8D4E5BBDBE2C0DDE0C5E3DDCDE4DBD2FFFBF9F3E9E7FFFEF8FFFFF1
F7FFE3EAF9D0CEE2AFDAF4B3C6E798C2E48EC1E38FC6E595C8E797C7E696CAE797CCE89B
D0EAA0CFE9A2CDE2A7CFE2B4DFF0D0F3FFF0F8FFFFF5FDFFFDFEFFFFFFFFFFFFFFFFFFFF
FEFEFFFFFEFFFDFCFAFCFBF9FFFBF8FCF8F5EBE6E3ADA8A4FFFBF7FFFEF8F6F1EDFFFFFA
FFFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFEFCFCFCFA
FAFBF6FBFCF7FFFFFBFFFFFBFFFFFDFFFEFFFFFEFFF6F4F5FFFCFBFFFEFDFFFCFBF8F4F3
F3EEEBFFFEFBFFFEFBC5C0BDFFFDFAFFFCF9FBF3F0FFFEFBE7E7E5FFFFFFFFFDFFFFF8FA
FFF9FBFFF4F6E9D4D3FBE7E6F8E9E6FFF8F3FFFEFAFFFFFAFFFDFAFFFDFAFFF9F9FFFDFD
F8F6F9F9F9FBFFFFFFFFFEFFF7F6FBF6F5FAFFFEFFF3F2F7
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFEFBF5F0ECFFFDFAC5BEB8
FFFEF8FFFDF6FFFAF3FFFEF8FFFDFAFFFFFFFFFFFFFEFFFFFEFEFFFEFEFFFCFEFFFCFEFF
F5F9FFFBFFFFFBFFFFFBFFFDFBFFF8FBFFF3FAFFEEFFFFF1BCB3AE493A33564535D2D0B9
9CBAA046735CB8E4D350735DDFF3D0DAE7BBCFE1AFC9D8ADE5EDD8FEFFFBF5F8FFFAFAFF
FFFEFDFFFEF8FFFDFAFFFAF7FCF3F4FFFDFFF4EEF2FFFAFEFAF3FAFFFDFFFFFCFFFFFDFF
F7F2F6F5F0F4FFFEFFFFFEFDFFFEFAF7F3EAFFFEF4FFFEF3CEC4BAA49A91FFFCF6FFFAF9
F9EDEDDAD0CFD5CDCAD1CFC3DADDC8E1E8C9D4DFB7DBEBBCC0D4A3C6DDA7DAEFB4D6EAAF
D1DFACDFEAC26A70541014002D3413677343223300CCE391CCE893C8E593D1EEABCAE5B0
EEFFDEF0FFE7F4FFE6F9FFEAFDFFECFFFFF1FFFFF6FFFDFAFFFCFDFFFEFBFFFFF8F7FAE9
F7FFE1E1F0C5C6DBA3C9E2A0D2F1A1CDEE97CBEB98D0EC9FD1EDA3CDE8A1CBE59ECCE5A1
CDE3A2CDE2A7D2E4B2DEEEC7EFFBE3F9FFF8FBFFFFFCFFFFFFFFFFFAF8F9FFFEFFF9F7F8
FFFEFFFFFEFFCFCBCAB0ACABD1CDCCECE8E5FFFEFBE7E3E0FFFEFBFFFFFAE9E5E2FFFEFB
FFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFDF6F6F4FFFFFDFFFFFBFFFFFB
FFFFFBF7F6F2FFFFFAF7F3F0FFFEFDF4F0F1FAF6F5FFFEFDF4F0EFFFFEFDFAF5F2D5D0CD
B0ABA8B8B3B0B5ADAAF9F1EEFFFDFAFFFDFAFFF7F2FBF6F2FFFFFFFFFFFFFFFDFFFFFBFD
FFF1F3F6E0E2DFC7C7C0ACABFBECE7D8CDC7CDC6C0C8C3BDD5D0CCEFEAE6FFFDFBFFFCFD
FFFEFDFFFEFFF3F1F2FFFEFFFFFEFFFBF9FEFDFAFFFFFDFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFDFFFEFBFFFAF6FFFEFAFFFDF7DDD6CE
FFFDF6ECE3DCFFFDF6FFFCF4FFFFF8FFFFFAFFFFFDFFFFFFFEFDFFFDFCFFFCFCFFFCFCFF
FCFFFFFBFFFFEFF3F2F2F7F0F9FFF3FCFFF3F9FFECFFFFF3EBDBDB2D13126E5340CFCAAC
B3D8B74984667BB4A176A38CCEE7C0D8EAB8DAEFB6D0E2B2EAEFD9FFFEFBFFFAFFFFFDFF
FEFAF7FEFBF2F9F6EFFFFDF8FFFEFBFFFEFDFFFEFFFFFDFFFFFDFFFFFEFFFEF9FFF3F1F4
FEF9FDFFFEFFFFFEFFFFFEFCF7F6F2FFFFFAFFFFF6F8F1E7FFFAEFF8EEE4FFFDF4FFF8F5
FFF8F68D8382ACA4A1FFFFF6FFFFF1D4DDC2D7E3BFC8D7ACD3E5B1E3F8BDC2D697C5D799
D5E2ADCAD2A943472C0004002128075561319EAF6BC8DF8DCAE691C6E693CBEAA6D3EEBB
F7FFEDF9FFF6FBFFF4FCFFF4FEFFF6FFFFF8FFFEFBFFFEFDF8F4F5FFFEFFF9F8F3FEFFF3
FCFFEAEFFBD5E1F1C0C4DA9CC5DF96C3DF92C7E19ACEE7A5D3E8ADCFE4ABCDDFABCCDEAA
D6E6B5D8E8BBE4F0CAF3FEE0FCFFF1FCFFFAFEFFFFFFFEFFFCF8F9FBF5F5FFFDFFFFFAFA
FFFDFFFAF6F5B5B1B07E7A79FCF8F7F0ECEBFFFCFBFFFFFBF0EFEDFFFFFBFFFEFCFFFFFD
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDF3F2EEFFFCF9
FEFAF7FFFCF9FFFEFAFFFEFBFFFDFCFFFDFEFFFBFAF1EDECF0ECEBDCD8D7C9C4C16D6865
9A9592F2EDEAFFFDFAFFF9F6FBF3F0FEF6F3FFFDF8FFFDF9FFFFFFF4F4F6BAB4B6AFA3A5
ECD9DDF2DCDECBB2B5C4AFAEEADBD6CFC4BED5CEC8B8B3ADA8A39FB7AFACF8EEEDFFFCFB
F1ECE9FDF9F6FFFEFDF3EFF0FFFDFFFFFEFFFAF7FEFFFCFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFDFFFEFBFFFEFAFFFEFAB2ABA5EBE2DB
FAEFE9FFFDF4FFFDF4FFF6EDFFFBEFFEFCEFFEFBF2FFFCF5FFFEFBFFFEFDFFFEFFFFFEFF
FBF9FAFFFEFFFFFFFDFFFFFAFEFFF8FAFDF2F5F9EBFFFFF6A18E90876B67A3836AA59B77
B9E2B884C4A14D887286B39C94A980BECB95D8EDACD4E5AEE9ECD1FFFFF6FFFBFFFFFDFF
FFFFF8FFFFF4FBFDF2FFFFF8F6F7F1F9FAF5FCFBF9FFFEFFFAF8F9F7F7F7FFFEFFFFFFFF
FFFEFFFCFCFAECEBE9FFFFFDFEFFFFFEFFFDF0EFEAFFFCF3F8F1E7FFFEF3FFF8EFF3E8E2
968B89FFFCFBFFFDFBECE9E4F9FBF0FAFFEFE7F1D8D9E7C3C5D6A2E3F5B7C0D08FE5F3B5
BCC69191986E4C5133090D005C6342D9E5B5D0E49FCEE794D1EF99CDEE9DBBDF99CEE8B9
F8FFF3FCFEFDFBFDFAFAFCF7FAFBF6F9FAF5F8F8F8F8F8FAFEFFFFFEFFFFF9FBFAFCFFF8
F8FFEBF4FDE0FBFFE1CEDEAFCFE2AAD1E6ADDEF0BEEEFFD3F9FFE3F9FFE4FBFFE8FBFFE8
F5FEE1F7FDE1FCFFE7FFFFEDFFFFF4FCFBF6FEFAFBFFFDFFFFFCFDFFFCFBFDF4F5D2CAC8
B4ABACBFB9B9F8F2F2FFFDFDFFFEFDFFFEFDFFFFFDEFEFEDFFFFFFFFFFFDFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFDFFFFFDF9F5F2FFFEFBFFFEFBFBF6F3
FFFEFAFFFEFAEDE5E2928D8AB0ACABCAC6C5FFFEFDFFFBFAFFFEFBF6F1EEFFFDFAFFFEFB
FDF5F2FFFDFAFAF2EFFFFDFAFFF7F2FFFDF8C8BFBAA6A19DDBDBDBC3C3C5D6D0D2FCF0F2
FFF9FDFFF8FAF0D7DAA99493FFFAF6FFF3EDFFFDF8FFFEF8EFE7E4D8D0CDE8DEDCD5CBC9
FFFEF8FFFEF8FFFCF8FFFEFBEFEBEAFAF6F7FFFEFFFAF8FD
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFDFFFEFDFFFEFBFFFEFAF9F2ECFFFDF6DED5CE
FFFBF2F4EAE1FFFBF2FFFDF1FFFFECFFFFEAFFFEEBFFFDEDFFFFF3FFFEF4FFFBF5FBF6F2
F6F1EEFFFEFBFFFEFBF2EEEBFFFFFBFFFFFAFFFFFAFFFEFA5D4D4EFEE5DEC5A485988B5F
CBF2C36FAC83497F68799C845860379D9E65D0DD97D3E1A3E6E7C5FFFEEFFCFBF7FEFFFB
FEFFF6F0F7E7FCFFF2F8FEF2FEFFF8EEF1EAFEFFFBFBFDFAF9FBFAFEFFFFFFFFFFF2F2F0
F5F5F3FFFFFBFFFFFBFEFFFDF8FCFF9B9FA27F8180FFFFFAFFFBF2FFFEF4FFFCF3B6ABA5
FFF8F6FDF3F4FEF5F8FFFEFDFFFFFBFCFFF8FBFFF3D7E4C6DBECB8C1D190DFEEABD6E2A0
919A63CDD4A86C71530509006D7453DCE8B8CADE99CAE692C7E792CCEF9DC4E8A2C8E2B3
FCFFF8FFFDFFFFFEFFFFFFFFFFFFFDFEFFFDFEFFFFFCFFFFFCFFFFF5FAFEF7FCFFFCFFFD
F0F6EAF3FBE6FEFFEAD5DFBDD3DFB9D4E3BCDFECCEF1FBE3FBFFF3FCFFF6FDFFF7FEFFF8
FFFFF6FFFFF4FFFFF3FFFFF3FFFDF4FFFDF9FFFBFCFFFBFCF6EAEAF2E7E5CDC1C1DBD1D0
FCF2F1FFFDFBFFFCFDF5EFEFF1EDECFFFFFDFFFEFFFBFBFBFEFFFFF9FBFAFDFFFEF9FAFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFDFFFEFDFFFEFBF8F3F0FBF6F3FEF6F4
CAC2BF877F7CA8A09DFFFDFAFFFEFBFBF7F6FFFEFDF0ECEB787370FFFEFBFBF6F3F9F4F1
FFFDFAFFFDFAFFFDFAD8D0CDFFFDF8D5CCC7A79E99E4DFDBFCFCFEFEFFFFFFFDFFFFF4F8
FFF9FDFFF8FAFAE1E4F8E3E2FFFAF6F9ECE6FAF1ECFFFBF5FFFDFAFCF2F0E3D8D6B5AAA6
41382FFFFEF4F2EBE3FFFEF8FFFCF9FFFEFDFAF8FBFFFEFF
FCFFFFFCFFFFFEFFFFFEFFFFFFFFFFFFFFFDFFFEFDFFFEFBFAF5F1FFFEF8A29992F6EDE6
FFFBF2FFFDF4DFD2C975695B625B41645D40726B4F90896FB8AD99D6CABAE4D8CCE4DAD1
FFFCF8FFF5F3C9BFBEA39A9BE3DDDFFFFDFFFFFDFFFEF8FA96918E887B6BAD9068AA9D69
BDDFAC0A3D14446A55CDDCC75C4E27AA975DE0E096E2E9A5F1F3CBFFFFECF7FFF3F2FFF3
F9FFF3F1FAE9F9FFF1FBFFF6FCFFF8FCFFFAFCFFFBF6FBF5FCFFFDF6FBF7F4F6F3FEFFFB
FEFFFBFEFFFAFEFFFAF2F7F3FBFFFF151C24DFE3E6FAFCF9FFFEF9F1EDE4C5BCB5FFFDF8
FFFCFBFFF9FCFFFAFEFFFEFFFFFFFFFCFFFDF7FEF7F4FFE8E3F1BED5E4A1E7F6B1BFCC87
838C53D7DDAF5F6243030700727958BAC897E1F6B1D1ED99C6E691C6EC99C8EDA7C4DEB1
FDFEF8FFF9FFFFFBFFFFFDFEFFFFFDFEFFFDFBFFFFF9FFFFF4FBFFF7FEFFF9FFFFFBFFFF
FCFFFDFEFFF8FFFFF3EFF4E0F7FFEAF4FDEAF6FEF3FCFFFDFEFFFFFEFEFFFFFDFFFFFDFF
FFFDFFFFFEFDFFFBF7FFFAF4FFFDF8FFFDF8F8EEEDE4D8D8D5C7C6EEE0DDFFF3F2FFFCFA
FFFBF9FFF7F5FFFDFBFFFDFAFFFEFDFDFCFAF5F3F4FCFCFEF0F1F3FCFFFFFCFFFFFAFEFF
FEFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFDFFFDFDFFFCF9FCF4F2E7DFDCCBC1BF
F0E6E4EAE0DE766D68352B29110C0994908FFFFEFDFFFEFD6C6764DBD6D3FFFDFBFFFBF9
FCF4F1E4DCD9D8CFCACBC2BD9F9691FFFCF7FFFDF8FFFAF6FCFCFEF6F7FBFFFDFFFFFBFF
FFEDF1FFEFF1FFEDF0E7D2D1FFFAF6FFFCF6FFFDF6FFFEF6FFF8F3FFFDF8FFFCFAFFFCF8
FFFEF3D3CDBFBCB6AAFFFEF3FFFEF8FFFDF8FFFFFDF6F4F5
FCFFFFFCFFFFFEFFFFFEFFFFFEFFFDFFFFFDFFFFFDFFFFFDFFFEFDF9F3F5B9B3B355504D
605951807A6EDCD5C5DDD9BEE2E2BCDADDB2D9D9B3E8E5C4FEF8DEFFFFECFFFEEFFFF9EF
F9EEE8FFFCF8FFFAF8D1C7C6ECE3E4F5EFF1FFFDFFFFFDFFFFFEFA2E25165E4B2BA29D75
C7E7C20F3D20E4FFFDF2FFF85D5232AC9667E4D89CE0DEA5E6EDC4F8FFE7E3EEDDD5E0CF
D2DCC3D1DCBEFBFFECFBFFEFF5FEEDF2FAEDFBFFFAFBFFFDFCFFFFFCFFFFFDFFFCFDFFFC
FBFCF7FEFDF8FFFFF8E8E7E3000007ABABB7FEFFFFF4F4F483847C404034E3E1D2FFFFF1
F7F3E7FFFFF4FFFFF6FAFCF1FEFFF6FBFFF4ECF9E7F8FFE6E2F0B5E1EEA844510B99A563
DAE3AAD0D8A96F7553000500626C49E5F2C4C8DC9DC8E299D0ECA2CFEEAAC1E0A5D1E7C1
FFFFFBFFFBFFFFFDFFFFFEFFFEFEFCFBFFFCFBFFFEFAFFFEF7FFFFF9FFFFFBFFFFF2F6F9
FCFDFFFEFEFCFBFAF5FFFFFAFCFFFAFBFFFBF9FDFEFEFFFFFFFDFFFFFBFFFFFBFFFFFCFF
FFFAFFFFFCFFFFFCFAFFFCFAFFFDF8FFFCF7DCD3CEAFA5A3FDF3F1FCF2F0FFFCFBFFFCFB
FFFAF8FFFDFBFAF4F4FFFEFDFFFEFDFFFDFEFFFFFFFFFFFFFEFFFFF2F3F5FCFFFFFEFFFF
FFFFFFFFFEFFFFFDFFFFFEFFFFFEFFFFFDFFFFFDFDFFFDFD867E7CE0D8D6FFFDFB807875
110907070000544A48FFFDFAFFFEFBFFFDFCFFFEFDF3EFEEFFFDFA040000766E6CFFFDFB
D8D0CEBEB6B3F1E9E6FFFDFAFFFDFAFFFAF6FFFEFAFFFBF8FEFFFFFCFDFFFBF9FCFFFCFF
FFFAFBFFF8FAECCFD1BBA1A2FFF8F2FFFEF6FFF6EFFFFDF8FFFBF6FFFCFAFFF5F3FFFDF8
FFFEF4FFFCF0FCF5EB555148ACA7A1FFFCF7FCF8F5FFFFFD
FCFDFFFCFEFFFCFFFFFCFFFFFCFFFBFDFFF9FDFFFCFEFFFFF9F9FFFFFDFFFCFAFFF5F4FC
FFFFFBFDFFEDD2D7B7D2DEB0D0E4A9C6DEA2D4E6B2DBE7BFFAFFE2FEFFEBFFFFF3FFFDF3
FDF6ECFFFEF4FFF8F0C6C2B9FDFAF3FBFAF5FFFFFBFEFBF6FFFCF6493C34020200D0DDD4
BFDDDB507E7ECEFFFFDDFFFFB1C2B0756D56C8B094E4D4B3F1FCDCEAFAE0F5F3E7D8D2C2
D9E1B8D7E5B2F3FFD6F5FFDDF6FFE7F9FFF1F1FBF2FBFFFFFCFFFFFEFFFFF5F4F9FFFDFF
FDF7F7FFFCFA7A716A4A3F3D90838DFFF8FFFFFCFFFFFFFB868A7CC1CBB3F4FFE1FBFFE3
FCFFDFC4CCA3E3EEC3CCD9ABD3E3B4D4E8B7C2DAA6D0E8ACD1E196ADBC6B9CA961BAC686
D7E1ACDDE6B969714C000700636E46DCE9BDCEDFABC9DBA7CCE0AFD4E9BEEDFFDEF7FFF1
FAFEFDFDFCFFFEFDFFFEFEFEFDFFFCFEFFFBFEFFFBFEFFFAFEFFFBFEFFFDFFFFFDFFFFFF
FFFFFFFFFEFFFFFEFFFFFFFFFBFFFFE3ECE9FBFFFFFEFFFFFCFBFFFFFEFFFEF7FEFFF8FD
FFFCFDFFFBFAFEF5F0FFFDF6FFFDF6F4EDE5D3CCC4C6C1BBFFFEFCFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FDF7F9FFFCFFFFFDFFFAF4F4FFFDFDF7F1F1CCC6C6B3ADADDFD9D9C0BABA827C7C76716E
8F8989E3DEDBFFFEFBFFFEFBF6F5F1FFFFFBFFFFFBFFFEFB7873700E0906FFF8F9D9D0D1
D4CBCCF4EEEEFFFDFDFFFEFDFCFBF9FFFFFDFEFFFDF7F9F6FCFFFFFCFFFDF8FAF7FFFFFB
FFFBFAFFF1F3F2C9CFEFCDCEFFFFF6FCFFF6FFFEF8FFFCFAFFFCFAFFFEFBFFFFFBFFFFFB
FFFDF8FFFAF6FFFEFAFFFEFBA7A3A0FFFEFBFFFEFDFEFAF9
FAFEFFF7FCFFF7FDF9FAFFF5FBFFEFF8FFECF7FFEFFAFFF9FBFFFFFBFFFFFBFFFFFBFFFF
FBFFF4FAFFE5D7E5B4D2E6A9D2EFACC1E1A0C8E1AACEE0B6F2FFE3FDFFF0FFFFF4FBF7EE
FFF9F1FFFEF4CEC7BDB7B5A9F8F8EEFFFFF6FEFFFAFFFFF8FFFAF363544D000B07E6FEFF
E6FFFF315965448486B0EDE8E9FFFFBEC4B8766055897667F2FFE5F7FFEFFDF4EBFFFDED
E5ECC0C9DAA3D9E9B8E0F1C5EAF9D8F8FFEDF8FFF4F9FFFAFBFFFDF2F6F5F7F7F7FFFEFD
ECE4E13A312A4D433AD0C3BDF0DFE5FFFAFFFFFDFBEEEEE4B3BDA5E6F5D4ECFED4E3F7C6
DEEFB9DCEBB2CCDC9ED5E8A8CDE2A1CEE7A5C0DD9AABC77D859B48ADBF6DC9DB91CFDF9E
C9D8A1D0DEAD6471460008006A7652E9F5D1E6F1CFE7F2D2E8F2D7E6F2DAF6FFEAFBFFF4
FCFFFFFCFFFFFEFFFFFEFFFDFEFFFBFCFFF8FDFEF8FCFDF5FFFFFAFFFFFAFFFFFBFFFFFD
FFFEFFFFFEFFFFFDFFFFFEFFFBFFFFF9FFFFF2F6F7FEFFFFF8F6F7FFFDFCFFFDFDFFFDFB
F3E9E7FDF2F0FFF7F3FFFAF3FCF5EDE9E5DAE7E3DAF8F5EEF9FBFAF8FCFFFAFEFFFBFFFF
FDFEFFFDFEFFFEFFFFFEFFFFFFFFFFF5F5F5FFFFFFF7F7F7F9F8F6FFFFFDF2F1EFFFFCFB
FFFCFDEFE6E7FCF3F4B7AEAFB7AEAFEDE7E7FFFDFDFFFAFAFBF5F5FFFEFDFBF7F6FEFAF9
F9F5F4FFFEFDFFFEFDFFFEFAFFFFFBE7E8E2FEFDF9FFFFFB7E7976EFEAE7EAE1E2CEC5C6
F6EDEEFFFDFDFFFEFFFEFEFEFBFBFBFCFFFFFCFFFFFBFFFFFCFFFDFCFFFDF7FCF8FFFFFB
FFFDF9FFF2F3F2C5CCF2CED0FFFFF6F8FFF8FFFDFAFFFBFAFFFCFBFFFEFBFEFFFDFEFFFD
FDFCFAFFFEFDF6F2F1FFFEFDBDB9B8FCF8F7FFFEFDFCF8F7
F8FFF6F8FFF3F6FFE8F8FFE3F8FFDCF8FFDCF8FFE1F8FFE8F3FFECEEFBEAF8FFF6F8FFEF
EFFFDAE9FBC7D5EAA5CDE59BCFECA9C7E4AAD6ECBDDBEBC7FAFFECFEFFF3FFFFF8FFFAF6
FFFDFAFFFAF4C3BCB6CDC9C0FEFBF4FFFFFAFDFFFCFFFEF8FFECE27C6A5E0A160AB4CDC7
F0FFFF92AFB759898B9FD3CFDCFFFCC9DDD4968D8645382FBEC5B3F3FCE9FFFEF3FFFEEF
F8FFDDD2E1B6CCDBB2D5E5C0EDFCDBF7FFEAF6FFECF2FFEBEBF8E6FBFFF3FCFFF4FFFFF4
8E8F81403D2EDDD7C9F6EEE3FFFCF8FFFAF5FFFFF3B7BCA6CBD8BAE4F6CEC8DCABC8DDA5
D4E6ACD5E7A9CEDE9FD8EBABC4D99893AC6A8EAB69A0BE789CB86BC6E192E0F8AED7EEA8
CBE1A1D6E9B16B7D4D000800788267FAFFEEFCFFF3FEFFF4FEFFF4FAFEF0FFFFF3FEFFF3
F8FDF6F9FEF8FDFFF9FEFFFAFEFFFAFEFFFAFEFFF9FDFEF8FFFFFBFFFFFDFFFFFDFFFEFF
FFFEFFFFFEFFFFFDFFFFFEFFFCFFFFE9EDECFEFFFFFCFCFAFFFFFDFFFEFDFFFDFDE8E0DE
D3C9C7E4DAD8EEE4E2ECE5DFE4DDD7D9D5CCE6E1DBFFFFFAFEFFFFFBFFFFFBFFFFFCFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFDFFFFFDF9F8F6F0EFEDFFFFFDFFFEFD
EFE9E9FFFDFDE4DEDEBBB5B5E9E3E3B7B1B1CBC5C5FFFEFDFFFEFDFFFEFDFFFEFDFFFFFD
F4F3F1FBFAF8F9F8F6FDFEF9FEFFFAFFFFFAFFFFFBE9E8E466615EFFFEFBD5CCCDD0C7C8
FFFDFDFFFDFDFFFDFEF9F9F9FBFBFBFCFFFFFCFFFFFBFFFFFAFFFEFBFFFDF8FDF9FFFFFB
FFFEFAFFF9FAF7CAD1FFDCE0FFFFF8F7FFF8FFFEFAFFFCFAFFFDFBFFFEFDFEFFFFFCFFFF
FFFFFDF1EDECFFFCFBFFFDFCD3CFCEFFFEFDFBF7F6FFFDFC
DBECCCD0E5BECCDFB1CCE3ABD2E8AACFE7A9D0E5ADCEE4B5D8E9C5D1E4C4F5FFE6F2FFE0
D7EBB8D2EBA9D0E89AC6E192C3DD9ED1E9B9F1FFDDF4FFE7FCFFF3F8F9F1FFFEFBFFFCFD
FFFCFBE8DEDCEAE2DFF9F4F0FFFEFBFFFFFDFCFCFCFFFDFAFFF8ED9E89782B322054695A
DEEDEAF1FFFF98B7B93961605F898771948EE2EEEAE9EAE44C4C40FFFFF1FFFFEFF7F2DE
FEFFE8EFFDDCD1DFBED1E0BFF8FFE6F7FFE8DFF0D0E1F2D2DFEED1E0EFD2DBE5CADEE6CE
ACB19AF6FAE3EFF1DBFFFFEDFFFBE8F3F0DDD3D5BD747E5CE8F9CFEEFFD3B5CC94DDF5B7
CFE3A4D5E8A8E2F2B1798C4A8FA461A5BE7CC1DE9CD2F1ADD0EFA9C9E9A0C5E59ACAE89E
CBE6A1CBE3A55F73420009007D8975FCFFFAFEFFFFFFFFFFFFFFFDFFFCF7FFFFF3FFFFF1
FEFFF3FCFFF3FEFFF4FEFFF6FEFFF8FEFFFAFFFFFAFFFFFBFFFFFDFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFFFFFEFFEEEEEEFEFFFDFFFFFDFFFFFBF8F4F3FFFAF7ABA3A1C0B8B6
FDF3F1FFFBF8FFFDFAFFFEFAFFFEFAFFFFFAFFFFFAFFFFFBFEFFFFFCFFFFFCFFFFFCFFFF
FEFFFFFEFFFFFFFFFFFDFDFDF7F7F7FFFFFFFFFFFDEAE9E7FFFFFDFFFFFDFDFCFAB7B3B2
FFFEFDDBD5D5F7F1F1C6C0C0746E6E726E6DC9C5C4FFFEFDFFFEFDFFFEFCFEFDFBFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFBFAFBF6FFFFFAFCFBF7B0ACA9797471E3DEDBC3BABBFFFDFD
FFFDFDFDF9F8F9F7F8FDFDFDFFFFFFFEFFFFF9FDFCF7FDFBFAFFFEFBFFFFF8FEFCFEFFFD
FFFEFBFFFAFAECC1CAFFDDE1FEFFF8F7FFFAFFFEFAFFFBFBFFFCFDFFFFFDFCFFFFFCFFFF
EBEAE8FFFEFDFFFEFDFFFEFDC8C4C3FFFEFDFFFEFDFFFBFA
DEF3C8D3EBBBCCE3ABCCE6A7D0E9A5CEE9A4CDE5A7CCE5AEC8DEB0C6DCB5F4FFE2F3FFDE
CCE3ABC7E29DCCE796C8E396CDE4AEDDEECAF8FFECFBFFF3FEFFFAF5F4F2FFFBFFFFFCFF
FFF6FAC2B8B9FFFCFDFFFDFDFFFEFFFDFBFEFFFEFFFFFCFDFFF1E6AE94835D5643020600
7C887AE6F3ECF7FFFFE9FEFFCAF3F594C4C481AAA6C8DCDA6B645EFFFAEDF0ECD3FFFFE6
F2FBE0F9FFECD5E2C6C9D8B9F8FFE6F5FFE1CBDDB7D6E8C2CDDFB7DBEBC4D8E8C1D3E1BD
D4DFBDCED8B6CED5B6848969565737646845E0E8BFE8F8C9C7DEA8C0DA9DE1FBBACBE6A1
C6DD97C7DB96D3E4A09AAE69CEE3A0E1F8B4D6F1AEBEDE9BC8ECACBCE3A2C0E59FCFF3A9
CBEDA3C1DE9C596F3E011200798476FAFEFFFAF8FFFDF9FFFFFBFFFFF7F8FFFFF3FFFFED
FFFFEAFCFFEAFDFFECFCFFEFFDFFF3FEFFF8FFFFFBFEFEFEFFFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFFFFFEFFFFFFFBFDFCF7FFFFFAFFFAF6FDF8F5DCD4D1FFFDFAFFFDFA
FFFDFBFFFDFBFDF8F5FFFBF8FFFFFBFFFFFBF8F9F4F7F9F6FEFFFFFEFFFFFCFDFFFCFDFF
FDFEFFFDFEFFFEFEFEFEFEFEF9F8F6FEFDFBFFFFFDF9F8F6FFFEFBC9C5C2AEAAA7FFFEFB
FFFEFDC9C5C40E0A09827E7DFFFEFDFCFBF9FDFCFAFFFEFCFCFBF9F4F4F2F6F6F4FBFDFA
FFFFFDFCFEFBFAFCF9F9FAF5FFFFFBFFFFFAF8F4F16F6B68ECE7E44A4542D5CFCFFFFAFA
FFFCFCFEFAF9FFFDFEFFFFFFFFFFFFFEFFFFFAFEFDFBFFFFF9FFFFF9FFFFF9FFFFF8FDF9
FFFCFBFFF0F2D9AEB7F6D3D9FEFFFAF5FFFAFFFEFBFFFCFDFFFDFDFFFEFFFCFFFFFCFFFF
FFFFFDFFFEFDF7F3F2FFFEFDFFFEFD464241F8F4F3FEFAF9
DDF2C9D5EBBDCEE5B1CEE6ACCFE7A9CDE5A7CCE3ABCDE3B2CFE4BDCFE3C0F5FFE8F4FFE2
CFE5B6CCE4A8D0E9A5CFE8A7F2FFDAF0FDE3FBFFF3F7FAF1FFFFFFFEF9FFFFFCFFFFF6FF
FFFBFFCABFC3FFFCFDFCF6F8FFFDFFFFFDFFFFFDFFFEF5F8FFFAEFC0A6956A53410B0000
868D7BF8FFF6FFFEFFF9FFFFE4FFFF94CBCE6AA8A5BEE7E19186848C7265E4E1BED4DCB3
E7EECDFCFFEAD7E0C3CBD6B6FBFFE6F6FFE1D3E1BDCBDBB45C6C4565764CD1E0B7E9F8CF
B9C59D6F7B53A0AB83A5AD84C7CFA0D7DFAEE0EFB8DDF2B7D6F0AFC5E49EC5E39BBFDB91
EBFFB9CAE097899D56CBDF98D7EBA6C1D894C5E09DD2F0B0C4E7ADC3EBAFC4EBAAC7ECA7
C7E7A4CBE9AB627A4A000D00798378FBFFFFFDFDFFFFFCFFFFFDFFFFFEFBFFFFF1FFFFEA
EBF0D0E6F0CDE8EED2EDF2DBF5F9EAFCFFF6FFFFFDFFFFFFFFFEFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFFFFFEFFFFFEFBFFFEF8E9E4DEFFFEF8FFFEF8FFFEF8FFFDFA827A77D2CAC7
FFFDFBFFFEFBFFFEFBFDFCFAFFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFDFFFFFDF8F7F5F8F7F5FFFEFBD5D1CEEDE9E6B1ADAA
5D5958524E4D797574FFFFFDFFFEFCF6F5F3FFFFFDFFFFFDFFFFFDFEFFFDFEFFFDFAFCF9
FDFFFCF6F8F5FEFFFDFEFFFBF6F5F1FDFCF724201D7C7875FFFEFBADA8A5FFFDFDF5F1F0
FFFEFDFFFFFDFFFEFFFFFFFFFDFDFDFAFCFBFDFFFEFBFFFFF9FFFFF8FFFFF9FFFFF7FBFA
FFFFFDFFF8FBDAB0BAFFE1E7FCFFFAF5FFFBFFFEFDFFFCFDFFFDFFFFFFFFFCFFFFFBFFFF
FFFEFFE5E1E0FFFEFDFFFEFDFCF8F7FFFEFD938F8E938F8E
EBFBE1E6F6D9E3F4D0E4F6CEE3F5CBE0F2C8E1F2CEE4F4D7E7F6DFE1EFDEF7FFF6F6FFF2
E0F0D5E2F3CFE3F6C9E4F5CBF9FFECFCFFF4FEFFFAF8F8F8FFFEFFFFFCFFFFFBFFFFF8FF
FFFBFFF9EEF2ECE3E4E7E1E3FFFDFFFEFBFFFFFDFFFBF6FAFFF7EDC2AB9B70443B210000
41442FF8FFF3FEF4F5FFFDFFDFF9FFBEF5FA277A7280BEB1958E866F5240BEBD8DD3DEA6
E2E8BCEDF1CCD8DCB9DBE1BDF4F9D9FEFFE4E7EECFA5AE8F40492AFBFFE3FBFFE3F6FFDA
D7E2B895A173D0DCAED8E5B0D5E0A6DCEAACD7EAAAD1EAA6C9E79DC8EA9DCBEC9DCFEEA0
B1CC7FB2C87D82964ED8ECA5CDE19CCDE4A0CFE8A6C7E4A4C8E9B0C6E9B3C0E1A8BEDDA4
C4E1ABD1EBBB6177500008007B8779FBFFFBFAFEFDFEFFFFFFFFFAFCFCF0FFFEEAFAFDE0
D0D8B1D0DBB1D9E0BEE5EBCFF3F7E6FDFFF7FFFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFF
FFFEFFFFFEFFFFFEFDFFFEFAFFFCF4EBE2DBACA39CEFE6DFFFFDF6B2A9A4E1D9D6D8D0CD
FFFAF7FFFEFDFEFDFBF8F8F8FDFDFDFCFDFFFCFDFFFCFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FAFAFAF8F8F8FEFCFDFFFFFDF2F1EFFFFFFDFDF9F6FFFEFBF6F2EFB7B3B0D3CFCC6F6B68
807F7DFFFFFDFDFCFAFDFDFBFDFDFBFFFFFDFFFFFDFAFCF9F3F5F2F7F9F6FEFFFDFAFFFB
FCFFFDF4F9F5FAFFFBF6F8F3FFFFFBFBF8F3797572B5B1AED2CECBFFFEFBF7F3F2FFFEFD
FFFEFDFFFFFDFFFEFFFCFCFCFAFAFAFBFDFCFDFFFEFCFFFFF8FFFFF6FFFFF9FFFFF7FBFA
FFFFFDFFFAFDDFB5BFFFEFF6FCFFFBF5FFFBFFFFFDFFFCFDFFFDFFFFFFFFFCFFFFFBFFFF
FFFEFFFFFEFDFFFBFAFFFEFDFBF7F6FFFEFDF1EDECFFFEFD
FBFFF8F8FFF3FAFFF0F9FFEFFAFFECF5FFEBF9FFEFF9FFF6FBFFFBF2FBF8FBFFFFF9FFFF
F6FDF5F9FFF4FBFFEFFBFFEFF7FDF1F9FCF5FFFFFFFDFBFFFFFCFFFCF4FFFFFBFFFFFBFF
F8EFF4FFFCFDCEC5C6D8D2D2FFFEFFFAF8FDFFFEFFFFFEFFFFFEF5B5A1967B464271403B
181100FCFFF3FFFBFDFFFAFFF0FFFFDBFFFF51A79E6AB1A1C2C6B7544325989B62D8E39F
E0E4A9D6D6A2D8D7A9ECEDC5EBEACBFEFEE4EDECD8767765BBBCACF7FAE5FFFFEAFEFFE4
F5FDD6B0B98CCAD4A0D6E1A7D7E3A3CEDD98D6ECA4CAE49AC3E495CCEF9FC6E997C6E796
D7F2A393A95E879B53CFE39BDAEEA9D4EBA5C0D995CEE8A9C7E2ABCDE8B5D7F1C2E3FAD0
E3F9D3E0F3D36A7D61000C007A8773F4FFECEAF6E2EAF3DEEBF3DCE7EFD7EDF3D9ECF3D4
D4DFB5D7E2B7E1E9C4EDF3D7FAFEEDFEFFF8FEFEFEFAF9FFFFFDFFFFFDFFFFFDFFFFFDFF
FFFEFFFFFEFFFFFEFBFFFEF8C5BCB5C7BDB4A89E95F5ECE3FFFDF6B8AFA8CAC2BFFFFEFA
FFFCFBFFFFFDFEFEFEFBFDFCFEFFFFFEFFFFF8FCFFF8FCFFFAFBFDFEFFFFFEFFFFF7F9F8
EDEDEDE9E9E9EEEDEBF5F4F2F9F8F6E4E3E1F2EEEB7C7875CAC6C3F2EEEBB5B1AEF8F4F1
FEFDFBF7F6F4FFFFFDFFFFFDFEFEFCFFFFFDF9FBF8FEFFFDFEFFFDFEFFFDFCFFFDF1F6F2
FCFFFDFCFFFDFCFFFDF7F9F4F4F3EFFFFFFAE9E5E2F2EEEBAFABA8FFFEFBF6F2F1FFFFFD
FCFBF9FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF8FCFBF9FFFFF8FFFFF9FFFFF4F8F7
FFFFFDFFF8FBD1A7B1FFE4EBFCFFFBF5FFFBFFFFFDFFFCFDFFFDFFFFFFFFFCFFFFFBFFFF
F7F5F6FFFEFDFFFEFDF0ECEBFFFEFDF9F5F4FFFEFDFFFEFD
FFFFFFFEFFFFFFFFFBFEFFFBFFFFFAFEFFFBFFFFFDFEFFFFFFFEFFFEFEFFFFFDFFFEFEFF
FFFEFFFEFFFFFFFFFDFFFFFBFEFDFBFCFAFBFFFEFFFFFDFFFAF4FFFFFBFFFFFBFFFFFBFF
FCF3F4FFFEFAFFFAF6E4E1DCF3EFECFDFBFCFAF9FFFFFEFFFEFFFAB9AAA370393CD49C9D
7D675CBAB4A8F8EEEFFFFDFFF4FFFFE1FFFF84CDC4397E6BB1CEB2DCE3B9737C3DD2D68C
E9E99FB6B36EA6A16760592B5B5233CAC2AF6A6057403635FFF9FAFFFDFAFFFCF1FAF9E4
FFFFE3A4A77C848B57E2ECB0DCE7A5CAD994D9EFA7C6E096C0E192CFF2A2BDE090CBEC9D
C9E4977B9146B5C981CBDF97CCE09BD2E9A3D1EAA6CFE8A7CBDFA4D7E7B6DCEAC6F9FFEC
F9FFF4F8FFF8323E300006007A896AEFFFD9D8EBBDD7EBBAC0D3A6D6E8C0D0E1BFCCDBBA
CEDBB0E0EBC0F6FED9FEFFE8FEFFF1FDFFF7FEFEFEFFFEFFFFFEFFFFFDFFFFFCFFFDFAFF
FEFCFFFFFEFCFFFFFAFFFFF6C4BAB1C0B3AACDC0B7FFFAF1FFFDF6FFF8F1FAF2EFFFFEFA
FFFEFDFFFFFDFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFFFFFFFFFBFBFB7B7B7B
6462635857552524224F4E4C4B474408040164605D56524FD8D3CFFFFEFAFFFEFAFFFEFB
FEFDFBFFFFFDFFFFFDFDFDFBFEFEFCFFFFFDFEFFFDFDFFFCFEFFFDFEFFFDFCFFFDFCFFFD
FCFFFDFCFFFDFCFFFDFEFFFBFFFEFBFFFDF9FAF5F2FFFEFBD3CFCCFBF7F4FEFDFBFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF9FFFFF7FFFFF9FFFFEFF3F2
FFFFFDFFFAFDC298A2FFE1E7FCFFFAF3FFF9FFFEFDFFFCFDFDF7F9FAFAFAFCFFFFFBFFFF
FAF8F9FFFEFDFFFEFDFFFEFDFDF9F8FFFDFCFFFEFDEEEAE9
FFFDFFFFFDFFFFFDFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFFFCFFFFFCFFFFFCFF
FFFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFBFFF8F3FAF3EDF7FFFBFFF5EEF6FFF9FDFFFBFB
FFFEF8FFFFF4D7D5C8B7B7ABDCDCD2FEFFF9FEFEFEFAFCFBF7FCF5DAD1CABC9091673335
B3908C55403BFFFCFDFAFBFFE5F2FBEAFFFFB3E8E272B09B7DAF8ABBDDAA768244CFD188
F7F4A5ABA559504809827749827459988A7D574748796973FCECF9FFF7FFFFFCFDFFFDF1
FFFFE6B5B58FA1A372CBD098CDD79ADDECABCEE29DD3EDA6CCEAA0BEE094D2F2A7C7E59B
D0EAA0AEC47B9DB16AD1E59ED5E9A4C7DE98C8E29BD2E9A5C9D79ADDE5B4E6EDCEF9FDEE
F0F4F3ECF0F311171500090071815CDFF3BED7F0AFD2ECABC2DBA1CDE7B7D9F1CDE4F7D7
E2F1CAEFF9D4FDFFE3FEFFECFEFFF3FDFFF7FDFDFDFFFEFFFAF9FFFDFCFFFFFDFFFFFEFF
FFFEFFFFFFFDFFFFFAFFFFF6FFFCF48E80778B7E75FFFBF2FFFDF6FFFEF6F3EEEAFFFFFA
FFFFFDFFFFFDFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFFFAFAFCEDEDEDFDFDFDA6A6A6
E2E1DFB7B6B49C9B99848381CBC7C4837F7CEBE7E4CDC9C6FFFEFAF8F3EFFBF6F2FFFAF6
FFFBF8FCFBF9FFFFFDFFFFFDFFFFFDF7F7F5F6F6F4FEFFFDFEFFFDFEFFFDFEFFFDFCFFFD
FCFFFDFCFFFDFCFFFDFEFFFBFFFEFBFFFEFAF2EDEAFEF9F6E4E0DDFFFFFBF8F7F5F8F8F6
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFFFFF4FDFAF9FFFFFCFFFD
FFFCFBFFF6F8D7ACB5FFDDE3FBFEF7EEFBF1FFFCF9FFFCFDFFFDFDFFFEFFFBFFFEF4F8F7
FFFFFDEEEAE9FFFCFBF9F5F4FFFEFDFFFEFDEFEBEAFFFEFD
FFFDFDFFFDFDFFFDFDFFFDFDFFFDFDFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFF
FFFDFFFFFDFFFFFDFFFFFDFFFFF9FDFFFDFFFFFCFFFCF5FCFFFCFFFAF4F8FFFEFBFEFBF2
A6A495CCCEB9D5D9C2D4D9C2F3F8E4FEFFF3FEFFF8F5FAF3FCFFF6F9F7EBFFEEE78D6766
7443478A63686C6364B3BDBEF5FFFFF1FFFFEAFFFF719C8942875BB6F2BCA1B580464409
716D23706A20655D1FE0D5A8FFFEE46F5E570D0002796475FFF6FFFFF3FFFFF9FFFFFCFA
FFFAE8DFDCBDBFC0969CA06ED8DCA9DEE7B0D6E5ACCDE3A5D2ECABC8E7A4C2DF9CD4EFAC
CFE6A2CFE4A1B4C883C0D48FE3F7B2D2E9A3C6E19ACFE6A0DBE5A6E5E7B5ECECD0FCFCF2
FFFEFFFEFEFF0000050004006F7F58C0D59AC3DD94C3DF95CDEAAAD3EFBEECFFE5F4FFED
F6FFE5FBFFE7FEFFECFEFFF1FEFFF4FDFFF9FEFEFEFFFEFFFFFEFFFFFEFFFDFBFFF9F7FA
F7F5F6F8F7F5FDFAF5FFFDF7DBCEC6E7D9D0F3E6DEFFFDF4E8DFD8FFFEF6FFFFFAFFFFFA
FFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFFFFFFFFFFFFFFFDF4F3F1
FFFFFDFAF9F7FFFEFBFFFEFBFDF9F6FFFEFBF1ECE8605B57E6E1DDFFFEFAFFFEF8FFFEFA
FFFEFBFFFEFDF9F5F4F2F1EFFCFBF9FFFFFDFFFFFDFAFAF8FFFFFDFEFFFDFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFFFFFBF9F4F1FFFAF7FFFEFBFFFEFBCECAC7FFFFFBFFFFFDFFFFFD
FFFFFDFEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFCFFFFF4FAF8FAFFFCFEFFFB
FCF8F5FFF9FAF5C7D1F8D4D8FFFFF8F8FFFAFFFEFAFFFBFBFFFDFBFFFEFDFEFFFFFEFFFF
FFFFFDFFFEFDFFFEFDFFFDFCFFFEFDE4E0DFB3AFAECAC6C5
FFFEFAFFFEFAFFFEFAFFFEFBFFFDFDFFFDFDFFFDFDFFFEFBFFFEFBFFFEFBFFFEFBFFFEFB
FFFEFBFFFDFDFFFDFDFFFDFFFFFCFFFBF2F5FFFDFFFFFDFFFFFDFFFFFEFBEDEAE18E8F7D
B9BCA1E5EACAFEFFE3FBFFE3FBFFE7F8FFE9F8FFEEFBFFF3FBFFEFFEFFEDF0EDDCEBD7CE
B7848994656F190F10000302F6FFFFF3FDFCF2FBF8DDFCEC418C65B2FBCDB3CFA9A2A57A
4B4B0FAAA667E6DEADE9DFBBFFFCE9BAA8A459454E756071FFF7FFFFF4FFFFF9FFFFFBFB
FFFCEFF8F4DBD4D4B29FA17A4C4D25EBF1C5D7E0B3BFCF9EDFF6C0C6DFA6CAE3A9D2ECAF
CDE3A5C4D698DFEFB0899C5AC7DC97D5ECA6CEEAA0CCE39BF1FAB9FFFFCFFFFFE4F6F3EA
FBF8FFFFFDFF000106676D63C7D5B1E3F6BFDBF2AED2EBA7F1FFD1E7FFD6F0FFEDEBFCEA
F9FFF1FBFFF0FCFFF1FBFEF3FCFFF6FEFFFBFFFFFDFFFFFFFAFAFCFAFAFCFFFDFEFFFEFF
FFFFFDFFFFFBFFFEFBFFFDF782786FFCEFE7FFFCF4FFFCF6FFFEF6FEF9F3FFFFFAF1F2EC
FFFFFBFFFFFDFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDEDECEAFFFFFD
F3F2F0FFFFFDFBF7F4FFFCF9FFFBF8FFFEFBFFFEFAB3AEAAD5D0CCF8F3EFFFFAF4FFFDFA
FAF5F2FFFEFDFFFEFDFFFEFDFFFEFDFFFFFDFFFEFCFDFCFAFFFFFDFFFFFDFFFFFDFEFFFD
FFFFFDFEFFFDFEFFFDFFFFFB908B88716966F9F4F1FFFEFBD0CCC9FCFBF7FFFFFDF8FAF7
FEFFFDFEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFEDF1F0F5FAF6FCFFFBFFFFFA
FAF5F1FFF4F3FFD9E1FFF3F6F7F7EFEFFBEFFFFEF8FFFBFAFFFBF9FDF8F5FDFDFBFCFEFB
FFFFFDFFFEFDEBE7E6605C5B7B7776FFFEFDFFFEFDFFFEFD
FFFFF8FFFFF8FFFFFAFFFEFBFFFEFDFFFEFDFFFEFBFFFFFAFFFFF8FFFFF6FFFFF6FFFFF6
FFFFF8FFFFFAFFFEFBFFFEFDFFFDFDFFF7F8FFFDFDADA8A5B8B5B0C2C2B8DADBC9DDE1C6
ECF4CFECF7CCEAF7C9EBF8CCEBF7CFE1EFCCDFECD0E7F4D8DCEAC6EAF8D4EEFDDEFBF8E5
FFD9DB956771948185A1A19F393E3ABBC2BBFFFFFB9CB0A51F5D4481C6AADEFFF2E1F2DF
FBFFDFDCDAB4D4CFAFE2DCC4FCF2E6FFF9F5CDBEC196878ED3C3CDFBEEF7FFFBFFFFFDFA
FCF8EDF2F1DFE0E2CCE1E1C7FFFFE69D9C80C5C8A9E1EBC8C6D6AFD2E8BAC7DDAED0E7B3
DEF1BABFD197DAE9AE788B4B9AAF6CB8D28BD1EFA5C8E299E7F3B1F5FAC4FFFFE3FFFFF1
FFFEFFFFFEFF0000026B7167CDD6BBCEDAB2CADAA9CBDBAAF8FFE1F8FFECF8FFF8F8FFFD
FBFFFBFBFFFAFBFDF8FCFEF9FEFFFBFEFFFBFFFFFDFDFDFBFFFFFDFFFFFDFFFFFBFFFFFB
FBFAF6E1E0DCBDB9B6A29D99FFF5EFFFFCF6FFFCF6F4EBE6FFFEF8FBF8F1FEFDF8FFFFFA
FFFFFBFEFFFBFFFFFDFFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFF7F6F4FFFFFDFFFFFD
FFFDFAFFFEFBFAF6F3FFFDFAFFFEFAFFFEFAF8F3EFC0BBB7B3ACA6FDF6F0FFFEF8FFFCF9
FFFEFBFEF8F8FBF5F5FFFDFDFFFDFDFEFAF9FEFAF9FFFEFDFFFEFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFBA9A19F352D2ACCC7C4E7E3E0ECE8E5FFFFFBFFFFFDF2F4F1
FEFFFDFCFFFDFEFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFFFDFEFFFBFEFFFAFFFFF8
FFFEF8FFF5F2E7B6BCF5CDCEFFFFF6F9FFF6FFFDF6FAEBE8D3C8C4C0B8B5C6C5C1D0D0CE
CFCECCD1CDCCB7B3B2DBD7D6F0ECEBF0ECEBFFFEFDFBF7F6
FFFFFAFFFFFAFFFFFBFFFFFDFFFFFFFFFFFFFFFFFDFFFFFBFFFFF8FFFFF6FFFFF4FFFFF6
FFFFF8FFFFFAFFFFFDFFFFFDFBF6F3FFF8F5FBF6F258554EE5E2D9FFFFF1F9FDE4E7EFCA
D4E0B2CAD8A3C8D9A2D4E5AFDBEBBAD6E7BBCFDFBACCDCB5D6E8B6BED29FD8EFC5FCFFEA
FFF7F3FFE5EA51363BB7A9A97B7A757C7F76B7BAB3EEFFF72E5C513D746E8EBBBEE5FFFF
E0EBE3FFFFF3FFFFF3F6F2E7FFFFF6FDF6F0FFFDF8AFA5A3C6BCBAFAF2EFFFFDF7FFFFF8
FFFEF5FBFDF0EEF0E3FFFFF3ECE4D7F5EEDEF6F5E3FAFFE8F9FFEAF7FFE6F7FFE3F4FFDA
F2FFD3D6E7B3C8D79EC0D294ABC07DB1CB82D2F1A5C1DD93B2C2819BA570A0A680AEB39C
CFD2C9FEFFFD0305027E817AFEFFF3FEFFECFEFFE8F5FBE1FEFFEFFBFEF5FEFFFFFAFDFF
FCFFFFFCFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFAFCFDF8FEFFF9FAFBF5FBFAF5FFFFFA
FFFFFAFFFFFAF0ECE9DFDAD6C3B8B4BCB1ABFFFDF8FFF9F3F6F1EBFFFFF8FFFEF9FEFFF9
FEFFFBFEFFFBFFFFFDFFFFFDFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDF4F3F1FFFFFDFFFFFD
EFEBE8FFFEFBF7F3F0FFFEFBFDF8F4FFFEFAFFFEFAFFFCF8D2CBC5BEB7B1AFA8A2C7BFBC
FCF4F2FFFDFDFFFDFDFAF4F4FDF7F7FFFDFDFFFDFDFEFAF9FFFEFDFFFEFDFFFEFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFEFBFFFDFB796F6DA69E9CABA6A3FEFAF7FFFFFBF3F5F2FEFFFD
FCFFFDFCFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFDFBFCF7F6F7F1F2F3EBFBF8EF
FFFDF6FFF8F4DAA9ADF0C6C7ADA99EAFB7A8D0C7BEE0CECAD4C7C1DBD2CDF6F3EEFFFFFB
FFFEFDF5F1F0FFFEFDFFFDFCF8F4F3FFFEFDFFFEFDFFFDFC
FCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFDFCFFFAFCFFF8FCFFFA
FCFFFBFCFFFFFCFFFFFEFFFFFFFCF9FFFEF8FFFEF87C7970D4D2C3F0F4DDEAF1D0DAE5BA
DFEDB8DAECB0D6E8AACCE0A3CADDA5D5E9B6DEF1C4D9EDBCC6E09FD2ECABCCE4B0F9FFE4
FFFFEFFFF8F678555BBA9BA0FFFCF673766B8A9A8DF1FFFF9DB4BA3152615B8FA5A5D5EB
F1FFFFFBFDFFF2F5FCFEFFFFEAE9E5FFFFF6FFFFF3B0AD9CDDDAC9FFFEECFFFDEEFFFFF3
FFFFF6FCFFF8F8FDF7FFFFFBFFFCFAFEF0EDEDE6DEDBDBCFF5FEEBF8FFEDE9FADAF7FFE3
F8FFDCDFEDBCCFDEA7E8FABCD3E8A5C9E39ACCEB9DC2DE93CEE3A2CADBA4E8F5C9F0FBD9
D0DAC2ECF2E40002007A7C77FBFCF7FBFAF5FFFFFAFDF9F6FFFDFFFFF9FFFFFBFFFFFCFF
FEFDFFFCFEFFFEFEFFFEFFFFFEFFFFFEFFFFFEFFFAFEFFF9FFFFF8FFFFF8F8F8F0F7F7EF
FBFAF5FFFEF9FFFDFAFFFBF7F6EDE8BEB3AFE5DBD9FFFDFAFDF8F4FFFFFAF5F4EFFFFFFA
FEFFFBFEFFFBFFFFFBFFFFFBFFFFFDFFFEFDFFFDFDFFFDFDFFFEFDFFFFFDFDFCFAFFFFFD
FFFEFBFFFEFBFFFDFAFFFDFAFFFEFAFBF6F2FFFEF8FFFEF8ECE5DFFFFEF8FFFEF8AFA7A4
BAB2B0EEE5E6FFFCFDFFFCFDFFFAFBFFFAFAFFFAFAFAF4F4FFFDFDFFFEFDFFFEFDFFFEFD
FFFEFDFFFEFDFFFEFDFFFEFBFFFAF9837977665E5C9E9996FFFEFBFDFEF9F6F8F5FCFFFD
FCFFFDFCFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFDFEFDF8F8F8F0FFFFF8FFFFF6
D5CBC2CAB1ACB48285F2C9C7A19D91ADB4A4E1D7CDFFF6F0FFFBF6FFFCF7FFFEF7FAF9F4
FDF9F6FFFEFDFFFEFDF0ECEBBEBAB98783827F7B7A827E7D
FBFFF4FBFFF6FBFFFAFBFFFBFBFFFFFBFFFFFBFFFFFBFFFFFBFFFDFCFFFBFCFFFBFCFFFD
FCFFFFFCFFFFFCFFFFFEFEFFFFFEFDF6F1EBFFFFF6FFFFF1E3E5CFD3D8B8CCD7ACD3E1AC
CADCA0D2E5A5D4E8A9CBDFA4D0E4AFEDFFD3EFFFDBD0E5BCC6E1ACD7F4BEC2D9AFF9FFE8
FAFBEBFFFCF4B593948A6869FFFCF3C0C2B556665996ABA4F5FFFFE4FAFF86BAD07EB2C8
E2FDFFEEFAFFF7FFFFFBFFFF010000F3EEEAFFFDF1A4A391DBDEC9FBFEE9FFFFEFFEFFF3
EAF2E7FCFFFBFFFFFFFFFAFEFFFBFFFFF4F4C0BBB8CAC9C4F3F6EBF7FFEFF9FFEFF9FFEA
FAFFE3CAD6AED9E9B8BED199CFE8A7D8F3ACC0E094C9E99ED2EDAAC1D99DD5EAB1DBEFBC
ACBC95D5E2C60008007C7E79FFFEFFFEFBFFFFFDFFFFFAFFFFFBFFFFFAFFFFF6FFFFF8FF
FBF9FFFAFDFFFDFDFFFCFDFFFBFCFFFCFDFFFFFFFFFFFFFDFDFEF8FFFFF8FFFFF6FFFFF6
FFFFF8FFFFF8FFFEFAFFFCF9FFF9F4FBF0ECB0A5A3FFFCFAFDF5F2FFFEFAFFFFFAFFFFFA
FFFFFBFFFFFBFFFFFBFFFFFBFFFEFBFFFEFBFFFDFDFFFEFBFCFDF8FFFFFBFFFFFBBAB9B5
DBD7D494908DFCF7F4FFFEFAFFFEF8FEF9F3FFFCF6FFFAF4FFFFFAEEEDE8FFFFFBFFFFFB
FDF8F5BDB8B5ADA8A4E7E2DEFFFEFAFFFEFAFCF7F4FFFEFBFFFDFDFFFEFDFFFEFDFFFEFD
FFFFFBFFFFFAFFFFFAFFFFFAFFFCFA817775302825A09B97F7F6F1F9FAF4FCFFFBF0F5EF
FCFFFDFCFFFFFEFFFFFFFFFFFFFEFFFFFDFFFFFCFFFFFCFDECE9E4B4B1AAE2DDD7E7DED7
C8B9B2E8CFCAE1B5B6FFF3F1FFFFF3FBFFF0FFFAF1FFFBF6FFF9F6FFF7F2F9F4F0EDE9E6
C6C2C1F7F6F4FFFFFDAEADAB888785949391807F7DB0AFAD
E4F4C5DFEFC2D9E8BFF3FFDDE8F3D3FBFFECFCFFEFF2F9E9F7FDF3FEFFFBF2F4F3FEFFFF
FFFEFFF9F7FFFFFDFFF9F7FFFFFEFFFFFFFBFFFFF4F5F9E2F7FEDC9BA779909D65DDEDAE
D7EAA8CDE0A0CBDFA4D8EABAE8F9D5F2FFE8EBFCEADDEFE1E3FAEADCF3E3E8FAECF9FFF6
FDFDF3FFFDF4FFF5EE77635AFDEFE4FAF6EA797F735A675EF2FFFFEBFFFF779FA7628F95
BCDFE1E9FFFFEEFFFFF8FFFF070004FFEFF5FFFCFBA5A59DD2DACDF9FFF4FCFFF4FBFFF8
F8FFFBFAFEFFFFFAFFFFF7FFFFFCFFF7F3F0B1B0ACABACA7FFFFFBF7FAF3FBFEF3FCFFF3
F3FDE5DFECCED0E2BAD3EBB9C0DEA2D4F4B1C1E79EC1E79CD0F1AAC8E89FCCEB9FBAD68C
CAE2A4D3E6B8000600818783FCFFFFFBFBFFFCFAFFFFFEFFFFFDFDFFFBFCFFFAFFFFFCFF
FFFFF8F8FBF0FEFFFBFBFDFCFFFEFFF6F5FDFFFDFFFBF8FFFFFEFFFBF7F4FFFEF8FDF9F0
FFFFF4FFFFF4FFF9F1FFFDF6FFFBF7E1D3D2B5A7A6FFF6F4FFFCFAFCF2F0FFFAF7FFFEFA
FFFBF7FFFEFAFFFEF9FCF9F4FFFFFAFFFFFAFFFCF9FFFFFAEFF5E9FBFFF6F4F9F2979893
DCDBD7A39E9BE2DAD7DED7D1FFFEF6FFFFF4F8F6EAFFFFF8F3F8F2F9FFFFF3FDFFF9FFFF
F8FDF7FFFFF6D1D3C6C4C6B8D1D2C2FFFFF3EEEBE2FFFFF8FFFEFBFCF8F7FFFEFFF5F4F2
FFFFF8F3F5E8FEFFF1FFFFF3FFFEF8BEB4B24F4A4489867DFFFFF6FEFFF6F0F8EDFBFFFA
FBFFFDF7FBFCFCFDFFFAF7FEFFFCFFFFF8FED9CDCFCABEBE978F8D96918DE5DAD8FFFBF8
FFF1F0EBD3D1D8BCBBFFF8F4FFFDF6F5F2E9FFFEF8FDF5F2FFFDFBFFFCFDA59A9E736A6D
817F80FFFFFFFAFAFAFFFFFFFEFEFEF3F3F3FFFFFFFDFDFD
D2EBAAD3EBADD8EDB2D8EDB5DCEEBEE6F7CBF9FFE4F9FFEAFBFFEFF8FFF3FCFFFBFCFFFF
F7F8FDF1F1F9FCFCFFFFFDFFF1EFFAF2F1F6FFFFFBFFFFF3FFFFE8DBE3BCC6CFA0C4D19C
D1DEA9CEDAA8E2EFC4F2FDDDEBF7E3F5FFF4F8FFFFF7FFFFF3FFFFF3FFFFEFF9F8FAFFFB
FFFFF8FFFBF2FFFCEFEBDBCC57493CBAB0A4F0EEE2737871707F7AE9FFFCEAFFFF5C807E
638E87E0FFFFE6FFFFF3FEFF040004F9EAEFFFF8FABBB3B1BBBCB4FCFFF8F7FFF4F9FFFA
E8EEECFFFFFFFFF6FFFFFAFFF9F3F3FFFFFBDBDAD8959492F9F5F4FFFEFBFFFFFBF8F9F1
FEFFF3E6F0D8F0FFDED2E7BCC7E2ADCBEAAEBCDF9DC9EDA7B3D48FCAEAA1D1F0A093B060
C9E39CC2D6A1000A00717775FEFEFFFFFDFFFFFEFFFFFEFDFFFEF8FFFDFAFEF3F7FFFCFD
FFFFF6F7F9ECFFFFFBFFFEFFFAF7FFFFFCFFFFFCFFFEF8FFFFFAFEFFFDFBFFFEF4FFF7EA
FFFFEFF9F2E2F2E8DCB2A89E887F7AEAE0DEFFF9F7FFFCFAF7EFECFFFDFAFFFDFAF2EDE9
FFFEFAFFFCF7FDFAF5FCFBF6FFFFFAFFFFFAFFFFFAF3F6EDF7FFF0FBFFF4F8FEF491928C
FFFBF8FCF7F3FFFDF8C7BEB7FFFEF3E9E5D9FFFFF3FFFFF6FCFFFBF9FFFFF3FEFFE7F0F5
F8FCFDF2F3EEFFFFF8FFFFF4F4F5E7C0BEB1C8C4B9FFFEF8FBF5F5FFFDFFFFFDFFF5F3F6
FFFFFDFFFFF8FEFFF6FAFAEEFFF9F5FDEDEDD4C9C3E4DDD3FFFFF3F8F9EBFEFFF4D6DCD2
B8BDB9FCFFFFFEFFFFFFFDFFFFFCFFFBF0F4FFFBFDFFF3F3FAF2F0FFFAF8FFFBFAFFFAFA
FFF9F8F1DCDBE9D6D2FFF9F5FFFCF8FDF8F2FAF6F3C2BEBB767072372E31B9ACB3FFFBFF
FAF6F7FFFFFFFCFCFCF8F8F8F8F8F8FFFFFFEBEBEBFFFFFF
C7E5A5C1DFA1C6E4A8B7D49AD2EDB6CBE6B3D6EDBFD5ECC2C7DBB8CCDCC1F8FFF1F3FFF1
F1FBF3F9FFFFF5FDFFFCFFFFFFFBFFFDF4FFFFFAFFFFFBFFFFFCFCFFFCF5EDEBDEB0AE9F
FFFFEFF2F3E1F9FAECFFFFF6F6F7F2FFFFFFFFFEFFFBFCFFF5FAFDFBFFFFFBFDFAF8F7F3
FFFDF6F7EAE1FFFBF1FFFBEF7E6C606B5D52EDE4DBF5F2EB6E736DCAD5D1EDFDFAD2F1EC
76A7A3D3FFFFEEFFFFEEFAFA111A15FFFFFAFFF2EFD0BBB88D7A76FFF7F2FBFFFAE6F0E8
FFFDFDFFFCFFFBFBFBF7FBFAFFFFFBFFFFFAFCF8F5FFFEFBD0CACAFFFEFBF2EDEAFFFEF8
FFFFF4FFFFEEFDFFE7D5E1BDC8D8ABD7EBB6D8F0B6CAE4A7DEF5BDC2D79CCDE29DC0D48D
C7DA9AE0EEBD000500898B88F8F5FFFFFCFFFFFBFFFFFAF8FFFAF8FFFCFAF8EBF2FFFAFF
FEF5FAFFFDFFFFF6FFFFF8FFFFF9FFFCEFFFF6E9FAFFFBFFFCF0F2FFFDF4FDF4E3FFFFEA
E3DBC48B846AE4D9C3FFFAE9FFFFF6FFFFFBF0EFEBFFFFFBFBFAF6F5F6F1FFFFFBFFFFFB
FFFFFBFEFFFBFEFFFBFCFFFBEFF4EEF6FBF5FCFFFBFCFFFAFCFFF2FFFFF4F2F2E8B5B2AD
FFFEFBFDF5F2FCF3EEFFFDF4B3AB9EFFFFF1FFFDEEFFFFF4FAF9F4F9F9F9FCFFFFFEFEFF
FFFCFFFFFAFFF8F0FDFFF8FDFDF5F3FFF8F6E5DBD9AFA3A3FFF7FBFFFBFFFFFAFFFFFBFF
FFFBFFFFFCFFFCF9FFFFFBFFFFF7FAFFF2F2B9A09CB29F98FFF3E8FFFEF1FFFFF4DFDFD5
DADBD6EEF0EDFFFFFFF0F0F2FEFAFBFFFAFAFFFCFAFFFDFAFFFEFBFFFEFBFEF3F1FFF0F0
FFF9F8D0BBBAE6D3CFFFFAF6FEF3EFFFFEF8FFFEFB030000B0AAACFFFCFFFFFAFFFFF5FB
FFFDFFFFFEFFF5F1F2FFFEFFFBF7F8FBF7F8FFFCFDFFFEFF
CDE7AACAE4A7D1EBAECBE4AADDF5BBC7DEA6BCD09BCEE2B1D1E0B5CCDAB6FBFFE8FBFFED
FCFFF4FCFFF8F7FCF6FAFAFCFFF8FFFDEEFFFFF8FFFFF4FFFBEDFCFFFAFFFFFAFFFFF4F8
DAD0D1EDE3E4FEF4F3FFFCFBFFFDFBFFFDFBFFF9F7FFFDFAF9F5F4FFFFFBFFFEFBFFFBF6
FFFCF6FFFBF4FFFAF3FFFAF1FFFAF1AB998FA4958EF5EAE4837E78010000F7F9F4E0F3EF
A6D4D284B6B5E8FFFFDFEFEC000600FAFFF4FFFBF3FFF7F16A4B48B29A96EFEAE4FFFFFA
FFFBFBEBE3E1F9FFFBF8FFFBF2F3EDFFFEFAFFFAF7FFFCFAF9F0F1E2D8D9C2B8B7FFF6F4
FFF8F0FFFFF1FEFCE7FFFFE6FAFFDCF9FFD8F9FFD5D3E1B0D4DFB5D9E5B7D4DFA5D3DFA1
96A064C5CCA016180265625DE3DCE4F2E8F1F4EAEBEEE3E1EBE0DCFFF4F2D4C5CCEADAE4
FFF5FCF0E3EAFFF4FFFFF7FFFFF2FFFFF2FFFFF9FFF5E6EBFFFBF8FFFCF3E0D3C3D1C6B2
C1B4A1BDB09FFFFDEDFFFAF1FFF9F4FFFEFBFFFBF9FFFDFBFFFDFBFFFDFBFFFEFBFDF8F5
FFFEFBF6F1EEFFFCF9FFFEFBFAF5F2FFFEFBFFFEFBF7EDEBFFFBF4FFF8F1FFF8F5E1C9C9
EAD1D4FFF7FAFFEEEFFFF1EE785F58FFEEE4FFF2E8FFF8F1FFF8F6FFF2F6FFF7FFFFF5FF
FFE5FFFFEAFFFFF2FFFFF4FFFFF5FAFFF6F4FFEBE89E7F7DFFDFE2FFF4FBFFF4FFFFE7F7
FFE9F8FFEDFEFFF3FFFFF4FFFFE6EEFFF3F4D6B3B1A48580BDA49DE6D5CBC8BEB4DED7CF
FFFFFAF2F1EDFFFFFDFFFFFDFFFFFDFFFFFBEAE9E5FFFFFAFFFEFBF2EDEAFFFCFAFFFAFA
FFF9F8D5C0BFF9E6E2FFFAF6FFFCF8A39C966A6663FFFFFBF4F0F1FEF8FAFFFBFFFFFBFF
FFFCFFF6EDF0FFFCFFFFF8FBFFFAFDFFFCFFFFFCFFFAF1F4
EBF4BFE1EAB3D8E1AACFD89FB5BD8299A1667B8046A4A973BFBE8EDAD8AFFFFFDFFCF6DC
FFF9E8FFF8EEFFFCF6FFFBFBFFF9FFFFF9FFFFF6FFFFF8FFFFF8FFFFF8FFFFF0FCFFF7FF
FFF8FFFFF0F4C5B3B3B9A7A3FAE9E1FFFCEFFFF2E3FFFCEFFFFCF4FFF5F1FFFBF8FFF9F4
FFF7F3FFECE8FFF9F4FFF0EBFFF6F1FDE8E37D6863B7A49EFFF4ED695A53CDC0BAF4F9F5
E3FFFF3363677FA6A5DDF8F1000500FFFFF3FFFCEFFFEEE3FFE5DF9A7471866765FFF8F6
FFF7F4FFFFF8F8FFF8EBF7EBFFFFF8FCF4F1FFFDFBFFFCFBFFFBFDFFF5F7FFFAFDE7D9D9
CFC1BEC1B4ACD9CFC3F6EFDCFFFFE8FFFFE3FEFEDCF0F0CEE9E9CDEDEECECBCE9FEBF0B8
C3C69157582C090400726B63E6DCDDF2E6EAF6EBE7F4E7DFF0E3DBFFF1EEE6D7DEFBEAF0
F5E3DFFFF8F1E7D3D2AF9D9DF4E1E5FFF0F4F4E1E3DDCBC945342DA09289F2E1D7E5D7CE
CFBDBBD2C2C3E7D6DEA9959ECCB5BBEED5D9D6BBC0B79CA1A58A8FD6BBC0F8DDE2FADFE4
A5888DC9ACB1FFE4E9FBE0E5C1A4A9AF9499CEB1B6DFBBBFCB9499CF9196FFDFE8E1A3B0
A16372BF838FE0A4AED4999FBA7F817C4240D79B9AAA6C6DBE7D85D795A3F8B5C7D995AE
C27B99D18BA7FFC0D2AF6973D69090B9746DF7B3A8854136B7726BF9B5B4FFC6CAB17078
BC7D88E0A2ADF6BAC6C78E97B67F85CF9DA0D2A4A4875F5D482722CCB3AECCBBB4EDE2DC
E0D9D3FFFFFAFAF9F4FFFFFBE7E9E4FEFFFBFEFFFBFFFFFBB2B1AD8F8A87BEB3B1857575
7B6766AC9796FAE7E3FFF4F0FCF1EDF4EDE7FFFEFBFFFFFBFFFEFFFFF9FBFFF8FEFFFBFF
FFFAFEFEF3F7FFFBFFFFF4F8FFF5F9ECE1E5FFFBFFFFFAFE
E2E0ADBEBD87A3A26A9D9C638A884D8C8A4D605C1F756F357E743F968B5EEDDFBCFFFDE3
FFFBECD8C4BBEAD5D2FFEBEAF4E2E0FFFAF8FFFAFAFFF6F8F8E3E8E2CDD4E2CDD6FFF8FF
FFEBF1F1DBDDAD9895A7938AF1DED0F5E0CDBCA890B2A08CFFF3E9DBCAC3FBE9E5FFFAF6
FFF3F1F0DEDCFFFAF8FFF9F8FFF9F8FFF7F69A8280917975DEC7C1DBC4BE5B423DFFFCFA
F4FFFF607B84516F71D2E8E610120FF2E7E1FFFAEFFFF5EAFFF3EAEAB5AFA76D6BE9B9B5
FFF6EFFFFDF4F5F5EDFFFFF8F6F3ECFFFEF8F0E8E5FFF5F4FFFBFDFFFAFDFFF5F8FFF2F3
D6C6C6AB9C99E9DAD3A19388D4C8B8FFFBE7FFFEE8FFFFEAFFFCECFFFFEAF5F3CCD8D8A6
D6D4A19794670702007F7868FFFDF6FFFDF6FFFDF1FFFEEDFFF9EAF7EDE3FFF4F6FFFAFA
FFEDE3FFF0E1FFFAEFFFFAF3FFFAF4FFF3ECF7E6DFD5C4BCBBAB9EBFB1A4FFF4EBFFFBF8
FFF9FFFFF8FFFFF8FFFFF7FFFFF6FFFFF6FBFFECF1FFEDF2FFE5EAFFF6FBFFF6FBFFF4FA
FFE8EEFFE3EAFFEEF5FFF3FAFFE9F0FFEEF5FFF0F7FFDDE3FFE1E6FFC7CCFFE7EFD296A0
FFDBE6FFCED8FFCCD4F5C3C4FFD4D0AC7A73EEB9B3FFC9C5FFDBDEFFD4DCFFCCD9EFAABD
FFCFE7FFCCE1FFD4E1C17F81F7B4AEFCB9B0FFD9CBBA786CD6968DFFCCC7FFDEDFC98C91
DCA1A5EFB7BAFFD3D6E3ACAFC79093CF9B9DE4B3B6CCA2A3A78383F9DDDC8A777381746E
857E78CFCCC5C7C6C18A8B8580827DF2F7F1FCFFFDF3F5F23B3C37030000312725130303
220E0D816C6BDBC8C4F4E2DEF2E7E3F4EDE7D9D5D2BCBBB7F1EDEEEFEBECD8CFD4E7DCE2
D0C5C9EFE4E8ECE0E4FAEFF3EADEE2968B8FFFF4F8F2E7EB
A8A16B9089529E985E9E985CB4AC6ED7CF90B4AA6CA2985B7F723DBFAE82E2CEAD5D4730
593E33B29695F3D6DBD9C0C3D4C3BBB4A69977695E887A6FC6B5ADFCEBE3EFDCD6EEDBD5
FCE8E1FFF4EBFBE5DAEED8CBF6E1D0F0D9C7EAD4BDFCE7D4C3AFA4A08C85CAB7B1EDDBD9
F1E1E1E5D7D7FCEEEEFEEFF2AF9FA0BAA7A9E3CDCFC0A8A66F53508467639C7B76987A7A
D7C3CE7C74810209131317202C1C27D2B7C0F4D8D5FED9D0E3AFA2FFC0B3C16F64833930
FFE5DDFFE7E2FFE0E5FFF6FCFFFCFAF7F4EDFFFEFAFDF8F5FFFCFDE0D6D7FFFBFDFFFAFD
FFFAFBFFF9FAFFFAF8AF9D99AE9D95F8E7DDFFFCEFFFFCEFFFFDF4E1DACAD2CEABDCDAAA
CCCB95A3A1700603008B876EFFFDEAFDF8E5FFFFE8FFFFE4EEEDD1B9B7A2DBD7CECAC1BA
C7B7A8DDCCBAB7A696AE9E8FAE9E91AD9F92AEA191F0E5D3FFFEECFFF4E2FFFDF1F9EEEA
FFF7FDFFF8FFFFF4FFFFF9FFF5E8F1FFFBFDFFFBFDFFFBFDFBECEFFFFAFDFFF6F9FFF3F6
FFF9FDFFF9FDFFF6FBFFF1F6FFF2F7FFF8FDFFF7FDFFF8FAFFECE5FFFBF1FFFCF3ADA09A
FFFDF8FFFEF6FFFDF1FFFFF1FEFDE8FFFFE6D1CBB1FFFEE8FFF6E3FFF9EBFFF8F1FFF7F6
FFF7FDFFEDF5FFEBEEFFF8F4FFF9F1FBE5DACFB9AEE3CCC4FFF5F0FFF9F8FFF9FAFFF0F0
FFFBF8FFF5EFFFFEF3FFFBF1FFF4F1FFF1F3FFEDEFFFEDF1FFF4F9FFF7FBB9A6A8CDC2C0
9088859E9B96BDBCB763645F858784FEFFFFFAFEFFFCFFFFFEFFFDF2F1EDFFFCFAFFFBFA
FEEAE9F5E0DFFCE7E4FFF6F2EDE2DEFFFEF8DCD8D5FAF9F5F7F5F6FFFEFFFFFAFEFFFCFF
FFFCFFEEE5E8FFFBFFFFFCFFFFFBFFFFFCFFFFF4F8FFFCFF
808145969859E3E5A4CFD28FD8D995EFF0ACDCDB9AB9B878CAC58ED0C89AFFFFDDB4A590
BEABA4F5E1E3FFF4FDFFF9FFFFFCF4FFF8E7CDC4B3B3AA99B6AB99F4E9D7FFFBEAFFFDEC
FFFCECFFF1E1FFF5E7FFFBEDFFFAEFFFFAEFFFFAEFFFF0E7FFEFE6E7D5CBF4E3DCF5E6E1
FFFCFAFFFDFBFFFCFDFCF6F8FEF4F5FFFBFDFFFAFBF3DEDD7F6360AD8E8BB6938F613F3D
C5ACAFCBBEC57A7A8400000CB2B1C1ECE9F4D7D1D1ECDED1DFC1A9F9CCADCD90738C5036
CCA18EC5A49BE7C8CEFEE9F2E7DFDDE3E4DCE5E4DFE3E0DBE1DDDAE5DFDFCFC6C7FFF5F6
DFD3D5FBECEFBFB1B1DDCDCDA08E8CC0AEAAE4D3CCF9EAE3C6BBB7BFB7AAB9B693D2D2A0
ADAE754E511A595A2E676944ACAD8EAEB192D4D9B1F0F5CCE5ECC3A3A987DEE1CCBEBCAF
ADA397E1D3CAB2A59DB3A69EAC9F96FFFAEEFBF2E1FFFFEAFFFFE5FFFFE5FFFFE8F9F6E3
FFFFF6FFFEFDFFFDFFFFFDFFFFFEFFF8F8F6F2F1EFFFFFFDFFFFFDFFFEFDF7F3F2FFFDFD
F9F0F1FFFCFDFFFCFDFFFCFDFFFBFDFFFBFDFFF5F7FFF7F5FFFFF3CBCCBCD3D7C9EDF5E8
F4FEF3EFFDEEF2FFF2F2FFF1F2FFECF3FFE4E4F4D0DCE7C5CACFB1FEFEE6FFFFEDFEF8EA
FDFAF1FFFFF6FFFFF6FFFDF1FCFAEEE0DDD4C6C3BEFFFEFFFFFEFFFFFEFFFBFAFFFBFFFE
FBFFFAF9FFF3F1FFE6FFFFECFFFAEFFFEEEBFFF6F8FFF6FBFFEFF7FFF9FFFFFBFFFFFAFD
FFFEFBFCFBF6FFFFFAE0E1DCFFFFFFF8F9FDFEFEFFFAFBFFF3F5F4FFFFFBFFFDFAFFFBFA
FFEFEEF1DCDBFBE6E3FFFAF6FFFBF8FBF4EEFFFEFBFFFEFAFFFEFFF8F6F7FFFDFFFFF9FD
FFF9FBFFFEFFFFFAFCFFFEFFF8F2F4FFFEFFFFFDFFFDF9FA
B5CF85C1DB91CEE69AD1E99DD3EA9CD3E99ED2E69FCEE19FD5E4ABCAD7A9FCFFE4FBFFEE
FEFFFAFEFFFFFEFEFFF6F5FDFFFEFBFBF7EEFFFCF0FFFFEFECE7D3C8C4ABCDC7ADEDE7CD
F7EFD8FFFEE9FFFDEFFFFCF4FFF5F6FFF8FFFFF8FFFFF6FEFFF5F0FFF8EDFFFDF3CAC3B9
CCC9C2FFFFFBF9F9F7FDFFFEFFFEFFF3EFEEFFFBFAFFF8F8FFF1EE8B6F6CBF9D9B503730
040100F6FFF3F4FFFF56737B44767FD1FFFFD8FFFFE9FFF4ECFFD6E3EEB4CBD49369682F
AEA27CFFFDECFFFEFDF9FAFFFEFFFBF6F9F0FFFFFAFEFFF9FEFFFAF2F1EFFFFEFDFEF8FA
F8F2F4FFFCFFFFF9FAFFFBFDD4C6C6FFFAF9FFF8F8FFF6F3FCF5EFFFFFEFE1E3BCDBE0AA
E7F0AFC9D293EEF5C1EAF2C3EBF4C9E9F4C9E9F6C1E7F6BDE4F5BEE3F3C4E3F1CDE7EFDA
FFFBFCFFFAFFFFFBFFFDF6FEFFF9FBFFFFFAFFFFF0F6F9DEEBEFCCEAF1C7EAF1C5E9F2C5
EAF2CBEAF1CFEBF1D7EAF2DDE5EAE3F4FAF6FCFFFDFCFFFDFCFFFDFEFFFDFEFFFDFAFAF8
FDFCFAFDF9F8FFFEFDFFFEFDF8F2F2FFFDFDFFFDFDE6DEDBE4DBD2EDE7D9FFFFF3FFFFF6
FEFFF8F9FFF6F2FEF0F7FFF1DCECD1DFEDCCF4FEDBECF2CEBFBE9FAFAA8DD2CAB3F1E9D2
F5F4D8DDDDC1E1DFC8BFBCA9DBD5C9D0C8C5FDF4F9FFFAFFFEF5FFFFFBFFFFFBFFFEFEFE
FCFFF2EAF3D8E7F3CDE7EFCAFBF4E2FFFAF2FFFCFAFFFAFEFFF8FFFFFCFFFFFDFFFFFDFF
FCFCFCFFFFFBFFFFFAFEFFFAFDFDFFFFFDFFFEFAFFFFFDFFFEFFFFF6F7F2FDF8F4FFFCFA
FFFAF8CFBAB9C2ADAAFFFAF6FFFBF8FFFDF8FFFEFBFFFFFBFFFFFFFFFEFFFFFDFFFFFDFF
FFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFF
C1E696C7ED9ACBEE9CC7EA98C7E899C9E99DCCEAA2CBE8A6CFE8B1C8DFB1F5FFEAF2FFF0
F6FFFCF7FFFFF7FFFFF9FFFFFCFFFDFFFFF4FFFFF1FEFFEBFDFFE2FEFFDFF1F6CEE2E4BC
686A43AAAB8BF2F0D9FFFFF3FFFDFBFFF8FFFFF6FFFFFAFFFFFDF4FFFCEAFDFAE9FFFFF1
D3D7C9C6CEC1F9FFFAF7FFF9F6FDF6FEFFFBFFFCF7FFFDF8FFEDE9FFF9F4AF93908A766D
080600E4ECD7F8FFFFD1EEF6326E79B8FFFFD2FFFFD6FFF5ACDAA9C8F1ADD3FAAB475E18
9D9C6EFFFEE8E7E6E4FCFFFFF6F8F3F8FBF2FEFFFAFEFFFAFEFFFBFEFFFBFFFFFDFEFEFE
FFFEFFFFFEFFF7F1F3FCF6F8C9C0C3FCF2F3FFFBFDFFFCFBFFFFF8FCFEE9E5ECC2E0E9B0
CEDB96DAE7A2CEDCA1D2E0ABD2E0AFD0E1ADD0E4A5D0E7A3D0E9A7D1E9ADD2E8B7D6E5C8
FBFFFFFFFDFFFFFDFFFFFDFFFFFEFFFEFFFBF7FBEAEDF6D9CDD8AED1DDABD3E2A9D3E2A9
D1E2ABD0E1ADCDDDB0CAD5B3E3E9DDF2F7F3FCFFFDFAFFFBFCFEFBFEFFFDFFFFFDFDFDFB
FFFFFDFFFBFAFFFEFDFFFEFDFEF8F8FFFDFDF7F1F1C2BAB8CDC3BAFFFDF3FFFBF3FEFBF4
F8F9F3FEFFFAF3FBEEF9FFF1E4F1D7D6E1C1CAD2ADCACEA9FEFEDAFFFFE1D6CFB2666141
55562A6A6E3CB2B389E3E3C1FFFFEAFBF4EAFFF8F9FFF6FFFFF9FFFFFBFFFAF5FCFFFFFA
F7FBE4D9DFB9D3DDA9D4DEACEFF5D9F9FBEEFEFFFBFCFDFFFBFBFFFEFEFFFEFEFFFEFFFF
F7F9F8FEFFFAFFFFFAFFFFFBFFFEFFFFFDFFFFFAFFFFFBFFFEFFFFFEFFFBFFFDF8FFF9F7
FCEAE8C2ADACAC9794F7E4E0FFFBF8FFFDF8FFFEFBFFFFFBFFFFFFFFFFFFFFFEFFFFFFFF
FEFFFFFBFFFFFCFFFFFBFFFFFCFFFFFBFFFFFCFFFFFBFFFF
C9EC9ACCEF9DCBEE9CC6E999C5E599C9E9A0CCE9A7CCE8ADCCE4B4CEE4BDF5FFECF4FFF3
F5FFF9F2FEFEF8FFFFF8FFFFF1F9ECEDF7DFDAE5C5C8D4AED2DFB1E6F3BDDDEBB0C4CF93
C8D399BCC692ADB68BAFB697CBCEBDEFF0EAFFFFFFFFFFFDFFFFEFC3C6ABD6DABFFCFFEA
EEFAE2D2E0C9ECFBE6F7FFF3ECF9E8FBFFF4F5F9EBFFFFF4FFFDF4FEEFE87F6C66B29B93
C9B09C5A4436DFD3D5F9FFFF56768B3C6B7D0F4246001506C4F1C8C0E6ABC5E49EC9D897
91885DC4AE99F6DCDDFFF6FDFFFEFAFFFFF8FCFDF7F4F5EFF7F9F4FEFFFBF8FAF7F7F9F6
FEFFFFFEFFFFFFFEFFFFFEFFD8D3D7D7D3D4C9C3C5B9B5B4D6D7CFC5CAB3CBD7A9D4E2A5
D6E7A1E0F1ABD3E5A9C4D7A0D1E3B1CFE4ACCCE5A3CAE69CC9E79DC9E7A1C8E4A9C8DFB5
F5FFF1F7FDFBF9FFFDFBFFFDF9FFF9EAF5E7DEEAD4D7E6C5D2E3B7D4E6B2D1E4ACCCE0A5
D0E5ACDFF3BEE9FDCCEDFBD8EFEFE5FDF7F9FFFDFFFFFBFDFFFAFDFFFCFFFFFCFFFFFBFE
FFFBFFFFF7FBFFFBFFFFFBFFFFFBFFFFFBFFFFF6FAD3C7C7C9BEB8EDE3DAFFFEF8FFFEFA
F8F7F5F7F8F3FBFEF5FCFFF3C8D0B8D4DDBEE4ECC7DBE2B9FAFFD7F8FAD3EEEECAD2D5A8
D9E4A2CDDB90D7E29EEBF3BAF2F5CAE7E8C9F7F4E5FFFEF8FFFDFFFFFEFDFEFBF4FFFFED
FFFFDFDCE5B0D7E49FD7E7A8E9F9D4EEFFEAF7FFFAF7FFFFF6FFFFF8FFFFF9FFFFFAFFFF
FAFFFAFCFFF6FAFDF2F5F6EEFFFFFDFFFDFFFFFAFFFEFAFFF4F8F9FAFFF9FFFFFAFFFCFA
FFFAF8F5E0DFEAD2D0FFFAF6FFFBF8FFFDF8FFFEFBFFFFFBFFFFFFFFFFFFFFFFFFFEFFFF
FCFFFFF9FFFFFBFFFFF9FFFFFBFFFFF9FFFFFBFFFFF9FFFF
C7E696CCEB9DCDECA0CCE89ECAE5A0CCE5A4CAE2A8C8DCA9D4E7BAE0F0CCF8FFEAF9FFEF
F9FFF4F5FDF2EBF2EBE4ECE1F1FEE4E2F0CDD4E3BAD0E0AFCFE1A7CFE2A2D2E69FD8ECA4
D6EAA3C9DC9AB1C3879BAB7A96A27C9BA6889EA7929CA68EE5EFCDDCE4BFDEE8C3E4F3CC
F0FFDBE4F6D0BFD3AEB6CAA7EBFCDCD4E2C8F7FFE9FFFFEFF5F3E4FFFEF3FAF0E7665249
A1806FA18174736161E8E5F0F7FFFF314A5E3C636A154339001100001E00C1DCA5DFECB7
AFAC838B7A60A7867FD1B3B1F5E7E4FFFFF8FFFFFAF8F7F2FFFFFBFFFFFBFEFFFDFCFFFD
F9FDFCF5F7F6FEFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFEFFF8F3FBE3CAD7ABB2C186
DDF1ACC3D694E5F8C0D7E9B7D4E8B7D1E8B2CEE8A7CCEAA0CCEB9FCBEBA2C9E7A7C9E4B1
F5FFE4F5FFE8F7FFECF7FFEDF5FFECE2F2D8D6E6C9D4E5C1CEE1B4CFE3B2CBDFAAC6DAA5
CEE2B1E1F7C9F3FFDDF9FFEAFCFDF5FFFEFFFFFEFFFFFEFFFFFDFEFFFEFFFFFEFFFFFDFE
FEF8FAFFFAFCFFFDFFFFFDFFFEF8FAFFFDFFFFFDFFFFF7F8FFFCF6D6CFC7D9D1CECFCAC7
FFFEFFF8F7F5FFFFFAEFF3E4E3E8D1CCD5B6CED6B1DAE2B9FEFFDCE9F2C7DDE5BCDEEAB8
D1E29CCBE093C9DA93DDEBADD3DDA9D5DBB5D9DDC4F3F4E4FFFFF8FDFCF7F9FBEEFFFFED
F8FEDCDCE6B4DBE7A9CFE1A5E5FACFEAFFE4F2FFF6F4FFFDF4FFFFF5FFFFF7FFFFF7FFFD
FBFFF6FAFFEFEFF4E0E3E6D5FCFCF4FFFAFEFFFCFFFFFCFFFBFFFFFCFFFBFFFFFAFFF8F6
FFEEECD2BDBCC0A8A6FFECE9FFFBF8FFFDF8FFFEFBFFFFFBFEFFFFFEFFFFFFFFFFFEFFFF
FCFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFF
D0E49CD3E7A0D3E7A2D2E2A3D2E1A6D6E3ADD5E1B1D2DBB0F0F8D1FBFFDFFEFFE3FFFFE6
FFFFE8F7F7DDE4E4CCD5DABCCFDBB5C6D7AACDDFADDAEDB5D5E9ACC5DA97C6DC94D5EBA0
CFE59AD1E79CC5DD93A9C07A8EA463869C5C91A66B9FB27A6E7F4BD3E1AEC8D9A5C4D7A0
C6DBA3CADFA7D9F0BA8BA26ED1E5B4D9EABEE0ECC8FCFFE6F9FDE4FFFFEDFAF7E88F8375
583A2F9E8277948B84747273F5EFFDAFB2C16481850E3B3413463300110087A082D7E7C3
DEEEC7A4A8836D583D7A5F4ECDBCB4E7DCDAFFFCFAEFE7E4FFFEFAFFFFFAFDFEF9FCFEF9
FEFFFDFEFFFDFAFCFBF6F8F7F7F7F9F3F3F5FDFCFFFFFFFFFEFFFAFBFFECCAD7ACA7B67F
DDF0B0CEE0A4B3C593D4E5BBC7D9B1C6DCADC9E1A5C9E49FCAE69CCAE8A0CCE9A9CEEAAD
E6FFBEE0F8BAE1F6BDE3FAC6E0F3C6D4E6BED0E1BDD4E6C0E1F3CBE4F6CCE8F9CFE9F9D2
ECFCD8EFFFE2F1FFE6F0FDEBF8FFFBF8FFFFF8FFFFF8FFFFF8FFFFF8FFFFF8FFFFF7FFFE
F5FFFCF8FFFFF7FFFFF7FFFFECF8F4F1FDF9F7FFFFF9FFFDFFFFFAFFFFF8D8D4D19A9697
FFFBFFF0ECEDFFFEFBFFFFF4E4E7D2EAF1D2E2ECC7CFDCB1E7F7CADFF0C3D9ECBED3E9B8
D5EEB5D6EFB5C5DDA3CFE3AEC3D4A7DFEEC7ECF5D8FCFFF1FEFFF8FEFFFBFEFFFBFEFFF8
F4F8E9E6EED6E7F1CFCAD9B2DAEFC4E1F7D1ECFFE7F5FFF8F7FFFFF8FFFFF7FFFEF9FFFA
FBFFF1ECF5DAE3EACBD8DCC3FBFEEDFBFAF5FFFDFFFEFEFFF9FFFDF9FFF9FFFFFAFFFCFA
FFF9F7D9C4C3CBB3B1FFF9F6FFFBF8FFFDF8FFFEFBFFFFFBFEFFFFFCFFFFFEFFFFFEFFFF
FEFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFF
CDE29DCEE3A0CEE0A2CEE0A4D7E5B0E4F2C1EDF8CDEEF9CFFAFFDBFEFFDFE8EEC8EEF5CC
ECF1C8E5EBBFD7DDAFD1D8ACE7F4C9E6F7CBE8F8CBE7F9C9E8FAC8E8FBC4E4F8BDDDF3B3
D4EAA9D1E8A2CEE89FD2EDA0D7F2A3D5F09FCAE594BFDA8DA0B572ABBD7FCEE3A2EAFFBC
CCE19CC9E09ADAF1ABA9C07C6D8142B2C58DD6E4B3D8E3B9E9F0CFFFFFEAFBFEE9FFFFEF
FFF6EC726056B1AAA0EFEAE4090000F0EEF1E8FCFDE6FFFF14433D8AB8AE719184000B00
8BA683DFF0C4DAD3A5F9E7C3A18D828D7B7B8E7E7E756766B7ADABF9F4F0FFFEFBFFFFFB
F8F8F6F7F9F6FEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFFFFF9FCF5FCFFEFEAF5CDC6D49F
B5C48BCCDDA70F1E00657551D5E4C5D8EAC4DAEEB9D5EEADCEE8A1CAE49DCCE6A7D0EAA9
CCE79AC9E495C8E29BCAE2A4CBE2AED0E3B6D7E9C1E0F0CBF8FFE3F8FFE3F6FFE0F8FFE2
F7FFE4F4FFE5F7FFEBF9FFF3F7FFF9F8FFFEF8FFFEF8FFFEF8FFFEF8FFFFF8FFFFF8FFFF
F8FFFFF7FFFFF7FFFFF4FFFEF5FFFFF5FFFFF3FFFDF4FFF9FCFFFAF3F2EDFFFFFDFFFDFF
D1CAD1C0BABEFFFDFDFFFDF4FFFFEFFCFFE4DDE9C3C7D8ABD2E6B5ECFFD2EEFFD9E9FFD5
BEDCAAC9E7B3C3E0A8D1EDB3CFE8B1EEFFCFEFFFD3F5FFDFF7FFE8F9FFEFFAFFF3FBFFF6
FAFFF4FBFFF4FBFFF1D5E2C6CDDEB2D5E8BBE5F4D5F4FFEFF9FFFAF8FFFCFAFFF9FBFFF3
EAF3D8DCE3C1DCE4BDD5DDB8FEFFECFBFFF1FEFFFFFBFFFFF9FFFDFAFFFAFFFEF9FFFCFA
FFF6F4D3BEBDC1A9A7FFF5F2FFFBF8FFFDF8FFFEFBFFFFFBFEFFFFFCFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CAEAA7CBEBA8CCEAACCEEBB1D9F4C1E7FFD1F1FFDCF2FFDDEAFFD2F4FFDBCBDFACD1E6AD
CFE3A4D1E6A3D0E69ED7EBAEF9FFE3F9FFECF8FFEAE9F5DDECF8E0F7FFECF3FFE5E3F2D1
CCDEB6CCDFB1CAE2A8C8E3A0C7E396C8E591CFED93D5F39BBAD2865A702890A55AC5DA8D
CCE192D8EE9CC3D987D6EB9CE9FEB38D9E5AC6D59AD8E4B2D5E0B6D4DBBAE8EED4FAFEED
F6F6EC938E885E5148322618D4D1C0080C00E4F0ECF0FFFFCCEEF857838C92C3C7000F05
5D7B61CDE0B2DAE6A4E9E8B0FFFBECF2D8DBC2A9AC998586A69696FFFCFAFFFDFAFFFEF9
FFFEFAFFFFFBFBFBF9FBFBF9FAFAFAFFFFFFFCFAFDFFFFFFFEFFF9F6FAE9ECF4CFCEDAAA
8D9A65D8E4B6000600747E65F5FEE9F8FFE7F8FFDBEBFFC4D9EEADCCE2A1CCE2A4D1E7A7
CEE89ED0EAA0D2E8A7D0E5ACD5E8BAE5F5CEF4FFE0F9FFE4F9FFE3E0EFC8D1DEB3D2DFB4
D3DEB4D1DCB4E1EBC6FCFFE8FFFDF7FFFAFDFFFAFDFFFBFEFFFDFFFFFDFFFFFDFFFFFEFF
FFFEFFFFFDFEFAF8F9FEFEFEFFFFFFFFFFFFFEFFFFFDFFFCF1F3EEFEFFFBF1F1F1FFFEFF
FFFDFFCBC4CBCAC4C6FFFEF8FEFFEDFEFFE8F2FED8F6FFDBC6E1AEC6E4AEC4E7B1D8FDC7
EAFFD9DDFFC8C8EDAAC3E79FBEDE92C9E89ACDE79DD3EAA4D6EAAFD0E0B1DAE9C2F5FFE4
F7FFE9F8FFF0F9FFF3D3E0C4CBD8AAD5E1AFE6F0CDF7FFE7FEFFF4FDFFF7FDFFF3FEFFED
E6EDCBD5DEB3DBE4B5D4DDB0FCFFE4F7FFE8FCFFF8F9FFFBF6FFF9F9FFFBFDFEF8FFFCF9
FFFAF8EED9D8DAC2C0FFF9F6FFFBF8FFFDF8FFFEFBFFFFFBFEFFFFFCFFFFFCFFFFFEFFFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
DBF9C5DCFAC6DCFAC6DCFAC6DFFDCBE2FFCEE0FCC9DAF6C3DDFAC4EEFFD0C4DDA3CCE6A9
CBE4A3D2E8A7D9F0ACE8FBC4F7FFE6FCFFF6FCFFF8FBFFFBFBFFFDF9FFFBF4FFF6E9F7E6
D1E1C7CCE0BBCAE2B0CBE8A8CDEBA1CBED97C8EB8FC8E98ED8F19EABC2728EA452A9BF6D
D4EA97DBF19ECFE590CFE592C7DA89D3E599B8C9858E9E60B3C18CD9E6BADBE7C1FBFFE8
F9FFF1FCFFF1A5A7917A7A629FA48E5E665767706DA7B4BCF0FFFF0E2F3E447A84C9FFFF
4D7163CCE8C2C6E49CEAFBB7FFFCDCFFF9F1FFF8F3FFE7E6BCA8A9FFFAFBFDF3F2FFFDFD
FDF9F8FFFFFDFEFFFDFCFFFDF8FCFBFEFFFFFCF7FDFFFBFFFFFFFBF9FCEBF1F7D5DFE8BD
8F986BCBD6AE0F1A00757F66F8FFE7F9FFE1F8FFD8F1FFCADAEEAFCCE1A0CCE1A0D2E9A3
C7E295CEE99CCFE6A2CAE0A2D1E3B1E6F7CAF8FFDCF9FFDDFBFFDAE1EFBED1DFACD8E6B1
D6E4B1CBD9A8D9E6B8F8FFDEFFFFF6FFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFF9FDFFF8FC
FFFAFFFFFCFFFFF7FAFFF9FBFFFDFFFFFCFBFBFAF8FFFFFDFFFFFAFEFFF7FFFFF8FFFEFA
F8F3F9BDB5C0FBF4FCFEFAF7FFFFEAFCFFDDF5FFD3F4FFD4C0DDA5CBEFB2C6EDACD3FCB8
E9FFD1D5F9B9C5E9A3CAECA2CCECA0CBE79ACCE69CD5ECA8D6EAAFC6D6A7D3E2BBFBFFE8
FBFFEFFAFFF2F8FFF3D4DEC6D3DCAFDBE5B1ECF4CDFDFFE9FEFFF1FCFFF2FBFFF0FCFFED
ECF6D4D7E2B8D9E6BACADAADF9FFE3EDFBE1F8FFF4F6FFF9F4FFFCF8FFFDFFFFFDFFF5F4
FFF9FBFFE6E9E5CBCEFFF7F7FFFAFAFFFCFAFFFFFBFEFFFBFEFFFDFEFFFDFFFFFDFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F4FFEEF5FFEDF5FFE8F2FFE0DFF7C7CDE6ADC7E4A4CCE9A7CEEBA8CDE7A6D2EAAED2E5AE
CADAADD8E4BCF3FDDBFCFFECFEFFF4FDFFFAFCFEFDFCFFFFFBFFFFF9FFFFF1FCF8E9F7EA
C6DAC1CEE7C0D2EFB9CBEBAAC5E79DC2E797C2E895C2E68FD2EE97CFE791CAE28E5B7222
889F51DCF3A5CBE294D2E99BD1E697C9DE8FD4E99C93A75F8A9E59D7E9ABC5D69FD5E5B4
D3E2B7CBE0B5C3E3B2CBE9C34557476A7676717A8300000CFEFEFFF2FFFF7DA8B1538A91
C3F0F5C0EAD6BEEAABC6EAA0D7E6AFEFEBC6FFF4DFFFF7EFB29A9AFFEEF2FFFCFFFFFAFF
FFFAFCFFFEFDFCFFFDF5FFFAF5FFFFF9FFFFFFF8FFFFF9FFFFFDFBF7F6E4F1F5D4D9E0B7
919B76DBE6C400070072825DD8ECB7C3DC9BD2EBA9D6EFABBED796E0F7B3D0E89ACDE692
CAE691D3EF9BC8E092CEE59DDAEFAED4E8A9D1E3A7CDDFA1CCDF9FDAEDABC8DD9AD7ECA9
D8EEB0C9E1A7E4FBC5EFFFDBFCFFF4FFFEFCFFFDFEFFFEFFFFFDFFFFFBFFFFFAFFFFFAFF
FFF7FFFFFCFFFFFDFFFFFEFFFFFFFDFEFFFAF9FBF6FFFFFAFFFEFAFFFEF2FFFFE8B2AF9C
ACA7ADFFFAFFFFFCFFFAFBFDCFDCB0CDE39BCBE699CAE89EC9E8ACC6E9A7C3EB93C3EA8F
CAE99DDBF4B2F5FFCDEEFFC6C0D59DD9EBBBD5E4BBF9FFE6FBFFECF1FAE7FBFFF4FAFFF6
FCFFF8F6FBF4FCFFFAF8FFEDF0FBD3C6D2A4FCFFE1E9F2D7FBFFF1FBFFF4F1FCEEF8FFF3
E2F1DAC7D7BACDE0C0D4EAC6F3FFE9F2FFEDF2FFF1F1FFF8F0FFFFEEFEFDFAFBFFFFFAFF
FFECF8FFE2ED9A7982FFF3FBFFFAFBFFFEFBFBFDF8F5FAF3FEFFFAFFFFFAFFF7F5FEF4F2
FFFEFDF8F6F7FDFBFCFFFEFFFFFEFFFFFEFFF8F6F7FFFEFF
F7FFF9F9FFF8F8FFF1F2FFE3E1F3C9D0E7B1CDE7A8D3EEABC9E4A1CFE7A9E1F6BEEAF9CE
E6F1D1ECF4DDFCFFF2FFFFFAFFFFFFFEFEFFFDFCFFFEFFFFFCFFFFFBFFFFF5FEF9EDFBEE
EBFDE7E0F5D6D4EEC1D0EDB5D0F0ADCEF3A6CDF3A0CFF39CD2EC95CEE692DBF0A18AA055
849853C5DA95E0F5B0C4DA92DEF4A9D7EEA0D0E799D5EBA091A75FC1D693F1FFC8C4D7A0
CDE1B0D2EEBD91BD82739D6B2538256B7574A4B1B93C434BB1ABABF8FCFBA3C6C81A4951
5C8694D4FEFAC5F9C9BBE9A8C3DFA2EBF5C3FFFBDAFFFBE78C7470E6D2D4FFFAFFFDF2F8
FFFDFFF3F2F0FBFFFDF7FFFDEBF7F5FAFFFFFFFAFFFCEFF9FFFDF7FFFFECF5F7D2959C72
D1DBB6E8F3D1000800677A4DC2DB9AD3EDA3DCF6ACCAE49DD0E6A8CCE2A1C5DC8AD5ED95
D5EE9AC6E190D3EB9FD0E69DB2C784BDD08EC2D691E1F5AEDEEFA8C4D98ED3E99ED3EAA2
BED795C1D99DD4EDB6F3FFDFFBFFF4FDFFFCFCFCFAFDFCFAFFFCFDFFFDFFFFFCFFFFFCFF
FFFCFFFFFCFFFDF7F9F7F3F2FFFEFAFFFFFAFEFFFAFFFFFAFBF3F0A49C91B1AD90F0EED7
FFFDFFFFFCFFEAE8FDFBFFFFD6E8B8D4EEA5D2EEA1CAEA9FC2E2A3BFE39DC4EC8CCCF28D
D0ED9BE3FAB4F7FFCCE6F9C1D0E0B3D2E0BDD0DAC2F3FAEAF5FBF1FEFFFBFEFFFDF4F4F2
FFFFFDFFFFFBF5F4F0FFFFF3E5EBC9C9D1A8E4EBCAFCFFECFCFFF3F5FDF0F9FFF8E6F2E4
F7FFF3F5FFEDE9FCE0D1E4C6C2D7B8C4DCBCE7FEE2F1FFF3E4FBF1F4FFFFFFFFFFF6E5ED
FFF4FFFDD4E29E7883FFF0F8FFF8FAF7F2EFFEFFFAFCFFF8FEFEF6FFFCF6FFFAF6FFFBF8
FBF5F5FFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFCFCFCFFFFFF
F9FFFAF9FFF8F8FFF3F4FFE9E4F5D1D1E7B9CCE2B1CEE5AFCFE6B2D7EDBCEFFFD7F9FFE6
F9FFEDFAFFF4FEFFFBFFFEFFFFFCFFFFFCFFFEFCFFFFFFFBFFFFF4FEFFF3FBFFF2F4FFEF
EEFAECF7FFF4F5FFEFE0F6D0C9E2ABC7E59DC7E88FC1E083D2E997C2D68EDDEEAA95A868
ADBC83E1F3B9C5D79DE2F4B8C2D595C9DC9ACCE19EDDF2B1ABBF8244571FC4D6A4BBCDA3
94AC8C0927031A3F097697606B7656000500C2D6CDE3F4EC2F3126FCFFF6E1FFF7DCFFFF
5F7B874E6D7298C5AED8FFDCF0FFDCEFFFD1D3DFB7D9DCBD6F6252C4ADA7FFF7F6FFF6F7
FEFBF6FCFFFBF8FFFCFBFFFFFFFFFFFFFEFFFFFEFFFFFDFEFDFBEEFFFFE4F3F6C9A5AD7C
D8E1B6C3CFA91422005F7043D2E7A6D1E99FBDD48CC0D594DDEEB77C8E5253651B708536
859B52889F5BBBD08FC6DA9BA4B67A85945954642690A05F96A5606E7F38C1D28BE5F9B4
D9EDAEDCEFB7CDE1AEF7FFE2FCFFF3FEFFFBFFFFFBFFFFFBFFFEFDFFFDFDFFFCFDFFFBFC
FFFAFBFFFCFDFFFCF9FFFFFAFFFFFAFAFBF3D1D4CBBABBB5DFD6D7FAF0EEFFFFEFFFFFEF
FDF9F6FFFEFFFEFEFFF3FAF3F6FFE3E2F6C5CCE3ADC3DFA5C9E6ACCBEFA9C8EF94C3E888
D0F09DC9E49DC1DA99BED39ADCEDC0EBF9D5F7FFE8FCFFF3FFFFF8EEEDE9FFFEFDFFFDFD
FFFCFDFFF8F7F9EFEEE0D7CED0CFB3EBECCCF0F0D6FDFEECFDFDF1FFFFF8FFFFF8FEFFF6
F7FEECF7FFE7F3FEE0EBF6D4D0DEBAD7E5C1E2F0CFE7F5DBF7FFF4F8FFF7FAF3EDFFF9F8
FFE3E7F9D0D6C59EA3FFF5F8FFF9F8F9F0EBFAFAF2FFFFF8FFFCF6EADCD9BBA3A3B39D9F
CBC2C3FFFFFFFDFDFDFFFFFFF8F8F8FFFFFFFFFFFFFEFEFE
F6FFF3F8FFF3F8FFF1F8FFEDECFDDDDDF1CCD7ECC5D9EEC5E3F8D1E8F9D7F6FFEAF9FFF1
F8FFF5F9FEFAFEFFFFFDFBFFFFFCFFFFFBFFFFFCFFFFFEF5FFFFEDFFFFEAFEFFEDFCFFF3
FCFFF8FBFFFAF1FCEEE5F3DAE1F2C5E0F7B3DBF59CD2EB90DAEBA4D9E7AAACB981B0BC8A
DCE8BACCD9ABC2CFA1CBDBAADAEBB7CFE0A9D2E3ACC9DCA5CEE0AE99AA7DCEDEB7475C3B
314D36517253486932D3EBAFD9DFB11E23035D7460C1D9CB020A00D1DAC9F2FFFAF0FFFF
ABB9C46276813D6660B2DFCAE6FFE5E1FED2B4D1A5D0E2BA908B6EB69F8DFFE7DCFFF8F1
F0ECE3FCFFFAFCFFFDF9F9F9FFF7FAFFFAFCF1F5F4FBFFF8FFFFEAF9FBD4ECF3BDACB57C
B5BF8DCAD7AB000800617142C8DD9ABED48B8FA45FA0B274C9D7A484925D7F8E49AFC079
D3E7A8D0E5ACD6E9B2CADBA7DAE8B5ACB98488955DD8E3A7CBD79797A45FB9C885C6D496
C6D39BD1DFACCEDBAFFBFFE6FCFFF1FFFFFAFFFFFAFFFFFAFDF8F4FEF9F5FFFDFAFFFDFA
F8F0EDFFFDFAFFFEFAFFFBF5EFECE5DBDBD3D7D9CEE6E5E0FFFCFFFFF9FEF7F2ECFFFFF4
FFFFF8ECEDE7FEFFFBFBFFFAF9FFF3EEFEE4D5E8C8CCE2BBCDE9B6D0F0ADCAED99C1E58B
C0E190C3E197D1EAA9D8EDB4D8E9BCE2F0CCF7FFE7FEFFF1FCFCF2FFFEFAFBF3F1FDF1F1
FAECECFFFAFAFFFAFAB0A19A69614C9B957DF1EAD8FFFCF0FFFEF6FFFDFAF2EDE7FFFFF6
FFFFEFFFFFEAFCFDDEF6FAD7D5D9B4DEE4BED7DBB8D2D7B7F3FBE4FFFFF1F9EDE1FFF8F3
FFF3F1FFE3E3D8B1B2FFEEECFFF0EAFFFDF4F7F0E6FFFEF6DCCFC99F8A895E404273595C
8D8485FFFFFFFCFCFCFFFFFFF8F8F8FFFFFFFFFFFFFAFAFA
F9FFF1F9FFEFF8FFEDF8FFECF7FFEAF7FFEAF7FFEAF7FFECF4FFEAF1FFEBF8FFF6F9FFFA
F5FBF9F8FCFFFEFEFFFDFBFFFFFBFFFFFBFFFFFCFEFFFFF3FFFFECFFFFE8FFFFECFFFFF1
FFFFFAF7F9F4FDFFF7FCFFEFFCFFDDDBEBACCBDE8CD9EB99C9D597A9B381D1DAADD6DEB7
D3DAB8E9F3D1D0DAB8D7E3BDBDC9A1EAF9CED2E1B6CFDEB3CDDDB6DAEAC64D5D401D341A
3D5F47C8EBCABFDD9FD1E59EDCDBA35A5C345E785F476656ACB8AC666E61E7F3E5F8FFFB
FEFEFFAEB8C252737808362C578267BDE7BFCAF5C7CDEDBC8D93677E6E4CA7896FB89B89
FFFDEFFEFBF4EBEAE8FFFEFFFFFCFDFFFCF9F7FFF6F5FFEDD8E0BBD4DDA8DFEAA8E9F6B1
68763B5A6835000C0047582494A765CBDF97C3D694D1E0A7D2DFB1D2DEAED9E4A8D8E6A8
C7D8A4D7E8BCF2FFD6EEFDD2FCFFDDE8F1C6CBD3A2AEB7805C6429BCC488F0F8BDD6DFA8
D1D9A8F2FAD1FEFFE3FCFFEAFCFEF1FDFDF5FEFEF6FFFFF8FFFEF8FFFEF8FFFEF8F3ECE6
BDB6B0A9A29C918C86A39E98D7D4CDFAFAF2FFFFF7FCFBF9FFF8FFFFFBFFF1EAF1FDF9F6
FFFFF4FFFFF1FEFFF3ECF4E7F7FFFBF8FFFFF7FFFAE4F7E1CEE5BBC1DDA2C8E69CD1F2A1
D2F1A3C4E298CEE7A6D0E5ACC1D2A5E6F2CEFEFFEAFFFFF0F9F5ECF6ECEAFFFBFBFFFAFB
FFF9FBFFF8FA371F1F816C67FFF7E8998C7CB0A297D3C6C0FFF6F5FFFBFBFFFBFAFCEFE9
FFF6E8FFFFEAFFFFE3FFFFDFF1EBC7F6F2CDF1EBC7F1ECCCFFFFE8F7F0DDFFF8E8E9CDC2
FFE9E1E8C1BADBB6B0A48580B7A39AAEA097766C628D837AB29F9BD8BCBBFFDEE1E5C5C8
796F70FAFAFAFDFDFDFFFFFFF5F5F5FFFFFFFFFFFFFDFDFD
E0EDCFD6E4C3CAD9BAC7D6B7C9D9BCD2E2C7E1F1D7EEFDE8F6FFF2F3FFF1F9FFFBFBFFFD
FBFFFFFCFFFFFEFFFFFCFBFFFFFDFFFFFDFFFFFFFAFFFFF4FFFFEFFFFFEDFFFFEFFFFFF3
F7F7EFEBEBE3D9DBCDCED2B9D1D8AFDAE5ABDFEBA3DCE7A29AA36EE8EFC6F1F7D3FFFFE4
F5F9DEEEF4DAFCFFEAF8FFE4FBFFE4FBFFE3EDFBD7E9F7D4D2E1C2CBD9BF000B00627861
C6E9C9ABD1A2DCFBB5D5E79BDDDBA058592FB5CFB691ADA1F2FDF9000100798078FCFFFA
F5EFF3E1E4EB4E6A6D1F4C454B816AB1E9C4BDEEBFB8DDA9D4E1ABF0EAB8C8B28B6D5436
624F40FFFBF4FFFCFDEDE4E7FBF6F3FFFFF6F1FEEAF7FFE6F4FFD1D8E6A8DAEA9FCADC90
D3E3A2CADBA4000A00647740D1E6A3E7FBB4D3E6A6D3E4AEC2CFA4DAE7BCDAE7B1CCDBA2
D5E5B8D5E5BEF9FFE3F5FFDDF3FAD8E6ECC6E9EEC5898C5DDBDFACE7EAB5CFD19FE0E1B5
E8EAC5DEDEC2FAFCE7FFFFF2F5F5EDFFFFFAFFFFFAC8C5BE8F8A848D8980C6BFB7FCF5ED
FDF6EEFFFEF6FFFFF6FFFEF8FFFFFAFFFEF9FDFCF7FFFEFFFFFBFFFFFBFFFFFCFFFFFFFD
FFFFF4EBEFDEFCFFF3FCFFF8F7FCFFF9FFFFF7FFFFF1FFF4DCEFCFCCE4B2CBE5A6D1ECA5
CFE9A0CBE29CE2F6B7C4D59ED2DFB3F8FFDFFEFFE9FFFFF1FFFEF6FFFAF6FFF5F5FFF8F8
FFF7F9A38B8B684E4DDCC4C0FFF0E6D7C6BC63524B635151FFF1F5FFF5F9FFF9FBFFFAF8
FFFBF1FFF6E6FFF8DEFFFEE1FFF8DBFFFDE0FFFDE0FFFBE1FFFEE8D8CBBA69534562463A
FFF6EDFCD7CF86655E7459505B493F8C7E73F0E3DAFFFCF3FFF9F4FFEDEBFFF3F4745253
A29698FCFCFCFFFFFFFFFFFFF3F3F3FEFEFEFFFFFFFFFFFF
E2F3C6D8E9BCCEDFB3CEDEB7D3E3BFDCEBCCE9F7DDF4FFEBF8FFF4F4FEF3F9FFFAFBFFFB
FCFFFDFCFFFDFCFFFFFAFCF7FFFFF4FFFFF3FFFFF4FFFFF6FFFFF8FFFFF8FFFFF8FFFFF6
FFFFF3F3F6E1DBDFC4D2D8B4E4EBBFE3EBB8A1A970505721C2C89AFFFFDFFFFFE3FFFFE6
FFFFEAFEFFECECF4DCFCFFEAFBFFE6F5FFDEF9FFE4D7E5C494A386A4B2991D2C19A4BB9F
CDEFBCC5EDA7BEDF8ED8EDA0D7D69D8989636176636F8582FEFEFFDDD7E333373AEDEFEE
FFFCFFBCBABB2C3F3993BFB040846D87CDABC0F3C8C1E4AECEE2A3F9FFC3FFFFCADCCDA6
BD9E8C6D4E4B816A70FFFBFFFCFFFAF7FFF3F8FFEAC8D9AFD4E7AFC9DF97C5DD89D1EA96
DBF2AAC9DFA10A1E005D723ACFE6A2BFD48FC4D899E1F3BFF9FFE3F8FFE0D4E2AFC9DAA4
F6FFDBEFFFD8F9FFE3FBFFE4DCE3C2C3C9A7B4B691A9A983DBD9B0FCFAD1FDFBD4FFFDDE
FFFAE4FFFFF3FFFDF97D7777C7C3C2CFCBCAD5D1CEDBD8D3EDE8E2FFFDF7FFFFF6FFFFF6
FFFFF6FFFFF6FFFCF6FCF7F3FFFCF9FFFBFAFBF7F8FFFBFFFFFAFFFEFAFFF8F6FBF9F9F7
F6F7EFFBFEF5FCFFFAF7FCF8FBFFFFF9FFFFF6FFFEF4FFF6F0FDE9E4F5D3D4E8B7C8DDA2
D3E3A2D4E3A0D2DDA149531F7F865C9296759D9C87DCD6C8A49B94B3A8A4BFAFAF5F4D4D
625050665251EAD5D2FFFAF4FFFBF1FFF4EBD4C5C0AF9FA088757B8A767FFFF2F8FFF9FB
FFFAF4FFF7EBFFFCECFFFCE8EEDDC9AC9B877665534D3D2D5D4F42928177A9928AB49992
775853573833654A43FAE3DBFFFCF1FCF0E4FFFDF1FFFCF1FFF7F0FFF7F3F3CDCA5E3F3D
DED4D3FEFEFEFFFFFFFFFFFFF8F8F8FEFEFEFEFEFEFFFFFF
CFE3A6CBDFA4CEE1AAD9EBB9E4F5C9EDFDD8F4FFE4F9FFECF9FFF1F9FFF1F9FFF2FBFFF6
F8FEF2FCFFF4FCFFF4F8FFEDFBFFE9FCFFE8FCFFEFFCFFF4FCFFFAFBFFFAFCFEF9FDFFF7
FEFFF1E3E9CFD6DEB9DDE6BBD4DBAFB9C192B7BF90CCD4A5DBE1B5E2E7BFC9CDAAFCFFE1
FCFFE7FDFFE9FCFFECF6FFE2F5FFE0FBFFE3485633768461F4FFE6F8FFED000700D2E7C6
C0E09FC8EF9CCAF09BC4E095DAE2A9DEE3BB74866E1B2A23F9F1FCFFFAFF7C7F88FCFFFF
FFFDFF76726F000500D9FFEA9FE7D176C2A6ACE0B9CCF1BDCCE6A5DEF2ADFFFFCCFFFFD4
FFEFDFA9818185666EFFFBFFF9FFF8F0FFEBF6FFE2D4E6B6CBE3A7CEEAA0D7F59FD3F199
C1DD93D0EAAB000E00657E45D4EDA9C9E39CD5EDAFC9DFAEF7FFE4F3FFE0D0E4B3D4E6B2
F8FFDCF8FFDFF2FED8FCFFE3D2D9B893967758593AE4E3C4E2DDBDE7E2C2FFFFE4EDE6D3
5B52494D4344D7CDD6FFFBFFFCF5FCFFFEFFFFFEFDFEFAF7FDFAF5FFFFF8FFFFF6FFFEF5
FFFDF4FFFFF8FFFCF8FFFCFBFFFEFFFFFDFFFFFDFFFFFCFFFFFCFFFFFEFFFFFFFBFEFFFA
FCFEFBFEFFFFFCFFFFF8FCFDF7FEF6FBFFF6FBFFF8F9FFF8F2FDEFE5F1DDD7E7C3D1DFAE
DAE2A7DADEA1E0E3AC585A29FEFED8DCD8BB67624E564E41595049B7ACA8DDD2D0FFF7F6
FFF8F5FFFBF8FFFCF6FFF2EAFFF6EAFFFCF3FFFBF8F9EBEBBDACB45D4C56594850C8B8BB
84727265544D62514956453B5E4C426A5750B29F99E2D0CCFFFBF8FFF1EEFFF9F8FFF8F6
FFECEBFFF8F6F1DCD7E7D6CFFFFCF3FFFDF2FFFBEEFFFDF1FFF5EBFFF9EF94736C6F534F
FFFAF9FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFE
D3E9A0CEE49CC4D996D4E8ABE9FAC4F9FFDAEFFED5FBFFE4FBFFE8F2FBE0F9FFE9F9FFE9
FCFFEAF6FFE2FCFFE8F0FBD9F8FFE0F8FFE3F8FFEAEEFCE5F9FFF6F8FFF7F9FFF8F6FFF3
FBFFEFE6F1D3D6E0BDD5E0B6D4DFB4CEDAACB8C196969F72A1A978DCE4B5D9E0B6F3FBD4
FEFFE4F7FEDDFAFFE4F5FFDCFBFFE1EDFACFBDCCA3F9FFDFF2FFDEF6FFE6849278D2E4BC
CCE69CC7EB93C8F3A3C3E8A3D5E6B2D2DDB3F8FFE479836BA09291FFF9FFABB2BC656F78
ECEDF1EFEEEAA6AA9BE7FFEDBBFFED77C5AFAAE0BEBFE7B5CEF1B1CAE39FCEDC9FFFFFD3
FFF8E699717176575FFFF7FAFBFFF6C8DAC0C9D7B3DDEFBFCAE6A9CDEFA5C6EA93C8EC94
C0E097C5E3A5B8D39EACC790D0EDAACAE8A2C9E5A8D3EDBDF2FFE6E5FED7F2FFDAEFFFCF
D1E5B0CCDEACD9E6BACBD6AED6DDBCBABDA0B7B79DDAD8BFE3DDC5EEE8D2D8D1BFC7BEB5
E4DADBFFF5FFFFF8FFFFF9FFFFFBFFFFFDFFFAF5F9FFFEFFFFFEFBFCFBF6FFFFF8FCFCF2
FFFDF6FBFAF5FFFEFBFFFEFFFCF7FEFFF9FFFFFCFFFEFAFFFDFCFFFEFFFFFAFEEDFCFFF3
FCFFFFFCFEFFFCFDFFFCFFFFFCFFEDFCFFE4E8F1D2FBFFEFFBFFFBF9FFF9F8FFE9EFF6CD
D4D29FE7E2AB97915F585125E5DCBBF1EAD0FFFDECDAD2C7FDF4EFFFF7F4FFFBF9FFFEFA
FFFEF8FFFEF8FFFFF6FFFEF3FFFEF0FFFFF3FFFEF8FFFDFBFFFBFFF7EBF5CCC1C9A3989E
BDB1B3F6EAEAFFFCFAFFF9F7FFFBFBFFFAFFFFF6FDFFF7FFFFFBFFF7ECF2FFFAFFFFF9FF
FFEEF2FFFAFBDED0CFFFF6F2FFF9F2FFFEF4FFFFF3FDF5E8FCF0E2C7B5A7675144DFCDC3
FFFEFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CEE597CDE398D4EAA2596E2DADBF83D0DEA9F0FDCFFCFFDFE1EBC6C8D2AFE6F0CDE1EBC6
B9C49CE5F0C6BDC89EDFECC1F7FFDCEFFFD9D5E7C1C8D9B7DDECCFCCDAC1C9D6C2E9F6E2
F9FFEFF9FFEDF9FFEAF9FFE4F1FDD7E7F4C8CCD9ABCEDAA8929F67D8E3ABD2DEACD3DFB1
DCE7BDD2DDB5E0ECC4DBE8BDCEDBADD7E7B6D3E3B2BACA9BD0E1B59DAD86788766BECFA2
DBF1A6C3E390C6F3AEB8E4A7BAD5A0D1E3B1F8FFD4A5AC806B5A489D8E8BDEE9ED000B11
474F52F1F1EF95938698A999D0FFFE3D84729BD4B4B8E7BBCCF3BACFEDAFD3E1ACFFFFDC
FFF2E1DCBEBC856A6FFFF9FAEDEDE3F4FEE6D8E4C0C5D8AAC9E8AFBFE4A1BCE191D1F4A4
CCEDA8C4E1A7C1DDACC5E1AEC2E19EBCDB97E9FFCBD8F4C3E4FED7D1EBC4E2FFC9DFFBC0
D7ECB1C9DCA4D3E3B2D4E1B6FAFFE0F4F8DDF1F0DBFFFFEDFEF8E8FFFFF1FFFAF0F5EDEA
FFFBFFFFFAFFFFFAFFFFFAFFFEF8FFFFFDFFFFFDFFFFFEFFFFFEFAF7F8F0FFFFF6FFFFF4
FFFFF6FFFFF8FFFFFBFFFEFFFCF9FFFFFAFFFFFBFFFEFAFFFAFBFFF9FFF4E6EFD2EDF6DB
FCFFFFFCFDFFFCFCFFFAFDFFE3EDCADFECB6F0FCCCEAF1D2F9FBF6F5F7F6FEFFEFEBECCA
FFFFCFC1B583695E31877B55E9DEC0EBE0CAFFFEEFFFFDF4FEF7F1FEF9F6FFFDFAFFFFFB
FFFFFAFEFFF8FEFFF8FEFFF3FFFFF1FFFFF2FBF8F1FAF6F5FFFAFFFFFCFFFEF7FFF2EBF2
F2ECF0FFFDFFFFFDFDFFFDFFFFFBFFFFFBFFFFF7FFFFFBFFF6F0FCFDF7FFFFFBFFFFFBFF
FBF0F8FFF8FCD3C9CAFBF3F1FFFEF8F9F5ECF1EDE1FFFFF14A4333A49B8AFBEEDEFFFDF1
FFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
859D519BB369DCF1AC5A6F2EA9BB7F97A66FBAC694FBFFD7EAF3C8D5DEB3D8E1B4D0D9AA
E6F2C0CDDAA5E4F3BCC8D9A5F5FFDFF5FFE3D7EDBFC0D6A5D4E8B5CEE1B3C3D5AFE4F4D7
F3FFEEF1FDEFF2FEF0F8FFF3F9FFE8F6FFDAC7D99FDCEFAF778A48CADD9BD6E8ACCDDEA7
CCDDA9C9D9A8D6E7B3C8D9A3CDDEA7C8DAA0DAECB0C6D89EE3F4BE8F9F6E49582DDEEEBD
CCDF9DCCE9A6BAE9B2B9E9B7D5F6BFCCE5A4C0D789D5E19985784C594E38A8B9AF5B7572
000404C8CCCB908C897C8580E4FFFF538D8165A48991CBA5B5E3B4C5E2B4CEDAB2FEFFE0
FFFFEFF0E5DFA49494B7A5A5CBBCB5FFFFEDFCFFE4D6EDC1CDEABCC6E7B2C4E4A1D0F1AC
CFECB2C7E1B1C9E2B8CBE5B6D0ECAFE4FFBFE5FFC7F1FFDAC3DFB6BEDBAFD6F5BACDECA9
CDE6A4C4D899D1E2ACD2DFB3FCFFE2FFFFECFEFFEFFFFFF3FFFFF4FFFFF6FFFEF8FFFEFB
FFFEFFFFFDFFFBF7FFFCF8FFFCF9FFFFFEFFFFFEFFFEFFFAFBFEF5FAFEF0FCFFF3F7FEEC
FCFFF3F8FEF0FEFFFAFEFFFDFCFBFFFEFBFFFFFCFFFFFDFFFCFFFDF3FFE9D7E4B9DCE8C4
F2F8F4F9FCFFFCFDFFFCFFFFD6E0AECEDB95DFEBADD2D9AFF6F7EFFFFFFDFFFFEDFCFCD8
CFC79992865663572DB8AB88E3D8BCFBF0DCFFFEF1FEF7EFFFFCF7FEFDFBFEFEFCFEFFFB
FCFFFBFBFFFAFBFFF8FBFFF6FCFFF1FEFFF2FDFEF6FCFCFAFFFEFFFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFFAFAF8F8F8F8FDFCFFF8F6FFF7F5FFFFFDFFFDFDFFFEFFFFFFFEFFFFFEFF
FFFCFFFFFDFFDFD6D7FCF4F2F6EEEBFFFEF8FFFEF4A7A1959E9A8ED0CDBEFFFFF1FBF9EC
FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
ADC383C2D898BED295DAECB2CEDCA7DCE8B68C9566BDC697DBE4B5D8E2B0DAE4B0D5DFAA
DAE7AFC5D398D9E9ABD0E1AAD1E2B8D1E3BBCCDEACD0E4A9CFE3A4D5E9ACDAECBAE9F9D5
F9FFF3F9FFFAF0F9F4F8FFF7F4FFE7E8F7CCA5B779C0D48D879F53CBE399DAF1ABD3E9A8
D1E6ABD2E7ACDAEFB4CCE0A3CCE1A0DAEFACD7EAA8C0D393CDDFA3C7D8A181925E5B6C38
C5D99CC8E5ABB9E7B8C7F6C8BCDEA2C7E399D3F094DCEE98DAD39D615C3C6B806D233F33
36463C353B37656364393F3FEBFFFFAAD5CE56917D67A387ACDBBBE5FFE5E5F3DAFBFFEE
FBFFF4FEFFF8FFFBF9AC9A98967F79BCAC9DEAEFD1DFF0CED9F1D1E6FFD9E1FCC7D8F1BA
DAF0C2E5F9D4D8EBCBD1E6BFC3DAA2B6D091F4FFD3EFFFD5D1ECC1CFEBBBC8E8A9BCDB95
CEE8A1D3E8A7EEFFC9E3F2C7F8FFE4FAFEEDFBFDF2FEFFF9FEFDF8FEFEF6FDFDF5FDFEF6
FEFFF9F9FBF6F9FBF8FEFFFFFFFFFFFFFFFFF7F8F3F7FAF1FCFFF3FBFFEFFBFFECDEEBD1
E5F2D8E3EFD9F1F9EAFCFFFAFCFDFFFEFDFFFFFDFFFEFEFFFBFFFAF5FFE6D2E2B1CFDFB2
E2EADBEBF0F3FCFFFFFCFFF6D3DEA4D9E599D7E29DDFE5B5FFFFF1D2CFC6A2A28683815A
979364B7B082C4BC95EEE8C6D3CDB3ECE7D4FFFFF4FFFFF8FFFFFDFFFFFFFEFFFFFBFFFC
FAFFFCFAFFFAF9FFFAFBFFF8FAFFF2FEFFF6FEFFFAFEFFFFFEFFFFFCFDFFF9FAFEF5F9FA
FCFFFDFAFFF9F7FEF6FBFFFAFBFFFDFBFFFFFBFFFFFBFFFFF9FFFFFBFFFDEFF4F0FEFFFD
FFFFFDFBF6F3F2E8E7F5EAE8FFFBFAFAECE94C413BB6ADA6FFFCF3FFFFF6EAEEE0FEFFF8
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D3E6B9D0E3B5DFF0C4C5D4A9E9F6CBCBD6ACC8D1A6949B6F40471B9BA372D6DEABC7D19C
D2DFA7556328D8E8AAD0DFA6DAE7BBD7E4B8D0DDA7D1DFA1D7E6A3CCDA9CCEDCA7E4F0CA
F3FCE7F9FFF6FBFFFBFBFFF8F8FFE9DAE7BCA7B67BC9DD95C0DB8AD2F29FCDEC9EC7E59B
C8E3A0CAE5A2D3ECAAD0E7A3D1E8A0C1D98FCEE49BE5FBB3DBEEACC0D294E8F7BE31440D
2F480FCFF0BBB5E0B39BC595ACCA8ACCE999CBF090C0DC85DEE1AC575836000E0057735A
D0DFC86C74650309056B7375F4FFFFD9F6F2A6D5CB52887888B7A7E6FFFCF0FFFCF5FFFB
F1FFF8F5FFF7FFFFF8FEEFEAC0A7A0BDA79AFFFFEAFCFFEDF1FCECF8FFF1F9FFE4F0FFD8
F9FFE6FBFFECCDD6C1DAE5C7DFF0BCDFF1B5EBFEC6F7FFD6C5DBADCCE4B2D1EEABC7E59B
C8E299D4EAAAF8FFD6F3FFDBFBFFEFFBFFF7FCFFFDFEFFFFFEFFFDFBFEF7F8FEF2FCFFF1
FCFFEFFAFFECFBFFECFBFFEFF9FCF3FEFFFAFBFFF1FAFFEFF9FFECF8FFE6F0FFDBD1E1BC
D2E2BED3E2C3E7F3DBF9FFF3FCFFFAFDFEFFFEFFFFFAFEFFF8FFF3F4FFE2D3E5B1C9DBA7
D1DFBCD9E3CBF2F9E7FCFFE6DFEBADCEDA90DAE3A0C2C693FFFFE33A381F5758308E905F
F3F7C5E9ECBDCBCDA5D6DAB7E7EACFFDFEECFEFFF5F9FAF4FFFFFFFFFFFFFFFFFFFDFEFF
FDFFFEFDFFFCFEFFFBFEFFFAFEFFF8FEFFFAFBFDFAF9FBFAF8FCFFF9FDFEFBFFFEFBFFFB
F9FFF4F8FFF2F9FFEFF9FFEFF6FFF1F8FFF6F6FFF8EDF9EDF8FFF3F8FFEFFBFFF1FEFFF1
FEFFF1FFFFF3FFFCF4E3D1CDFFF5F1725E5DC1AFAFFFFBFAFEF9F6FEFFFAF9FFFDF1FAF5
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DAEACFF7FFECF5FFE6FBFFE8E6EFD0F4FBDAFDFFDFD5DBB5CDD2A9A8AE809CA47396A06B
9FA974CDDAA299A86DB6C489CAD39ECAD39ED2DCA0A8B275A7B174C8D198E3EBBCB0B893
D9DEC7EBEFE0FBFFF1FEFFF1FEFFE8DCE4BBCAD4A0D7EAA8D4F4A1CAEE96C6E995C9EA9B
CBEBA2CAE8A0CAE59EC9E39AD9F4A7CEE698CCE395C3D98EC8DC95E7FAB8CAD99E55692E
3A591E214610113809A4C995E1F8B4C8E392CBF69CBFE69797A478050E003B5333DCF4D2
D0DCB6EEF7D8E7F5E892A19E050F1098AAAAE7FFFFC8F2F078A4A32A5453E7FFFFE7FFFF
F0FFFFF2FFF6F4F4ECFFFAF1DFCBC2836F64FFF8E8FCF8ECFFFFFDFEFFFBFAFDEAFFFFEA
FFFFEFFFFFF378786CAFB19BE9F0C4D8E3ABF0FDC5F3FFCCC6D7AAC7DBA6CAE49DDAF6A9
C7E19ACAE0A2F4FFD6F3FFE1F9FFF4FBFFFDFBFFFFF5FAFDFCFFFFF6FDF5F7FFEDF6FFE7
EBFBD6E7F8CEE6F9CBE1F1CAE6EED9FCFFF3FCFFEFFBFFEAF3FFDFE3F5CBE2F5C7D1E7B6
CDE0B2CEE0B6E3F4D2F8FFECFBFFF4FBFFFAFBFFFEF7FEF7F7FFF2F6FFE3D8EAB6CEE1A9
D2E3AFD2E2B3E7F2C7F3FDCBCDD798E0E9A681874B5F612F7B7C549B9972BABA86E0E5AB
E5F2BDF7FFD8EFFED3DEEAC6E5EFD6E8F1DEF2F8EEFCFFFBFEFFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFDFFFFFBFFFFFBFDFDFBF9F9F9FBFCFEFEFFFFFCFFFFFCFFFBFBFFF6
F9FFEFF9FFEAF8FFE6F8FFE4F2FFE1F7FFE8F7FFECF3FFE6F1FFDEF3FFDCF9FFE3F2F9D8
FDFDE1FFFFEAFFF2E4AE978F5C403DBA9E9DFFEDF1FFF9FDFFFAFFFBFCFFF6FFFFF7FFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F5FFF8F3FFF4F2FDEFFBFFF3FCFFF1FDFFEBEFF3D8D4D8B7CACEA9C7CCA3D7DEB2E0EAB8
FEFFD6FCFFD4D8E7B0D3DEA4676D2DD3D896A8AC6F4E511ADDDFAEE9EBC3BCBD9BBFC0A0
D6D9BCEDF0D3FCFFE2FCFFE0F0F6D2B4BA94D1D8AFD0DFA8C8E998BDE68AC7ED96CEF4A1
CEF0A4CEEEA3C9E79DC8E499C2DD8ECEE796E2F9A9DAF1A384985051621E4B591CC8DEA0
BFE6A5D3FFBFB7DDA4C9E7ABD5E49FCBE196C8F6ABBEEBB2576D560915094F6347D6E8BE
D2DBA4DEE8B6F2FFECEEFFF8BCC9C2768282F4FFFFDBF6FF91B9C355879079ABB2E1FFFF
E8FDFEFBFFFDFFFFF6FFFEF1FDF6E685796BECDAD0FFFAF8FFFAFFFFFBFFFCF5EFFFFFF3
FFFDF8FEF4F219100B665F4F97956E585B26E7EEB8BCC491F0FCCCDCEDB7B8CE85D5ED9F
D5EEAACEE5ADF7FFDFF8FFECF8FFFAF6FEFFF9FFFFF2F9FFFBFFFFF1FBF0F2FFE7E8FAD4
CFE6B2CCE4A8CFEAA7C6DEA4D6E1C1F1F9E1FAFFE7F9FFE3E9FACED1E5B2D3EAB2CFE8AE
CEE5ADCDE4B0E3F5CBF8FFE6F9FFEFF9FFF2FCFFFAFBFFF8F8FFEFF4FFE3D6EAB9D1E5AA
D9ECAAD0E49DD0DF9ACAD694DDE7AA4E561D555926535524E7E7B5C8C78FE4E4A4DCE2A2
CCE1A8E2FECDEFFFDCEBFFDBF2FFEAF7FFF3F8FFFAF4FAF6FCFFFFFFFEFFFFFDFFFFFCFF
FFFCFFFFFBFFFFFCFDFFFCFDFFFCFDFCFAFDFFFDFFFFFEFFFFFEFFFDFFFCF6FCF2F5FEEB
DEEBCDC9D8B1C9DAAED1E3B3C9DDACC9DFB0D1E7B9CDE3B4D9EEB6D4E7AFD8E6B1CED6A7
E7E8C0D3C8A8AE99848F7367FFF6F1FFEDEEFFF5FBFFF7FFF0E4EEFEFEFFEFF9FFF7FFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EDF7F8F9FFFFF9FFFFEDF4EDFEFFF8FFFFF4F4F5E5FFFFEDFFFFEAFFFFE8FFFFE4F4FCD7
FCFFDCEDFBCAD6E4B1D6E4A9D0D794A7A96AD8DAA8D9DAB2FFFFE4FFFEE5FFFFE6B4B595
90956DBEC39ADDE2B9CDD4AAAFB68A6D7546C9D1A0DBEDB1CAEC9FBEE892C9F09DC3EA9B
BBE093C4E69ACAEA9FCDEBA1CBE79CD3EEA1C6DE92CFE59A93A75F44550FDBEAA5D0EAA3
BFEBA0B9E79FC9E9AACDE3A5CAD994D9F3AAB1E8A4629C6A2449380008006B7F64C8D9AF
D5E4ABE4FDC6D7FFEADBFFFFE3FFFF56727368727EF7FFFFEAFFFF84B0BB4B8589BDF5F6
E7FFFFF2FFFFF2F4EFFFFFF6FFFFF3C1BEAF5E4E41716059FFF2FBFFFBFFFFFBF8FFFAF4
FFF8F8FFF7FA0B00003C34276F6E4FA7AA7F46471BEAEDBECDD7A5CBDDA1E0F8AACBE697
CEE4A3C8DCA7F6FFDEF4FFE5EBF8E4DEEADEEAF5EDEDF9EFF8FFF6F7FFEDF7FFE4E5FBCC
C5DEA4C4E19ED2F0A8CDE7A6CEE1B3DFEFC8E3F4C8EDFFD0E2F7BFCBE0A7CCE1A6C9DDA2
D2E3ACD1DFACE5F0C6FEFFE3FFFFECFFFEF1FFFFF6FFFFF6FFFFEFF8FFDED3DCADD2DDA1
DDEAA2CDDB8EB7C57A9CA9645962293E4712C2C993D8E0A7CDD397E6ECACD5DB9DDCE7AB
CFE8AFCAE8B4D9F4C7EEFFE0D7EBCFEBFDE7F1FDF1FBFFFBFBFFFEFFFEFFFFFDFFFFFDFF
FFFCFFFFFBFFFFFCFDFFFCFFFFFCFFFFFDFFFFFDFFFFFEFFFFFFFDF9FCF1FAFFEDFBFFE6
EFFED3CADCA8C8DDA2DAF3B2D2EBA9C6E19ECAE4A3CAE3A2CAE39FCEE3A0DDEDAED6DFA8
DCDBAB817753665136B79A8AFFEDE7FFF5F4FFF5FAFFEFF6FFFBFFFEFEFFF1FBFFF7FFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8FBFFF9FCFFFCFFFFFEFFFFFEFFFFFFFFFFFFFEFFFFFFFDFFFFFDFEFFF9FEFFF6F9FFEC
FBFFE6F5FFD9D5E7B3D5E4ADD8E1A8D3D6A7FBFBE1EFEDE0FEFEF6FFFFF4FAFEE3EAF1C8
9DA77396A06BA3AF7FB5C191B3C08AB3C384C9DC8DD9F29FC6E89EC2EAA3C4EAA1C4EAA1
C7EBA1CAECA2C7E99FC3E29CCEECA6CCE7A2C1D894E9FEB9CBDF9746580CD7E898D1EA97
B9E58ECFFAAAC7DFA1D6E8ACDBF2AEB9E198AFF1AAAFF8C1427A61153E2E40573DCCE0BB
BFDFAED7FFE593F0DD6AD3CE71D0CCABECEE6A7B8B000010FCFEFFE8FCFFA8DFDA3A7D74
9FD7D4DEFFFFF2FFFFFCFFFFFCFFF8DCDDCFD1CFB8B4B29D5A584B6E675FB5A29BC5A6A1
8557597C52540D0000848478F8FFECF6FFE4504C2FDEDCB5DAE7B2C5DC98CAEA97CAEA97
CDE3A2DDEEB8F5FFD2F2FFD4D2E5B8BFD4A9CFE4BBDFF6CAEFFFDAF1FFD9F4FFD8DFF8C1
D5F1B6B8D497D0EDADCFECACCBE8A8C4E1A1D4F1AFC3DD9CCBE1A1DAECAECAD89DDDE6AF
9698699D99739D9274A08F7BD8C2B5FFF3EFA48686AD8F8FC5AFA4827259DCD1A4D9D598
B0AF6C6E712E75783F949B67D4DCA9D5E2AAD8E9A5D6EAA2D3E7A0CFE4A3CFE1AFD0E3B5
C9E2ABCCE7B0CDE5B3C9DEB3D3E4C2EAF7DDF9FFEFFBFFF5FEFFFAFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFBFFFEFFFFFAFFFFFBFFFFF9FFFCF8F5FDFFF2FBFFE9E7F3CBCCDEAA
CDE3A3CEE89FCEEB9BCBEB98C8E893C7E891C9E994CBEB98C2DF8FE3FBB1CBDB9AD7E1A5
A4A272908760CCB89DFAE0CFFFF8EDFFF7F3FFF9F8FFFBFBFFFDFFFEFFFFF9FFFFF8FFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFF9F9FBF7F7F9FBF9FCF9F6FDF1EEF5FFFCFFFDFCFFFEFFFFFCFFF8
FBFFEDF6FFE1D2E3B6CDDDACD9E2B3D8DCB9FFFFF3F6F6F8FFFEFFFFFFFBFAFFE6E9F2C7
CCD9A3B0BD85A7B584B8C695C7D8A2D1E4A2D1E792C6E089C9EAA3C6EBA8C6EBA5C4EA9F
C5EA9DC6EB9EC7E99DC6E89EC4E19ED1EBAAC9E2A1C0D592D8ECA495A859D7E995CEE68E
C5EE92C7ED9AC7D798D1DCA0D3E8A3BFE79EAEF0A8ABF2B884BFA149705D3E4C33E5F0CE
CDE9C0ADE9C56DD3C81A8E8E1E88886AB5BA94B0BC373646F9F3FFF4FEFFCBF5F1418077
5C9E9AD9FFFFDFFCFFF3FFFFF6F8F7EFF1E4EEF3DCF7FDE1959883615A4A584036704A47
825454B6908F1304007E8075F3FBECF4FBE94E4933DFDBB8DEE5B1CEE29BC6EC95C7EF99
C9E2A0CEE0A6DBEEB6E2F7BCD4ECB2CCE6A9D1EAB0D1EDB0DEFABFE9FFC6DDF6BCD9F1B5
DCF4BAEEFFC8D0E5ACC2DA9CC7E59FA6C67B92B066B3CD84C6DB96D6E5A4DCE4A9DEDEAA
585125716340AE997E8D725F947268FFF4F1AA8082FFD9D9FFE6DD927A60D9C799ECE0A4
5A5213545217CBCA9CD7DCB4D7DFB6CCDAA7C6DB98CFE69EDEF7B3E4FDC4DFF3CED3E8C7
C5DDADD8EFB9E1F7C6D9EBC1D3E1BEE1EBD0F9FDECFEFFF4FFFFF8FFFFFBFFFFFBFFFFFB
FFFFFBFFFFFBFEFFFBFFFFFFFFFBFFFFFAFFFFFDFFFFFEF9FFFFF1FCFFE6E6F6C9CDE0A8
D2EBA9D0ECA2CCEB9BCBEB98CCEC97CDEE97CEEF98D1EE9AD9F4A7C6DC94D1E1A0D5DDA4
7A774AADA37FFFFDE3FFEDDAFFF9EFFFF9F3FFFAF8FFFCFAFFFEFDFEFFFDFBFFFFFBFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFFFFFBFDFEF8FFFFFAFFFFFBFFFEFDFFFDFFFFFEFFFDFAFFFBFAFFFEFFFFFCFFFB
FBFFF4F5FFE8D0E0BCC9D8AFE6EEC7E7EBD0FFFFF8FDFCFFFFFEFFFEFFFDFAFFE8EAF2CB
E0ECBAD2DFAACEDBAFD1DEB3D0E0B3D8E9B2DBEFA7D0E89ACCECA1C8ECA2C7EC9EC6EC99
C4EA95C4EA95C8EB99CAEC9FCBE9A1D1ECA7D3ECA8CCE19CCADE968C9F50CEE08EDBF19C
CEF099C9E694E0E9A8E3E7AAD6E39BCDE99EB7EBA0B5EDB0BFEBC8284028302C0F5A5130
D2DAB175987800423B60B9BFC8FFFF5B989D8BB2B9ABBFC6959CA2F8FFFFDBF5F6CBF8F5
407C7ABBF7F7D8FFFFF0FFFFFEFFFFFBFAF5F9FFF1F9FFEDFEFFEFFFFCF0FFF5F1FFF4F1
FFFAF3FFFDF41009017C786FFFFFF4FFFFEF565239E0DAB6E7DFAEDDE4A1BEE990BBF096
D0F1AACCE4A6CFE7ABD4ECAECCE6A9CAE4A5CBE5A8C6DEA0D3EBAFC8DEA0D3E5ABF5FFC9
EEFBC3D8E3A96C753ED9E7AACFE49FD2E9A1768C446F833CB2C17EEBF4B5D3D79CD7D6A0
CCC495F8E9C2FEE9CAFFE9D3775748FFE0D79A736EF8D3CBFFF9E6A4906F685825DAD093
DFD99BDEDDA5E7E8C0CDD0B1E4EBCCD7E3BDD1E1B0DBF0B8EFFFD0F5FFE1F2FFECE4F6E0
D3E8C1E6FCCDF2FFDAE9F9D4DEEBCDE6F0D8FAFEF0FFFFF8FFFFFBFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFEFFFBFFFFFFFFFAFFFFFBFFFFFDFFFFFEF9FFFFF4FAFFEAE6F1CFCDDEB2
CFE3B0CAE2A8C9E1A3CAE4A3CEE9A6CFEAA7CFE8A6CEE4A3C7DC99DCECADCCD79D9A9E6C
817E55D2C9A8F7E7D0C4B1A2FFFAF1FFFAF4FFFAFAFFFCFBFFFEFDFEFFFFFBFFFFFBFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEF4FAFAEEF9F9EDFFFFF4FFFFF6FDFAF5F5F1F0FFFDFFFFFBFFFCF9FFFFFEFFFAFBFD
FCFFF8F5FFEDD6E3C7D2E0BFF9FFE1FAFDE8FFFFFBFDFEFFF8F9FEFCFEFBFCFFEBECF6D1
CEDAACD6E3B5E0ECC4D8E4C0C7D6AFCADAADD3E5ABCDE4A0C9E99EC5EA9AC8EB97C7EE95
C6ED94C3EA91C7EB94CCEF9DCAE89EC7E29BC5DE9CDEF3B099AD6854651ED5E396D0E694
CCEC97CDE899FFFFC6FFFFC0DBE69AD2E99BBCE89BC2F0B0B9D9B0E2EFD1B1A482C2AE89
E5E0B86D8062376E696CAFB7D6FFFFBDEEF35F8B8E99B8BA000307515459F8FFFFEDFFFF
4A80804482818EC1C4E6FFFFF7FFFFEDF2EEF9FFF6EEF7E6FBF9ECFFFBF2FFF1EEFFF2EE
F8F1E7FDFFF5000200878579FFFDF3FFFDED5C5036D8CAA7E6D8A9E0E5A3BAE890B9F196
C4E8A0C5DF9EC9E3A4CAE4A3C2DC9DC6DF9ED0E8AAD3E9A9CBDDA1CDDD9FDDE8AED2DA9F
DCE1A9EAEBB2605F29D6DA9FD8E4A2C8D993EFFEB997A25E47500FD4D999DCDCA0EFEAB3
CBC190CCBD92FEEAC5FFFBDD5F432BCCAD99CBAA9BB79886FFEDD0D3C49B635822B5AF73
D2D095DBDBA9FFFFE1FFFFECF4F9E5F2FCE4F2FFDDF4FFDFF7FFE5F8FFEFF8FFFDF8FFFB
F0FFE3F4FFE0F5FFE1F2FFE1F5FFE7FCFFF3FFFFF8FFFFFBFFFFFDFFFEFFFFFEFFFFFEFF
FFFFFDFFFFFDFEFFFBFFFFFDFFFBFFFFFBFFFFFCFDFDFCF8FDFFF7F9FFF0EBF5DDD9E6C8
D2E2BED2E2BBD1E4B7D2E5B7D2E5B7D1E3B3CDDFAFCDDBAACCD9A4E2EBB69CA2725F6038
9B9774DED4B9DCCFBCF5E5D8FFFBF3FFFBF8FFFBFBFFFCFDFFFEFFFEFFFFFCFFFFFCFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFAEBFFFFEFFFFFEFFFFFEFFCF8ECFFFFF6FFFBF8FFFDFFFFFCFFFFFCFFFFFEFFF9FAFE
FCFFFDF8FFF5E3EFD9E7F4DAFCFFECFEFFF3FEFFFDFEFFFFF8F9FEFCFFFBFCFFEFF1FBD8
E8F3C8E5F2C6E7F3CFE4F2D1E2EFD1E9F7D6E1F0C7C7DBA6C8E69EC4E793C7E992CBF093
CAEF92C6EB8EC7EB93CBEE9AC9E89CCDE8A3C2DB9AD1E5A898AA6C7D8D4CDEEAA8C9DD95
C8E89CCBE79CFFFFC8FAFFBCD8E596D3EA9AC0E99BC5F0ABCFEBBBD0D8B1B2A37AA68F66
AD9F78535C41E4FFFF2C606BA3D2D8DEFFFF8DB7B699B7B7D6DDE3BCB7BEFFFCFFE6F0F9
BFECEF4F918F5CA19EB6F1EFE1FFFFF5FFFFFCFFFDFFFFFAFFFCF6FFFBF4FFFAF6FFFCF6
FFFFF8FBFFF80005007D8375FFFBEEFFF8E763452DC7AA88DED29ED9E6A1BDEB93BFF49A
CCF0A6CCE9A6D1EEACD2EDAACAE4A3CDE6A4D6EAABD2E5A5E0EEB1DDE7AADCE1A7DADBA1
D9D49DE6DFA8918551625C22D0D593F3FDB8CCD38FE3E8A59C9E5DA0A062DEDC9FD8D399
B9AF7A7C704072633859461EB19A78FFEFD1D4BA9F8C7556B0A27BE3DBAA837E449E9C5F
E3E2AAE3E4B8FFFFE8EDEFE1FDFFF7FCFFF8FBFFF3F9FFF3F9FFF4F6FFF8FBFFFFFBFFFF
F9FFF1F9FFEAF8FFEBFAFFEEFCFFF4FEFFF8FFFFFDFDFBFCFFFDFFFFFDFFFFFEFFFFFEFF
FFFFFDFFFFFDFEFFFBFFFFFDFFFEFFFFFEFFFFFEFFFFFFFDFEFFFBFCFFFAF8FFF3F0F9E8
F9FFF3F9FFEFFBFFEDFAFFEBF8FFE9F9FFE7FCFFE8FFFFE6FFFFDFA2A37B6B6845969374
FAF3D9FFFFEAFFF7E8F1E7DDFFFCF6FFFCFAFFFCFDFFFEFFFFFEFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEECFFFFEFEEEDD9D2CFBCB5B2A1EAE6DBF8F3EFFFF9FBFCF7FEFCF9FFFFFDFFFBFCFF
FCFFFDF9FFF6EFFBE7F9FFEDF7FFEAFCFFF3F6F8F5FCFFFFF6FAF9FBFFF8FCFFEDF1FDD9
FBFFDDF8FFDAF6FFE0F9FFE8F9FFECF9FFEDF5FFE6D7E8BED1ECA9C8E797C6E691CBEE94
CDF094C7EB91C6EA93CBEC9DC8E6A0CCE6A7CBE2AAC9DBA7C0D19DB3C08BADB782D5E7AD
C9E9A8C4E4A1DAEAABD9E4A2CFDF94D0EB9CC3ECA0C0EAA8ECFFD5FCFFDCC3B88B514015
392F0B3139224F717245717C547B82E6FFFF8FB1B09BB3B3F9FFFFA3A2AA26232EF8FFFF
E6FFFFBEF6F75EA2A14B8B8A6D999AE2FBFFEFF7FAFEF8FAFFF5F5FFFBF6FFFDF8F8FBF4
F4F6F1F9FFF9010E04859080FFFFEFFFF8E3714C32B79570DDD69FCFE39BC0EA94C1EE99
C2E297C1DC97C8E19DCDE6A2CEE5A1D4E9A6D3E6A4C8D796D1DD9DD4DD9ED2D397F2F0B5
B4AE74B8AD75F2E3AC5E54199D9C5CCED390D7DA97E6E9A6E4E4A47F7F3F312F00E6E4A7
DED99F9C955F9C9561DDD3A2E4D7AAEDE0B4E2D3AA877A506D67359B9A6264642886874D
E4E6B4CFD4ACF6FAE3FEFFF6FBFFFCF9FEFAF7FCF6F9FEF8FCFFFDFCFFFFFEFDFFFBFEFF
FBFFF8FBFFF1FCFFF3FCFFF6FEFFFAFFFFFDFFFEFFFFFEFFFFFDFFFFFDFFFFFEFFFFFEFF
FFFFFDFEFFFBFEFFFAFEFFFBFFFFFFFFFFFFFEFEFEFCFEFDFCFFFFFCFFFDFBFFFBFBFFFB
F5FCF4F5FBF1F7FAF1F8FBF0FCFEF1FFFFF3FFFFF3FFFFEF827C64979074E0D8C1FFFFEA
FFFEEDFBF3E6FFF7ECEDE6DEFFFEFAFFFEFBFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBEFFFFDF1CCC9BAB2AC9C918B7DC3BDB1CBC4BED3CDCDE6E1E5EFEDF2FFFEFFFCFEFB
FCFFF8F9FFF1F2FFE5F9FFEAF8FFEAFBFFF1E2E8DEEEF5EDE4ECE1F4FFEEFBFFE8EDFCD5
E4F4C7E1F1C4EAF9D2F2FFDFF3FFE7F6FFEEF3FEEDE5F4D5E1F8C0D1ECA5C8E499CAE999
CCEE9AC8EA96C7E79BCBEAA4C5E1A4D0E8B4CFE5B7D9E9C2DBE7C3C7D1AE9DA37FD2E1B8
C8E8B7CCF1BBC6DDA5C6DA9DCDE4A0C8E7A1C1EEABBBE9ABEBFFDCECFFD3F0F3C4959267
888969617260638A8F0935401F4045A5BDBFF2FFFFEAF8F9E5F3F4F5FFFF00060BF1FFFF
E1F8FFE7FFFFAEDDE36DA3A56EA1A4A1C9CBF2FFFFFEFEFFFFFCFDFFFDFAF5FEF9F7FFFD
FEFFFFFBFDFC08150B576453FFFFECFFF3D9765335A2855BDEDFA3CAE298C8E998C6E796
D6EDA5D5EAA5D8ECA7D3E7A2C9DD98D0E19DD8E7A4D4E09ED2DD9BEBF1B1DBDD9EC2C083
817B3FA69D62E0D49A63591CAEAD6CDADD9AE5E8A5DCDF9CDDE09D949754505211C3C584
E1E3A4C1C38465662AB4B57B98975F9C9B63BDBC86BEBD8790915852561B5F6529B4BC83
DAE2B1DAE0BCFEFFEDF5FBEFFBFFFCF6FAF9F3F7F6F8FAF9FEFFFFFEFFFFFFFDFFFCFBFF
FBFDF8FCFFF8FEFFFAFFFFFBFEFEFEFCFAFDFEFBFFFFFDFFFFFDFFFFFDFFFFFEFFFFFEFF
FFFFFBFEFFFAFEFFF8FCFFF8FEFFFFFCFDFFFBFCFEFAFEFFFAFEFFF9FFFDFBFFFEFCFFFF
FCFFFDFEFFFBFFFFFBFFFFFAFFFEF8FFFEF6F2E9E2E1D7CD695B4ECEC0B3FFFCEFFFFCF0
FFFDF4F8EFE8FFFEF8EBE8E3FFFFFDFFFEFFFFFEFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEF9F5F9F4EEE6DFD7FFFEF4F7F1E5FFFEF4FCF5EFFFFEFAD1CDCCE2E1DFFBFCF7FCFFF6
FBFFF1F9FFEAEDFDD8F8FFE3F9FFE8F9FFEDCEDAC4D7E3CDCBD7BFE5F2D6F7FFE2EAF9D0
D4E4B7CCDCADD6E5BAE8F6D2F3FFE4F9FFF1F9FFF6F5FFECF0FFD6DBF0B7CAE2A4CBE6A3
CCEAA2C8E89FC7E6A3CBE9ADDBF6C3F4FFE1E8FBDBF8FFEDF3FCE7FEFFEFF6F7E5D2DCC4
C9E4C5E2FFDAD2E8BAD2E4B0D6EBB2C2DFA5C3EBB6C0EABAEAFFE1F1FFDFC7D3A5E0E7BE
FBFFEA9DB3A7729AA284AEBC253C424A5557E7ECF0F8FFFFE9FFFD94B4B1325654001216
E6F4FFE2EEFCEEFFFFE7FFFFC6F6FA2E5E62C0E1EAEDFFFFFAFEFFF9FBF8F7FFFFF5FFFF
F7FFFFF0F4F5313B33878E7EEBE9D2E7DCBC614E26857844DDE3A3CBDF97D6EEA2D1E99D
D2E29BCFDC97BECB868F9C5757662144530E505D1855621D5C6723434C09606523999B5A
D6D696E5E4A4787435615D1E424502EDF2AFD7DC995D64206269255C631F535A1797A05D
D3DC99D5E09CBFCA86889452B1BD7BCFDB99C6D290DCE8A8D9E3A4DCE6A9D2DBA2DBE5B1
F9FFD7FBFFE3F5FDE6FCFFF4FCFFFAFCFFFDFEFFFDFEFFFFFEFEFFFEFCFFFFFDFFFFFEFF
FFFFFDFBFDFAFAFAFAFEFEFFFFFEFFFFFDFFFFFCFFFFFAFFFFFDFFFFFEFFFFFEFFFFFFFD
FEFFF8FCFFF4FCFFF3FBFFF4FBFFFDFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFCFFFDFCFFFD
FEFFFBFCFDF7FFFDF6FFFFF6FEF5ECDAD0C7A3968D786962F3E0DAFFFAF6FFFAF6FFF6F3
FFFCF8FDF5F2FFFEFBCFCECCFFFEFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D3C9D1BFB6BBF8EFF0FFFDFAFFF9F3FFFAF2FFF8F0FFFEF8EDEAE3C2C2B8FEFFF4FCFFED
D2E0BFF3FFD8DBEFBAE1F5C2F7FFE1F5FFE1CDDDB9DAEAC5CADAB5DAEAC3E7F8CEDCEDC0
D2E4B2CFE1AFD8EAB8D9EABDD7E7C3EFFDE3F8FFF4F3FFEFF2FFE3D1E0B9D7E8BCC3D7A4
D4EDB4D5F1B7C8E5ADCAE6B5DCF5CDEFFFE7F7FFF3F9FFF8FCFFFAFCFEF9F7F6F2F5F8F1
BAC7BDE6F5E2CDD8B8CCD7AFD8E4BCCFE1BBCAE5C4C3E2C3EEFFEAEDFFE1CBDBB4D8E6C5
F7FFF3C2DBD8759AAA698A9D323C456B6A6FBFBEC4E0EBED9ABEBA4B7E77255C56133D3B
68727CFCF5FFFFFAFFFBFEFFEAFFFF34616676A8AFC1EEF1EAFFFFE8F8F5F8FFFFF4FDFF
F0FFFFF7FFFF3737358C867AF2ECD2D5D6AE9BA66E465514E0E9A6D5DF98CADB94DBEBA4
BAC17D9DA05D7075325C631F6F7934909B569CA96394A15B8F9C5696A35DAAB570C8D38E
DDE7A2D5DF9AB6BD79979E5A79823FCFDA96D8E39F9EAB668F9C5794A35E9AA964ACBD77
D3E49ED1E59ED0E69ED0E89ED0E89ECFE79DCDE79DCFE69ECFDFA0D7E5AAD5E2ADD5E2B4
F9FFDDFBFFE4EEF8DDFBFFEDFAFFF0F2F8EAFEFFF8FFFFFAFCFBF7FFFFFAFFFFF8FFFFFA
FFFFFDFFFFFFFFFEFFFFFDFFFFFCFFFFFCFFFFFCFFFFFDFFFFFEFFFEFCFDFAFBF6F4F7EE
FBFFF3F6FFECF2FEE6F9FFF1F6FFF8F9FFFFF9FFFFF9FFFDF8FFFAF9FFF8FBFFF7FEFFF6
FBFDF0FFFFF3FFFFF1FFFCECFFFDEDC8BBAB706051D1BFB5FFF8F7FFF9FBFFF9FBFFF3F3
FFFBFBFFFCFDFFFCFCBBB9BAFEFCFDFBFBFBF8F8FAFFFFFFFFFEFFFDFCFFFFFDFFFDFBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F2E7F5FFF6FFFFFBFFFFFCFFFFFDFAFFFEF6FFFBF3F5F1E6BCBDAFD7DAC9F2FAE2F7FFE0
D2E3B6D7ECB3CEE7A5D7F0AFF1FFD4EDFFD4CEE2B1D7EBB8C6DAA9CDE1B0D7E8BBD0E2B2
C9DBA9CDDFABD5E8B0D4E6B2D2E3B7E2F1D0F5FFF0F9FFF6FBFFF3DAE4CCD6E3C5CADAB5
CCE2B4BAD2A2CCE6B7EDFFDDEDFFE3F3FFEEF7FFF8F9FFFDFCFFFFFFFFFFFFFDFFFFFBFF
FFFEFFBFBEBAFFFFECD4D0B3F8F8DCFDFFEAF5FFF2F4FFF7EFFFEBF7FFEAFBFFE6FBFFEA
EDF9EDF2FFFFE6FFFFD2E9FBECF3FBCDCDCF4A4F5327393B3259566596929CD1CB89B2AE
18272C77747FBEB2C0FBF5FFE7F5FFD6F8FF1D52585A9293D8FFFEEBFFFFF5FFFFF4FEFF
F1FFFFEFFCFF0300007B7167EBE6C9E6EEBFCEEDAA6080356B7B328C964F9BA66167712C
515411807F3EB5B674D4D794DFE6A2E2ECA7DBE8A2D0E099D0E19ACADB94C6DA92CDE199
D9EAA3DCEDA6D5E69FCDDE97CCDD97DDEEA8D1E29CC6DA95D7EBA6D2E7A2C6DB96D1E8A2
CCE69FCBE79DC8E69CC7E79BC8E99AC8E99AC8EB99CBEA9ED0E5A4D3E4ADD0E0B1D2E1B8
F3FFDDF5FFE1D3E1BED8E6C3D7E4C6D9E3CBF6FDEDFFFFF6FDFDF5FFFFF4FFFCEDFEFCF0
FFFEFFFFFEFFFFFDFFFFFDFFFFFCFFFFFCFFFFFCFFFFFEFFFFFDFEFFFFFBFEFFF6F2FBE8
F9FFECE6F5D6E0F1CDE7F7DAEFFBEFF6FFFBF8FFFBF9FFF8F0FBEDE7F2E1E6EFDAE8F0D9
E2E6CDF0F0D6F2EED5F8F0D9FFF6E0847560FFF8E4FFFBEFFFFAFAFFF1F7FFF8FEFFFAFD
FFFBFDFAF0F1FFFDFFEBE7E8FFFEFFFFFEFFFBF9FCFFFFFFFFFEFFFBFAFFFFFEFFFEFDFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFFFCF4FFFFF9FFFFFDFFEDE8E5FFFFF6FFFFF3B5B4A2AFB19CF9FFE5D9E4C2DDECC1
D4E9B0C2DB97C8E497CDE99ED6F0B3D9F2B9C8E0A2D0E8AAC6DEA2CAE1A9D5E9B8D6EAB9
F5FFD6F7FFD4F2FFC9E2F6B9D4E6B2CADAB3D5E3CAEDF8EAFAFFF8F5F8EFFAFFF0F9FFEA
F7FFE4D4EBBFE0F9CFECFFDEF2FFE8F4FFEFF7FFF6F9FFFBFDFFFEFFFFFFFFFDFFFFF7FF
FFF9FFFFF0F4FFF5E6E0CEB8FFFCECFFFCF3FFFCFFFFFEFFFEFEF2FFFFECF0F3D6FFFFEC
FEFFFAFBFFFFE2EBFCF5FFFFF7FFFFE3F2EF798D8C00070721393D94ADB1EBFFFFDDF7F6
203A37000604737B7DF2F5FCFBFFFFF1FFFFC4ECF415464A82ACAACAECEBEDFFFFEBFFFF
EFFFFFF7FFFF030002938D81F4F5D5B7C892C2E69CCDF7A5B4D181CADC90E6EFACE7E9A8
DDDE9CE7E6A5E7E8A6D8DD9ACED893D0DB96D2E29BD0E49CD5EBA2D1E99FCBE59BC9E399
C9E59ACBE79CCDE99ECFE99FD9F0A8D0E7A1C7DE98D2E9A5DDF4B0D0E9A5C9E49FD7F5AF
CBE9A3C9E9A0C7E99DC5EA9CC5EA9AC4EB9AC4EB98C8EA9DC9E2A1CFE1ADD4E5B9DBEBC6
F8FFE4F7FFE3D0E1B5CBDCAFCAD9B0D2DDBBF5FDE6FFFFF4FFFFF5FFFFF3FFFEEBFFFFF0
FFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFEFFFFFEFFFCFDF8FEFFF6FBFFF1EEFBDF
F0FFDCD2E7BCCDE5B5CFE4BBE5F4E1F1FFF2F7FFF6F6FFEFE4F2D8D4E1C3CFDBB7D1DCB4
DFE6BDD8DDB5D1CFA9D9D3B1594E3297896FFFF3DCFFF9EBFFFBFBFFF2F9FFF8FFFFFBFF
FFFBFFF9EEF2FFFCFDEEE5E6FFFDFDFFFDFDFFFCFDFFFEFFFEFDFFF9F8FDFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFFFCF4FFFFFCFFFFFDFFF3EEEAFFFFF3FCFBE9C2C4AEDBDFC6FCFFE4C7D6ADCDDFAD
D4EDACC5E196CAEA95C8E895C3E09DCCE6A5C7E29BCBE79DCCE5A3CDE5A9D5EBBAE2F8CA
F7FFDCF7FFD6F0FFC5E1F6B5D9EDB2CADBAED3E2C5F9FFF4FDFFFCFFFFFDFCFFF6F7FFEB
F7FFE4E5FCD0EEFFD9D2EDC0C1DAB3C4D9BADFEED9F9FFF4FEFFF8FFFFFAFFFFFAFFF5F6
FFF3FCFFF7FAFFEFDAD2BDA2EFD9CBE7D2CFF9E5F0FFF9FFFFFDF3FFFFEAF7F4D5D9D7BE
F5F1E8FFFDFFFEFBFFF9FCFFE9F7F7EBFFFE779A9400141330434A1C2630F2F9FFF5FFFF
74928A4E6E634F665CB3BFBDE8EBF0E5ECF6EDFFFFBADCE5365859698D8DB4DBE0D1F3FD
EEFFFFF5FFFF00000278796BF6FED7D5E9AEC3E598C6F09AC4EE98D6F5A5CDDA95D4D697
DBE09ED8DD9AD3DA96D2DD98DCE9A3E2F3ACD8EEA5CAE298C7E398C8E79BCBEA9ECCECA0
CAEA9EC8E89CC7E79BC7E59BC4DF98CFEAA5D4EDA9CCE7A4C5E09DC4E19FC9E8A5CDECA8
CAEBA6CAEBA4C8ECA2C7EDA0C6ED9EC4EB9AC3EA97C5E79AC9E2A1D5E7B5E5F7CFEBFCD8
F7FFE6F6FFE0D5E9B6D3E8B0D3E5B1D8E7BEFBFFEBFEFFF4FCFDF5FFFFF6FFFFEFFFFFF3
FFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFEFFFFFEFFFFFFFBFCFFF4F8FFECF8FFE9E0F2CC
DEF4C5C9E2ABC8E4A9C4DFACE2F5D9F3FFEFF7FFEDF6FFE7E1F1CACEDFB2C9DAA6CEDDA6
DEE8B3D2D9A5DCDEAFE2DEB8665B3DAB9C85FFF9E7FFFBF1FFFAFBFFFDFFFFFCFFFAF1F4
FFFBFFFFFBFDFFF7F9B8ACACFAEEF0FFFCFDFFFBFCFFFDFEFFFDFFF9F8FDFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F3FFFFFBFFFCF7FBF3F0EBFFFFF4FFFFEFB0B29CEDF1D6FCFFE6FBFFE1C9DAADD1E6AE
CFEAA7CBEC9DCBEF97CAEE97CAE8A0CDEBA5CDEC9EC7E698D0EBA4CAE4A7CBE2B6DEF4CE
EBFFD7E6FCCBD4EAACCDE4A0D2E6A7CADCAAD5E4C3FBFFF3FBFCF7FFFFFDFBFFF1F4FEE5
F8FFE1E2F8C7E3FEC7BCD9A1D3EEBBCFE6BAD9EAC6E4F1D3E7EDD3E9EBD5FBF8E5FFFEF1
FFF2EFFFFBF1FDF0CEFFF7D0FFF7E084716AFFF8FFFFF9FFFFF5E7ADA689BCBA93989572
958E7CCCC3BAFFFCF6F7F4EFF4FFFFE9FFFF8FBEB6517B79CAE3EA4A525D8A8490F5F4F9
B8CCC3DDFCECA1C2AF0018092E3837ECF1F7F9FFFFF5FFFFBED1D8809FA45184885D8F96
DDFAFFF2FFFF000505828E7AD6E3B8E1F1B3DAF1A3B7D982C0F397CEFEA8CEE39ED6E0A1
DBE8A3D8E9A3D1E59EC8DE96C5DC94C7E198CAE89ECBEBA0CDEDA2C9EB9FC7E99DC6E89C
C8EA9ECAECA0CDEDA2CDEDA2C5E39DD0EDAAD1ECA9C4E19FC7E4A2D4F1B1D0EEAEC2E0A0
C6E4A4C6E6A3C8E9A4C8ECA4C8EDA0C6EB9DC4E999C5E59AD9F1B3E7FBC8F7FFE3F5FFE4
E9FDD8DDF3C5C7DFA3CFE5A5D1E5AAD6E6B9F8FFE9FEFFFAF9F9FBFFFDFEFFFCF5FFFFF8
FFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFBFEFFF6F9FFEFE7F4D8E2F2CDCDE3B4
D1EAB1C4E3A0CBECA5C5E3A5E2F8D1EFFFE4F5FFE4F1FFD9E1F5C0D3E7AAD2E5A3D9EAA6
C5D18FDFE9ACDFE3B095936A554B30D3C6B5FFF4EDFFFBF8FAF6F7FFFFFFFFFEFFF4EEF0
FFFCFDFFFBFBFFF2F3A29090ECD9DBFFFAFBFFFAFCFFFAFDFFFEFFFAFBFDFCFFFFFCFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFFFDFFFFFEFBFFFFF6FFFFEFFAFEE59A9F81FEFFE4FCFFE3F0FFD6D3E7B6D8F1B8
C7E4A1C8EA9DC5EB94CCF29BCBEBA0CBE9A1D0EF9FC4E491DAF6ACD0E9AFC7DDB6DDF2D3
F5FFE6E4FACCD0E6A8C9E09CCDE2A1CDE0A9D8E8C4F1FAE7FFFEF9FFFEF9FFFFF1FCFFE8
F8FFDCD3EAB2D0EDADC5E4A1C5E2A2CAE3A9CCE0ADD3E3B6DDE5BCD7DCB4E4E4C0FFFFE3
FFFFEDBFBFA3A1A37190935CD6D3B0D1CABAFFF3F7FFF9FBFFFFEAA19F789DA16F909364
ACA98ACCC4AFFFF5E0FFFEEDF7FEF7E3FDFA98CBC4417A74CBFDFEA0C1C6000109ACA7AD
FFFFFAF5FBEFF4FFF363786745564C5E6869FBFDFFFCFEFFF7FFFFD9F4FD699EA4417D85
C1EDFAE7FFFF000C096C7B66F1FCD2C4D092D1E495CCED94C5F89BADE28AC3E199D5ECA8
C0DA93C9E59BD1EFA5D2F2A7CEF0A4C7EC9FC4E99CC2E89BC7EC9FC4E99CC2E79AC4E69A
C7E99DC8E89DC7E59BC4E29AC3E19BCCE9A6C8E5A3C4E1A1CBE8A8CAE6A9C7E3A6CEEAAD
C9E5A8C9E6A6C9E8A5C9E8A4C9E9A0C9E99EC8E89CC9E79DE2FABCECFFCDF7FFE3F2FFE1
D9EEC7CEE4B5C3DC9BCDE7A0CCE2A2D1E3B3F5FEE9FCFFFFFCFCFFFFFDFFFEFCFFFFFEFF
FFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFEFFFBFEFFF8FCFFF3F8FFE9D5E5C1CDE3B5C5DEA5
CBEAA7C3E599CCF1A1C6E7A0D4EEBEDEF3CAE3F9CADFF6BED7EDACCFE79DD0E797D5EB99
E8F8ADC7D28ED9DEA855532CA9A18AF9ECE3FFF9FBFFF3F7F9FBFAFBFFFFFEFFFFFEFAF9
FFFCFBFFFBFAFFF4F5C3AEADDEC8CAFFF7F8FFFAFBFFF9FAFFFEFFFCFDFFFBFFFFFBFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDEDECE7FEFEF2FFFFEFE0E2CAD9DEC0989E7CD2DCB7EAF6D0F4FFD9CFE5B4D0ECB2
C7E6A3C4E99CC3EB95C8F09AC7E99DC3E398CEF09CC3E591E8FFBCDCF8BECCE2BEE1F5DC
F4FFEBDCF1CACFE4A9CEE5A1D2E7A4E1F4BCF5FFE1FBFFEFFFFFF8FDF9F0FAFCE7D8E2BF
CFE1ADBFD896CAE69CD7F6AAC7E59BD5F0A9CCE2A1C9DB9DCAD59B9DA26C7D7D49919465
91A17AD2EABAC6E298CCE69CE6F8C6EAF4D9F1F3EEFFFFFAE5EBC9E0EAB6BBCB8C99A76A
CED5A9F1EFC9CCC09AEADAC0B9AAA7FBFFFFADDBD860ACA272D0C26BBFB2032D29818586
7F5F62FFE3E3FFF9EEAFAD9E4D625300180F849197ACB4BFEDF5FFEEFFFFAAD6E16DA9B3
488D948ECACB00171274816FF8F9D1CFD398D4EB99CAED91C3EB92C8F49FCCF6ACBAE49C
C8F1A5C2EB9DBDE698BEE99AC3EE9FC5F1A2C5F1A2C4EFA0C3EC9EC7EDA0CBF0A3D0F2A6
D1EFA5D0ECA2CCE69DC9E39CC8E3A0E3FDBCE1FBBCD3EDAED0EAADC4DDA3C9E2A8EDFFCC
E0F9BFDCF6B9D6EEB0CFE8A7CBE4A0CBE59ECCE69DCEE8A1DDF3B3DAEEB9EBFDD7E1F2D0
CFE4BDCFE6B2CBE4A0D2ECA3E0F6B5DFF1C1FBFFF3FCFFFFFDFBFFFFFBFFFFFCFFFFFDFF
FFFEFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFAFEFFF4FBFFEFF7FFE6CDDFB7CBE3AFCCE9A9
D2F4AAC2E895C9F49BC3EA9BC9E4ADCDE5B5CEE7AECEE9A6CCE79ACBE490CBE38BCCE389
C5D7857D8A44525923DADAB6FFFFEFFFF6F6FFF7FFFDF1FFFBFFFFF5FFFAFBFFFDFFFFFB
FFFCFAFFF6F3FFF8F7DEC6C4DAC0C1FFF8F8FFFAFAFFF7F7FFFEFFFCFDFFFAFFFFFBFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFEEDFFFFEFFDFFE8FEFFE5E8EFCDDEE6C19EA67FCED9B1E5F1C9F9FFDFC8D9AFC5D8AA
CFE7B3CCE8AECCE8ABC7E3A6CFE8B1C8E1A8D6EEB0CCE4A6F5FFD4E7FCD1D0E0C5E2F1DA
F8FFECDEEEC9D3E6AFD1E3A5CEE0A4E1F2BEF9FFE4FAFFECFDFFEFF7FAE5FEFFE6D2DFB3
D0E4A7D6F0A7CCE79AC3E090D0EC9FCAE49A99B0688598569DAC6B929E5E99A263D2DFA7
D2E7BCC4E1B3D2F0B0BCDA9ACDE4B6CADABFF9FFFAFBFFF6D3DEBCDAEAB9CCE0A3D8EAAE
D4E0AED3D9A9979564E8DEBBBFACA6FEF9FFE9FFFFA0DFD62E8676398C7C4D7F76CDD9D9
60424ABD949CEAD2D04D4A4344584D68837C172526323941F2F6FFEFFBFFDEFBFFDDFFFF
1E5D62437E7C000C07747C6DE6E1C3DCDAA9D7E7A0D0E996CDE897CFF09FBEE999C5F4A4
C2EE9FC2EE9FC3EFA2C4F0A3C2EEA1BFEB9EC0EA9EC1EC9DC5EB9EC6EB9DC7E99DC5E59A
C4E29AC7E29BCEE7A3D5EBADD6E4B3FBFFDDF2FFD6D0E1B5D1E4B7CBE1B2CDE3B2EFFFD2
F4FFD6F0FFCFE4F9BED6ECAECEE3A2CDE09ED0E49FD4E5A1D9E8A7CDDBA0D8E4B6D3DFB7
CDDAAFD5E3B2D0DFA4D0E0A2FBFFD4F6FFDBFEFFF6FFFEFFF7F4FFFFFBFFFFFAFFFFFDFF
FFFEFFFEFFFFFEFFFFFEFFFDFEFFFBFEFFF8FCFFF4FCFFF1F9FFEDCFDEBFD3E8BFDDF5C3
DEFABDC6E59FCBF0A0C4E99CC9E7A9C9E5ABCAE4A7CDE6A4D2E8A0D2E79CD1E198CDDD96
B7C383444D16868D63E3E6CBFFFEF2FFFCFFFFF5FFFFFBFFFEFFFFFAFFFCFBFFFDF9FBF6
FFFDFAFFFBF8FFF9F8D6BCBBDDBDC0FFF6F8FFFAFAFFF8F6FFFEFDFDFDFDFBFFFFFBFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0ECC4D5E2B7EBF8CCFAFFDBF3FFD1798557BCC79CCFDAB0D2DAB5D9E0BFFEFFE8FBFFE9
FEFFEDF7FCE8FDFFF0FCFFF3EFF5E7FBFFF3F4FBE9F6FDEBFCFFF1FCFFF1F7FEECF9FFEA
F6FFE0ECF6D1DAE6B8CFD9A7D7E0B3ECF4CDFCFFE4FCFFE8F4FFE2D2E4BCCADEADC5DAA1
DEF5B1D1E99FD5ED9FCDE5998DA55B768D47A4BA79D0E6A6D2E8A8D1E7A6CBE29EC7DCA3
DDECCDE0EFD8E5F3D9E7F5DBE7F4E0ECF7E9F6FDF5FBFFF6E6F0D8E2EDCDECFBD2E7F4C8
D0DEADD8E5B0D2DBA4A6A880E0DACEF1EBEBF9FFFFEDFFFBDBFAF2CEEFE8EDFFFFF2FFFF
F8FFFFA4A8B33B444D0411177D8C8FF7FFFFFCFFFFBCB9C0736D7B9E9DADF7FFFFE7FBFF
CBE8EE6B878A0818173F423BAAA391EBE2C3DAD6A7CCD093EFFAB5D2E798B9DA83D1F7A0
BFE697C0E69BC5EBA2CBF0AAC9EEA8C2E7A1C4E8A0CDEFA5C2E497D2F3A4D0EFA3BEDC92
CFEAA5D3EDACC5DFA2E5F4C9EDE5DAFFFBFBFFFCFAE9E6DDE4E8D9E7F3DBE8F9D9EEFFDD
E4FECFE7FFCBD4EBB3CADEA3D8E8AAE1EDADDAE3A4D9DE9CC1C27C9B9C58959559B9B882
DAD8A8E8E7BBEDEBC4EBE8C5DFDBC0A8A390C4BDB7D8CFD0C4BBC0EDE3EBFFFBFFF7F0F7
FFFDFFF0EEF9FFFEFFFFFFFDF7FAF3FEFFF8FDFFF7F7FCF5FCFFFBEAF1EADEE8DDF8FFF1
ECFBDCD1E4B7D7EBB6C1DB9EC3E6A4D7FAB8C7E1A4C1D49CDDE7B5D9DBB3E4E1BE9E9A7D
67654ED3D5C0F4F8E9F8FEF2FBFFFBFBFFFDFBFFFEFAFAFAFFF9FDFFFCFFF8FEFCF9FFFD
FEF9F6FFFBF9FFF5F5DCC2C3E4B9C2FFF2FAFFF2F1FFFFFBFFFEFDFFFEFFFFFFFFFCFCFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4FFD0D7EAB3DBECB6F5FFD0A7B582B5C191CFDBADCAD2A9E0E6C4D9DCC1FFFFEDF6F4E7
FFFEF8FFFDFDFFF9FDFFFCFFFFFEFFF6F6F8FBFBFDF9F9FBF2F2F0F6F7F1FEFFF2FFFFEC
FFFFE4EDF3CDD7DEB4D2D9AFDEE4BEEFF5D3FAFEE3F9FFE3F7FFDFC5DDABD8F0B6CFE8A7
CCE39B374D02455A0F93A75FCFE2A0C5D99AD8ECB1CFE4ABBBD399C7E0A6D1EBACD8EEBD
EBF7DFF2FAEFF7FEF6F8FFF7F7FEF7F7FEF7FBFFFAFBFFF8FBFFF4F4FDE8FBFFEAF6FFDE
D7E4B8D4E2AFDFEDB8D3DEB3FAFBEDFFFEFBFBFAF5F6F9F2FBFFFAF1FEF5F1FFFFE4FFFF
E3FFFF72979D31545A19363E364B50778286FCFFFFFFFEFF9B919A443947EAE7F2FEFEFF
F7FBFFF8FFFF00030402080405090052563FCFD3AEE8EFBCC9D597C5D58CE1F7A5C5E18C
D7F8A7CDF0A0C7E99DC7E99FC8E9A2C7E6A0C8E89DCCECA0D9F8A8B6D683CAE797D5F1A6
C1DC97C2DC9DD9F2B9F9FFE4FFFDFDFFF5FFFFF7FFFFFDFFFFFFFBFCFFF2F4FEE6F8FFE6
ECFCD5C9DDACD9EBB7D7EBB0BACC8ED1E4A2C1D1905C67237F803A64611A595515645F27
68623268603B685F42655A46B2A89CFFFDF4FFFCF8FFFCFAD4CAC9F6ECEBF6ECEBFFFCFF
FFFCFFFFFDFFFFFEFFF9FAF5FAFDF4FCFFF4F8FBF2FCFFFBF9FDFEFBFFFFF5FBFBF9FFFA
F9FFEFF4FFE1F4FFD7D1E8B0C2E29FB7DB95E7FFC3FCFFD6FFFFDFFFFFE6FFFCEF685952
AFA5A3FFFEFBFAFAF8FCFFFDFBFFFDDEE8E0F9FFFAFFFFFBFFF8FEFFFAFFFBFFFFF8FFFD
FFFEFDFFFCFBFFFBFAEED5D8F6C4CFFFF1FAFFFAFAF9FAF5F8F4F5FFFEFFFFFDFFFCFAFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C3D49DC4D59EB3C18CC2D09DC4D0A0F7FFD5F7FFD6DDE3BFDBE0C2FAFCE6FFFFF1FBF9ED
FFFEFAFFF6F7F8EFF2FFFDFFFFFEFFEBEBEBD4D4D4FBFBF9E0E1DCC2C3BBDBDECDA3A78E
DAE0BECBD1ABCDD4AAE9F0C7FFFFE1F5FADAD2D6BDB2BB9CD8E9BF839A668A9F66CADE9F
97AB66AEC27BD6E7A1D9E9A8D5E4A9D5E3AEE6F3C5E5F4C9EAFBCFF0FFD6DFF2C5D9EBC5
F4FDECFAFFF8FCFFFBFCFFFBFCFFFDFAFFF9FAFFF9FCFFFAFCFFF6F7FEEEFCFFEDFCFFE6
D6E0BBC6D1A6DCE8BAEDF7D2F6FAECFEFFFDFCFFFBEFF9EEF4FFF8EAFFF4DDFFEFCDF9EC
97C9BE437870467875A2D0CD7A9E9C0017144B5E586C726EFEF5F6C9BABF77686D43383E
ABA5A9F1F2F4293332192D24355240587B5D40653C9FC491D6F3BBD7EDAFD6E5A4D8E89F
BFDD87BDE084C2E48DC9EB95CCEE9ACAEA97C8E895C9E994D1EF97CCEA92CEEC96CBE898
D3EDA6CFE8A7CAE1A9EBFFD8F2FFF8EFFFFCF2FEFAF8FFFAF8FBF2FAFBEDFFFFEDFFFFE6
E4E4C2DBE1B58F9B6964793E8AA96594BA7191BD6EC4E99CDEEEA7DCDE9DDCDDA1DFDFAB
DDDCB0E7E4C1FAF6DBFFFDEAFFFFF1F8F1E9F6EFE9FFFDFAEAE2DFDBD3D0FFFDFAFFFDFD
FFFBFFFFFDFFF9F9FBFEFFFAFEFFF6F6FAECF2F8ECFCFFF8F6FBF5FBFFFBF7FFF8F8FFF3
F8FFEAF6FFDDEBFDC9D4ECB0D6F5B2BEDB99EFFFC9FFFFD8F8F3D3FFFDE8F8E6D8AC9992
FFFBF8ECE2E1FFFEFBFFFFFBEAEBE6FFFFFAFFFFF8FFFBF7FFF7FDFFFAFFF5FEFBF8FFFD
FFFDFCFFFCFBFFFBFAF7DEE1B07E89FFE2EBFFFBFBFFFFFBFFFEFFFBF7F8FEF9FDFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DBEAAFBFCE95909F68BDC997F3FFD1F4FCD3F0F6D4E8EBCEFFFFECFCFAEBFFFFF4FFFEF8
FBF3F0FFF8F6FFFAFBB7B1B1E2E1DFB1B1AFD8D8D6F6F7F2F4F5EFFFFFF6EDF0DFC8CCB3
949A78939973A6AD84C5CBA5D5DBB9D0D5B7CFD3BCD7DDC3E2F1C8C9DBA9CDDEA7D4E6AA
E1EFB1D6E5A4D8E4A6CBD69ED3DCADD5DDB4EAF4D2F6FFE3FBFFEAF3FFE6EBFADDF9FFED
F8FFF3FBFFF9FCFFFBFCFFFDFAFFFBF8FDF9F8FDF9F9FEF8FCFFFAF3F9EDFCFFF1FCFFEC
DCE5C6C7D1AED5E0B8E9F0D1FFFFF8FCFAFBFFFFFBEFF7ECE9FCE9EEFFF3E2FFF289BAA4
578E79B3EEDC7FB7AA7CAEA383ABA28AA8A0A7BBB2394038968F89FFF4F0FFF5F4C6B4B4
4A3C3C817D7C000804365045ACD6C247795C4F87624D825681AB7B83A16F97A977A6B57A
D6EB9ED6EE9AD6EF9ED5ED9FD1E99DCEE69ACEE698CEE998B8D480D0EC98D2EF9DC5E196
D2EDAACBE5A8C7DFABF2FFE3ECFFF0F0FFFBF4FFFBF4FFF4E4EADEEAEBDDD3D0BD99957C
D7D6B7ACB189CBD7A7E6FBC2BADA97B2DC92CAFBACC0E99DC8DB9BD0D89FD7DEAAD5DBAB
D0D5ADE4E5C6FEFEE6FFFFEFFFFDF0FFFFF6FFFFF8F9F6F1E5E0DCE0DBD5F7F2ECFFFEFB
FEF9FFFFFDFFFAF8F9FFFFFAFEFFF4FDFFF0FCFFF1F7FFEFF9FFF2F9FFF3F2FFEBF5FFE8
F7FFE1D9F0BCC7DFA1D1ECA9C9E3A2CFE7A9E9F6C1FFFFDAFFFFE1FFF9E5836D62E4CDC7
FFF8F7FFFAFAFAEFEDFEF4F2FFFDFAFFFDF8FBF2EBFBEDEAFFF8FDFFFAFFF4FDFAF4FFFA
FFFBFAFFF8F7FFF7F5F3DADDFFD0DAFFF1FAFAEEEEFDFEF9FFFEFFFFFEFFFEFCFFFEFCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D1DFA2919F6496A36DE7F1BFE7EFC6FFFFE3FCFFE5FFFFEDF6F4E7F6F2E9FFFEF8FDF5F2
FFFDFBFFFCFBB5ABAA9C9492F1F0ECFFFFFBF4F5F0FFFFFBFFFFFAEFF1E6FFFFF1E2E6CF
D7DCBC9EA4807F8561A9AF8BEAEFD1FFFFEAF4F7E4DFE4CED6E0BDE5F2C6DCE8B6C0CD97
DAE3AAE2EBB2EDF4C0F7FDCFF0F4D1E5E8CDEEF1DEF8FCEEFEFFF8FCFFF8F3FBF0FBFFF8
FCFFFAFCFFFBFCFFFDFCFFFDFAFEFDFBFFFEFCFFFFFCFFFFFCFFFDFCFFFAFCFFF6FCFFF1
F1F9E2E9F2D7EAF3D6EFF1DCFFFAFAF9E8F0F8EEEDFFFFF6EFF8E5E1F5DAE5FFE9113E1F
699B7EC1F7DF81B4A1C3EDDFE5FFF7F2FFFDEEF8F087877DABA195FFFCEDF8E4D9FFFAF3
C9BAB50600000107030B22186E978574A8914E8B6C3D7957B8ECC69ECBA44B6E465C7146
D7DFACD6D6A0CFD29DD4D8A5DDE4B0E0E9B4D7E2A8C9D99AEDFFBEC4DB95C5DE9AC6E3A1
C3DFA5D3EFBCE0FDD1EEFFE4F9FFF3F2F5ECF7FDF3F7FDF1D6DCCECAD1C1EAF3E0F9FFED
DAE7C9DBEBC6D2E3B7CEE2AFDEF6BCE8FFC0D9F4AFCCE2A1D2E3ACDDE9B9E9F4C9EAF5CD
E3EDCBEFF5DBFDFFEEFDFFF1FDFFF4FFFFF8F8F8F0FFFFF8D4D1CAFFFFF6F2EFE6FDFAF5
FFFCFFFFFDFFF5F4F2FFFFF6F6FAE9F9FEE8FCFFECE1EBD2EBF8DEF4FFE6F3FFE2ECFFD8
E6FECACDE7A8BCDA92D2F0A8CAE3A2D5E9AEE5EFBDFFFFDCFFF2D7C1AC99785D54F2D6D3
FFF8F6FFF7F6FFFAF8FFFBF8FFF3EFFFF1EAFFFAF3FFF3F0FFF4FAFFFAFFF9FFFFF6FFFC
FFFEFDFFFCFBFFF8F6F4DBDEA2737DFFE7F0FFFBFBFEFFFBFFFEFFFBF7F8FCFAFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DDE7AAC7D296E6EFBA909869A3A983FFFFE6F9FBE6FDFBEFFFFEF8FFFAF78B8283CCC3C4
F7EDECC2B8B7EEE4E3FFFDFAF6F5F1FFFFFBFFFFFBF3F3F1FAFBF6FFFFFAF6F8EBF7FAE7
F3F7DCDEE3C3D9DEBEF0F5D7FFFFECFFFFEFF6F8EDF2F4E6E5EBD1E0E7C5D5DCB3E4EBBF
D3D9ABFEFFD4FFFFDAFFFFDEFFFFEAFFFFF1FFFFF8FEFDFBF8F8FAFFFFFFFBFCFEF9FBFA
FCFFFDFCFFFDFBFFFCF9FDFCF9FDFEFBFFFFFCFFFFFCFFFFFCFFFFFCFFFDFCFFFAF8FEF4
FBFFF3FCFFF1FCFFEFFCFDEFFFFAFEFFFAFFFFFDFBF1F3E6F8FFEDB1CAAA466F4785B88F
AAE2BBB4EDCA80B599DCFFF1E3FFF0F2FFF7FCFFF8E4E0D5544B3AB2A592FFFCEDFFF2E5
FFF8F0FFFEF802040016231C0721189CC0B2C8F7E33569524B82659AD1B1B3E9C5BCE5BB
B3C1909595616668365B5F2D747B48959E699EA97196A467BBCB8CD4E7A7E5FBBBCAE2A6
C8E0ACE8FFD3EEFFE2F7FFECF8F9EBFFFEF6FFFEF8E2DFD8DBDBD3FEFFF6FCFFF6F1FAE9
E5F1DBD4E1C7C8D3B3CEDAB4E4F0C2F1FEC9ECF6C1DDEAB5D1DEB3D7E5C1EEF9D7FAFFE7
F8FFE9FBFFEFFCFFF3F9FCF1FFFFF8E6E6DEFFFFF8E0DDD6A29F96F7F5E9FFFFF4FFFEF8
FFFEFFFFFDFFFFFFFAFFFFF4FFFFEFFEFFECF8FFE4D2E0BDC0D0ABD7E9C1E7FDCFD2EBB4
C9E6A6CEEEA5C5E697CBEA9ED8F1B0D0E1ABEAF1C5FEFCD6B7A98F675241FCE1DAFFF7F4
FFF7F6FFF7F7F2DDDCB19C99B29D98A7908A6A4F48806763EFD6DCFFFAFFF9FFFFF6FFFC
FFFFFDFFFCFBFFFBF9F7DEE1A0717BFFF1FAFFFBFBF3F5F0FCFAFBFFFEFFFFFEFFF8F8FA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D6DEA2E7F0B7D6DDAA4F542BA3A786FFFFEBFFFFF3FFFCF8FFFDFD898085ADA4A9FDF4F7
F8EEEFFFFCFBFFFCFAFFFDFAFDFCF8FFFFFDF3F3F3FFFFFFFFFFFFFDFDFBFFFFF8EAECDE
FBFEE9E6EAD1DCE0C7EAEDD8FDFFF1FFFFF6FFFFFDFFFFFBFFFFF3FBFDE8FFFFE8F7F8D9
FBFBD96B6B494C492A5F5B422F291B7E7771F4EBEEFFFCFFFFFCFFFFFAFFFBF8FFF9F8FD
FDFFFEFCFEFBFBFDFCFBFCFEFCFDFFFCFDFFFCFDFFFCFDFFFAFBFFFEFFFFFBFDFCF5F7F4
FCFEF9FEFFF8FEFFF6FEFFFAFEFFFFF6FBFED7E3D9E7FDE88FAE8C1C4A1C86BF8CADF0BA
B8FFCEA2EABC77B590A7DABBD8FBE3EEFFF3FBFFF6FFFFF3B9B4A19B957FF4EFDCFFFCED
FFFFF6FCF9F45C5656322E2F4D4B4E000102D2E1DCC7E5D94F7F69458467AAF6D2A3E7B6
CAF2ACCEE698C8E096CDE49CDAF0A8D6ECA4B8CE8598AC645D7227BDCE87EBFBBAD1E0A5
D1DDADD0DBB3CDD6B9FFFFEFFFFEF6CCC1BFA29696D2C6C6FFFBFDFFFCFDFFF6F7FFFCFD
FFFDFAF7F0E8FFFFF0FFFFECFFFFE6FFFFDEFFFFDFFCFFDEF6FFE3F1FEE4F9FFEDFBFFF1
FBFFF3FCFFF4FEFFF8FAFDF4FEFFF9FFFFFAFBF8F15C5751D5D1C8FFFFF4FFFEF4FCF5ED
FCF6F6FFFCFBFDFAF5F8F8ECFFFFEDECF2D6CAD4B2DAE9C0A2B386B1C592D0E9B0C4E1A1
BCDC93CEF1A1C7EA96C4E596C4DE9FCBDDABEEF7CCFFFFE1B0A48E645244FFF1E9FFEBE7
FFF8F6EED9D8846F6C6F5A556C534E8E736ADFC1B7AA8D89C4ABAFFDF2F8F8FFFFF4FFFA
FFFEFCFFFCFBFFFAF8FAE1E46B3C46FFDCE5FFFBFBFEFFFBFFFEFFFFFEFFFCFAFDFAFAFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D7DFA6D3DAA4A3A97BEBEFCAFFFFE8F7F6E4E4DFD99A9494A1979FFFFBFFFFFBFFFFFCFF
FFFAFEFFF8F7FFFCFAFFF7F4FFFFFDFBFBFBFFFEFFFFFEFFF8F7FCF7F7F9FFFFFBFFFFF8
FFFFF3F4F7E4ECEFDCF3F5E7FDFEF6FFFFFDFFFEFFFFFEFFFFFFFDF0EDE6FFFFF3E2DFCE
C4BFA9D7D2BCFFFFEAFDF6E6DED5CECDC3C2F3E8EEFFFBFFFEF3FFFFFBFFFFFCFFFFFDFF
FEFEFEFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFCFFFAFAFFFBFCFFFEFFFFFEFFFFFEFFFF
FEFFFFFDFFFEFAFCF9FEFFFFFAFEFFF9FFFFF8FFFAD4EAD3C3E1BDB2DCAEAFE4AEB1ECB4
A5E4AFB9F4C680B48D5C8364D3E9D4E8EEE0A89F968A8076585242A5A492FFFFF1FEFFF4
FDFEF6FFFEFB3C313525141C4C3841FDECF4070105D0DBD7CCF1E078B2993C8C6955A87A
A9EDB4B6F1B1BAF2B5B7EDB1BAECAFC1EFAFC6EFADC6EBA5C4E49B79954B809550C1D193
DBE5B0B3BA8E808461827D69C1B4AEFFF2F5FFFAFFFFFAFFFFF8FFFFFBFFFFFCFFFFFDFF
FAF5FCFFFDFFFFFEFDFBF6F0FBF7ECFFFFEFFFFFEDFFFCE9FEFFF3FAFFF3F9FFF4FBFFF6
F7FAF1F7FAF3FFFFFBFFFFFBFFFBF8FFFFFAFFFAF7A9A29CFFFDF6FCF3EAFFFDF4FFFDF6
D5CDCBD4CFCCB4AFA99B998CBABCA79EA4887C8661CEDEB1A8BA869BB377C4DE9DD0EEA8
C9E99DD0F3A3C5EB96C8EA9DC8E4AADEF1C3D9E3BEFFFFE4D3CBB69486798D7A74988581
9C8887B6A2A1D9C6C2FFEBE6FFF2EAFFF8EDFFE8DDA3857DAA9195F8EDF3F8FFFFF3FFFB
FBFAF8FFFBF9FFFAF8FBE5E7E1B3BDFFF2FAFFF6F5F3F5F0FFFEFFFFFEFFF6F6F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E7EBB97C7F52F6F8D1FFFFE4F2F0DBBBB7ACB3AEABFFFAFEFAF3FBFFFBFFECE2EBFFFBFF
FFFCFFFCF4F2FFFDFAFFFEFAFFFEFFFFFEFFF6F5FDF3F2FAF9F8FFF2F1F7F5F5F5FFFFFB
FFFFF6FFFFF4FEFFF3FDFFF4FFFFFBFFFFFFFFFDFFFFFCFFFFFCFFFEF7FEFFFAFADAD3CD
FFFEF3FFF9ECFFFBEFFFFDF4FFF7F3D8CECFDDD2DAFFF7FFFFFBFFFFFAFFFFFCFFFFFDFF
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFEFFFEFEFFFEFEFFFEFEFFFEFFFFFEFFFF
FEFFFFFEFFFFFEFFFFFFFFFFFFFCFFFFFCFFFFFEF8E9EAD8DCE5C6D6E6BFB4CE9FD3F0C0
CDECC0E5FFDBF7FFECFFFFEFFFF1E6CCAFAB6C40419B7475FFFBF3FFFFF6FAFFF6F7FCF5
F7F9F6FFFEFF786B72745F68F8DCE8E6CAD6FFF9FF010000C2D6CABFE9D377B79538886B
27897C8DF6EF83E7DF86E3D868C1AD3383683179537FBF8DBAF2B5B9E8A4C6EBA5D0EBA6
CDE2A1CDDB9EDCE3AFFFFFDFFFFAF6FFF8FFFAEDF7FFF9FFFEFEFFF8FFFFF4FFFFF2FFFF
F2FFFFF0FFFFEBF6FCFBFFFFFCFAFFFBF2F5FFFAFDFFF7F7FFFFFBFEFFFAFEFFFBFEFFFB
FFFFFDFFFFFDFFFEFDFFFEFDFDF4F5FFFDFBFFFCFA564B47CEC1BB8D80788A7B74BBAEA8
FFFCFAECE7E4FFFEF8FEFCEFFFFFECE6ECD0D8E2BDD2DFB1D2E3ACC5DB9BC2DB97CBE99F
CFEFA3C7E99CC2E799C8E9A2CAE6B3D0E5BCE3F1D0FEFFE9FFFFEFFFFDF2FFF7F1FFFAF7
FFFBFAFFFBF8FFF5EFFFF5ECFFFAEFFFF2E4684B3D6A4E43CBB2B5ECE1E7F8FFFFF5FFFD
FDFCFAFFFDFBFFFCFAFFF5F7ECBEC8FFF0F8FFFCFBF5FAF4FFFFFFFFFEFFFFFFFFFBFCFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DCDEB7DEE0BBFFFFE2F1F1D9C4C1B2FFFBF5FDF7F7FFF8FFFFFBFFFFFBFFFFFCFFFFFCFF
F6EDF0FFFDFDFFFDFAECE7E4F7F5F86D6C7237363E04020D28263105040A4B4B4DFFFFFB
FFFFF8F8FAEDFAFCF1FFFFF8FFFFFDFDFCFFFAF8FFFFFBFFF3ECFEE0D8E7CEC7CFFFFCFF
FEF5F0FFFDF4FFFDF4FCF1EBE0D5D3E8DEDFFFF9FFFFFBFFFFF8FFFFFAFEFFFDFFFFFBFA
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFEFFFEFEFFFEFEFFFEFEFFFEFEFF
FEFFFFFEFFFFFEFFFFFFFEFFFDF7FBFFF6F7FFFEF6E1DECBC6C6AAE3EBC6E2EFC4CBDCB2
CBDBB6FBFFE6FFFFEBF7EBDDFFF7F1F4C8C7874F529D6F72FFF2F1FEFFFBF9FBF8FFFFFF
FFFDFFFBF4FB42353E73626CFFEDF6D8C3CAA6979A8984810009005E7563C8EAD193CAB5
61BAB41981802B8D8C2A89830C645684D6BF67B190296A3F48814A85B577CBF2B1BBD898
D0E5AAE2F0BBD1DAADF8F7DBFFF2F2FFF8FFFFFCFFFBFFFFEEFFFFCBEAECA1CBC98FC0BD
C5F6F3E0FFFFE7FFFFE3F7FEF9FFFFFFFCFFFAE9FBFFF9FFFFFDFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFDFFFFFDFFFFFCFFFFFCFDF5E9EBFFF6F6E9DBDAC5B6B3FFF0EBFFF6F2FFF7F2
FFFCFAFFFDFAFFFEF8FAF8ECFFFFEFDDE1C8D6DEB9DAE6B894A66CBCD190D8F2ABD4F0A6
CBE9A1CEEDA7CEEFAAC6E5A9CDE8BBD1E6C5E2F0D6F9FFECFFFFF3FFFEF5FFFAF7FFFDFB
FFFCFAFFF7F4FFFDF6FFFDF3F5E5D8B39D8F937867CEB2A7FFEBEEFFFAFFF8FFFFF2FFFA
FCFCFAFFFDFBFFF9F7FCE8E9E7B9C3FFF2FAFFFCFBFCFFFBFFFFFFF5F5F5FCFCFEFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F3F3D7F5F5DBE2E1CCFFFFEFEFECE3FFFDF8FFFCFDFFFDFFFDF8FFF4EFF6FFFDFFFFFAFF
FFFDFFFDF9F8FFFAF7B6B2B1010002818086F5F4FCFFFEFFFFFEFFF4F3F8B8B8B8F7F8F3
FFFFF6FFFFF3FFFFF4FEFFF5FDFEF9FFFFFFFFFEFFF8F6FFFFFCFFDED7E9E0D8E3FFFDFF
FFFDFAFFFEF6A9A097CDC4BDE9E0DBFBF1F0FFFBFFFFFCFFFEF5F8FFFDFDFFFEFBFDFCF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFEFFFFFCFFFFF4F9F2FCFFF3FEFFEDFCFFE6FAFFE0F1FFDAEEFFD8
ECFDDBF9FFEAFDFFEEFFFFF1FFFAF3FFF4EFFFEFEE745050B4A8A8FFFFFFEFEAF0FCF2FA
FFFBFFFFFBFF090007746D74EBEBEDFEFFFFFCFFFBA1A69F8B8D824240336E66598F9782
BDE5C2A6DDB3B4E9BFBFF2C9C0EFC5B8E6B7AFD9A7D3FAC388AB7166854CCAE2B0D2E4BA
D3E2C3E1EDD7F0F8EDFFFFFDFFFAFFFFFBFFF6FAFBC4DBD5ADDBD097D7C642947D126C53
3B947E4A9B8ACBFFFFE0FFFFEDFFFFF6F9FFF4E6FFFFF5FFFFFBFFFFFDFFFFFDFFFFFDFF
FFFDFFFFFCFFFFFCFFFFFBFFFFFCFDFDF1F3FFFBFBFFFBFBEADADAFFFAFAFFFAFAFFF8F5
FEF4F2FFFDFAFFFBF7FFFEF5FFFFF3F9FCE7FEFFE4F5FFD5A9B881CCDEA0DEF5B1CDE6A2
BED796C6E0A3D3EEB7D6F0C1DDF5D1DEF2D7E9F6E2FAFFF2FFFFF8FFFEF9FFFCFBFFFEFD
FFFEFDFEFAF7FFFDF7EBE3D85F514493806FFFF9E6FFF9ECFFF8FAFFFCFFF4FFFCF0FFF8
FFFFFDFFFDFBFFFCFAFFF0F1AE808AEFC7CFF7EDECF7FCF6FFFFFFFFFFFFFFFFFFFBFCFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F2E3FEFCEDF7F5E9FFFFF6FFFFFAFBF7F4FFFEFFF6F4F7FFFAFFFFFEFFF8F3F9FFFEFF
FEFAFBFFFEFF6E6A6931302E7E7E7EFFFFFFFFFEFFFFFEFFF4F3F8FFFFFFF9FAF5F9FBF0
FFFFF3FEFFEEFFFFEFFFFFF1FEFFF5FAFBF6FCFCFEFFFEFFCECCD9CAC6D4FFFDFFFEF8F8
FEFAF1D2CCC08E887CDBD4CAFFFDF8FFFDFAFFF8F9FFF9FBFFFBFDFFFEFDFFFFFAFEFFFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFFFFF6F8F3FFFFF6FFFFF1E2E1CCFFFFE6FFFFE2FBFEDFFFFFE6
FEFFECEBEEDBF3F1E4FFF7EEFFF9F4F0D3CFB78F8D674846C9BFC0FCFAFDFFFBFFFFFAFF
FFF0FAFFFAFF29242A6D7172EBF7F3EAFBF3F4FFFBE9F3E8ACA9A0A5948C42231E331E0D
737C51E4FDC4C9E2ABC6E1AAC6E1ACCCE9B1D6F5BCB4D69AE2FFCB53784265895B87AB87
C5E6D1D5F6EDE9FFFFEDFFFFF8FFFFE8F3EBF1FFFACAF1DC95D0B25FA986247C543F9E74
22805B1970508AD2BCADE5DAE6FFFFF0FFFFF9FEFFFFFCFFFFFCFFFFFDFFFFFDFFFFFDFF
FFFDFFFFFCFFFFFCFFFFFCFFFFFAFBFFFCFDFFFBFDEEE2E4FFFBFDFFFAFCFDEFEFFFFBFB
FFFDFAF8F0EDFFFEFAFFFEFAFFFDF4FFFFF1F0F4D9DAE2BBEDF9C7DAE9B0CEE0A2D0E4A7
CCE1A9C8DCABD6EBC2EEFFE1F3FFEEF1FFEFF6FFF3FCFFF8FFFFFBFFFDFEFEFCFFFFFEFF
F3F3F3FFFFFDF3F0E9DED7CD6B5D50D0BDACFFEFDCFFF8ECFFF4F6FFF8FDF6FFFEF4FFFD
FFFFFDFFFDFAFFFDFAFFF9FAEEC3CCFFF2FAFFFDFBF6FBF5FCFCFCFBFBFBFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFCF8FFFFFBFFFFFBE9E8E4FFFFFDFFFFFDFFFFFDF8F8F8FFFEFFF5F5F5FFFEFFFAFAFA
F4F2F33C3C3CACAAABFFFFFDFFFFFBFFFFFBEBECE7F9FAF5FFFFFBF1F2ECFFFFF4FFFFEF
FFFFECF3F7DCF1F6D8FFFFEAEEF1DCC3C5B7B9BAB2CFCFCDF7F7F9F7F7F9FFFFFBFFFFF6
FFFFEEBAB7A4E0DDCACCC9BAF1EAE0FAF5F1FFFBFBFFFDFEFFFEFFFFFFFFFEFEFCFDFDFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFFFBF8F0DED4D0BAAFC3AC9EFFEFDEFFF9E8FFF7E7FFF0E2
FFF1E7FFFBF4FFFAF8FFF9F8E1C5C4856362C19997E9CAC7F7E9E9FFFDFFFEF3F9FDF0F7
FFFAFFF8EFF409090B65706CDCEFE9F0FFFDE9FFF3EBF7EDFFFEF8FFEEEACFADAC997C74
383516A3B085BBCA9FBCCEA489A376CAEAB9B6DEAAC9FAC2A5DFA5A8E9B176BF8A38855B
7BCBAE7DD0BE79CCC469B5AB7BB39A8EBD9B6EA07B00350B0F49198BC794B0EFBAB7F7C3
ACEBBCA2DFB63F7858265A4483B3A7CEF8F6DEFFFFE9FFFFF9FFFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFDFFFFFDFFFFFDFFFFF9FBF9F3F5FFF9FBFFFCFEFFFDFFFFFDFFFFFCFFFFFDFD
FFFEFBF6F1EDFFFEFBFFFCF9FCF9F4FFFFF4A0A28CC1C7A5EFF8CBCEDBA6C9D8A1E8F6C3
F3FFD7E5F3D0E4F2D9F8FFF3F8FFF6F9FFF8FCFFFAFFFFFDFFFDFFFFFCFFFFFCFFFFFDFF
FEFDFFFFFEFFFFFEF9AEA59C564639FFFAECFFF8E6FFF2E6FFF4F6FFF9FEF7FFFFF4FFFD
FEFEFCFAF5F2FFF7F4FFF9FA936871E8C0C8FFFAF8FBFFFBFEFFFFFDFDFDFAFBFDF9FAFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFCFAFFFFFEFFFEFCFFFFFEFFFFFFFFF5F5F3FFFFFDFAFBF6FDFDFBF9F9F7FFFFFF
000000797B7AFFFFFFE0E0DEFFFFF8F9FBF0FFFFF6FFFFF6FBFDF2FFFFF3F8FBE6DDE1C6
484D2D676D498D936DACB28EC8CDAFE5E9D0F8FBE8FFFFF4FEFFF8FEFFF8EBEFE0F4F7E2
FEFFE8FBFBE1FFFFE8FFFFEC8C887CD5D2CBFFFEFDFFFEFFFDFCFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFEFBFFF5F06C4F476D4D427753476F473D61392F744D46694843
6C504FFEE5E8FFF9FB574345644F4EECD4D0FFEDE6FFF9F3FFFBF8FAF2F0FFFDFBFFFDFD
FFFAFAFFFFFD5C615D65706CD1E0DBF4FFFFDFECE5FBFFFBFFFEFBFFFBFAFFF8FAFBE6E1
7B7360C8C8ACE7EACFF6FFE0D4E4C0809971CCEEBCC0EBB5CBFFC5C5FFC8A9F0B497E5B1
77CAA0004B2A00503833866C5EA27993CF9CC8FFCCB9F0B6B0E4A4B9EAA8B3E09DC7F4B1
C6F2B5B6E1ACCEF9CEE3FFEF1A4A34427266DDFFFFE0FFFFF7FFFFFFFFFFFFFFFFFFFFFD
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFBFCFDFBFCFFFFFFF6F4F7FBFAFFFDFBFFF9F7FA
FAF6F3FFFEFBFFFDFDF9F3F3FFFEFBFFFCF3646553DBDEC1D6DDB4D3DCADDFE8B9F4FFD4
FCFFE4FBFFEEF7FFF4FBFFFBFBFFFBFCFFFBFEFEFCFFFCFFFFFBFFFFFBFFFFFBFFFFFCFF
FCF9FFFFFEFFF3EEEBFFFDF6604E44412A1CFFECDAFFF7ECFFF8FAFFFCFFF4FFFCF2FFFB
FDFFFCFFFCF9FFFAF7FFF8F8CDA2ABFFE2E9FFFCFAF5FCF5F9FBFAF7F9F8FEFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F2FFFFFDFFFFFEFFFFFEFFF6F5FAFFFFFFFCFCFAFAFCF7FEFFFAFAFDF6F6F8F3646663
686A69BEC2C1F5F6F8FEFFFDFFFFF3F9FCE9F3F6E5FFFFF1FEFFEEFFFFECCBD0B2B9BF9B
9BA279C8CFA3DBE3B4CCD4A5D3DAB1F9FFDDFFFFE8F2F7E0F1F9E4FCFFEDFCFFEAD8DFC0
CBD1AFDFE3C0BEC1A2FFFFE8949283D6D6CEFFFEFFFEFDFFFDFEFFFCFFFFFBFEFFFCFFFF
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFBFFFFFBFFFFFBFFFFFBFFFFFB
FFFFFDFFFFFDFFFFFDFFFEFABBA79E614539F3D1C5FFEEE2D6AEA4C29993D3ABA9B69495
A78E927A676D73686EA49EA0C9C4C1FFFFF6FFFFF1F4EEE0F9F0E7FFFEF6FFFFF6EAEDE4
F6FDF5F9FFFA6A716A717672FFFFFFFFFDFEFFFDFFFBF5F7F6F2F3FBFBFBF7FBFAFEFFFB
D7CEC71104004E4438867F6DFFFFEAB6BA99A7B385C6D7A0C0D997BCDA94C9EDA5CAF1AE
BEE7ABBFEAB5D4FFD2B3E1B3B8E8B4C1F3B8C3F1B1BEE9A4C9F2A6D0F7A6CAED9BC8E998
D1F1A6C3E3A0C5E6AFD3F4C9618466244635C3E8E0EBFFFFF8FFFFFEFFFDFEFFFDFEFFFB
FEFFFDFEFFFDFCFFFDFCFFFDFCFFFFFCFFFFFCFFFFF1F7F7FCFFFFF8FDFFFCFFFFFEFFFF
FFFEFDFFFAF7F5EFF1FFFCFEFFFEFFFCF9F46F6D60ECEED6E7EBC8EEF5CBF6FDD3F8FFDB
FAFFE8FEFFF6FEFFFFFEFFFFFBFBFBFEFCFDFFFCFFFFFAFFFFF9FFFFF9FFFFFAFFFFF9FF
FFF9FFF8F2F6FFFDFBFFF8F2DDC9C0AD9386624130947469FFF7FAFFFCFFF3FFFBF0FFF9
FEFFFDFFFEFBFFFDFAFFF9F9E2B7C0FFECF3FFFDFBFAFFFAFEFFFFFEFFFFFEFFFFF2F6F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFEFFF9FBFFF7F7FFFFFEFFFFFDFFF9F7F8FFFFFFFFFFFDF8FAF7FCFFFD000200848A86
F4FBF4FBFFF8F9FFF4FCFFF3F8FCE5FFFFE8E3E7CCCED3B5D4D9B9858D66BFC89BD5E1AF
D2DFA9D2DFA7D6E3ABDBE8B2DAE6B6E0E8BFF3FAD8FCFFE6FCFFE8F2FBDCF3FDD8DEE6BD
D2DBAEDEE5BBDAE0BAD6DBBDFFFFEFFFFFF8FAFAFCF8F9FEFCFFFFFCFFFFF2F7FDFCFFFF
FEFFFFFEFFFDFFFFFDFEFFFDFFFFFDFFFFFDFFFFFBFFFFFBFFFFFBFFFFFBFFFFFBFFFFFB
FFFFFDFFFFFDFFFFFDFFFEFAFFFAF361463BC7A99EFFEFE4FFF5EDFFF5EFFFF3F1FFF6F6
FFF4F7FFFAFFF9F3F5FFFFFFFCFFFDFBFFFAEFF7EAFCFFF4FFFFF6FFFEF8FFFFF8FCFFF8
F8FFF7F2FEF4676E66767873FFFDFAFCF2F3FFFBFFFFF8FCFFFEFFFBFFFFF3FFFDF3FEFA
FFFCFDFFF6F50A00000D0300FFF9EADDD9C0B5B28FCED1A4E9EEB8D4DCA1D9E3A6D7E2A6
D1DEA8D5E3B2CBD8ACD1E2B8CEE8BBCEEBBBBFDCA6C7E0A7D1E9ABCCE39FCFE49FD1E6A1
D2E7A4BCD294DFF7C3BAD5AAD0EECC4D6E53D5F8E4E3FFF4F0FFFFF4FFFFF8FFFFFBFFFF
FBFFF8FBFFF6F9FFF4FBFFF8FBFBFDFFFEFFFEFFFFFBFFFFF4FDFAF6FFFAFEFFFFFBF9FA
FDF8F5B9B4B0B8B2B2FFFDFCFDF9F6FFFFF8AEB19EFFFFE6FEFFDDFEFFD8FCFFD8FCFFDC
FCFFE4FCFFEDFCFFF6FEFFFAFDFFF4FFFFF6FFFFF8FFFFFAFFFEFBFFFDFDFFFDFCFEFAF9
FFFFFDFFFEFBFAF5EFFFFCF3FFF8F1E6CEC46E4E43957870FFEEEFFFFDFFF9FFFFF8FFFD
FFFFFBFFFEFAFFFDFAFFF6F4D1ADB1FFEBF0FFFCFAFEFFFBFFFFFDFBFBFBFFFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFF
EAF4FEF8FFFFFBFFFFF7F6FBFEFAFBFFFDFFFBF4FBFFFDFFFEFEFFA4A9AF000608B1BDB9
F5FFF2F7FFEAEDFDD6FBFFDDFFFFDFFFFFDFD1D6AD9098699AA46FD2E2A4CEE29DD0E69E
DCF4AAC5DC94D0E7A3D1E7A9CADCA8E8F8CBF9FFE1F9FFE1FEFFE1FEFFDDFAFFD4D2DCA8
DEE8B3D1DBA7C6CFA2AAB18FFFFFEFF3F6EFFDFEFFFCFFFFFCFFFFF1F4F9F9FDFEFCFFFD
FCFFFBFCFFFBFEFFFBFCFFFBFEFFFBFEFFFBFEFFFDFEFFFDFEFFFDFEFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFEFFFFFEFBFFFBF8E2CDC8806963826964DFC6C1FFF4EFFFF5F1FFF9F6
FFF3F1FFFCFAFEF9F6F1F2EDFCFFFDF9FFFDECF9F2F8FFFFF7F8FAFFFFFFFFFFFFFEFFFD
FEFFFBF5FAF340433A6A6B63EFECE5FFFFFAFFFEFBF2EEEDF9F7F8FFFFFFFAFBFDFBFCFE
FFFEFFFDF7F7C7C2BF817C78ABA79EF7F3E7FFFFEEDBD9C4E8E6CDCECDB1F7F3D6FFFFE4
FFFFE6D8D6BDDBD9C2DDDBC6E0E1CFF6F9E6FFFFEDFAFCE6F6F6DEFFFFE8F9FCDFF7FCDE
F5FFDDF4FFDFE7FBD8CDE9C3B1D3AE94BC976E9B744A7B5B6FA291E2FFFFF1FFFFF8FFFF
F7FFF2F8FFE8F4FFE2F7FFEAFFFAFFFFF4FFFFF9FFFFFEFFEDFAE9CCD5C2B3ACA4B8AAA7
E0D7D0F8F1E9FFFEF8E9E6DFBFC1B4BEC6B1D7E2C4E1F0C7E3F5C1E2F8BAE2F8B7E2F8B7
E2F7BCE2F7BFE3F5C5E3F4C8EBF7CFE9F5CDF6FFDCF9FFE1EDFBD7E0EECBE2F1D2E5F2D6
E6F0D8F2FAE5F7FAE9FFFFF3A598909A8783B29A98E8D4D3FFFCFBFFFFFDFEFFFBFFFFFA
FFFEF8FFFDF6FFFCF6FFFAF6E5CDCBD8C3C0FFF3F0FFFDFAFFFDFDFFFDFCFFFEFFFEFCFD
FFFEFFFFFFFDFFFEFDFFFFFDFFFEFDFFFFFDFFFEFDFFFFFD
F5FFFFF4FFFFF2F7FBFFFFFFFFFDFDFFF9FCFFFBFFF7EFFAEBE9F6393D48828D91F5FFFD
F5FFEFF4FFE0DBF0B8C0D298CBD3A2CDD0A3BDC490919C62D2E1A0DEF2ABD3E99ECCE496
C8E394DEFAADC9E59BCEE7A5D4E9AEBDD19CCCDEAEE6F6C9E1ECC1E7F0C3EEF7C2D7E2A8
CED99DB2BD85CBD4A5EEF6D1FEFFEFFCFFF8F1F2F6EAEDF4FEFFFFFCFFFFFEFFFDF4F7F0
FEFFFAFEFFFAFEFFFBFEFFFBFEFFFBFEFFFBFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFDFDFAEFEDFFFBF8FFFAF8C1AEAA978480A5928CFFF4EEFFF6EF
FFF8F3FFFCF6FFFEFAFFFFFBFCFFFDF9FFFFF4FFFEEFFBFBFCFFFFFEFFFFFFFEFFEDEDED
FCFCFAFFFFFA6B6C645D5F54D8D8D0FFFFF8F4F3EEFFFFFBFFFEFFF8F6F9FFFDFFFFFEFF
FFFEFFF4F4F6FFFEFFFFFFFD6965627C7974F4EFE9FFFDF4FFFEF4BBB4AAB4ACA1B5ABA1
A1978DB8AEA4B0A69CAFA59CABA09AD9CECAF1E6E2F4E9E5D0C5C1E9DEDAFFFDF6FFFFF6
FFFFF3FBFFF1E9FBE1DAF3D5D0F2CFC1EAC09DCC9E76AD8641826C8AC3BCEAFFFFEEFDFF
E7F8E6F7FFE6F4FFDFFFFFEDFFF7FFFFF0FFFFF7FFF8F1F9FBFFF1B9C1A9E4DAD0FFF5F0
FFFCF8FFFEF8FFFEF8FFFFF8F7FBEDF9FFEDF0FFE0D8EAC0D0E7B1CFE9AAD0E9A7CFEAA5
D0E9A5D0E9A8D0E8ACD2E7AECDE0A9CFE2ABE2F7BFEEFFCDE1FAC3D3EBB7D0E8B6D0E6B7
CCDEB4C9D7B4E3E9CDA7A692635B4EFFFBF4FFEFEBFFFAFAFFFFFDFEFFFDFFFFFDFFFFFA
FFFDFAFFFDF8FFFCF6FFFCF6FFF6F1DDCEC9FFFBF8FFFBF9FFFAFBFFF9FBFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F4FEFFF9FFFFFEFFFFEDE9EAF7EFEDFFF5F4FFFBFFFFFCFFC2C1C7585D61F3FFFDF5FFF8
E9FDE1ECFFD7CAE2A8D8ECADE7F2BA919A639FAA70DAE8ABD1E1A2C6D997C7DC97D5ECA4
CEE89FB6D087D2ECA3D0E7A1D0E7A3E9FEBDD6E9A9D1E3A7D7E3B1D0DCAADDE7B2DBE9AE
CAD89BA1AF74CAD4A2FEFFE1F2F7E1FEFFF8FEFFFFF7F8FCFFFEFFF7F9F8FFFFFBFFFFFA
FFFFFAFFFFFAFFFFFBFFFFFBFFFFFBFFFFFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFFFCFBFFF7F3FFF1EEFFFBF693817D5F4D49FFFBF4FFEFE8
FFFBF6FDF2ECFFFBF8FFFFFAF2F4EFF2F8F4F9FFFFF9FFFFF7FBFEF9FAFEF5F5F7FFFFFF
FFFFFDEBECE75D5E5842433BBBBCB674756FEAE9E4FFFEFAD3D1D2FFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFF7F5F6FFFFFDBFBBBA3B3734B5B2ADF9F6EFFFFBF5FFFEF6FFFAF2FFFDF6
FFFDF4FFFDF4FFFDF4FFF8F1FFFDF8FFFDF8F8EFEAEFE6E1BEB3AFC2B7B3FAF1ECFFFEF5
FAFAEEFCFFF3F7FFF1ECFFE7DDFADBD1F5D1C0EAC2ACE0BC7ABAA25F9B93DDFFFFEEFFFF
F0FFF7F6FFEDF7FFE6FEFCEFFFEFFFFFF5FFFFF7FFEFE5EDE9EBDDC2C5B2FFFDF8FFFBFB
FFFCFDFFF7F8FCF6F6FEFDFBFFFFFBFCFFF6F0FCE6C4D5B5CDDFB5CBE2AECDE2AACBE3A9
CDE2AACDE1ACCDE1B0CDE0B2D0E2B0CEE2ADDBF2BCE5FEC5D9F2B8CAE6ABC9E2A9C8DFA7
E9FDCADDEDC0FEFFDFBABB9C46402AFFFDEDFFF3E7FFFCF4FFFFFFFBFFFFFEFFFFFFFFFD
FFFEFDFFFEFBFFFCFAFFFCFAFFFBFACCC1BFFFFCFBFFF9FAFFFCFEFBF9FCFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FFFFECEFF4FFFEFFFFFEFBFFFCFAFFF9F8FBEFEFA89FA0706E6FBDC1C0F8FFFAEFFFEB
D8EECAD9F1BFBBD395D8EFABCADA998A9656D9E8A7CEDE9DDFF2B2BED392EEFFC3C3DA96
C9E29EE0FAB3D3EAA2BCD28A889E558EA358BED3888E9F59909F6666743F5B6A318B9B5D
C2D294C8D69BD1DDABEFF7D0FBFFE9F7FBEDFFFFFBFBFBFBFFFEFFFBFAF8FEFDF8F8F8F0
FFFFFAFFFFFAFFFEFBFFFEFBFFFEFBFFFFFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFDFFFBF8FFFCF9FFF8F6FFFCF8EEDFDCB9AAA582706CFFFBF4
FFFBF6FFF4EEFEF5F0FFFEFAFFFFFAFFFFFBFAFFFBF8FCFBFEFFFFFDFEFFFFFFFFEEEEEE
FFFFFDF0F1EC11120D7677716D6E69FFFFFB71706C878684EAE8EB7A787D78757CB5B3B8
FFFEFFFAF8FBEBE9EAFFFEFFFFFEFDBAB6B5423E3BC2BEBBFCF7F3FFFEFAFFFEFAFFFCF9
FFFEF8F4EDE7FFFEF8FFFEF8FFFEF8FFFEF8F9F0EBFFFDF8FFF5F1EBE0DCFCF2F0FFFEF8
F8F5ECFEFFF4F9FFF3F3FFEFE2FAE0D4F3D4CBEECDBEEBCCA5E3CA32706374A1A6E9FFFF
F1FFFFE8F4E8FEFFF3FDF6F0FFF0FFFFF6FFFFF6FFFFFBFFB0AA9EEDEADBFFFCFDF6EDF2
FFFCFFFFF9FDFFFAFFFDFBFFFEFEFFFCFFFDF5FFF2DAE8D1CFDEBFCFDFB8CFE0B4CFE0B3
CFE0B4CFDFB8D0DEBBCFDFBAD7EABCCAE1ADCBE4ADCDE9AFC3DFA2C1DE9ECCE6A5D2EBAA
E8FDC2F3FFCBF9FFD2F8F8D2585134D3C7AFFFF7E5FFFCF3FFFFFFF9FFFFFCFFFFFEFFFF
FFFEFFFFFEFDFFFCFDFFFCFDFFF9FBAAA0A1FFFCFDFCF6F8FFFDFFFCFBFFFEFFFFFDFEFF
FEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
F7F8FAFFFFFFFAF4F4FFFCFAFEEFECFFFBF6FFFBF80700008B8A85F4FAF0EFFCEAF0FFE5
C4DBAFC9E5ABD5F0ADC2DC93D0E49CD6E89ECDE19AC2D792D4E9A6D2E8A7BED494D5EEAD
CDE3A3D2E9A5CEE39E91A75E9EB366D4E798CFE290E7F9ADCBDD9FD1E5AAD2E4A6D7E9AB
D2E4A6D0DFA6DFEBB9FEFFDFFEFFEAFFFFF3FFFFF8FAF9F5F6F2EFFBF8F3FFFFF6FFFFF6
FFFEF8FFFDFAFFFEFBFFFEFBFFFEFBFFFEFBFFFEFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFFFFFFF9F8F6FFFEFDFFFEFBF6EEEBFFFCFAFFFBF85D4E49A69792
FAEBE4FFFBF6FFFCF6FBF2EDFFFEF8FFFFFAF9F8F3FBFBF9FFFFFFF0F0F2FDFDFFFFFFFF
F2F2F0FFFFFDFFFFFDF7F8F3FFFFFDFFFFFDF3F3F1FFFFFFFFFFFFF2F1F6FFFEFFFFFEFF
FEFCFFFFFEFF242223010000F2F0F1FFFEFF9897958D8C8AFFFEFDFBF7F6FFFEFDFFFDFD
FBF5F5FFFDFDFFFBFBFFFEFBFFFEFAFFFEF8FFFEF8FFFEF8FFFCFAD2C8C6BBB1B0FAF2EF
FFFFFAFFFFF8F5FBEFF3FFEFF5FFF3F1FFF0DCF6DBBEE5CAB5EFD630705F497F7FE0FFFF
EDFFFFF3FDFEFFFEFDFFF9FBFFF9FFFFF0FDFFF3FBFFF7F7D2C4BBFFFDF4FFFDFFFFFDFF
FFFCFFFFFDFFFFFCFFFFFDFFF8F7FFFCFFFFFBFFFDF7FFF6F9FFF1F9FFEAF9FFE6F9FFE6
F9FFE8F9FFECFBFFEFF9FFECDDF2C7C8E3AEC5E1A7C8E6A8C6E5A2CFEDA7E4FFB8F0FFC1
D8EDAAEAFABBD1DAA3E3E5B65F5935AB9D82FFFCE6FFFCEFFEFFFFF9FFFFFBFFFFFCFFFF
FFFEFFFFFDFFFFFCFFFFFCFFF9EEF29F9498FFFAFDF9F4F8FFFEFFFDFCFFFEFFFFFBFEFF
FCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FFFFFDFCF8F7FFFCFAFFF6F3E0CFC8B5A29B4B3C35887E74F7F5E8FCFFEFD7E6C9CFE5BE
C6E1ACC8E5A5D9F7AFCEEA9DB4CC7E889F5194AC608AA159CFE6A091AA668CA564A6BF7E
D3E9A9BED39290A562ACC07BCEDF98D4E69CE2F2A7C1D28BD4E9A8D9EFAFCBE1A1CBE09F
CADE9FD7E9AFDBE9B8ECF7CFF1F7DBFAFDEAF6F6EAD8D5CEBDB8B2DED7D1FFFBF1FFFDF5
FFFDF8FFFCFAFFFCFBFFFCFBFFFCFBFFFDFBFFFDFDFFFEFDFFFEFDFFFFFDFFFEFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFFF3F5F4F9F9F7FDF9F6FFF8F5FFFCF8F1E3E0685954
7A6962EFDED7FFFBF6FFF9F3FFF8F3FFFDF7FFFBF7FFFEFBFFFEFFFFFFFFFBFBFBF5F5F5
FFFFFDF3F3F1FCFCFAFFFFFDFDFDFDFFFFFFFFFFFFF1F1F3FAFAFCFEFFFFF6F5FAFAFAFC
FFFFFFF8F7F5FFFFFD838280747273010000110F100402035B595CFFFEFFF7F2F6FFFEFF
FDF8FCFFFEFFFCFAFDFBF7F8FFFDF8F8F3EDFFFEF8F8F0EDFFFAF8DCD2D1C6BCBBFFFDFB
FFFEFBFFFDF8FCFDF5FCFFF6F9FFF6F7FFF4ECFFEBD7F7DFBFF6D764A68B6FAEA5C9FCFD
EAFFFFF7FFFFF6EFF7FFF9FFFFFAFFFFF6FAFFFBF8998880FFFAEFFFFBF4FFFEFFFCFFFF
F9F6FFFAF7FFFFFDFFFFFDFFF7F7FFFCFCFFFCFFFFF6FDF6FBFFF4FBFFF1FBFFEDFBFFEC
FCFFEFFCFFF3FCFFF6F9FFEFE2F9CDCDEAB2CAE8ACD0EEAECFEEA8D5F5AAE5FFB4EDFFBB
E2F8AFD9E8A7D2DAA1D2D4A5827A567E7055FFF4E0FFF7ECFFFFFFF9FFFFFBFFFFFEFFFF
FFFEFFFFFDFFFFFCFFFFFBFFFFFAFEB7ACB0FFFAFDFCF6F8FFFDFFFBFBFDFEFFFFFEFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEF9F6FFFDFAFDEFECFFFAF6937F78604C433D2D208D8473FFFFEAFCFFE6C6D6AFC2DAA8
D7F3B8CAE9A5B6D68AC4E393CDEA9AC5E292D3EEA1D3EDA3BBD58CBDD78E87A05C526B27
C8DE9D9CB071C5D799E0EFB4CCDBA0D3E1A6D7E2AACFDEA3CDE3A3D4EDABCDE6A4DBF1B1
CCE0A3CEDFA9D5E2B4FBFFDEFEFFE8FFFFEDD9D7CAE3DFD4F7F0E8FFFDF4F7EEE5FFFDF4
FFFBF8FFFBFAFFFBFBFFFBFBFFFBFBFFFCFBFFFCFDFFFDFDFFFEFDFFFFFDFFFEFFFFFFFF
FFFFFFFEFFFFFEFFFFFCFFFFFBFFFFEFF5F5FCFFFFF9F9F7FFFEFBFFFDF8FFFCF8FCEDE8
53423BA6958EEBDAD3FFF5EEFFFCF6FFFCF6FFF7F2FFFAF7FCFBF9FFFFFDF2F2F0FFFFFD
FBFBFBEDEDEDFEFFFFFAFCFBF6F7F9FEFFFFFEFFFFF8F9FBFEFFFFFCFFFFFDFEFFFEFFFF
EAEBE5FFFFFAFBFCF6EEEFEAFFFFFDFFFFFFFAFAFA58585A0E0D12F0EFF4FFFDFFFFFEFF
FFFCFFF3F2F8FFFEFFFFFFFFFFFFFBFBF8F1FFFFFAFFFEFAFFFDFBFFF7F8F0E6E7E0D6D7
FCF3F4FFFCFCFFFEFBFFFFFAFAFFF8F4FCF1F5FFF2F1FFF4B9EBC880C29E468E7877B4AC
DFFFFFF5FFFFF9F1FEFFF9FFF7F1F1FFFFF6F1E5D74D3C2CFFF9ECFFF9F2FDFDFDF3FBFD
FEFFFFFDFCFFFFFEFFFEFEFFFEFEFFFEFEFFFCFFFFF9FEFAFCFFF6FCFFF3FCFFEFFCFFEF
FEFFF3FEFFF4FEFFF8F9FFF1D8F2C3C5E4A8C2E2A1C7E8A3C3E398C2E394CAE797CAE596
D9EDA5C8D796DDE4AEDFE0B6CDC4A560513CFFEDDFFFFBF4FFFFFDFCFFFFFEFFFFFFFEFF
FFFDFFFFFCFDFFFBFDFFFBFDFFFAFDD8C9CCFFF9FBFFFBFCFFFDFDFEFAF9FFFFFDFFFFFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFDFAFEF5F0AC9D986B5852A48D87FCE8DD0F0000ADA28CFEFFE0FCFFDFC5D7A5D8F1B7
C4E19FCEEEA5C8E99AD0F1A0CAEB9CCDEC9ECFEEA0C2DE91D3EFA2DBF7AACBE59BCDE49C
CFE4A1D3E5A7CDDCA5D5E3B2E0EBC1DBE5C0E5ECCAEFFCD1E3F9BBCFEAA5C1DA98E5FDBF
E1F6BDD4E6B4C7D6ABEDF7D2E0E6CAEEF0DAC0BFADFAF4E8FFFEF3FBF2E9BDB3AAFFFCF4
FFFBF8FFFAFAFFFBFBFFFBFBFFFBFBFFFCFBFFFCFDFFFDFDFFFDFDFFFEFDFFFEFFFFFFFF
FFFFFFFEFFFFFEFFFFFCFFFFF9FFFFF3FDFCEDF3F3FEFFFDFFFEFBFBF4EEFFFCF8FFFBF6
FCEBE4A08F88796861AB9A93E5D6D1FFF6F0FFFBF8FFFCFAFFFEFBF9F9F7FFFFFDF2F2F0
777777FFFFFFFAFBFDFEFFFFF8F9FBFEFFFFFCFDFFFBFFFFFAFEFDF3F7F6F9FEFAFCFFFA
FEFFF4F0F4E5FEFFF6FEFFF8FEFFFAFEFFFBFDFDFDFEFFFF67666B36373CFDFCFFFBFAFF
FFFEFFFFFEFFFAFBFFFCFDFFFFFFFBF9F8F3FFFFFAFFFCF9FCF6F6FFF6F7FFFCFFD8CFD2
FFFCFFFFFCFFFFFBFDFFFDFCFFFFFBFEFFF9FCFFF8F3FFF1DFFFE3A6E3B9034D2C357564
E3FFFFE8F9FFFFFCFFFFFBFFFFFFF7FFFFEDBDB69C64523AFFF7E6FFFAEFFCFFF6F7FFFB
FCFFFAFCFEF9FEFFFDFEFFFFF7F8FCFAFBFFFCFFFFFAFFF8FCFFF4FCFFF1FEFFEDFEFFED
FEFFF1FEFFF3FEFFF6F9FFEFDEF9C6C7EAA8C4E8A2CAEEA4C9E99DC8E799CEEA9DCEE89E
D1E5A0D7E5AADAE0B0D8D8B4FBF3DC5B4D40FFFAF6FFF4F4FFFFFAFFFFFBFFFEFBFFFEFB
FFFCFAFFFBFAFFFAFAFFFAFAFFF6F6E8D6D6FFF6F6FFFBFAFFFCFAFFFAF7FFFCF8FFFEFA
FFFEFBFFFEFBFFFDFDFFFEFBFFFDFDFFFEFBFFFDFDFFFEFB
A19893685D59B5A39FFFF6F0FFF4EE7963583423118E8469C9CBA6E1EDBDD9EEB3CDEAA7
C7E79EBFE194C7EA9AC5E898CDEFA3CAECA2C8E89CC9E89AC8E797C9E694CBE695D0E89C
D3E8A3DCEEB2E4F2C1E5F1CDEBF3DBF4FAECFBFEF7F8FFECF3FFD2CAE8A0D2ECABF5FFD1
E4F8C3D8E9BCD1E0B9D6E0BEDAE0C4A0A28CE0DFCDFFFFF1FCF4E9FFF9F0FFFCF4E9DCD6
E3D4D1E2D2D2DFD1D1DED0D0BDB1B1736968FFFCFDFFFDFDFFFDFDFFFEFDFFFEFFFFFFFF
FFFFFFFEFFFFFEFFFFFCFFFFF8FFFFF4FEFDFBFFFFF1F6F2FFFEFAFFFEF8F7ECE8FFFBF6
FFFBF4FFFAF4FFECE69F8E87796A65A39690FDEFECFFFDF8FFFFFAF1F0EC878785000000
B8B8B8FDFDFFFEFFFFF2F3F7EEF2F5FCFFFFFAFEFFF5FBF9FBFFFDF4FBF4F4FBF3FBFFF4
F8FFECFCFFECFCFFEFFBFFF0F9FFF1FCFFF8FEFFFBFCFFFFF5F6F885898C5D5E63B7B8BD
FAFAFFF9F9FFFEFFFFFEFFFFFEFFFAFCFDF7FFFFFBFFFEFDFFFEFDFFFBFDF8F2F6FFFCFF
BEB5BAFFFCFFF8EFF2FFFDFDFFFEFBF2EFEAFFFFFAF9FFF3D5F8CEB9EFBDA3EABE408266
DBFFFDF0FFFFFDFDFFFFFEFDFBFFF0FEFFE69C98755E4F2EFFFAE4FFFCEAF8FFEBF0FFEC
FBFFEFFCFFF1F2F8EAFCFFF8F8FBF4FEFFFAFEFFF8FEFFF4FEFFEFD2D7C0D8E1C4CCD5B8
D6DFC4FCFFEDFAFFEFF5FFE5DBF8BECCF2A9C5E99FC6EB9ECAEA9EC8E79BC9E59BCFE6A2
D3E5A9CCD8A6F2F6D1FFFEE5FEF6EBA79998F5E4ECFFF7FCFFFEF6FFFDF1FFFFF3FEF4EA
FFFBF4FFF9F2FFF4EFFFF8F4FFF0ECEFDAD5FFF4EFFFF0EAFFFBF4FFFCF4FAF0E7FFFCF6
FFFCF6FFFBF5FFFBF7FFFBF5FFFAF6FFFCF6FFFCF8F3E8E2
645B56ABA09CFFF9F6FFFAF6FFEBE7180200332210585232A6A97ECEDBA5D1E7A6C8E69C
C9EA9BCCEF9DD4F7A7CBEDA0C6EAA2C5E9A1C7E99DCAEB9CCBEA9ACCE997CDE897D0E89C
CFE39EE8FAC0FBFFDDF9FFE8F3FBEEF7FBFAFCFFFFF9FFFAF5FFD8C6E49EBDD798E9FFC8
E2F5C7E5F5CEE3F1D0E6EFD2EAF0D6A6A892E3E2CEFFFCEEFFFDF2FFFDF4FFF2ECF9EBE8
FFF8F7FFF5F4FDEFEFC8BCBCAFA3A3A19796FFFCFDFFFBFBFFFEFDFFFFFDFFFEFFFFFFFF
FFFFFFFEFFFFFEFFFFFCFFFFF9FFFFF0FAF9F0F6F4FEFFFDFFFFFBFFFEF8FFFCF8FFFBF6
FFF6EFFFF2ECFFFAF4C6B5AE746560BCAFA9FFFBF8FFFBF6F1EEE9FFFFFA444540333333
FFFFFFF6F6F8B8B9BDC3C4C8FCFFFFF8FEFEF7FDFBFBFFFBFBFFF8F6FFF3F9FFF4F9FFEF
E4F2D1E7F5D2E6F4D3E2EFD3E7F0DBF1FAE9F9FFF4FCFFFBFAFEFDC1C5C6565A5D383C3F
74757ACACBD0FEFFFFF4F5F7FFFFFDFFFFFBF8F8F6F5F4F2FFFEFFFFFEFFFFFDFFFFFCFF
ACA6AADBD2D7FFFCFFFBF2F3F5F0EDFFFEFAF0EBE7F7FEECDFFAD1B4E0ABC0FECB57956E
5C8B79CDEAE5F7FFFFFAFFFAE9F7DDD4E0BAA5A67E6A603CF8E4C9EFE3C9F6FFDFE2F6D1
DDEBC8F2FBDCFCFFEAEAF2DBFEFFF1FEFFF3E8EDD9FEFFECFEFFE8CFD9B7D7E1BCD1DDB7
D4E0BCEDF8D6ECF7D9F7FFE1D6F4B6C8EEA3C3E89BC8EA9ECDEDA2CDEBA3CFE8A6D3E8AD
D2E3AFD5E0B6E7ECCEFFFFEFF8F1EBA89E9FE7D7E2FFF6FAFFFAEDF8F2DCFFFFECFFF7E7
FFFCEDFFF4E9FFF4EDFFF8F1FFF8F1E0C7C2C0A7A2BEAAA3BEABA4C7B6AEFFFCF3FFFCF3
FFFBF3FFFBF3FFFCF4FFFCF4FFFCF4FFF7EFF1E4DCD8CBC3
FFFDFAFFFCFAF4E6E5FFFAF8FFF9F60F00007869569D9775C9CC9DDBEBADCEE89FC6E798
C8EB99C2E895C6E999BBDD91C2E69EC4E8A2C7E99FCAEA9ECBEA9CCDEA9ACCE79ACDE49C
CBDE9EEAFBC5FBFFE1FBFFEDFAFFF9FBFFFFFBFEFFF1FCF6F4FFDAD2EFACC1DAA0D6ECBB
D6E8C2F8FFE8F9FFECFAFFEBFCFFEBACAE99DEDDCBFFF9EBE2D9D0FAF1EAFFF5F3E0D4D4
B7ACAAD2C8C6FFFCFBFDF3F2FFF9F8FFFDFBFFFDFDFDF9F8FFFEFDFFFFFDFFFEFFFFFFFF
FFFFFFFFFFFFFEFFFFFCFFFFF2F8F6FBFFFFFDFFFCFAFBF6FFFFFAFFFCF7FCEEEBEDDED9
77665F6E5D566A58547D6E69A79996FFFAF6FFFCFAFFFDFAFFFDF672716CB1B0ACE0DEDF
FFFFFFFFFEFF6263686B6C70DADEE1F9FFFDFBFFFBF9FFF8F3FEEDF6FFEDF8FFEDEDFCDB
D1E4B7D2E6B5CFE2B5CDDFB7D5E4C3E5F3D9F6FFEEFBFFF6FBFFFAF7FDF9FCFFFFEFF3F4
68696B2E2F3178787A6F6F6FEEF0EDFEFFFDFEFFFDF6F6F6FFFFFFEEECEFFFFEFFF7F2F8
FFFCFFFFFCFFD0CACCFFFCFCFFFDFBFDF5F2FFFEF8FEFFEFDCECC7D8F8C6A9DCA489C190
4F80625F8674C7E0DAEDFFF5CFE4C5E2F1C8DADFB7D5D1AC9B9275A29F7E818E628CA06D
95A576A2AF83C5D1ABEEF9D7FCFFE8E8F1D4FEFFE6FEFFE3FCFFDFCFDAAFD5E3B2D5E6B2
CFE1AFD5E6B9D8EBBEF5FFDAD8F8B5CCF1A4C6E89EC6E89EC9E8A4C8E5A5C8E0A6CADCAA
F0FFD4F4FEDCFFFFECFCFDEFFFFFF88F8989F2E7EDFBF1EFFFFFECFFFBDDFCF5D9D6CAB2
DCCBB9EDDACBE3CBBFB59A8FB59A916D524BC0A7A0D1BAB2B6A299BAA99FAA9C9185776C
83756C695B52584A4153453C594B4276685F9B8D84AEA097
FFFEFBFFFEFBFFFBFBFEEEEFFEEAEB0E0000A3968395916EE3EAB7DCECABC1DC8FC4E692
CEF19DC3E996C9EB9ECAECA0C3E79DC5E9A1C8EAA0C7E79CCBE79DCFE9A0D2E9A5D1E5A6
D4E5AEE9F9CCF7FFE0F4FFE8F9FFF6F8FFFDF5FFFFDCEADDCCE4B0D5EFAECBE2ACC4D6AC
BFCEAFF4FFEAFBFFF3F4FBEBFEFFF1D4D5C56B695A504D3E49423A605654D1C5C7FFF6F7
FFFDFBFDF5F2FFFEFBFFFAF7FFFAF7FFFDFAF3EFEEFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFCFFFDFEFFFDFFFFFBFFFFFAF8F0EDFFFDF861544E70615C
BFAEA7FFF0EBFFFBF6FFFBF8FFFCF8FFFCFAF9F1EEFEF9F56F6C6561605BFFFFFBFFFEFF
F4F4F6FFFEFF727378000104828888FBFFFDF9FFF8EFFCEAF8FFEDF8FFEAD7E6C5D6E8BE
CDE4ACCBE5A6C8E1A8C7DFABD0E5BAE2F3CFF5FFE9F9FFF1F9FFF4FBFFF8F7FCF6FCFFFD
EBEDEAFEFFFDF1F1EF1F1F1D0C0E0B5F6160555756666867F5F5F7FCFCFEFFFEFFFFFEFF
FFFEFFFFFBFCE2DEDDEFEAE7FFF7F4FFFEF8FBF4ECFFFFEDFBFFE1F7FFDDC0E6ADCCFBC5
AEE0BA47775D86AF9FD7F8E7BFD8B8C3D5AFFEFFE1FFFFE1F8F7DBEFF3D0D7E8B1CDE3A3
CEE0A487965FCBD9A8F3FFD4F4FFD7FCFFE1FDFFDEF3FED3F2FECED1E0A9D3E5A9D3E7AA
CDE3A5CAE2A6CBE4ABE8FFC9DAFBB6D0F2A8C7E8A1C7E6A3CCE8ABD1EAB1D3E7B6D2E3B9
CEDCB9FCFFE8F9FEE7F4F7E4FFFFF34C4940FFFFF8FFFFF1C7C3A65E5B384C47275C5336
675841574433624C3E70584C644940503730FFF3EDFFFAF3FFF1EAFFFCF3FFF9F0FFFCF3
FFFCF4FFFAF2FFFCF4FFFCF4FFFCF4FFF5EDFFF7EFFFF8F0
F6F6F4FFFFFDF9F0F3FFF3F68D7A7C86756E9B907E9E9B78C1CA95D3E7A2C9E495C5E791
C9EC98C4EA97CEF0A4CBEDA1C6EB9DC8ED9FC8EA9EC5E59CCCE7A4D8F0B4E1F5C0E3F5C5
E7F6CDF3FFDDF5FFE2EFFCE0F0FEE4F6FFECE9F9DFD1E5C2C1D8A0D2EAAED0E6B5D5E6C2
D2E0C7F9FFF4FBFFF8F8FEF4FDFFF5FAFAEEF4F2E5FFFFF3EDE6E0D8D0CEFFFBFFFFF6FB
FFFAF7FEFBF6F9F5F2FFFEFBFFFEFBFFFFFBF7F6F4FFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFAFBF8F3F5F0EAEBE2DD675C56B0A39D91827B
FFF4EFFFFBF6FFFBF8FFFCFAFFF9F6FDF8F5FFFEFDB2B1AD6A6964C5C4BFF8F7F3FEFCFD
FFFFFFF2F1F67A7B800001047D8381F6FDF6F9FFF6F8FFEFF8FFE8F4FFE0C5D7ADC7DEA8
CDEAA7C9EB9FC8E7A3C9E7A7CFEAB3DBF2C4ECFDD9F7FFEBEDF9E5FBFFF4F7FDF3FEFFF8
FFFFF8F5F6EEFFFFF7F0F1EBE5E7E4A9AAAC88898B4C4D4F202125424347CDCED0A3A3A5
C0C0C2FFFEFFE3DFDCC0BDB8E0DCD3FFFFF4FFFEF2FFFFEFFFFFECE9EFCDDEF2BFC4E7B1
B0E0B680B998447B648DBDA7D3F2D3CCDFBFFCFFE8FAFFE6FCFFECE9F5D1D5E7A9CFE59C
D4E8A3C7DA9A99A86FC8D6A3DDE9BBD9E5B7E2EEC0D1DDABDCEBB2D4E6A8D3EAA6CBE59E
CBE69FCBE9A3C6E5A1D1F2ADCFF0ABCAE9A5C5E3A3CBE7ACDCF4C0ECFFD3F4FFDEF5FFE1
F9FFE8EEF9DBFCFFE8FEFFE8EEF4D8B2B69B54593B646A489DA27A9A9C74D5D5B1E6E1C3
EAE0C7E6D7C4DECCBEBFADA1FFFAF3E8D3CEFFF2EEFFFAF8FFFBF8FFF9F5FFFDF8F3ECE6
FFF9F7F9EFEDFEF4F2FFFCFAFFF8F6FFF5F3FFFCFAFFFCFA
FEFFFFFFFFFFFFFDFF0E03093E2F34F8E9E6ECE4D13A371487905BC9DD96DCF7A6CAEC95
C0E38FC3E898CEF0A6BEE094C6EC97CAEE97C8E99AC5E39DCFE8AEE5F8CAF4FFDFF8FFE6
F2FFE3F9FFEAF7FFE6E7F7D3DBEDC3D7EDBCD5ECB6D0E8AED0E8AACCE4AACEE1B4F3FFE3
F9FFF3F9FFFAFAFFF9FCFFFBF8F9F1FFFFF6FCFCF0FAF8ECFFFEF8FFF8F9F8EEF6FFFCFF
FFFFFDFFFFFAF9FAF5FDFEF9FCFDF8F4F5F0FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFDFFFFFBF9F6EFFFFEF8FFFEF6534842A59892FDEEE7FFFBF4
FFFBF6FFFCF6FEF3F1FFFAF8FFFEFBF5F4F2FFFFFFEEEEECFFFFFAEBEAE5FCFBF7FFFEFF
FFFFFFFAFBFF62636865696CDEE4E2F9FFFAF3FFEEF8FFECD5E6C2D5E8BBCEE2AFCDE7A8
CAEC9FC6EC97C5EA9ACAEBA4CDEBADD0EBB6DAEFC6E4F5D3F2FFE6FBFFF1F1F8E8F7FBED
FFFFF4FFFFF4FFFFF4FFFFF8FFFFFDFEFFFFFCFDFFF6F7F9FEFFFFF4F5F9FEFFFFC5C6C8
060606000000B7B6B1FFFFF8B1AFA3D3CFC3F3F0E1FBF5E7FFFDF1FFFFEAD5DBADC8E1AA
BFF0C1B5F5D03F846885BFA7DFFFE8F4FFECF9FFF1FBFFF1E7F8E5DDF1CCC6D997D9EC9D
CFE499CCE09BCFDFA1ADBC83899563BBC795BCC896D4E3ACC4D698D3E8A3D0EAA0C6E295
CAEB9CCEF1A1C4E99CC1E59BC8E7A3C6E3A3C5E1A6D0E8B4E4FACCF7FFE3F8FFE6F9FFE8
E5F2D6E5F0D2DCE6C4F5FFDAF3FED3E7F3C3E1EDBBF0FCCADCE5B6C4CDA2ECF0CBFDFCDD
FFFFE6FFF7E4FFFBEDFFFCF3FFF3EFE1D1D1FFF9F9FFF7F7FFFBFAFFFBF9FFFEFDFFFEFD
FFFEFDFFFDFCFFFDFDFFFEFDFFFDFDFFFDFCFFFDFDFFFBFA
FAFEFFF3F4F6FFFDFF060004776A71FFFBFAD8CFBE3F3F1D859058BDD38BCFEC9ACAEC95
C7EA96C9EE9ED5F6AFCDEFA3C6EA90CAEF92C8E998C4E19ECFE7B5E8F9D5F8FFEFF9FFF3
F6FFF1F0FCE8E5F4D5D9EABECEE3A8C7E198C9E692CDEA98CCE5A1D2E7AFD4E5BBF5FFE7
F9FFF6F9FFFDEDF1F0FCFFFFFFFFFBF6F7EFFFFFF4FFFFF6FFFAF6FFFDFFFFFAFFFFFAFF
F5F5F3FEFFFAFEFFFBFCFEF9FEFFFBFDFFFAFEFFFDFCFEFBFEFFFDFEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFFFDFFFEFAFFF9F3FFFDF8FFFAF4675A54CEBFB8FFFBF4F7E6DF
FFF6F1FFFCF6FFFCFAFDF5F3F6F2F1F1F1F1F6F7F9FEFFFFFAF9F4FFFFFAF8F7F3F4F2F3
FEFEFFFEFFFF6C6D7265696CE7EDE9F9FFF8F5FFEEF8FFEABACCA4C7DBAAD0E7AFD0EDAA
C7ED96C1EC90C3EB93C8ED9FC9EAA5C8E6AACFE7B7D6EBC4F8FFE8F6FFE8FCFFEFFFFFF1
F5F6E8FFFFF3FFFFF1F7F5E9F8F8F6FCFDFFFCFFFFFCFFFFFBFFFFF3F7FAFCFFFFFCFFFF
7E807F7B7C77484941A6A69CE5E3D6C0BEAFB3B2A0CCC6B8E8D6D2FFF6EAC8C099DDEBB8
C6F6C4A1E5BC519D8170B49DE7FFF6F3FFF3F8FFF8E6F3E9F1FFF8D9F3D0E4F7B5C9DB89
CBDD91D9EDA6D6E6A7B4C38868754066733E9CAA7595A46BB5C886CFE69ECCE999C4E491
CBEE9AC9F19BC1EB99C1E79AC9E7A7CBE4ABCCE4B0D4EABBE5FAD3F5FFE4F5FFE7EDFAE0
ECF9DDCFDDBAD1DDB5C6D4A3D5E4ABD0E09FD6E7A0CBDC98CBDCA6D0DDB1E6EEC7D3D9B7
F5F5DBFFFFEDFFFEF3F9F0E9FFF6F6CABEC0FFFBFFFFF6FBFFFDFFFFFEFFF1F0F5F9FAFE
FDFEFFF7F8FCF9F8FDF6F7FBF3F2F7FBFCFFFFFEFFFEFFFF
FBFFFDFBFFFEEFEEF40C050D897E86FFF6F6C4BBAA9D9A77DAE1ADDAEAA9CAE298CEEDA1
CFF1A5BBDF97BEE29CC5EA9CC3EB8AC9EF8AC7E993C2DF9CCCE4B4E2F5D5F3FFEBF5FFEF
F7FFEFE3F4D4D0E2B8CCE1A9D0E6A5D0E89ECFE799CFE79DD1E7A9F5FFDAF8FFE4F8FFEF
F3FDF4FBFFFFFAFEFFFEFFFFF6F8F5FFFFFAF7F7EFFEFEF6FFFEFBFBF7F8FFFDFFFFFDFF
FFFFFFF6F8F3FEFFFBFCFEF9FEFFFDFBFDFAFEFFFDFCFEFBFEFFFDFEFFFDFEFFFFFEFFFF
FEFFFFFEFFFFFFFFFFFFFFFDFFFEFBFFFEFAFFFDFAFBF2EDA496939D8E89FFF4EFFFFAF6
FFFAF6FFF7F4FFF9F5908885403B38C5C4C2FFFFFDFFFEFCFFFEFAF7F2EEFFFEFDFAF8F9
FFFFFFF9FDFF5A60600004007B857AF1FEEAF8FFE8F7FFE1CCE2B1D8F1B8C5E2A2C7E99F
C7EF99C1EC93C2EC98C8EEA1C8ECA6C6E6A7C9E6B0D1EBBBC9DEB3E1F1CCF9FFE4E3ECCD
D2D8BCDCDEC6D8DAC2FFFFEFFFFFFBF9FAFCFCFFFFFCFFFFFBFFFFFCFFFFF8FCFFFCFFFF
FEFFFFFEFFFDB3B4AF43443C74746AEDEBDECDCBBCE0DCD0DDCFCCC2B1A9FFFEE3FFFFD8
B9E2A6AAEEB37FCFA8509880D6FFF1F2FFFDF1FAF7F8FFFACAE2CABEDBAFD1E8A4D0E694
D1E898D3E99ED4E9A6C5D79DE1EFBCCCDAA9CDDBAAEBF9C4AEC084CCE19CCCE498C8E595
CEF09CC5EB98C2E998C9EEA0C9E9A0CEE8ABD2E8BADBEFCCECFCE1F7FFEBF1FEE0E3F1CD
D8E7C0CCDBB0DFEDBCE0EFB8BDD090E2F6AFCAE097D3E8A7D7E9B9CDDBB7E4EFCDE6EFD2
FEFFEDFBFCEEF9F6EFFFFDFBFFFBFFE8DDE3F9F0F5FFFDFFFEFCFFEAEAECFCFFFFF6FCFC
FCFFFFFCFFFFFCFFFFFCFFFFFAFEFFFCFFFFFCFFFFF1F5F8
F0FBEBFBFFF8E6E7E908050EB5ABB4FFFBFBB6AB99A29C7ADDDCACE0E7B1CCD9A3CFE4AC
CFEAB3C4E6AAD1F8B5C4F09BB8E67AC9F387CEF298C8E6A0D4ECBAD4EAC3D8EEC8DEF7CD
E5FFCCCAE8AAC8E7A3D2EDAAC7DCA1C7D8A4D5E0B8D3DDBADAE8C4EDFCDBF9FFEFF9FFF6
F9FFFDFBFFFFFCFFFFFEFFFFFEFFFFFEFFFDFFFFFBFFFFFAFFFFFDFFFFFFFFFFFFFFFFFF
FEFEFEF7F7F5FFFFFDFAFAF8FEFEFEFEFFFFFEFFFFFEFFFFFBFFFEFBFFFEFCFFFFFCFFFF
FBFFFFF6FCFAF4FAF8FCFFFFFBFBFBFFFEFFF3EFF0FFFDFDB7ADAE7A6E6EB6A6A6F3E1E1
FFFAF8C2B0AE8F807D392C266D625EFFFCF6FFFDF6FAF1ECFFFBFAFDF1F1FFFBFDF5F3F6
FCFFFFEEF7F66F7A7200060077876CF7FFE3F7FFDAEDFFCCC5E2A0C4E8A0CAF0A5C0E99D
C6EFA3B8E097CCF4AEC7EEABC2E9A8CDF4B5C5E9ABC8ECACCDEDAEDBF9B9EAFFC7E9FEC5
D8E9B5CFDCAEDFEAC0F9FFE1FEFFF4FEFFFDFCFFFDFCFFFFFCFFFFFCFFFFFCFFFFFCFFFF
F4F8FBFEFFFFFFFFFFBABAB82E2D29777671EEEEE6FFFFF6FFFFF6E5E1D8FFFBF3FFFDDD
CBED99AFEB9184D19B175D45E1FFFFF1FFFFFCFFFFF6FDEDCFE4B9C5E1A4CDE8A5D0ECA1
CFF099C9E994CAE59ECEE6ACCDDEB2CDDBB7DDE9C5F2FCD7C9D5A5A4B179D5E5A4D0E69E
C9E197D5F1A6DDFBB1C1E092C9EA91CCE89DE2F6D1F5FFF6F7FFFAF3FFECE6F5CAD6E5AE
D2E1A8D3E2A7CFE1A5DCEEB2C6DA9BCDE3A5C9E0A8CEE1B3D2E0BFD8E4CCF0F9E4FBFFF3
FBFFF8FCFFFBFFFEFFFFFDFFFDF2FACEC1CAE1D4DBF7ECF0FFFEFBFFFFFAFBFFFAF9FFFA
FBFFFDFCFFFDFCFFFDFCFFFDFCFFFDFCFFFDFCFFFDFCFFFD
F6FFEEFBFFF680818557545DFFFBFFFFFBFBDCD1BF271E00615D30E1E0B2E9EEC6D0DCB6
D1E6BDC4E0B0B2D699C2E89BC7EF8ED2F694C5E290B8D18FD1E5B2E3F6C9D1E9B9CAE7AD
C5E69FC0E595C8EE9BCCECA1D1E9ADEFFED3FEFFECFBFFEEEFF9E0F9FFECF9FFF3F9FFF8
F9FFFDFCFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFBFEFFFDFEFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFEFFFEFCFDFEFEFEF2F2F2FBFDFCF7F9F8FCFFFFF7FBFAFBFFFFFAFFFE
ECF5F2F9FFFFF9FFFFE8EEECFCFFFFF1F2F6FFFFFFFFFDFFFFFCFFE5DBDCBDAEB159494A
7A68680D000055433FFFFBF6FFFBF4FFFAF2F8EBE2FFFCF4FFF7F5FFFAFBFFFBFFFFFDFF
FEFFFFFBFFFD566055000C006A7855CBDBAED0E3ABCAE09FDBF9B1C6EB9EC5F0A1BCE69A
C9ECAACCEEB1EAFFD0DFFFC8C7EBAEC0E7A8B8DF9CC0E8A1C5EBA0CBF0A3D3F3A8D1ECA7
C5DD9FC5D8A1D9E9BAF3FFDBFEFFF3FEFFFBFEFFFDFCFFFFFEFFFFFCFFFFFCFFFFFCFFFF
FCFFFFFEFFFFEDEEF2FFFFFFFFFEFF6C6B69A6A5A1FFFFFAF4F7F0FFFFF8AA9D97FFFFE4
D0E89ABBED9454985B175A3B9CC7CDDBF5FFF4FEFFF5FEE9CADEADD6F0B3D2EEB1C3E29F
C3E495C0E192C8E5A5D9EFBEE4F3D2E6F3D9EEF6DEFAFFE4FEFFDF8C9664818F52C5D692
DDF1AAB9D088B8D28BD8F5A5CDEC8FCBE79ADFF2D4F7FFFDF8FFFDF4FFEDE5F5C4D3E3A2
CDDD9CD3E6A4D8EAAEE3F7BAC9E2A1D5EFB2DCF4C2E8FDD6E4F1D3E9F3DBF5FFEDF9FFF4
F6FFF5F7FCF8FDFDFDFDF7FBFFFAFFF6E5EFF3E2EAFFFAFDFFFDFBFFFFF8F8FEF2F7FFF4
FCFFFAFEFFFBFEFFFBFEFFFBFEFFFBFEFFFBFEFFFBFEFFFB
FEFFF4EDEEE866636AE4DCE9FEF2FEFDF1F1D9CEBC5E5333BDB68CFFFFD6F7F7D5F5FADC
F6FFE2F8FFE4F5FFDDF5FFD3D8EDA8CCE099FCFFCDFCFFD3D7E0B1BBC797CEDFA8CEE7A5
CFF0A1C6EC95C2E891BDE090C2DF9FE3F6C8F9FFE8F5FFE7FBFFE8FBFFE8FBFFEFFBFFF6
FBFFFCFBFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFEFFFDFEFFFFFEFFFFFEFFFF
FFFEFFFFFEFFF0EEEFFCFAFBFFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFBFFFEF5FBF9F8FEFC
FBFFFFF0F6F4EDF6F3FBFFFFF0F4F5FEFFFFFFFFFFECEAEDFFFDFFFFFCFDFBEFF1150707
0B0000B0A19EF0E1DCFFF6F1FFF4EDFFFCF4F3E6DEFFFCF4F5E4DDFFFAF6FFFAF8FDF5F3
FFFEFBFFFFFA6C6E61292C178E9271DDE4B8E4EFB7C6D697D9F0ACB7D58DC5E99FC8ECA6
C3DFA5D3EBB7F4FFD8F2FFD8D8F5BDCBEAAEC1E4A2C6EAA4C6EAA0C9EB9FCAEAA1C8E5A2
C7E0A6CDE4B0E1F4C7F6FFE3FEFFF4FFFFFBFFFFFDFEFFFFFFFFFFFEFFFFFEFFFFFEFFFF
FEFFFFF8F9FEFEFFFFFEFFFFEFEFEFFFFFFD5E5F5A858480FFFCFDFFFEFABCB9A6F6FCDA
D0E3B5BFE5ACC5FAC2356F4793C5C4E3FFFFEDFFFFF2FFF3C5D6B2D3E6B9CFE6B8BCD7A2
CDE9AECAE3AAD2E8BAE8F7D8F7FFEFFCFFF4FEFFF3FFFFEDFFFFE3CDD6A789975C9BAF6A
C8DE95DFF7ADD5F1A6C7E494D1EE9ACEE9A6E0F2D8F7FFFDF8FFFAF4FFE8E6F7C3D2E5A5
CEE0A2DDEFB3E5F8C1ECFFC8CDE5A7D8F2B5E3FEC7F4FFDCF8FFE1FAFFE3F9FFE8F9FFEC
F7FFEFFBFFF3FFFFFAFFFDFBF9E8EEEEDAE3D4BFC6FFF9FFFFF8FAFFFDFAFFFFFAFEFFFA
FFFFFBFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
E7E7DFBCB8B7413944FEF3FFFDF1FBFFFCFAF0E5D16D6443B4AC85FFFAD4FFFFE6FFFFED
F2F0E1FFFFEFF2F9DAF9FFDBD8DDB49B9E7397986EB3B188D6D5A7DDE1AEEBF7B9CBDF97
D1EE9AC4E78DC9F097E0FFB5EFFFCBF1FFD7F3FFE0F6FFE5FBFFE4FAFFE4F8FFE8FAFFF1
FCFFFAFCFFFFFEFFFFFDFEFFFEFFFFFEFFFDFEFFFBFEFFFBFEFFFDFEFFFFFEFFFFFEFFFF
F4F2F5FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFF0F2F1EFF1F0FCFFFFF2F6F5FCFFFFF9FFFD
FBFFFF8389877379777E84826165660001023A3B3D8A8A8CF9F5F6FFFCFEFFFCFDF5E9E9
FFFBFA9A8C8B8C7E7BFAEDE7FFFCF6FDF3EAC4BAB1A699919C8B81AD9A93A99A93C3B8B2
FFFEF8FFFAF2837D71070000827D5FC8C59CD8D8A6D5DDA4D2E2A4D4EAAAD2F1AEC3E1A5
C9DFB0D6E7BDF2FFD7F7FFDAE7FEC8DCF5BBD1EEACC9E8A2CBEBA2CAEAA1CCEAA4CDEAAA
D4EDB6DFF5C6EFFFD9F9FFEAFEFFF6FFFFFBFFFFFDFFFFFDFFFEFFFFFFFFFFFEFFFEFFFF
FEFFFFF5F6FAFEFFFFECEEEDFEFFFDF4F6F3FBFDF8686765DFD4DCFFF7F6494D34F9FFE6
C1D0BBC9DFC8CAF0C18BBA906FA597B3EAE5CDFBEEE9FFF8EFFFECF0FEE4F5FFEAF5FFE6
ECFFDAE6F7D3E5F3DAF1F9EAFBFFF9FEFFFBFFFFF8FFFFF1FDFFE4EFF8CD9EAB73A5B974
C6DC93D8F3A6CEEA9DC4E395CDE99FD0E7AFE4F3DEF5FFF9F2FFEDE8F7D6DEEFB8D0E3A3
DCEDB6EBFDC9F1FFD6F0FFD3CBE5A8CFECACD5F3B7E2FDC6E5F7C5E2F2C5E4F5CBE3F3CF
E0EDD1EEF6E1FFFFF3FFFCF7FFF5F6FFF0F6CAB3BBFFF8FFFFF5FBFFFCFDFFFEFDFFFEFC
FFFFFDFFFFFDFFFEFFFFFFFDFFFEFFFFFFFDFFFEFFFFFFFD
3F3637786F74FCF1FFFFFAFFFFF8FFFFFDF8EEE6CFA7A17D837E56FFFFDDFFFEECFFF9F1
FFF7F6FFFCF8C2B8ACB9AD9D6C5E51BEB1A0887962615434D9CDA3E0DBA4D7DA97D5E293
D5ED97C8E68EC4E690D3F5A8E3FFBFE1FCC5E1F7C9ECFBD4E9F4CCE6EDCBEAF0D6F7FBEA
FEFFF8FEFFFDFDFEFFFEFFFFFEFFFFFEFFFDFEFFFBFEFFFBFEFFFDFEFFFFFEFFFFFEFFFF
FFFEFFFFFEFFFFFFFFF7F7F7F7F7F7FFFFFFFEFFFFFEFFFFFEFFFFF6FAF9B0B4B3CCD0CF
292D2CA4A8A7B0B4B3BBBFBEE6EAEBFCFFFFFEFFFFFBFBFDFFFEFFE5E1E2FFFDFDFFFDFB
FFFCFAFFFCFAE0D5D16158515047406158517A716AB1A79DE2D2C5D8C6B89C8E8394877E
A0938BB3A69ED4C3B98E7D6B9D8C72DCCEABF4E8BEFFFFD3C7CE9ACEDFA8CBE4ABD5EDBB
E5F3D0EEF9D9F9FFE2F9FFDFE7F9C7D7ECB3D2EBAAC7E09CCBE69FCAE5A0C9E3A2CBE3A9
D3E9B8E3F5CDF1FFE0FBFFEDFFFFF6FFFEFBFFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFFFFFF
FFFEFFF6F6F8F6F7F9FEFFFFF5F7F4FCFFFDFBFFFAF3F1F293818D857679C2CDAFF5FFEA
E9F2F7E7F0F5C8DBBFA2C59B508D6C59A2877CBDA7BDF0DFEEFFFBEBF7EDF2FCF1F5FFF2
F9FFF4F9FFF6F8FFF8FAFBFDFBFAFFFBF9FCFDFCFAFFFFF4FFFFE8F5FCD3B2BF89C6D997
D4ECA2C9E598C0DF8FD0EEA4CAE2A6D3E5BDE7F5E4F2FEF2E3F1D7D5E6BAD1E5A6CDE2A1
E4F6C4F2FFDAF4FFE3F1FFDCC9E5AACAE9A6C8E7A4CCE9A9CCE4A8CBE0A7CDE1AECDE0B3
D0DEBAE7F0D3FEFFEDFFFCF3FFFAF8FFF8FBC6ABB2FFF6FFFFF4FBFFFAFFFFFCFFFEF8FA
FFFEFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFF
070000887D83FDF3FEFFFBFFFFFCFFF3EFE3F6F5D6B0AE8576744BD7D2B2FFF9EDF2E2E2
BCA9AFAC979E7964637C6762D4BFBEFFF9F48771636E5A3FD4C398E1D69EE7E4A1DDE497
CDDE8ED7F09FCFEBA0C0DE98C5E2A2CEE6ACCEE0AED1DEB0DAE1B7D6DAB5E0E3C6F6F9E4
FFFFF4FEFFFAFCFEFDFEFFFFFEFFFDFEFFFBFEFFFAFEFFFBFEFFFDFEFFFFFEFFFFFFFEFF
FFFFFFF2F0F1FFFFFFF9F9F9FFFFFFFEFEFEFCFEFDF2F4F3FEFFFFFEFFFFD8DAD9C4C8C7
7A7E7DE5E9E8FCFFFFE9EDECF8FCFDFAFEFFFEFFFFECEDEFFFFFFFFFFEFFF6F2F1FFFDFD
FFF7F5FFF7F4FFFAF7AAA39DB1AAA4B0ACA3D4CDC5FFFEF3FFFDEDFFFDECE6D8CBD7CAC1
695A5363524B8F7B72765F515E452F977F63C9B695FAF1C8E7E8BED9E5B7C0D3A5CBE0B9
F7FFE8FCFFEDFCFFE8F8FFDEDDEBBACADCA2D4E8A9CFE4A1D0E5A2D1E6A5D0E4A9CEE0AE
D4E3BAE4F2D1F6FFE7FEFFF1FFFFF8FFFEFBFFFCFDFFFDFDFFFDFFFFFEFFFFFDFFFFFEFF
F9F7FAFFFFFFFFFFFFFEFFFFF2F7F3F1F7F3FBFFFBF9F8F6D5C0C9160606B7C4AAE9FCE6
F9FFFFFCFDFFC5CBBFD7F1CC5B9A653184503D8D7068AA9CE4FFFFF5FFFFFCFFFFFEFFFF
FAFEFFFCFFFFFEFFFFFFFEFFFFFDFFFFFAFFFFFCFBFFFFF4FFFFE9EBF1CBC2CF9AC7D99B
D1E8A2D6F2A7CFEEA2CAE7A4D5EBBDE0EED4F4FFF4F7FFF3DFEFCBCFE1ADD0E5A2D1E7A7
E4F7CAF1FFE4F4FFECF0FFE2CBE8B0CEEDAAC7E8A1C5E4A0CDE7A8CBE3A9CCE5AECBE1B2
D0E2BAEBF6D8FFFFEDFFFFF3FFF0EBFFEDEFB89DA4FFEDF6FFF1F8FFFAFFFFFBFFFFFDFF
FFFDFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFFFFFDFFFFFEFF
8E8586C4BBBEFDF6FEFFFDFFF7F6F1FFFFEDDEE5BCE6EEBDC0C396878765857D728D7D80
89737FC9AFBCFCDFE3FFF5F4FFF5F2FFF2EB745F4CDEC9AAEAD8AAE8DCA2E3DE9E9D9E5C
899251B6C687D1E5A8D4E9B0D9ECB4D5E6AFCFDCA4D7E0ABD8DBACD5D5AFE0E1C2FBFAE5
FFFFF3FFFFF8FBFBF9FFFFFDFEFFFDFEFFFBFEFFFAFEFFFBFEFFFDFEFFFFFFFEFFFFFEFF
FFFFFFEAEAEAFFFFFFFFFFFFEAEAEA868686ACACAC989898E8E8E8FEFFFFF0F2F1F5F7F6
FEFFFFFEFFFFF9FBFAFEFFFFF8FCFDFCFFFFFEFFFFFEFFFFFFFFFFF5F3F4FFFFFDFFFEFD
FFFEFBFFFBF7FFFEFAF8F3EFFFFCF8FDFAF3FFFEF8FCF8EDFFFDEDFFFEEDFFF6EAFFFDF3
F7EAE4FFF3EFF7DFDBDEC3BAF7DACCE3C8B5B59F8778694CF0EDCEF0F7D6E8F9D7E2F5D9
F9FFF4FBFFF4EBF5DCE7F3CFD4E1B3CAD9A0DDEDAFD5E5A4D4E4A6E0EDB5EAF4C2E9F1C8
EBF0D0F4F8E1FFFFEEFFFFF4FFFDFAFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFFFFFDFF
FFFEFFF7F5F6F9F9F9FEFFFDFCFFFDF4FAF6FBFFFDF8F7F3FFF4F5867470545B4B424F46
F8F9FFFDFAFFFAF8FDD9EBD1BBF9B097EB9E75CFA9449284A0D1CEEEFFFFFEFEFFFFF8FF
F9F8FFFEFDFFFFFDFFFFFCFFFFFDFFFFFDFFFFFEFAFFFFF1FFFFE8ACB28CA7B381CBDDA3
D4EDACBFDD97C0E097D0ECB1E8F9D9F0FBEBF9FFFAF9FFF1E1F2C6D0E4A7D2E9A1D5EBAB
E3F4D0F2FFECF4FFF3F0FFE8CAE7B1CEEDAAC9EAA3C7E8A3CDE9AFCBE6B3CCE6B7C9E2B8
CCE2BEE5F4D7FBFFECFBF7EBFFFCF6FFF9FAD3BAC0FFF7FDFFF9FDFFFAFDFFF4F8FFFDFF
FFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFF
FFFEFBFBF7F6FFFEFFF9FAF5F9FFF0FBFFE6DEECBBD2E1AAD2DCAACFD3B0E0DCD0D8CCD0
EFDBE7FFF6FFFFF2F6FFF7F2FFFCEDFFFEE8564728F5E6BFDCCE9DE9DCA7C3BA835B5823
585A29757C50889369919C71939C6D8B945FA4AA6ED6D9A0DFDEAEDAD6B0E6E3C4FEFCE5
FFFFF3FEFEF6FAFBF6FFFFFDFEFFFBFEFFFBFEFFFAFEFFFBFEFFFDFEFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFF4F4F48A8A8A000000A7A7A7E7E7E7FDFDFDFFFFFFFFFFFFFAFCFB
FFFFFFF5F7F6F7F7F7FEFFFFFEFFFFF0F1F3FEFFFFFAFCFBF8F8F8FFFFFFFFFFFDF7F6F4
F5F4F0FFFFFBFEFAF7FFFFFAFFFFFAFAF7F2FFFFFAFFFEF5FFFFF1FBF5E7FFFEF4FFF9F1
FFFCFAFFFAFAFFF1F0FFF7F4FFEAE2FFF8ECFFF1E15C4B39FFFFECEFF4DEF8FFF1F5FFF4
F7FFFAF1FDF1D0DEC5D3E1BED2DFB1CFDEA5DFEDB0CDD99BD4DDA4EBF1C1FFFFDCFFFFE4
FFFFECFFFFEFFFFDF4FFFCF7FFFCFBFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFDFFFCFD
FFFDFFFCF8F7FFFFFDFCFEFBF7FCF8FBFFFDE7F0EBFFFFFAFFFCF39E9085F0EFEA686C6D
F8F6FFFFFCFFF3F0FBF7FFF1AFE494BCFFB198F4C32A7F6C5C9898E6FFFFFEFDFFFFF9FF
FFFDFFFFFEFFFFFDFFFFFAFEFFFBFAFFFDF7FFFFF3FFFFECFFFFE1989E78B2BE90D3E4AE
DBF0B7CAE4A7D0EEAED7F2BFF0FDE9F2FCF3F9FFF8F8FFEBDEF1BACEE39ECFE79DD0E6A8
E4F7D7F5FFF6F4FFF6EFFFEAC6E1AEC9E8A5C8E7A1C9E7A7DCF8C7DAF4CDDBF5D0D6F0CD
D9EDD1F0FFE8FCFFF3FFFDF4FFFBF7FFFAFADDC7CAFFF9FBFFFAFBFFFBFBF9F4F1FFFFFD
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FDFDF5FFFFF8F6F9F2FBFFF6F8FFEDF7FFE1D3EBB1CFE7A9CEE1AAD8E4BCF8FAECFFFDFD
FFF5FFFFF8FEFFF9F4FFFAE5E0DEB7D2D6A467673393905BA19A666156288B8259F3EDCB
FFFFE5B7B79FA3A38BA0A084B7B890ABA978656124E0DA9EDAD4A4FEF6D1ECE5C8FFFFEA
FFFFF3FBF8F1FFFFFBFFFFFDFBFDF8F8FDF7FBFFF9FCFFFBFEFFFDFDFEFFFEFDFFFFFEFF
FFFFFFFFFFFFE5E5E5343434000000EAEAEAFFFFFFFBFBFBFCFCFCFFFFFFFCFCFCFAFAFA
FFFDFEFBFBFBFCFAFBFFFFFFFFFFFFFEFFFFFCFEFDF9FBFAFBFDFCFEFFFFFEFFFDFFFFFD
FFFFFDFFFFFDFFFFFDFFFEFAFDFCF8FEFDF9FFFEFBFFFFFAFEFEF4FFFFF6FFFFFAFFFDFC
F7F1F3FFFBFFFFF8FCFFF8FAFFF7F6FFF6F1FFF7EF5D4C42FFFEF4FEFFF6EDF9EFF4FFFB
F4FFFDEFFFF3CEE0C6DDEFC9C6D6A5D8E7AEE5F0B4A9B176949665898760ADA68AF5E8D7
FFFBF1F2DFD9EFDCD8FFFAF8FEF2F2FFFCFDFFF3F5FFFBFDFFFBFBFCF0F0FFFBFBFFF5F4
FCF2F3FFFEFBF8F4F1FEFFFAFEFFFDF5FBF7F9FFFDFBFEF5FFFBE7BCB3A2FFF5F6BEB4BD
6F6A71B0ADB4FBFBFFF5FFF1B9E397B9FC9F98EEAFAAFFDF2B7370D3FFFFFCFEFFFFFAFF
F7F5FAFEFFFFF5F5F3FFFFF8F6F4E5F7F6E1FFFFE8FFFFE4D4D5B3989D75D1DAAFCEDBAD
CADCACDEF4C3C2DDA8F2FFE1F8FFF6FBFFFBEEF9E9F9FFE6EFFFC6C6DC91C9E195D6EBB0
DDEFD5F5FFFAF3FFF8F4FFEFCEE6B4C6E3A3D3F0B0C8E3ACECFFE2F2FFF1EFFFF1E8FFEA
F4FFF4F7FFF6FBFFF8F5F4EFFFF6F4FFFAFADCC9CBFFF8F8FFF5F4FFFAF7FEFEF6FEFFFA
FAFEFDFAFEFFFCFFFFF4F8F9FCFFFFFCFFFFF8FCFDFCFFFF
FEFFF6FEFFF6F9FFF6F9FFF3EFFFE2EAFFD3D1EDB0D0EDABCAE1A9D5E5BEF3FCEBFFFFFD
FFFBFDFFFCFAFFFDEDFFFFDDCFDA9EE6F7B08B9853575D2163612EA7A27AFEF7DBFFFFEC
FFFFF3FCF5EBFFFFF3FFFFECFFF9D7DFD7A89C9056F2E6ACEDE0B483765461553B59513E
B2ACA0FFFEF8FDFCFAFCFEFBFEFFFDFCFFFBFAFFF8FCFFFBFAFCF9EDEEF0FFFEFFFDFCFF
F0F0F28989890000006E6E6EFFFFFFF5F5F5F9F9F9FFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFCFAFBFAF8F9FFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFF7F9F8F9FBF8FEFFFD
FCFCFAFDFDFBFFFFFDFFFFFDFFFFFDFFFFFBFEFAF9F8F7F3FFFFFBFAFBF6F6F8F7FFFEFF
FFFEFFFAF5FB7669700E0001947E80FFF9F6FFF9F45D4E47F2EAE7FFFFFDF9FFFFE7F6F3
F2FFFDF0FFF4CADEC2C6D8B0D0E1ADFCFFCFD1D99E61642FC1BE95C2B99CA5958674615A
5D4845674F4F674D4E543E40C3B5B5FFF5F6FFFCFDFFF5F7FDF1F1FFFBFBFFFAFAFFFCFA
FFF9F9FDF3F2FFFEFBFFFFFBF3F5F2FCFFFDFBFFFDF7FDF1FFFFE9E7E2CEFFF5FBFBE9F5
FCF1F5706E6FDEE2E3F7FFF1DAF7B7B7E897BCFFC088DBAD347F7ADAFFFFE2EBF2FFFBFD
F8FAF9FBFFFBF7FDF1FEFFEFFFFFE8F4F8D7D3D5B0D9DBB4979972BABF97E6EEC7D9E3BE
CAD9B2F2FFDCF4FFE2F5FFE8E9F3E8FBFFFAECF5E2D1E0B7CCDF9DCFE696D9EFA4C8DDA4
E2F1DAF3FFF7DCE9DFD4E4CAB5CB9CDBF3B9F1FFD2F1FFDBF5FFF3F5FFFBECFCF2F5FFFB
F5FFFBF0FBF3F8FAF5FFFEFBFFFBFBFFF3F4574545FFF7F4FFFCF8FDF9F0FFFFF6F2F5EC
F7FCF8FBFFFFFCFFFFFBFFFFF0F4F5F9FFFDFCFFFFFBFFFF
F7FDEFFBFFF4F4FFF1F4FFEDD0E3C3CFE6B8C8E4A9CCE8ABD0EBB6D9EDC8F1FDEFFBFFFD
FFFFFDFFFFF3FFFFE4FAFFCECBE695C5E68BCFE696D6E5A4DDE0B1F3F0D1FFFFEFFFFBF3
FFFDFAFFFCF8FFFCF2FEF7E4F3EACBDED2A892824E99875598865E9E8D6FB5A58E5C4F3F
A59B92FFFEFAFBF9FAFEFFFFE8EAE7FCFFFBFBFFF9F4F9F3FEFFFDFEFFFFFFFEFFFBFAFF
FEFFFF0103028A8A8AF2F2F2FAFAFAFFFFFFF6F4F5FFFEFFFFFEFFFAF8F9F5F1F2FBF7F8
FFFEFFFFFEFFFFFEFFFEFAFBFFFBFCFBF9FAFFFDFEFFFFFFFFFFFFF8F8F8FBFDFCFEFFFF
FEFFFFFDFFFEFBFBFBFBFBFBFFFDFEFFFFFDFFFEFFFFFEFFFEFCFDFEFFFFF9FCFFF7FAFF
F6F9FFF9F8FF99949B4A3F45CFBFC0FFF1EFF6E4E06D5E59FFFCFBFFFEFFFAFEFFF8FFFF
F3FFF8F4FFF1D3E4C4D0E1B5D2E1AAADB87E818650BEBD8FF1EBCBFFFDEAFFFAF4FFF8FA
FFF7FBFFF7FBFFEDF0EBD5D770646650474A857B7CB2A6A8D4C8C8FFF9F8FFFBFAFFFBF8
FFFBFAFFF4F2FFFDFAFFFEFBFFFFFDFBFDFAF4F8F7FCFFF8FCFFECC6C4AFFFF7F9FFF6FF
FFFAFF76736E7A8072E2F0D6E1F0C9CBE9B3B2ECA2BEFFCB3D857ABEF5FCF1FFFFF7FEF6
F4FFF8F5FFF8F8FFF1EAF7D9F2FDD5EEF5C9D8DEAED9DCADA4A77CD1D5B0BFC5A3D8DFC0
DEE7CCF9FFEAF8FFECF1FFE6FBFFF6FBFFF4DFE9CEDAEABBDAEEA6C8DF8DCAE095D0E3AC
E5F3DCEAF5EDF8FFF6DEECD2CEDEAFD7E8B4F1FFD7FBFFEAEFF6EEFBFFFFFBFFFFF3F9F7
F7FDFBFEFFFFFFFEFFFFFBFCFFFAFBF9E5E7917D7EFFFAF8FFFBF5FFFFF4F0F0E4FEFFF6
FEFFFBF4F9F5E8EAE9FCFFFDFEFFFFEEF3EFFEFFFFFCFFFD
FBFFF6FBFFF6F9FFF8F8FFF3CBDBBECADFB6D0E9B2D6EFB8E3FACCE8FBDDF5FFF8F8FFFF
FAFFFAF1F9E4ECF4CBE3F6B6D4F99CBAE281D1EE9CC4D899CCD4ABE6E6CEFFFFF4F5F0EC
FCF9F4FFFFF6FAF7E8F3EFD6DDD7B5DED5ACC1B386BEAD81C5B190FFFBE3DBC8B7847369
C9BBB8FFF9FAFFFDFFFBFBFDFEFFFFF8FDF9F8FDF7FBFFFAFEFFFDFEFFFFF9F8FDFFFEFF
F8F9FBE6E8E7FFFFFFFFFFFFFFFFFFF8F8F8FFFEFFFBF9FAFDFBFCFFFEFFFFFEFFFFFEFF
F9F5F6F9F5F6FFFEFFFFFDFFFFFDFFFFFCFDFBF7F8FAF8F9FFFDFEFFFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFFFFFCFCFCFCFAFBFFFBFCFFFCFDFFFCFFFFFAFFFFFDFFFEFEFFFBFFFF
FBFFFFF2F5FE737278040002847878FFFBF65A4942C7B8B3FFF9F8FFFCFDFFFDFFF2F4F3
F1FCEEF9FFECD6E2BEC0CC9EE0E9B29FA46C60602EFFFFDCFFFEE8FFFCF3FFF5F7FFF8FF
FFF8FFFFF3F8FFF9FAFFFBF8FFFCFDFFFDFFF0E7E8C8BEBD998D8D5D4F4E5B4C49B7A8A5
FDEEEBFFFBF8F5EBE9FBF3F0FFFEFDF6F6F4F7F9F8FCFFFAFBFFF1A5A696FFF9FAFFF1F7
FFF3F6FFFEF86D725C313B22FCFFEFF3FFE4C1E9AAC9FFC6114E3EABE1E1E0FFFAF0FFFA
EFFFFCEEFFF7F2FFF1F5FFE6EDFDD0EFFCC7E6F0BBD0D7A3A8AE82E6EAC5D6D9BCFFFFEC
FAFFEBF8FFEDFAFFF0FBFFF1F1F8E6FCFFECECF8D4CBD9A4C4D98CD6EC99ECFFB9F8FFD6
F8FFEFBBC5BABDC6B3909B7BCAD6A8DCE5B8FEFFE8FFFFF3FCF7F4FFF6FBFFFCFEFFFCFE
FFFDFFFFFCFDFCF0F2FFF9FAFFF4F7FFF7FADEC6C6FFF9F6FFF4EFFFFAF1FFFFF4FDFFF4
FAF9F4FFFFFBFBFAF8FFFEFAFFFFFDFEFDF9F2F1EF878682
F8FDF6FCFFFAFBFFFBFBFFF8CFDBC5D1E0BFD9EABEDEF1C4F3FFE2F5FFEFF7FFFFF7FFFF
F6FFF9E4F2D9D5E7B5CFEBA1C8F195C3EE92DBFBB2C4D8A3DBE4C5F5F8E7FFFFF6FCFCF4
FFFFF3FFFFEDECF1D1EAEEC9DCDDB5F0EDC4F5EDC6FEF0CDFFFCE1FCE3CF8C7668AF9C95
F2E4E3FFF6F9FFFDFFFAF9FEFEFFFFEDF2EEFCFFFBF8FDF7F2F4F1FEFFFFFFFEFFFFFEFF
FEFFFFFEFFFFF5F7F6F0F2F1FAFAFAFEFEFEFFFEFFF0EEEFFFFEFFFDF9FAFFFDFFFFFDFF
FFFDFFFFFDFFFFFDFFFEF5F8FFFBFCFFFCFDFFFDFFFFFCFDFEFCFDFFFFFFFEFFFFF8FAF9
F9FBFAFEFFFFFFFFFFFFFFFFFFFEFFFFFAFEFDF7FBFEF5FAFFFBFFFFFCFFF8F5FEF2F5FE
FBFFFFFBFFFF83878A040301827B75FFF7EE5E4D43F2E0D6FFFBF4FFFBF8FFFAFDFFF8F6
FFFFEFFEFFE2DADCB4D4D6A5E1E1AB92915B514D1EFAF4D2FDF1E3FFF7F6FFF9FFFFF6FF
FFF9FFFFFCFFFFFDF7FAF6EDFDF9F6FBF7F8FFFDFDFFFDFBE0D4D4BDAFAEB0A19E7E6C68
E8D6D2FFF8F5FFFBFAFFFCFAFEF8F8FFFEFDFDFDFDFAFCF9FCFFF8A9A9A1E9D9D9FFF3F5
FFF9FBFFFCF6C8C7B2757865747472F7FEF6D6EDC3B8D9AA4672576C9F8EC1F4E3CBF9EC
E7FFFFEBFFFFDEFAE4F1FFE8F1FFD9E2F5BED3E0A8D9E3AEA4AA7ED8DCB9D7D9C1FEFFED
F9F9EDFFFFF6F1F4E9F9FDEEFBFFEBFBFFE2EBF8CCD7E6ABD9EE9FE1F7A4DEF2ABE2F2C1
B3BFA9B1B9ACE0E8D0CBD1AFD9DFB3E3E5BEF4F0E4FEF2F2FFF9FAFFF7FAFFF5F7FFEBEA
FFF6F5FFF9F8FFF2F2FFF6F8FFF3F6FFF5F8DBBBBCF9DDDCFFF1EDFFFBF8FFFEF8FAF5EF
FEF6F3B6ACAA938988B0A6A4CAC0BF827876625857070000
F9FBF8FDFFFEFAFCFBFEFFFBE2E6D8E5EDD6E5EFCDEBF6D6FBFFEFF9FFFAF6FFFFF6FFFF
F6FFFADFF2D6CBE2AAC8E89CD0F8A0BAE490C1DFA1CCE1B6E9F3DBE8EBE0F1F2EAFFFFF3
FBFFE7E7F1CCC9D6A8CBD7A5CFD8A9F3F8CFFDFDDBFFFFE4BFA992917665A89086FFF9F6
FFFAFDFFF7FDFFFDFFFFFEFFEFF0F2FCFFFFFCFFFDF1F6F0FEFFFDF0F2F1C0BEC1FFFFFF
FFFFFFFEFFFFFAFCFBFEFFFFFFFFFFFFFFFFF9F7F8FFFEFFFFFEFFFAF6F7FEF8FAFFFAFC
F9F3F5FFF9FBF9F0F3D7CED1E3D9DAF9EFF0FFFCFFFFFDFFFFFCFDFEFCFDFFFFFFFDFFFE
FAFCFBFCFEFDFFFFFFFFFEFFFFFDFFFFFDFFFFFCFFFFFBFFF7E7F1FFFAFFFFFBFFFFFDFF
FBFEFFF5FAFE7177750001008C887C908778786858786556EDD6CEFFF8F4FFF8F8FFFAF4
D3C6B39E95749B9468A49C6B7D76406059256E653AF5ECCFFFFCF4FFFAFFFFFAFFFEF7FF
F9F8FFFEFFFFFCFFF6FCFFF4EDEEE9FFFEFFFEFAF9FAF2F0FFFCFAFFFBF8FFFAF6F3E1DD
75635F64524EDFD0CDFFF8F6F8F0EEFFFDFDFAF8F9FFFFFFE5E9E8FFFFFFFFFBFADBCBCB
AF9B9AF2E1DAFFFEF1FFFCF3B1B0B80000059DA192D5E4C7C7E2BF628E6D58988075B4A9
8EBABBE2FFFFE0FFF1D1F0D1CEE9BCD1E8B2C9DAA3FCFFD4FDFFDADEE2C1BBBAA5D1CFC2
E0DDD4FEFEF6F8F8F0FFFFF3EBF2D3D7E2B7CEDCA9B9C98A9BB15F82984590A45FCEDCAB
E8F1DCF6FDEDE1E5CAD2D4AFBABB8FFFFFE1FFFCFAFFF8FFFFF1F2DCB4B2C9A3A0C7A6A1
D3B2ADCEADA8C7A4A0FCD6D5FFEDEFFFF2F4EDC6C9F2D0D1A18788705E5E695D5D8C8281
8E7E7E8D7B798F7D7D7A686684727292807EFAE8E8FFFAF8
FFFEFFFFFEFFFCF9FFFFFEFFFEFDF8FFFFF3FDFFEAFFFFEDFEFFF6FCFFFFF4FAFFF5FDFF
F5FFFDE0F4D8C7E3A8CAEA9FBDE495CAEEA8D4EEBEECFDDDF8FFF1FEFFFAFDFFF4E7ECD6
DEEAC2E0F3BCDEF4B4D8EEADD5E8B1F2FFD3E6EFD2FFFFEC907969A3857AEFD3CFFFF9F8
FFF3F9FFF9FFFFFDFFF5F4FAFEFFFFFCFFFFF2F8F4FCFFFBF0F2EF828483828083FFFFFF
F7F7F7FCFEFDFEFFFFFEFFFFF3F3F3FFFFFFF8F6F7F9F7F8FCF8F9FFFEFFFFFDFFFFFBFD
CEC5C8C7BEC1DDD4D7DDD2D6E1D5D7E4D8DAF1E6EAFFFAFDFFFEFFFDFBFCFDFDFDFFFFFF
FFFFFFFEFEFFFBF9FCFBF9FCFFFBFFFFFBFFFEF4FCFBEEF7FFF8FFFFF8FFFFFAFFFDF7FF
FEFFFFFBFFFF7D847D050800858271E7DCC8AB9B84A38D78977B6FEFD1C9D8B9B69E8179
927C658C79587E6D4162521F60511AA69965C7B992EDE1C9FFF9F5FDF3FCFAF6FFFCFEFF
F9FFFFF5FFFDF2FFF2F5FFF4FBFFFBFAFAFAFFFBFAFFFEFBFFF9F7FFF9F6FFFAF6FFEFE9
C6B3AD9D8A86B5A6A3E9DBDAFFFCFBFFFCFDEDE9EAFFFEFFFFFEFFFFFEFFFDFBFCF3EBE8
C5B2ACFDE9E2D9C7C7F8EDF1FAF8FF89889668606D59544EE1EDBFBCE3AE509A813B8A84
5489918FB6BDE6FFFFCCEED5C5E4BBD1E9B7CEE1AAFBFFD5FFFFDDDDE0C1BBBAA8BDB9AE
B5B0AABFBAB6D9D4D0F1F2E2F1F9D4D1DDABA3B279798A469CB25FDCF2A0DBEBAACEDBAD
E6EED7FEFFF1EEF1D2E0E1B9B2AF84DED7BBFFEEF6FFF4FFFFE0E0BB877CB28278D1A59A
D8ACA1AA7F76986B65EDBDB9FFE5E6FFF0F3A072757B52583B1B20260D13C7B6BCFFFAFD
FFF6F8FFF4F2FFF8F8FFF8F6FFF8F8FFF2F0FFF0F0FFF8F6
FCFBF6FFFFFAE8E7E3F0EFEBFDFAF1FFFFF3FAF8E9FFFFF3FEFFFBFCFFFFF4FBFFF5FEFF
F5FFFBE1F6D7C7E3A9CCEBA5CBECA5C6E4A6C7DEB2F6FFEBF1F9EAFCFFF8FEFFF4DEE6CE
DBE8BDD1E2ABCADE9FCADE9FDBE9B8DEE8C37E836D5D594DCAB8AEFFF9F3FFF9F8FDEDF0
FFFAFFFDF3FEFFFCFFF9F8FEF8F9FDF8FCFBFCFFFDEBF0EA696E67646760F4F6F1FCFEF9
FDFFFAFCFFFBF0F5EFFCFEFBFFFFFDFDFDFBFFFEFFFFFEFFEEEAEBDCD8D9DED8DADAD4D4
D2CCCCF1EBEBFFFDFDFFFCFCFFFCFDE6DBDFDFD4D8FDF4F7FFFDFFFFFEFFFCF8F9FFFEFF
FFFDFEFFFDFEFFFEFFFFFDFFFFFDFFF0E7EAC8BFC2ACA0A4E3D0D6FFECF5FFFAFFFFFCFF
FFFEFFF8FCFB7E837D101308939182FFFFECFFFDEAFFFBE96751438A726660483E988074
E4D2BEFFF8DBEFE0B5DBCE99E6D9A2EBDFADD2C5A3FFF6E6FFF7F8FFFBFFFFFDFFF8FCFF
F4FFFEF4FFFAF1FFF3EFFFF0F9FFFAF7F9F6FFFFFDFAF9F7FFFAF7FFFCFAFFF2EFFFFAF6
FFF9F5FFF9F4715E5A71625FF3E5E4FFF7F6FFFDFDFFFDFFFFFEFFEFF0F5FEFFFFFFFFF8
FFFCF3FFEFE7FBEBECF1E6ECFAFBFFF8F8FFC5BDCC9A92905B6238C8E6B4ACECD2B7FEF8
BEF3F7477074E4FFFFD9FCE4C6E6BFC3DDB0D5E6B9FCFFDCFEFFE1FFFFEAFEF4E8FEF1EB
FFF7F7FFFAFAFFF1F1AA9E907D7E56A5AC76DBE3A8DAE3A4D7E19ADAE3A0CCD19BDCDEB9
F8F5E2FBF5E7FFFEE4FFFFE1FFFCDCCCBDA8C3AFB8A08492AB8383CB9F96DAB2A8A07A6F
A07C70C9A49BA27C73875E58AE8080916365714749200000725359BBA4AAF9EAEFEFE0E3
B9A7A7F5E1E0EAD5D4C2AEAD927D7CC9B5B4CBB6B5DBC7C6
747A58DFE4C4DCE1C3D1D5BAFEFFEAFEFFEDF2F6E7FCFFF6FBFFFDF9FFFFF8FFFFF7FFFD
F2FFEEE3F7D4D1E7B6C2DC9FCBE5A4CFE7ABCAE0B1F6FFE5F8FFEFF1FCEBFBFFF3CFD9C1
D7E1BFD0D8AFDBE2B6F1F6CDF8F7D8FFFFEA544C41FFFDF8FFFEFBF9F5F4FFFEFFF8F6FB
FFFDFFFEFCFFFFFDFFF8F8FFF7F8FDFCFFFF6C716B03090080867AF3FCEBFBFFF1FBFFF1
F9FFF2FBFFF4F5FDF0FCFFF8FAFDF6FFFFFBFCF8F7D7D1D1E6E0E2F7F1F3FFFEFDFFFEFB
FDFCF7FEFDF8FFFFF8FFFFFAFFF9F9FFFCFEF8F2F4FEF5F8F9F0F1FFFCFDFFFCFDFFFCFB
FFFCFBF6ECEBB8AEAC867C7A594F4DB3ABA8FFFDFAFFFBF9DCCECDFFFBFAFFFBFBFFF7F8
FFFEFFF6F4F583838300000084837FF9F6EFFFFFF6F9F5E9FFFFF34C4638FFFFF1FFFCED
FFFFF6FCFEE9FFFFDAFFFFC9E2E4A5D1D19DE1DDC0F4EDE5FFFBFFF7F1FFFFFEFFEDF2EE
F9FFF4F6FFF0F5FFF1EBFCE9F9FFF8FBFFFBF5FBF7FBFFFFF9FAFCFFFEFFFFFCFFFFF2F2
FFF9F8FFEDE8EED7D1A28E877C6B64FFFCF6FFFCFAFBF7F4FBFDFAFBFFFAF0F5EEFEFFF8
FFFFF6FEFCF0FDFAF3D8D7D2FBFEF7F2F7F0FEFFFBFAFFF4DCE9CF697D61B7D8C3D1FCEB
E0FFFF3D6B60C8F2DED0F4D8C0DFBDC7E0B9DBE9C6F7FCDEFFFBE5FFFCEFFFF8F4FFECEE
FFF3FAFFF0F8FFF1F8FFF2E8E9DAB1EDE6AFC0B683C1B786E1D3A665562FCBB89A96816E
4A3429ECD3CED9C1B7473124E4CEC0DCC8BDC2ADAACDB9BAFFF9FBFFF2F3FFF7F6FFF8F4
FFFCF6EBE1D8998A83FFF9F2D4BBB62E120F6145445C44441B09090800000400000C0807
E4DEDEFFFDFDFFFCFDF9F3F3FFFCFDFFFAFAF8EFF0FFFDFD
919B66A7B17DD7E1AFC7D0A3DEE9C1EDF6D7DEE7D2F4FCEFF9FFFDF8FFFFF8FFFDF8FFF8
F8FFF1F3FFE4E9FBD1E1F5C4CFE2ABE6F8C6E1F2C8F7FFE7F9FFF1F3FEEEFBFFF3D9E2CD
CED4B8DBE0C0E2E3C1FFFFDE888069625545DAC9C1FFFCFAFFFFFDFAFEFFFEFFFFFEFFFF
FEFEFFF9F9FFFCFCFFFEFFFFFDFEFFADAFAE494E47787E70F2FBE8FBFFECF1FEE2F3FFE2
F4FFE5F9FFECF1FDE5FBFFF1FEFFF3E7E9DEBDBAB5C8C4C1F7F3F2FFFDFCFFFEFBFFFFFB
FCFDF7FCFFF8FEFFF8FEFFFAFFFFFDF4F2F3D5D1D2FFFDFDFFFCFDFDF3F4FFF5F5FFFBFB
F2E7E5D6CBC9B6ABA9E2D9D4F3EAE5FCF5EDFFFAF4FFFEF6D3CAC3C0B5AFFFFDF8F7EDEB
F4ECEAFFFDFF6D686C0F0D10848285FFFFFFFDFDFBFFFFFAF7F8F0EFF1E6FFFFF3F8FEF0
F7FFFAF4FFEFF7FFD8F4FFC7E1F2AEDAE5ADE2E6CBE6E7E1F6F3FEFFFDFFF0F2F1FCFFF4
FBFFECE2F1D2F7FFECF1FFE7F5FEEDF5FDF0EEF5EDFBFFFDFAFEFFFAF8FDFFF7FAFFFBFB
FFF9F8FFF9F3FFE7E0F7DED7847067F2E4DBFFFCF8FFFDF8FFFCF8FFFCF8FFFBF8FFF2EF
FBECE9FFF7F2FFFBF6F8E9E4E4D7D1FFFDF4FBF1E8F8F2E6FEF8EC353326454336D3DBCE
CCE6DB0B2D1FA9C9B4E6FFE9CFE6C9C9DABAC8D1B6F3F2DDE9E2D2F6E5DDE3CBCBAA8B90
B49197CAA5ACEAC3C8E7C7BC8B79538F8351AFA174B4A27CE6D1B4E7CEB8FFF6E8FFF1E9
FFEDE9FFEDEDFFF7F6FFEFEEFFF8F6FFF1ECFFFAF4FFFBF8FCF6F8FFFEFFF2F2F4FEFFFF
F3F5F27D7E78EFECE5878078120300C3B2ABCCB9B5FFF1EDFFF9F7FFFDFA7D7C78E8E9E4
212121656565ABABABF8F8F8EEEEEEFFFFFFFFFFFFF9F9F9
CEDA9AA6B272E1EDAFDEE9B1D5E1AFDCE7BFD9E2C7E6EFDEFBFFFAF9FFFDF9FFFDF9FFFB
F9FFF4F8FFECF0FEDBE9F8D1D2DEB6FBFFE3F9FFE8FBFFF1FBFFF8FAFFF9FCFFF8F0F4E5
FFFFECFBFEDFB3B391595434D7CDB2FFFEE8FFFCEDF4E7DEFFFAF4FFFFFBF2F1EFFDFBFE
FFFEFFFFFEFFF0EFF5FFFEFFFFFFFFC5C7C2B5BBAFEEF5E3F7FFE6D2DDBDD2E1BADCEBC2
CFE0B6CEDFB5DBEBC6CFDDBAFCFFEAD9DEC8E6E8DAFFFFF6FFFFF8FFFFFAFFFFFBFFFFFD
FBFDFAFBFFFCFCFFFDFCFFFDF8FAF7FFFFFDB2B1AFC1C0BEFFFEFDFFFEFBFEF6F4FFFCFB
A39998FFFAF7FFFDFAFFFAF6FFFEFAFFFFF8FFFFFAFFFFF8ACA39AACA298FFF6F0FFFDF8
FFFDFBFFFDFF8E888C030004827D83F0EEF3FCFAFDFEFDFBF3F4EFFFFFFAF2F3EBF9FFF6
C9E5CEC3E8BFC8ECAEC8EAA0C9E59ADEF4B6F8FFE3FBFFF8FBFEFFFCFFFFFCFFFBE4EBD9
DCE7C7D9E8C1BDCDA8DCEAC7D4DAC0FFFFEFFFFFF4FCFCF4F9F5F2FFFDFBFFF7F7FFF1F0
FFF6F2FFF1EAFFF8EFFFF6EB927C719B897FFFF1ECE8D3D2FCD3D9FFDAE5FFD9E4E1AFBA
CD99A5E6B3BCEDB8C2DEA9B1CC99A0CD9CA2EBBAC0FFD7DAEBBEC1D1A9AAC59D9E260C0D
4A4647060F0C0004008F9686C3C8B29FA38AB1B39DFFFFEBD9D6C7FFFAF0FFFCFAFFF5F4
FFFCFBFFFCFAFFFDF8FDF4E5E5DFBDDED7ADFEF6D1F6EBCDFFF1DAFFFCECFFEFE6FFF9F6
FFF8FAFFEDF0FFF7F9FFF9FBFFF5F6FEF0EFFFF8F5FFF7F5FFFDFFF0EEF3FFFFFFF9F9F9
C4C6C3FFFFFAFFFFF8625B53F8E9E4FFF4F0D4C1BDF6E4E0F7ECEAFFFDFAFFFFFBFAFBF6
FFFFFFD3D3D38C8C8C393939444444DDDDDDFFFFFFF5F5F5
D2E095B1BE76BAC781CAD694C8D59DCFDBADCBD5B3EEF6DFF8FEF2FAFFF9FCFFFFFCFFFD
FCFFF8F2F9E7E2ECD3D9E2C5D4DAC0FEFFEDFEFFF4FDFFF9FEFFFFFEFFFFFFFFFBFFFFF6
F8F9E7FFFFE8A29F804F4A2AFFFFE3FFF9E2FFF9E7FFFDEDFFFCF1FDF6EEFFFDFAFFFDFD
E6E0E2FFFDFFFFFDFFFFFEFFFFFFFDFAFBF5FEFFF3FCFFECDFE9C7CEDBB0DEEBBDC7D8A4
CADDA6D0E5ADBFD19DDBEBBEA0AC84F3FDDBF7FCE5FFFFEFFFFFF4FFFFF8FDFEF9FAFCF9
FAFEFFFCFFFFFBFFFFFBFFFFFCFFFDF6F8F3D3D3D1D0D1CCC1C0BCF3EFECFFFEFBDCD7D4
D7CFCDFFFEFBFFFEFAFAF7F2FFFFFAFDFCF7F5F6F1FCFCF4B9B1A6AEA498FFFDF4FEF3EF
FBF1F0FFFBFC80777C05000589828AFFFDFFFFFDFFFBF9FAFFFFFDF3F4EFFAFBF5F9FFF4
B8D3B2BEE3B0CDF1ABCCECA0CCE69CE4F6BAFCFFE4FFFFF6FFFCFFFFFCFFFFFCF6E8E3D0
DDDDBBD7DAAFD8DBAED9DBB3D3D2B3FAF8DFFFFBE8FFF9EBFFFDF4FFF9F4E3D0CCFFEDE9
FADFD8F5D8D0FFF7EBF6DCCF8B73675E4A41D1C0B9C8B0B0D6ABB4E4B0BCF8C4D1D59FAC
C48E9CE4ACB9E4ACB9E1A9B4FFD2DDF5C0C8C39099FFD7DDFFF0F6FFE1E4DCB2B69C7C81
2D1E252F292D635E5BEEEADFFDFAE9FBF8E5CCC9B6FFFCEBFFFFF4FFFFF8FFFFFBF7F9F6
F9FFFBF4FEF6F8FFFAFBFFF3E4E7CAE3E2C3E4E0C5FFFFEAFFFEEFFFFDF4FFF6F5FFFAFD
FFF0F5FFFAFFFFFAFFFDF2F8FFFBFFFFFCFFFFF9F9FFFDFDFFFDFFECE7EBFCFAFDFFFFFF
D1D3D0FFFFFAB8B5B0BEB7B1FFF5EFFFF6F2B9A6A2E9D7D5FFFCFAFFFDFAF2F1EDFFFFFB
F9F9F9FFFFFFE9E9E98888883A3A3A6D6D6DDBDBDB888888
D7E695CFDE8DB1BF72A9B66EBCC88ACFD9A5979F78F1F7DDFCFFF2FDFFFAFFFFFFFFFFFF
FBFCF7F1F3E8E4E7D6DCDFCEE0E0D4FDFAF5FCF8F9FFFBFFFFFDFFFBF8FFFAF8FBFFFFFA
FFFFF3FFFEE9807A603E371AFFFFE3FFFCE2FFF0D9FFFDEAFFFDEDFFFDF1FDF0E8FFFCF8
FFFCFDAAA1A4120C105A5657FFFEFAFEFFF5F9FEEAFCFFE6F2FDD3D6E4B1D7E6ABD0E3A3
D5EAA7CFE6A2E3F7B8AFC187B1BF8ED5E0B6E7EECDC8CEB4FCFFEFFAFDF2F9FBF6FCFEFD
FCFFFFFCFFFFFBFFFFFAFFFFFCFFFDE9EEE7FEFFFBFFFFFAC9C8C3C7C4BFC3BFBCD4D0CD
FFFEFBFCF8F5EFEBE8FFFFFBFFFFFBFAFCF7FCFEFBFDFCF7D8D0C5D5C9BDCCC2B9DED3CD
C7BCBAF1E7E87A6F75251C21857B83FFFCFFFEF9FDFFFEFFFFFFFDFFFFFBEDECE7CBCFBE
D8EAC0D5EDB1D7EBA4D0E095D5DF9AF3F3BDFFFEE4FFF3EDFFF6FFFFE5F1FFF6F6D2B5A7
C2A789C6AF85B7A1729F8D5FA59C75B3AD8DB2A88FC9BCA9D5C3B7C9B5AEB09792DABEBA
FDDFD7B99B9172564A6C5245654D41B29E95F7E4DEFFF7F5FFF4F6FFF0F2FFF8FDFFF8FB
FFEDF3FFF7FBFFF7FBFFF7FAFFF7FAFFF9F8E3CDCFFFF7F6FFF4F2FFF5F0FFFBF8FFF8F8
EADEE80D010B6C6165FBF2EDFFFEF3E3DDCDFFFFEFFDFBECFFFFF5FEFFFAFBFFFDF8FFFF
F5FFFFF0FFFDE0F5ECE5FAEBF8FFECFBFFEAEDF0DDFFFFF4FFFFF8F6F2F1FFFDFFFFF9FF
FFFCFFFEF6FFFFFBFFFFFCFFFDFAFFFBFAFFFEFFFFFAFAFCFFFDFFFFFDFFF2F0F3FBFBFB
9EA09DAEAFA973726DBBB4AEFFFBF8FFFBF8FFF8F6FFF0EDFFF4F2F7EFECFFFFFBFFFFFB
FFFFFFFFFFFFFFFFFFE9E9E9FFFFFFFFFFFFEFEFEFFBFBFB
DBE99AE1EFA0DBE99CC0CD87D5E1A3DFE7B47E845EF3F5DDFFFFF4FFFFFDFFFDFFFFFCFF
FEFAFBFCF9F4FAF7EEFAF7EEFDF5F3FFFBFFFFFBFFFFFBFFFFFBFFFFF9FFFEF7FEFFFDFD
FFFEF5FFFFF1ADA592726751594D3563543DF9E8D4BDAC9A4C3B2B6250445F4E46E4D5D0
6C5E5E190D0FFEF5FAFFFDFFFFFBF8FFFFF4F9FDE6FAFFDFEEFACAC4D297C1D190DEEFA8
C5D991D4EAA1CADE9991A365CBDAA3E1EDBFCCD4AFDADEC3FFFFEFFEFFF3FEFFF9FFFFFF
FEFFFFFEFEFFF9FCFFFAFDFFFBFDFAFEFFF8FFFFFAF6F7F1FFFFFAEFECE7ABA6A3FFFEFB
F9F4F1FFFEFBFFFEFBFFFFFBF3F3F1F7F9F6FEFFFDFAF9F5F9F0E7FFFCF3FFFDF4F9EEE8
E5DAD85C50526A5E6207000092878BFBF2F5FFFAF7FFFEF9F8F8EEFFFFF4DADBCDD9DFC3
C9DAA6C4D996CADA91D1DD95D8DD9DDEDAABCABBA6A68E8CB696A1E2C1CCE9C7C8664438
DEBFA0DEC195624614C6B17CC5BA8CE2DAB3ECE1C3FFFDE6FFF8EAFFF3E9FFF3EFFFF7F3
9A7C74765A4F6E53488D7569DCC8BFFFFAF3FFFAF6FFF3F2FFFEFDFDFDFBFFFFFFFFFFFD
FCFBF9FDF9F8FBF7F6FFFCF9FAF6F3F8F7F2CBCAC6FFFFFAFEFFFAFCFFF8FBFFFAFCFFFD
FEFEFF54525D07050AD6D5D1FCFCF2FFFFF3F3F1E4FFFFF4FAFBF3FEFFFBF5FBFBEEF8F7
F0FEFEF4FFFFF2FFFFF4FFFBF0FCEEF3FBECFCFFF8EBF0EAFCFEFDFDFEFFFFFEFFF8F7FF
FFFDFFF8F6FFFEFEFFFEFEFFFCFFFFF6FBFFFBFFFFF8F9FDE8E2E6FFFCFFFFFEFFFFFFFD
2D2E29050601010000FFFEF8FFFCF8FFF9F6FFFBF8EADBD8FFFCFAFFFDFAFFFFFBFCFDF8
F9F9F9FDFDFDE6E6E6FFFFFFF8F8F8FAFAFAFFFFFFFFFFFF
CED995D7E29ED9E4A2DAE4A7DFE8B1B8BE90B7BB9AFFFFEDFFFFF8FFFEFFFFFCFFFFFBFF
FFFBFFFFFCFDFFFDFAFFFDFAFFFBFFFFFAFFFFFAFFFFFAFFFEF2FEFFFBFFFFFBFFFFFCFF
FFFDFBF9F0E9FFFDF1F8ECDEF0E3D3C7B7A77B6A5A7D6A5BC1AB9D856F622F1B12402D29
C9B6B8FFFAFDFFF8FEF9F0F3FFFFFAFFFFF4DDE1C8D1D9B2E0EDB8D9E9AAD5E69FD5E79D
DAEAA3D0DF9AD8E7A6677538E8F2BDD1D8ACD7DDB7E4E7CAFFFFEDFFFFF3FFFFF8FFFFFD
FFFEFFFDFAFFFCF9FFFFFDFFFFFFFBF9F9EFFDFAF3FFFCF5FDF8F2FFFEF8FFFBF8FFFDFA
FFFDFBFEF6F4FCF6F6FDF9F8FFFEFFF1F1F1FFFFFFFAF9F7FFFDF8FEF4EBF4E7E1FFFBF8
F9EBEAFFF8F88D7E81120606695F5DB3ACA6EBE7DCDAD9C7DFE1CBC8CAB2C7CCAEDFEAC0
B0C98895B46887A1578CA059A7B57AD6DBB2FBF6E2FFF4F0FFF9FFFFF8FFFFF9F8FFEFDF
FFFFDCF5EBB8F8F0B2DDD799E7E4AFDBD7AAD7CDAAFFFDE4C9B4A383685F9F827EB0938F
B39793CAB3ABFFF1E8FFF0E6FFFBF4FFF5F2FFF5F5FFFCFDF9FDFCEFFAF6EEF8F7F9FFFF
F9FFFFF6FCFAFBFFFFFBFFFDFBFFFDFBFFFBD6DCD8F9FFFBF1FCF4EEFBF1F5FFFBECFDF7
E2F7FC72868D5F737460716BF6FFF9F8FFF6EBF1E3FEFFF6FCFDF7FFFFFDFFFDFFFFFEFF
F9F8FEFEFFFFF5F9F8F5FAF6FBFFFBF9FFFBFBFFFDF3F9F7FAFEFFFCFFFFFCFFFFFCFFFF
F2F4FFFCFEFFFCFFFFEFF2FBFBFFFFFBFFFFFBFFFFFEFFFFFFFDFFFFFBFCF4EEEEE9E8E4
0E0F0A6B6C67CDCCC7FBF6F2FEF4F2FFFBFAE6D6D6FFF9F8F6ECEBFFFEFBECEBE7FFFFFB
FDFDFDFFFFFFFFFFFFFBFBFBF7F7F7FFFFFFE7E7E7FBFBFB
FFFFD4FFFFD4CED6A3E5EDBCC8CEA2646845F5F5DBFFFFF1FFFBF7FFFCFFFFFBFFFFFBFF
FFFBFFFFFAFBFFFAF8FFFAF8FFF7F9FFF6FAFFFBFFF7ECF2E7DCE2FFF6FEFFFCFFFFF8FB
FFF8FCFFFAF9FFFCF8FFFCF6FFFBF4FFFBF3FBE8E1FFFAF1F0D8CC250A00210801C2ADAA
FFF9FAFFEFF2FFFBFFFFFBFBFFFCF7FFFFF3E2E8CCD1DCB4D2E1AACFDF9ED3E59BCFDF96
DDE9A7D2DC9FD4DDA4818A53C7CD9DE1E6BDDDDEBCD4D4B8FFFFECFFFEEFFFFDF4FFFEFA
FFFCFCFDF7FBFFF9FFFFFDFFF7F2EEFFFEF6FFFEF6FFFDF6FEF5F0FFFCF8FFF8F6FFF9F7
FFF8F8FFFCFBFFFCFDFFFAFAFFFDFFF6F2F3FFFEFFFFFEFFFFFDFAFFFBF7FFFBF9FFFBFA
FFFAFAFFFBFBF5E7E62E201D5F554CD8D1C1FFFFECFFFFE6FDFFDEFCFFD9FFFFDAF1FFC9
C8E39CC3E397CEE9A2D5EBADD7E7B8E8F2D0FCFEF0FFFDFAFFFCFFFCF2FAFFFEFBFFFFEF
FFFFDDEDF4C0DAE3A0D2DC97D2D79DE2E4B3E2DDB7FFFEE3C1AB9DB49992FFF7F4FFF7F6
FFF9F6FFFBF4FFF5EFFFFDF6FDF3F1FFFCFBFCF0F4FFFBFFFCFFFFF8FFFFF7FFFFF9FFFF
FBFFFFF0F6F4FCFFFFF2F6F5F2F7F3FCFFFDC7CCC8F1F7F3F9FFFBF5FFF8F1FCF4F2FFFF
E6FFFF153C41000B09BCDBD5DDF7EAE8FDEEF8FFF8F0F8EDFFFFFDFFFEFFF8F1F8FFFBFF
FFFBFFFFFAFFF9F0F5FFFEFFFCFEFDFBFFFFF3F7F6FCFFFFFCFFFFEFF2F7FAFDFFFBFFFF
FCFFFFF8FBFFF9FCFFFCFFFFFCFFFFF6FAFDF4FAFAFEFFFFFEF5F6FFFCFB817C79060501
9FA09BFEFFFBFFFFFAFFFFFAFFFAF8FFFCFAFBEDECEFE1E0FFFCFBFDF8F5FFFFFBFAFBF6
FFFFFFEFEFEFFFFFFFFFFFFFFFFFFFF0F0F0FFFFFFFFFFFF
C2C5AABCBFA2D0D3B6D0D3B6ABAB8FE3E3CBC6C3B4EEEAE1E9E0E1F8EEF6ECE0EAE6DAE4
B2A5ACDCD0D2EADFDDF1E6E0E5DAD4FFF5EFF1E6E0F5ECE7D6CCCAE8E0DEF2E9EAD0C7C8
F0E7ECF5EAF0DFD2D9F5E6EBD8C8CBECD9DBF4E0E1D5C0BD593E376A4D45684F4A907876
DFCDCDEBDDDDFFFCFDFDF9F6F1F1E9FEFFF1F6FFE2FAFFDCD2E0ABCBDE9ECADE96C7D691
D8DFA9FFFFD6F7F9CAA0A1757B7C54E1E1BDE3E2C3FFFFE6FFFFEAE1DBCBEAE4D8FFF9F1
F0E6E4ECE2E1F8ECEEEFE3E5FFFBF7F2E5DFF2E5DFFFF4EFE6D7D4F4E2E0F9E7E7FFFAFA
E9D9DAF4E6E6FFF0F3FFF5F6FCF1F5E6DDE0DFD9DDFEF8FAEDE4E5EBE1E2F7EBEDF8ECEE
D6C8C8FFF5F4BBADAA0A0000756C5DE0DAC2D3D0AFDBDEB3D7DEABCFD89FE3EFAFCDDE9A
D8F2A8C0DB94D6ECAED7E9B9F3FFDEFCFFEFFEFFFAFAFAFCFEFDFFFEFEFFFCFFFFF8FFF1
F9FFE6E2F4C2C8E19DD1E8A0CBDB9DFFFFD4FEFED8FFF7DCBBA89AB69E9AFFF8F8FFF7F9
FFFBFBFFFDFAFFFEFBFFFFFBFFFEFFFFFDFFFFFCFFFFFBFFFFFDFFFFFEFFFFFDFFFFFDFF
FFFDFFFFFCFFFFFBFFFFFBFFFFFBFFFFF9FCCDC4C5C9C3C3FFFDFDFFFEFDF8F4F1F7FFFF
E3FFFF88BBBE4A7B77C3ECE499BBADDFFAEBF3FFF8F5FFF6FFFFFFFFFDFFFFFAFFFFF9FF
FFF9FFFFF9FFFFF9FFFFFBFFFFFEFFFDFFFEFEFFFFFEFFFFF8F9FBFBFCFFFEFFFFFCFFFF
F9FAFEFBFCFFFCFDFFFDFEFFFEFFFFFEFFFFF6F8F5FFFFFDFFF8F7FFF4F2BAB2AF292621
F4F5F0FEFFFBF0EFEBFFFEFBFFFDFBFFFBFBFFFBFBDACECEFFFCFBFFFEFBFFFFFBFFFFFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8FFFFF6D1CFC2CBC9BCC5C3B4F9F7EAFFFFF6FEF9F6FFF9FEFFFBFFFFF5FFFFFAFF
FDF0F7FFFBFDFFFCF8FCF2E9FFFEF1FFF9E9EFE9D9FFFFEFFCF9EAFFFFF3FFFFF6FDF8F5
FFFCFEF1E7EFFFFAFFFEF1FBFFF9FFFFF9FFFFF9FFFFEBEDFFEFEBE8CDC6917873A28D88
FFFBF8FFF4F0EFEAE4EFEFE3D6DACBDAE2CAC5D0AED3E3B6C4D59EBDD090A7BB7695A463
ABAE7FC9C7A0E9E7C0D2D0AAFAF7D490906EDEDBBCE3DFC2E9E5CCE8E3CFEBE4D4EBE3D6
ECE2D9F1E6E0F7E9E6F6E8E5F0E1DEFFFBF6F6E4E2FFF3F1F6E2E1F0DCDBFFF6F7F3DFE0
F6E2E4E0CDCFE7D7DAFFFBFDF3E7EBF5EAEEFFFCFFDCD3D6F5ECEFF3EAEDF9EEF2FFF8FC
FAEEF0DCCECDA2958F110700120A00E7E2C4E7E5BED3D7A4E6F0B3DAE7A2CEDE95CEE094
D9EDA5CCDF9FEAF6C6E8F2CFFAFEEDFFFFFAFFFEFFFFFCFFFDFBFFFEFEFFFBFFFFF7FFF8
F7FFEDE0F7CBC8E5A5CCEAA4CBE3A5F9FFD4F8FDD5D3CEB178685BFAE5E2FFEFF2FFF9FC
FFFCFFFFFFFDFCFFFFFBFFFFFBFFFFFEFFFFFFFDFFFFFCFFFFFDFFFFFCFFFFFDFFFFFCFF
FFFBFFFFFAFFFFFBFFFFFAFFFFFAFFFFF2F7FAEEF0978B8DFFF9FAFFF7F8FFFDFBF5FDFF
DBFFFFD9FFFF0C3D3A97C2BB000C00708A7DEBFCF2F9FFFBFFFFFFFFFCFFFFFAFFFFF9FF
FFF9FFFFFAFFFFFAFFFFFBFFFFFEFFFAF8F9FAF8F9FFFEFFFFFFFFFFFFFFF8F8FAF8F9FB
FEFFFFFDFFFEFFFFFFFBFBF9F9F8F6F1F0ECFDFCF8FFFAF6FFFBFAE4D6D5413735514E49
FBFCF7FEFFFBFCFDF8FFFEFBFFF9F7FFFAF9FFF7F7D4C8C8FFF9F8FFFCF9FBFAF6FBFCF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFF3EEF2D4CECE837E7BFFFEFAFFFEF8FFFAF7F8F2F2FFFBFFFFFBFFFFF8FFFFFBFF
FCF1F7FFFCFDFFFDF8FFFCF1FFFFECFFFFE8FFFFE6FFFFE6FEFFE4FFFFEAF9FAEAFFFFF6
FEFAF9FFFCFFF2E8F3FFFAFF867683B5A4AEFFF9FFFFF9FBFFF9F3EBD3C9917A72A5948A
FFFCF2FDF7E9F5F6E4FEFFECFBFFEAF9FFE4CFE0B6D3E5B3D6E9B1D8ECADD2E7A4D0E0A2
D8DBB0D9D6B3D0D0ACCFCFABF6F6D29A9C77FFFFE1FFFFE3FFFFE2FFFFE6FFFFEAFCF5E2
FFFBEAFFF9EAFDF1E5FFF8F0FFF5F2F9E7E5FFF5F6FFF9FAFFF8FAFFF8FAFFEDF0FFF9FB
FFF9FBFFF5F7FFF4F5FFFBFBFFFBFDFFFCFDFFFCFDFAF4F6FDF7F9F6F0F4FFFDFFFFF7FA
FFF7F8FFFCFAF2E7E1080000150D00D3D0B1D6D7ADD3DAA4DAE6A6D2E299D1E697D5E899
D9E4A0DBE0AAFFFFE0FFFAE7FFFCFBFFF8FFFFFAFFFFFAFFFFF8FFFFFCFFFFFEFFFCFFFF
F9FFF3E5F6D4CFE6B0CAE7A5CCE9A9F0FFCEF2FDD2B7B6985A4C3FFFFAF6FFEFF3FFFBFF
FFFEFFFBFFFFF7FFFFF5FFFFF8FFFFFBFFFFFFFDFFFFFDFFFEFFFFFEFFFFFFFFFFFFFEFF
FFFEFFFFFDFFFFFCFFFFFCFFFFFCFDFAF1F2FFFCFD82797AFFFAF7FEFAF7FFFEFBF1FBFC
E7FFFFE0FFFF1E46488AACAB000F08748A7EEFFCF3FBFFFDFFFFFFFFFDFFFFFDFFFFFCFF
FFFDFFFFFEFFFFFEFFFFFFFFFFFEFFFFFDFDFFFBFAFFFCFBFFFFFDFDFDFBFDFDFBFFFFFD
FFFFFDFBFCF7F4F3EFFFFFFBF7F3F0FFFFFAFFFEFAFFFCFABDAEAB8374710E03005A5551
FFFFFBEFF1ECFFFFFDFFFEFCFFFCFCFFFCFDFFF9FBD7CBCDFFFCFBFFFEFBFEFDF9FEFFFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F1FFFFF8FFC8C1C8FFFDFFF1ECE9F4EFEBFFFEFBFFFDFDFFFBFFFFF8FFFFFBFFFFFAFF
FFF6FBFDF4F5FFFDFAFFFFF3F7F9E1D1D8B6D3D9B5DBE3BCEBF3CEF6FDDCE6EBD4FEFFF2
F8F7F3FDF8FCBEB6C1726873776A7486777EFFFAFDFFFAF8FFF9F0FFF6E8B4A393B0A593
FEF9E3FDFFE5EBF2D1DFEBC5DBECC0E1F5C4C9E0ACCDE2A9CFE5A7C7DC9BC8DD9CD0DFA4
E3E9BBD5D7AFC7C9A1BDC397C5CAA1D9E0B6F2F9CFF1F8CFEDF3CDEFF3D0EDEECFF1F0D4
FFFBE2FFFDEAFFFCEAFFFDF1DACCC9DDCDCDD0BDBFA29090D9C5C6FFF8F9FFF9FBFFF0F2
FFF9FBFFFAFBFFFBFBFFF5F4FFFDFBF9F4F1EAE6E5FFFEFDFFFEFFFFFEFFF9F5F6FFFAFC
F7EEEFFFFCFA756A66140C013D3624F5F1D4F0F2CBEFF7C6EAF5BBDDEEAAD2E89FD1E59D
D3DF9DD8E0ADFFFFE6FFFFF6FFFCFFFFF7FFFFFBFFFFFCFFFFFBFFFFFDFFFEFEFFFBFFFF
F6FFF6E4F7DBCFE9B9C5E3A5C4E7A5E1FFC1EBF8CAC7C8A8827666D3C1BDFFF9FDFFFBFF
FFFFFFF8FFFFF4FFFFF4FFFFF7FFFFF9FFFFFFFDFFFFFDFFFEFFFFFEFFFFFFFFFFFFFEFF
FFFEFFFFFDFFFFFCFFFFFCFDFFFCFDFFF8F9FFFCFDA8A09EFFFEFBFFFDFAFFFEFBF8FFFF
E0FCFFB5D9E5193A41D2F0F02037312D3E36F9FFFBFCFFFDFFFFFFFFFEFFFFFDFFFFFEFF
FCFFFFFBFFFFF9FFFFFBFFFFFDF9FAFFFDFDFFFDFDF6F2F1FCFBF9FFFFFDFFFFFBFEFFFB
F4F5F0FFFFFBFFFFFBF6F5F0FFFEFBFCF7F4FFFDFBF5EBE97765610D000080756F524D47
F7F6F1FEFFFBF7F7F5FDFCFAFFFDFFFFFCFFFFFBFFD9CFD0FFFCFDFFFEFBFFFFFBFFFFFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFFFFFBFFA89FA4FFFCFDFFFDFAFFFEF8F6F1EDFFFCF9FFFCFEFFF9FFFFFCFFFFFCFF
FFFCFFFFFBFDF6F1EEF1F1E5FCFFEACBD9B5CAD6AED0DFB4D2E2B5C7D6ADD0DBBBFCFFED
FEFFF6F6F6F4050006807980FFFBFFFFFBFBFBEEE8FFF6EBFFFCEC62533E655B42FFFBDD
F0F2CDC0C99EE6F4C3D0E5ADC9E1A5D6F0B1CFE9A8CEE9A6CFE8A4C8DF9BD5ECA8D7EAAA
C2CF97AAB47FCFDCA6C0CF96DAE9B2DCEBB4CEDFA8C5D6A0D5E3B2C6D3A7CCD7AFD3DBB6
D5DABAF0F3D8FAFAE2DAD7C6ADA49FFFFBFBFFF9FCFFFBFBDDCFCF827474EBDDDDFFFBFB
FFFBFBFFFCFBFFFBF8FFFEFAFFFFFAFFFFFAFFFFFBFEFFFBF6F7F2FFFFFBF3F2F0FFFEFD
FFFCFD524A48A99F9D070000070000FFFFECFFFFE6F1F9D4FCFFDAF9FFD6C9DEA5CFE7A9
C6E3A1C8E5ADF4FFECF5FFFBF7FFFFF6FFFFF9FFFFF7FFFDF8FFFDF6FFFEF5FFFFF2FFFF
EBFFF6DEFBDFCCF0C0BDE4A5BFE7A0CEEEABDBECB8DADBB9A49786AD9A93FFFAFAFFFBFD
FFFFFDF8FFFDF4FFFDF4FFFDF7FFFFFCFFFFFFFDFFFFFCFFFFFDFFFFFEFFFFFEFFFFFDFF
FFFBFFFFFBFDFFFAFDFFFAFDFFF7FAFFFAFBFFF1F2C5B7B6FFFBFAFFF5F3FFFCFAFDFEFF
EDFFFF53758156747CDEF8F9798C8A000500FBFFFBEFF1EEFFFFFFFFFEFFFFFEFFFEFEFF
FBFFFFF9FFFFF7FFFFF9FFFFFFFEFFFFFCFEFEF8FAFFFBFCFFFFFDFFFFFDFAFCF9EEF3EF
F7F9F6FEFFFDF7F7F5FFFFFBFFFEFDFFFEFDF8F2F2F5EBEA24120ED0BDB70B0000BDB8B2
F5F4EFFBFDF8FEFFFDFFFFFFFFFCFFFFFCFFFFF9FDD6CCCDFFFCFDFFFEFDFEFDF9FEFFFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFFC6BDC2E0D8D6FEF7F1FFFCF2FFFAF0FFFFF4FFFBF5FFFBFBFFFDFFFBF6FDFEF9FF
FFFCFFFFFEFFFFFFFDFEFFF6F1FEE4CDDFB9D7E9BFD1E4B6CEE2B1D2E5B7E0F0CBDCE9CD
DEE5D57E817AC5C3C4E5E1E2FFFDFAFFF6EDFDF4E3EBE0CC8B7F67BDB398BFBB98E5E6BE
EBF3C2D4E3AACADF9EC4DF98D2F0A6CBEB9FC4E498BEDD91C6E298CBE59CDFF6B0C3DA94
A7BB76C0D48FD1E6A1CDE49ED8EFA9CAE39FD7F0AEC8E2A1D7EFB3CFE3AED8EABACFDEB3
C4D0ACEAF3D4F6FCE0C1C4B1F9F4F0FFFCFDF1E7E8FEF4F5FFFCFDFFF6F5ECE2E1847C7A
CFC7C5FFFEFAF4F3EEFBFCF6FCFFFAEFF7ECFBFFFAEEF6EBFCFFF8EDF0E7FFFFFAFFFFFB
CFC9C9D3CACBFDF3F20600000E0701FFFEF3F8F9E9F4F9E2FBFFE6F8FFE3CDE2B9CCE6B6
C6E8ABC4E7AFEDFFECEEFFFAF4FFFFF4FFFFF8FFFFF4FFF7F9FFF8F5FFF7F7FFFFF5FFFF
EDFEF6E7FDE6DBF8CCC4E6A9C3EBA2C1E29BCEDFA8DCDCB69D8E79BFABA2FFF4F0FFF7F6
FFFFFAF9FFFAF4FFFAF4FFFAF8FFFBFEFFFBFFFCFFFFFBFFFFFEFFFFFEFFFFFEFFFFFEFD
FFFCFDFFFCFDFFFBFDFFFBFBFFF5F5FFFBFAFFF7F6B4A9A7FFFCFAF8EEECFFFCFAF5F9FA
E4FFFF8BB1BC52757BCEEAEBEBFFFD6E7D76A1A8A1FEFFFBFFFEFFFFFEFFFFFDFFFFFEFF
FEFFFFFCFFFFF9FFFFFBFFFFFFFEFFF8F4F5FFFCFFFFFEFFFFFFFFF7F9F6FCFFFFFBFFFD
FBFFFFF6FAF9F7F9F8FDFDFDD2D0D1403C3D4641457F7576E0CDC9C0ADA6E9DCD4FFFEF6
F9F8F3FEFFFBF6F8F5F7F7F7FFFBFFFFFCFFFFFAFDD4CBCEFFFBFCFFFEFDFDFCF8FDFEF9
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDF3F2FFFCFAC6BDB4FFFEF1FFFFEFFFFCE9FFFFF0F9F5EAFDFAF5FFFEFFFFFBFFFFFDFF
FDFAFFFFFEFFECECEEF3F8F1F7FFEFC9DFBBC6DDB1CAE2B2CEE5B1C8DEADC1D3A96F805E
000600000300EEEFE9FFFEF9FFFFF4FFFFEDFFFFE64A4424625C3CEDE9C6FBF9D0E6EDBA
D2E0A3CEE39ECCE79ACFEF9AC5E790BDE187CCF098CFF19BD6F3A3D2EEA3CFE9A0819B51
89A453D6F49EC7E58FD5F5A0C3E58FCAED9BCDF0A0C0E296C1E29DC1DFA1CCE7B0D1E9B9
CDE2B9DDEECAEBFADBE6EFDAFFFFFAF4F2F3FFFEFFFFFEFDFFFBFAFFFEFDF4F0EDFFFEFB
D4D3CEFAFBF5FCFFFAFBFFF8F8FFF8F4FFF3EFFDF0F7FFF6FBFFF4F9FFF1F1F4E9CDCEC8
FFFEFBFFFDFDEAE1E4060000675E61FFFEFDFCFDF8FCFFF8EEF9E9EEFDE8D4E8CFC9E1BD
D2EFB7CEEBB5F4FFEFF3FFFBF9FFFFFDFDFFFFFFFDFFFDF4FFFFF3FFF9F1FFFDFDFFFDFF
FDF9F6FDFEEEF8FCD9D9EAB3D1F3A7CBEDA1D1E0A5E6E5B99B8B72C9B1A5FFF7F1FFF7F2
FFFFF6FBFFF6F5FFF4F5FFF4FBFFF6FFFFF8FFFCFAFFFCFBFCFFFDF8FFFDF9FFFDFBFFFD
FCFFFDFEFFFBFFFFFBFFFFFBFEFAF7FFFFFAFFFFFAA5A59DFFFFF8F9FAF2FFFFF8F0FFFC
E3FFFF8EC0C74B777AE6FFFFE5FFFB6C8077E5F0E8FEFFFBFFFEFFFFFDFFFFFBFFFFFBFF
FFFCFFFFFDFFFFFEFFFFFEFFFFFEFFF7F5F8FFFEFFFEFFFFF0F4F5F5FBF9F9FFFFE7F0ED
EDF6F5F9FFFFEEF4F40408090000040C0B10F8F5FCFFF9FCBCAAA6B19E97FFFCF4FFFEF6
FFFFFAF5F7F2FEFFFDFFFFFFFFFEFFFFFDFFFFFCFFD6CDD0FFFCFDFFFEFDFFFFFBFFFFFB
FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEF8FFFEF6FCF3EAE4DCD1C7BDB3A0968CA0988DDFD8CEF9F4EEFFFFFBF3F3F1FFFFFF
E6E5EABAB8BD3E3B420101002C3824000F00293C1C697D5A576846293A18697A5A708063
E2F0D6EBF7DFE2EAD2FCFFE8ECF1D1CBCFAA5F6139989B70D1D4A7F8FECEDCE5AEDAE8AA
C2D890CDE899D4F59EC3E68AD2F79AC2E78AD1F59BCAEA95C5E292C7E197CDE49E708A41
A6C671CDF096C6E98FC6EA92CEF29AC4EA95C1E794D0F5A8CCEDA8C6E4A6CBE6B1E4FACC
E5F6D2C4D3B6CCD8C0FCFFF3FEFFFDFBFBFDFFFEFFFFFFFDEDECEAFFFFFAFFFFFAFFFFF6
FAFCEF888C7DE3EAD8EFF8E3D1DFC6F7FFEDD6E6CBE9F7DDDCE7C9EFF5DBFEFFEEB6B6AA
FFFFFAFFF9FBE2DBE20F080F070007FFFBFFF8F8F8FCFEFBFAFFFAF8FFFADAE7DDE0F1DE
DDF2C9DBEDC7F9FFF4F9FFFDFEFEFFFDFAFFFFFDFDFFFEF8FFFDF4FFF5EFFFFBFDFFFBFF
FFF9FAFFFDF6FFFFEAE9EEC6DFF3B8E7FBBCE1E8B5FAF4D0AD9D86B19B8EFFFAF3FFFAF4
FFFFF6FCFFF6F8FFF6F8FFF6FCFFF6FFFFF8FFFCFAFFFDFBFCFFFDF8FFFFF9FFFDF9FFFD
FBFFFBFCFFFAFEFFFAFFFFFAFFFFFAFDFCF7FFFFFAB3B4AEFBFEF7FEFFF8F4F7EEF2FFFB
D4FFF896D2CA447677E3FFFFF0FFFFA8B7B0ABBDB1F3FFF7FEFFFFFFFCFFFFFBFFFFFAFF
FFFAFFFFFBFFFFFDFDFFFEFDFFFEFFF9F7FAFFFEFFFDFEFFF6FAFBFBFFFFEAF3F2747D7A
333C3B0003022D3132F6FAFBFFFEFFF6F5FAFFFDFFFFF8FBAF9D99FFFAF3FFFAF4F6F1EB
FAFBF6FEFFFDFDFDFDFFFEFFFFFEFFFFFCFFFFF8FCDCC9CDFFFDFDFFFFFDFFFEFAFFFEFC
FFFEFFFFFEFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFF
FEFFF6FBFBF1FFFCFAFFF9FCFFF8FFFFF5FEFFF9FFB0A4A4FFFEF8F7F9EC7A7E70393C33
6B6A68BDB6BDFFF9FFFFF9FFFFFFF3F5FDE8FAFFF4F4F9F3EFF5F5FBFFFFF9FFFBF9FFF3
F8FFE8C9DAAEC3D69FDCF0B3ABBF80839758B7CB90CEE2A5CDE2A1D2E7A2D5ECA4D0EC9F
C8E895C4E690C6EA92CAEE94C2E68CC8EC94D2F29FC9E598D0E79FC9DE9B8C9F5FD2E7A4
CEEDA1C1E494C5E898CCEF9FC7EA9AC5E599C9E99EC7E59FCEE8ABCDE1ACCDDCB1FCFFE4
FAFFE8B4B5A7E9E6DDF9F5F2FFFEFFFBFBFDF8F6F7FFFFFDFFFFFAFCF9F0FFFFF3FFFFEE
FFFFEA777A5DA3A987CBD3ACD4DFB4D9E6B8D3E3B2D6E4B1DAE1ADCDD0A1CDCEAC8C8B76
FBF8F1FEF9FDFFFCFF010007020005FDFBFCFFFFFDFDFEF9FFFFFBFEFFFDFDFEFFFCFFFD
FCFFF6FCFFF4FEFFFBFEFFFFFFFFFFFFFFFFFFFEFFFFFFFDFBF7F6FFFEFDFFFDFFFDF8FC
FFFDFFFFFEFFFEFBF6FFFFF3FFFFE6FFFEDFFFFEE4E8D9C4807061D3C2BAFFFCF6FFFCFA
FFFFFAFFFFFBFCFFFBFCFFFBFEFFFBFFFFFDFFFFFDFFFEFFFBFAFFFEFFFFFFFFFFEEEFEA
FFFFFAF8F5EEFFFFF8FFFEF8FFFEFBF8F2F2FFFEFDB5B1B0FFFFFBFDFEF8FFFFF6DFF2DC
AEE5BB72B490508688C8E8F7FBFBFF807F7D668172E6FFF7AFBDBD6F7075453C413B2F33
3D303A7C727A7A7A78FEFFFBF7F5F6FFFEFFF1EFF2FFFFFFE6E8E7000100464A49B0B5B1
E6EAE9FCFFFDFFFFFDFFFFFDFFFDFCFFFCFBFFFAFBFFFBFBCCBAB6FFF6F1FFFEFAFAFAF8
FEFFFFFFFFFFFFFCFFFFFAFDFFFEFDFFF5F5FFF1F8DFBCC2FFFEFBF9FEFAFFFFFFFFFAFE
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F9FFF4FEFFF8FFFCFDFDEDF7FFF6FFFFEAFAE7D1DDC0B1B4F3F1E58186720F1901616A57
E5E6DEFEF8FAFFF9FFFFFAFFFCFAEDFEFFEFFEFFFBFEFFFFFCFEFFFCFEFFF7FBFEDFE7DA
DAE5C3E1F2BCE1F5B0D3E89B657C2E42580FE3F8B7D0E6A5CEE89FCBEA9CC8E99AC7E897
C6E995C8EB97C9EF98CBF19ACEF19DC8E998C9E598C6E097D5EAA5D6E9A98D9B5ED6E9A9
CBE99FC3E598C8EA9DCEF0A3CAEA9FC7E79ECCE7A2CEE6A8CCE1A9E3F3C6E7F1CEFFFFEA
FCFAEBC9C2BCE0D6D5BCB3B6F3F1F4FFFFFFFAF8F9F4F3EFFFFFF6FFFFF3FFFFEFEAEAD2
EFF0D18B8F6A999F73E6EEBDE9F3BEE7F5BAE4F4B6C9D799DAE0A0DFE3A8ADAE84606044
FAF7EEFFFCFFFFFDFF04010A010005FCFCFCFFFFFBFEFDF8FFFFFDFFFEFFFFFCFFFFFDFF
FFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F3F6FFFEFFF8F6F9
FCFAFDFFFEFFFAF8FBFFFDFBFFFBF1F7E0D2E1CEC08B796D75675EDCD2C9FFFBF6FDF8F5
FFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFF8F5FCFFFEFFFFFCF9
FEF9F3FFFFF6F7F0E8FFFCF6FFFBF9FFFCFDFFFDFFABA7A8FAF6F5FFFFFAFFFFF6D7EBCF
C3FAC092D6A53E7879B4D7EBFFFCFFB1A8AB213D2E6489782436382D3037716B6D7C7175
968993403941000100E9F0E8FFFFFDFFFEFFFFFEFFE4E4E4676767000100B1B3B0F5F7F4
FEFFFDFDFFFCF5F4F0FFFEFAFFFEFBFFFEFBFCF2F0FFF9F5E5D3D1FFFBF8FFFFFDF3F7F8
F8FCFFF8F7FCFFFBFFFFFBFFFFFCF9FFF9F6FFF0F8C89DA4FFFEFAF8FFFCF6F6F8FFFDFF
FFFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
00030076777129232572626C0D00070E00053E2D33786E6C7C7F6EE1EBD2F8FFE8F8FFEA
FBFFF1FFFFF6FFFCFDF4EFECFCFFEDF9FFEDF3FDF2F6FFFEFBFFFFF8FCFFEAEEEFE6ECDE
D7DEBCCDD7A3C6D18FD6E29A5D6921949F5BD6DEA2CFDA9ED1E8A2CAE89EC7E79CC8E89D
CAEC9FCBEDA0CAEC9FC8EA9DD2F2A6C9E99EC9E49DCEE59FD3E8A5D6E9A97E8C4ED2E5A3
CBE79AC7E897C9EA99CCED9ECAEA9FC7E6A0CBE5A4CFE7ADD4E8B7F9FFE1FCFFE8FFFFED
FFFFF4F6EEEBFFFCFDE0D7DACBCAC8FFFFFBFFFFFBF6F7EFFFFFF4FFFFEFF6F8E2E4E7CA
D6DAB9969D748A9366FCFFD4FBFFD1F3FFC9F8FFCDDEEEADD9E29FDEE2A59193647E7F60
F7F5E8FFFFFDFCFAFF06030A020003FDFCFAFFFFFBFEFDF8FFFFFDFFFEFFFFFDFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFF8F4F5FFFEFFFFFEFF
FEFAFBFFFEFFFBF7F8FFF7F5FFFBF35440357E6C60CCBBB1FFFCF4FFFDF6FFFDFAFFFEFB
FFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFFFFFDFFF1EEF5FFFBFCFFFEFB
FFFFF6F3ECE2FFFEF6D8D1CBD9D1CFFBF2F3FAF4F8A7A3A4FFFDFCFFFFFAFCFEF1E4F8DC
B4E7AEA8ECBB094B498EBCCCFEFEFFA79EA1000700779385EFFAFEFEFEFFFFFDFEFFFCFF
FDF1FBFEF7FFFEFFFB2B322A383735666263110F103B3B3BFFFFFFFEFFFFFBFDFAFEFFFD
FEFFFDFEFFFDFCFBF7FFFFFBFFFEFBFFFEFBFFF8F6FFFCF8D2C3C0FFF8F4FFFFFDFAFFFF
FBFFFFFAF9FEFFFAFFFFFBFFFFFEFBFFF4F1FFECF49D7077FFFAF7FBFFFDF4F2F5FFFDFF
FFFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
F6FBF4FAFBF6F7F1F3FFFBFFEFDFE964555CFCF0F0FFFFF4FAFFEBF8FFE6F1FFDFF5FFE3
F8FFE8F4FEE6FFFFF3FFFFF1F8FFEAF7FFEAF5FFF1F8FFFBF9FFFFF8FDFFFAFFF9FEFFF1
FFFFE1DFE3B1DFE3A6E3E6A3484907A5A366D4D19AE9ECB3CFE4A1CAE8A0CCEBA5CEEDA7
CDEEA9CAEBA6C6E7A2C3E49FC5E4A0C8E5A2CEE9A6D6ECABCFE4A3CFE2A07B8B4AD4E8A1
CCE997CAEC95C5E793C4E594C9E99EC9E6A3C9E3A6CEE5AFCCDEB4EFFDDAFAFFEAFDFFF1
FFFFF8FEF9F6FFFCFFFEF8F8BEBDB9F1F2EAFFFFF6FFFFF4FFFFF1F7F9E4EDF0D5D7DCBC
D3D9B39BA479919D6DFBFFD4F9FFD1C6DC9CD0E6A5C6DB98DAE5A0CAD090919563DCDDBB
F6F7E5FFFFF7FBF9FA010002020001FDFCFAFFFFFBFEFDF9FFFFFDFFFEFFFFFDFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFF8F2F2F5EFEFFFFDFB
FFF8F6FFFDFBFFFDFBFDF4EFB6A59EB1A096FFFBF3FFFCF4F4E9E3F8F1EBFFFEFBF6F5F3
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFFFFFFFBF9FEFBF9FEFFFEFFF8F3F0
FCF5EDFFFEF46D665ECFC8C2AFA7A5645B5EC8C2C6FFFEFFFFFFFDECEDE5FEFFF4E0F3D7
C7F6BFB3F5C527726D8CC4D17F8891140E10717D73EBFBF1F9FEFFE8E7EFFFFEFFFCF6F8
FFFAFFFFFBFFF5F7F2F1F6EFF9F8F6FFFEFFFAF8F9F8F8F8FBFBFBF2F4F3F9FBF8FDFFFC
F0F2EFFEFFFDFFFFFBFCFBF7FFFCF9FFFEFBFFFAF8FFF5F1CCBDBAF4EBE6FBFBF9F9FFFF
FBFFFFFEFFFFFFFAFFFFF4F8FFFEFBFFFAF7FFE7EFB5888FFFFCF9FBFFFDFCFAFDFFFDFF
FFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFF
FEFFFBFFFFFBFFFEFFCEC8CAB5AAAEDCD4D2FFFFF6E9ECD7D7E5C4E5FAD1DBF5C5D6F0C0
DFF6C8E8FAD2EBF9D8DDEBCAD7ECC5F4FFE4F5FFEDF6FFF5F7FFFAFAFFFAFEFFF6FCFEE9
FCFCD8D4D2A2E7E2A8DAD294675D20675A23E0D09DD1CB97CEE1A1CBE9A3CDECA8CCEAAA
C9E7A9C9E7A9CDEBAFD2F0B4D1EDB2D0ECAFCEE8A9D3E9A9CEE3A0D4E8A395A660CFE497
CDEB93CFF095C5E68FC0E08DCBE99FCCE9A7CAE3AAD2E8B9D3E4C0F3FFE4FBFFF1FCFFF4
FFFFFBF8F4F5FFF8FDC9C3C3F9F9F1FAFEEFFEFFF1FEFFEFFFFFECFFFFE8FFFFE4C5CDA8
CED6ADABB789C5D6A2F6FFD1F7FFCFC8E2A1CEE9A6D4EBA5D4E199C4CD8AA4AB75F0F5CD
FFFFEAFEFFF1FFFFFA010000020100FDFCFAFFFFFBFEFDF9FFFFFDFFFEFFFFFDFFFFFEFF
FFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFEFDFFFEFDFFFDFDFFFDFBFFFCFAFFFCFA
FFFCFAFFFCFAEBE0DCC8BDB7968782F5E8E0FFFCF6F9F0EBFFFDFAFFFEFBFFFEFCFFFFFF
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFDFFFFFDFFFFFFFFFEFFFFFDFFD7D1D1DFDAD6
D7D0C89B948AE9E0D9FFFCFAFFFCFDFFF6F9FFFDFFF4F0F1FAF9F5FFFFF8FEFFF4E2F2D5
BDE4AFB2F0C12A7D758FD3DC55666D030000FEFFFAF5FAF4FFFDFFFFFCFFFFFEFFFEFAFB
FFFAFFFAF0F9FEFFFBFCFFFAFFFFFDEFEBECFCFAFBFFFFFFFFFFFFFEFFFFFEFFFDFCFEFB
FEFFFDFEFFFDFFFFFBF9F8F4FFFEFBFFFBF8EBE1DFD9CECAF8EAE7FFFEF8FAFCF9F7FFFF
F9FFFFF9FDFFFFFBFFFFF8FCFFFCF9FFFBF8FFEBF3F6C9D0FFFCFAF5FAF6FFFDFFFFFDFF
FFFEFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFEFFFF
CED0CBD9DAD5ECEBE9FCF8F7FFFEFBFFFFF6EEF1DEFBFFE8DDEFC7CCE7B4C7E4ACCFEEB2
CEEBB1C6E1AACDE3B2DAEDBFCDE3B4CBE0B7D0E1C1F8FFEFFBFFF4EDF3E5FFFFF1FFFFE8
FFFFDDE3DDADDED59EE8DCA2E2D39AA1905C968152E4DAA7D2E2A1CAE8A2C8E7A4C5E3A3
C5E3A7CEEBB3DFFCC4EDFFD3F2FFD8E9FFC9CFE7ABCAE0A0D1E6A1D9EDA5B1C377A9BF6D
C3E084D0F294CBE991C2E28FCEECA4CEEBABCDE5B1DBF0C7F0FFE1F8FFEFFBFFF4F3F8F1
FFFFFDFFFEFFFDF7FBAFABAAFFFFF3F7FCE6EDF2DBD0D6BCA0A788AEB594B8C09B6C774D
9BA7799CAC7BD0E3ACC9E1A5D5EFB0CCE9A7CAE9A5CCE7A0CCDC93D6E19CB9C289B3B98D
F9FCDDF9FAE8FFFFF6010000020100FDFCFAFFFFFDFEFDFBFFFEFFFFFEFFFFFDFFFFFEFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFFFDFFFEFDFFFEFBFEF6F4FDF3F1FFFAF6C0B3AD
AC9F99B0A19C81726DA39690C7BAB4FFFCF8FFFCFAFFFAF7FFFEFBFFFEFDF6F6F6F5F6F8
FEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFDFFFFFDFFFFFDFAF5F9D3CED29A9494F6F1ED
FFFEF6FFFEF4FFFBF6FFF8F6FFFCFDECE6E8FFFDFFFFFEFFFFFFFBFCFFF4F9FDEEEFFEE1
DBF9C7488154328C82A0EFF400161A797778FAF9F4FCF8F5FFF7FFFFFBFFFEFCFDF6F4F5
FFF6FFFFFCFFF2F4EFF4F9F2FFFFFDFFFDFEFFFEFFFFFFFFE8E8E8F3F5F4FEFFFDFEFFFD
FEFFFDFBFDFAFBFAF6FFFFFBFFFEFBE2DDDAD3C9C7E2D9D4FFFCF8FFFEF8F6FBF7F6FFFF
F7FFFFF7FCFFFFFCFFFFFAFDFFFFFBFFF7F4ECBDC5E9BCC3FFF8F6F8FDF9FFFDFFFBF5F9
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFDFFFFFBF1F2EDFBFCF6FFFFF6FCFFF1F8FFE7D6E8C2CEE6B6BFDCA2C2E2A1C6E7A2
C9EAA5CFEEAACBE8A6C7DFA1E1F3BFC7D7AAC6D4B0FBFFE8FEFFEDF9FBE6FFFFEAEEEBCC
FFFFDAE9E3B3DAD19AE0D39CF1E2ABD0BF8B5C4718E3DCA6D2E6A1C9E9A0C8E5A2C8E5A5
CEEAAFDBF6BFECFFD4F4FFDAF4FFDAEDFFCED1E9ADC7DD9CD4EAA2D4E99CC6D9887B923A
ACC76ACBEA8DD1ED96C8E595D0EBA6CCE5ABCDE3B4E4F8D3F7FFEDF8FFF3F9FFF6EAEFE9
FCFCFCFFFEFFFFFDFFD3D2CEAAAF99B5BE9FC1CAABBAC4A29FA986B6C199E3EEC4D1DEB0
C4D4A3CADCA8DCF1B8CCE6A9CBE8A8CCECA9BFE39DC5E59CCCE196DFECA6C8D397A4AC7B
C9CFABEDF1D8FFFFF0010100040100FFFBFAFFFFFDFEFCFDFFFEFFFFFEFFFEFEFFFFFFFF
FEFFFFFCFFFFFEFFFFFEFFFFFFFEFFFFFFFDFFFEFDFFFEFBFFFDFAFFFDF8B4A7A17F7069
A89992B9A8A0C6B5ADFFFBF4FFFCF8FFF9F6F8F0EEFFFDFDF5F4F2FBFBFBFFFFFFFEFFFF
FEFFFFFCFFFFFCFFFFFEFFFFFEFFFDFFFFFDFFFFFBFFFFFDFFFDFFACA6A8FFFDFBFFFEF8
F8EFE8FFF8EFFFFAF5FFFCFAFFFCFDFFFDFFFFFDFFEBE9EAFFFFFAFEFFF6F0F4E3F9FFE8
F4FFDC65986D167267B1FFFF00090B6F7170FFFEFAFFFAF9FFF9FFF5E9F5FFFEFFFFFFFF
FFFAFFFFFCFFF3F5F0FEFFFAFBFAF8FEFAFBFBF9FAF3F3F3FFFFFFFEFFFFFEFFFDF4F6F3
F8FAF7F6F8F5FFFFFBFFFFFBFEF9F6D6D1CEDDD3D1FFFDF8FFF9F4FFFCF6F5FBF7F7FFFF
F7FFFFF8FDFFFFFCFFFFF6F9FFFFFBFFF1EEDCADB5BF9299FDF3F1FCFFFDFFFDFFFFF9FD
FFFFFFFCFFFDFCFFFDFCFFFDFCFFFDFCFFFDFEFFFDFEFFFD
FFFFFDF3F4EFFFFFF8FEFFF4E5EED9F9FFEAF7FFE3DFF5C6CBE6AFC6E4A6D1F0ACCCEEA4
C4E499CAEA9EC9E89AC9E39CCCD9A1DEE6B7E2E9C0F9FDDAF9F9DDFFFFE6FFFCDD817D58
605C2F4F491769622C7A7138938852A094606C5E2D2C2900D1E79FC9E99DCBE9A1D1EEAB
DBF7BCE9FFCBF1FFD5F5FFDACAE0AFD9EDB8D1E7A9CBE09DD7EBA3CEE492D7EB966A8127
94AE53C4E187D5EE9BCCE69CCFE8A6C7DEA6CAE0B2E9FDDAF7FFEDEFFCEBF9FFF8FBFFFB
FEFFFDF2F2F2FFFEFFFCFDF5D7E0C5D8E4BED7E3BDE2EEC6D7E4B9CBD8ACE6F3C5F6FFD5
E7F9C5DBF0B8C1D99FD0ECAFC8E6A6C3E6A2B9DC98D5F4AED2E89FD7E7A0D0DEA0D2DCA7
959C72E1E6C6F3F5E0010100040100FFFBFAFFFEFFFEFCFFFFFEFFFFFFFFFEFEFFFEFFFF
FCFFFFFCFFFFFEFFFFFEFFFFFFFEFFFFFFFDFFFEFBFFFEFAFFF5F3FEF3ED5447418D7E77
FFFBF3FFF2EAFFFBF1FFFAF1FFFCFAFCF4F2FFFDFDFFFEFDFFFEFFFFFFFFF9FAFEFDFEFF
FCFFFFFCFFFFFCFFFFFCFFFFFFFFFFFFFFFDFFFFFBFFFEFDFFFDFFE5DFE1E5DDDBEFE8E2
FFFDF6FFFDF6FFFDF8FFFAF8FFFCFDF3EDEFFFFDFFFFFEFFF2F3EDFCFFF4FCFFEFEAF5D5
E3F5C58DBA91348E84257D7F94B8B8FBFFFFF0EDE8FFFCFBFFF2FFFFF9FFFFFEFFFDFDFD
FBF6FDFEF9FFFFFFFBF7FAF3FEFDFBFFFEFFFFFEFFF8F8F8FFFFFFF4F6F5FEFFFDFCFEFB
FEFFFDFEFFFDFFFEFAFFFFFBFEF9F6EBE6E3F3E9E7FFFDF8FFFDF8FFFFF8F9FFFBF7FFFF
F7FFFFF3F8FBFFFDFFFFFAFCF7F8F3FFFBF8FFE8F0CB9EA5FFFDFAFCFFFDF7F2F6FFFDFF
FEFFFFFCFFFDFCFFFDFCFFFDFCFFFDFCFFFDFEFFFDFEFFFD
FFFFFBFEFFF7FEFFF4F4FDE8E7F6D9E3F5CFD7EDBFDAF3BCCAE4A7C8E2A1CDE8A3C9E59B
C9E598CFEC9ACEEB97D3E99ED6DBA1DEDDADECEBBFFFFFDCFFFFDBD7D3B0ADA9837A774C
9E9C6CAAA875ADAC74A1A067908F5686854C7F7E46747D3ECBE397C4E692D0EFA3C8E69E
DFF9BAF4FFD3ECFFCDF7FFD6CFE3AEC7DAA2CEE2A5D5E9A4D3E89DC9DF8DD4EA9594AB53
95AD59CDE693CEE499D4EBA5D0E6A8C4DBA5E1F6CBDAEECBF7FFEDF8FFF3F1FCEEF9FFF6
FCFFFAFEFFFBFFFFFDFEFFF4F3FEDCF0FFD3E5F5C8D4E4B5CCDCADD5E5B4E7F8C4F3FFCE
E1F4BDD3EBB1C6E0A3C9E5A8D2F0B0C7EAA8C1E4A2CEEFAAC6DD97E2F6AFCCDC9DCBD8A0
98A174C4CAA6EFF1D9030100040000FFFEFDF5F0F4F8F6F9FFFEFFFDFDFFFFFFFFFEFFFF
FCFFFFFCFFFFFEFFFFFEFFFFFFFEFFFFFFFDFFFEFBFFFEFAFFFCFAEFE4DE6E615B6D5E57
BCABA3D9C8C0FFF8EEFFFCF3FFFCFAFFFAF8FFFDFDF8F4F3FEFCFDFFFFFFF9FAFEFEFFFF
FCFFFFFCFFFFFCFFFFFCFFFFFFFFFFFFFFFDFFFFFBFFFEFBFCF6F6FFFCFDE1D7D5CCC3BE
FFFDF6FFFDF6FFF9F4FBF1F0FFFCFFFFFDFFFFFDFFFFFFFFFEFFFAFCFFF4F5FDE8E9F4D4
D8E5B7BFE5BE358880378A8E577B7BE7F2EEFCFFFAFFFDFAFFF8FFFFF8FFFFFCFDFBFBFB
FCF9FFFEFBFFFFFFFBFFFFFAFFFFFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
FEFFFDF9FBF8F8F7F3FAF9F5FFFEFBD8D3D0FFFCFAFFFDF8FFFBF7FFFEF8FBFFFDF5FFFF
F2FEFEF8FDFFFFFDFFFFFDFFFEFFFAFFFCF8FFDBE2DBB0B7FFFEFAF9FFFBFFFEFFFFFDFF
FAFCFBFBFFFDFCFFFDF9FEFAF6FBF7FAFFFBFEFFFDFCFEFB
FFFFF7FEFFF3F3FBE6EAF7D9DDF2CBD4ECBCD3ECB5D0E9AFDBF3B5CAE09FDEF3B0D3E7A0
D3E89DD0E596BFD783ACBD6F7B7C42655F2D332D00979364D3CEA47B784D585729E0DFAF
D8DBA6E1E6AEE4ECB0DEE8ABD9E3A6D8E4A6D9E5A7D5E6A2D1EE9CC8EA94CFEE9EC4E298
CEE9A6DAF2B4CDE2A9D5EAB2D6E9B2D8EBB3CDDFA3C5D896DAEEA6D3E89BD3E997A5BB69
8A9F54CCE29AD2E7A4D3E7A8D1E4ACD3E7B4F6FFDEEEFFDDF3FFE6D5E5CBCFDCC8F7FFF2
FBFFF6E9EFE5F7FAF1FCFFF1F9FFDFE5F9C4D1E5B0CEE0ACCFE2ABCFE0AAD1E2ACD5E8B0
EBFEC6F5FFD1E7FFC4CBE7AAC1DFA1C3E3A4C1E4A4C1E1A0D1EAA8C6DB98D8EAACDAE9B0
656E3FA0A680D8DBC0262415040000FFFDFDFFFDFFFFFEFFFFFEFFF8F8F8FAFCF9FBFDFA
FCFFFFFCFFFFFEFFFFFEFFFFFFFEFFFFFFFDFFFEFDFFFEFBFFFAF7F9F0EBFFF2ECF5E6DF
D7C8C1AD9C9488776F85766FAFA4A0FFFDFAFFFDFBFFFDFDFFFFFDF7F7F7FFFFFFFBFCFF
FEFFFFFCFFFFFCFFFFFEFFFFFEFFFDFFFFFDFFFFFBFFFEFBFFFEFBFFFDFBFFF8F3F0E7E0
FBF2E9DFD6CFEDE4DFFFFDFBFFFBFEFFFBFFFDFBFEFDFDFBFBFEF5F1F8E8E4EED6DBE6C4
CCD8AAE0FFDB438885003C44CBEDEEF4FFFFF4FFFAF7FEF7FEF0FDFFF7FFFFFCFFFFFEFF
FEFDFFFFFEFFFFFFFBFAF9F4FFFEFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
FCFEFBFEFFFDFFFFFBFFFFFBFFFEFBD0CBC8FCF2F0FCF3EEFFF7F3FFFEF8F7FCF8F7FFFF
F7FFFFFAFFFFFFFBFFFFFDFFFBFCF7FFFAF6FFDCE3DEB5BBFFFDF8F3FEF8FFFFFFFFFDFF
FCFEFDFBFFFDFCFFFDFBFFFCFCFFFDFEFFFDFEFFFDFEFFFD
FFFEF1FEFFEEDFE8CDDAEAC5CEE6B6BDD8A1CDE7AAC3DB9DCDE1A4CEDEA0D1DB9ED3DC9D
E0EAA5CAD589A1AE5E4E560B8B894EFEF7C3F0E8B7B7B17F59562365653190935EDAE2A9
CED89CD1DD9FCFDFA0CADD9BC7DE9ACBE29CCCE69FCCE89DCEF09AC6E891CDED9AC8E79B
CAE59ECDE6A4C5DB9DCEE2A7CADBA4C6D7A0E1F0B5D6E6A8C7DA98D3E7A2C9DD95556922
96A86CD1E2ABD3E4ADD1E4ADDBEDBBEAFECDF7FFDDF5FFDFF7FFE4CADBBBCCDBBEF9FFED
F9FFEFF1FAE7FCFFF3FBFFECEFFFD2D3EBAFC4DCA0CEE3A8D5EAB1CEE1A9CADDA5CFE2AA
DDF0B8ECFFC8E7FFC5D1EAB0C6E2A7CDEBAFD0EEB2C9E7ABD1EBACC3DB9DC4D89BD2E3AC
929E6CD1D8AF909376030200040000EFE9EBFAF5FBFCF9FFFFFEFFFEFEFEFEFFFBFEFFFB
FEFFFFFEFFFFFEFFFFFEFFFFFFFEFFFFFFFDFFFEFDFFFEFBF8F0EEFFFCFAFFFCF8FFF7F1
FFF5EFFFFBF6FFF9F45649435D504ACFC4C0FFFCFAF9F1EEF8F3F0FFFEFDFBFBFBFEFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFDFFFFFDFFFFFBFFFDFBFBF1EFFFFDF8FFF6EF
FFFDF4FFF7F1DED5D0D8D0CEFFFCFFFFFCFFFEFCFFFFFFFDFBFEF5E8EFDFD7E1C8D2DDBB
D1DAADE0F8D600191C0A3F4D98B6B8EAFFF9DDFFEEF0FFFBFFFBFFFFF7FFFFF3F7FFFCFD
FEFFFFFCFFFFFFFFFBFFFFFAFFFEFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
FDFFFCFEFFFDFFFFFBFDFCF8FFFEFBD9D4D1FFFCFAFFFCF8FFF5F2FFFEF8EFF1EEF7FFFF
F8FFFFF4F9FCFDF8FEFFFBFDFEFFFBFFFDF8FFE6EDEDC6CBFFFFFAF7FFFDFEFFFFFFFFFF
FEFFFDFAFFF9FBFDF8FEFFFBFEFFFBFEFFFBFFFFFBFFFFFB
FFFFEDFFFFEACFDBB7CEE1B3C7E3A9BBD999DEF8B7D5EBABD8E6ABDBE3AAD5D5A1838049
6561248F8E4B93954CC7C882CDCB90D6D09CDBD8A1E3E2AA95965CB3B97DDDE7AAD1DD9F
DCECADD8EBA9D3EAA6CCE7A0CAE8A0C9E99EC8EA9EC7EA9AC8EB97C1E58ECBEA9AD2EEA3
CFE9A0D1E8A4D3E7A8D8EAB0D1E2ABD3E2ABCFDEA7D2E1AAD9EAB392A46A8FA167CDDEA7
C5D2A6DEEBC0D3E0B5D8E8BBEFFFD3F8FFDCF7FFDCE1F4C6DEF1C4C5D7ADD1E1BCF6FFE2
F5FFE4F8FFEBFBFFEDD5E3C2D3EAB4CAE4A3C9E3A2D1E9ABD3EBADD1E6ABD1E5AAD6EAAF
DAEDB5D7EAB2DEF3BAE9FFC8ECFFCCEEFFCEF0FFD2F0FFD2ECFFCEF4FFD3DFF4BBD1E2AC
95A16FD8DFB5828568030200807B75FFFDFFFFFCFFFBF5FFFFFEFFFEFEFEFDFFF9FEFFFA
FEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFEFDFFFEFDFFFDFDEFE7E5FFF9F7FFFCFA
FFF8F6F9EEECFFFCF8FFFCF6FDEEE963564E8E817BFFFAF5FFFDFAFFFBF8EAE9E7FFFFFF
FFFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFDFFFFFDFFFFFBFFFBF8FFFAF5FFFDF6FBF2EB
FFFDF4FFFCF6CAC1BCCAC2C0FFFCFFFFFBFFFEFCFFFEFFFDFBFFF7E3ECD9D1DEC4D1DDB9
D8E1B4E3F4D4E7FFFF1E4155556A6F3E5950C5FBE3DCFFF4FCFBFFFFF6FFFFF9FFFFFAFD
F8FDFFF8FFFFFFFFFBFFFEFAFFFEFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
FEFFFDFCFEFBFCFBF7F9F8F4FFFCF9E2DDDAFEF4F2FFF6F2FFF8F5FFFCF8F5F5F3F2FBFA
F9FFFFF1F5F8FFFBFFFFFDFFF9FBF6FFFCF6FFE4EAF0CCD0FAFBF5EDFEF6F7FDFDFBFCFE
FCFFFDFBFFFAFBFDF8FEFFFBFEFFFBFDFEF9FDFCF8FFFFFB
FFFFEAFFFFE4CFDCB1CFE3AECEEBABCCEBA5F4FFCAF6FFCAFCFFCBECEAB96E6135A29165
D9C797E6D7A0E6DB9BDBD696D9D89FE3E6ADDAE0A4E0E9AADDE8A6D5E29DD8E9A3D5E9A4
CFE6A0CAE49DC8E39CC7E79EC8EA9EC6EB9DC3EA99C2E996CAED9BC3E694CAE99DD3EFA5
CAE49DCAE09FD4E8A9CEE0A6D3E1ACB4C28FA9B786A9B68ACCDBB0D1E0B7DDEEC4E9F7D3
EDF6D9EDF6DBE0EBCDEBF9D6F8FFE1F3FFD7E1F5C2D1E5B0CAE1ABC3DAA6D6EAB9F2FFD8
F1FFDAF9FFE4F9FFE6C2D2ABC8E1A7CCE9A6CDEAA7CEE8A7D4EDACDDF3B5DBEFB2D2E6AB
D5E6AFCCDDA6D9ECB5EAFCC8E7FBC6E8FFC9F5FFD6F4FFD8F2FFD8EBFFD1B9D09AC7D9A5
8C9A69D7E0B5B4B79A0E0D00817C78FEF8FCFEF6FFFCF6FFFFFEFFFFFFFDF5F8EFF9FCF3
FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFBFCFFFDFDFFFDFDFDF5F3
FEF6F4FFFDFBFFFDFBFFF7F2FFF8F1F2E1D78F7E76A79A92FFFCF6FFFEF8FFFCF9FFFFFD
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFFFFFBDED6D3BDB2AEA59A94A69C93
DDD3CAE5DAD4BAB0AEF8EFF0FFFCFFFCF7FBFBF9FCFEFFFBF9FFF3E3ECD7D4E1C5D5E3BF
DCE5B8EBF6D8E6F3FF00051FC4D3DA2F5045001900ADEDD3B7BEC4FFEBFAFFF8FFFFFBFF
F0F8FBF8FFFFFFFFFBFFF8F5FFFDFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
FEFFFDFBFDFAFEFDF9FFFFFBFFFEFBE2DDDAD4CAC8BDB2AEFDEBE9FFFBF8FFFFFDF8FEFE
F9FFFFFAFEFFFFFCFFFFFDFFFBFFFAFFFEF8FFE9EEFCD9DDF9FEF7F1FFFCF8FFFFFBFFFF
FCFFFDFEFFFBFFFFFBFFFFFBFFFFFBFDFCF8FFFEFAFFFEFB
FFFFE2FBFFDCD6E4B3CFE7ABCCEAA4CCECA1ECFFC0F2FFC1F8FBC6D6CB9E624C27DCBF9D
FFF2CAE3C899F0D9A3EADEA4D7DAA1DEECAFC2D092C7D894EEFFB8D0E59AC1D98DD4EEA4
CBE79DC7E59DC7E79ECBEDA1CDEFA2C9EE9EC6ED9AC7EE9BC8ED9FC6E89CC9E79FD2EDA6
C6DF9BCBE09FDCEEB2CAD9A2C4D09E7C885ADBE7BFFBFFE3C7D4B6C1CEB2F8FFECF4FFEA
F9FFF1F9FDEFF6FDEBFBFFECF9FFE3E2F3C6CEE2ADD2E7AED1E9ADC9E1A5D9EEB5F7FFD6
F8FFDAF8FFDFF9FFE1D0E3B5CBE8A8CCEBA5C9E8A2C9E6A3DDF8B5F3FFC9ECFFC3D5E9AE
CADBA4C9DAA4D8E9B5D7E8B4C5D7A5D4E6B4F0FFD0EFFFD4EBFFD5F2FFDCD8EFBBE2F4C2
A6B4839BA479828568040100908885FFF6FEFFFBFFFDF7FFFCFAFFF9FBF8FDFFF7FCFFF6
FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFECEAEBFFFEFFFDF9FAFFFEFF
FFFEFFFEFAFBFFFEFFFFF9F7FFFBF3B29E938F7D71CCBBB1FEF1E9FFFDF6FFFDFAF3EFEC
FFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFFFFFBC3BBB8AA9F998B81789F958C
DFD5CCF9EEE8D6CCCAFFFAFBFFFCFFFFFAFEFEFCFFFEFFFBFBFFF5ECF8E2E5F2D6E6F5CE
E1EABBF0F4D9878499322E4FEDF6FF60867909603D97E8C8C1D0D3DCC7D6F4DAE3FFFAFF
F8FFFFF4FFFFFBFAF6FFFCFAFFFDFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
FEFFFDFCFEFBFEFDF9FFFFFBFFFEFBF6F1EEE0D6D4CBBDBAE4D0CFFAEBE8FFFEFDFCFFFF
F7FCFFFCFFFFFFFCFFFFFAFCFCFFFBFFFEF8FFECF0FFE5E8FBFFFAF0FFFDF7FFFFF9FFFF
FAFFFBFEFFFBFFFFFBFFFFFBFFFFFBFFFEFBFFFEFBFFFDFA
E9E6C5E4E6BFD6E4AFCDE6A5C7E59BC5E599D0EAA1D9E8A7DBD9A6614F29997C5EB08B70
AF8869B28F69836235AE9D69A1AA71D9F1B3D7F0ACC9E39AC1DC8FCFEC9CD0ED9DC6E597
CDECA0C8E89DC9E9A0CBEDA1CAEC9FC3E996C3E994C6EC99C8EAA0C8E9A4C8E5A2D0EBA8
C6DF9DD4E8A9ECFEC4CDDBA6DCE8BAE5F0C8FCFFE4EEF8DDE9F5E1F7FFF2F8FFF8F7FFF9
FDFFFEFEFFFDFCFFF8FBFFEFF6FFE3DFF0C3CBE0A8D3E9ABCDE6A4C8E19FC9E2A1E1F9BD
E6FAC5DEF2C1E2F3C7CFE3B2CCEBA8C8EAA0C5E59CC9E7A1DBF6B3ECFFC2E8FCBFDBEDB3
D9E8B1C5D39ECFDDAADAE8B7CCDCADD6E6B7EDFDCEE9FCCEDEF8CBE4FFD2B8D0A0C3D7A4
F4FFD1EBF4C9C0C0A41310001F1715B7ADB5FFFBFFFFFCFFFFFEFFFEFFFDFCFFF4ECF2E6
FFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F4F7FFFEFFEDEBEE
FAF8FBFFFEFFEBE9ECFFFDFBBEACA2866F61CCB9ABFFFBEFFFFCF3FDF3EAF1E8E3FFFEFB
FFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDEEE7E1F9EEE8FDF3EAFFFDF4
FFFBF2FFFCF6FFF7F5FFFCFDFFFCFFFFFDFFFFFEFFFEFFFBFCFFF6F8FFEEF7FFE6F6FFDE
FCFFD8FFFFE70A00128B799FFCFEFF537C6E3BA0787BD9B5E7FBFCD2BDCCD2B7C0FFEFF5
F7FFFFF1FFFFF8F4F1FFFCFAFFFDFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
FEFFFDFDFFFCFFFEFAFDFCF8FFFEFBFFFEFBFFFCFAFFF9F6DFCAC9D4C2C0FFF9F9FEFFFF
F4F9FCFEFFFFFFF8FFFFF9FBF8FDF7F8F3EDFFDDE1FCDEE0ECF6EDEBFFFAF1FFFDF1FAF9
F8FDF7FFFFFAFFFFFAFDFCF7FFFFFAFFFFFAFFFBF7EAE5E1
C4C19EC5C79FCFDEA7CBE4A2C9E89CCBEC9DCBE399D7E3A3D8D4A45C4823704E337A5239
764A2F7149269A754B5543116B763CB7D494BEDC96D5F3A9C8E797D4F4A1BFE18DCCED9C
CCECA0C8E89DC8EAA0CBEDA1C9EB9EC5E896C5EB94CCF29DCAEBA4CCECA9C8E5A3CEE8A7
C4DD9CD7EBAEF2FFCACAD8A3F9FFD9F7FFDCFCFFE6EEF8E0FBFFF4F8FFF9EEF9F3F9FFFF
FEFFFFFEFFFFFEFFFBF4FDECF5FFE0E9FACDD0E3ACCDE3A3CEE7A3D3EDA6C8E19FCBE4A3
D0E5ADD0E4B1D8E9BCC8DFABCCEBA7C6EB9EC8E89FCAE8A0CAE5A2C9DF9ECBDFA2D1E3A9
E1F0B9A6B47FA9B786D5E3B2D9E6B8CFDCAED0E0B3C9DCAFC6DFB5C0DBB0D9F1C1D5E9B8
F5FFD2FEFFDCEDEDD10A07004F4745D0C6CEFFF8FFC9C3CFC9C6CDF6F8F5FEFFF6FCFFF4
FFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFEFF
FEFDFFF8F7FCFFFEFFFFFCF99F8B82D5BEAEF5DFD2FFFBEFFFFBF1FFFAF2FFFDF8F7F2EE
FFFEFDFFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFEF8D9CEC8D4CAC1FFFDF4
FFF5ECFFF8F2FFFCFAFFFCFDFFF8FDFFFDFFFFFEFFFBFDF8F9FFF3F9FFEFF9FFE8F9FFE1
FCFFD8F7F5DC110015866D95FFFDFF679183259066228660D0E8E8F0DBEAFEE0EAFFEFF5
F6FFFFF2FFFFFFFEFBFFFCFAFFFDFDFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFDFEFFFD
F9FBF8FEFFFDFFFFFBFFFFFBFDF8F5FFFEFBFFFBF9FFFBF8F0DBDAC5B1B0FBF5F5FEFFFF
F6FAFDFEFFFFFDF6FDFFFDFFFCFFFBFFFBF5FFE4E8FFE8EAF4FEF5EEFFFDF4FFFFF8FFFF
FBFDF8FFFFFAFFFEF9F9F8F3FFFFFAFFFFFAF7EFECD1C9C6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 383.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0002?b000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`002P3oool0203in_h0lO;Z0=WL
b`3enMh0j^kC0?ool@3koO00oook0P3oool20?ono`070?_jn03oood0n_Wg0?ooo@3mo?X0ooom0?Wh
mP020?ooo@060?_gmP3?alD0oocm0?Sdl`3oood0n_[j0`3nool30?ono`2E0?Whm03cf]h0ongb0?ok
o03kool0ooco0?omo`3enoL0n?om0?ojnP3WdM<0n>k_0;6]ZP31_KX0ooSe0?omm`3^in40em;<0>g/
i`3ooo/0o?kk0?conP3loo@0o_om0?_onP3@iK`0b^2_0=CWb@3<g/@0bm^Z0=GUY03KiJH0SYQI0<_Q
UP3DjZ80an2L0<[XXP3;j:D0e_Fa0<7PW03BkJH0bN2J07b@B03;fi@0][Ym08fAE03MjJL0fnbX0<CI
U03@k:80`>2E0<c^XP2nhiD0bO2Q0<KXV`3AiZ40b^6K04]R702;XU`0b^BM0=?]YP30fY<0[/Eo0:Ro
N@3@iJ00bn>I0<7LS`3Hl[<0c^FQ04MM5@3IhJP0W9Mi034Z3P2YYgh0c]BF0<kSXP3@ij<0S9iD0:bm
N@3:eZP0e^2k0?Woi`3ionP0nOoQ0>?ga03=iJT0cNbN0=C`X`3FhZ@0h>j`08>GDP3=iI/0an:E0=G`
X`3<j9d0cNfQ0=Kj/02ni9/0aNNM0<GITP3MlJX0b=nI0<gXX@3GmJd0co:P0<cSV`39gIP0e=jO0<[D
U@1eQCh0TJIK0=7VV`2M[Fh0JWDk0?Sgf03ooO/0oogo0?ooo`3noo/0nocg0?Wdl@3oo_P0k^gH0:B/
Q`35eJ@0fOB_0<;MV03:hIT0a=^C05me;02=XeP0aMnE0=OaY`3<hI`0dn>T0=;NX02JXVH0eNBO0<K/
W`35l:40dmnM0:><F03Chj80b>VR0<WYX036jih0c>RM0<gWW@3:jId05P39jId02P39j9`0d^bR0<CN
U02[`gT0Rj5H0=G[XP3<hYT0eNfS0<3HSP3Jm:X20=3`Y`0e0<[ZW`38j9d0aNNK0=_m/@3GnJd0b>ZN
0<GWW@37jIl0a^FO0<ORW`3Jlk40b=nI0:NoM@3Bj9d0e>bP0<cWVP39j9`0b^RN0<GVW`3;kJ<0a^RK
0<;YVP3Djj<0bMfF09N]I@26XEX0SH=80694401kD2<0dLnD0=KUY03Okk00cmnQ0=CRY@38eYT0e=jR
0=cTZ`3FeZ00h=nY0=[DX01ICa`0OWm508VXG03;jYh0[<b00=GeZ@3GnJd0aNZM0<W`X@35kYl0_NRH
0<3]W038lj<01039jId0RP3Gjj<0_>^K0;WZV@3Cj:<0_<n=0:N[KP2VUf00e^NS0=;`YP36i9X0c^nP
0=C_XP2DXeh0VJ=T09:JG`3IijX0c>6N0<KYU`3Amj@0b^:H0=SWY01GFah0[KMb0=3QV`3DjJ@0d>VW
0<k]Y`38jYh0b>fO0<CTV`3Ek[@0eNfk0=[b`P39k:P0aN^F0<[]V@3?jj40dNNO0=CU[`001@00UJMe
0<GRT03AlZ40b>RU0;WGT@3FkJL0cmJC0<G7QP1`NS/0UJ=V0=W]_038g[L0ioWS0;No/P1WHf80n_Wo
0?Kio`3ko?h0no_m0?ono`3no?d0Lg=a06QYH`1`NE`0NHEM09f^NP3Lj[L0`m6N0<oNY`3JjK00a]VI
0=O[YP3@iil0a=bB09NaI`24X5H0d_2V0=;[VP3;j9H0b_BX09fnN@1[DB00/9IS0<KWV039iYH0aN6D
0<_YX`3@iZP0Y/>10;cOV`3Lol80_^6W0<g[[@3AjjX0cnBO0=7QV03MkJ@0d^JQ0=OZZP3Aiil0bn6F
0=?YX@3GjZP0d^:Q0=WYZ02]_7T0e>6Y0=WU/`3_mMT0o_oa0:nSY@3Hcm00mook0?[on@3oo?T0oO7e
0?ono`3oooX0mNoQ05=D;02neId0bnbK0<k[U`36ghh0e^NP08JJD`35h9<0bnbM0<odYP2nhYX0e_6l
0=;U^0001@00moo[0?_oj03IjkL0f>j`0=3ZX`/0oooo000:0?ooo`0D0?coo`3nooP0o_oa09fSQ`2j
_Z<0oooa0?oom03gm_80nOOj0?omo`3oo_l0ookm0?C`k@3AcLX0bLG20>cXi@3mnOH0ookk0?omnP3n
n_L20?onn`050=38aP3oo?d0oo_j0?ooo@3kno/00`3nool30?ono`2E0?gln03[d]H0onW^0?ono`3k
ool0oo[n0?oko`3ioo/0mool0?ojnP3WdM<0o_Gf0?ono@3oo_/0fmKC0>?Kf@3onoP0oo[g0?oon`3n
o_`0o?om0?kon`3loOL0o_oo0?_ooP3NkLh0f^c40?Ool`3hoo@0io;80>3Z[@3Hg:40WJEY0<cRU`3=
i9`0c^VT0<gZY`35i:40`=jN0=;a[P39i9l0d>ZS0=O]Y030e8`0d]jN0>?_[`0R<`00PYIA0=O/Y`36
hYP0bnVO0<GUVP37ii/0`N>F0<KVVP3=hYd0bn:L0<7KU032g9D0a^6J0<COV02mf940[/R107J=A`2l
dH`0b^6I0=;/XP39hj@0hORb0<KLT`2NYV/0@SdM09F<K`1@CB80KW8e0=7QXP2lcY00gnna0<GDV`2o
bid0[KR>0?coh@3Ghk/0f^Zi0=K[/P34gI`0anJJ0<GOV03IhJh0d=fW0;;8R03?j:@0enjV0=cbZ@34
f940cnFM0=7/Y`3Cm:l0cNbX06Yn=`25Ve<0enjX0;oITP3Im:d0co:P0<cVW@2=XUd0QiIE09FTH`3>
hYX0c>BH0=G]X@31e9@0/l660>OXaP3oo_<0jn[U0:JYWP3joo80mok^0?ool`3ooo40bLj`0?7nd`37
g:@0d>jV0<gWX03Ek:@0`]VA092XGP3>jI`0dNVO0<kVW03JjjL0fnV[09^WJ@3Fh:<0dnBN0<G[WP33
kYl0fNFS0;>LJ03Chj80b>VR0<WYX036jih0c>RM0<gWW@3:jId05@39jId0@P38j9`0b^VM0<[VV`3;
ii`0d>ZP0=[bZ01WOcD0/lV00<kTV`3MlJT0d>JN0=3[YP3@jj@0`MfC0<g[X@3Al:@0a^FI0<KVVP3;
jj00c>bS0<_ZY03:jJH0b^6[0=W^]@3CijP0//N4082FC@3Vo;40fO6U0<GQUP3<jZ00a>JL0<W[X@3:
jYh0a^fN0<[TV`3>i9`0dNfS0;_MT`3ZiZT0[YMQ06U75`1/KC40M8=20<?=T03KiJP0XJ]^02Xd001?
Ea/0>T0402@W001EEQ`0Si1G0<S7S`3Ggj<0d_:W0<GUVP3BlZT0b^ZQ0<;SW03;k:D0anfT0;kWV`36
lJ80a?2Q0;gXV@@0bNVM03/0bmnG0<3_W`2lkI`0e>VT0=?VY03FfYd0RGY30=7RWP34hYP0d>jT0<[[
W039i9L0fnbV09JUI03HhjL0cMfO0=7VX`32hi80b>VH0=[`Y`3Ci:00gnBZ0<oDVP2^]h80cmbW0<?D
X03?j:h0`]nO0<SWX@3<jjD0cNJ/0<gU/@3NnL@0a^ZT0<S[U`39jIH0c>JM0=OXXP3Jik800PP00<[H
Y`3Ak9/0`n:B0<c[Z037iId0c^BL0;bnO@1UJb/0iORh0=3TY`3@fk00jo_G0>Cgh@3hooH0ookk0?Gc
n03oo_l0ooom0?Whm0020?oon01=0=OIcP3Hg<d0bmVe0=g__`2GZg00TJA/06enA`1_PDL0:CP006Ee
=P3EiJ@0^Lf80=3UX03Qn;80bnBP0;oJU`3>iYP0eO:P0;oYW@2nhY`0on^i0:N@G03?lZ80a>>C0=Cc
Y@3Eljd0fNna0<W/ZP38kj`0fO^o035@5`3IlkH0`]RH0=CYY01KKB<0RYaB0;_;RP2b`X@0T:AM0=KZ
XP3Ej:H0i?Bf09>QI03HiZP0WZY/0>ce`03Ih;@0n?[T0?ool`3onod0oogo0>Gej`3loo/0oooj0?ok
n`3gm_80o_c`0?ghi033aYL0eo6b0<k]W@3;iYD0c^JJ0:6eKP35fi<0c^ZO0<GVU`34jiX0a>ZM0=;[
/@3Tm/@0mooR0?Woh`3iomd0dnNZ0;gDT039h9P02`3oool000X0oooo00T0o?oo0?SklP3noo40^l6U
0:>WS03ooo40mOOZ0?Gdl03hm_T00P3oo_l0403ooO`0j>CQ0=oKf03Whn00hMgJ0>gYiP3onoP0ookk
0?WelP3oo_/0jnKS0=G=b`3onOX0o_[i0?ooo@3no_h30?koo`<0ooko09D0oook0=k5b@3ffn00oo_l
0?coo`3onol0o?Ok0?_oo@3foo/0oo[j0>?=c`3oo?d0o_[i0?ono@3onoP0oocm0?omo@3oo_/0ooom
0?gmn`3lood0o_ok0?ckm`3oo_l0o_oo0>olhP3_o]d0nOoh0?OomP3Pi/80dmRP09VJH@1EFal0dNVM
0=3ZX03;iZ40b>FS0<OUY@3aoll0eO>c0<WWX@3CkJH0h?R/0=CZX@3>gYd0dnJT0<[NV@3Kl:/0d>NQ
0:>mM033giD0b^RN0<k]X@34i9P0dO2T0<WNV@3Il:X0d>ZS0=3[Y03Im:d0m?o80=C_Z038hY/0e>^U
06^0>`1iSdL0c>JL0<gWZ031fi@0fo6X0<oGW02FTg80LFQ90:2KL@1:B`l0fnV[0=WX[`3>g:T0dn6^
0>kjc03`o<h0V:Af0=_Y^03=gZL0bn6S0=Sa[`3>k:80foBb0=WO/`30c9`0amnS0<gWYP39h9X0eNJP
0=GRW@3IiJ<0dnVX0<;OW@30gIX0dNFN0;C:PP3Aj:80b^6K0<[UWP2ffHL0SJUO0<cSW@3Okjh0f>RW
0=?[X@37hYD0h?^^0=g`/033dIH0oOoJ0?ook`3>d/40k_KO0?WojP3]mmh0k?3I0>_]e@2SZhH0e^Je
0<gUZ@2ngY<0f>nY0<KMU@2?ZF00_=R=0<STU`3AjIl0`]R?0<WHU@2T/7809S800=WUY`3EiZ00aN^N
0<;]WP3Ghj40]9eY0=?SXP38jJ80bNVP0<K[WP3<j9d0cNNM0<[YW@0E0<WYW@0;0<_[W`3>kJ40bNFJ
0<GQUP36h9H0c>BJ0=7YW`2jd8L0R9aD08fQF@3BiYl00P3DkJT0=@3DkZD0bnNL0<WUVP3;ii`0b>NK
0<c/X@3;jj80b>NQ0<cYZ@39gk00d>Ba0=c`]@3Kkk00`mVA09^aJ03BjYh0c>RK0<GQUP3;jj80aNFJ
0<WYW@39kZ00bnFL0<WPV036i9X0a>RN0>GUY`3D`HT0TgE30<W?T@2EZ6H0PXa=05UQ9@1dOT40Uj5R
0=WSY03Rk:d0Uj1Q0=WRX`3;e9D0koRi0=?RX@32hYT0dNnW0;kLUP3<ij@0bNJT0<GRX03=kZT0b^jV
0;cUV@31jil0boBV00@0bNVM08X0c^:J0<;aX@2mkYd0dNJQ0=;UX`3IgJ00Wi1I0<oPW032h9H0b^RN
0<g^W`3Dk:00b]jG082@C`3SlK@0`M>E0<gRW`3?kYh0do2P0<[PU`2GZ6@0fn>Z0?Sjb`2e]hl0oooM
0>_fcP3<h:l0e>fd0<GTX@36iJ80joo:0?CoeP3Mn<40b>bV0<GXU037i980d>NO0=KSWP3=eJ801@P0
0=KR/P3BjiX0b^NG0<KUXP2ofY<0fNfV0:VYJ@1ZLc80^]>B0=7Y[@2maI`0MH1N0?;ok`3gooH0noKc
0?ggn`3no?l0k^_V0?oon024PWH0/[:V0=_OcP3do>D0`]>W0=W^]P37h9l0/LN908RLH@27VEd0U:IX
02<c000@8000g^j]0<_NW038gI`0c^BT0>Cl_P3<i9P0d>fK0;STU`3;kjT0i/nM08I_>`3:kId0`N2@
0<o^X037iZ00amnQ086VH`2afYP0S[1d0;CAV@3=hZL0e^^Z065e<03?hIL0c=jD0=KUY02mbi00bmbF
0=O[X`3<g9d0b=NL0=3NX`2LYfd0Ef0W0<kEXP3Ifk<0ooo/0?chk03on_h0nO?g0?;on03looX0n?G`
0?okn03oooP0`;n]04]7;P3Ri[<0an:M0<3OS`3Dkih0_=B:08FIE03<hI`0c>^O0<S[V`30jYH0dORY
0<3JV`0cAPl0jOS=0>?caP3;g:P0eNZY0>;g/P3@iil;0?ooo`002P3oool0203lool0o?oh0?col@3V
k=00gN760:BWUP3SiMP0oook0P3ooOl04@3ooOh0oo_j0=kJe`3glo00ookk0?gimP3ooOX0in?P0?on
n`3ooOX0a<2m0?onn`3on_P0oocm0?ono@3oood0oooo00<0o_oo0`3oo_l0;`3ooo/0g<?70?cQiP3o
o_l0n_ko0?omo`3onol0noom0?Ooo03Ve=@0h/c>0?kemP0N7A/0L6m]0?oin`3fl?80oogo0?ono`3k
no/0o?cj0?coo@3koOP0oocl0?olo`3ooOl0o?oc0?cok@3lool0o_oo0>SXc03GeJD0Pge9055B6@3B
kJ00cnVO0<OTX@3=jZX0`mnR0>goc02ieIP0`n2M0<kYXP3=j9/0d>^N0<_VX@38hih0d^bU0080a]fG
06@0NI=:0:FoMP35giH0an6G0<kXWP3?jIl0OY=>0;gBS@3=ij00f_F^0<CRVP2jf900cnfU0<KQVP3@
ij40cn>N0=cbZP3SoK@0amnS04MP7035gI<0f>2T09RELP1ZGd40j>6g0<o@U00d?P80dMf[0>7/bP3U
lLd0io?50=o[^@3Jj:/0Y;Ae0<_OVP3<hid0cNJR0=_i/`3AjJd0in[;09fWQ03Lm<00f?6g0=[][@3E
gj00Bd/=03do001lRT`0cn>T0;gFU035fi<0eN^S0<WPVP2X_gT0EFlX08^bG`2ddXP0`=ZC0<_PW@3M
lZl0b>BI0=KgZ03Al:80[<:10;73Q`3jomD0kOC;08REI`3Tm/@0h?Fm0>[maP3EhK40am>S08>BF@3C
jZH0cNbN0;OKQ039giH0fo:Z096]H`31hID0dO2R0<WOUP3AhY/0f^JT03I2102=VE/0h_:c0=7UWP33
jI`0`njO0=cXYP2bVfL0dn>R0<SYXP39jJ00a^^N0<cXW@3=iid0b^VM5@39jId0@P37ii/0a>BH0<WX
W03=k:00cn^P0<SRV03=iid0bMnF0=SYXP3BhY/0amRB09N/J`2AY680Igde0:[2N03Xok@0dn^O0<cW
VP3=jIl0c>NP0=3]ZP3Nmkd0mOoV0?Ooh`3gomL0kOo80=;UX`26W5@0dnVP0=ObY@3;ii`0`n>H0<o]
X`3<j9d0a>JI0<_WW@3?jJ00anbO0<;^X@3KiZ@0aKb109AoBP3GijH0an:M0=c[Z038ei@0a]FB0=?T
X03EjJ80cnFM0<KMU@2nf8l0aN6G0=Wg[@3FlZP0g_6_0<GHV030ci@0e>6Y0=gZ]03Um;d0h_Jk0>ko
aP3>jjP0a>>M0<[/XP@0bNVM08X0d>BL0;c[V`2lkI`0dNJQ0<kQW`3Df9/0ThA=0<_LV03DlZP0`^2F
0<CSU@3@j9`0X[I_07B7A@35fIX0go>d0=3WX`36hI80e_6R09J/H`2O/fh0hNRe0>_QaP2ZWXh0ooo_
0?cmj`3ionH0j_cB0<STZP3`olh0e_>c0<KRY`3@k;40`nNO0<W[U`3?jYT0f>bU09FNF`1KGbd01`@0
0=7IZP34fHX0dnjO0=3ZZ@37hIX0hoB^05=B4P2ha8@0dO6^0<OSZ021Peh0dmZi0>[ok03eooP0o?Se
0?gcm03onoT0fmG90:RRTP3kn>D0n?OR0>K/dP3Mj<H0lOoB0=ci]`3=kJ80d_2X0<GPV`3?iZ80f^n/
0=OWYP3GiZD0QiEH0::`M@33dYT0f^^e0=g_^`3?iid0cNfJ0<7]X02lhI/0H4TG0:^DH02lghl0cnjN
0<c[W@3Al:X0dNV[08nhMP2;^7L0cnje0<GNY`2@XVP0JG`l0=KZX`38gI00ambA0=STYP3TkKH0d^6N
0=o`ZP3Nk:l0cMNR0=CLZ@3iol`0em^Y09VJL03HeK80dLZh0?[aj03omol0ooko0?3om`3foOD0ooof
0;JYX@1GEDP0oooX0?SedP3:dYH0b^^L0;[IR@1nVD`0R9iF0=;UY@3@iJ@0d_2V0<K[V`3=mj40a>^H
0=_f/@37fI/0_]:G0=ga]03?i:40cN>H0=O]XP2_aGX;0?ooo`002P3oool03@3kool0mO_a0?col@3e
nml0jNoC0>CWeP3>c/80l_7]0?omo`3bkO40oogo0?ojm`3km_800P3oo_X0303oo?P0ookj0?ObkP3o
o_X0o?Oc0:2KU`3oo_X0oogk0?olo@3oo_d0o_kl0?ooo`<0o_oo0`3oo_l0;`3noOT0gLC80?oTj@3o
o_l0n_ko0?olo`3ooOl0noom0?Soo@3Td]80oo3b0?olo@0S8R00K6]Y0?omoP3ooOl0n??g0?Wdn03o
ool0ooom0?_oo03lo_/0oo_m0?olo`3ooOl0o_od0?col@3nool0nOSm0>OUcP3Sgk80THUH06=R:P30
fhh0e_:W0<SUXP3:ijL0_]ZM0?;od`3Dl;<0`=fJ0<?NU`35h9<0b^JI0<g[Y@32h9X0cnZS0080e>jW
06@0b=nG0=;YX@3?iYh0cNFK0=K^Y02neX`0cnBO0=ca[03Ajj@0^=><0=Og[P3Hn:l0`=jF0=ObZ`3=
i9h0g?2[0<[PV03@jZ<0b>2T08RQG@3To;80bm>G09NEK`2KT780g=F[0?Of_@0oB0l0>4@F0?_ok03e
on00e^:d0=7NZ@3JjJP0g^nY04AH403KlZX0`mfF0;[GU03^old0o_kV0=KO`03_omL0cNRa0<KHVP19
DQ<0fmNJ0>7OXP0b?000c^2R0=gc/P3Cjj40`mZB0=ke[`33fY@0e>^W0<K`W03No[<0a=nH0=K]Z@3=
i:00anJJ0=3cX`2eeXL0SZMU09^]L@3BfZ/0g^Rf08fOI@2odi@0cNJT0<_QX03GiZd0d^6X09>VI03=
iid0_Mn90=7eV`3Yok@0amjF08FQE`38j9`0f_V[0=O]Y03Ol:T000/004MA503Dh:80_Lf>0=CXX@32
j9/0`njO0=GQW`2RReL0dn>R0<SYXP39jJ00a^^N0<cXW@3=iid0b^VM5P39jId0@@36iYX0aNFI0<KV
VP38ii/0h?Z`0;_ER`37gI@0dN:K0>;bZ`3OkZT0koo20<cLV`3AiIh0Ni5805]a9P3@j9`0bNBG0<kZ
X03=j:40d^fZ0>7j`@3eon`0l?oO0<cM/036f:@0bmjN02i30039giH0cnZM0;OCR03?kj@0`=jD0<kZ
W`36j9/0an>I0<STVP32j9/0aOBV0=[VY02GTED0JeXT0=S]ZP35i9h0dnBN0<WJU03;giP0i?Zb0<oW
W@3>jYl0d?2T0=Wk[P2lhI<0_NJG0<KXV`3>g9h0;CT00=KOZ03oom<0TIQU0<C;V03_o<H0l_o80=7Z
Z03<ij@0bnVS00@0bNVM08X0d>BL0;g/W02mkYd0dNJQ0=;UX`3MhJ@0Ge0I0<kOV`3=jj40aN>I0<KU
U`3@j9`0TZIO05IY9`3:gYl0cn>T0<ONVP3Cjid0cNFG09>YH03Oljh0eMf/0?__f@20LFX0ooO^0?oo
m03konX0lOoM0=Ka^P3aom40dNj^0<3LW`3AkK80aNJO0<c/V@3?j9L0f>VS09BKF01FF2L010000>CZ
_03IkYl0dn^M0<gWYP32g9D0enJQ06=O803FhZ80co:`0<CRYP3UiL40oooV0?7ol`3Pl^@0ookk0?ok
o@3[hMl0X9R;0?ook@3oo^L0oooZ0>Wbd`3Gi[l0m?oC0>?o^`3<kil0b>RM0=cj/P3Bk:D0b]nJ0=WZ
YP3Ei:<0jOBh0<oJX00G9000nOoF0=_[^P3?iid0`n>@0<KbY@3>ljd0IU0N0;2KIP31i9@0a^FE0<?R
U033hY`0QYiP05f7A`1?OC`0anJ]0=W`^P15Ea/0UJEV0=7UWP3LljD0c>6F0>C`/P38dIX0F6@T01@S
003Wl[P0aLfJ0?3faP3oom80j>^l09FCK00h<a<0ook_0?olmP3om_h0oogo0?Con`3jooL0ooof0:^N
U@3dl^<0oooV0>OU_`3PjJP0e_RT0=CcX`3EkjD0cnBO0;g@T03Cj:L0`n6I0=?hZ037lI/0bO6K0;KA
RP3Lkjl0eNVZ0<ONVP3Bj:00e^fO01he0038gI0;0?ooo`002P3oool05P3mn_<0ooof0?oomP3oooP0
n?_b0?gonP3oood0m??a0<Bk_P3ainP0oock0?omn`38`;h0ooSf0?olo@3ooOd0oOWh0?omo03ooOh0
o?Si0?Sfm`3ooOh30?ono`@0ooom0`3oool04@3oo_l0oOcj0>:la`3of^D0oooo0?kmo`3on?l0oo?m
0?coo`3fm_@0Z9fK0?olnP3omoP0;2HX07QbM03nn?X0n_Kg0080ooko00D0oooo0?koo`3lool0o?om
0?klo@020?omo`3D0?ono@3oooX0n?oc0>kgi03HhKH0g^>[051;2@2SXed0dNNL0<oWW@3;iZ<0d>b_
0<GR[03`on40_=R_0=3/_035h:T0d^^W0=gj^P3Yon00g?W;0=S`]P35fiX0bN2H0<_XU037iHl0c^bF
0<gVU@3ChiX0CELH0?Wke03RjKl0g^nk0=ke_@32hYl0b^jX0<W_YP31iI/0aNNK0=CbZ031giD0eOFY
0<7QUP1YQ3d0a=^G0<oNY`1MJ3d0LW]@0=SR/03Fi:L0dnRM0=CSX03OgKL0LGM;0;_=T@3FjjX0e^JO
0=cXX03Eg9H0/kii0=?RW`3?jJP0i_W10?cif02f`IL0c]n[0=;LY`20ND80XYeS0=k_Z`36h9T0/l:1
06ET:`2JV5l0d=nN0<CDT`3Qn;80]m:;0=;bY`2lj9T0cNfT0=cf[`3Lmk00`N>I0<_]X@3>jZ00cmjI
0:N]K@2?UEL0dMnQ0=3SX`37gYX0RJ1J0=W`ZP37gYP0c^>P0<KKV020Ue40g?>[0<SRV03@kj<0do6W
0<[UWP2:Y5d0cN6J0=KUX03AgYT0f^JT05ET8@3?hih0eNZW0<kYY03@jZ<0`nVP0<3VW@3OgZH0bImg
0=oLY`3ChZL0cnFT0<WXY039j:80b^RP0=7]X`3=jIh0anJJ0<GUV@38j9`0a>JI0=?hZP35k9d0a^nP
0<SaXP36kj00a^bO0;kRV038kJ00anVM0<k`YP34i9/0a>BI0<g[X@3<jZ80b^FN0<[ZW`2ih8d0bO2O
0<7[V@2ojID0bO>Q0<3ZV035lI`0_^ZE0<3ZV035l9h0_nVG0<C[W036jid0b>NK0<cVW03AjIl0EfdU
09V_I`3DjjL0_mZE0=Ke/@3Km[l0mooc0?GojP3Ci[P0cN:Y0<KMU`3>iId0cNNN0;[BU03Il;X0`=N[
0<cO/@3;gY`0dNbY0;kSWP31jJ<0aNVQ0=3^Y03DhI`0[kEe07Aj?P2neid0dNj^0<oXU`3@iil0c^^A
0<cZTP39iZ<0a>6=0=;Z[03Kl;P0dnRU0<GGW@2ib8l0_m>>0>3c/@3Ai:@0nOo=0<[NX@3@i:L0B64P
09beM03DlJh0_]^H0<_ZY036ji/30<S[V`1^0<;RV@2nhYP0a^NP0>[o_03?hZ00e>2P051F603Ei:<0
gNf/0=[^Z@38giT0bNNM0<g[Y@3El:d0m_o<0<GJU`2BYUl0Zl1a0;78MP3=j9/0d^jT0=3U[@3TjlX0
loCT0?oom03nno@0UYB70;flY`2JXGL0fnB_0;W8Q`1HJBD0c>6N0<_TXP3@jZ40eNnU0=7YW`1^QS80
/L>700012@3hoo<0mooF0<GNW03>gYL0IEPS085]>`3RjjP0`=f=0=?oZ@2dh8L0e>>R0=OKZ@31`jd0
a<Ji0?oon`3joo00nOoX0=k/]`3@gZ00e>2R0=[UZ`3Oj;d0k_K=0=?RY`3=gYL0d>JA0=GZY`3AiZD0
e>ZH0<3HP03<iiH0bnVQ0=7/``33f;T0looY0:R]S`2<S6P0d>6K0=G/WP3=g9T0g^J[05]E9@2l_Xd0
a>^/0;o/Z@35m;00GhA1059Z;01fOT<0MGm20<7KVP3;kjT0`NFM0<SVWP30e8d0OhA105EJ5`3BgIT0
d>6M0=_/Z03HijH0WZI]092@GP3_il80oooO0?C[cP3Ie<00fM[:0?3jlP3good20?oio`0H0?gln01c
LfL0D58m0>W_b@3lomX0b=FM0=cWZ`3?fiT0enRR0=OaY`35i9P0do6Y0=_h]P3>k:`0cnf_0<KTYP00
6000>E4C0<[JW03Ii:X0I7Le08nTG`2ldH`0c>>K0P3;iI`;0?ooo`002P3oool0103oo_P0o?Wb0?Ke
l03lo?X20?koo`0@0>c/k03oo_l0ShN50;2VY@3kl>h0ooOf0<[1`P3oo?d0ooSi0?omo`3ono`0ooko
0?omo`3mnoh0noWl0?ono`<0oooo0`3oood50?ooo`0@0?ono@3gcML0onKa0?koo`3oo_l0ooCo0?o_
n03lood0ooci0=;9a03omo80oocm02dW:@1jM7H0oogo0?omoP80ooko00D0oooo0?koo`3lool0o?oo
0?gmn`030?ono`250?ooo@3koo<0hNkB0<kLZ@3IhjL0GEdE0:NYGP3?iIX0enfT0=K_[@3<iZT0bnJa
0>goh036h;/0`mbd0;cDY03RnkX0l_oA0>koiP3FlLP0`]FM0=OZZP3Xo[D0cnfG0<CUS03:ji@0a=n>
0=7QV01jQ4L0g]fn0?ooh@3com@0cnJ`0=3`[`2df980co>[0=3bZ032hYL0`]jD0=SdZ@37j9T0dO:S
08^UG03RnKD0c=nX06IfA`17EbP0_m2L0<_MW`3Ek9`0dN>I0>SZ^`2OYW<0KGTk0<GDT@3Kj:00e>2H
0=kYY02iaX40[Kak0<cNXP3Vlkd0k^c50:JbQ03Ljk@0j>fe05]>5`3Ugj<0b^FN0<W]X`3@hj40LFld
05iE7P3`n[d0hnn_0<7FT@3HlZ/0^m^@0<?]X@32hYT0a=jG0<SLU`3?iZ00aN2I0=;/Y@3LlJ`0/kmm
08:=B`3Ii:80dNFP0<WPVP2fcHL0WKA^0=cc[@3>iIl0i?^e0:BkM@2Z`G/0bN2J0<KPV@31hIP0e_B/
08ZTG@3Ql:d0c]ZH0=COW@3PjjT0A5DA0=S/Y`35g9H0cNRQ0<WTW@35kJ@0a^bS0=cJX@2nTfT0hM^W
0=CRY@3?iJ@0bNRR0<SZX039jJ00a^BJ0<c[W`3Al:@0d_:V0<k^XP39jih0b>ZM0<7VV03=lZ@0`>NH
0<?XV`020=;`Z01;0<[XX03;iYl0bN>L0=G/YP3Mm:h0d^NR0<oTW`3Hk:L0d>NO0<odY039k9`0_N:B
0<ccXP3=m:<0^N>A0<WdXP30jiT0^>>A0<3]VP2ljIH0a_6O0<_eX`3@l:@0cn^P0<gTW01BIb80CV<N
0=S_Z`3@jjP0bNRT0=?_]@3foo00m?oY0=OY_`3Bi[<0e>f/0<_TXP3BjjX0]LbD0<_Q/03<hKX0h_76
0<oGV`3IjJ/0`n>R0=[o_03:iJ00e^NQ0>?XY@35ahH0W:9V0=SY/`3=hZL0dNVK0<oYXP3=jXd0bnV?
0<SRX@3Kmj00c^>X0<SIY@2jbXT0];j90:ZgP@3>iId0fo2[0=3WX`3/ol40d>VW0<SSX01HMC80EW<`
0<o^ZP3;j:D0b>RO0080a^^K0P38ji/0RP36jZ80bNRR0<k/YP3/okh0eNRV0=SXY`1AGAd0f^JV0<OF
U@34e9<0h?Na0<SXW@32hI/0f_Ne0;36R03Zokh0HGD`0:NlK`31f8H0d^fP0<g[X@35hJ@0d^>f0>ki
f`3ionX0mOWX0?Kdi@2b/YX0MG]?0<;9U@2`_g`0>d`60=_aZ@3Mm;00_=J=0<cVW033gY40OYY30<GN
W@000``0lOke0?Oog@36fj00gnVR06aF9@2ZSf80cMfF0=coZ`2aiH<0e?nR0=c]YP3Sj;00^[JM0?Gc
i03gn_<0k?oS0?Cog`39h9`0g?>U0<_KTP3HijH0lo[@0?Omf@3?fJL0am>E0;71MP28VeT0TJAT0=ob
X`3HkYT0`]n?0<o^Z02geZ`0gOKF0?Gok`1YJeD0b<:X0=g][`2mdh/0dm^O0=oRZ`1<E2<0YKF40<W/
]02ZdYH0Q:i_0;kNW`2bc8d0SI5F08nCEP34gIT0c?2V0<KXWP3BkJH0koji071`<02XZ6P0amN@0=cd
ZP32fI<0c=nM09fUK01lNd/0n>g=0?omh`3gj=D0oo[_0?7^i@3hood0kOcg0?ojo`3onOl0oogj09FC
Q01EF3d0h>jm0>gla@3Slk@0d^:Q0=[YYP2^^WX0`=ZA0=7_Y@39jJ00_MbI0;cJVP25XVP0Gg]105eb
>P2<WfL0hNnd0=gX[P2AYV<0[lJ00<_RW03:i9d0b^FN0<[XX0/0oooo000:0?ooo`0@0?oln`3ln?L0
o_cm0?ooo`3in_`0loGd0?ooo`3lnoT0oo_h0>CKeP37_;H0oocj0>?Jf`3<`l@0oo_k0?ggn@80ooko
0P3ooOl00`3no?l0ooko0?ooo`070?ooo`80ooko0140oooo0?kjm`3[`/X0om[S0?Gin03inOT0ooOo
0?oho@3looX0k^_T0?ojl@3on_<0oogk02DO8@1cKFl0ooko0?olo@020?ono`230?ooo`3nool0o_oo
0?koo`3moOd0ooko0?omo`3oo_l0ooom0?Wol@3Ljlh0e>Fa0=gX[01[KB@0NX4d0<[PU@3Aiih0b^6M
0=7WZ@3>iJl0mOoT0>_og@3@ikd0bn6`0=Ka[P3Ro;/0f?;20=W`_03@h:80dN6P07b@B03>jiT0aNNA
0=7cW`35i9H0d>JN0;6oPP3Sil80o_oM0>3b`03XolL0b^VV0=[g]033hI/0Rj9L08ZPF02`_gX0G70X
0<GVU`3FmJL0//b30;oFTP3AhZ`0/;f?059O<@3Ol;`0e>JX0<oVV036g940f>Vc0=SQ[01^K3<0HElR
09bVG`3SmJ/0bnNL0<KQVP1iSTd0iNZb0>g]^`13@QH0a]:P0<?BV@3EgJ80[ZEZ0>3NX@3>k:80bNnR
0=W`ZP3LgYl0jNBZ0:Z`LP3Gh:40h>n^0<WMV03CkJH0b>bR0=CdZ`3=ij00inb/09jLG`2kbXL0]M>;
0<7]X02oj9`0//b50>SVZ@3MjJL0cnBO0<OLU`2J[fX0_mB?0<SMV03<hI`0d>FP04mT7`1fRdH0_mJ@
0=3^YP3Ak:D0]lj80;31O@3Dhj00cm^I0=o[Z@1?GQ/0/<5m0=c`Z`3=i9`0b>BJ0<G`X@34kj00e]^K
0;JBHP3Kgj80cnJR0<cWX036jih0a^^M0<SZW@3:k:000P35iIX0E@38j9d0aNFJ0<CRV03=jIl0`mnE
0<WUV`38hYT0d>JN0=7LVP3PjjT0b]FC0>[c/P3MiZD0fMnO0<W?S`3CfIT0f=jN0=3EU@3Fgih0c>JM
0<kUW@3?jJ00dnnU0=3/XP3ClJL0`n>H0<g]XP3FmZ/0b^bP0<c^XP31iYP0`N>F0<KTVP3<j9h0dNRP
0=_b[02kdX`0aMbF0=7/Y`3:j:80e^ne0>_kgP3gonX0jocH0=c^b03:gK00d>>e0??oeP3gomH0l_oA
0;c@V`2mbY@0knRa0=SIX03:g9h0c^:S09BOG@2@Te00XiUK07ib=P1RFB00fMVW0=CMY029XEL0RImN
08JPB@24WDT0PIMF082J@`27Ve`0U:Q]0:6eKP3Ai:@0enV[0=3ZX@3<hid0cNNP0=OaZP3>jJ@0b>>N
0<;MV03Ak:L0ZLN10=[e/03:j:000P38jYd20<WYW@2:0<GYX@39j:80c^VT0>;g]03BiJ<0enNV05UX
9`3=g9/0fnZY0=7QX02oeY00bnZN0<WWX@38hZ40i?Vn0;W=T03;gYh0U:QP0;kEQ`38i9L0bNNM0<_Z
Y`31fih0enZl0=SZ`P3bon00o?oX0?3je`3Jj;D0fNR]0<_RW031fi@0OYQA07bFC`2CZf40SJEI096Y
G@34gXD0d>JU004;503_n_80i?G;0=3SZ`2KYF00GDdI0<jjR03;g9H0/]R50;KWR`32kI@0cmjI0=gP
Z`2OWX00ooo]0?GmkP3Zo]T0i?c:0=O^Z03FkIl0j?Nb0;_9SP3Eg;/0dmS10<G<Z`3MiK`0f>F_0<oT
X@3Bij@0QiMF09FVHP3;hYh0h?Zi0;GBV038hk00looM024S2`3/iM<0dN>a0;oIW03Lj[D0bMJQ05E/
>01GLSd0U[5j08RLI`26Uf40cnBY0<OSYP3;gYh0fNVX0<gVXP3?jZ<0en^V0=3LVP38cH/0J6PX0=_P
WP35fi80e_JZ0<WYWP3GlZ/0^/N?09fSL`3Ab:/0oogX0?o]g`3om>`0oogh0>;SgP3loo/0ooSk0?of
nP2_Zil0MgUS0<oE/`3SlKh0c=^R0=;UY@32eI<0ZKUh071n@03FlJX0cnnT0<;PV03AkZ`0UK9b02Q1
1`1MMC/0dnR]0<cPX`3:g9h0Y[Ig0;kES`3<iYl0eNnX0<SSW038iYh0c>bS2`3oool000X0oooo00l0
ooko0?omo`3jnOh0noco0?[ko`3nool0mOOd0?oon`3cknH0noCZ0?kgk@38`;d0nO?c0=_Ee@3on_X0
1P3oo_l20?ooo`80ooom0P3oool60?ono`0@0?ono@3P]kl0oMGM0?_on`3noo/0oo?e0?ohn03ho_80
a<Bh0?onl@3llnX0oogk01dI6P1[IfP0ooko0?omoP80ooko103oool0S@3moOl0ooko0?omo`3oo_l0
oook0?Kok`3Xnm/0b]jY0<_MW`3=fHl0Z;AX0=S^Y@30e8`0g>^Z0<SCV@3Li;<0o_oS0?koi03Ok/<0
f^bh0<gYW`3=jI`0f>VR0=?PVP3;eI00QI1;0:NgL03=iih0cNfR0<W]X`31hiT0a]nK0<kTY03Pm;l0
]LZB08JNHP2T_Wd0eNnX0>?j]036fY<0i>fZ0<cAT@3/jZd0UIYH0<WSV@3@jih0HgTa0=7TXP3Fhjd0
FFDe08RDIP1cPD`0W:a^0=kcYP2jch@0a=>H0=OUZ03DgYl0hNbZ09FRG01LK2D0eNBQ0=?RX@3=f9`0
dmbW0=WP[03Sj[@0g^ba0<gMWP2AW5X0i>NT0=3JU@33iIP0_^RF0=?bYP3@h9T0dMbH06=n=`1GLR/0
fORb0<_/Y@3?mJ`0^]jD0=3OW03_kk40IU4J0:^JHP1BGQ`0T[1X0;gYW033kJ40a>JL06Uh=@2;WeX0
go>^0;_?RP2W^gH0C60K0<WMV03=hI`0eNVT0<GIU03Smk80ambG0=S_Z@39h9X0amjH09J[IP2M/Vd0
cN6L0<oPW03?fiT0?TT70=KOWP3BgIT0dnZL0<3/U`2kj9<0dN>I0;RTJ@3AiIh0aNbM0<K/V@33kIT0
b>^G0<WZV@33j9/0cNnU0<c^Y037hY/0an6J0<oPW03Ei:40c]NF0=3FUP3EfYX0jn^]0:RRI02ASDh0
C4P90::NG`020:2LG@0c08R4A@2PW5d0YJAT04Q71`0V9P00TIIL07YoA@2Y/GH0f>2U0=gUZP3Egj<0
hnfa0<kIW@3=f9`0gnZ^0<oMW`3:giX0cN:M0=?ZY03Ajj@0cnVR0=;/X`3Ajj8083X00<kXW`33fY80
g_Fa0<oS/P3GjKl0l_oX0?Ool`3dooH0n?oh0?Sol`3Di;d0a]RT0<kRV`3Ci9h0^l260>7_/P2T_G/0
Z<5m0<[NU`3:ei40fmbJ0:f]K@1bM3D0cMFI0=KTYP3Bj:P0dnN/0080enVM0:00enJU0=KYU`3CjZ80
e>jW0<[ZU`3:k9l0`nFI0<KVV`38j9d0c^bR0<_YW`38iY`0a>2F0=OaZ03:i9/0XKQ`0:_2NP3DkZL0
bNVP0<[XX039jJ00bNVN0<SZX039jJ00c>NP0=7XXP3?i9l0d^JQ0<_OVP2M[VX0AETD07:6@@33fI40
b>2B0=W`ZP2ndYD0d>2a0<cL[@3KjkX0e^Z]0=W`[033gi@0bnZN0<OZVP39kiP0c?6Q0=Gg[@3<jZX0
j?o90<kZ[`31gY/0a^BL0<k`Y038k:80c_2V0<cXW@36gY00h?RZ0=;YV`3Fki@0d^FS00011`3kooP0
j??;0<GBW@2Q[6X0GEhR0=cPX`31g9D0d_NZ0=7fZ@2ng9@0en6U0>_[^@3Vjl<0n_oO0>Chd`2hdi`0
foFd0;oGR`3NmJL0X[5f0<G@Y@3nooH0n?[i0?coo`3lood0jNoU0>goe@38g:/0h^k00;k7VP22SeX0
nooA0<SNWP38gZ00enVe0005003ooo40m?WU0?Gok02IcIl0LZ]f04Y]=@1YOTH0XJ5[0;^kQ@3Nhj/0
d=jS0<kKX`3:kjT0bO6X0<kQW`3Fg9`0/:I[08Aj?`1SFad0bmJB0=KZX`3>ljD0_>NG0;k]W02mjIX0
c>F[0>kkc`1[He00XI280;NRW`3lh^D0ooKf0?okm03oo?<0mO;O0<g=]@1iOed0jo?:0>7]_@3Jk[40
dnRW0=O/Z@2kd8d0b=^K0=?UY`30gYP0do>Z0:?1N`3Fkjd0b]jO0=_[[@3Di:H0c=nO0<ONVP27XU/0
Xkme0<WWW`3:jZ40bnVQ0<OWWP3:jZ40b>RO2`3oool000X0oooo0100l>k_0?ooo`3mooh0o_oo0?gn
o`3bm?<0o_om0?_lm`3oooP0ooof0?ojlP3SfmP0oogm0:>MW@3ooOd0kNWZ0P3ooOh30?ono`80oooo
0P3oood20?ooo`H0ooko00h0o_[i0>_1b`3ofn<0m?_d0?Sjm@3onO/0nNWY0:BZWP2UYIT0oo[]0?om
m03ooO/07a/L06iZJ`@0ooko103oool0`P3moOl0ooko0?omo`3oo_l0oook0?Sol@3RmML0cNFa0<[P
XP3JjZ<0e>BK000?003NkjT0cmVL0=7HXP3Lgk80nocL0?ooi03lomd0i?O00<OSV03@kId0go:S0=KT
V@3HhY/0Yk5/0<7>R@3Gl:`0c^bV0<KWX031hIP0bN>L0=3VY@30fYd0cNNX0;K@S`1QO3L0cnVP0<7H
T03Cij00f^>P0>GWZ03NfYd0Y:IW0<OOU@3AjId0UJUQ05MX903>fj<0L7Y808jGJ03Vlkh0c]jP03U>
0@3QljL0fnJZ0=KVY`3@ij40bn:J0=c]YP2FXE`0HFDX0>W]/P3EfZ80ho2j0<SEW`32c8l0e^JW0<kM
VP2[^7<0d]bG0=_[XP3AmZH0^>>A0;oPT@3<h9P0hO:[0<oYXP22W5D001000;_IT`34hid0f_bb0=cR
XP3Ec940JULO0>WOY028U5806c000<?MUP37iId0c^jU0;cLT`28WeT0cn>N0>Ch/`3FjZD0go>^0=;V
X@3EjJ@0e>RS0=ga[02mdH`0DVHQ0<OKUP3JkjX0fo2[0<oYXP2nf940g?6/0<KJU@3GhZ00E5XJ06M/
;03Oi:80dn>H0<?]U`2ok9L0cN:G0:jNHP3?iYh0`nbM0<K/V@35k9T0b^ZG0<cYV@3=kJ80bn^R0<WW
W`3:i9d0dNJQ0>?_[@2mb8H0fn2P0>W[[01UHbH0D4hA069R8P2a/G40hN>R0>KXY`3@dY40f]nM0>S]
Z`3KhYl0emjK0>O^Z`3PiZH0GF0W0413301`Lc`0AT/A03m22`3Oi:`0d=FK0=cTZ@3Oijh0dm^R0=oY
[@3Hi:@0eNBS0<gRW`3>iIl0cnVR0<gYW`39iI/0b^BJ03mG3@3OmJ`0c^BL0<cQYP3?hk00m?oY0?Oo
m03hool0n?om0?SonP3Mk</0eNFf0=GXYP3>hYd0bmfQ0=O][`38ij<0eoRa0=?_Y@3HkZH0g^^V0<WD
T02X/g40gNbY0<gPWP3;hJ40c^:U0P3Di9/04P3EhIl0d^>C0<cSV`3:j9h0`nJD0<KaX@31k9d0anbO
0<W^X@35ii/0b>RL0<c[W@34h9D0a=jD0<GMT`3:h9P0PYQ@0<cSV`80b^NT08`0b^RR0<WYX039jj40
b^RP0<_YX@3>j:40d>NQ0=3UX03Nljh0d>BO0<kRW@2FZfH0BV0G05md9@34f9<0c^2V0=3O]03=g;<0
n?oM0<GJX@33g9/0`^2F0<o^XP39jYT0anjC0<CZT`33iYH0anNN0=Ca[`34hIh0bNNM0=?cY`2jg8l0
bo2S0<;TVP36hI@0d^ZL0<gUU`34fhd0e^fC0<?CTP0000D0o?od0?kog`3Tk;/0QHm@0=CNW`3VmK@0
b^VS0<gaZ@31h9`0h?Jf0>K]]`3:bYP0m?c=0?Wog03=ikL0dnnb0<g[Y@3@jih0amnC0::aN03_n]80
o_oj0?koo`3lool0m_Wo0?Chn@3conl0mOoZ0=kX``3BfJl0Uj1[07Z5C@3Ai:d0dN>c0=GV_00W<1D0
ooo_0?_on03Un^T0HIE^082jR02^eYX0`]ZN04i>4P1fM3/0hN2W0>oi_@3LjZl0[]R@0<WeZP3GiZD0
g=ZM0:fLI01ZFb80WYQJ0=?WX03AkJ<0_^NH0<SaXP38n:@0aOBS0<OSZ@3NkL80Yij?05I4@01K@TD0
ooKj0?ogn03ono40ooKW02`]3@1DFc80en2c0<_GY@3Wm[l0c^BT0<OMW02jdHd0N8m;0=;XY`35fIX0
e?>]000B00004@00iOZi0<SKV`3Hi:H0gNV[0=[]Z`3:hI/0P9mC0>3o]037iI/0b>JN0<WWW`3<jZ80
bnVQ0<GSV`/0oooo000:0?ooo`0@0;S1YP3anN80hn_F0?Snl03nooP0o_om0??em03jn_X0oooo0?om
oP3oo?/0ookm0?omo@3ilo<0oOWh0?_gn080ooko103oool30?ooo@80ooko0P3ooOl30?ono`0A0?om
o`3on_h0iK_90?oJi`3hool0n_on0?ojo@3ono/0ZK2Y0=GDc`3ml_00oocj0?onn`0S7ah0LFe/0?oo
o@3mo?X01P3oood0b`3loOl0ooko0?omo`3oo_l0oook0?OolP3dond0f??60<oW/`3CijP0c^>R0=GY
ZP2ib8d0a<RE0<k=W`3MfK@0[:F;08Z6K@3EfkD0cmf/0<GQU`3:jI/0bnJI0<KLT`38e9@0en>U0=CR
Y@2_aHD0Tje/0<gXX@3EkjD0cn:C0=GWV`35h9/0c^VT0<k/XP3Al:@0bNRJ0<SWV@34h9<0d>BL0<cM
U`3Ghj<0TJ1M0<kTV`3DjIh0bm^D0=SWXP3BgJ<0PX]F08bFI03DhJ/0d^:T0<OLS`3Jk:00NXU808jR
G@36hYP0bnNM0<oSW03BgY`0e]NM0<g>U@1JGBH0enB^0=;TZP3JkZH0`=6;0=gZY01;F180cnBI0=;/
XP3;lZ<0a>jL0;oRTP3Hm:T0b]jF0=OLW03MhZ80dM:F0>7RYP2RXfT0V:MT0;6jN@3NijH0d=^I0=oX
Y`1gMCP0Y9]P0>?GW@3Jh:00bN>L0;OXV@2K]Vl0_Lj:0<;CS`3Sm;00_m2<0=OXY02gb8@0^<V50<_L
V03Bhil0d>6M0>3/ZP3MkZX0c^>N0<cWX03Elj/0b^FN0<oVX037di40h>FU05eM7`3UhJ80g>6N0<[Y
W@32iiX0dMfK0;6LI`3@iJ80aN^R0<[XX03:j9h0dnBM0=KSW@3Ei:40enJU0=SWYP2Y]GD0Mh=308J@
D@21RT/0LgTk0:2VJ03Lh:<0en:P0=?_Y@3BkZ@0d>bR0<GSV@3>k:80bn^P0<_]X@35jYd0anbO0<S^
X@37jId0c]fL0=OSX`3BgYh0fnNW0>3/[03EhJ40]/:208^JF@2FYF@0FVTX02Lc0020Q4T0Z;1d0=CT
X`3Cj:D0c^RQ0<KRV03Dl:H0an6G0=kdZ@1lST@0h?:X0<[QV@3:h:00iOO=0>kog@3hoo<0n?of0>Oe
iP3VmN80i?CJ0>Whe`3Rm<`0a^>]0<SU[@36iZ<0bNfW0<c[Z036hj<0f>j`08nSI01<Gal0c]jG0=KX
WP3=jIl0c^RO0=?TW@3Chi`0d^6L0=;SW@3;iZ<0bNVX0;gVXP2lkjd0]^VV0080`NZN09L0b>nP0<GZ
VP3:jiX0bnZJ0<OOT@3JlZ@0dNJK08fNE`3FjZ<0c>JW0<cVY@3<ij@0b^NT0<g]Y039iil0cN^S0<oZ
X`3BkJH0bnFN0<WSW03=ij00_MB>0=cc[@3FjZ80/l5d05aV9`3GhJ`0a=:^0=_[a`3boml0bMn^0<[S
Z@3:iIh0bNFJ0=;]WP3>iiH0eN^P0=S^YP3=hZ40f^n/0<KKUP3Il:80`]V90<SOT@3=hiX0e^^V0<cR
U`3Nm:/0a=RA0<[NV@3Ahhl0c]fL00840`3Lgl`0JFi505AJ:P17DQH0b^BM0=Sj[P32iZ00^m^H010U
002AWf`0f]f^09NKJ@3Ynl40lOo;0=3`[@34hid0d_2X0=3ZX01gSTH0eNJ_0>SebP3joo40o?ok0?Ok
o03iood0noom0>_go`3eool0o_oZ0?oof@3Xj[P0`LNI0?[okP3_no40n?ok0?_ol`3Sjm<0DfYR07jI
U03BiM40gOGC0<O[[@34j:00dNJI0=WPVP3TiJ40F5hN07Z=C@2jh9L0d_>/0:bbM02ZY6P0g=>H0>7Q
X`3JjjD0coFX0;SSU03CmJP0an6G0<_^W034jIT0d>>/0?kog`3onnl0gLW80;ROXP2dW9X0`JjW0:BJ
P@2RWGd0eN:Z0<_NWP3Kl:d0`=FB0=K[Z03=i:00//^70:O0O03EkZX0b>6O06=l>`2Ua800anJP0<oZ
Y@3Slk80b]JD0=KOW03>fID0Sj1I0:o5NP3=l9h0fOn[0<gWWP3>hih0c^:M0=7UX03@i9l0dnNR00/0
oooo000:0?ooo`070;W6VP3CgkL0hNg90>Waf@3fn^T0o_oj0?koo@020?koo`<0ooko0`3oo_d30?on
o`80oooo00<0o_oo0?ooo`3kn_H00P3oood20?ono`030?[goP3ooOl0m_Cg00<0ooko00l0oogo0?G:
f`3hd^40m?ok0?Woo`3omo`0oo_m0=cUh03oo_l0o_;f0?oko@3oo?`00@0006e/JP3gm_@0103oood2
0?ono@2:0?ooo@3bm_L0oooo0?omo`3on_`0ookm0?WomP3eoo40g_SA0=3W^@3:gZT0dNB]0<3AV`3H
i[40emZ_0>CR_03JeKL0oOKS0=WD`01oQF<0e^>g0<oXY03=jj<0bnZV0<oYZ03ChZT0f>F]0<oNY`2a
ahT0IWln0=SbZ033f8/0gNZH0=3NS`3Nn;40a=jG0=Wh[033hY@0cO2N0<?VU032iI<0`=nC0=7]X`31
g9D0[<Io0=KZXP3Bi9X0dN6H0=gZY02AVel0OhYB082:EP3EhZ`0bMVK0<_PT`3Dk9h0[<N009BYI02@
VeT0KgPg0=cXYP3DijD0dnVX0=S/[@2@WV<0Si5O0<;7S`3KlJH0d>2I0;>mN01?FQD0aMfC0<[XWP33
j9/0b>fO0<OVVP3<j9h0cNNN0<kRW@3Hk:L0eNBS0=_ZZ@3JiZP0gnBT0<[QV`3AkjL0cnVR0=kTY01Y
EQh0hljG0>_OY@3QkJ/0cnJP0:c:PP1WO3L0dN:N0=_/Z03@hId0gNjZ0=WZYP2Y^WH0RIYF0=WZYP3F
ij<0bMZF0;[6Q03<gIT0eNZU0<COV03>k:@0d^fV0<;LU@3UlJl0b]2@09:DE@2XY6L0jn^]0=ke/@38
iZ00kO:h09MjCP3:f9d0e_Fb0<CJV@3Aj:@0dmjL0>3VYP3Kgj80dmNJ0>?YZ`1PJBX0De`M06E_<01h
Q4@0]lJ50<kMW03HijH0dNJQ0`38jYd01036jid0aNbM0<7ZV`2kiYH20<7^W@180<OdX`2oj9T0d>ZP
0<kVW03Cjj40bn>I0<OOU@3FkZ@0ennU0<[RV03IlJL0T:QN09>WH00k?`@0GfL[09j]K03FjJL0cNBN
0=K`Y`36h9L0bN6G0=?YWP2<WU@0f>ZP0<[PU`3?iZ00bn2W0>_oc03gon@0mooZ0>Oih@3eooH0koob
0>gmlP3aoo00e^S00=;U]`2AYFX0/LF80=OZ/P3AhZ`0Z;B208B<F@1;DaX0Xj=S09NNF01jVd`0SZeO
0;_CR@27Ve@0RYiI092TI@1ELcL0a^V_0<[b_@2TeZ40]>F]0;oYW`3:m:P0[mJ70=;gY`3;kIT0bNVF
0=3YV03Dk9h0enbQ08>DC@3>hY/0gOFg0=_c]@3Lmk@0c>VV1@3:j9h30<cXWP80cNNN0800dNFM0<gH
S011BP/0cmRS0=7O^`3=g;/0looP0<gU/`3@jJl0`]bE0=?]X`3?hi/0e>6L0=CNXP3MiZd0dMZS0<OA
U@3Rk:d0fnNK0=KSU03Ojj40f>BL0=gYY`3AhY`0fNbZ0<WIVP3BhZ@0bmb<0<kLWP010`00Ui^4038h
3019D1d0Q99E0<SXW`3Bn:/0bNfW0<[XZ01SM400c=RX0=cO/02;TUl0fNf`0=gh]@35iYl0d?6Z0<;P
V03Ajj@0Mhi80=KX[P3KjKP0m?gP0?_ok03koo<0loc[0?[ol03^n_l0m_oo0?kok`3oon40emZ_0;>i
U@3iooX0mooo0?Koo`3Zm>/0kOCR02/e=03eool0^]:l0>Wof`3RkKD0en6R0=W`X02geXH0a^VG0398
000R:`00dnRU0=?ZYP1gNch0I60S0=WNWP3AhYh0c>bQ0<KgYP2okYh0f?:X0<_HTP3BjY`0a^6D0>7[
]P3all`0ooc_0?ojm03[e]<0ooO_0?oei@3/k/T0e]fa0<KKV03GkjD0cNBL0=3WW`3=i9h0b=nK08:K
F@2jdi40d^^Y09bgM00[AP<0a>6N0<[WY03HlJd0fnbX0=gYY`3Lij80JG@_0=_]X`37gY00cNjM0<G[
V03=hIX0fNRU0=cXYP3NjZP0a]:@09ZVI0/0oooo000:0?ooo`080>Sn]P2L/G00bM^O0>;_``3lon<0
nOg/0?komP3noo/20?coo`060?_lo`3oo_l0ookm0?ono@3oood0ooko0P3oool30?koo`0L0?ooo`3g
m_@0ookm0?oknP3mn?`0ooco0?omo`3nnOd0nOGb0>gZh`3hmN`0oood0?onnP3S^L<0ooCj0?OonP3b
o_@0oock0;N][P3iool0ooko0?oio`3on_l0oogn0001001]KVT0[:fX0:j]Z@80oook08d0oogj0?on
n`3oo_/0oOcj0?_oo`3oool0oo[n0?olo`3on_`0o?ok0?Son03eonl0lOoY0?GohP3ion80o?oT0?co
iP3nonX0o_o]0?Ghi`3oooP0mOS_0?_ok`3_oM`0f>^d0<OOY@2lfJT0eNbn04UI;02MZW`0_/jM0=?/
/P3>jj/0f_F^0<gWW@1;G0h0bm^@0>7h/P36gID0fOFZ0<?RU02gfXP0a^bI0<[`W@3:lJ00`^^M0<7Z
WP32iY`0DfLO0<kOV03FiY/0konf0=?OW`1aO480RIQQ0<gOY@3RmkH0gOFY0<KQU036gi/0fo2]0<WC
U03GhJ80S9]J04iQ8@3Bj:L0k?o20=g_/@3Cfj80fNFW0=WdY`3Ch9P0j>ZY0<S>SP3>ij<0do:^0=Sa
[`3Jkjh0MhY:0;G<R03HkJX0fn2P0?Sj^`1MFb00HE`R038Y003FkJL0g_Vb0<WTW@3@gi`0WjAT09RD
E`3De9H0lONg0<GAS`2>VEL0e]bL0=_ZY`3JkZT0bmnJ082DC`15FA@0eNVT0<WMV03JkZT0e>RS0=7U
X039fYH0cn2L0=W]Z03AiZ40d>ZS0;OARP33gIH0eNnX0<OKUP39f9D0gNRV0<kDUP2IV5l000/006Ah
?@3Rg:`0^Xm]0>;P/038fJ<0f>F]0=7PY`3<dIT0Si1F05YJ7P1HF1X0Z:Y[0=gSX`3RkJ/0f>VU0=;W
XP37hY/0aN>K0<[/XP3>kZD0103=iid06@3<j9d0b^JK0<g/X034i9P0c^jR0<OWV`33iYH0b_:L0<;Y
UP3=lj00bNnJ0<?YUP37jYP0cO2L0<GWT`33i9<0anRG0<_WVP3KjZT0gNb[09>SHP1=GQX0HgLb0<cP
V@3Pm:d00P3KlJP0<`3Fk:<0T:IM0=?YX@34fY40amnC0=K^Y03:iJ80_m^Q0?7og@3`oo<0l?oo0>ko
o`3ToOl0iOo_0=Gde00_BQd0F7A30>3kd036h[`0d^g:0:c5WP2baIP0gNFY0=GTX@2hhI<0e_f^0<[]
Z`30hj<0_^6M0;OGY@2_e:40Qjen04EZB02`fK/0RK>;0<;]Z02hhI/0c_BY0;oVU`39jiL0`^:?0=3[
VP3=iIL0cN>J08RLE@1RMS40e^b/0<[PX03KlK00c>FS0<cXWP020<[XWP80bNVN08D0b>ZN0<WYWP39
jIh0b^RN0<cXWP3@iYd0i>bS09^OI01EG2P0nOoO0?Ooh@3^omP0d^^b0=7YZ`39gIP0f>VU0<oIVP1T
I380BdPM06AR>@1AD2@0IfXe0=KJW`3Rj:00f^2F0>GXX`3Be9<0EUTP03<l1@3Cgjl0E60b049=8P3X
mk80/Kn400L=0@3GhKh0l_g50<SCV@3;gYh0c^jU0<?YW01JMc@0S:9R0=;OZP3Ni[<0RY9O09VVL03S
nKT0c>ZT0<SXW`2ogYP0e_F_0=Ka[02@ZFL0fnf_0=W[[`3?gZL0c]bW0<kLZ`3>gZd0cMf/0=WUc`3Y
lN@0o_od0?oom03koo@0MhAc05Y_H01FK600TZJM00D=3`3Zjo00m?oo09j/[03ij>00oo_Z0?ooeP3h
ol/0`NNL0<kbZ037iZ00b]VN0>;/]`3JhZH0f=jP09FNG`3RkJ/0bNBM0;kTV@34lj<0[Mj=0<gfZ03;
fi@0jnj[0>7_Y039fI00emZS0=kK[P3oo^<0`[:K0:bMR03oon<0mOWD0=od_02nfi/0d>nQ0;KCP`35
giD0eNbV00LN003:gYl0d^JY0<KLWP2neiH0dNbW0<WWX@39hZ00a]bK0<7HU03Smk80PIE>0<[KU03K
kJ<0fNjS0=_aZ033fi40b^BJ0=OSX@3;e9<0WZAT04]A4@1RJ2P0k?:b00/0oooo000:0?ooo`0<0<?K
S@1>IAd0UZ]X0=k/^@3Ul<H0o_oZ0?kol@3ko_<0o?om0?Woo@3lool0ooom0P3oo_d0103oood0ooko
0?ooo`3oool30?koo`0K0?ooo`3oood0o_[i0?ono`3ooOl0n??i0?omo`3imO@0oooh0?ool`3oonl0
ZZVE0:nYW@1hD540RFMU0?Gom03/n^T0oOK^0<[2_`3hood0n_[j0?oio`3olo`0oogl03@e<00i>SD0
oOki0080oook00l0nOSd0?chm@3ln?D0n??`0?ooo@3eno/0o_oo0?omo`3on?d0ooco0?Wkn03go_L0
moof0?Som03konl00`3lonl0<@3koo<0nOod0?WonP3eo_d0nOoo0>KchP3Nk=80?4hN03A85`1_QEh0
F6Y409nZP019ERX000X00;gIWP37ijP0`^JP0<WZY@3PnKD0PYUC0:6hLP3?iZ00_MN=0<gYW03Mo:`0
]MJ50<SYV03CmZH0a>VK0<GYW`35iI`0bmnH06en=`39fHh0c=bA0=GTX@3:f9/0WJme0:JjO`2fc8/0
Y;mb09N_H`2L[6/0V:]Y0=;UY@3RmK<0d>>S0:blO@2?WEl00P37eIL0B@3Pl;40d>NS0=?_XP35d8/0
jnV/0=kOX`3BjjX0do6a0=GWZ`3NjJl0[;Mm096SI@0]@000QX];03@i003ShJH0fmJL08n9C`37iId0
am^F0=;QWP0X;P00CULF0<C@SP3Dhj00bmZG09nXI`2JX600e=fL0<SGU037fiH0Sj=N0:k2O@3BiZ40
e^ZU0<oSWP1hS4L0=DT406]o>P3GjjH0f^jY0<OLU`3Rmk80h_Vc03aC3@3Ek:H0c^FO0=GZY@3Dj:<0
cN6L0>Gd/`3HgZ80RI]O06=h?@1:@Q<0?a4007Qa@`1_O4L0B5<K02Dd001>Eah0B4hB0:JZK@3LhJ40
gN>S0<OCT@3JjJH0cN:M0<[TW@36iYd0a^RN0<S/XP3;kJ401@3@iYd0C@3:h9L0dn^Q0<cTVP3Hl:H0
c^JL0<STU`34jiP0`NRE0<O]VP32j9D0_>:?0=3cX@36iiH0d?6P0<WZV@3=k9`0d_6S0=?ZY030eI00
gNjZ0;C5P@1eQ440Tj9M0=[YY03Hk:D0d^RP0<KPU`39h9P0U:QQ0=S/Y030f8X0d>^L0<CRV039j:D0
e?>j0<WWb`2D/j@0FgQn08JY[@2JbkP0bOOK05N0EP006`00OjN2076MO037l]H0KIEc02Q87`3@i:L0
c^NU0:G@R`2RcHD0W<F;0<O`^02ljJP0]=^^0=SocP32jK`0[m:d072BN@10I400ao2^0<7ZYP32j9l0
`>JI0<[]V`3BlYl0`]n=0;oJR`3Ejj<0_M>;08BIE028WUd0]lf=0;kDT`38gYd0c>RN0080b^RN0P38
jYh0Q@36jih0b>ZN0<SZWP39jIh0b^RN0=3VW@3NiIl0dMFJ059K9P3aomD0mooM0?Cog035gj80_mRG
0>7a/037di40E5TO08n?G@3Yj[h0gn2d0=SK[P3GgjH0f^>T0=oYX03Hh9D0gN:P0?3d^@2k_H`0M7Y<
02H^1`1jPEl0Yjj=0=GSY@3Ul[X000@00=7M]@3GijT0OHe>0=kc/P3CljX0`>:H07RAC`3@i:D0eN2X
0=CMZ02CX6X0g>^b0=_d/`3Dkj`0cnfW0=?cZP3;jj80b^FP0:S1O`3@i:D0_]2B0=?SY03Kjj`0e^RZ
0=W[[`3AhjL0m_oH0?Woh@3noo40nOoc0?OonP15Ed/0k?of0>kon028X9<0EEeP0?[ho`3gool0nOoo
0<6/Y`1mHUL0g]Ze0<SDY02geiP0b^J[0=S`]P3jomH0o_oJ0=GJX03Jh:80`ln?0=?WXP2mgiD0e?fa
0<7/W@38kZ40eOFZ0761>P2FWET0RYY?09f]I01GGB40j^Rg0=?9Y@2o/Y00Uha/0>7R^P3Hh[00bnFV
0=on^P38jIX0gOb/0<_VW`26WET0]/b<0<GIWP35f:00Z[j309J/K03>jJ80_MRA0<_RWP3Jkj`0c>6N
065h<02fcX@0e>ZQ0<OMTP3Pm:`0^Lf60=7UX03EiZ80VJAR07En?@18DA00PX]:0;:kNP3:di802`3o
ool000X0oooo00`0e?2S0=K`Y`36gIT0]LJ?0=CP[P3WklP0k??A0>cfe03konX0kocP0>kjhP3nooP3
0?ooo@<0oooo00D0o_oo0?coo`3lool0o_oo0?Ofm0020?ono`80oogo0:D0f]KE0:BQVP3RhLl0m_KN
0?ooi03clm40oocM0<jYUP20HD`0LHMP07R<I`1gME`0V9J108REQ02:Rh<0S7f008UmO`27QX804aD@
018D3`2TYJ00X9nK09nKV02=RHH0RXJ307mjM`1]J6D0OWei06ehM02g^k`0ooko0?gbnP3onol0oogo
0?ono`3kool0o?oo0?ooo`3ooOh0oooo0?coo`3eool0l_oo0?3oo`2AZK<0E6]c09>VY03]nnh0d]fo
0=WP_`3RhLD0i>720:n]QP1EF2/0?T/F06Z<C`1aWEh0_?:h0;C[]034n<P0/MfZ0<3MV`2mfYL0?eTB
0768@03EjYl0cn6G0<cNTP3?g9@0a]>=0<CAS03=g9L0dnVQ0=;VWP3FjIX0ioZ[09FYHP2_`X80f>fb
0=K^/03Hlk00/mB50<[TVP3=dYP0h>ja07B>C@2_c8X0cN6R0=7OX@3CfI/0/kam07R7AP1jV500UKY]
0<OUV`3Efi/0k>2/0=_HX`3Il;P0eO2i0>K/_P3oomH0VYIY0<kDY03Qm;`0b>bT0=Cc[@2D[fX0DfhW
0=7XXP3DfIT0RXI90:>QI03JjJH0c^bT0<CVW038hi`0eN6O0:2VIP37di40cnfU0=C[Y@1BIb80g_>^
0<3ET03Om:l0dNJQ06Ik=P3=hYd0]/^60>Sm^03:hI/0bnFN0=[d[@3NmJl0RimJ0<?GTP35fI@0d>FP
0<SSW030gYH0a>JL0=?eZ`3CjZ@0^]VC0<_ZY03UgZP0[GeG0;ZcO`3JiJ/0dn>T0=K_Z`32g9D0cnJP
0=WcZP31fi80d>bR0<KRV032gY@0aN>I0<CTV@35iIX0anNL0<W[W`3:jYh00`3<j9/20<gXV`1@0=;Z
WP3@j9`0f_2U0=S^X`3PmZ/0b^2G0=OaZP3=ij00aMbF0<ONV03:giX0c>2K0=O[YP3?hih0cMjJ0=GV
XP3Aj:00^N:C0;gOTP3<hYX0bMRC0>Sa[P0/<@00AT`<0>Si]@3BjJD0`nBM0=?b[03;g9P0Z;Uc0<kV
W03GlJL0co2Y0;cQW02khZ<0NJEd04mlD@3Qoo00__CL08cCc@1h^jX0IYmn039ZA@2^jLd0/o7L05nM
SP1MV88001d00;WOYP36jK40JiUb0;?U/P1bZ8@0>G5:0;?a/P26_YT0^^Zh08RbP0005@00?eHj05A/
B02mhjP0`^R[0;oTWP3=lJL0`nJF0<CUU03Bkil0dNfP0;kHT@3<iJ40`]VE0<oVXP3>hj00PIIC08fR
G`3=iid0c>RM0<WYW@36jid30<G/W@1<0<K[W@38jYd0bNVM0<oVWP3cnKT0g>6Y04eG8P34f:<0i?g4
0<KRY@3;iYl0b=nG0<G@SP22QT/0hNB[0=?OW`3Rmk@0amfL0<WRX033gYL0b^VM0<GRTP2ofhh0bMnQ
0<oQ[`3MilD0e=Rm0?Sii`3noo80oOob0>3]^03@gZ/000H0082BHP2F[FL0bnFL0<[SW`3BjjL0bN2L
0>?c/P3>fYX0U:1R0<CBU03Yokl0mOo?0=3ZZ`3AjJ/0_]JJ0<[ZW`3`olD0_=ZB0=?^Z`2X_G`0/LB2
09Z[I@38fI80f>bW0=ob/035fIX0gNRV0=SQX038dZ00j_W@0>WojP0XBcD0L9V;07jRV02ng=@0LWQf
02DQ803onol0ooco0?Kkm@3fo?80noSY08f6M080oooZ03D0o_o/0?ook@3oo^/0lo[60>;a/03>jJ@0
_^2F0=CdZ`34giP0d^JO0;2kM`3`nkL0]<b20=gl/03@kj40a^:G0=c]Y`3Ym;80JfXa08V7CP1_K3D0
cm>H0=;LW@39h9X0c>ZP06F5>P0S@`00a]nN0=?X[@35f:00d>2_06=c@P1mSUL0f>b_0=C^Y@3AkJ80
b]^G06]j>@1ZOST0e_:X0;gLT03=l:00aNFI0<gTWP3Ik:X0/kQn096AF`2g`H80bmZG0=GTX@3Ci:00
bmnJ0=;WXP0;0?ooo`002P3oool03038iYh0a]nK0=W_[`2CY6d0Tim]0=CM/P3IhKP0g>No0>okd`3Q
l<L0h>k=0?kom0<0ooom00@0oooo0?koo`3nool0o_oo0P3lool00`3nool0ooko0?omo`020?omo`0E
0>OQi@3im?40l>_U0?ook03Lfkl0c<bZ0>3Q^@3Mfk@0FcPJ0<jaT@3EkK/0c>:c0=gM^`3oon<0n?o_
0>c^h03onoX0ooCb0?oonP0L7aP0M7M`0080oooj00d0jNKQ0?_hl`3oo_X0ookj0?omnP3ooo/0k?Oa
0?coo`3oo_l0oo[o0?ogo`3mm_h0noSo0080no_o0800oo_o0?omo`3jnOl0o?oo0>ono`3Yo_l0Xkk5
0=Cbo@3Yool0lOoo0>kmmP3coN@0oooV09:4JP2IRfh0^[>90?ooe03Pj[D0anj_0<Kf^01m_8D0;F`m
05RHL`2il<H0eoNf0;cKV038hId0cnBO0;?0N01`O3@0GVDO09nRG@2ZZfL0O7/j08jCD@3;hYX0aM^B
0<oTU@36fh`0cn>L0<GHV039gZ<0cNFW0<_XY@39jY/0e_FY0=OVZ`3:f9d0fnB[0:N`M`3;fid0d^FU
0;gFTP3WokX0e_2Y0:>iL@1gTDP0O9Y@09^QH`2MSeh0X9YX08>GI022VVP0oooJ0?oof@2m/HT0hnBh
0<?AW035jJ<0`N2J0<7LU@3<ij00dNRP09mgAP3Abhl0g^ZX0<oeZP2/d8H0aMVD0?Co_P15D0h0dNJQ
0=Oe[@32iY`0dNbU0=C[Y@35g9H0g_F_0<[QV`31f980VK1Z0=3WX@3Aj:80eNbV0=Wc[03:iIh0`=ZC
0:g4OP3PlJd0k_fj0=g^ZP3=hYd0e?:Z0=Oi[`35kZ80_>FG0<OUV`2lhYD0b^nR0>COY@2_PUP0fM:K
0=KRY03=hYd0bNNM0<OWV`3:jYh0]=V;0=Gl[@33j9X0bo2R0=3bY@3?lJ@0c^jR0<c[W`3:jId0cNVN
0<_[W`<0aNbK0P36ji/0D@38jIX0`N:C0=OfZ031h980g?R[0<;LTP38fi/0[Ken09n]K`2]^gd0^LF7
0:>]L02Z]7L0YZib09fUJ@2OYFT0c=bK0;OWT`32k9X0cN>J0<oLUP3SjZL0cLn@071e=@3<fiX0eN^Z
0<;VX031hY/0e^NS0<SIU@39h9`0`mjK0<KYY`3Eo;/0]=bM0<Kf_02ej:l0/^Vb09OAZ@1ASY40EXf7
04A`E`0UD3D0a??Q0<KjkP0OE4h0V/Zn04=[D@3;hk<0c>Jg07BRR01bYX00MJnF04Z:J02Tj:/0PKjL
0;?U/01cWVP000d00;G8Z02T^I00]mZR0<c_]@2nhId0bnnW0;kQT@3>kih0b>NI0<?RU03Ak:D0cnZU
0<gVXP3?iZ00d>FP0=3TW`2V^WD0cNNM0<cXW@39jId0a^^M0<G/W@020<?/W@230<G/W@38jYd0bNVM
0<oVWP3@eYP0e=VQ05AN:@3Cj;00dN^^0;kKV@3>jZ00g?:Y06Yc<P1oP4H0f=^R0<WOU03@kj40_]n@
0=;gZ@37kYd0`^bH0<K^V03BnJX0`MjT0>;lc@3Zn]d0o_o]0?oomP3oooP0o_oh0=?O[@1YMdH0KgaX
0:c0S@3?jj00/ln20=;/Y@39h9`0fNb/0:ZfMP2>V5T0i_:b0=_ZZ@3>ijD0c>JU0=C^[`3Fk[80aMRP
0<SWV`2^dGl0bnVQ0>7l^@3EjZT0b=^I09>TGP2AXU/0HgHd0763A@1TN3d0cMJE09jUH@28Ue80/lR5
0<GY^`29/Y80S[Rd08>Y[014HFD0^L2h05mLB`2_YJ@0l^c`0?_oo`3hoo/0j_;W0?cnl`2HRH@0NfIS
0;6LV@3bin40o?W`0?WodP3BjJD0_n>K0=7g[037hY/0f>VU09fRH03KeiP0gMnN0=_j[P2hiI@0`^^L
0<k`X`39hIL0cMbG0=[LV`2d/g<0ZZUY0<C9Q`2IXeh0TjMO09ZbJ034hYX0`^6K0>3h^P35fZ40j?[6
0009000K:000^lbE0>_o`P2dcXD0fOFX07N6@`3FhZ80eNJR0<o[X@38j9`0c_FV0<GZW@3Pn[<0UjMX
03hn2P1bKSh0e^:T0=S/Y`3Bij80g?6/0=[aZ`3;iYl02`3oool000X0oooo0180bNFH0=7/W`3;hiL0
eNVR0;o@S02?Weh0fNb/0=O/Z`35gY`0dNbY0=kg_@3_o]l0o?oh0?con`3moOl0ooko0?gin03oo_/2
0?oonP2R0?3_j`3kmoH0f]7D0;Rc/03:aKl0l_CO0?oojP36dJT0i>o40=;N[03Ii[00M8590:jkP`3D
hJ/0ckR?0;^WPP3<iK/0b]ji0?omjP3ooo40moof0?conP3oo_d0oocm0?oin`0_9BH0KfIW0?kjn@3o
o?d0a;k20?omo`3ln_l0o?oo0?Ooo`3aool0mOoo0?Smo`3hool0jooo0?Ooo`3oo_l0n_Wn0?3hn`3o
oOl0m?oo0>GooP3Qooh0h?ok04UUIP2je]L0go_l0>ConP3]ood0m?of0?Wom03/j=`0k>;F01/8100S
3QD0=2TE01XD000f<b00<CTT06QeF@38gK@0dN?=0<kQ``3:iKX0Y=:B08RdM`39l;T0_NB]0<CW[@3C
mkT0[MBC0<C]Z`2Ydi@0Ag@m08JgO`22^GH0V<f906ZCC`3?lZh0^mJA0=;YY@2T^740PiM?08JLD@3Q
nZL0bN2@0<oJU@3WlJ`0gNJU0=7KWP1gRDd0Iga10<GSY@3;jj`0_=bM0<c/Z`39jJH0co6U0=7/Y@3H
kZd0cNJT0<k[Z`3;iJH0k_Vo0?gobP2CTU`0k>fd0=GOXP38kJ00d_BX0;gKT@3Dl:D0b^JK09Ac@03U
hjH0f>NT0<G^XP2ni9T0c^:M0=OSX@27T4l0cmjK0=K[YP2oiIP0_o6L0;W5O@3VijD0e>VT0;?LT03A
jZH0Z[Uf0:ZeL@3;hIP0`n:D0<k]W`3GkjD0h?J^08NME03@iYd0cN>K0<oYX03=jIh0bn^O0<W^X@39
l:40aNZL0<cXW@2gh980_^VJ0=KOWP2OOdh0f^2R0<cWXP3<j9h0b>ZN0<WYW@3:jId0b^VK103<j9/4
0<gXV`1J0<oWV`3=j9/0eO6V0<OSV03DkZ@0f_2W0:VmM@1aPS/0V:UR09BZH@3=hiX0RjEK07>9@@2L
Z6X0b]ZI0=3ZX@3:jId0aNRH0<K[W@32iiX0dNj^0<OOY@3=gJh0T:1a07Z>G@2dcYh0a>ni0;KS[03<
mkl0_]bV0=G/]P0W=000aMBI0<;GUP3Ejj<0f_2M0;_BQ039hi`0KXQ10=K_WP3@jID0f?6N0<3NWP33
ikT002<D008b8P2UeZL0^^>g05Z0E`0JA1h0AgYK06VIP`1bS840QYZA02De:P0G=b00EGaY07:KW`1S
SH`0QZj]000>1@1eXhT0CW]T0;WQ_034i;d0HGMC07MkF00k@a`0T[>60<3Q/P3Fl[l0_mZU0<oW[@3L
lKH0fo>e0<_SY@3?jJX0b^BU0<KTWP3<jIT0an>F0<_WW03=jIl0L7i10=;RX`3Bij@0eNnX0<gYW`3:
jId0b^VK0P3:jId0P@3<j9d0d>FP0=WSY`2d^H<0DULQ0=7EXP3Kh:X0f]nW09BNG`1gPd40c>2I0=W_
Y`3@jih0bnRF0<KWUP2nhI40_nBF0<_`XP34jIT0d?:U0<_YX@34f:D0mOoN0?_olP3oood0oOo`0=?N
_P3Ei;/0XKN806MnD03=jKP0anJR0<_[UP39jI@0bNFH0<[WU@2I]V80cNFK0<WNV`2oci40d>:T0>3f
]@2lei@0_=bI0<GXYP37jjd0eoJ`0;KBR03?iYh0a=ZB0=;RV@3BhYL0d>>D0=K[W02jehL0c^nP0=7c
YP3EjiP0e>RA0<WWS`3>hi@0BeTT0=3U_03YooT0l?oo0?Soo`3ono/0_K>Z0?oom03no_@0oook0?oo
o`3oo_l0noKl0?oho`3oo?l0nO3a0?Wll@3ioo@0h?jd0;GIO`2XcH00b>bV0=7^Z`3;iYl0cnNI0<cV
R`3FliL0a^Z@0<O_V@3?lZ80`N>G0;oTWP32gil0emNU05YD9020N4T0eN>U0<oYXP32i900d>bG0<_Y
X`3>jZd0g?>k0=KX]01UMT80lO_90?3jaP3Lijd0h>j`06Mm=@2kdhL0]NJ;0<OlX02mji<0a^NH0=K`
YP3FhZ00e=fN059K702AVe`0enNV0<SKV@3?kZ00_n2?0<[[W039j9X0b>NI0<KUV@0;0?ooo`002P3o
ool0AP38iID0cnZK0<[RU03JkZH0eNVQ0;_?R020UTh0cNBN0<WTW@3;jIl0do2`0=c^b03goo00nooi
0?gmo`3ooOl0oogm0?KakP3flN/0n_O`0?oonP3Je=@0XiZM0?onnP3ln^h0oooV0?Sof@3LkKL0]LN=
0=3RY01;GAl0`mFG0=o^/`3Hik00bK>>0<jjV@3=hkd0fn_>0?onl`3on_<0l_of0?coo@3ooOh0oOOi
0?oko`0/8R<0JVAT0?ooo`3no_l0SHR>0?kgoP3noOl0kOGh0?7oo`3Sn?T0hoGg0?Goo`3^o_h0h?Cb
0?Goo`3kool0mOgo0??no`3iool0l?oo0>goo`1EOGD07cln0?3oo`3]o_l20?Coo`030??on03Pi]P0
dm7500804P0006P0f/g70?oho`3lmN<0oo_U0?ool`3oooH0o_o^05]Q?`000`00e]^m0<kM/P3>mkd0
b?2k029<701DP4l0`O2i0:_MX03>ol40O[9b0:kQYP2dj;L0`_S60;Oa]02<`XH0c?Jg03QL7P3Gkk40
f>f/0=3TW@3Hk:@0EF/P0<3HRP3KlZ@0DedF02Ha003EhIl0i?:d0=SZ[P2<WV@000d00=;Z[P3Ajjh0
_=VI0<SWY031hIH0aNFL0<_ZY032hI/0a>6N0<[UXP26VET0G6X/0;W2P`3;dI<0fNFS0<3RU@2lg900
d>bQ0=WcZ@3CkJ<0WhiF0<o?T@3KiZ@0bn^R0<GUW03BjJ<0eNJR055M6`3Ghj40e^NS0=_m/@36o:H0
Yk5X08f:A`3Cij80`^bR0=G^ZP38e980HFPT0=[_Y03ImZH0]]F50<oUVP31eHd0VJmV0<_SV@3CkJ<0
bNFJ0<WXW03:jYh0`nFH0<O/WP36iYX0cNNM0<K_X@3:ljD0e=nM0:N9E`3GhJ80b^RR0<[XX036jih0
b^VM0<cXW@/0cNRK05P0_mN=0<SNU@3BiYh0@e<<09bYH`37dXd0hNjX0<;CS03JkZH0amnE0<gSV`3K
jZT0en^V0<[[W037kY/0_>RC0<7aW@2cgi00_N:O0<7NY00Y?a00a=>X09FPMP1PMdT001@005R?F00o
MSl0bo2l0<[U/P11CA/0/K^60=OVZ`3@i9l0aN6:0>Wo]@3?kJL0WKQc0;kGQ03Dji40dNR>0=Ob[@3>
kl008di70:kLc`3Gol@0^=^Q07bMKP20ZW`0goo]04YeF@3=flh0`lS10:F/Y@3Zoo/0E7aa0=ooo`3E
m_/0fOOg0<GTg`1JO6/0CG=J0;GG]03Bk<L0dn>n00`:000L8@0000l00<;R/`2/aI/0mOoQ0?KogP3h
omd0io_60<kV[03?jZL0c>ZT0<k/Y03;jJ40bnVS0<k[Z03;jZL0am:J0=SVZ@3Hj:T0dNRR0<SRV03;
ii`0b^VK0`3<j9d0B03@iJ00eN2T0:FZM01FFB@0j>Jc0>7NZ`3Mg:H0Ff4U082:B`3?iYh0bNFJ0=;c
XP3<k9T0d?6R0=3`Y03;kJ40_n6E0;cNT@2ng980an2L0=g]_03lon40n_c^0?kno`3kon`0_LbS0=c^
^P3<i;@0EFm00<7NYP3<jjD0aNJ?0<CRS03>j9h0`=b8051/5`37hiP0bNNQ0<?RW`3LnkP0_n2I0<[^
YP3Io[/0a^ZZ0;_QYP2egIL0c_J]0=Wk/@3Bl:H0cN>H0=;WVP2oe8D0cnJF0<o^WP2mgXl0`^FE0<7M
R@3>k9@0c?BN0=WaY`2IXg40c=Zf0>Som03ZooH0m?[h0?oio@3ono/0b/^m0?kolP3[j><0kNOW0?C]
m@80ooco03H0n_Si0?kon`3]mNH0n?oa0<o`X@3;l9<0bNVN0<g/Z@3>kJX0b^ZQ0=GdY03:kHl0bnj@
0;[NQ`30hYD0b>JL0<;RU`38l:T0`^6N0>?S/@2f[Wl0ThQJ0<CFV03@kjT0dONT0<WVU03?k:T0[l^>
0?7ocP1VND8011800<oIY@3AfjH0am:F09VWJ@3Fk:<0`m^?0<_oY02ajX/0^njB0<CSU@3>hY/0f]jQ
00H7003DfYh0g>JW0<GOV03;jIl0`nVF0=[oZ`37jYP0e?FT0<_ZVP3FlZD;0?ooo`002P3oool03`38
ji/0bnbM0<g/WP38giL0bN2H0=CYYP3<hIh0SJAP0<_TX03El:/0c^J/0=7Q_@3koo<0o?oh0?cjn`02
0?omo`2R0?oko@3oo_/0_[Vf0:>NV`3oo_d0oogo0?oonP3ooo<0h>S30=o]_02/_gl0Gg@a0<3ET03I
k:X0cN2P0<gLY@3Wl<D0eKFP0?OJb03Zn=l0nooa0?okn03onOT0moom0?gmo@3on_l0oogo0?ooo`09
4Q40FVIT0?Goo`3gool0o?oo0=7BeP1UJFX0VZBU0::f]02cbLH0OiRE051cK@0R>3H0[INT0<O:c`3M
noT0d>[Y0=cYk`1@LW<0RH^G0<>mb`3^n?l0j^ck08IhT@0o;DD0:aP^00X01@34]KX0nN[W0?oimP1M
?cl0mMkF0?3je@3OjlL0h>c60=[Y`P3Bh;l0kokQ0?SojP3gon`0loo]0=o^f@39f;/000P006n1F`35
iKh0b_370<3`_02fj:d0_^n^0=7e]`35hJL0_lbP0>7aa03AkK`0eNfm0>3b`P3Bh[40JGE3075mB`2?
XVX0enbc0<GOXP38j:T0dNj^0=ORZ03DgjD0WJQ`08bGG`3BgJ<0en:X0<[FUP3;fYL0f>FP0=;OU`3D
hIT0ZKA`0:>`J`2X^GD0OY=>0=[d[@3BjjL0f?>^0=Wc[03?iZ00f_6[0<3GS`3BjZ00e^bS04mP6@2Y
^G80fnRR0=CJVP1kOCh0SY1A0>Sa/03BhIh0c>NP0<3PU`3=kjD0L8M10:bmN@3<fiH0`N>F0>7aZP3E
fYP0VZIT0:_6P@3;iYl0_M:=0;k5P@2g`g/0c>6D0<?VU03El:<0gOF[09:/HP32g980b^BJ0<OSV03>
jYl0cnjR0;kMT@3;jil0cNVN0=kdZ`39jil0anbO0=KLW02[RET0f>6R0<cWXP3:j:00b>ZN0P3:jId0
0`39jY/0b>^K0<S[V`070<S[V`1H0<WZV`32fY00b^2G0=G[XP3Ci9d0f^^T0=;SW03;giL0d^ZP0<kX
WP38i9T0aN6F0<gSV`3;iI`0anbO0<7ZW02jiYL0]^BI0;[UW@1jWe`0bnV[0=;W[`2:W680bmnJ0<kY
Y02dgIT0aO:_0;gWZ036hJ`0g>jl03m86`24SEh0GVhm0=3Y/02afi<0_NNW0<Ob^P2fgjL0?5dF0<?R
TP3Cm9d0_^6A0<3YY@0@@aP0Tl>I07NIG02G/7L0e>^g0:[4U02beZX0f_GB0?SeiP3VfM40b;fk0?Ko
oP3aool0f^kU05][H@3dooD0mood0?Gok03`on@0mOoQ0<_J[`3bnLl0UXeR05mM;@3=j;40c>Jf0?Go
iP3bonD0`]:h0=CTa`3Bj;T0an6T0<W[U@36jH/0bNVF0=SZa03Qm/l0k?oK0>WofP3HiZT0fnj^0<_P
W@3<iY`0dNfP0<WXVP80bNZK0880bNVM0<[YW@3?iZ00`<n>08jFFP2^/gT0_;b606i^>025QDl0d]ZO
0>C`/P3:hI/0c>RN0<_[W`3?kZ80b^ZQ0<KUW`31hYd0`^>L0<CTV`3:j9h0dNZV0=OX]03Kj;d0mOgV
0>odk@1MJdP0DV@b0<?HW@34fjL0I7]=0<OOZ`3DkJ/0b>6@0<oXU`28VeT0b=VC0<oSW03Ookl0[MbF
0:c`Y`1d_780K[I]09CGTP2nkkP0anjo05AdB`1TY6L0M/5l0;Oj]@2dlJ`0`_2_0<G_[@38k:`0c>ja
0<c`/`3Dmkd0_>:Y0;OOX@2nkjd0PKUh0;cW[`1ONUL0WKjS031PE01;LVl0/<S:0?gko`3lool0aLVk
0<O8^03hmN`0n_Ga07A[KP060000/Zj]0?oonP3in_80o?oa0>ohh`39hZ40d>bR0<cVY`3<i:X0dNV]
0<kWYP3Gl:`0bnFN0<oXYP2jdZ00`=N]0<gUZ@3:j:00`>NF0<o^WP3Ig8l0LV/S09nHDP3@hI/0a^BN
0<oa]01JLcX0>58E09ZdM@3[olD0n?oA0<SJX03Ij:l0ho:g096QHP32eI<0_MR;0<3MS@3:i9X0fo>Y
0<kTW03Ql:l0/[ao05IN8`3Fh:@0dN6R0<GLV03@lZH0`^RK0<;YV03CnJH0`^FC0=C`X`3Dkj80[l=k
2`3oool000X0oooo01@0anbN0<OYW03?kj<0cNVO0<gWWP3DjjD0b^6M0=7XY03AjZP0f?6_0=7X/03D
i<00nooc0?comP3kn_P0oogo0?olo`3onol0ooco07UcL`80ookk08l0lno`0?oomP3am>40h>_00<kM
YP2AYV40S:=K0=K]Y`3<hJ00c>2S0>omc03jomd0jLFi0?oOe03hoo80mO__0?oin`3on?/0n?oo0?oo
o`3oo?l0oo_o0?Woo`015180Ig]i0=kbl03Kk^X0Z[>b08N;S02FVYT0hN_Z0?7oo`3]oo`0enGU0:K5
`01fT8d0^;Fn0;[9c021Vi`0Cf9V0<?:e027Y:P0k?Wo0?Cmo`21TXP0KgQc038Y:P1CAdT0@S@d08Ek
LP3oo>`0oooX0:BOPP2QTgH0oooM0=3Y/P3Gl;L0bn:d0=7Z`03IllH0l_oT0?;oj03Klm/0lOo_0>[o
k@3RmMl0Qi5^05ES@P2G[hl0QJ=o0<CX^P39k;H0]]RL0<WQY@33dY/0]K^;0<kDYP3>fZ`0R9AV08fD
J02QYg/0cmJZ0008000fB1H0aMbX0>7lb@35j;80a>6[0=kR/03?dj40b=2O05QR;P3DiJh0a=RK0<?N
V@38iY`0eOFY0;cOR`3Sok00cLn>0=;GU@2kaX80=D@00<_QV@34gYL0`^2H0<?QU`3;jIl0d_2V0=C`
YP3Kk:D0c=bE09BQF`2EX5/0i_2[0=GVXP1VK2`0Hf<U0<[8R`3WkJd0cN^S0<[`Y@35kZ80Q9mH09b]
J@3Mhj<0hoZb0=7UWP3[mkD0VjAU07R;B@3?kJD0eo6Z0=ONVP2QYf40fnVN0<g`W03;jY`0a=jD08VU
FP3:iY/0dNfR0=3/X@020=C`Y@0<0<[VV`3Al:@0e>jT0=?TW@39iid0`^:G0=OLW02cSel0f>6R0<cW
XP3:j:00b>ZN0P3:jId00`38jYd0a^^M0<K[W@070<K[W@1H0<SZW@3QnJl0c^BK09V_IP3>hYX0fNfU
0=gcZP3<i9X0dNfR0<_ZWP3AlJD0cNbP0=3[WP3?kZ80_nFJ0;_UV`2okJ@0eonm09c7PP2VbHL0anBT
0;36R01<HAh0dnbK0=WfYP39kZ40fOfe0<c/Z@3Ai:d0bMFS06eeAP2QZWd0@58R09biP`2ijZP0`_Bi
0;[Z^P2SdJ80:4l@06jBB03BmJ<0f_n[0<OaY@0OEAL05DL<03mM7`2fbI40d=nX07jCF`3=jKP0f^c4
0?g`g`3onO40nnKU0?Cfm@3hool0nook0>;Wh@3oooP0m_S[0?_ok`3ion`0m?oQ0??mfP3Bdk40XIAb
07]cCP2dbY/0mOoO0=OXaP3aon40c=fm0<KG/`3;i:d0anBR0<c`V@37k8d0bnfI0>?bb@3dom/0mOoM
0>;jbP3<g9d0a]VG0<kSWP3;ii`0c>^M0<SYV080b>^I0880b>^K0<WZV`3=iih0eNJR09BMGP3:d9@0
L7<j05EH8@2/[gP0io6e0<_IV`3JlJ/0dnnU0<k^X`33hiX0c^fY0<[YYP3<k:/0dO2/0<SWX@3AkjD0
`mbH0>7d_@33djH0n?oW0?Cok`002P00QYUR0=7WY`3?i[00J7i?0<SOZ`3AijH0cnBG08fRE@2[_Wh0
dNZV0<o^ZP2/g:80_OK306NbQ`14U6d0<h=N04bHLP2UhK/0]^g50;WW`P15PUP0DYEY09WH[@2km/X0
Vm2T09W<X@2`iKT0]^g307:/Q01f]8/0Sm2X0;gea02WhZ`0CI1J08g1T@2nh/H0NjFA03A]I01EPh40
Z<O:0?_oo`3bo_`0mo_]0=kOc`3el^T0ookh0=G@c@1kMGD0A40m08R8P02YZj00noo`0?cok`3IjkL0
cN:W0<_PZ03>hZd0b]nV0<gRY`37gId0c^BV0<[NZ@3`oml0iOCM0<?GXP2nfI@0_^>C0<o_VP3WjIH0
E4d00:JOD@3Xn[00_M^E09joRP003000[<B80=G^[@3Ejjd0fnnb0=CXZ`3CiJL0YkUk0:c1OP3KlZ`0
eo>V0=[gY`3Pk:X0d]RJ0<gCU`3DfYh0LWXo096LHP3;fI`0e>ZY0<OUW`39kj80_^VI0<[_W`37jYX0
`^>D0<OQU`3;hiT0O8e62`3oool000X0oooo0:L0c?>T0<?XVP37jI`0c>^O0<kZW`3>j9l0bn:L0=_b
[P33fIP0c>FS0<oT[03AhKd0noo_0?[ol@3lnoL0ooko0?oho`3klOT0oogo0<:l_P1dKf`0m_?/0?oo
n03XjmP0j_7B0<KDX@1PLS@0bN2H0=gd[03?iJD0i_W10=k`_03bo]P0m_cR0=fj]P3iemD0n?oh0??j
l`3on?h0ooWo0?Woo`3nool0oo[n0?ooo`3bo_h04BXV05]fL@2G/:`0^Lk90>_dl`3<d<l0o_oo0?_o
o`3]o_H0loom0?Soo`3HmO40j_oo0?Goo`3Tool0jooo0>koo`3ko_l0Y/7807B;T`0X>cl0X;NW0;W7
^P3oooH0ookf0?omm03mn^T0ooo/06]bD02=Tfd0loK90>;^_02khZ<0dOVc0<GW]@2mg[40a>Jd0=Oh
b@3Som`0aNG>0:K5Y@3Gmn00kOoc0=?T`03aon@000/0000C001QLd/0HgE5024b001UL3H0G6D/06Q_
>`0T:`009bd0030c1P1eN4/0bLbO0:V_P`2<UFX0D64d02Dk300D<000^n2]0=Kfa@2ndYl0gO6n0=3T
/`38gj/0Cf/a08j/L03Ook`0`^JN0;_QU02ji980_]f?0=oNWP3/kZd0e=fJ0>G`[01LL2P0QiiF0<o]
X`3:jYl0_n6E0<7QUP38i9X0c=bE0=_XXP3JiJ00[KMb0:F/J03DjjD0gnRW0=cLWP14@0<0RXa=0<7L
U@3DnZl0a_2T0=7/Y@3Gj:@0YjUZ0=3OW035g9P0eNRV09nUI`1>F1T0^mVA0<k/XP3GhIX0CDh809ZT
F`35jiH0`=nA0<[VV`2ieHX0Mi=80;kJS`3>jYl0bnNL0<OSV0020<_WW00:0<kVW03?g9H0eo>Y0<?Q
U`3GfIX0]Y9R0=[PXP3<ij80c>NP0<SZWP80b^VM00@0b>ZM0<K[W@35k9d0aNbM0P36jid20<G/W@80
a^^M05P0b>ZM0<;JT02aagh0@5H=0=oe[03:h9L0cnNM0<WSV@3>kJ40`n>G0<KXV`38jIX0aNBD0<OZ
VP33jj80b?>/0<Kc[P1:McH0LieK0<7TXP3=jZP0S:=O0<cRV@32gXL0anF?0;;AP`32gY@0dnbX0=_V
[P3Nik80f>2_096JJ`1LL3d0C6Xd06RLGP2AaY00P[F<09C4W03=mL00SK5a01m1002dehD0aNjO0<?g
[@38n[D0]]:E0>3_]03?gJ80RieQ0;gDW03gomH0oo_V0=Vm/P3Xc<T0noOf0?coo`3moOd0ooom0?on
n`3oo_X0oood0??jjP3bn^<0ooo/0?cjh`3Ib;@0a[bS0??oh@3aoml0n?oT0?Soh`3@hkD0c>>_0<WV
YP35i9h0anfJ0<CZT`3=kJ40i_?80>Whc@3Xo<T0goK00=7TXP2G[6L0b^6I0<OVV037j9L0c_6O0P38
jiT20<S[V`200<cXWP3PlJ/0TiiL0:6ZJ`2RYfd0jo2f0>7V[P38diL0bMVJ0=S_Z`34giP0a>BK0<SW
X@37iJD0`MnQ0;oNXP38ij@0b>NS0<o]X`34giP0Vk1e03=54`1IId@0D5i70>Cha`3Ikk40_=>?0>So
a`15FBP0eNNe0<WMWP3;gI<0SimF0=[Z[038gYh0cNZZ0<C[]02dh[4044XT05fMN`2alMH0[Nc?03]b
D`2jjl/0DWmN06>BL01[W7`09eHd04EcC`1FQ600IIA`0;kdd02/iL80AhYW0:ccd@1S[HX0/_390;;a
aP0?F2X0QKnG092jY00D@c40AXEl06JJUP2SbLX0mooo0?7onP3amnT0oooc0:bYX03=b<80nOCa0?on
n`2WY9l0MgM_07inM03gnn`0o_oa06IbC01NKT40IgM:06EeAP1PLCX0K815086CE@3Gj;80bm^^0>kj
hP3foo<0h_C40<gVY@30hYD0eO:P0>OXV01PF@/0W9A90=SXX@3:ij@09dLE096XOP3Cj:d0b^2O0=7W
YP3Ml[40bMjM04aR8@1@IRD0amjH0;oIT02nfXd0c>^K0=3DU`3NfJ40j>J]07Qk@P26Re40eN>V0=GZ
Z@2nfI80a>BI0<G/W@2ojIL0^=^;0=ko/030g940iOfc08nSF`2kbh@;0?ooo`002P3oool0]@2khI@0
b>nP0<K[V`3<kid0cNjM0<cYV@37i9@0f_:V09fcJ`3@iYh0dNFX0=;Q^03ionP0n_oY0?ool@3oooP0
oogo0?kho`3ooOl0ooko0?3]j01lOVT0MWeK0>Sda01cPT/0]/^60<cSV`37hIX0hOZi0>Kkd03eonH0
m?o^0:bh[P1lPg/0>Q/Q089WKP1^OW/0NXJ60;6W/028PHT0NH^;0:>][P2>TYD0KWIh07R8R00020D0
634]07B9Q01lS8T0RXZ:055=C01_IfD0OWYg07f2N`0X;bP0=TA400lj<@003`L09Ce1000U900DA4H0
JhbC086:V@1mYZX042ld05ieN`2gc/P0j?Wc0;Rj]@1XIf80=cHa07b1NP2b_;400AD00<GM^`3>i[@0
bNNc08_1Q`35oK@0Lj9f06nKM`22/Gd0`Nbg0;WT]`0oId`0_nfl07FQP010Kdl0c?g@0;cR_@1YMeh0
9BPC0?W^dP3LcZT0]JQk0<c=T@1gPD80TjaZ08RQG`3@gZ00enFW0:njP01RKCD0KGY507Z8E@2AYG@0
fo?30;cFY`3JmlT0_nNc03am>`0>C0d023l508>iO`0KBQ@0>F@_0<CY]@37j;<0Pj5[05=`=P1ZPTH0
?DH704iH6@3?g9L0dN6J0<cQUP3>hiP0dNNL0=S`Y039hiT0`M^B0=K]Y@36ei00b]ZC0=GRW03Kj:80
_/^5065b;P2lb8H0gnZX0=SQX02mb8H0J7`g09^bK036h9T0e^^V0<SIU@3Fgj00X:AY0<ORW`3@kJX0
VimR09RHFP3:iY`0b^ZO0<oLU02RXel0MW`d0<obX03;k9d0`N2D0<[YW@3DljL0`]jC09B`I@22WU<0
Mi5709VcJ@25WeD0RIeE09:MF027XEP0NiM=0>7OXP2bS5d0fmnR0<gVXP3=ij00bNVN0<[YW@3<j9d0
0P3:jId20<WYW@80b^VM0P39jId30<[YW@0g0:o7O@2V_W@0e^jT0<[TVP3=iid0cNbP0<k^XP2lgY40
b>ZM0<[_X@37k9`0`nVF0<[_X@2ki9h0aNn]0;_UYP33k;00^^:T0<SXY@36i9h0S:AH0<WQT`35iI00
dNbK0=KXWP3MjZD0d]^L079c>@2CUUd0Uj1W09:PI@34fYX0b^RX0;OWZ`2eiK40OZb806F@LP35ilH0
/<ZS05]c@`3=hj<0_MRE0;oUW03;lJP0b^NU0<_NWP2ncHX0KWlk0=7VY@3golP0h/f^0>o@_03Vb;h0
ookh0?[ln@020?olo`0P0?oko`3gkOD0oogo0?WmoP3iool0n?kj0?ooo@3klO00b/310?Smm`3joo80
j?G:0<cMYP3>iiH0an>>0<SYTP38jiT0b>bV0<;VYP3<jK<0lo[H0>;]a@3Ei[80e>V`0<cQW02L]6X0
b>:H0<3QTP3<kI`0`NB@0<K/U`36k9T20<K[W@0W0<[XWP3?iI`0]/F008fLE`3KijL0dmnQ0=[UZ@15
EAL0Cf<T045J5P0aC0L0dO2Z0=7`[@39ij/0aN:X08NTK0005P0001/005=a9`3>jZ00bnJS0=G]/@3G
kKh0i?[C0=Od]03BkZ@0dNjN0<SMXP1OLd80f>Rg0=3NX`2JYf40QiA?0<gHX03EhZ`0dMjV0=;LW`3B
fi`0eMZR0080o`0001`0B5Lh02Dn8@31g/80dO;E09>[Q`3Pm<l0U:R301/`2@3;i;`000d002M<8@1A
NU80F8QR0;[^b01VWWT0N[>B0:KV``0mR5l0Ok^G01e9<P2ei]40O/6_03]dI@2E_k40lOo^0?;ok`3l
oo<0ooof0P3oooP0>@3kn?<0_[fi0::QW@3ooo/0oooj0?Ofl@3oooX0o_oe0?kol`3Gg[l0b]F[0=;Q
YP3=gIh0a]JE0=SW[P3;ejL0YjfA069WD`28TfP0k?o80<gY[`3=hZX0i]j`0=31UP2QTfH0TYmY0319
3`2mg:00c^N]0=[]Z`38g9L0eNZU0=C[Y@1oVE80b>BJ0=C`YP3?jj00`=bA0=?^X@3=j9/0j^b]09B?
E@1>C0l0Z[=b0=g/Y`3FkZ@0bnNJ0<3OS`3ClZ80bNVF0=KcW`3Cjj40`]VA0<oUW@2BXed0g>fW0<WJ
U00;0?ooo`002P3oool0;@31iI/0a^^N0<CYV`38jiT0aNNC0<[WT`37i900cNJE04YP5@2>XeP0bmjN
0=7R]@3fon40mooQ0?Woi@3ooo40nOOj0?kko`3oo_l0ooom0?oomP3mon80h^jl04mR801nTdh0c>JL
0=7[X@3;iJ@0cNJ_0?CojP3eoo@0j?O`00031`0020L0J4eF02`E7`002@P0N8Z:0>OTk@0?3QH0/<W6
0:k1_`0/=SD0628S00041@020006101e05m_K0000`802P@600L0001fJ6P0HEEE00<0002^/jd0eoK`
00e;?00oM6X0o_ko0<K^l00lPgd0_OGd0>koo`16Qh40en_b0?Ojo`1RKfP0^L2h04M3>00n>2`02`@0
04Y;@`1>ETT000P00<oP_03Ai:d0`]fX0;C/_@2/i:D0`>o=000G0014LT@0_>Rc0;oZ_@36l]40/^>[
0<gnd@004`00]nnn0<Gbb@1NLUL0<CTQ03@]4024Ne@0H5XZ0=_QX@3FiJ80_=J?0=;]YP2ofI00bnFL
0<7FT@3AiZ<0BEdP04]O900E:@0000d000<K003<ik@0cnbf0<ga]02gfZ00`nRb0<;Y]032j;T0_nJi
04QbA01JQ5H0Q[630;kZ^@2oi[40cn>T09FZJ@2BZ600f^jV0<[OU03<hI@0JW`b0<?ER`3QlZ/0d>6K
0<_LUP1?Ha/0Sj=K0<WMU@3Dj:00d>BL0=cUY02LZ6H0gNjZ0=KZY@33ei80d=bJ04eH5P1AG1X0cmjK
0=?WXP3IjJP0V9aQ0<?NV`3FmK40WJ=U09JDE`36h9L0e_J[0=g^Y`3Gg9T0JFlY0;oPT@3GmZX0dO2T
0<k]X@3<jil0an>H0080c>RM0`3=iid0D03AiId0dn2J04aV7@12GQ@041000;6;G03NhZD0aMbH0=7[
Y039jIh0b^JK0<[TVP3>j9l0c>>K0<_UW03>j9l0cnJN0<gTW03Bk:<0cnVP0<[QV@3Il:P0cNBL09ng
K@31fi40dN^Q0<kZW`3<j9d0`^6E0<WYW@3Fn:/0^]b?0<c^X@34iYT0eOZZ0<3UV036kjT0Q[1`01]5
1P38l;@0a^b_0<c/Z@2edh/0e^jP0<kVV03?kZ80cNNN0=WUX`25STl0DUHK0?oob`3bm[/0g>RZ0=?S
XP3;hY`0c>NR0<?[[`31jKD0]mnm03EI?@2BZY80:SXP051N?@3@gJl0eNJ`0<_UYP31h9d0co2Y0=7X
Y03JjjL0cN6J0<_RWP3lold0k=Zf06=7;`2RR7L0oooc0?[om`3no_`0ooom0P3nn?P0AP3noo/0mooi
0<SHcP2FXiX0IW1X06i]J01`KFP0o?ge0?kol@3Njkl0d>:X0<SQT03CkiX0co2I0=7dXP32iZ00_n:R
0<OQ/@3noo40o?o]0<oM^@3@hkD0enfU08bTFP3;iI/0anRI0<c]W030hi40`^RE0<K[V`32iiT0_^>F
0=3^Y03@iYd0bmbE0=WZY03BhJ00b]ZK06em?P3<h:40d>FT0<;KU`2>ZF@0aNBN0<[YY@0J>0000Ah0
01Tf003Ckk@0b^NU0<[XWP3<j9d0c>NR0<cVY@3:iK00cn^k0<;QV`3?kYh0dNjL0=;W[01RMT<0enNf
0<kLX@2P[FL0Q95<0<[IWP37hYl0cNbX0<CNX@3FkKT40?l0001F096iX@2^g;P0`O;509G3WP36l]40
_>G501Y2802gg;/001400<7Va`2mi<T000h008fdW`2]e<40A7EG0:oY``0hOE00P;N?01m69`2fhlH0
038D04=iG`27[iD0enC60<GJ/`3loo40nO_`0?oomP3inNl0oooh0?oonP3Kg=L0Q8F00>g]j`3hm_L0
ooko0?omoP3ooo/0d]Rn0<OBZ02FYVL0BelJ000>003IjJX0a=6I0=SO]P3Ykld0F64d02Xj2@3;h[@0
f>S30?oli`3RcKX0[IR30=gX_P1nUf00cNjW0<[TV`3IjZ@0a=FA0=O]Y@1PMbl0c^RO0<GTV03ClZH0
c^ZO0=?_Y036gY@0enfT08fDD01QIR<0SIA@0=;TVP38gY<0c>VI0<c/V@3Dm:40c^^I0=G^V`38ghd0
e^ZR0=O[YP2<X5/0dN:N0=OXY03NlZd;0?ooo`002P3oool0303Km[l0cNV^0<KRY@3<jZ80bNRL0=;_
W`35hY00cnRG0<oTU`29WU<0e>RS0<oW[@80`mZR00<0h?330>Kac`3noo/00P3nool0T@3nooH0noo/
0<cJY`35fi00^=5m0=WeX@34hYP0]mBA0<WU]@3:i<40Sj>J0;g<d@3<f>H0[[K909:MX@2EOXP0onkg
0>3imP3Ml_<0g=cT09nRZ@2Wa/40O9FA0<7Dd03cool0nooo02`b<P1KI640m?Sg0?ooo`3omoX0ooWm
0?ognP3onO/0oock0?ooo@2if]<04T`n0<;gk@3dool0c?[j09SMf013NgX0jooo01mGCP3dool0mO[d
06=iDP2W_Hl0d>:^0<SLY`2abIL0/]F[0<O]a01kYW40R[9c0<CXT03>m:L0[=^i0<Cca`20YhX0KI9c
01Ll4`2dfJH0`NNf000X002^gih0Z]jP0:SJW`2af:40/=RT06^BIP0jH3L0aN^j0<CW[`30h:40g_>^
0=[YY03@ei@0dMjH0<G/V@33jIH0cNjO0<[ZWP39iI/0`MZF0<oUY036fY/0d^JW0<cNXP3GkJd0a^BN
0<[WY@3:hZP0a=RS06mkD`18Cbd05aX001dK10060@00L6UF08V>L032jJX0U;Qh0<[[Y03GmJd0a=Z?
0<SJSP2`_7@0TiiI0<O@S`2CW5/09S800<_SV@3JlZP0_m^@0>Co]@31h9@0inNY0=?TX03GlJX0anNN
0=K`Z@3GfIX0fmNJ0>;IWP3Vkjh0c^>N0;[HTP2MXFH0h?Je0;kMU`2eaX80Gf@T0=__Z03;iid0`n6I
0<kSWP3DiJ40SZ=N09:/H`33gi@0_]Z?0<kZW`3AkJ801@3<j9d0V03?iid0eNJO0<k^X`3>l:@0l_Ng
09YfAP3VjZd0`=NC07J=A`1^S480OiU?05ab:@1QMBh0dnBN0=[^Y`3@i9d0c]nI0=?TWP3Cij00UZYS
0:ZkM@2T]Fl0S:1I0<CNU03>j9h0c^ZO0<WXW03:jId0`^:F0<CTV03;jYh0f_V]0;_GS03BkZ@0aNBN
0=?b[P1iW5X0^MfM0<W][@38k:`0b>^Y0<g/YP2Q_gD0dNbM0=C^Y03:iZT0eNV^0=?GY01BDR00oooC
0<oDWP3Zlk`0d^BV0=;UX`3:fiD0d>2O0>oocP3Ai;L0m?o]0:jo[027SXH0i^SS0?oon03im^<0dM6g
09nZP033fZ@0CgPZ065m<`2hc8L0gO:_0<gWYP3Rm;X0m^S1069>;@1cHT@0k?OE0=cbb`2W^hX0`m>V
0:ZeRP2c_Y<0d^Fg0=C^_P2ifJP0d_;00<7M[@3Un<X0k_kA0=oU]`35c:00hNfo0<WIZP3`om40dnbc
0;kMVP36iYd0`>>C0<GVU@32g9/0o?ob0?WnjP3Ah;T0a]ZW0<7ET02EZf<0cNFK0=;aX`31hY<0b^fM
0<g_XP3Bm:P0`^>L0<KWX03Fm:h0a=jE0=;XX03<hYX0H7Lc01P^002/`X40cNJT0<WRWP3GlZ/0dNnU
0<_[W`3>l:H0a>BS0=Wg^@3Fm;P0c^RY0<_VX`3<j9d0b^VI0<WYW@38jZ00a^VW0<KW[P3<kZ40bN^D
0<OXS`3?j:L0Kh=>0<7AX03CiJT0c^2F09VZH`28UUT0d]jP09VUH`2T`6`0_>28103o0000EP34iKX0
bNJf0<3IXP2li:H0_^Z]09[6Q`39m[D0`N^Y0<G_[@34kZh0]N6R07>OI00oJS80bOBn0;3HY02ojkH0
/>R[0;oZ/P3:ikL0Rjn100]34P0HB1P000l00:NaO03BhZ@0cmVg0?Kni`3_mml0nooZ0=cVc@3honX0
o?oc0?comP3Qi=d0aLG70=kKhP3:b<d0[Jf[0<cE]P3Hj;T0f_6Y0<_SU`30f8X0dnVQ0=GXYP2nbHd0
Qi5E09nVL036dZ00NX]Y0?3lj03on?l0j/kJ0=k3bP3fo>80j_oB0<;UU@3SojH0dn>L0=CSX01_QCd0
an6H0=OcZ030hI80b^VK0<oYW`2kdHP0cm^I05YU8`2U^Vl0_MR70=[eY033hi00c>jH0<;UT@34ii<0
/m:40=kj[@2ne8`0enbW09V/JP25VUL0ZKal0<cOW@3AiZ<0dnZV2`3oool000X0oooo02@0m_oR0=O]
_`3;hK00c^R[0<_VX`3;iid0c>JL0<gUV`3MlJX0SYmI0<cOW@3Bk:d0d^n]0<gXY@3>hJX0d=nd0?[o
m@3iood0noom0?_ol`3konX0eNN[0=G^W@3>jYD0cnbJ0<k]ZP31gZ@0//bY08ZRRP2?XZ00kO_o09>P
/01CG6d0SYRJ09AiPP3okOL20?3oo`1k0?kmo`3Dem`0RJRR07fCT03dool0l?ch0?7clP0d=S<0EeaH
0?koo@3fl_40oo[m0?oho03ok_00ooWk0?ohn@3emO<0l?oo05j9PP3Oool0i_oo0=_oo`1RVYT0@6a]
0?3oo`1BMG40cMcI0>WgjP2jfZ/0d_2l0<KYZ@3>mK@0^NFX08[0S`2jm<@0Ij1Y07:WH`3@oJ80`NbJ
08fgT`2Na9d0MIMd03eM>0003@00i?o@0<WZ]@0XCaH0`>f/0;c]Z`1bWeh0bnZ^08f`N02E`i80M:Ue
0;cc^P2cijL0_njZ0<?NU`39fY@0dm:B0>CYY`3JoJ/0_N2@0<g]X@36iIT0b>:I0=;/Y@36fiP0h?Fb
0<KIU`3Vm[L0c^6O0=O^YP3Kl:/0c=^P0=KS[@2[/HD0Vi]g0:RQQ02<PVL0BCdU044a6P0i>1T0GXQ9
07bTI@3:kJT0b>NQ0<oUW03DiY`0e^>K0=[UX01PJBX0I6d^08fIF@3KlJP0^]:80=KbY`34hiL0f?R/
0=cRXP3IkJP0`mfF0=;`Z034fiD0h>:S0=kJW@3/hjP0ZK9a0<WNV@3GmJd0^[j10=c_[@3=j:40i?^c
09BQG03;fYD0d>JN0;cPV03BlJd0a=nL0=CTY@2N]Fd0eNnU0080bnNL00<0cNVN0<cXW@3<j9d00P3<
j9d0603:jId0c>RM0=7WWP2kh9<0_N>F0<kDU02mWF`0e]bN0<oXY034fiD0ZlUo06Z2>00^A0009c/0
0;K:P`3Dj:40d^JO0=O[Y02FZV<0_=290::fK`2hc8D0`mN@0<?IT@80d>bQ0P3;jYh0N`3;jil0b>RL
0=?bYP35hIH0aMnE0<kVW03?iYh0bnFV0;SEU@2>[6`0/]:A0<ob/035j:@0b>VT0<WWW`2A[F<0b>>F
0<o[X@3DkK<0cn2Y0:jbP01]K3h0oooF0<oGYP3dold0d>F/0=7UZ03DhZD0fnB]09VMN02[/Y00WJVC
08NBPP3nood0ooko0?7[k@3oo_@0ooo_051G=@1MLD00@f`M00XV003Qm;80cn>T0<kVZP3Pk[T0oooH
04Le3`0@0P00a=FX0<k[]@34hIh0d^^Y0<_NWP3:gId0an6P0<_ZY`2kh9/0cOF_0;gPW036h:40cN6R
0>?/[@3GhJD0KWY:05i^@@3Rml`0g_G90;GBV03Mo;T0eoNT0<?TS@3DkZL0o_oa0?cok03Yn/d0e^^b
0=KWX`2CYf80aM^C0<cXW@39j9`0`^:F0=7cY`3;kJ<0anRS0<[YYP3;j:D0f_B]0=W`Z03>j:40XKYf
06Io?@3Dkj`0an:M0<_VW`3<jZ00cnjR0=7bX`30hYD0dO:]0;_KVP2lf9/0dN^Z0<SSWP3<j9/0b^ZG
0<S[V`36jid0aNZU0<GYZ`3<lYl0a>R>0<OZSP3;i:<0LXIA0<kP[P3DiZP0dNNL0:[0M@2:WEd0VZAW
0:2[I`020?l0000O0;;_T03o0000o`000<?ea02[biX0g?C00<oQY`3Ij:d0enJ[0=;UY@37g9T0a]fI
0<?MUP2lfY@0d>n[09boN`0D>@00c?2`0<_]/@3;lK@0[n:M0<[a/03Ck;<0c>Zd05:9D01FPd`0IHI?
08NAE02lc8D0c]^_0?;nfP020?Woh@0i0<_K]03Gil<0nOo/0>cehP3cnN/0oooo0>o^l`3[j^P0j^cQ
0=WU_`3:gJH0e_2V0<cXV`39iIP0dNRT0<gRX@3Mjjd0g>JW0828C@2T[WT0b=Rd0?KojP3on?d0mmWS
0:Z<U03oon`0dNJk0<[/W`2mfH@0cMbG0=_ZZ@1KL2/0d>ZQ0<;QU@3@lJ80b^VK0<_SV@3FjZ<0WJ=U
055B5P3Lm:P0c_2L0<;TT038jiL0c>nK0<[]V`38ji/0bNVP0<[YX`3CkJh0aMnR09^dL`2N]gD0dNZX
0<CJV@3=i:00c>>O00/0oooo000:0?ooo`2V0?koo@3jooD0m?o/0>Gfe03CiK/0c^F]0=?X[`3BiZ/0
c]fT0>3_^02DZ6/0bNRR0<OZUP34iY00cn^Q0=?[/@3conX0n?oh0??ol@3Pk]@0dnFk0<gWX03<j9/0
d>jT0=_j]`32gk40`=jl0<?Kb`3XooL0>Ti?0=KXk03_o_l0n?oo0?koo@3T_lH0ooCk0?Ooo`3hool0
ooKn0?olo`3aool0koki0?Woo`3hoOT0oooj0=cKeP3ooo/0o_ok0?OflP3aiNL0f/_>0?oin`3oo?l0
o_oo0?7emP3]l_H0n?oo0>koo`0lL6h0CW]n0:>o``3]ool0i^k`0?ono`000@0000X005emEP1PQ5@0
^^Z/0:WQXP2oolH0<h5G04JFL@00@aX0LJei0<KbY@37kJ00:dPB00LQ001OM3T0Sj=V0<SIX`2gb9@0
KH970=;aZ`3Bm;L0a_2X0;cUU`34hiL0b>bV0;g][`2ejjl0Pkmo0;gf/@2jkZH0`n6I0<kOV@2ETeP0
Y:9W05MS8`2Y]GD0bmZI0=_ZZ@2?Weh0Ohm>0:BhL`3;giX0hoB`06io>`3@giX0e]jE09ZQF`1`NCP0
UZ1Q0=ORYP3EhjP0fNR]0=7SY`3=hJ@0TZQX07jHF`0D>`H0[=:I0<?QX`3:ij@0WkI^0=_aZ03>hY/0
en^V0=kc/P3AijL0cnBS0=CQV`2Y^G80fo>Y0<CPU@2ifhh0f?J^0>Ck]@3?hih0cMJE05QN7P3Kh:00
b]2@0>Wb/@1>Ga/0YKUd0=[[Y`30aXH0gNZU0;C:P@3PokD0_mV?09fTH@3?fiT0a?:Z0;7TW`2dgYh0
g^>]0:JeLP38gYD0dn^Q0=C/XP38hYP0c>RM0<[YW@80bNVM0P38jYd06@39j9`0^NFF0;CST`3IiJ<0
SW900>ce]P39hYh0bn:L0<cXWP3Ejj80d>JM0=3WX@38hY/0e>jW0<kXX@3;iIh0b>:K0=oi/P34gYL0
an6J0<SRV`3<iYd0anJJ0<GTV038j9`00P39jId0N@35i9P0d>bQ0=W_YP2ibX<0VJIP08>?C`2]_hd0
]<JB08FMG`35h9d0c^VR0<k]X@3Em:H0c^fQ08ZVG039i9d0c^VT0<_QX@3Jj:d0W9i_0:>TN03Ffk80
enW10<kW_@38hKT0QYQb0:FYR03oonH0ooS_0?omm03loOD0o?oj0?gmo`3km_`0ooco0?onn`3ooo@0
iO?B0<_Q/P3?l:40enfU0<kGWP3NjkH0O8aO0=;K/01LCRT0HU0X0;JYO03Fk:`0_n2I0<K/U`3=k9`0
b^:D0<_RU036hi<0bnbM0<;/VP34kY`0c_FT0<GVU`2le8H0gnbM0=CQV@2mc940dnFa07>:GP21Vfh0
c>Nb0=C]/`32g9D0g?NZ0<3FV03koo@0nOo_0?Oog@3Pn;h0cMbK08bLF`3Yo;X0enjX0<WSW03>jJ80
bnZT0<KSX031gYh0a^:U0:>mP02F[fd063<00<WTW`2jei@0f_Nd0<KSX03?kJD0bnVO0<_ZVP3;jiP0
`^B@0=7dX02jg8l0`nFK0<o/ZP34gi`0dnjW0<[ZU`3:jYD0a^bG0<G/V`33jj80a^fZ0<[bW02oiXT0
c>nA0<GPW@2>YFd0b=bW0=;XY`3AkY`0bNVF0<KTWP3?jZD0103o0000F@33nLP064P`00<]6@0G=`h0
NIIN08RRF@1B?A00MU@_0:nBJ02oYg/0UXAB0:FHH`3WhZX0f]RO06=V;@30aH/0XZM_0<WNV@33hYH0
boJT0<_ZW03PmK00bNJS0<Gj]02jijH0fOVh0=?OU`29W4X0d>BO0<kSXP3NmK40aMnH0<oZY`3<iZL0
d^Rg0?Cog@3]n]`0o?od0?kon03nond0o?oT0=7VZ`3Mm[80_mnC0=Kh[030h9d0bNB_0=;Z^03?h:X0
fNJ^0=[PXP3Wl;40N8UC0=GN/`1C@B/0aJVK0>C:^`2FVg/0b]nf0<OT[03Omk/0g>N[0<kJW02J[fX0
cNNP0=7_Y@2if8X0dNfR0<_LUP3FhIl0HehW0<c0S034gYD0b^nO0<caX`3;kJ00b>ZN0<_/Y`31i:@0
]=^T0:38UP2njl00Z]Zb0;gYZP37kjT0]mbG0<gZY`37h9h0fnj/00/0oooo000:0?ooo`0f0?_io`3n
ool0o?ok0?7oj03Sm=@0i?O90>3d``3Fj;H0d^2]0=CR/@2Q]7`0/M>90<K]U036jY00b^VI0=C^[@3P
l=D0loob0?GolP3Pl=<0dNNi0=3/XP3Hm:X0bNJT0<GRZ00cDBd000/00<gWgP2S_;P0lOoo0>Wkn`3d
ool0nOoo0?KfkP3[`<L0onWa0>_dk`3`m_@0ooSo0?oko`3ZnOH0n?oo0?GjmP3ooo/0noK`0?oon03n
ooT0o_oj0;Nh/`2YX:40ooKg0?W`l`3ooOl0nOoo0P3hool0Q@3eool0amKM07F9TP3Xool0hooo0>go
o`3eo_/0iNKQ09F0N`3<_:d0bm^/0>3e^P3<lZL0cOfa0:kWX01c^HD0^_oB0:[T]035l[T0b^JA0=O_
V@3Jl:l0bM^Y0=SWXP3YmZh0a]6E08bIH`3Di:H0`]jC0<OVZ`30j:40c_RV0<O_V@37lZ<0]N:Q0<Kd
]P28]WP0_>JV0<W`[@1^RD80K80k0<kGV03Lh:D0blZD08F5C`3Uj:l0d]ZO09NSI@3@g9h0C5`K0;S8
Q`20U4l0QIUB09>YH02:ZET0Q:=E0<c[W`3No;80bNNM0<KTW034hiL0foZ^0;oNT03BlYl0cNfR08^]
N`2J^hH0eo>h0:O1P02cbX80d>RN0=O^YP3>j:40c>VW0<?QX@38hJ00@T`708jIE03CjJ00bN>I0=cl
/02hhYH0c>JO0=WXY@3elK@0k>R[09NPG`3LjjP0b=fH04UN6@2EZF@0b]FC0=[OW@3Bg9L0h_J^0:oF
Q@36iiP0d=FC03a51032m:d0/>bV0<Oh]`3oom80gNVY0<CHT039giH0eNfS0<SRV03<j9d0b^VM0<WY
W@38jYd0a^^M0<SZW@32i9L0^NZI0;c]W03Pkj`0GdDB0<gGV030fiH0gOB^0=;/X`3@i9`0c^BK0<cW
X03ClJT0dNnW0;gKT`2ogID0`n6I0<[XX03>k:@00P3ClJT0CP3<jZ00b>NK0<WXW03=kJ40bN^N0<[Z
WP35i9P0d>ZP08^OE`2gah00d]bG0>3ZZ`3Fi[T0IgM608RLG`3Mm;00cnVP0<OTU03Al:00bNRJ08FS
F@36i9h0bNBO0=CYYP3`o/00_Kn=09FFJP3Pikd0cN>m0;gI/`3^onT0amZn0>WXe03ooO40ooWm0?od
m03ooo/0o_om0?koo`3oo_l0ooco0?oon`3koo00iOKB0=G]^`2og8`0aMB?0>CY/`39dJ8000P001XN
001iJDD0VXMM0<RlS03PmK00_MnC0;_PTP3>k:80dNRP0=3VWP35hIL0cNfT0<G[X036kj<0_>2F0<o]
Y@3HkjL0cm^C0=SUW`3HjjT0dnVY08ZSJ@1fTUP0VK9i0<;KX@3AiZ/0enf_0<WJ[P80nOoo02l0moo]
0>;fd@3AgIl0SYaN0;W9R03GkZX0an2L0<ORW@2og9T0e>j]0<;LW`2ke9X0:T8805]e=03Dkj`0b>>P
0=Gb[`2ieY<0bnZV0<k^Y@3>kZ80bn^H0=7aW038jY@0a>RA0<c_W`38jYh0bnRU0<oZY@36h9L0b^ZE
0<[[U036k9L0aNbI0<?/X036kJX0c?BN0<3WRP3;kY00b^FR0:k7SP3Llkd0an2N0<;RS`3:k9P0a^FO
0=;/Z`060?l0001G0=CMbP0lB200Kgi708ZKE02U/gD0e^6U0<WHU`3@gih0fNZT0=3QVP2faWd0enNN
0=cYX`3VlJ`0Uj9N0=W^X`3?k9`0bOBK0<;OS@3RmZh0_]bD0:kSV`2nkJT0`nJR0=gYW`3Aii@0HWTY
08:JC037hY40do2N0<SWU`39j9`0cnV/0=CX]`3bom/0o?o_0?colP3lonH0c=V]0<;KV@3BkZ<0`^NI
0<7UW@3=kk80g_W<0?;oh@3hom`0kog:0>;XZ031bXL0f>^[0;2kP@0M2`00Melm0?o/c@1IGcT0dnRo
0=ojc@3Tn/`0d=^S0=GQX`39gYT0bN>L0<CRV03ClZH0d^jS0=3OVP3DgI`0W99M0?;R/@3Aj:80b>fP
0<OYW@37iih0cnjX0<SXZ@31hZT0BG=3025@900/I440H9]k09C8RP3<nkD0b?>/0<_[Z033gY/0Z[Yk
00/0oooo000:0?ooo`0V0?clo03oo_l0ooko0?_ko`3lool0mo_l0?[on@3loo<0j_CA0=kV_@3Fhjd0
_LbA0;[:R`3GijH0e^JU0>Cd]P3Dik00fNfj0=okb03Dl[`0co:h0<;VZ034h:H0cnRn05A]C`3Mmn`0
c>OR0>koo`3aool0mOoo0?Soo`3kool0ookm0?okn`3cg^<0oo?f0?Omo@3fooh20?ono`090?koo@3j
o?L0o_oj0?Ghk`3oo_80SHZ10;2_ZP3oo_l0n_Sk0080oogo08X0ooko0?ooo@3looP0nooj0?Koo`3P
ko@0GgQo0=koo`3Yool0gooo06:DR03Gl=/0N6mP0?[[f03dl/`0d^^J0<WTU@30i9`0_nRT0<;b]019
PT/0]>^d0<;Z[P3EkJl0hN6I0>3TV030h9@0a^JM0<o`X@36iIL0d>bR0<WSW03@iil0fNZS0:bkN00V
<@00d=fG0<oUW@3Bij80cN2P0=7SY@19Fad0[L2005EZ:@3:gi`0dNJS0<SOV`3Ek:P0dnZV0=;WXP2H
[6L0dNFP0=CSZ021T5T0HW4j0<gLX`3EijT0fnnW0=3XW039jIh0^]R@0<_QX03?hj@0c=jR0=KXZP3?
j:H0bnJO0<KXWP2gh940a>jR0<OZ/029Zfl0g?Zj06Z7A037hIP0bn>I09jfK01cSD@0SjYU0:2mNP3=
k:H0g?n_0;kOT03IljT0e^bS0=g^Z03;gI40N8A208:>D03Ni;@0a/fQ0=SU^@3Bh[<0f>Ve065/<P1P
JRd0g>>P0=GOVP1hPTH0`<ZE0=WV^03MjK/0g>2^096HI03Dj;D0a=^_0=?Wa03fon00o?oC0>Gd/@2<
VeP0RiYG07f<B@3Hij@0cMVG0=gYY`3:eY@0dmnM0<gIU`3DhI`0a^RL0;kTU`3AgI/0L5HS0=CSXP37
iZ00cnVR0<_WW@3Bhi`0en^S0<[ZWP36jih0a^^M0<CVV@36j9`0bNVN0<[YW@3<j9d20<gWWP0R0<oV
WP3?iZ80bNVP0<G[WP31kYd0`nfK0=KbY@21Ud`0^<R10=WXX`3>ij<0`>>O08:]M@2eai<0T:AU0=7[
Y038i9T0bNZI0<OZUP3BlJD0PiA>0=3a[035kJH0e?>`0=kb]@3dj<00?3@?0=KV_`3Ym]X0m?kV0?Wo
lP2e[ZH0oooj0?kon`80oogo0P3oood04`3oool0o_kn0?kon`3ion`0kOgF0=7[ZP3:jZ40b^VM0=7U
W@3FhZ80e>:T0=3TY@3HhjL0MF<a06QA7`2WTf00en:P0<oPW03FhZ000`3GhZ00A03FhZ00e^FR0=3T
W`3NlZd0`MF@05AX8`1?Ha`0`Mb?0<gXV`3<j9d0b>BI0<g/X03>k:80`n6G0<k/XP2ccXL0MI1904=K
7@1AHT00IWMC0=W[`@30djH0b<JO06]/@P0b=@X0OhMF07f7D`1bOdT0cn>X0=GY[02G/6l0Z/>10<WW
X@32i9X0cNnU0;gOU@37ii`0dO6V0<WWW@36iIT0`nBE0=;cXP3<ki/0aNBD0=O/W`3AhIX0fNVR0<CE
S`3=hIX0eNVQ0<[RUP37hiH0d?6R0<_/W@35jY`0`NRI0<G/V@2oiY<0bNjN0;[NV03;kZ`0anZX0<GY
X@3:kil0_^BA0<kcX`31hIP0b^FP1P3o0000EP2ldY80e_6/0<;PUP3Bhil0fO2Z0;gfY@2elj00b>RM
0=GTW`2HUeH0g^FR0<[PV03Llj/0RIeF0=_eZ`2lgHh0bNjN0<OXV@3<jil0bnZN0<OWW032g9D0h?B]
0=cVW`3HhY/0b>NI0;kST`3HmjL0X[ia0:6fJ`3;gI<0d>6K0<[KU`3CiZH0cN>U0<OOX@36hZL0e>fc
0<_QX@3FjjP0f^VV0=KUY03@fil0b=BR0=GS/P3gom/0iOS;0=?ZY03>iYP0e>ZQ0<SUU@3Lci/0?R40
04DV503CgkT0c>Nd0=[]_`3eonl0n?oa0?kok03Kek@0oooH0=KSZ`34kIl0`NRG0=SSWP2PX680c/^H
0<kEX@38i9X0bnZL0<c[W`3:iJ00cNJT0<OOX`1SN400_M6N0;_?WP2X^Hd0U:Ei09FdU01TQfL0HXAS
05moEP0A<0@0;4PH2`3oool000X0oooo00<0fmS?0?ono@3gl_H00P3oo?l08`3no_l0o_oo0?kon`3j
onP0k?KA0<cHYP3=f:00Lgi20;O3Q@34d900cmjM0=7VX`3Nmk<0bNVV0<OZZ02ggY/0doNj0=Wd_`1G
K4/0KH=/0;[Cc`1XP880l?oo0?7oo`3hood0noom0?koo@3oo?l0ooWm0?kbmP3oo_l0nOoo0?Kno`3l
ool0oooo0080oook00H0o_oh0?kom03gn^L0nocZ0?ool`3ooo/30?ono`0K0?ooo`3oood0o_oh0?ko
n03kool0jOKl0=7Zl@2cgNT0c^_i09O6`01DRGL0l?o_05A5<P3oon@0jO720=;`V031hHh0aNVS0<_c
]02bgZ<0DhI>0<Oh`03CmKP0cN6R0:JSH01?DP/0b^nQ0080`nRJ06X0^]nA0<[/W`3?kZ80an6G0=OW
X01=F1<0g>6N0;o6P`1>GA`0VjYY0<OCT`3KiJH0]L61079n?P3Ah9l0b]fK0=;WY03EkZX0b>>N0;WI
SP31giD0Z/Aj09bcJ`3AhjL0U:9]07R6D`3Kj[<0c]fR0<WMU@38gY<0b>>L0:2gL`29VE/0Tj5V08>>
EP2?W6@0bMfN0<7JV03:jJ<0ao2R0<7YX032iZP0/mFH0:G4P@2lfY@0fO>Z0=3XWP3=iI/0dnZR0<gW
X03Fkj/0]]B<0;3GQP3Am:@0c>:I0=7RV`2/]G80OH<k0=GNW`3XlKP0ino60>cfd@3PjlT0hng;0>O_
b02h_Xh0Mga60<_?TP3OjJX0emn/04E<8P3fnM`0fMbm0?GjdP2IWg<0j?370>Wbd`3Nj=00m?oZ0>Ce
`@3Okjh0dN6P0>7`[`2kbXT0Ig<c055K703Jhj@0jO:c0=OPX@3LiJ@0e]fJ0<GSV@3;kJ40c=RF08]d
@03?gih0b>VR0=7/Y@3DlZP0d^>L0<?GS`34hiL0co6T0<GWVP3:k9l0cNfQ0P3:jId30<cXW@0R0<gW
WP3?iZ80bNVP0<G[WP31kY/0`^jI072;?03Fj9h0h>fX0=CXX`32hih0c_^f09C8RP3:g:P0XKIe0=?^
Y`3:iY/0bnjL0<3VT`34hiL0SYUE0<WZX`2liil0bNbZ0=CY[P3omLh0D4HS0=OY`@3cnn<0o_o^0?oo
mP3:_;T0o_ok0?KonP80ooko0`3oood04@3no_`0noog0>ong@3Tn<L0cn^P0<[[VP36jid0cnNM0=?T
WP3@iYh0cNNN0=[[Y`2o/gT0KEPQ04`k1@2HXF80W:]Z00<0Uj1O03@0UZ5O09FQG`2iaH<0L7ll07j?
B`2X^GD0fnbX0>3f[P37iYP0cNbN0<SWV@35i9H0b^VK0<GTUP37iYP0cNbN0=7`XP3:jI/0`n6I07ZA
F@1OMT00OYEO0=;Y/@11@A/0R8QR08f?I`0X<040GVPf086>F@3>hZD0fNf^0<WRWP38hi`0b^ZO0=;h
Z`2mhiH0c?6T0<g_XP35iIT0bNRL0<WXVP39jY/0a>NE0<?VU03@lJ00`mfC0<[PU`3OmJ`0dn^Q0=C/
XP3Ajj40c>JL0P39iIX04@37iYX0c>fN0<[]V`3;l:00a^^M0<W]X`38jjL0cO2/0<[^Z03>lZX0`^NI
0=;gY`2hfhT0gOfb0;[ESP3HkJP0dnNR00H0o`0005@0c_2V0=CMW03Ij:D0^oJT0:OXU03;jJ40g>FT
0:bSJ03PhZ<0e_2Y0;gHT@2gdHX0`mnE0<o^XP3=kJ40dO>V0<OYW033iIP0d?2T0<STV@3Ajj40b=bD
0<kOV03:k9l0b>nP0;cLT039hiT0a]N@07^;A03:fY<0g^nX0<OKT`3<iY`0cnjR0<CUX03;jZL0a]bN
0=KUZP2=U5h0DULQ0:FWM@2<TV80fnBe0?OofP3NlL<0b>JN0<_WVP3CjZ80bnfI0>SMY`1Q@R<0;0X0
09BSNP3;j;00i_S40?7oj@3hooX0nokc0;>WT@3on]H0e=bY0<_fY`2ojYX0eN2K08n?D@3FeZ80f>Ja
0<cXWP3=k9h0cnjR0<oZY@3>ijD0d>FZ0>Gh`03Ok[L0koc60::[MP2LXfl0dNS<0<WVd03^oo40/m6]
0<c/``28ZGX;0?ooo`002P3oool0900W50D0Sgec0>CCc03on_d0oo_o0?omo`3oool0o?om0?SomP3c
onl0jo[I0<kKX`3Um:l0Y;E^09>ZG03Fkih0b>FC0;cLR@32hi80`N:C0>Co]P34hIh0g_;1000?003L
kMd0MXR80?7oo`3bool0mOoo0?Won`3noo/0oook0?olo@3omOX0oo_o0?oko080nOoo00d0o?oo0?oo
o`3oo_/0oooj0?gom`3Jh//0FFDg0=;OZP3>fZ`0i>[>0=[Ob`3oooX0ooom00<0oooo02L0ooko0>_Y
jP3lool0joSo0>Clo`3anol0kOoo0>Cok`2/_IT0JEDj0>oW`P3>f:<0aNRD0<WZV@33hY`0_]jK0=Wl
_030j:T0d_bl0<_[Z03Jl:l0dmZG0=_UX039iIX0aN6F0<7PU034hiL0c^fQ0;SGR`39iIX0cnFL09FY
H@3AhIX0cMbG0=c_[@3@hj40VJUX09VXI`3;eiL00P3MjJT0AP2da8<0_M2>0=?XY@2AZ6@0YKmf0=O^
YP3Aiih0d^JO0<7?U00M:P00h^jl0=KS[@1IJ2d0QIUA08ZOE034fI@0j?^i0=SXZ@3:fY`0c=jP0<cO
W`24VEH0L8Lo0<_SV@3Im:L0bnVO0<W[[P27YVX0C6TW0<_VX`3Om:l0cN>K0=S/Y@39giL0fO2Z0=3W
X`2ofI80b>NI0<WSV@3NkZL0VJAO0;NiN03Gei/0YjEb096@I03oonH0ooo/0?3^g`3ooo40noSW07Yd
FP2f[i80j^C00>SZ`P2m`:<0knkI0?oom03ooo<0];6N0;nnZ@3ko^T0o_od0?_onP3iooH0a=^W0<gX
X`3BkJP0^]F@0=3YY@2ke9020<gTX00E0<_PW@3LlJh0VZiY09VVH@20X5D0Rk1S08B@CP1YDQh0TZES
06Z>AP27YEd0P:1E09BXH03Fij00amRA0=KWX03;giL0cNFK0=3ZX03:jId0bNVM0080a^^M02<0`nbM
0<K[W@3=iih0bNVN0<K[W@35k9/0b>^I08fRE`31dHX0g_:]0<gVY03;m;00X]F@0;OWZ@3Ci:d0YkYj
0<_UWP3;iI/0c>fL0<?VU03?jih0b<n<0<k/YP35kJ@0anRQ0<cRX@3on<d0IE`e0<gO]@3Jh/X0j>_H
0?Sil@3_hN00o_om0?Woo`030?ono`0C0?ooo@3ooo/0oooj0?Snl03Gil80cN6/0<cYU`37kIH0`NjM
0<SZW@3<j9h0bNVN0<K[WP3@jj@0lNnb04Ln0`2e[gD0goBa0<WTW`030=;WXP090=7XXP3?jJ80aMnH
0=?^Y`3;iYl0bNBM0=GcZ`3ClJL0b^^L0080bNRJ03d0b^^L0<_/W@3:jI/0b^VK0<_/W@3:ji`0anJH
0<CTV03>kjP0dO:]0<[[YP3;k:D0h?:h0=c`/`3Dj:/0c>:R09fcLP31fYH0e?2V0<3NU03:ji`0`^>B
0<g`X031jY`0d_^]0<3VV@34iYX0do>X0<c[W`3ClZH0d>nS0<g^W`3@lJ80^^BB0;[^V`2hkYX0]n^H
0;kbW`32kih0bOBT0<S_X03<lJ<0bNVM0<c[W`37iYX0dNfP0<WUVP3BkZ@0aN2K0<gWZ02J]7D0a^2Q
0=;]ZP36hYP0an>H0<SSUP3>i9`0h?B_0;W8Q@0h@`40h>JV00H0o`0005<0MW8e06MW:@35kZ80_o2Q
0=?XX`3DfYX0BdT<0=GPWP31hiT0e?Z_0<CXWP2DYEl0Pi1:0;oCR`3EkJ<0_n6D0<WbX`36mJ@0`_>Q
0;7UTP2hkYX0/NNC0<_`XP37ii/0e?>W0<o[X03?jIl0g?BZ0=W_YP1RN2l0J7he0<OOU@3]ok/0b^fI
0;WLRP3Gl:l0d>:^0<G:ZP3_lMT0lO?M0>CVcP3_m=H0j_G:0>Oea038iJ<0d^n/0<[SX@38jYh0im^Y
099cE01D<RH0cMZ/06V3@P3GiZD0l_oJ0?Won03nooX0Z:2=0?oohP3JhkH0_N:L0;gSV03=g9L0VYmO
0?;g_@3Ah:L0d>jX0<k^Y@3FmJl0eoBa0<GRX03=jJ`0g_Zm0>3j_@3Ilk@0f_Bc0;O@S`31fj`0g_W>
0=[eb030gJL0b>F[0<KTY00;0?ooo`002P3oool07P0o91<0?R@G0:B<P03ono@0oo;_0?SblP3mo?X0
o_om0?Soo@3goo/0k__W0?3kd03Ei:T0fnf_04MQ6P2R`7H0bn^O0=Sh[03<k:40e_:X0<3KU03FjZl0
UjIm04A@?03<f<`0^/S90>cko`3eool0mooo0?_onP80oooj01D0oock0?oin`3on_d0oogm0?_oo`3i
ool0o?oo0?gmo@3oo_/0m_G`0?comP2Z/iP0AE@I0=CUX@3NkK80aM:W0>O`d@3noo@0o_oj0?ooo`3o
o_l00P3ooOl0H03aj>/0ooko0?Kjo`3dool0oOgo0?3ol`3GlM@0`m2U04Pd4@3AcIh0h>nd0<7WU032
iID0c^VR0<GPV`36hj00doJb0;?HT`2bdHd0[lR40<kJV03EhYd0ennU0=WaY`3Ajj40e?2U0<[VV`3I
n:`0e?2U09VcJ@2]aG/0fNnV0=cbZP39h9X0a=VD0<KJU@3Bhil0g>^X0<kJV02EXEl0e>FQ0=OXY03S
mk80a=VD08BJDP3:gYL0e^NP0<gLU`3Qk;8092h00=cV]03;f:80gNba0=KZXP3@iIX0fnZU0<gNVP3:
fYT0fNb/0=3UXP3LlJ`0g?:Z05M]903DjIh0d>>D0=7WWP30gj<0VKMk04eW9P3HlJl0h?F`0<cPV`2a
`Wh0en^V08BIE03LlJh0dnjW0<;[W03Lok<0`]jD05]a:@3Kj:<0emBM05iL;01PGC@0[jZD0<Bn/03l
mNl0ooWf0?_bk@2k[j<0mNSH0?onj03NgL40ooo_0?7_h`80oogk04P0]:fU0=oKd03inNl0o?gh0?ko
o`3gooH0bNB_0<SZX03:k:80cNnU0<[ZX@3BlZT0cN^S0<[XX03:iIh0bnJO0<CKU@3?h9X0fO^_0<gc
YP3@g9X0JE8N0=[]Z`2beXh0`=jF0:C4N@22V4l0]<En0>Gb[03@fiH0fNJP0=gaZ@3?iI`0c>RM0<WY
W@36jid0`nbM0<7^W@33k9d0b^VM0<WYW@38ji/0bNZK0<cXV`2;W5D0/;mj0=7VY@2ddi00aOB`07Z_
J`33kk00c]^S09^[K039h9X0c>BJ0<WXV032iI<0b^FH0;g4P@38hih0a>fQ0<SZWP3@iJ80m>Ji061D
;03;g;80jO7I0??fi@3ko?@0kn7P0?Wim`3goOd30?ono`0C0?ooo@3ooo/0oooj0?Wol@3Bh[/0bMjU
0<k[U`37kYD0_^nM0<G/W@39jIh0a^^N0<?/WP32i9X0gN:R05eI702ASe@0dnbX0<KWX0030<cWX00c
0<[XX039jJ00c^jU0<3PU`34iY`0c>jT0<7SV@2ff8`0aNNJ0<KVVP3:jYh0bnfP0<SZW@3<k:00a>BH
0<CVV@3@lZD0do>W0=7cYP37k9h0[mB70<caY02lhI<0_MRC0<kYXP3:iIh0eO>Y08:PEP37iYX0anJH
0<WZV`3=kYd0bnfI0<[]W@3;lJ@0`nVN0<7UV`38j9d0b>JL0<?OU@38hYP0bN>I0<[VV`3=k9h0b>VJ
0<?ZV`3=ljH0_N>F0<CZW@2igi80_>:E0080`nbN00d0`^^M0<G^X032iiT0d^bR0<cRVP3JkjX0c>6P
0<_OXP1mTEH0g?2c0=O[[03AiZ40d>JN0080o`0000H0a=>@07F0?P1^M3@0g^>S0=WNWP3TjJT40?l0
001C0<>jO`23NSl0b^RP0<O]XP3@i9l0fMnO05]M7P3AgI/0bnfS0;3IS@35kZ80^lB105]J6P3QiZ@0
fN:O0<_OV03:i9/0aNFJ0<caY032j9/0e_b_0<;[W@37iYX0dN^Q0<OSV03?jj00c^fQ0<CSU`38hYP0
[lUo08jVG03@i9`0eNVQ0<?WS`3BnJ00c>JU0<SLZ@3@eKh0bL^m0?oom03in^X0ooo/0;k6W@3=fJT0
a>6Q0<g[Z`3<iZD0bnnU0?;V]02RPfH0FSHX0=cX]P2W`7`0fnRS0<gJ[P3hooD0oook0;J_W`3hmm/0
emnf0<S[Z@38k:@0d=nL08:;BP3@f9d0amJK0<GOWP39iZ<0foRf0>Ko``3?k:`0bNNY0<OUY`3No[/0
d_>^0<3QVP3CmJ/0Oi]Q0<7JX`33g:<0cnVZ0<SSX035hIL02`3oool000X0oooo01h0fKb^04<V600]
4`H0LemD0=70^03ooOP0ookj0?oon`3goOd0n?oo0?Kom`3]m]/0nooO0<?DZ03Ck[T0`^6X07^JGP2I
^7`0N9AI08bSJ`2FZG8000P003U28`2`^:T0RYB<0?Ooo`3eool0n?oo0?Soo@3looX20?oonP0E0?ol
n`3on?X0oo[m0?omo@3kool0nOoo0?coo`3dm?@0ookk0?Wfl@3moo@0Xjb?0<gRX@3Fk:<0aMZG0=?S
]03[mm<0o?oc0?kon03oool0ooko0080oogo0600oocm0?cgn`3nool0l_Wo0?oko`3koo40fo3?0>7]
_@2ST6D0PX9<09J[JP34kIh0b>ZM0<cSV`3HkJP0b^6K07jLEP1DLbd0`^:I082KEP3IkJP0bmbH0=3T
W038g9@0e>bR0=SbZ035giD0S:QM05Qg:`3?jj00aN6F0=?_Y02mfHh0f?:[0=K]Y`3Wo;L0d>BO0<gL
V@2?VeT0VJES0=CSX035eY80^Lf80=S/Y`2L/6T0/<5k0=_[Y03IiZ40UIiU010H003Dg:/0c]RS0>?a
]P3DiIh0c^2F0=3KU`3;eiD0fNZV0=GZY@3Ilj`0`MR@0<[PU`3Sn:d0SZ1D0<KCQ03AhIP0aN>W09Ve
N02O]gT0[L>30<7DTP3?gih0cMjJ0<KGT`2I[FP0L8=10<_UWP37k9h0^=R<09V`J03=gYP0gnZV0:RW
L@2@Sel0eM>/09^FPP1fL6@0LfUX05E;C00m<C<0m>KS0?okmP3onnl0W9J60?kklP3oo_X20?oko`03
0?K]kP3ooO/0ookk0080ooko00P0nOoh0=;]^032iY`0]m^A0<__Y@33iI/0bN^Q0<?UV`80d?2W01T0
anNN0=GaY`3EjJ80_^>F0<ceY`3AgI/0XHYF0=GXYP31iId0cNfT0<c^XP38h9H0eNJO059M602`^WD0
bmJA0<gNU`3?hi/0c>RM0<[YW@36jid0aNbM0<;]W@33k9d0bNZI0080bNZK01h0c>RK0=3VV`23TTd0
ho:_0>So`039k:X0__>_09oHT`3<m;D0eMjU09:PHP3>hih0c>:I0<o^X038jIP0aMfC0:6VI033gIH0
a^bQ0<KYV@3@iYh0imJX05iB:P3;g;80n_oY0?ool@3oooP0iMGF0?ooo`3iool30?ono`0D0?ooo@3o
ooX0oooh0?[ol@3Ah[P0bMjU0<o]U`36kI80_?2M0<G/W@39jIh0a^^N0<;]WP3<kZ@0fn6Q08V7BP2S
XfL0b^RR0<;VWP3<jZ830<_[XP090<[/XP3<kZ@0c?2V0<__Y@30i9X0aNVO0=[o/P36j9/0anVL0080
bN^N02X0a>JI0<SZW@3;kJ00anVL0;kPT`31hiH0a>JI0<G/V`3EnZX0a>VI0<K]W03>kZ<0_=b@0<c/
X01/S400Z<Uj0=WhZP36iID0eOBV0<SWU`3>kId0b>NI0<CVVP31hIP0e_J]0<SSW036gIL0g?>[0=S/
Y@3HkZH0cNFK0<WQU`3GlJL0d_2V0=7aYP31hIH0aNFJ0=GeZP3:jYl0c>ZP0<[XWP3;jIl20?l00004
0<oUW03>gi/0fn^Z0=3PXP80o`0000<0eNB[0<GDV@3Pl:l0103o00001P2;UU@0k_Bd0=GJVP3DfIT0
`lV90;_4P`80o`0000H0c^>N0>oVZ`2KTUL0cnBO0<o]Y@3AhYh20?l0001<0>3/ZP3Lo;<0`^RM0=;k
[`3Fgi`0h=nO06=U902c^WL0V:EP0=SWXP30e8d0e^bT0<WOU`3CjJ40c>>K0<[PU`3Qmjh0cNNM0<_Z
WP3:jYh0`nFH0<3OT`3Kmj`0f?:X08bPF02S]6d0bNbB0=KmXP39iZ<0c^F_0>;/d`3MhM80d]C90?gn
l03hn^D0DeLb09:IK@38iJD0b^ZW0<cYY`38kJ00kN6_08i_DP3H]:H0e>2^0<CKU@3Eh9/0c=FX0>7V
g`3fm_@0f]O80?ooi`3Vl</0d>j`0<KUX@3@hId0_LN809jXJ`2oci40cnNY0<kXZ@3DkZl0eNnb0<_U
Z03@k:l0dNn_0;GFT@2cehl0anjO0;gVU`3@jZT0X;Qj08jTI03Ek:H0aMnE0=3[W0/0oooo000:0?oo
o`0J0?oimP3onO@0g/_403@T5`0c8aH07A4307=YG@3Ec<<0oogk0?oloP3ooOl0nOWo0?Woo`3boOl0
lOoo0>;ll@3^ooP0]ljn061^H@2DW94010D00:ZWX02/[:80o_ok0??gn03`m?d20?_oo`0I0?con`3o
ooH0oooh0?oonP3ono/0ooSk0?ojo@3ooOd0n_km0?_oo`3dm_D0ooom0?ghm03oooP0]kV^0;BnY@3F
j[D0cNFW0=cc^`3Hj/00l?kM0?col`3looP0o_oo0?ono`020?omo`1Z0?okn`3oo_l00@430?_mnP3o
noP0oOoR0=7R]@3Chj@0_[Ai08VHD`37jIl0_nVM0<OYW`3Fij00f>FO0<K@R@3Bi9X0cnFJ0:[9O@33
hIL0]]B>0=3ZX`2__7H0Q9A=0<_LU@2ld8P0TZQO0<oYW`2nfXl0dO6U0<SZW@3AmZP0`>FG0<[XX03B
kJH0c>>M0=kc[P26Ue<0iOBa0<cKV02U]740RiaH09f^JP3Ci:00dn:M0=gZY@3FhI`0c=NC0=CLX`11
B1D0dMNW0:nhP`1SKS@0a=B=0>3]Y@3LhIl0cmJC0:FfL02AYel0bNFJ0<o[WP3Ikj@0bmfA0=kZX01H
G180K7Ha0<CRYP3Ajjh0bMjS09^_LP3<g9h0g>Z/065`;`2O[Vd0bmbH0=S/Y`2DYF40R9E@09:MF@3S
iJ@0f]ZJ05aH6@2laXL0fnB]0=OO/03joN80ooo^0?onn`3lm_P0ooOl0?oko`3hkO40o_Cc0;2XYP3o
oO/0oocm0?oko`3Ndm/0ooKn0?olo`3oo_l0oogn0?ooo@3loo40b^6Y0<7QV080aNFL01T0c>bS0<KV
W@38j9l0bnVQ0=;`Z039iil0bnNM0<OMU036k9l0`nbN0<GAS`1_EB80f>RW0<[^YP3AlJP0c>jR0<WS
V@3Aiih0c^:J0<WMU@2aaGd0DVPO08>ID03?iid0cNNM00<0c>RM0280b^VK0<S[U`3:jYL0c>VI0=?T
W@3Dhih0NXU80=7TY035j:P0^N>S097:QP32nkH0_=nK0>GX[`2BWE/0fnbV0<SLU034hiD0a>FF0=G]
X`2CUE@0d>NQ0<?XVP39jiL0cN>J0>KEY`1ZGSP0amN`0?kok`3ooo@0o?_g0;ZZ[@3oool0mogm0`3o
o_l04`3oood0oooj0?oon03ioo00dnBj0<cQYP3>k9H0`^J<0<;]W@39jId0cNNN0<[XWP35jih0d>jV
0=_MWP2?Rdh0aL>80<3KUP3@lJX0103;jJ401`3:jZ40bn^R0<OWWP34i9/0a^JM0<_[XP38j9l00P38
jYd20<KXV`0Y0<c^X@3=kj80`>:E0<7SUP3;kJ00b^bO0<KXV`30h9@0b^VM0<k]X@39jId0c>bP0<KU
V@1VQCT0eo6W0=3ZX03=iI/0a=ZB0=KZX`3Bhid0hO:/0=GTX@3JjZ/0d^2R06mk>`3Bfi`0hnV[07Il
?01=DQ80GV<S0=;IUP3QjZL0enBO0<cMU`38fI<0gNjX0;K5P02=V5@082T003Dj001>D0l0103o0000
0`1AGAd0DelQ0?l000030?l0000306eh@017DaD0o`0000<0o`0000d0d>6M0>3_[03Zm[@0c=RF06im
>P2gb8@0d^NR0<cSW@3;iIh0eM^K0:V^KP3BiZ40d>NQ00H0o`0000<0e_2Y0=?aY`30gY@00P3<iYd0
1@3=hi/0f^^U08>>BP2NYf@0VJ1M0080Y:AT03d0RYA?0<SHT@3AjIl0c>RM0<O/WP3;lZ<0c?6S0<c/
X03GljP0h?6Z0;2mM`38j9<0e?RQ0;kMT@39i:40e^Rd0=3P/`3<e[40aLZ/0>KYc03jnMd0e=>g0<g[
Y@2oi9@0d_2V0<O]VP3ZgZX0I4<T0<BNT`2//hT0`=BG0:2VJ03Tj/H0k>gX0>WXiP3koO00oOo[0?_o
i03?hk00a]jR0=7VY@3;h9d0g>n]09ndL@1QL3D0OXeF0:JeOP3Ok[L0i_Fn0<oSYP3DjZX0d>jX0<KV
V`2li8h0e?jX0=OaY`3<hYX0d^RO06Ak;@2Q^6P0aMb:00/0oooo000:0?ooo`0d0?oko`3ono/0oocj
0?kaj03Kcl<0Bcla01d?0P0;0000T85l09:3P03omod0mO;o0?Glo`3[mol0V:^_0;S=cP2Q]K<0[l:n
0?Cmo00_<3800@020<6k_`3Sgm`0ooom0?koo`3gn_l0o?oo0?coo@3nooX0ooof0?oon03oooX0oo_m
0?kXj`3on_/0ooWg0?coo@3kool0o_om0?ooo@3oo_X0oooh0>;Tf@3Vk]T0k?kF0<[P/P39g[D0l?oQ
0?Goj@3loo@0o?oh0?koo@<0ooko01l0ooom0?ooo`000@00n_oi0?ohkP3noml0e^fg0=;WXP2NV5X0
Z/1g0<S^X@3Fok<0_=bC0=?PVP3Mij80dMNA0=CQV@3Bii`0anJJ0<_[X035iI`0dNbU0:jkM@3Hj:40
bmbE086EC@3Bj9l0e>jT0<KRU`3;jil0aNNJ0080aNbM08T0d>jT0<WUV`2_aWh0P9I>0=OXXP3GiZ40
dn:M0;K5P03:fiD0VZiW0:BhL@3>gIP0enBO0=;MV03CgYX0eMZR03<g1@3HgZh0Jg@o0=KOYP3DhI/0
hNfU0=gOWP3Jgid0fn^T0=?WW`1FL2H0L8Y00<OMU03?hIL0i?2X0=[OW02JXf80eO>g0;oHWP0A9P00
fNf`09JVJ035diH0R9IH082?CP36ei<0fNfV0=CZXP3@jj@0cnVR0=CYY01^PSd0]/F20=[^YP35eIH0
e^F^0?Kog@3lonP0ooof0?kmn@3ooO`0oogn0?ono`3nnOH0[:NT0?omn`3on?H0oocm0>;Gf`3onol0
ooco0?OclP3oooX0mOG]0?cojP3:gJD0dN^R0<WSVP3Bk:<0bNFK0<_WW@3AkJ<0b>BJ0=;^Y038i9X0
dN^R0<oUW030iYT0`^^M0=KRX01SBAH0eNBS0<?TW@3<jZ80anVM0=;/XP39hiT0bNFJ0=3/X@38i9T0
dN^Q0;WCR@1[PcT0dnVP0<GIT@3>hYX0fNfU0<WQU@39k9P0a^JC0=ojZ`3=gIH0e^>N03A41@3=hj<0
/mZI0;k[ZP2Yh9`0__J_0=Ce/02IVV00SYMF0<kOV@3IkJD0cNbP0<CTV03<i9X0WZ1O0<oVX039kZ00
a^RD0=;VWP3Qd:@0IeTf0?7of`3ioN`0ooof0?ooo@2^WZ40ooko0?Kjn`030?ono`0E0?ooo@3oooX0
oooh0?_olP3?gkP0b=fT0=3]V@37jY00coBV0<kXWP37fi@0e>^S0<c/X@3FkJL0in>V06]Q9P2SWF<0
dNRT0<k/YP3:iIh0bNBM0080bnJO03@0b>>L0<[UWP3DkZL0d^bU0<cVW`39hi`0bnJO0;?ER@3DmZX0
a>JJ0<OYW@39jil0bnfQ0<oaY@34iYX0b>ZN0<c^XP32hYL0a=jE0=C[X`3?iYh0f?:Y08fWGP2>Z640
eNnX0=ca[03;gY`0e^JU0=CPXP3PjZd0KGDi09bRIP2FVF00Y:U_06Q[<P2MWV@0WieT0>g[/P2JUE/0
g=RK0:>QI02h^7X0hnFV0:VWJP1SFAh0GU8H07id>@2[XVL0WimQ09^PH03;fYL0fNZV103o00000`2A
WEd0UJ5S0?l000030?l0000308fHH02ha8H0g>RV0080o`0000D0dnZT0=?XX`3:giX0hOF`08fQG002
0=CYY0070=K`Z@3GlZ/0^mVA0<OKUP2L[FT0eNZU0<WPVP070?l000180<K`Y032lj@0`O2R0<;/X037
kJ80bnfS0<WTW@31fi@0e>^U0=__ZP3=hI`0S9UC07^8@P2U_G<0d^jS0<3UU`3<lj@0b>fO0<[/W`37
iYX0c>2H0=CTW@1hU4L0d_>T0<KUU`3FlZD0b=nG0<oTX@3Ah:D0[kJ:0=KJ]@3oonX0c<Nd0<7OU@3>
mI`0c>^K0<kdW@3Md9`0Kdda0=:/X`1TJT@0c^6Z0:R]M`3oonP0oook0?;ak@3Tjm/0noo]0?OohP3C
hk@0cN2Y0=CZZP3=iZ80c^FO0=?XX`2CXFH0RIAL05QQ;034cIP0oooC0=_V[03:fY`0c^FO0<_UV`32
iI40c?:M0<[TVP3@iYh0c>:I0<OMTP2BZE/0b^6A2`3oool000X0oooo01T0o?ko0?kno`3loOl0ookk
0?onn03ooO<0akV^065AA00P2@40;aH?02XH503Ee=T0PhbA0:F_/@3hool0kOSb0??mm@3iooP08B8L
0?OflP1GDe00oogm0?ono@3oool0oOco0080ooko01P0oook0?oon03oooH0oooj0?ooo@3onol0i]3C
0?ogm`3onOP0n_ok0?coo@3moO/0ookj0<k9``2?RX@0oood0?kom03iooH0k?S/0>Wej@3iooX0n_oi
0?con`3noo/20?oon`<0ooom02X0o?oo0003003hooH0ooo]0>Wkb`37iJL0a^:H09^JF@3Ek:@0]MV?
0<;RV@3=iZ80QHi=0=[OW`3QhZH0g^VW0<gQW03?kJ<0bNVN0<_[W`3;jYh0JGXc07R9@P39gID0W[9Z
09Z^IP3Cjj40a=jD0<7PU032i9L0bo2R0;gRU033hIL0aN6G0;C;P`3:h9P0b]jG0<_LUP1<GAL0am^D
0=GYXP35fi<20=K/Y01m06b0>@3>gYL0f^NR055I800Z;P00h>>d0<?:UP3FgZD0cMNB0>oi/P3Nh:40
fn2P0>3]Z03_o[T0cN:M0<_PV`2DZFH0DF@T0;[:S030cID0d^BZ0=om_`2bcY<0X[Z004mT:`2_`HL0
Tj9Y0>3`/P31dI80^/j90<WMUP3Ci9h0hNNY0>kd]P1BF1P0^Kmo0=kSX`3Hn:<0an>H0<7JUP3domH0
nooS0?Olj03bm^P0j>_R0:Z[YP28R8H0];Bb0?Kbk`3oooP0ooof0?onmP3oo_P0ooOh0?olo@3oooP0
n__[0?GihP3jomX0cmnQ0::fK`2Q]Fh0hoN`08^OF024VU80PYUA0=7XX037gYH0d>NO0<GLU03BiYh0
aNZM0=3fZ@3;e9<0J4XH0>3YZP31g9L0fOB]0=7aYP3>j9h0e_:W0<C[W034kIh0`NRI0<SZW@3?kZ80
f?2V0=3TW02AXEX0PHa70=[TW`3Hj9l0_^6=0=GbXP3LlZL0`=6=0:JfM@3@kJ/0cO2^09c9QP1o[VX0
^NRT0<Sf[P3>k:@0WIeO0<K?S03KkjP0d^ZP0<GUV@38kIl0a=jD0:J[J@34fi<0bN^N0<KUV@39fIP0
jmNb05Q7:`3konX0ooof0?onn`3oo?d0]J6Z0?ono`3lool00P3oo_l30?ooo@0A0?oon`3kooD0k?_J
0=oc`P3:iYT0b^ZG0<CPU@3FiYl0d=^G0=[YY03JlJT0cMbI0:bPIP1dHb/0X9=L0<SGUP2AZVH00P29
X5X0302=Y5h0SjIP08nTG`2L/F`0g_:]0>Ch/`3Cij80bmnJ0=S]Z03MoK80bNNM0<7OU@80b^ZO02T0
eO>Y0;kLTP3AlJH0d?2U0<[XWP3:iIh0`=>A0<[JV`3GijP0Wk9`0<gMW`2nc8l0eN>V0=KPY02MYF`0
8RL006a/>03=biP0G5HT04]34P3SfJP0h=JS0<k2T03`hjl0GDdJ0;BTL@2;NdL0SX==0?ke_P1eL3H0
`/250>__/P3;fYL0bmnJ0=3UX03>hih0bN>L0<[UWP38iYh0cNfT0<CVW0020?l000040<OMU@3o0000
o`000<oOX@80o`0001D0f>N^0<oNX`3EiJ@0enRT0=7UWP3<iYl0c^VR0=7/Y@3@jj@0JXDn0=cg/02o
gID0bNNO0<o_YP38jZ00bN^Q0;SLTP3@lZP0enbW0<7FT@2ogID01P3o0000B03EjJ@0d>NQ0=;YX`3F
kJL0dN^T0<_VW`2ohIL0c?2V0<;[W`2fhYD0aOBV0<WPV03Ol:T0f>jU0:FoM@37iYX0d?2T0=OgZ`38
j9`0cNbP0<_SV@34fY40dnVX09B]J`3>ji/0]=9j0=3`S`2og7l0eo6H0=o][`2?UfH0ooo]0>KMeP3@
jZ40b^^@0<_VU@36jY<0lnFf06I4:`3of=H0LWMG0;k@X02e^h/0o_o/0?onmP3ono00mOo/0<SH^`30
cjh0cMBZ0=;LZP3@kJ/0anRQ0<c/X@3EkJ<0dn:Q0=cXZP3HhZH0Zk=j06md?02IW6<0f^2T0=ORX03A
h9/0_mN;0=_fY`39hiT0e>jU0<gTW03Llj/0dnfS0<GOU@/0oooo000:0?ooo`0a0?Woo`3kool0n_go
0?[jnP3nn_L0oOC]0?olm03oo?<0T7ac05Q4>`0>00000@<005eXHP3ioo/0lOO]0?komP3ooo@0n?S/
08b:OP3oooH0ZjRO0?_hl`3ooo/0no_m0?[ioP3oo_l0oooo0?oonP3oooH0oooh0?oon`3oool0oo_o
0=o9c03olO40oo_i0?goo03io_X0no_i0?onn`2d[JL0OGU`0?ool`3gn^l0nook0?SnnP3enoL0noom
0?WnnP020?koo@@0oook05X0n?Oe0?WknP000`00mood0?cnj03EjKH0`N6P0<cVW@2PW5d0i_Vg0<c[
Y@3=j:40e^^X05UO8`3AeIX0d]FL0=gX[03>hJ40dNnW0<WYWP3>kih0b^NG0<SNU@2I[fH0e^bS0=[^
YP3;giL0cnFL0<cTVP3ImJX0bn^O0=7cYP30hYD0_m^A0<kXW`3KlJT0e^bT0=7UWP3QlZ`0AUXC0<gS
V`3:h9P0fo:Z0<gWWP31fi80h_R`08jOF039f9<0g>B[02``003FfJX0gn>`0>?X/03@ei<0RI1:05aQ
8@1AEaL0KWTg0;O3P@3FiZD0a=NG0<GIW02L/7D0go:j0=SZ^03<hjd0^m^L0<g[[`0fCaD0bn>Y09Z]
M@1<GBH0bMRM0>co_`2=XUd0b^2H0=c]Z@33ahX0hNFX051E5@3OiJD0g^BT0<KXTP1XQcT001L00?3o
d03kon40j^oI0>;TeP12@c/20?oon`80ooom04h0m?7Z0?onlP3ooo<0noCZ0?gel`3ooOd0oooe0?oo
k@3nonH0fnVf0=WYZP34eHl0cn>L0=W]YP3@i9d0c^BL08>JDP003`00enjV0;WCRP3>iId0fnnW0<c^
XP3?m:L0gN:R085O;`3GgIl0f?6]0<KPV@2iehd0e_2V0;oKT035k9d0a>nO0<K_X031hiH0`n>G0<oY
W`2ne8/0hO:[0>3]Y`1FHA`0S9iD0=?dX`3El:<0_=:906=c<P1mTU40_n:P0<gf/P0SE@h0d_nk0<[c
[@2li9d0aN6F09ZJFP3Fgi`0e>RQ0<SPUP35iiX0c?>T0<STV@2f_GX0a^2G0<[/X03Jn:h0c=bN0>C=
[@1ZF400noo]0?oonP3ooOd0oo[n0<2/]@3oo_l0noon0?ooo`3oo_l20?ooo@190?ooo`3oood0o?oj
0?Soj03Xnlh0bNFK0<o^X03Ajj40bMJ@0>C]ZP38eI00=D`4061_;02_XfT0Dd8:07EV;`3Ah9l0bN:N
0<[TW@39hi`0cnJP0=7XXP3@iJ00c>6L05=W8P0jCPT0BU/G055R7P0mDPd0^MN=0=[f[03=jIl0eO>Y
0<k/XP39iI/0`]jD0=GcZ@39iid0bnNM0<[TW@3Plk40c^6Q04eP802fbHL0c]bQ0>oj`03<eid0f>2W
05ML901=D1T0emFR0>_X]@3Xh:l0VHmN03X^003Ibi`0I5@S06=C8P1RDQl0Xi=P0=c?V`2OUUl0dLZC
05YJ7P2KW600dM^L0=C]Z@32hYT0eON]0<W[X@2igI<0d?BZ0<GYW`020?l000030<S/XP35iid0o`00
00<0o`0001X0`MFH06Mk@03?hjH0`]JG0=S]Z037gID0c>BJ0=?]Y03CkJH0bnJO0<cWX034giP0a>:J
0<7OU`37iId0c>bS0<SXW`3?kjH0bO:V0;OKT@27V5@0f^VV0<[ZX@3:kZ@0eNnX0=;MV`80o`0000<0
@DX90=kSX`3Mgj000P3DfIT0A03KiZ@0g>^X0<_RW02ofY<0_^2F0;cVVP34l:<0e_2W0<;FSP3;hIP0
dNVO04US6@2ieHX0[lj20<SWV`3JmZ/0f?BY0=;/XP3CjJT0PIEF0=3[W03RoZT0`N220=SgV@3=jY00
fn^Z0=SP[`3oond0kNCK0=3WX`3Bl9X0cNFK0<WZV`3C`YL0Hch[0?C:c01bMeT0b=ZX09>JI`001@00
oooc0?ool@3gon`0mOoX0;?3W`3[l<L0e=b]0=3^[P3>m:/0b>ZM0>Cl/03Hk:D0amRD0=g/Z`3Fh:<0
jO6e04iA601GFb00c=FF0=WUX`3Gjj@0^=260<[VV`3ElJL0cNVO0<KRV03:iY`0f_J/2`3oool000X0
oooo0340o?om0?[ln`3nool0ooko0?[io`3ooOl0noKj0?ono@3oo_P0ookf0??ci`001@0000/00086
000T7Q80GE=701<5001aHeP0ookc0:JRU`3oooH0n?_d0?gnn@3oool0ooko0?_jo`3lo?`0oooh0?oo
mP3nooX0o_oo0?coo`3oo?l0ooSm0?ojnP3onOL0o_ok0?koo@3mo_T0oooj0=SAb@3oo_H0oooc0?oo
mP3jnoH0ooom0?kno03oood0oOki00@0ooom0:d0oooo0?ono`3on_h0n_Cf00H;1`3goo<0ooo/0<[Q
[@3Dm;D0dnJT0;BUKP2SXfl0d^2S0=7UW@3EhIl0Z:]f0=OIZ03GfZ/0`=2O0=_b^P3:jJD0c^jR0=7_
V@3:ii<0`>2D0<[YW@3EkjD0d^ZP0;S>Q@3EjJ40Yk]c0=cdZP2nf8h0hOfb0;??Q03<i9X0d^ZP0<SL
U03Ciil0c^:J0<KJTP1HKRD0bN>I0<WUVP35i9P0b>RL0;SHS@3<jZ00aMfC0<gQVP3Ii:X02A000<c>
W`2YZgT0IFPa0=7FT`3WkJL0en2Q0<gFU`2@UUP0DeTM02de00002P00cn6_0<?IZP37hK@000l005am
D033ijL0_MnR0=;_]@25XFL0dNJ^000<003SmkX0eN^[09>ZI02K/VX0cnJP08fMGP1BIB<0d^VU0<GP
V`3InK00c^^K0<[TW@3FjZ/0c=FZ075gE@3oo^l0ookd0>KNf`3oo?d0o_Sj0?omo`3oo_l0oooj0?oo
mP3ooo<0ooof0?Kbl@3gmOH0o_of0>ogg`3kon<0B5XN0:6eL03:h9L0f?2V0<gUV`3XokH0`mfC0<o[
X032hID0c^fQ0<GTV03BkZ<0c>2H0=3`Y@3;kJ40hN6S06Q24`1HF1`0E6LU0<[NV@3Fl:L0c^JL0=_c
Z@3@l:@0aNNJ0<SXW03;jil0c>^O0=OfZP35i9P0d>bQ0<cVW03Fl:H0bNFJ0>3n]035g9@0cN:M0<GK
V`3>jj/0c?^g0;7VX02Cb800`^fV0<[UX03Im:d0c>RK0:>TH03RkJP0c^JL0<_WW@34jYd0`NbM0<[Z
W`2f_g`0c^ZO0<CYW02kf9H0gnjg0?WQb@1C@340l?WX0?ooo@3ooOl0ooco0>?>e`3ooOh0nool0?oo
o`020?ooo@0O0?ono`3oool0oooo0?Sln`3eon`0iOOA0<KPX@3<jZ@0_]R>09FUGP3Eh9`0e>FO0=;/
X`3WnkH0dLR=06eQ9`2NUE`0d>FR0<7OV@38j9l0anFM0<SVWP39iil0b>>L0<CNU`3>iIl0d^VS0=?Z
Y03>hih0bn2K0<[TW@020<_RW00X04=M5P36h9T0g?>]0=?ZY03Fl:T0d^bU0;oFT0004000a=jE0<cV
W@3:i9/0e>jU0<_FW03DgjD0h>^_0=SPY@3Cfj00e=ZN0:FVK01KFR40m?:i0=gKXP3]i[00YYYX0>SL
[01]HC40PWQ5040f0`1VH2`0g]nV06=Y;@2N[6h0eNFV0<SNW@3Om[80dNZV0<cUX@3;iZ40`=jH0<cZ
Y0@0o`0000<0`NFK0?l0003o00000P3o00006`3Al:d0]M>C0<?RW`36iJ40_]jC0<k_X037hiH0enfU
0<kRW@3JkZT0SjAO0<[QV`35g9H0g?>]0<KPV@38hY/0eo6Z0<CNU`3AljT0a^BL0=[LW@2IVe`0_MfD
0<C^XP3AnZh0amjH0=gVY@020?l0001808>3A`1iKSH0FTdF05a?601UFR80IU/S05eH7P1IFAd0_L64
0=WUY@3Ah9l0cnJN0<;LTP3>iY`0h_J^0;c=QP3Fij00e^bS0=C/XP3Ckj@0_n6D0;;GR@3=hI`0gNbY
096UGP3JlJT0_mfC0<k/YP3=ijH0enVe0?cog@1XJ4h0FEA00=;S[@3AijT0a]NQ0=?]/03_f[/0g;J[
0?O=d@1UKDP0jOk30<OCT@3=fZh0oooW0>[Vc@33fkL0bN:k0?Ooh`3/j/<0blbP0>oocP2liil0a^nP
0<3KSP3<kYX0^]f90=OhZ@31f900_m>>0<cHVP3Ji:P0ADlC0:6/L033eYH0h?Fd0<SXW02ni940a>NG
0=GhZ03=lZ@0c?6S2`3oool000X0oooo00H0ooof0?onn@3ooo/0o?_o0?_jo`3_k_H20?ono`0?0?ko
o@3inoH0nooh09ZWW@1bO7<0BT]301dB3014<Rh03`0007YWH`3omoD0h=_H0?OflP3lood0o_om0080
o_oo00D0no_m0?_kn`3oooP0ooof0?konP020?coo`040?olo`3ii>T0oo[j0?oel`80o_ok00/0o_gi
0?oonP3_j>00k>GM0?gkkP3lo?00o_kf0?oonP3no_H0oooj0?onn@020?oon`250?ooo@3oool0o_oo
0?omo`3Sd]X0_[>g01@D4P3goo<0mOOQ0<CKY`3Mnkd0f>NV0>K@W`2RVV/0i>bc0>7aZ034chd0QHME
0=;DY@3HgK@0[l2C0>Gmb@34hil0dO6U0=3/U@3=jI@0c?6S0<_]X02`c840jOng0<OMU03>giP0`mN?
096WGP3GkJ@0`]Z@0=og[@3?iI`0b^2G0:NkL`3Dj:00am^C0>Kl/`2jd8L0c^RN0<kZW`2ngY80b>ZM
0=Sm/02gfHd0e_2V0;S>QP3HhjT00PT00:b^O`1IFbT0UYIP0>3SX03Fg9H0bM>F0=KNXP3AeIX0VimT
079g?`1CG2L0H75409^bQP0/B20000l0000@002@]7@0cNnb0<WV[03AkK<0?eHN0766CP33f9d0`MNG
0<kXX@23WE@0cnFM08J>DP1PJRd0dN6P0=S]ZP2ie8d0dnfS0=CYYP3Ei:T0h>Fm0=7@/P3ooO80oocf
0?okn`3on_l0i]WP0?gcn`3jmoh0moSc06]/I03dmNL0ooof0?ono`3eloH0noke0;c4[@1mRFD0dnFY
0<[QV`3<iY`0d^bR0;kJS`30g940eoJZ0;kNTP3JnZh0_MnB0<[/W`35i9P0en^S0<OUV`34i9T0hn6T
07I=7`3Ng:40g>b[08^OFP1fT4L0c^BK0<CJT@3Ajj40bnNL0<OSV0020<SWV`0>0;cLT02ogi<0eoV/
0<KXV`39kZ00`nFH0=?_Y@32fI<0dnRU0<GNW@3;jjX0Z]fH0;gf[`35nk020?l0000H0<CKT`37i9@0
VIYF0=OTWP39hIL0an>I0<?/WP2lj9T0b>ZN0::]J03?jj00a>ZM0=Ga]03komH0mMc607eZG03fo^l0
o_cm0?oho`3oo?l0j=?L0?ginP3hoOT0oooo0P3oood20?ono`0C0?glo`3jo_l0mOo^0>OheP3;i:X0
bNRT0<_ZWP2X_7@0gNbW0<cPV@2heX`0bN2J0>OSYP29Od@0/J]a0=7ZYP35iYl0b>bR0<W[X@020<g]
Y00b0<cZXP3@jj@0dN^T0<oYXP3=ij00dNRR0=?ZY036gIL0d^NR0=O/Y`3=i9h0TZUS086FD@38gIP0
d>NQ082GD@3VnkH0TJQP0=7`XP3;jY`0do:T0<3OT@3Pk[40dMnR09FQH`0^>000I6ha0=SQXP3OhjH0
W:5Q0=CDUP30`880eM2F085gA03Ygjh0ThUH03H`001oNDD0^;N10=oW[03KiZX0cN:Q0<?LVP3>kJT0
`^6K0<_ZY033hI/0dnjY0<CKU`3Ai:840?l0000O0=kZZ035hI@0o`000?l00036jZ00aNRT0;GHU02c
ei40d_J^0<7VV02oi9@0`N2@0;kBR`3MjJL0HG0]0=?TX03Dj:<0gO6/0<?HT`2DZF@0WK5/0=7UX03B
iZ40`MnG0<gTWP3Ugj<0IV0T0=Wg[`2iiIP0b?NY0<?QV@040?l000170=3OWP3o0000o`000<;3Q`2R
XVH0RXQ=069R9P1eMCT0;Bh007Um@03Djj<0eOBX0<OOU@3Dj:00eNFN0>3]Y`1UMRl0f>jU0<3JT03V
okd0_^FF0=CUWP39e900Oi9@0:2fMP36hZL0b>F]0<GP[@3Lk/@0nooQ0?ooi03elMH0g^jo0<WKZ`3I
i[/0bN2/0>G?]`2_Qgl0eJZa0?7idP3Gl:l0gnfP0=o^]`2=R6X0o_[M0=?/a039h[X0m_oP08V5G`32
`ID0kOo<0;kYX@35l:00c^VL0;cTS03=nYl0a_2J0=?bYP3Ek:@0d^:S0<[HV`3lold0X[1e0;oCU036
g9`0doJV0<?[U@2oiI80`NND0<7XU`2mi9<02`3oool000X0oooo00<0k_co0?Goo`3Zn?P00P3dool0
DP3`ool0k_oo0>_oo`3Fmo`0gooo086UY@33h]80n?oo0?Sfo`3Vd=d0]IVF03PM2P0c6@P0^jRT0?oj
nP3giN<0/jVO0?onn`3fmoT0o?oo0?_oo`3dn?T0oogo0?gfoP3oo?l0ooko0?koo`3ooo@0kMS70?C[
bP3Wk<@0i_c=0>Cfc03]kMD0oo[[0?OXi@3oo?X0mOgb0?Won03looH0oooa0?gojP3an=L0m?cG0>ge
cP3Rj/<0k?KC0>7Zb`3Xl=P0c]Nl0?_nh@3kn>D010000?Ocl03oooH0looO0>coe03Lk[00h>6W06iR
<02LUEh0cn6G0<;RU`37jZP0Y;b20>?V]`2;OU@0jnBf0<o/ZP2nj9`0_NZE0<K`W038ii/0c>^O0<OW
V`33hiL0bn^O0<_ZWP38ii/0bN>I0=7WWP1bQSh20=;WW01^0=;VW`2I[6X0SJ1N0=?TWP3Eiid0e>NH
0>[m[03<hI80f^nT0<oUW03<j9h0b^FD0<SOV@3PmK00g^n[0009002JXfh0c=FN0=cS/020RDX0][al
0;W3SP2YaX`0bNFd0<_K]03?c[T0dM[5000=001WRfD0f__>0<KUZ@3BkKH0014003MG;P2kiJD0a^jW
0<SYVP35jYX0]NVF0;OXUP3Chi`0XYMG07ma<P3EiZ80UZIU0<kSX036gi/0dNnW0=CTW@1IHQl0g^BV
0=gT[P3=ej<0m?oL0?;og`3eon@0ooo/0?3Xe@2kZIl0/JRQ0=7=a03onNl0n_3T0?omk`3oonX0oOSK
0:>YO@3GhJ`0eNFW0<SOU`3Ajj80eNBQ0=KSWP38i9T0b>NI0=GZW`3Ijil0b^JI0<CWU`37jYX0b]nD
0<oQU`3FjjP0d^^Z0<oIY@1SCBH0dMRT0=[^/`3=ijH0b>fZ0;K5SP1QIS00V9UP0=WSWP3GjId0`^J?
0<?^U@2lkYT0]NJE0<ggZ`31iiX0c^nP0<_ZVP38iiL0bnbM0<OYW@36kZP0b?>^0<3b[@1?PSd40?l0
000D0>7]Y@2CW5T0a=VF0<oZY@3Bl:P0anJH0=;_W`3=i9H0UJMM0<KQW03=kZT0g?g40>koeP2l[JP0
c;Nn0?oio`3oo?l0n?Ce0?;ck@3ckn`20?oko`80oooo0P3oo_l0B@3oool0ooom0?Wjm@3joO80o?of
0>?Yg`3>el80e^b^0=WX[@3Jlk40`>6J0<;/X036iY/0h=nO05=;3@2QVel0`mfF0=Kh[P38iYh0`^BJ
0<C]X@2ojih0]nZK0;7TU@2bhi@0ao>V0<WcY`38k:80b^jT0=Ol[P38jYh0e?JZ0<[/W`3?kj<0`^:G
0<SVW03<jil0a^FI0<gYW`3:j9h0bnVS0=Ka[03?hZ00cm^K07^1@`2BVe`0h>^Y0<kJV03KjZL0c]nK
04iO6`23U500g>^X0=GTX@2EYV80[/>00<SNW@3DjJP0cmnP0=o_/03AhJ80a]VG0<kTX`39ij40bNRR
06J1?02;VUT0/;Ih06me=`24RT`0UYYM09nPI02SXfL00P3o0000802;QT`0T99C0;O4OP2BXe`0TZ9K
08ZGDP2>UeP0WJIW096GF@2EVed0SYMF08B=C02R[V`0gNjZ0:>gLP2eaX80dnBP0>?d/03=gYX0GF`Y
09j]JP2AWE/0_/Z80=;MV`3BiZ40c>2K0>?^[03?fYP0Oi=>0<WSW03>jJ80dN^T203o0000@`3<iYd0
dNRP0<_RVP3BjJ40enjV0=C[X`1WNcH0MhI50=OMW`3LhJ40g>NU0=KWX@3:jYl0YLMk06>3>02mdHT0
eN2K0<[OTP39hI<0bn6I0<;FT@3Il:`0b^>O0<gXX`3>j:L0d>F/0?OoeP2RXh@0oooa0:b/XP3on_L0
oock0?o`nP3kc]D0l^GM0?_of`3^m/<0f>bW0<3KV03DhJ`0/[b:0<SJZ03Mkkl0mOoF0?Kmd@3nomL0
Kh570=G[Z`3=hiX0e^JM0=;RV`3AjIl0_nJE0<?eWP31kIP0dNRJ0<3ERP3FmZd0^mZF07F4B`2a[Gh0
eNjZ0<GZW@31hiL0cnnV0;oMU@33hIT02`3oool000X0oooo0580]=3D0>[oo`3Yool0fOob0=GnkP3H
oo@0OJVL07JQV02Nb<L0UL740>?oo`3ZooT0n?go0?gfo`3om?l0ooWd0;n/V`2EPgD03`0003@N8@28
L6`0oo?P0<Vg/`32_KX0mOK`0?_on`3lood0noKm0?oko`3onOl0o?[o0?ooo`3ooo00o>[B0>[W_03J
i;00`MnQ0<OSZ@3lomd0oooX0?okm03ooOD0m?ob0?3nk@3konl0o_oX0?coi03Cg[<0am>S0<oLY`2S
/G`0LX1?096NL01TLDH0bm^^0>?^a03oonP061840=K<c@3oo?T0k?WM0?Gog@37gId0eN6S09N>E`1Q
F1l0j?Vb0<W_XP33lJT0`n6S0>O[^02HPUT0iMNZ0<OQX02jiY/0^^^I0<;]V`3BlJD0bnZN0<g]X@3@
lZD0a^RK0P37ii/0@@3>j9h0goN]0=7UW@2R]f`0g?6T0<_OV03CiZH0T:=S0=WZYP3Bi9X0f^fN07J8
=P3Jji/0fNJN0=3OVP3HkjL0bN:A0<kSX030eI80b]^D02`h2P3:e9l0i>ne0=;JZ`3=eiX0iNj_0;g9
V@2/a980l?oS0?CojP3looH0nOoj004M1`1/SFh0g_oD0<[UXP36fj<000T0072ALP2njk00e?nh0<[]
W@2oiYD0QlE`0<7kY`3IiJ<0[YUR0:N>F03;fYL0eNJR0=W^Z`3<hil0d>^T0=_[XP3LiJ80Be4A0<C<
T03Pkk@0do:g0<7RZ`3<k;X0Tieh0;>`T@3okmP0o_WV0080ooo_0300oo[X0?ook03oo^00fm^e0<G@
V03NkZl0aM^C0=7]X03>jZ00cnBO0=7WW`3>jYl0bnZN0<GPT`34gi80cNVL0<OWV`3:jYh0e_6T0=Wd
Y`36gi/0aN:R0=7X]01[HS/0eN6_0<SQY`31i:80_nf/0<WMZ03SjKT0e=NR09BMG02;Ve80`>6:0=?k
XP38mJ80`_6Q0;WSU`2khIH0d>nQ0<7PT036iY<0b^fM0<W^X032jjD0`^nZ0:SGT`2Ea7h40?l0000G
0<C9QP2KZ6<0c>FS0<SUXP37iIl0c>NH0<;IR@3LlJ80OI970=gf]02mg9T0goo50?Ooh@2eZZP0j=CM
0?ogo`3onol0oOWf0?comP2i^[@0ooKn0?oko`3oool00`3oo_l0;`3nool0o_oj0?com03jo_00n?_b
0?3al`3/l^H0a=FN09JSJ`3DkJ`0`nBO0<;^X@3@l:D0f=BE07a`=P2MU5T0f>n[0;GCS@3=hI`0dnRS
0=3[Y03=jj<0c>jT0=Ch[P3QokT0^=Z@0<SXW`2kfI40aNFL0;oQU037jI`0_^2C0<SZW@3:k9l0`nFH
0<WYW@34i9P0b>RL0<WYW@38iY`0dnb[0;K:R`3Sk[80_<67096GE`3Gh9l0f>>Q0080c]nK01L0e>RS
0=GZY@3IkZT0e^NS0<CET@3<hI`0f?>^0>3n^037hYd0enjZ0;kCT03Cj:D0fo2]0<SOV`2ZaH00S:YT
08BOFP2FYVD0iNn`0<OCT`3>f9T0d=ZK0=STY0020?l0000R0=[TY@3EhJ40dn:O0<_OV03>giP0f^^U
0=KRX03Bfi`0fn6S0=oSYP3VjZd0YJ]]08jGF02FXV80Nhm:0;K;QP3Smk80f>bW0=SYY@3>gi/0_<^8
0=3LVP32cX`0UJ1N0=GPWP3AiJ00f_6[0<oTW`3Smk80W;1[0724?`3Kl:/0amjH0=_f[`80o`0000<0
cNfR0?l0003o00000P3o0000@`3Al:@0`^6E0<KUV@3<jil0a>BH0<c[W`3Hj:L0KWPk096BF03^k[80
h^f[0<WMV038kJ00`NNJ0:C6NP3TlJ/0jnj[0=7XVP3DlJ40dNNN0=W]YP31eHd0g?BX0<gZVP3:iY`0
bN:P0>3[`02EVGP0nOC^0?SblP3oo?d0ooSk0=nY]P2[OX<0g]c?0;ZmWP3MgkP0^<b?0=?aZ`38gI`0
fnfa03e?5@35e9d0fNNb0>7__03EhZd0YkEj09ZXJP3Hij80enNN0>;YYP3SlZd0_N:E0;7VSP34mI`0
`MZ70=odY@2dfH`0`NNN0:2ZM@2YWG<0aMVJ0>;o_03aolX0fOB_0=3YY@3Jkj`02`3oool000X0oooo
0<P09Ee@05bKQP0>DST00Tl[0013700^O5@0K[VB0:c]b`1QUW`0EhA`0>OnmP3alO40oocm0?omn`3i
mn/0o_od0=kXg@3UknL0kNWX0962O@0j7a@0700002X2002CMf`0onkP0?7Ze`1aJe/0oogj0?omo@3o
o_l0o_oo0?;io`3kood0l>WG0=[R^@3Aj;80_^NQ0<7VX@3Fik40dmV]0?Ode@3oon<0i_OE0<SM/P32
eY/0g>j`0:bnPP24Uel0Y;N00=KY/@3>hZL0en^/0=O/Z@37gI@0e>^W0>_ieP3konP00`400>CJf`2i
/;40n_oZ0=3P^@39gj40bmjN0<W?S`2IVeX0fnJQ0=3/XP37kjT0cnb/0=SQZP34^H/0g=VV0=7[ZP37
kJ@0a>^L0<?XV036j9/0b^ZN0<OVVP36hYL0cnVO0<?MT`3SoK<0eo6W0<SPUP38hYP0e>nR07jEA`3>
i9/0g>n_0=7SY@28VED0hO:[0=CVW03IjIh0SimF05IU9027UeT0PiQG092TG02L[W80d=nT0<cKV00>
5P00aLjI0<oHW`3HgZh0TYYN0=KRY03Pkl@0oogK0:6OQP3iond0l?oj0>O`j`1DEDl0RI:10=3XaP3/
ol/0l?oG04IME@1BMfD0PJ^30;[Q/P32hJP0eORn06^RH@22]WH0f>bk0:2HL@1HBal0^;ml0=[PX019
EA<0//5n0=O[YP3Dk:00enNP0=KSWP3Ghj<0h_:c0<3MW@32h:@0^]VN0;73T@2<UFH0e]V^0=7R]@3:
g;@0cMfh0=KQ``3=e[/0a]6_0<?BZ`33gj@0aNJQ0<3VV@36kIX0b>VJ0;gaWP2jl9`0anVM0<[VW02k
k9d0]>VI0<3XW`39iZ<0cnbY0;CYV`2nmJ40Ok9U07:TG@2=/gX072800<_TZ`33jZT0/>BL08c>Q01`
VEd0^MNQ0;kIY03DjZ`0b]nL05Y/803>gY<0d=nJ0=OXY03?j:@0eOF/0;gTT`3?mJ80b>>D0<cXW@3?
kj@0`^NR0<C[Z02Ob8H0c?Fa0<3UW`80o`0001P0bMnD05QR7@2^_GP0d^fZ0<SUXP3<jjD0cnZK0<oV
UP39gY40VJmV0;OATP3?kJd0e?2c0=g]_P2bZ9`0[YnL0?oemP3on_@0ooof096HR03EfL/0ookk0?gg
m`3oood20?koo`0m0?coo`3kooP0m_o/0>Gbf03VlmD0l_oT0?Sok`3honD0h^j`0:NaLP3?hih0b^JL
0<OYW@3Mlj/0g<fD06=<602VT5h0Q8iB08JAE@1lLcP0Fe4F05=42`1[FR80Gd`D065<5@1_GRH0JEdS
0:BJG`2WXfH0f]ZL0=WXX`3ChYd0eNJP0=CXX@3FkJD0c>JM0<o_Y03<kZ80bNjQ0<;WVP3>jJ80b<j@
0;JlP015B`l0X:UZ0=O/Y`3Aj:80e^fW0<;LU@3Bk:D0fO2Z0<CIU03AiJ00dmnM0=WRX@3Hi:80enbW
0<_RW03>hih0b]jI0=c]Z@020?l00009096RGP32ei80e^fW0<;RV@3<mZ`0/^2E0;o]XP2bh9D0_N^P
00@0o`0002D0^>JK0;_ZW02ok9/0^nJG0;cWV02jhiL0cO6[0<[^Z03=kZT0`NFO0;oUW02]eH`0d?B/
0=Wd[@30ei40aMZE0=S]Z03IkZT0b]jI0<7BSP3=gYX0aMJB0:RgM02=W5T0d_:Y0;cPUP3AlJP0cN^S
0=?ZY03Qm[40fnnZ08bPF`1MLB`0NXi90=CXX`3IkjL0bMnF00@0o`000480a^2F0?l0003o0000`]jC
0;WERP37eiH0fN>V09>GFP1PI2L0en>Q0=3TW`3<kZ@0b^bR0;KDRP1OK2L0X:EU0=7XVP3@kId0c>:J
0=O[Y02:X5L0d^ZN0=7^WP3:jId0d>^V0<kLZ`2a]i40m_S]0?oomP2n_Ih0in:l0=6TS@3I]:40fM_6
0?oom01lNV/0g^k10;K@T`3El:40b>6>0=_cY@2P]Vd0NHm70=K[ZP2ldI00^Lj=0?;oa02V^gP0FVhY
0>C_[@3GiZ40`^:G0;o_V@2kii00cNJE0=[aX`2ogi@0^]^D0:njPP1ECAl0e>VX0<[YX`3:iJ00cN:O
0=7PW`2>UeP;0?ooo`002P3oool0V@0hM5/01T4S0;7/c008@QX0DH]R05>@I02Pgk80]oK906jcQ`12
RF40XMJh0>;`h@3oo?40oooc0?ook`3kon`0dnVk0<kU[`37dId0oooL0?oeg01cD4`0B20H058a8P1=
<Ql0onkH0?oag`2JRH40hmC?0?_io03`mod0m?oo0>7em03Zk=l0fNS10<WV/036m:/0`NfP0<CMW030
ciH0YjYm0<O>Y038g:/0dNZ`0<kVVP26WU00Z/9h0=3VY@3AijT0fo6c0<3FUP3=i9`0`MV=0>?lZ031
fi40l?oP0?cok`010@00nnoa0<g3a03oond0dmnk0=CY[P3<hZ40fnbV0=KQW03;dXh0fo6Y0=Kg/P3C
l;00dn2X0;:`O@2h^hH0cnRV0<OXX@38j9`0b^ZN0;cQT`3=kj80_]Z?0<_UV`3IlJL0RYiF0<[PU`3@
j9h0f?:X0=GdZ037hiH0NY5105M]903<hJ00a]ZK04iQ7`3Bhid0d>6J0<oPV@3?gY/0b]RM05MT;P3H
jZh0`]>?05YY<0075000j?Bd0007000b>@H0gNB^0=kQ/P1@EQP0SiUL0>?_b@3oon40YY^50?ook@3P
mnL0eNWP04]<AP2PW940f]c40=3[]P31hK00GWe]01U1:@11JdD0`^Vl0=Kd`02ceY`0^nn_08foP037
gjd0VIie05YG:P3Jij80i?6/065b;02:WUL0b^6I0=KeZ@35fi80gNjX05AP7P27V5@0dNZX0=;_[@3F
m;@0e^jb0<CEWP3LjK<0cN:W0=O[]P3DiKP0dn6n0<KA/`020?Soh`0/0<cU[03@kj`0b^nR0;OQR`31
j9D0ao6O0<7ZV`33jI`0an^Q0<;ZX`3:lZ/0b>fZ0=?f]P3=l;00VLAm07N^F`34nZ`0U/Z20=?f_02d
]XL0enZb0;oOX03;n[@0/_:X0<3Y[`1jWFL0EGY60;WHW03@jZT0eN:M06=]:03Nhj<0i>Z^0<CIV03>
jJ80_NNE0<K]VP39i9L0b^JK0<c/X`34jJ@0a^fZ0<G/Z`3An;D20?l0000F0=7[X@3GkJ80FF@O0;o@
RP38hj00b>NS0=?b[03Ak9l0b=nA0=7VV`24VE@0cnV/0=3/[`3<hZ@0i_;20=;:]`16>C00ooSe0?on
mP3ooo@0Vj:B0?kom080o`0002X0ooom0?koo`3lool0o?oo0?Wom03UlMT0d^700=;T^P3Qm//0k?oK
0?;oe`3QkZT0_LJ30=GVW`3>iY`0b>NK0<WJU03fhJ`0OUl`0:Z>G`1OHRd0Ce@L061A601JCQ@0Ti=E
0<S>SP3MjJL0f>>Q0<W>SP3Ng9l0k>>X05Y94@1[GbD0c=6A0=OMW@3TkJ`0g>RV0<oSWP3DjJ@0cNRQ
0=3^YP31hiT20?l0000C0>KTY`2[Zfl0WZAV0=gXYP38hi`0d>jV0<k/Y03;jJ40d^fV0;kITP1WO3L0
1a/005IQ7`1?F1L0JgHd04=G403CjJ40eNVR0<kOV@040?l000040>3d[@32f900foF/0<;RV@80o`00
0P32iY`40?l0000V0<CXWP3;lJ@0aO2P0<GaXP37lZ<0a_2T0<[bZ`2gg9L0fonk0;gUW`3DokD0aO>X
0;3JSP35hi/0dN^T0=K]Y`3=i9h0`mZD04iS7P3JkZT0c^:M0<_OVP2eaX80EFHR0<gaY`31jYh0a>RN
0<[ZX@3?jJ80_mB?0=GYY039fYH0g^n[0<kOV`19FQH0?Td807F4?`3Gj:870?l0000n0=WcZP3QlK00
am6B0>?YZ`2i_h40c=RH0=W/ZP2feHl0foZd0=KaZP3=fIL0:2`00=;ZWP38iID0enfU0=CXX`2/`WX0
d^bR0<WXV035iIT0cnZS0<cJY`35c:80o_od0?com02<TV@0RX]B0;F>I`3>[Hh0o_oW0>_Zi@3Nfm@0
fnW60<cT/03;ii<0c>V?0;kJQ@35gX/0dn^M0=G/Y03Ek:H0e^fW0;S?R`3Ek:P0b=nK09BPGP3?gYT0
d>jT0;[VT@37lI/0aMj=0<KMS`3OoK<0b>JP0:6/M01CCAd0c>6P0=;bZ@3<ij00d>BO0=WUX`1AEQH;
0?ooo`002P3oool0aP2igjh0a>2_0<kQ/`3KhKD0h^>i0?oofP3LkL00_=V[0<CocP29eYh0;geC07be
YP3VooL0k_od0?Soo@3fn_l0l?Cm0?Woo@3XnL`0h>ji0=7NZ@3[k<X0ooWT0?olk@1kJE/0<aL;040N
501hDdX0TG=[0?C_k03`nod0g_[n02I<C@0@8AT0WKFC0<;W]02fjid0/nVE0;kUU038j9`0b=bG0=3T
W`38hYT0f?NY0=;cVP3=kY<0/]=j0<SXT`3Em:@0aNBF0<g/WP2ogY00dnnR0=7]X03<iZD0f>OD0?_o
mP1UIV00oocm0?ojo039a[L0oooX0<SLY`33h9h0d_BW0<GPT`1dMC<0]l:00<OLV`37gId0e>JX0=?Q
YP2``880iofl0=_b[P3Cij00d^ZP0<O^W`36j9/0dN^Q0=G[XP2mcXL0d]nI0<_KU03Jl:L0_]Z?0<k`
X`31i9@0cNFG0>Kn]035fYT0am^L0=CWY@1CIb80dNFP0=;RX`34diP0dn2b0>7^`P3Pk;X0cM^N0<oI
Y`3Li[80en6T01@H002d^8H0BdhI0:FWN03OhJ80jnnb0=3H[`3lomd0_kZJ09ZDNP3YmN40cn_E08:=
O@1YJ5H0[ZB;0<[W[`3;mkX0S[Z705R7D`2D`HX0NZ=Y0<3UXP2hh9T0boZZ0;3OS`2OaG`0a>6N0=O/
Z`3Hi:80c=VD0=cWX`31c8P0aM2<0<SZWP2lf8d0c^JL0=?TW@1AHQ/0cnFM0=7XX03Onk40`=jD0=3^
Y03@jZ00TjIG0;k9Q036d9@0f]be0<o@/@3oonH0oooS0=WU/`3FiZP0dNFN0=3/V037ii@0f>FM0=GP
V`3Ak:L0aNJQ09RSJ`2^]H40Sj5]08VVL014GbX0KG]60<;VW030i9`0do:_0=GMZP1]DBX0hmVV09JI
H03:gYl0b>n^0<kR[`3Dj[/0c?;30;KMZ03=kk<0eN^Z0<cLW@2DWV80/;^10=c`/`3>ijD0bN^N0<S[
V`37iih0bN^Q0<CXX037l:X0^nJQ06NBC@@0o`0001@0bN6G0;[:P`3?hi`0anBQ0<g/YP37iId0a]jB
0=3UV01kS4H0bmfO0<_S[`36gJT0iNfj0<G8W@2XXXX0mNkN0?omm03oo_P0lO7Y0?oon0@0o`0002P0
o_oo0?coo`3koo/0n?o]0>Ced@3@i[L0bnRX0<c[Z02mgIX0`N2L08bQE02c`7P0d>FH0<gUU`3;ii`0
dn2K0>36U@2hUF/0SFe40?;da@38fJ80anfR0<gcZ03;lJH0a^bQ0<?YWP31ii`0aNNM0<;RV@3Elj/0
a^6J0<[OVP2PY6L0VimR06ab=01dNS`0YJm`0<KBTP3@h9l0fNbZ103o00003035ahH0e^FP0<?IT039
i9d0dnjW0=?aZ@27YEd0TK5X0<OUW@2lei00f?:[0=;VX@80o`0000@0dNNO0<WQU`38h9H0c>:I103o
00000`2neX`0c>BJ0<oSW0040?l0000[0>7QX`38bX/0o`000?l0002KVed0XjEV0:bcL02T]Fh0cn>L
0=CXX`3GijH0ho>e0<GDV@3>h:@0c>:T0<SSX03Bl:X0^mVA0=G`Z@3Ak:D0gORa0<kYXP2S_GH0RZAM
0<;LU@3=i9h0d^VS0=7XXP3Il:X0a^RN0<W]X`3=kJ@0gORa0<?JU03<hI`0ambG0=__ZP36fiH0k?nm
0=K]Y`3HjJ<0enJQ0=WZY0070?l0000n0<?OU@3TmK40b=BB0>7/ZP30bX/0d>2Q0=7VY@3BjjT0bMnO
0<OKW03Ag:00[KEj0=GZY@3=ij00d^FU0=3OY02L[fl0SJAN0<kZW`38j9`0cN^S0=;QZP3Sjk`0l?WX
0?Wom03Pjl40jNfj08eW@02XQf@0fMnm0?oom03oooH0QHmg0>Ced`3<ij@0d^jQ0<;NT@2nfXd0a^:G
0;KER@2>ZUl0_MV>0<k/XP3Mnk40`=jF0=_/Z030ch`0K8<k0<c]WP3>kj00dnjQ0=3XW031fi80dNRT
09jXK02GUV00e>VV0<KQVP32g9D0f>bW09>TH03LijD;0?ooo`002P3oool0aP37i:@0en^^0<WDVP3I
ej@0i^2^0?Caa03BeJP0fNVl0=KodP2cikL0AXMU035dK@3Jooh0dooT0?7om@3Vl?80h>Oa0?Soo`3e
omX0cnNY0<[SX@3<gK00o_o]0?3]i03Ug]H0Gda60656?`0X2P00<1<;0?[ck@3[m?<0//[>041RI01P
LF/0G7AD08RYNP35nJh0_?6O0<[eX`2mhY80d^bR0<oWV`3Ak9/0anND0<GWT`3CmIl0bnfF0<kaU`2n
h8T0d?2K0<;RS`3AkjD0anFO0<WSY03AjKL0h>kO0?[om`1eMg80ooKg0?oko@2h/ZH0ooo/0=KX^03?
k:`0]n6?0=?dX`1>CPh0KgDe0=CSXP3FjJT0c>2Q0=?WZ02S^GP0hoZf0=[_ZP3FiJ00d^RO0<gbY030
h9@0ho^a0;kBRP2U]Fh0f>>N0=OTWP28WUD0cn^P0<;WV@3:kId0e^jP0;K>Q03FjjX0cN:Q0<cOW@1_
Pch0g_:]0=[Z[03BhJX0l_oD0?[ogP3gom40e>:W0=CM[P3AfjL0en6T020T0@3Nh:l0HfHa04]=7P3B
e9D0fn2P09FNK`2d`900hNJm09JJM@3Dg/<0en_@02@c702laZ/0B4h/05Yf?029/740b_Rj0;k[/02n
jK40WlR>0<?ZY`3=mJ`0]^6?0<kjY@2[e8D0d_NZ0<;PV02ia880e]nN0=KHU`3Lg9`0YjIV0<_]X@3D
lZP0`M^A0<oSV`2CY5d0cn>K0=S^Y@2oehd0do:T0<3QTP39jIH0d^J?09RSE`2IXV40Viic0:VYQ`3o
on@0mo_J0=oY]`37dYH0e>>N0<ONS03@jIP0e>6I0=;MV03DjJP0_mNI09fULP2_]HD0Tj5`09:TM011
DB80_<VD0<SSWP3:hil0c>2Q0>WW]`1W@Ad0[9MX09ZEG@25T5@0Tk5c0>;^_P3PkL80anNn09k4T@2m
hjX0c^fZ0=Sb/@3>i:H0Vk1e0<[RYP3Il[40bNFK0<OVVP35jJ40b>bT0<7YXP37lZ/0/]nJ07bYI0H0
o`000180d^RP0=;`ZP3AkjT0_M^C0=7WW02gbGl0Xk9_0=_]/@3OmlL0j?_>0=oR]@3oomP0OGUP0?oo
k@3oo_80oooj0?onn`3/jnT40?l0000X0?ooo@3o0000o`000?Sok03WnM40c>>_0<SVX03>kZD0VK]a
08JXG01lU4H0fN^Q0<SNT`39i9L0anJJ0=c[Z03[dj<0ajIk0:F8H03Ef:/0c>>[0;[]WP2eiYL0`>ZN
0<7ZWP38k:80`>BJ0<3RV039kJ<0b^jT0<O]XP3?kjH0dMZK0=OPX@2g`840Mh1104YD5@2QZf`0c=JG
0=[TY@@0o`0000H0fN>N0=3VW@3<j9d0e^^V0=S_Z@33gIH20?l000030<GUW03GmJd0aN>K00@0o`00
00@0b^JK0=3/X@3;iI/0d>ZP0P3o00001036h9H0dnnT0=7]XP3Ejj840?l0000/09fMG`2:RT`0Kfla
03<c001jNS`0WIeO0;foOP1/Lbl0b]B?0=gVY@3Ni:H0dmRP0:^`NP3Qj[<0c]VQ0<gMWP3CiZ@0fO2Z
0<cVW`38hi`0c>NP0<kYXP2J]6d0cnVR0<7KU03DkZL0bN>L0<kXX@31fi@0Z/En0<gXX@35g9H0d>NQ
0<[OVP3Ll:/0hOJa0<WPVP3GlZ/0_=ZB0<CRVP39giL0e^NQ0=O[Y033fI420?l0000408^WG@3o0000
o`000=3`Y@80o`0003`0dmnM0;C0OP1XMcH0gO2`0<gRX@3AiJH0d^BX0=3OY02HXf/0PHYC0<_PW`3@
iZD0d=nV0>;_^@2CYFT0R9iM0<_VW`36i9X0bNNO0=?RZ`3Xl<40nooa0>[giP3lonH0oOkL07]D=`2R
P6@0hnW50?oojP3oo^/0NXA/0?Ook@3Bj[H0bnFX0<kXY`3CkZ/0d>^V0=7_Y@2P_W@0ZLQl0<k]X@3:
jYh0bNVM0=CXX`3Kk:P0YK]c0=;^X`35hI@0b>>F0=3XW03=hi/0dNFP08jFFP2YZW40bMjK0=KaZP31
fi@0b^6K09:WHP3<gIT;0?ooo`002P3oool0a`26WU00SJ9G0<OHT@3BgY`0i>ja0=[Q[@3KhK40f=ne
0>_edP3Gh/80b>OE03ioP`31oo40ZNNn0>[og`3:i/00`]Zf0=3Z^`3=kYl0d_BP0<GVU@3?i[P0m_ob
0?KooP3iool0n_[j0?7^j@0h;200<B<F00H0000_<Bh0<3/m0=obn03Ag=H0LhM[07FDJP2`hY/0bOb_
0;g/W039m:D0dO6U0<[YV@35hh/0b>RC0<g_Y@37jId0b^fK0<[^U03=l9@0bNZA0<[ZU`39hj80c>F^
0>gof`3eonX0k_[^0?_onP3HgML0oogm0?kdm@34^k@0hMk=0?Wog@3JlkT0_^VG0<[]V`3Cf9H0Mg`l
0>G_/02ib8L0hoRg0<oZY`3@jjP0QiaI0:2dK`3Hij80dNFN0=_m/02ngI40fo6X0=WZX`1=GAH0d]nI
0=OWX02AYeh0P9aA0<KXV`36jIT0cNFG0=3XWP37gYX0cN>R0<oTX@2[`7/0b]nJ0<OIV`3ChJ`0f^K0
0?_oh@3]nLL0f^R]0>C]_P3CgJT0f^BW01<G003Nh:l0g=nZ05mQ<P3Nh:40fn:O0=kX/`1[M3l0bMbU
0<kU/@1XMe00/kZK000=001fT6T0XL>A06Ai?P18GR00^nFU0<K_]@2mhk00QZij01i82@31jZ@0anjM
0<7XU@2`ehP0Qk5U0<CUWP2DVUh0[K5d0>?MW`3Ici80HU8F0<3NUP3El:T0^=:90=[`Z02R]Vh0dnFK
0=CYWP3<hYL0bnZJ0<?VU037ji@0bN:70<gOS@3LjJ<0]Kn;0=WP]P3gomX0o_oO0>?a_03Di:H0e^ZS
0=7XUP3=hY<0f?BY0;[HSP3Hj:X0g>N_0=;V/@36gJT0TYi`0:BWO00Y;`<0d>F]0<[UX03EjZL0f>RZ
0?3/_01`B2@0ilnO0=cCVP3AfId0/L^>0;BkS`3oomd0b^2j08:SM00lHB/0X<^60;kYY02jhJ00an^]
02U72`3<iZL0`]NB0=O^YP33jj@0do^d0;GPV@2hij40LjEN0;[YX@2okZH01P3o00004P3CkZT0c>ZT
0<_VW`35fXl0P9170=CPX03DhjX0mOoO0?3of@3dl//0oooO0;2`UP3oond0ooob0?ono@3dko<0oogo
0?kio`80o`0000<0ooki0?l0003o00000P3o0000103Tm<d0b=nY0<OUW@2B/VH20?l000040=?_XP3L
lZT0cNNM0<g/X080o`0001T0kMVW05i15`1dGC<0e=f^0<OPY`39lZH0a>ZO0<SXW`3;jJ40dN^T0=C^
Y`39h9X0an6J0<gWX03Ak:D0cnVR0=KYY`3Di:<0eNBS0=KRXP2BW5d0G6HW0:6WJ@2EVE`0H6@W0080
o`0000H0e>BK0=O/X@37hiH0c>nO0=SSX@17EQ<40?l000030<W[X@32i9X0o`0000<0o`000P39jId0
2@3:jYh0bNVM0<OYW032hYH0c>bP0<_[W`3<k:00cn^P0:6eKP020?l00080dn:M0300cMbG0=CSWP3B
hI`0eNBO0=CSWP3DhI/0f=nI0:V/J@2>T540UiQN08J4D@2BTV00bLfJ0<oFX03Pjjl0bMRG0<cPV@39
h9X0cnVR0<[TW@38hi`0CVTR0=3[Y03BkJH0`MbE0=?^Y`3;iYl0dnjW08^OFP2T]G40_Lb90>Cc/03H
jJD0cn2L0=ke[`39hi`0`^BJ0<;VW03:l:D0c^VR0<KMU`3HkjT0an6J0<oZX`2:YEh0bn^R0;oOUP36
iYd40?l0000k05IU8P2CXf80`MJE0<oSY027UU/0GV/c06ej@P1iPdh0^<:>0:6cN@2GZFl0ZK>106Yc
A01AGbX0>4`A0=K_[P1OOCL0b^FP0=CS[03Xl<40m_oZ0?SomP3dmn`0oood09Q]I03A[Y/0e]bf0>gb
bP3hmM80_lN_0?Col03Ol]80h_O@0=7W^03:hJd0e^nf0<ORW`38iYh0OYeA0<KUU`37j9T0cNjO0=S^
YP3Bhil0d>6K0:k4N`3<i9X0e_:W0<cVW03Fij40c]ZH08^AE@2UZfl0c^>N0<7KTP3CkjD0Oi]A0<7M
T`3@k:802`3oool000X0oooo03D0b^^@0=SfX02nfXH0d>RL0<OLU`2``XP0a=FO0=KV^@3bom`0nOoV
0>kol@2mm>40?Wi^07:^XP1g[Z/0LJBU03]eG@1j]8/0[n6J0=3h/P3Fm;H0e>730?Kmm@3aool0iOoo
0<3]lP2:^;H073h]024j900G60H020000100000X41d08aPF0<O<]@3Tl]40EGE407NNJ@3>nL40XlnD
0<_b[`37jj40d_>L0=7`X039ij/0bnR^0<WWY`33hYH0a>>E0<STVP37h9l0f^c60>cki0020?Soo`2B
0?coo@3hoOL000800?kon`3ooo/0o?Ca0?K_i`3Wk<`0gNfn0=?hZP2oi9@0b]VD0>S][@1CDA@0hNNW
0<CHT`3?lj/0anVO0<3ET035e940Y;Qa0=_aZ@37giD0dn^Q0<WOUP28WUD0k?nh0=S/Y032eXh0cnNM
0<OQU`2]c800bNFJ0=;]X03:i9/0PYUE0<kTX`3>iIl0b=jE055W7P2aa8@0]<F>08nNM`3fomh0i?>l
092PG`3Zml80`/nI05MS9@093`00g^Fb0<gBW03cm/L0DeLJ028W003MiJT0g>b[08n^J00M>P00b<nL
07ajD@3KmLH0dOS30;;OY03IjJ/0VJAZ0::kT`2nd[H0Df]M0:[:^`28]IP001800=?^]`2meI/0aN:X
0:kGW`1gY6/0W/N506^?C`3Km;00fNZV0;JmN@1CGB00gnn^0<3ETP3BjJ<0dNRR09RYH`2^_WL0c=bE
0>_o]`31gXh0_^J@0<SaU@32j940aNZJ0<g`[P3:k;00hoo=0=Si`P3Pol<0aNZT0<cbY@32jIH0anjO
0<7_Y02hiYd0[ljB08fZLP2=/gX0PjU`04UT;@2S^800cnB/0<GSX`34hYX0cNBP0;C:RP2h`HX0LE//
0=cGW@3Eh9h0bn6P0<;YZ02gaiP0_<:L0?[ohP37g;40aN>_0;k]Z@2BaWh0R;ei09?4P`2jg:00^]BG
09jZK024U5D0PjQU082WIP2:/fl0BGPb0<Of/02mk:@0`>jU0;gSVP3=kjD40?l0000=0=C]Z@3=ij00
dNJQ04MB3@3QjjH0bM6F0?koeP3[n]T0n_oW09nDM016@Ql0o_oS0?Gnh@020?l000060?_dn`3FbMX0
ooWo0?olo`3oo?h0ooch103o00000`3Ylm00g>Vk08nTH@040?l000030=K_[P3:iJ00o`0000<0o`00
01D0JE<T09b;G@3hom@0fNje0?Gg^03@eYH0RYmJ09VcK039jj40VK]a09jeK`2DYF40SIIE0:fYK032
a8D0cNfT0;_IT@3To[L0bN2J0=KWX`3Ei:400P3o0000103>d940o_o10=3IV034hiL20?l000030<[_
X@2_/G80cMJE00@0o`0000<0`^JL0<KZX034kJ400P3o0000403>l:@0c>jR0<[/X033j9/0`NJI0;kT
U`3;lJ@0^]nB0<c^XP3>l:@0`N>G0:W?PP36k9l0`nbN0<?YW038kZ420<C]W`0^0<O]X035jih0`nbN
0<W[WP2ie8D0dnVP0=__ZP3@hZ@0`LnJ0;_9UP3=gZX0b]fU0=ce]02C[VT0S:QN096[I01mU4h0g?>]
0<GLUP3OnK80a^2I0<gXX@38hi`0anFM0<7OU`3=jj<0h^f[0<gBTP1UJb/0Zk5a0<KAS`3JiZ@0dNJQ
0=3ZX`3Lo[@0cO>X0;kWV`30h9L0bnVQ0<o]Y@2edh/0BfTQ0=;`Z03Imjl0a^BL0;cLT`@0o`0003/0
`=B?0<WPW03Ejj/0`mFI030i101_MT<0Mge=09^TM@002@006B@00006003oon<0ZZV=0:>YQ`3<ejl0
e>Be0:VnQ@0Z?`H0en2a0=oQ^@3ammd0fn;B0?omo`3onOl0_X^L0:InO024R6<0emfQ0??d^`3eomd0
mooc0?Woo@3^mNh0nOoa0=o/d03>g[L0dnR_0<3FU@23WE<0a^:E0<_ZVP3<j9/0a=^C0=O[YP3@fiT0
@D`80=GTW`34hYP0dnnU0=COV`38cH/0Gf@T0<SCT@36g9@0b>:I0:G1M`2lg940eoV]0=Wo/P0;0?oo
o`002P3oool0H@36jY<0aNFB0<kYVP2kdHT0cN2P09:SK02M[g/0m_oI0=cgbP33h[H0_NG00<gmh`0m
L6404dDl04AhMP1>QX<001P204f>K030m/80]Mn]0;gM[P39f;/0n?of0>Woo`3Vool0AGb1000J6@1H
Pg8000`0014@000;0000GD=601H00P0M20D0e]6m0=KI_P33fKD0GWYD0;KO]@31j[h0cOBk0;[OW02o
gh`0a^:E0<_W[03:iJh0b^J/0=;/[@3@j:X0dnR`0=?V^03Vm=/0n?oe0?_oo`3lool0ooko0?GglP00
0P00j_7Y0?kon`3ooOd0oogj0=cLa039e:X0^]R>0=GhZ03BjJ40bm6A05mK7P3Ff9T0h_Ja0<S^X`2m
hIL0d>FP0<cMV@2DZf<0e^fU0<kOV03Ciil0eN^R08JNE03<i9X0b>2F0=_eZ`3:i9X0d>ZP08^UF`37
hIL0d>ZP0=C^Y@2AZ6@0g?>_0<KMU@3<hYL0e^bQ07nBD02CYF/00P3ioml0I03=gj<0bMZF0=3OYP3H
iJd0e^:R02/c2P3KhZl0injh0<oBX`3HgZ00Zje/06i_=@37fYP0a=nH0=CYY03Iej@0eMJZ0>kof02k
g:L0d_6h0<oOX@3DhJ/0D5m20:jfY`1GJF/0j_oo0:CE`P004@00d>Jh0<_KZP3CjkT0`>Je0;GV[`2h
lJd0KZ=O0<3XXP2kg9D0cnNM04Y94@3KiJP0enNV0=;[Y`38hId0SYmK092OFP3BgiX0cMjG0<OOU@3=
l:00_^J@0;kXUP2niiP0a>bV0;kUY033jZ/0_nJW0<?[Y@2niYd0_nRJ0;oZVP32kIh0b?2Y0<;YYP09
;`00^=jU05enB@39ik40c>V_0<KTYP3@kZh0b>6M0<_QV@3FjJL0fnn`0=OUZP1TDR00d]NG0=k_Z`34
hY`0e?fi0?Oof03Jg[T0oooR0=CS^038gj/0`>NT0;_VX@2]fiX0`Nf^0<_Z/@3Snl40d^2S0=SXZP34
i:D0aNNZ05=g=`33k:P0a_6/0<3ZXP35kJH20?l000030=7WW`3o0000o`000080o`0000/0cnBO0=GV
XP1IH1`0gnBQ0>?V[`3Tj[h0kocP0?cojP1ZGcl0DThY0=KQ]`040?l000060;JU]@3McMX0oo_o0?og
m@3oo_X0oogk0P3o0000103ooo40fn320=_S^P2:V5/40?l000030?Ood`3;hjD0o`0000<0o`0000L0
f/BE0?od``3<gjL0c^JZ0=KHV@3GgId0c]nK0080o`0000/0c>ZR0;[AR`3<gIT0g^VW08b<CP1FG1`0
c^jU0>3n]P2`bh@0goVb0<oTW`040?l000030=3IV03GiZ40o`0000<0o`0000<0V9iN0=gXYP3Ghj40
0P3o0000A`3Ak:D0c>jT0<_]X`2ohiT0aNVO0<CVW036i9X0anFK0<KVV`38jYh0bNjQ0<caY033j9/0
^mfA0=GeZP2heX`0b^ZO0;cRU@37l:80`nbN0<3YV`33k9h0`^^M0<G^X036kj40_nRJ0<3YV`32jIX0
dOBR0<OVVP3;jJ40a=jM0=_b^P3<hjd0c^F_0=G^]@2geY<0^mbE0;gMTP3Ajj@0dNRR0<ONV039h9X0
_MB>0=_e[P3@jj@0b^FN0=7/Y@3?kJD0d>jV0=ORX03Bf9P0e]bL05iT901JHb80CUTG08RIE@3>hih0
]=::0;gMU030hYP0c>ZR0;kITP3FlJX0c>NP08fXH@3=j:40`M^D0<SRV`3Ajj@0f_B]0080o`0003`0
QiA?0=of[P3:hil0aM^K0=KX[03?eZ<010H000@5003PjKh0;CX>0=ON_0011000k^WE0?ohj0030`00
GfI50<oK/`33eJ<0EFHb0=kU^`3MgKL0fMbo0=7D_`3km?/0ooSo0<RCY@32V9T0/;6?0<c@U@3/jk80
iNo:0?Ook@3jooh0o_oo0?com03honP0fNG10<gNY`3Jkjh0U:aR0<gXV`3BkJ00cNNM0<[TW@3MlJ`0
en2O06Y_;@3<fI@0eO>Y0<_WW@3Ki:40k>b/09FGF03>fYP0i_bd0;kES@29XeX0a^JK0<3RUP2fg8l;
0?ooo`002P3oool0aP30fJ80enbd0?Woe03Dh:h0c]RV0=;N[03Ci;00NY5I0;cNX@2khZ<0]mjW0=gg
e03bon`0k?oT0>kog`3;m;X0`o_:06JROP31nnl0eooo0933/P2B_iP0^>Je0;c[b`1=O6`0hooo0>;o
o`3bo_X0o_of0>CKbP3oo?<0oo?`0?obm03?/ZX0500003LT5@2FUXX0j?CZ06j<PP1lX980g?oR0=Ch
b033hI/0b>BI0<[VV`37h9l0dnR`0?SoiP3honl0nook0?coo`3nool0oooo0?ooo@3oo_d0ooCh0?Sg
l`1OIe`0k?g]0?Gon03oo_l0iMcO0?3Xf`2JVG/0gNf^0<gYW`36k:40f>BR06QN8@2`[6d0cMZE0<?Y
W030iYT0fo6Y0<gQW03<kZ@0g?Z`08ZAC@2AW5L0enfT061j<03?kj<0anbN0<GWVP2nfXl0fo>Y08bM
EP3@hIX0d>ZQ0<WSW02P^GD0Xkef0=C/X03EkIl0c>FD0=CZXP2ba8H0iOG80>goc`3Cj:D0Q9]=0=OZ
ZP3:gId0d>6K018M002ob9<0@T/B07=iB@3Tk;00eMVL0;>]N`1EFR00`<240>OPZ@3/j;P0`/ZK0>3W
_P3oomd0jnK00=k[]P38eZ<0moGL0?omm03^n?l0hoko01]A@@1;OUl0OhmN06ea?P3AgZT0cnfi0;[R
[@20[gP0eOo70;gQX@33i9l0`N2D0>K>X01JE200h^Z_0<OPW`36h9l0e^RZ0=;NX03FgZ80d=RL0=cV
Y`3=h9h0d^FU0<[MW@3Hjj/0enb[0<[OW03GjjH0eNVT0<_OV03PlJ/0cn2J0=3TW`3;i:<0/kb70?3g
a021Tf40goG40821E@30_I00gNFZ0<gNVP3?giP0gMRF0>[PXP2TVf80`/270>CU[028LCl0i^RW0<oO
V035fYL0f_Rh0>?P]`2eZXX0gmZj0=3CZ02b]X@0UimT0<7;S`3Bg:L0RiMU0=3R/034f:<0Ykn309N/
L@2:VfD0B5/T08FJH@3Ajj`0e_2a0<GNW0@0o`0000<0_L:00?l0003o00000P3o00002P38eI00EeXG
0>GTY03IeJD0g]bf0?cok@3non/0Uh]Q0=kN[03?hjH40?l0000=0?gXl@3fhNP0fLc40?okl@3ooOP0
oocm0?oko`3on_l0oogg0?ojjP3oonH0OWmC0:NYM`020?l000040=?O^@3ooml0dmb_0=OU/P80o`00
00L0o^Jf0:24E@3;]H@0c=jP0<GRW`3Ilj`0S:5L00@0o`0000D0dn:O0<kRW@3BjJ<0bn^R0;kNU@02
0?l000030:BkL`3>j9l0e_BZ00@0o`0000<0bNjQ0<K[WP3o00000`3o00006`3=i9h0aMnH0<?MUP3<
ij00`MbE0<COV02abh@0U:]U08NKEP2Y^WH0f^VV096PG@2cah80a=VD0<kXX@3@jZ<0d>^T0<GOV02]
ah00SjAO0::fL@3QmK00c^RO0<cXW@39j9`0bnNL0<gYWP020<_ZWP1]0<cXW@3;ii`0dO2T0<SYVP30
hi40`^NI0<GWW@3:j:P0dnbe09^bOP2ab9@0ho[40;[DT`3Jn;80cn^P0=kc[P36fYD0am^F0<CHT`3>
hih0c^FO0<kXX@3KmJh0c>NP0<kYXP3:iIh0bN2J0=GZY@3:fiL0e>>P0=_TX`36chh0c]BD0>O][@2E
WUd0Phi<0=kYY`34eiD0h_Nd05md<@1iS4X0c=bK0=3OWP3GhJ80bmFF09JOH01mPdD0^l630=kWY03B
giT0f_B[0=cj]03;i:<0`]BJ06]Z?02g/XX0_KVC0=WQ^03DhkX0EeU4018<003GbLH0ooKf0?O^i`2n
_:d0M7QO0?3leP3Xll/07b0006QSAP2>S6D0i>:k0?oojP2YUhd0_XJ90?o^j03oo^40[:]o0=[GZP3H
i;H0eNRk0:2RU@3oo_P0ookZ0?cmgP3AeZd0e=nS0<SDU02_`7X0b]jG0=7VY@3EijT0d^^W0=7UX02l
`H40^kMj0=gSX`31hIP0e?:Z0<G:R01QGAh0f]^I0>3aZP2R]Vh0S:1H0=7WWP3>j9h0b^BJ0<kZW`0;
0?ooo`002P3oool0aP3Ghkl0e^Jo0?Cog03=i;H0an6a0<[Q[@3@iJd0OHaE0<[=U03Heih0g=^R0>Sf
^`3konP0o_oa0?7eiP3Jild0iooY0:?=]`2gk_40[>W^035aL@0gOE/0[OFe0;[ea@00;0l0jO_o0>WZ
o03ol_/0ooWh0?oik03ooo<0o_oh0?cnn@3Pa[T0OUe>04P/8@0U7AX0iNWZ0;;<c@1>LFd0^n?90;[O
]P35hZ00eO6V0<cXT`3;hYX0d^F]0?Wol@3`nO@0n_co0?cko`3ln_l0o_co0?oom03oooH0oo[o0?on
n@001000l_of0?ConP3oool0ooco0>cOeP3=ajd0f^BW0=3ZX@3Eok@0amJA089f>P1[HbD0^<Eo0<W`
X@3BnJX0bn6I0=?WX02Vc840a^RL06]^:`1TJbL0bn6H07nKD035iiX0`>VJ0=Gl[@3AkJ80b^:H08ND
CP2jbX<0eo>Y0<gWX02N]g<0MHm80=7YV`3=iYD0`MZ90<_QV03Jkjh0n?oJ0>;d`P3<hi/0^]>20<OL
V@3IkZ/0eNJO00/G003Fh:/0TIaR065Y>P3Fh:<0h>VZ0=cFYP2=Ndd0I50N0>WMZ@3=eJ80bLbQ0=_@
/P3oo^40oooO0>O]`@3Lh[@0n_;>0?K[f@3bn_d0jOoo01iJ@029`9H0dn:W0<G7R03:eI<0d^n]0<KU
Z@2MZWl0`/jP09NLIP3/l;D0gn6P0?;BZ@1KDB00P8=<0<WQX`3Ekk00g>jb0<gHW03NhjT0f]fT0<_C
U`3Fh:@0kO2k0>WW]03ViJd0emRL0>7SY03MgY`0b<V70>[YZ03UhJ80em>D0=gHWP35_h/0e=>S0<c9
W02n]Hh0f/jX0;N[P`3UfZd0hM:K0?CQYP3^g9`0k=VG0>g@V01RAQ@0i]:O0>?FXP27HSD0fM6C0=cQ
WP3SjJ/0d=nT0>GA[P2oYXP0Ui5_0;RgR`35`I40VI1I0=C9T`3Zh[<0TXiQ07f6E`3Kk;P0`MnS0<oY
[02j`Y40Q8iJ0>Kc_@32e9P0e^R/0<WIVP@0o`0000<0iNBT0?l0003o00000P3o00002`38dhl0GE`K
0=K@TP3Ugjl0jNG00?cok@3oon`0ZYma0<g>U@38giT0`mjK0080o`0000L0n_7X0?ohn`3okNl0/jFH
0<o6]`3kl>`0nnoa0080oo[o01@0oo_j0?cdj@3oonX0QH5K0:FRM`3Sh;<0h>6g0>3Ua@3oon<0g^2i
0=kW^P2GYVl0LG@o0?3DY@2DM4D0^J9`0=WYZP3HkJX0_;io09FJFP@0o`0000@0go>^0=OXY03ChYl0
h^j/103o00000`36gY@0bn^O0<K[W@020?l000040;g^W02dj9D0boNX0>;i/`80o`0001h0T9UH0<W[
X@35iid0`>:H0=3`Y`3<jZ80eO2Y09R]J02M[VX0WjQW09bRHP2DVET0SYMH09JRHP2BXF00O8m=07B9
AP1bQd@0TjQU0:NjN03>gI`0hNf]0<oNV`3>j9l0b>NK0<SXW03;jYh0bNRL0<SXW03:jYh20<OVVP0b
0<o_X`2oh940c^fM0<STV@35giP0gO>e0<;BX@1ZMdT0gNVi0<oKZ@3IjJ/0d>>Q0<gQV@31eI00iOJb
0=GYY03BiZ40cnBO0=O^Z033fY@0cNNP0<kXX@3GlJX0a^6J0=Oe[@2ccXL0f_6[0=GYY03PjjT0h^RX
0=kPX@2>SU00P8120=WIV`37ahT0f>BT0<oRX00eA@@0^LR70=kXZ@3?f9T0h>BW096BEP1SHbL0_[b1
0=oJX03NiJ80aM:<0<KPU`2bdH/20?l0000g014>002PV740n_G?0=CL]@3?gkP0ZjVJ01lF4@2gYjP0
onkd0?;Wi@2m^Jh0LG=N0>gge02_]i8071/003@]4`1JEB/0knfm0>SN^P3We[X0olg40?obiP3oonH0
dm2_0=;>Z@3=fJT0dNF`09FGP@3ckMl0o_[O0??cc@3JgJh0fnBU0:jiM@3Kj:<0f>NT0=3RYP3FiJh0
d>VW0<OKUP2OXF80hmfS0=?GVP3=k:H0^MV@0825@`1jM3H0i^NU0;?4O@1dR400Yk]c0>Sl]03HkZD0
d^RO0=3VW@0;0?ooo`002P3oool0aP3Yf=00ooga0?onk`3Nf<80ooWO0=C@[@2m^980GeP^0;J[O@3D
b9H0f/BC0:N2F03f`Z`0k[BV0=^RU`1cA380gLNR0?[]``3PfJl0gLnZ0?[Va@3Kg;@0C8QB04QiF@1d
QG/0ooKo0??cn`3om_X0oo?c0>SEa`3glnL0oooh0>k;dP2UJF/0onkZ0>Ji/`0k8Q/03`000>WAd@3o
moX02`0003hk<P32eL40dNC60=CL[@3Dd:<0j^:m0?okjP3omo00ooCh0?o[lP3oj>h0oo;f0?o/k03o
m_40ooo_0?K`hP3QfLh0oocd0?oin03ojnd0ooCf0?odj@3olml0ZXaX0>_E[03Rgk80hLjT0?oJ]02_
PEd0Ne@[0>OAX03VfJD0fmRQ0=cKX`37bY<0i^^c0<[DU@3Chj80b^>O0<oZY@33fYH0en6R0>W]/03Q
hJ40gNBQ0=OXX@2HYF00dLRA0>kU[P3If:00em^P0=GOX03Skjl0a=2@0=OSY@3FhJD0f>6Z0=3KX@3?
gIl0d=bL09bPI@3DdiX0fM:K03/^0@1PERD0F50O06UQ<P1GE240FU@P0:BOI`2:VUT0TY=G061G7P3T
f:H0i>:a0=WK/`3noml0iOG@0>;`c`3oon<0OEPk0=6fV@0`:`d08B@504A<9`1<C2H0E3`F08M[A01I
AQ`0F4dP04Q65P1<Dad0F5`Y00H4001XI3l0F58b0<2^R01GCb00JFPb05]I7P1[Eb80Y9QT09fGH`1U
GRX0IDHH05]54`3;kJ<0b>VT0<oXY03Cj:<0cn2I0<gRU`3:iiL0eo>V0<GKTP3^nKL0c<fA05aI8P3K
jjd0e>Zl08fOM`3Gg[80D5XN0<SRV03=kjD0_^:R0<g[Z`3Ek:H0eNNA0=CUU@39di@0gnfb0<S8U01d
AA/0hm6A0=?DSP27Re00DdlP0=W:/`2h[hP0];MV096HI@2FWWT0E5T`06MT@`1MCRl0GDd[0=S9Z03K
ckT0GeTU04i?5P19FCD0C5HT05QL8@1A@`00HTT907138P<0o`0000<0O5D^09MhB@1ZH2D00P3o0000
2P1WFR<0FDXA05i94P1iHRh0IddL0>?8V`2HOeH0ESdD06U=7P1QAAD20?l0000P05Xc202WMUD0_XUZ
060X3`2LI4T0VFQ8079:9P1RD2P0IE<[07EN?02;M580Fd<O09MoF@38/HP0RgI;099oE02EQ5H0i]6V
0:EoF`2/PEl0ZhYQ06aF9`1RGbP0RX1;0;J?I01jBR@0IcLC05U25P1[FbX0H4TC05i74@2KPT`20?l0
000506IL8@1PEa`0GE4G061?5`1_E1l0103o0000G01XDR00I4hL065=6P2CPdl0Ge8M08b3C01NEb00
Ie`T09Z0C@2<LSl0JdlM07EG9@1UCQ`0WXAC06A8601eEBH0/8iP060n4022H380]iEW06];702SQ5D0
Wh1A06i>7`20HC<0K50P06iH9P2<N4H0FDPD06=C7`2AOdd0IDlN05]54`1UCad0HdlL06eF902JOTh0
JdTK07iC:02EJSl0GcH:06Q35P2CO4X0GDTF06=F7`1TDa/0AcH009V6CP1TD1d0Gd`R06YF<@1LC2/0
G4h[085kB`1PGbH0GV4N055F5P1OHbH0GV@V09jTIP1MIRL0DEXK04aB501TJR`0VY]O06EU:@1?Ca<0
EfHU04iM701UH2H0E4L@065@6P1QDQ/0M6hd05IA5`1ZHBP0]JQa08Ed?P1TB1P0Nel_061:602`W6T0
IT`K07AE9P1iDbH0M4hQ07eK;@1/FbL0FE0I04E;3@39chl0NGXn103o0000=P24O4/0GUHU05Q@8@2B
RU/0/GIh08PkB`2kL7@0LBLT0<N1O`2`KVl0JRT_0:Q_MP1g@4D0V6QL0;Z;M`1^BRH0KDXR09EYAP1S
<1<0JRHI08e:@P2]M6d0M4Dk0=jgYP1RCbL0FThL08b9GP2ITFX0bJn<0<^aS01[FRl0PXAB08J;E@1X
ERP0S7A805a:701WHBl0QHA<05eF7`1TE200Jd`M060n4@1T@QD0JdHJ07987P1^Aa`0^Ie]09^7E02A
LT@0YhEH06E35@2GMDD0WWY806Y64P/0oooo000:0?ooo`350<bh]`3Zem<0jMSA0=;2/`3^gl`0/ZN;
0;2UQ@2JT6`0clRL0>CM[`3_g[<0]I5a0;=nK03MXiD0dYb@068d901_FC@0aKJ;07MZ=P1nISH0TW56
09N5G`0aHSD002PA045@B`38^<D0fN?U0<ng]`3<YZD0I4a20:n]X03Fe/h0h[;00>>MY@3[/K00j[ni
08mgK@0W3`D0>18A0>>k_02gVI/0SGmo00060019GTl0R95f06iZC@21NF80onkP0=_0^@31Wj00onCX
0;R?U`3M];`0omWQ09]kO03>b;P0d<Rm06MJDP3KaLL0/INJ0<n//03V`/80V7IZ0>O6/`1XBbd0Idl]
04dn5@2/VFl0Q6Tn09f0E023ISX0MEd]04lk2@2<PTl0If0/09NAH@20ODX0^LF50:6dM01`RDL0ZlB2
09:RH`2l^h80d<Z@0<_2Q`2d]7@0V:aT086>B@2FQ580_:mk0;^fO`2a/WT0WjM/096KG`3;eIT0dm^P
0=[OY@3LgjH0gnBZ0=GSY@3Rk;00Y:=[06]V;`3/gZd0:AT00>OIZP3[gjl0g=:Q0=cFY035_h/0ZZY/
0=W]Z03?fYP0inNY08MgA02g/Gl0cMVY0>gnd@3ZomH0fnk>0?ooi03of;`0ooWJ0?GW`P3Wg[L0jN6j
0>3G/03ijLD0jMNc06eM>@2UUg@0h=V]0=_VZP3Rjk@0@48K0:^[R@2WXhX0i=be0>_Y^03KfjD0F58F
07QJ9P3RdId0h]^U0=7;U`2`RUd0K58O0;SSU02lji/0a^^N0<cZX03?iid0c^ZO0<;YV02ji980cnnT
0;c@R`3[lK<0cm2F0<?RW01WR540dN^l0:FgP`2H[f/0c_RT0;GYU`2mm;<0Y]JH0<Sa[`3?k9P0T;9L
0=Sb/@35gZD0gnNf08AG;P3LcXl0jO2Z0=kX]03NfkP0blZe0=3GZ`3Nj8l0gn^k0;k;[@2GYXD0RIAf
0<71W@3RgK<0j=jj0=;6]P3NfK<0eMb`07VHN01OMdL0dMnQ0>KJSP3jgi`0103o00000`22H3/0[YIV
0=7;T@020?l000030?7V[P3^hj/0YIIO0080o`0000@0nNB_0?OP[03^e:40V7Q9103o00009`3hdZD0
m<^O0?[AY@3me:P0onbo0>G5UP3FbI80hMBM0=[=V02cYW40VhiI0:nRKP3Ic9P0kN2/0>KHY`3Qdj80
i<nP0?33VP3oeJd0TF`o07EK:03KeY`0i=^T0?7:W`23Dbd0dj5n07=E;`3:]HP0ooJn0>3=U@3XciT0
n>6[089a>@36_840m^fb0>cRY`3SdYX0Rg0k08]a?P020?l0001M09=mC024K3`0[I9S095eAP35ZW/0
[YIV0<JbP02OSE/0Y9=O06mJ9@2=N4<0[IQS0;RSKP2`UFH0ZHeN0;ZKK@2^S5l0XWeA0;bJK@2VQEP0
a:Eg09j3E02cWF`0ZI=R0;VJK037Z7X0]Y]/0;JRL03<^XP0YiMT0=G8U03eiK80XY1N0=W5T`2XTV40
ZY9R0:b=G`3R_I40Sf@j09eY@P3_^I<0/7mG0<FHK`2iVV`0LUXZ0<^gQ02/UF40k]FO0>oFX03Zd9d0
j]6X0>WA[@19=QH0]JF40>KP/03OgZH0d]FB0=OIVP3[k;00cM6D0=cPX`3;dI<0i>Z/0>7RYP3ViZX0
ZJAZ0:NQI`2LTeX0^L>40<gIV@3aj:l0k=RS0?gV/P2:MT40d<^A0:VYK@2IU5X0^[5h0:RGH@2bTV<0
DS830;>MJ`3/f:D0XhUH06U:6`31UV/0Z7mC0:n=G`2m/W`0gMbS0<3:R`3NijP0iN>X00@0o`0003H0
l^ff0=_HX@3Of:@0ooG30?oZjP3YWj`0onWZ0?oZi03oj>80onGV0?oWk03okO@0on7U0>g3/`3jeKX0
gknF0<NVN`3ogkT0k[fL0>2UT`3^/ZL0bXf80?oZh03omN@0E44I0:^OK@3MgJT0bLJC0?[M/`3RaId0
@bh30=oV/P3FgJT0jmBX0?CEZ@3La9@0in2Z07]h@@3Qg:D0hMFQ0>;7V03]bih0`9A]07mB:`2VNU<0
/haS0>_@X`3F`940ajZ00<Z[O`2/SEl0d[:109]kB02[S5H;0?ooo`002P3oool0a@3oo_/0ookj0?cg
l@3gmNP0ooo]0>WYd@3dmmX0oooS0=WP]`3Cf[00o_oO0?Soi`31aKH0f=S>0?omo@3lo?X0mOok0>Gl
k03`oo<0j?_U0=gZeP3Wlml0d>cC0;[WdP0_I5@0c?oi0>[oo`3oo?/0ooGf0?oMg`3kooP0l_oi0?oa
o03oe=X0ooGc0?o[iP3oo_<0ooG/00l0000j8240ooSj0?olnP3Wn>h0<T`o05ahK03^ool0j_ok0?;o
o`3hool0nooo0?Sjo`3in?l0lO3n0>[Ym`3ooOl0oo[o0?ogo`3HbmD0ooKo0?obo`3on_l0n_Cd0?oo
l`3en^@0j_SE0=SS^02;TTh0f_2W0<OgX`2hk9L0[N6<0<o_X`3KkjL0g]nS07]j@@1iO4D0embR0>kg
]03OjjT0cn>N0=S/Y`3BhIh0`l>50>[VZ@3Qfil0fM^J0=_/YP3@hId0WZAV0=SPY03Vl[@0f>NV0=[Z
Z@1TLS@0R9AD05]Q8`27R4h0PGY30:RXK02@Yf40VZe[0:6[K02=TeD0W9eS09nNI@2TYF`0TIIL07Em
A03@fj40d>BU0;O<Q`2GR4l0i>VY0=;SW`33c8d0R8=<0=7HY03komD0i>g00>coeP37eZ/0^ZR005e7
8P1SBbL0GddW0;O0T`32g:`0HhmJ055mB02fdJ@0X;:809f]P02AXV/0f^Rc0=WR/`3JhKD0QhaT06Ea
@`3=h:T0c^>X0<kNW@3HciH0_;Mm0=?GW03Bg9l0bkZ407Y`=@30ji`0aNjO0<WYX03;i:80f>Z^0=O]
[@33hYh0eOJ_0<?OU@2odhh0KWTg0<_GU@38mJ00dO6U0<cPV@2R/W40c^bV076SG01aY680T;J302i;
7@1:ICP0SZa`0:S8M@3Bj[X0PYUl0=?Ma01iE3L0f]^R0<OPY`0WBC0093`^08Z]S013JCH0c^nX0;_=
Y`1mS7L0c>WG0<7Zc02diJ<0W<Yo0=on`P3]onX0Njn]0;C`kP1GVW/0Y=na0<Wm_`3BkZ<0c]fJ00@0
o`0000<0i>ne08BDD`3o00000`3o00000`36gIT0o`000?l000020?l000030=o_[P3DgYl0VY=L00@0
o`0008L0b^^V0<SYY030hI`0eOB`0;_FT`3@jJL0fn^Z0=GXYP39h9`0e>^W0<oZY@3Ck:P0cNJR0<SO
V`3AiZ<0`M6@0<OAU03ci[40WHUF0;BYL@3Qgj80f>NT0=KQW`3bgZ/0XX=E0;BCJ01^I3<0i>N`0=3T
W`3Ci:00WZUW08VED`3Pm:l0aMnH0<GPV@38hY/0g_:]0;S1P02MYVD0g>b[0<_IV`3Rk:l0[kQi0<C:
S03Bf9`0hn^_0=[TY@2_^g/0UjEW092SH@30hIX0`N:K0=[i/`34hid0do:^0<WVX`37iIl0JH@o08BM
F`2L]G40d>^V0;gJU`3<kJP0^mnG0<?TW@3?j:H0dNNV0<gVXP3:j:80bNRT0<c[Y@34hid0`=fJ0=;]
ZP37h9`0e^VW0=;NX03@f9`0XJMY0:JZK`2@TEL0XZ=W09nUI`2AVEd0UJ=U0<gPWP2odY00fMnO0820
@02YZ6P0ViUL0<c:U`3[j;/0UiQ`0=KK/P3>fJ40konn0=7SV@3KiZ80e]nP0=gWZ03NjZX0c]ZJ0;k:
RP3KiJH0ZK9c0>CXZ`3Vij/0e]JJ0;?8P`3Mm:h0bmBC0>k^/02MVeh0inVZ0<WHU@3Cij80i?Fa0=OR
X03Mhj<0MG/m0=cVZ@3Di:D0c=nO0=CPXP1@F1`0c/bC0=gHX03Wj:h0e^^Z0;oLV@3Fm:`0b^6I0=_Z
Y`3AgI/00P3o0000203MijX0c=RJ0=OUY`3Hi:H0bmFI0=;C]03oonl0moC_0P3oo_l0;@3em_00o?oa
0>gmeP3`omL0lOoH0=gnb@3JlJd0bmbF04A:2P1lNd80F4`R0:ZKNP2n/9H0oooX07]nH@3@i;<0b>6X
0=?VY031bXT0O7<h0=gDV@3YjJ/0c>>M0=;/Y@3HfYT0hmfO0:^ZJP2LZF<0cnJR0<SOV`3Un;H0gn^]
0;2jO@1SIb`0TIEJ0=WLX`3LhJL0c=NK09:MH@3;iJH0bNVV0=?d[`2^d8H0YLMk0=3bY@0;0?ooo`00
2P3oool0=03lo?X0ooom0?Sjm@3loo@0o_od0>3Xd`3eonH0mooT0>;]b`38e;00iO?@0>3ce@3Zln80
ko;W0?_em`3ooOl0inc`0?Ooo`3_o_T0moom0?Kon03kooP0`Ljm0:OMaP1ja:d0;h9`07fbZP3knOX0
onK/0?o_mP3eo?@0l_om0?odo03ok_D0ooOf0?ofl03kno<0oooh0<2a[P0n:R/09aDE07adL@3dooL0
lOok07>>Q@33hMT0fO;^0>goo`3`ool0joGo0?Ooo`3/m_l20?Ooo`2@0>c`n@3on?l0ooCo0=k=g`3o
n?l0oo?o0?ojo`3oo?l0n_[b0?oom03Li<d0g>S20<WRT@1aTCh0]>270;[[T037nYh0`NjI0<;YUP39
h9P0d^>O061V:P1SIb`0`lZ60=oZYP3@hI/0b=VC0=o/Y`3]kJd0VYIG051?3`2VZ6T0c]nK0<oSWP29
WEP0bmjL0=3WX`33fY@0dnZT0=gb[`3Rljl0c=:B0=_KW`2WWVD0Xj=U0<_WW@3CjZ@0cMjJ0=STXP3:
di@0cMJG0=OQY03Agj40c]jP0=?WZ03BkJX0dnbX0<c6S02ZXFH0loVi0<_TX03IhJD0MW0l0>3L[03D
g:T0cN6^0=OY]`3DeZD0hmnb0<o8W03Nfk00738105f4C`2Ug:D0^>nh0=?jb`3Gm<P0`MR/0:RlQ`2:
W6P0:3H307=oC@2_^HL0D6Lc0<gY[`2mg:00`=fK0>3TZ@2NWf<0g>FV0=S[Z@3Vh:@0XImR0<?^W`34
jI/0c>NT0=?YZ`3aolh0m_oC0<KPX`3@kJ/0b>:K05a`:`2<V5H0f^f[0;?XV03;jYh0h?2W0=?OW`37
ijH0FY5@0:OKW@3:j;80b^2_0<SN/02D/W`0`nFA0=7X_P2K/id0c][<07UIA03Wkkh0`^Jf0:7?`P2d
fM80gOoX0:oV[033l:l0f^o607nAN`20X9d0P[VR0;_o_P31ok@0[^2K0<god@0cPhX0DJF`07ZjX02h
l/X0/N>^0<KUX@38fY`0c/jZ0P3o00000`3oon@0g^^c0=CWY@040?l000030<WNV@3o0000o`000080
o`0000@0a]ZE0=[_[03/ol@0b^>Q0P3o0000`@1?FA`0U9iQ08RDEP38fi/0cNJT0=Wh]03:kZP0b>jU
0<7UW@3CkJH0dNJQ0=CUX@3>gIX0d^>O0;WCS03?kjH0d_R]0=Wi/01gNch0O7Xo0<?8R03;f9<0b^JL
0<KLU03Reil0ET8?0;^UM02BTU`0cmfP0>Wo_@2nf940`MF@0=[_ZP2nfI80anVO0=?i[P2^dXP0anFM
0=SYY@21T4d0f>>Q0=OQXP3QijT0cmBD0;2bL`2/[G40Wj=V09:HF02JXf80d=ZK0=3QW@3AljT0cnnV
0<OWWP3CljX0b>VR0:W8PP2<[6<0Q:9J0:c7PP31giL0dO6X0<KUW`3;kjL0`nVN0<_dZ032jZ40_NFL
0<7[W`2njYd0]^:G0<;aX`3=nJ`0ao6W0<?[XP3;lJH0anNN0<gRW`2W^WP0P9A?0;W<RP3=hYl0a]fG
08ZTG@2G/Vd0_]fG0<SZX03ClJT0fo6Y0=KVW`3@gIL0TYmJ08VDFP23SET0en:g0>3]`@2Q]GP0TjeV
0=?[W@3Ci9h0d]jL0=GTX@37f9@0f>bW0=W]Z027UU<0W:]X0<kGUP3?eID0g^BT0<SRV`37iI/0fNZT
0<_FTP3SkZX0aMB?0<oYX036i9X0a>2F0<cSV`3;giP0V:eZ0<_QX035h9d0c>VV0<CJV@1>GQl0f>2T
0=WOX`3Ji:L0bN:P0=Gf/@3:k:00bNVM0;_ES03?iYh0_m>>09FYI03Ej:H0a]^H0=W^Z`3GkZX0d^NV
0?Gof@3honH0_/;10?coo`3_lo`0moom0>Odh03;hk40dNnc0;oSY@3CnKh0`>JI0<;UT`3?ii/0d>6K
0<S<VP3Gf;00iNK60?Ooh`2DXh80hoo@0<KY/@37hIX0h?2Y0;o0O03SiZ40b]J>0=7bX`2nhI40amN<
0=oYX02BWU@0eN^P0;gIS`3Ilj`0^M><0=7XY014FaL0^<f:0=?XY@3Cj:L0enb[0>Ci^031eIH0`^6N
0;oRWP39kJL0QZYP0<7WVP30jYP02`3oool000X0oooo05/0nOko0?Woo`3iool0m?gh0?Won`3hooH0
l_o^0?3mj`3Xmn80gNcE0>Cce03NjL40l?3:0>;L_03Ze<H0TgYe0;jSZP2BNh<0kMgP0>GEe@3biMl0
YIfB0?cil029b;<0OmFl0<7oo`2kool0e>WZ0?ojo`3ok?L0ooco0?Chm`3oo_l0oo[m0?olo@3elO00
l?Kb0?SnnP3ooOd0oo_k00/0000:0000jn_Q0?Gol`2oklT0V=FY02m/@01;QE`0AGmG04b4G@15OEH0
:64f00@o4`0>BAT0=W1805F5M`1dY9P0;eeB0=Wnm`3Yool0kOoo0>7jm`3aool0iOSd0>onn@2eb;80
bn^R0=?WX01cM300W9aF0;RiL`3GjY/0dNbK0<[`W@3<kil0goN]0<WJT`1OIR80FfDN0=STW03UlJT0
am6:0:F[I@1?DPl0Ff0N06M];@3Hi:@0f^ZY08bVG03<j9h0bNVN0080anNK06l0cnfS0<oYW`2mcHH0
g^VU0=WNW01bO3L0eNnU0<SPUP34f900cMjH0=c]Y`34dhh0dNFP0=O/Y`34gIT0Li5;07ZHDP36gIT0
bnJQ0;NaM@2WWF80`MJA0<KTW02CSE<0JUdV0;^kO`3Jkjh0eNj]0<GQY031i:@0/]jO0:_IV`00:000
7T0=0=S_``33f:l0//NP07RAJP0U?QH0`=RX0;C<VP3Yo/D0c>2S09^^K01bUE/0>ElT0;WUYP38mk<0
b=ZN05mO8@2X/Fh0dN^Q0>_d/@3Cg9d0`n:N0<kYXP3@hJX0dn2d0?[oi03lonH0e^Jg0=;U[@37g9L0
TJIQ0<SLU`2cdID0PKf90;gEX@3CeZ40c]FQ0;[O[02gm[d0/>RW0<_PT`3VlZH0SIeF0;oVX`36kIX0
b>Jd0;CC]01?I5D0IDQ20?Ooj`2ni</0?G5U066?Q00DCb4085dQ07ngMP3Nm;H0d]fc09Rc_03Fool0
KknH04:;EP34lKH0`ORe02nFQ@1H_KT0IY]m0;WW`028/7h0630008fKIP3Pgl40ooo]0?ojkP3oon/0
j?370<GBW@17F1@00P3o00000`3Gj:@0f>VU0>?d/0030?l0001]06Ei=02BYV40dN2O0>;^[P2obHX0
g>FV0=oUY`3Gei/0i=nU05Y?5`1LCAH0HThI0<o2R`3FfYd0e]bL0<WJUP3EjZD0`MfC0<_UW03@jZ00
e^NP0=7LU`1kP3d0DE`G0<CTV`3GkZP0c>>K0<OVVP2oj9T0b^ZN0=GEU`1aIRh0HEHP0>?^/P3=hZ40
dN:N0=cXYP2DWed0hnj/0<3AS@3Bij80`=ZC0:FlMP1nTTd0g>:R0=WTXP39jId0c^jS0<GSV@3Em:P0
a>>G0<g[X@3BlZL0bn^O0;oQU03;kJ40a^BJ0<cGU@3RkJ/0a/n>0>Sa/02ga7l0c]^F0<kKU@37e8h0
kOZe0<?@RP3Kjj@0e^FP0=O[Y03BiYh0cnNM0<[ZW`31iYT0cO:T0<W^X031iYT0anbN0=3`Y03ClJL0
b>BJ0=GaYP3?iI`0d]fI08fHE03Lk:D0eN^S0<;PUP3:k9l0_^>E0=?hZ`3=kJ80dO2T0;kMT@2ifHd0
`>6B0<[[W03GmZX0_=JE08FNI02oeZ80c>B`0=Kc/@3=kJ80bn^H0=;ZX03AiZ40c>>M0<cVW`020<oZ
X`1H0>Ko^P35giP0`MJA0>7e/035fI@0a>:H0<c/X03>j9h0i?bb0=?]X`3Ln:d0c?6S0<S_X034ji`0
c?>T0<?XVP2abXH0AEXG0=W^Z`3Lkjd0e^:R0=KOX01NGb<0E5DI0;:fN@3/m[L0bMFE0<SWV`3:kil0
coBT0<kcY@36iYX0?U`B0<oYX03=ij00dnjW0<;TVP35jIl0e]nZ0?oofP3Hd/@0ooWg0?olo`3oo_/0
oooa0?Ckd@3Fh:`0fnfa0=W]/P2kgX`0fOfU0<KRSP3Bii`0Ri1J0<o@YP3Wi/L0n?[T0?_oj@3Ei/80
e^g107F7B@2HYf@0g^^V0<cMUP3?ii/0bo6N0<S_W020Wdl0aN:B0<cWVP37j9T0enBL0=SOV`3WlJ`0
BEXD0<CJTP3=ij00f_B]0<CIUP3NlJl0Yk=e0<[BUP3holD0hnf`0<??T@32dHh0dn:M0=;VWP/0oooo
000:0?ooo`0]0?Slo`3bn?P0nooo0?Omn`3hoo`0nOoj0>cfj`3hooP0n?of0?Som03conH0iO350<gA
W`3Yi[T0oo[L0?odhP3omoH0ooOj0?ohn`3om_@0oo[a05eJB`3nooP0@7iY09oZe@2coo408HUb0<kg
l`3[l?H0IDeJ0?_/l`3oo_l0o?om0?__l@3oo?l0ooko0??im`3kool0ooko0?_alP0Q3`l03@0005U?
AP3kond0]=j^0080[^R^09H0]Njg0:oX/@2`jkD0[NR`0:kZ[P2ak[80YN>R0;Cc^P2Qh/@001D0000D
001CQ6l0AW9Q0<o`i`3Zool0lOoo0?;oo`3ao?h0mOoh0<CPY@3Lk[@0inJ]0>7KW`2SVed0fmjI0<cH
SP34gi00e?>S0<3QT03Dkj80cmJB09JPF`1=FA40e^:J0=gWX018C`T0I6/U0<gDT@1NIbH0gNNZ0<WE
U@2CZf40bN>I0<KUV@3=kJ40b^bO0<7QU@3Em:P0b>2F0=KZXP3HiIl0TJ5J0<GMT@3HkZD0bmbE0>Si
/P1@HA/0DF8L0=;VX@31eY40foF^0=;`ZP29XUh0g_>`0<3TW03SjJT0CD/>0=cWY@3CkJH0iNZZ05YF
5`2NVU/0d>6M0<[SW`3<k:/0`nbX056:A@13O3P0P:U_045L:@3Hg[P0hN;003m99P002@00_]B]000=
00036`00]LfA0=kd/`3;hIP0c?2b0<O_/@005@00/NBQ0=O[/02GTeH0ZJi[0<;MT03<fiH0e>2P0=3V
Z03@iJ@0d=j]0=?M^03nonl0o_o]0=?P]@3=gZP0^m2;09fdKP35g9H0dONn03akD03Hk/00cljN0=cR
/P3>l/@0YnR`0<Gm_03GjID0Tia90:^iJP3:ljd0^^FE0;oSYP2ni;D000l0038D503kooX0jOok04Yk
IP1mYhl0]N^j04n9C`007000CEhJ04mC800V>Cd0Z]gH0:G/cP0>BRH0anBd0<3YY`0bSg80HL2/03i`
BP0[FBX001<00<CNX@3LkKL20?l000080?oom03hnnX0iNo=0=SX^`3Sn;<04RL00=S]Z039gYT60?l0
000_0=3TW`2[[700c=2C0>G^[`3@fY/0fN>T0=oXZ@3IgJ00h]fS0>?HX01PC1L0I5<M04U72P1/K2h0
f>>Q0=SWY03EjJ80f>bT0<CESP0W<P00CE<=05IE4P3OjJ@0d_R]0<?QU`3Bk:80b^ZN0<?/W@38j9`0
g]bO06=I7P2SV680gnf`0<gPX03KiZ@0d]RH0=;GU`3PiJD0h^f[0=;QWP1@I1l0c]nK0=?OW@3Ti:H0
eMbI0<K]WP34ji`00P32jIX00`3;m:D0b?6R0;_VUP020<;]W@0E0<KaX@35jY`0h^f[0<gFU@3Jh:00
LgTi0<oLUP3LjJ<0d]nI0=[ZX`3:fY<0gnnX0=k_Z03=gYL0e>RP0<[NUP3?iI`0cnVO0<WUVP3GljP0
dnnT0080c^RN05T0bn6H0<kTV`3Bhi`0dN:K0=OTWP3HgIX0SiIB0=?PVP3Ciil0c^fQ0<KXV`33j9X0
aNNJ0;oKT03EkjD0goV_0<g`X03<lYl0b>^I0<;RUP3<jJL0FG<f0<gU/@3=iZl0_=VG0<k^X`34i940
b>:H0=7[Y03>jJ80d>^T0<KTW03;jj80_]jE0=7_Y`35giP0c^RQ0=O^Z03@k:40cNVN0<gWW@33gI<0
NiY>0<CTV035iiX0a^^M0<G/W@30iiP0a^fN0;kES`3RmK<0d^6P0=?OW`3Efid0gn>V0>KTZ@1@CQ<0
G5`P0=cMX@3RhjL0cNFK0<[[W02jghl0a>^L0<c^X@2=[600a]fE0<cSW@3CkJH0bnfS0<ceZ@3KiZX0
ooo=0:j[S03NfLD0oogd0?okl@3ooo40jnc<0>7X_P3:ej40cmjS0=3_X@2ohH/0d>NG0=;RV@29S5L0
_[bC07QcE@020?ook@0N0>kif`3Bh;d0RiAO0>7Y[P3>g9h0c=nM0=W`ZP3;kJ00anbN08BWE`31hY<0
cn^P0<o^XP3OiIl0g]fJ09BGE02Y]6l0b=VB0=;YX@37gYP0dnJT0<cKVP2<TUH0hN:X0?oobP3fo<00
/;Uj0>;/[@3?fiT0f>NR2`3oool000X0oooo00D0h]kO0?ono`3ono`0ooko0?OemP020?ooo@<0o_om
05/0nood0>kogP3QoL<0dNZ`0>;e_P3iomL0ooo]0?Sdj`3lnoT0o?ok0>Sbi`2>YI40@5m?0>Koo@3[
ool0P:2K0364LP1U`K80UmC?0;RS]02dVZL0ooKi0>gejP3fk>/0oo_o0?olo`3mo?l0o_oo0?Kam@3o
o?l0jmWI09b4Q00D0000IUE50?oog03<gJT0a=FQ0<OKZ03<h:d0bn:^0<cT/03;i:/0b^>Y0<_UYP38
iZX0`>Nj0;oT^@1ENTl0]]Rc0<3O_@3@j]40G7=O0:bm]@3gool0n?oo0??oo@3ZonP0eo_E0;oY^@31
j;<0g?W10>;Z[`3BdYH0GE`K0;[1N`31g8l0fOFZ0>Oe]`32cXh0en:M0>;^YP2:UTh0/L5h0<_KTP3>
fiH0RIAB0=kRY`3EfI`0`Lf505UV7P3?iIX0dNfP0<?VUP39kYh0`nZI0<?XV034iiL0c^nP0=chZ`2T
]V`0g>bS0080d]nG05d0dMjH0<cKUP20SdX0`mB>0<gQW038gIP0en^V0::aL02H[f/0`>RO0=[h/P2X
WV<0SHU<0=KeZ@38ii/0][eg08jFC@2OZf<0LhI609N]K@39ijL0b>JX0=K[/`3Dh:h0NgeE03<d3020
PUd0Vj5k0=CP^02K/XP0Xk^;03YB5P2oeI@0a]jD0<GTWP3<k:/0bOJe0<3g]P3Ik;@0Z9QM0:NPG031
f8P0e^fW0=;PX`2QY7L0/;J80>gbe03ho>/0n_gf0?oomP3Ni;h0d=ZV09J[IP2]bhD0`>>Q08FfOP2B
eJ00b^6Y0=3AV03Gg:H0`>2^07nlP`2`iZP0bM^A09JPE`3BhI`0bo>g0;WWYP36mZ80]nNC08^UMP1f
EUL0e<cI0>[jm`2feZL0`=NQ09RbPP2P_iH0`n;30?;e_03?bHd0Ff4m076@IP2mhk`0EVi>09jCM@1@
CaT0I9M/000d2@31l[40_>VT0;kXX038ij<0103o0000103ioo@0iOCM0=3V_`2nhiH90?l0000e0=3`
Y@3/l[80fN:Q0<??S@0kC0P0UJYU0<cWX033hiX0cO6W0<W_Y02fgi<0an^Q0=CZXP3TmJl0fnBQ0=_M
W03OgYh0i^FU0=gMW@3AfYL0e^>N0=7WW`36i9X0_nVM0=Kd[03;hYX0d^bR0<3OT`3Qmjh0THM<081/
=`2[VVH0dM^O0<;BT`2_^gT0Y:e/0>_`/03OiJD0gn^Y0=;SW`3>hih0gO6/0<_JU`24QTL0PhY708:J
CP3KljL0`mnB0=gl[P3:ji`0bnbM0<c]WP3:kId00P38jIX01@39jId0b^ZO0<[ZW`21WeD0a^BJ00<0
a^^K0P33kI/50<;]V`190<G/V`3MnJ`0c>:G0=7VV`3Fj9h0eNNM0=;RV@2V/f/0enBL09RUG@2`_GD0
UJ5I0;K0N@3MkJ@0e>VN0=7/W`37k9`0aNbK0=3jZ03<lj80e?>U0=?^X@3Dk:00dO2R0<o^X03AkJ00
`mfC0=__/02BYFd0RYYY0<KHYP3GkJd0amjF0=7/V`31fi40gON^0<WWW@3Bl:H0b>ZN0<?XV`35jYd0
bN^O0<SXW@3>k:80a^:H092QFP3BhY/0a]bC0=OaY`3;jYh0N9A90=3ZX038h9H0f?BY0<g/X034i9P0
cN^S0=3ZX`2BXel0^/J40=GNW@3Sk:/0fnBS0=SQX03HgYh0V9YK05IF603NjJ@0cnBI0<;QT`36j9/0
e?>W0<cSV`020?l0000e0<oKV@38iYh0anfR0<oZY`3IkZd0dNFP0<?FU03ZmlT0fnK40?Gnj@3hooP0
m_ob0>3ebP3Ck;<0anJR0=?aZ`33f9D0i?Bf0:6WN`1cM580PX1Y0?oom03moO<0mok/0>cfgP1mN5/0
]k6A0>cdb`3bom<0bM^W096UJ02=Xf<0g_^h0<k[Z03CijP0g^V]09^NF`1BD`d0/KMa0=7QVP3<h9P0
d^bU0<WTW`3Nlk80UJEW0=;JX@3Hfj@0/<2109R^K@32f9L0b>6O0<?NV`3;j:D02`3oool000X0oooo
00D0gmWI0?okn`3ooOd0oogm0?gin0030?ono`80oooo0;P0o?ok0?ColP3Ro]D0anNe0<[W[`3Unl`0
o?oa0?konP3moOl0nOoo08RDTP1ROW00XlVj0?7oo03en_H0dmoM07VcY`0JRW@0Mlg20??Ll02SRiP0
oo_k0?_ol`3oo?X0o>g`0?oko`3hm_T0mOCi0?ono`3ooOl0ooSh0>C<bP0a3`d0=b4D0?Ojf`3KkLD0
`]B/0<gS_03?j<40bnFn0<_W_P3:ikT0a^>c0<[V]@3>j[T0d_750<GV]`004000`NRi0<WdaP2gi[`0
^>S207BRQP2@_JH0^^KG0<?bh03Aon<0]Ng60<3ocP2lnl@0[^R^0;kTY`3;j:P0[[Qk08nEE`38bX/0
b]>D0;[>T@3/o;h0dmjL0<cGT`3TlJT0c>6F0=_aYP3@hI/0XZe[0=gLX`3Lg:00f^6M09:LE`34f900
bnFK0<KXV`2mhY@0a^fN0<7XV@36kIh0cNnR0;kMT@1dQ3/0enNP0=g]YP3FiYl0i?6/0=3MV01WLc40
]/F20=[YYP3Gj:@0e^NS0=k]ZP1dQ4<0aN^R0;[KU02MVeh0CD<80=7WWP3Gmj/0b^VK0;ZkM@2UXUl0
:2h0075b>03Nfj@0f=NQ0=3GX`3SlK`0Y;^706ElB03>fjd0gNJk0<gH[P2`aIX0YK^=09>XK`1TN3T0
b^2H0=3/X@3<jJL0aNf^0:[RX`32eih0WhU?0:bNG@3Cj9T0d^fV0=GTZ`3ooml0a/JR0?_nj`35b;l0
j^c[0?oon03Oi[d0cMJO09>ZHP3Dljl0b_:c05ZAE`2_lJX0e_2W0=SOV`3Jhj@0cnjc04Z1A`2VfIh0
bmnT09jXL`3Jj;L0YLVM07bWL@2mkYD0_Nn@0=7Z/029IV80mNOf0?;mn@3Ek;@0j?Nf0=KT/@3Ei/80
i__/0>_Y`03om[l0]KUn09N^JP39hJD0O8EF0:29J@2fYg`0`^2j055lC`33i9d0anNN1P3o00000`3o
oo40loSR0>Sdd00;0?l0000l0;SJT03o0000o`0009BUH@29V5D0b=VE0>?g/P2lg9<0_^NK0<OjZ`3=
mj/0c]jG0<7BR`3Pn[40`MfC0=?cZ03:jYl0cN^S0=3ZX`3@iJ00dn:Q0=3UXP3IokH0^]F>0=__Z03H
kZH0f_6Y0<cKUP2MS5@0J54M0:>?G03^m[d0enV[08bVG`2`aH00d^>O0=CUX@37hIX0anFM0;oOUP37
iId0aMnH07F4@@16D@d0G6<O0=GLV03JiJ00ioB^0=?TW@3>giP0dnBM0=7UW@3AhY/0e>FN0=CZX@35
ii/0a^RL0;;DR03AljL0aNbM0P33k9d20<7^W@030;o^W@2nkid0_njM0080_njM02H0`^fM0<;TU`3;
ii`0gOV^0=?[X@3<i9X0d^RO0;kBRP3Aiih0R9iE0;C<PP3FkZ@0bn>I0<STV@31hID0anbN0;cYV02i
j9L0^nZI0;OTT`38kj00`N>F0<WXW03<j9d0f_:V0=;ZWP38gYD0eNFW07F2C03Hi;H0d=b^0<gOX`3E
jJ@0enjN0=O_Y@36h9L0a>:H0<7OU@80c_2T0200a>VL0<W[W`38j9d0cNfR0<OUV`2@WeX0f>>O0=S^
YP3=iih0f?BZ0<KPU`3AiIh0fnbV0<[PV03?iYh0c>RN0<W_Y02aeh`0foF^06^0>`3GjjH0`MF@0<[Q
V`34fiD0c>6L0;70O@1XLC00`LR40<kIU03Fl:H0bNNM0<GQU`@0o`0003@0b^>O0<?WW`37hJ80c^BT
0=S^Y@3@iYd0dnB^0<kM]P3[mn40n?om0?Oon`3`on<0hOW90<KX[038jZh0dnbc0;[?U`2W/h/000H0
0;FjYP3looX0nOoh0?Oom03doo00/:BD0=71/@3monD0m_oN0<kO/`2DXF`0UZ=[0<cVY`37hJ00fnZ_
0=?FW`1gPSd0Ri]@0<GJS`3Onk00b^VM0<c^Y03:jj@0P9eK08nWJ@3Fj:h0hNjf08nUI@2U_W`0bnBS
0<[TX`3Bkjl0eO>e2`3oool000X0oooo00H0n_;_0<:j]`3ooOX0mno]0?onn`3oo_d40?ono`2g0?ko
o`3iood0f_7D0<GQ^035iZd0dNfj0?;nj03nooX0l_;l0;k2c@0Z<cP0MHj80=Gfj`3dnO<0oO?b0?on
o`3Vool07iEo03:DQ`3okol0gl_F0?oln`3moo00n^gW0?ojn`3onod0oogo0?ono`3nool0n_[j0?oh
mP3onOH0>1HD0180001UHdh0noo/0?3mh`3gond0lOo[0?Cok`3conh0m?o/0?CojP3eonP0mooV0>?a
cP3CiKl0GWE;0<SX^@2oiK@0b_[80:GIZ02<aIX0V=2Y09C=[@25`:005eP`07fnU01QYG80M[^407Bh
O@2el;00]>NU0=Kb]`3@gjH0`K^709NGH`3<iJ`0bn2W0=7OX@3KijD0cmnH0=;ZWP3Ak9l0g?2Y0<7=
R`2TXVT0hmjV0=ONVP3Mij80W;1X0=3XWP37ii/0cO:T0<_`XP3AmZP0bN^N0<CTV03Hm:T0[l1i07:3
?01]OSL0UJIO0=CSWP1]O3L0N8M40;g9Q`0X=000enJS0<SGU03KjZL0[kmn0<k/YP3;jJ<0e]nP0>ON
Y@3DhI`0_MV>0=Go[@3Fei40i]fL09^LH01dKCH0b;J40?WY]P3[k[L0`]6H06>5B@0oHbH0Jh9<0=;P
[`3Bgk40amV_0<[K[`3Ci:h0EVP^0=KYY`3@jIP0b^FP0;[SX@2bkJd0dNV_0:^BF@2^We`0aMb<0<?T
W@3?hZ/0oocR0?ooiP3dm>X0mOOf0=CHf`3Ef=40f=fd0=GNY@2U_G<0c_6]0;?QX`0:A@/0YNJD0<GP
S`3Pjil0dmbI0<gZZ0008000Cgm50=7Y^@28VFd0aMF^0;3@Z@1mY7D0`>jF0=7oWP3DjZX0ek6X0?oh
o`3kooX0dnNZ0=?MV03@fj40cmjg0?Oon03oon<0oooF0=cOV03HjYP0gN^P0=gOX03/eZl0j]^d09J/
Q@0B;`00c>:I00H0o`0000@0oooX05iJ@@3jm]/0m__C1P3o00000`2icHH0o`000?l000060?l0000]
0=__ZP2c`Wl0S9eI08ZQF`3Ak:D0^]bB0;gMTP3IkjH0eo6W0<_]X@2lhYD0`^bP0;OQU@2miI`0a^NR
0<GRW`3@i:D0d^^Z0;cTV`3<ij80dnBP0=_/YP3Cij00LWdi0=K2S@1XCQd0ZI=R0;o7SP3EjJX0S:aS
0<cWX033fY@0f>nY09jnM@1DN2h0bo6V0<[^Y03Gmjh0cN:M0:flN@2?U540ZJi[0=gXX`3DhI/0e^NP
00@0dNFM00T0dnBM0=7UW@3ClJL0_=Z@0<7OU@3Hn:d0b>ZM0<K[W@35k9d00P32kId30<7^W@80`^fM
01P0aNbM0<CYV`33iIP0^]Z>0=7]XP3@k:40b>:H0=SbZ035hIH0a^FI0<k^XP3CmJP0c>jQ0<7VV032
jIX0b_FU0;k[VP30kih0/N2?0<WfY@2jhi@0b>nP0<GUV@3>j9h20=CXX00^0=;SW@3CgZ@0Q8iJ0>3Y
_P2e_Y<0RiUN0;O8Q01iST40dNNN0;?:PP3Hm:X0do6W0<;RU`30hYH0`^NJ0<SZWP37ii`0bn^P0<WW
W@2CWUX0hNZW0<oUW@35hIL0c>ZP0<cXWP22Tdd0SIYE0=WXX`3BiYl0_MB<0;oYW@3=nJ`0c>bS0=;/
Y@2hchT0b^FN0<;TVP3Emjd0e?B[0=O/Y`3Ah9d0IFXX09BKE`3;hYX0`n6G0<KPV@@0o`0003@0d^VU
0<KZY03<iJ`0cn:[0>;e]@3JjZT0b=BR0=gW`P3Xl=/0o?oo0?_oo`3hoo40l_oP0=Caa@3Oom00i?k?
0?Gog@1OKD`08bdE0?7ijP3goOT0n?on0?GonP3^onh0o^oX0>3=a`3jon/0kokO0>?cc03Khk@0g^Jc
0<GMW`36h:40b]FK08J3D02ibX<0f?>T0<?OTP32hYH0co6U0<;VWP33ij40PImO0=Ga]03Qm[d0amZR
0:k4Q03?j:H0g?:b0<KNXP39hjH0a=fT2`3oool000X0oooo00L0ookd0?okl02o^k80ookg0?oon03o
o_/0ooom0080ooko02P0oooo0?omo`3omol0oood0?3og03:jJD0a^FO0<OCZ`3Nh//0ooco05IAF00A
41H0gn?R0;Ne]P3jl^l0W8f:08U`L`1_NgT08G]_04JGT@3fkol0aKS10>7Je03Zl]X0ooGY0<Ff/@3o
o?P0o_cm0?Chn@3eool0mOom0>o`jP3onO80RFeY044U8@0n:BH0ooSh0?ohmP3glO40o_Sl0`3ooOl0
S@3oo?d0oo_j0?olnP3onoP0ooK^0=oHb03kon00nooO0=;Z]P3Kn<00/mBK0<_/]@2cdj40aNbg0<;i
`036ml00/=^U0<cg_`2ahJL02TL;03]m@01c[gT0Pk>30<OQ^P3;i;d0Ega905A`?`3:gJD0cn6S0;kC
T034hiL0a^NH0<cVW03OkZ/0PW]40:6LHP3GiZ40c^:K096XH02F/VP0do6W0<_YW`3DlZP0dnZR0=3T
W@3EhYd0cMbG0<cXWP34h9H0aMnF0;cFS@37hIX0_mJ@0=;UX`3>gYd0enNV0=?QX`3@gih0_Lj80<cP
V`2[/GD06B<00<oYZ03:g9h0d=6E07Z3@P3AkJ80g>VQ0=WPVP3PjZ/0fN:S0:JWK@1cM3X0TYiP08nT
H`35iJ80/M6>05im>P1MMcP0J7e406QeBP1KJ3`0J7A4004=0036did0d^^?0=K`YP2fhIX0Y^^X0;_H
WP1iGRL0XI9A0=7^W02`hYT0`=jZ0?olk`3ooO<0moGj0?kno`3fn_l0n?gf0=?IZ@3;eY@0c^ZM0;kW
X`2gk;@0Y>Nb0<CkY`3;ii`0fn^Z0;g9R`3IkjL0a>bS0;_XY@0PAaP0A6@k05mjD@17Gbl0Jh]L0<WZ
X`2ffh/0e^RZ09mfH03on_40n_o^0=;Y/@3IiJ<0aMVB0=?WZ03iom`0nood0?cok`2^_7l0Pi=<0;g9
M@3RjYL0`lZ70=kW^P2bdIP0bn^X0=3MV0040?l000070;g0R@2OXVd0emZU08:5D03RiJh0a/jB0<oS
V`040?l000030=ORW@3o0000o`0000L0o`0003`0do>X0<[VW03FkJD0cmRE0<;2PP2RUUX0^[Uh0;kX
U031j9L0a^JK0=OcZ@3DjjL0bMnN0<OPW`3:j:X0c^fa0<K/[`31jJX0eOZe0<_TX`3Ojjd0e^:R08nP
G03DfY`0i]2O0<2UN036[h<0oooC0<oTZ@2T`WX0bN>L0=GZY@3:giX0QjEM0<OYW`34jYl0bnnU0<[X
X03IkJP0SIiJ0=S^YP2DZf<0d^jT0<c/X@34jYd0`^RK0<3VV@32j9/0b>fP0<O/W`3:j9h0f^ZS09VY
HP3FiYl0b]^D0=CSWP3AiIh0d>JN0<gWWP3<j9h30<[XWP0E0<gWWP3?iYh0cNNN0=3`Y@39jIh0f?R]
0<7MT`3@jZ40I80f0<KTVP3@l:D0^MjA0<W_XP3<mjP0_nRJ0<CYW031iYT0a^RL0<CTV@3Bl:H0b^RN
00<0cNVO03<0bnFL09faK01`O3X0en>Q0=oYZP2g_XX0BDlO0=GL/`39dJP0h>fe0<_KW03Bii`0a=R@
06Ij<P3Jl:L0`]bB0<GTV03BlZH0a^JJ0<[ZWP36iIT0b>NK0<kZW`3Dgid0^<>10<?NU`3Gnk40a>RN
0<WYX039f9D0b]>B08fHEP1DHb00fNjY0<CZW@2liIL0cNNN0<_OV03:h9P0BfDL0=Sn/@31jY`0`nRK
0=K/Y03EhYd0EEDG09fOH031f980a>>M0<GSW@3CiZ@00P3o0000=@3=c9<0bN:Q0<3UX03MkLP0hnW=
0?ooj@3lnnH0[:ZE0>GPc@3hl^80ookd0?onn03oo_l0oogo0?OnmP3ZmnH0nooa0?3eh@1?CD40oooj
0?kjn`3ooOl0no[o0?_oo`3koo/0ooKm0;VTZ`3goo@0lOo/0>[nf`3am<L0dmZW0=_d/`30gIX0en6T
069G8@36fY<0c_6Q0<WYW@3HmZh0a=nH0<3FU@0bB0X0hOBl0>Wla@3Lk[X0[l6=0<?EV@3HjZ`0d^BX
0>cmb@3Pl;l0h?7400/0oooo000:0?ooo`050?oml@3ooo80oood0?cllP3no_H00P3ooo/07`3oood0
oooo0?koo`3ooOl0oo?o0?kol@3gomd0`nfG0<7/T`3@j:h0hNg50?ShkP0@4@`00080055BC02=NWh0
NgQa00P0000S0`P02ADC00e?B`0kMgP0c=3L07EZL00D2`@0IW1E079[F@3;_[H0oo_d0?ooo@3iool0
0P3bool0VP3iooX0ooof0;bXX@0@00002P000?O_k03oooX0o_om0?_loP3jo_l0mOWj0?_mo03jn_X0
oock0?ono`3kn_l0oOon0<[?b03XmmX0k?oH0<STZP2cci80fO>d0<cTYP3TnKh0cN6V0=7Y[`2of9h0
gO[00;oLXP32hJP0kOoL05^1D0005@00GYU]02]dB@2fnLd0]=^/0;_KZP3NlKX0c^2T0=GZZ@37ii/0
cNnR0<oYW`3BhIh0WiIO05aG7@3=i9h0h?Na0<?NU`29Yel0bnVQ0=C_Z02nf940cmjK09RSH@2;SDh0
jO:a0;WKS`3MokD0_MfD0>Wo`038iZ00dnjY0;gCTP3Wo;/0c=nO000=003Di:D0iOJ`0>We/`2FWV80
FV@W0=3VYP3Dlk00f>RW0=OMW@1<B0T0aM^@0=?bYP3;hYh0dNbW0<CUWP3:jJ<0d>VU0=KYY`3Jj:X0
b]RJ0=G[ZP38hj00bN>T05eX?@1CGS<01Pl007b5F03Ihk40bnJ50=;_W`30kZD0[oRa0=7c]`2VSED0
[9iM0<;TT031nK00coC00?ocjP3kl>`0oogo0?Wko`3iool0o?oj0=[Q[P3FhId0_m^>0;WSX@2bjk@0
Zno00;CVW@3>j:/0e^Rf09BQJ`3Fij40b^nO0;kZW`2ljk@0N:1/0;KGX03:h9l0e>nl0<cX[@3?kZ/0
d=jS0>O0X`3ooNX0looT0<_V/`3?hJD0Uk9U0<?PT03<hYX0m_oc0>Cdj@3Kk/40gNjh0=CRU`36eH80
enjP0<WV/035ljX0c?^Z0<SWX@35i9h20?l000090<SSWP36hI`0bnJQ0<SRV`3Nn:l0d^bR0=SdY`32
jIX0eOZ/00`0o`0003`0/L1k0>?d[P39fY@0e^ZS0<cRVP3CjZ80`=N?09R`IP2neXP0h_Z^0;gDS03I
l:P0_MB@0=;XZ03Hk[00k_o;0?Cod`3Rm/<0dNbe0;cTWP3col/0c]ZL0>?_[`3Lk:/0i^b`0?;LZ`2Z
Sf80WXUL000;002CZ6d0f^jY0=KUXP3Mj:H0en:P0<?GTP3KlZ`0d>^T0=SbZ`30e8l0dMZI096GE`3B
fiX0^lJ40=GVXP3:giX0a^2I0<kYXP3El:T0dnjW0<gWX03@jZ<0eNbT0=g^Y`36ei00bmnG0=K/X`3C
i:00d>FP0<oVX03:j:040<WYX01J0<cWX03=ij00cNNP0<cVW`2neHl0c>>M03M<1`12EQ40d>BO0;_@
R`3HlZ/0`N6H0=7cZ@34j9h0anVO0<oZX`3>j:40e^fW0<[KU`39f9D0f>BR0=_WY@3BgY`0m?o002`m
001DHb80cm^I051L6P1DGQl0Nh9>0:2VN0001`00lo_B0;g<U@3HjZ`0R9eB04]L5@3Ol:T0dNNN0=ge
Z`3Ckj@0a>>G0<OVVP3<jil0an>H0<STV@3?jIl0e^:P0>;^[P33hY`0/m^B0<3XW`3Cm:d0d^6P0<oH
V@1GH240@e8A0=K[Z03;jj00_mfC0=cYY039d8d0RIA@08fLE`35hiT0b^ZO0=3^Y03Kj:<0bm2>06eY
;036ah/0d^^W0<WZY@37iZ80d^NV09>BFP3Qg:D0g]nV0=;/[@39lZh0looW0?SolP3koo/0i^SW0:j]
Z03ooo@0o?g[0?ook03ooo40o_go0P3ooOl09P3oo?`0oo_f0>kSg@0W5aL0ooSl0?obo03on?l0ooWo
0?omo`3ooOd0ooOo0=S7c`3dooH0j_oW0=3Xa03?eJL0g^F_0=G`[@2ng9H0en:P05Q=5@3OkZT0bnNL
0<gWWP35fI@0aMBC092JGP3WkkH0mOW60?_oc`3Pj;T0PXYK0<kTYP3Ajj`0a=jQ0?Cof03domX0h_W;
2`3oool000X0oooo0;l0oooZ0?ook`3ooo<0h>7L0=OKg03kool0m?[j0?coo@3noo<0oooa0?oojP3j
n^00lOoN0>7fc@39hj80cNJR0=3c^@2^fJh0PJn]05^1Q03Ajn`0l>_W06EGEP3dn_00o?oh0<c0a03e
m_/0g_oo086`]P3^ool0YjR/0?onnP3oonl0ooga0;JHUP34Z:L0SXJ307ioNP1dKf`0>S8`06i_I`1o
QGT0LFMM02PK4`040000=3Ha03Tn>P1QIF@01`L700d41`0@1PL04PH600L000050P00<BhW00H0000o
=SL08A`I00h>100=3`803aH4000700033@0021@003Y6;P1UKe@0K7]B0<cM/@3?iK@0d^Zf0<;NY036
i:@0a>NS0;[UW@33mZT0`on^0;7^X034okd0ZnNY015:4`2Ndil0R[J507nEI`2=VF/0VY]R0;ViN`3L
hiH0d=N906e_;P3HhJP0b^>Y0<[WY02?Ye<0`/mo0>obZ`2ARe/0e]:S0>[e/`26UTl0cN>J0>?g[`3E
jYd0e>VL08VMF02aa8@0c=jP0=W[[@3JjZT0go2Y08JLD@39j9`0dNRR0=7SY`2;Ved0e>FN0<kSU038
gXT0h_>S0=SSWP30fJ00//^B0<oKW@3Ij:L0cnFM0=?[X@39giH0c>:I0<?HU`3>ijH0a^>Y0=?b^@2j
h:d06TLV00HS1`1<ASH0GD/o05Hk<03Dej`0^>F^0;oo`P2`lk00c?Bf0;niQ@2UTf40I4lP0:^IL@38
`id0l_oW0?Wom03iood0ko[f0?;onP3Zmnd0moo/0>[nf@3Lo<X0/=^U0<?d_01o]GL0aNnU0<SSX03D
jZ`0UJA[0<CGU`35hI@0d_>T0<_]X@2;YUl0SZ=P0=c/Z`3;j:H0b^fK0<kaW@3;fid0OVE70?onk`3m
on/0d^Ja0<[YYP2/_GL0WJYU0=o^Z`2daY80SJ5^0<WNX`3;hJ<0cnJP0<gWWP39jIh0b>VT0<?/X002
0?l0000<0<?/WP36k9l0b^bP0=7aYP3=k:00a>BH0<KXV`32iiL0bo:Q0<K]WP31k9d0b?:V103o0000
1037ii`0o`000?l0003CmJ/50?l0000g0<oNV`2cah80bn2K0=_k/P2gfi40b_BX0<cbY@3Aiil0Rj5I
06^2?030ei40bn:L0<[QW@39h9`0b^2O0=?XY`2oe9<0e>ZZ0=7[[03hol`0/Kb20:VkO@38ij<0aM^J
0>;PY`1ME1d0P7i50=G^[038ij40dNNN0=S^YP3Vmk40cn2I0<gQV@3CjJ40bN>J0<cXW@3@k:80`=bB
0;O>QP3Lj:H0cmbD09R[FP33f8/0c^>[0??of`3don`0m?oZ0=3[]P3=jZX0cNRS0=[Z[02U]gT0b]nN
0<WOWP030<cXV`80b^VI00<0bNZI0<[YV`3:jId00P3:j9h0BP39jJ00c?6T0<o_Y039iIX0[/=h07f=
@P3?gI00dnBD0<;EP`3BkYT0e?:L0<WZV@34gIT0cn6S04UG6@1kQDH0fNJQ0<kNU`3:hYP0[<Il0:>m
L`38h9H0cnJP0<GTX03;jIl0dNfP0<GLSP3BgJ<0e=^_06AUD`3Yj]`0jnoF0=cT_@27UEL0?U8:0=7W
W03Bj:00bn2K0=?VYP3=gIh0eNFV08RGEP2LZF@0TYeH092LE03;hIT0cnZS0<WWW`35hi/0an:K06Z1
>`3FjZ<0g>fY0<SLU`3Jl:P0`MRB0=SXW@3Agi80RIM:09BTF@3NmJL0amnA0=7YV`33f8T0h_2S0;bl
LP26PST0d>NG0<g/WP35f:40en>k0?;ag@3JelP0kn_O0P3ooo40=03co>/0n?od0?[jl03ek^H0V9>?
0=WDd@3km_80ookh0?oomP3oooP0oooj0?koo`3lool0nooo0?_jn03eiNH0TXN50>C7b`3bem`0oocm
0?ojo`3onol0o_oo0?omo`3oood0oOWf0?oon`3WoO00`mc70<W5XP3gj[d0bNRL0<ghYP3Ci:00HEDQ
0=KQW`38gY<0goBY0=S[W02=WU00c=NC0=oWZ`3Nhj/0e]^S09VOH`3LhJ40oooO0?Cif`3oon@0f=fd
0:N]O`2?U5h;0?ooo`002P3oool0;P3on^l0n?C[0?_hl`3kno/0jNg`0?Gjo@3kool0mo_j0?cmm@3`
l>@0moKR0?ooiP3Ulll0cMjb0=[d]`37iZ<0]^:a0;g^d00TEET0R:fe0>goo`1_K6D0ShR20?Won03i
ooX0/jf_0?omo`3Oool0TKc20>[oo`2HX:80ookk0?onl`3on>l0o=SJ0?oXk03on?H0n?Ob0<^k_02Q
Shl0:RLP02/e:P0F3`D02P0001491P061`820001002>0040000Y7Al0@30c0551@@0c9B80GeeA0:BP
U@1oM780WY>A040f=01hLfl0SHZ506IUH00Y:R@0;S</0458@000100000D0000;001VM5<0c=jf0<kT
]P32fZH0dnnb0<SWX`3Io[40/=N60;cVT02mjYD0]nfR0:oXX`0<BA00G9IT0;O/`02mgkX0foG>04eK
:02AWf80f^^M0=SUUP1UIBT0Jg8l0=7V[@3<iJ<0/<Ic0:RcI02n`GX0`Kj;0=oQ/03BhZ40UJUR0=SY
XP34eX`0dNBE0<SKS02<WEL0VZY[0<oNX`3GijT0`m>B0=[/X02>YEL0eoN/0<SVWP3DjjL0eNZU0:Fg
J`30dH40`mJ50<gRU@3Aiil0e>^c0<gPZ@3KiJP0hnf`0=[YY03AhY/0e^bQ0<oWW@3DlJh0e_Bd0<GV
[@33i:l0_>Jf01I=;P1CNF00ZjnQ05I>@`0>0000f=c30;gT^02ikk/0OkMj0;?LX03CgJP0lNfm0;2J
L`1QAbH0G4d/0?WoiP3monh0lo_/0?Sol`3doo00h?;J0>3_dP3]o=/0goS>0;cN[02hhjd0]nRV0<7Z
W034h9H0dNRT09:RI03BiJD0cNNM0=7^WP3<jIL0TZQM04EF403ChJ<0anJP0<S/U037ji40fN^]0:jI
OP3oo_<0ooo]0=3S[033ij40]/:20:fcM`2DXV@0U:MW08ZMG@3Bj:L0b^>O0<cWXP3:j:80bNVP0<SZ
X0@0o`0000T0a^fN0<KVVP38ii/0c^ZO0=3/X@3CljL0d?:U0<;WV@2khY<00P3o00001P3;kJ<0o`00
0?l0003CkZL0_mfE0<;RV@P0o`0003H0RimJ08fRG@3>j:40dNnW0=Ge[02eeH`0dNRR0=S_Z@1YP3X0
UJaV0;78PP3KlZ`0c^FO0<gTWP3@ij40g?>]0<_TX03>hjP0hNbb0<WDVP3>hZ<0`nBO0<k[Z03Ngj<0
KFP^07Ad=P36hIX0anVM0=SbZ037giD0d>JM0=7WWP3Ejj80d>JM0<SRV03:iY/0c>bP0<GWVP31giD0
enJS0=OWWP2AY580g?6R0=c^^P3gonH0k_o]0?Col`33gJh0_=RK0=G_[P3@gjH0RYaR0=S/[@3?iJD3
0<[YV`<0b^VI0P3:jI/20<[XWP1E0<WYWP32j9/0bNjP0<GVU`3?iIX0Z[Y_09ZXG@3^o;40d^:I0<OO
U@34h9D0d_2X0=;[ZP2ocY<0MX940;BnO`3MjZD0dnNO0<[YV`36iiP0a^FI0=C`Y@36h9L0a>RR0<_`
XP38jYH0b^JB0=?QYP3JhkP00`<00?oonP3[kMP0/KNE07b:C01XOSD0b>2B0<cTVP3@iYh0enZZ0=GU
Y`2@WV00XZi`0<?>RP3Lij80f^JN0=?]Y03:jZ40a^BL0<WSW03?i9l0FFhY0<GITP3;hIT0b^6I0=;Y
X@3Nn:l0amF:0=WUV@2BY5P0cnBG0;WDQ`3:iIP0cnFJ0<gMU03Zm:/0UiMA06IR6`3BlJ40`nRK0>gm
d03Yk=40oogh08Z0P@3oo_d0ooom0?[ln@3nool0oooo0?olnP3HblD0Ng1Z0>3GdP3oo_P0n??]0?oo
nP020?ooo@090?koo`3lool0nooo0>OYiP3on_X0_K>a0?GFf`3ol?<0oooj0080oocm01h0nooo0?on
o`3bmo40n__e0?ojoP3dool0hOSX0=;=[`3oo]H0bNVM0;gZU`3Ah9l0I5XY0=OVX`3CkZ40^]F60;O@
O@2U_6`0f>bU0=CTYP3HhZh0fN>_09JOIP3Pj:`0oooT0?ook03lon@0U9I^096DI@2SYf`;0?ooo`00
2P3oool0;`3ln?l0ooco0?Cbo`3oo_l0oook0=GDc`3?c/T0oooo0?Oeo`3noOl0n?Oo0?cko`3bn=80
dnFY0<Sm[`2^m:/0e_ok07ZWX03kool0n??g0040003loo@0ooOe0>_hk`3`ooD0oogk0:ZIW`3`ool0
Tk:d0>Woo`3=fm`0oooo0?oln03onoP0Fc/n0?oamP3eknl0o_om0?kbmP3jj^d0oook0>gik`3oo_P0
eLK100l0000d9B80ZZ:O0080o_om08`0oogo0?oio03ono/0oock0?WdkP3im^l0o_Kd0?onn`3RgMX0
oo_h0?[fl`3noOT0oook0?_mn03lo_T0o_ok0?Sil`3ooo@0f]S;04I7=@0@4P00310000L>0018Db/0
fnRj0=?Q/036e9l0enJ]0=;QWP3:f9X0]l^F0<g]^`2bhJd0@8YE00MJ8P10SED0RLRC07ZKK03=iKD0
fNje0<WIVP1GGQX0Ri9?0<kLW`3@i:D0cNRS0=_n[P32hYH0dnV[0=3TZ@2CZf40@ET=0<[QT`3FkIl0
bMjI0<cPX@1GJc00`]JI0=3SX`2oe8T0V[1W0=K^/03AkJ<0d_2H0;_IP@36hI@0`mbJ065e@031eYh0
dNFV0=S]WP3MlZ<0d^FU08nTH@3Il:P0b>:H0<CSU@004P00?60H03iS7P0QB@/001`0035I9@2H`Y`0
Z]Ra0;C/_`19PE@0cOoE0>kok03monD0no[L0??ogP3Yom`0`>Va0<[a^P004`00]MV[0=W[a@2fWHL0
ooKO0?Cfd@3KikT0b^2P0=[_ZP3DhI`0en:P0=_/]@3=j;D0ZlnO0;GRZ`3:l:D0cnVO0=K[YP2FYVL0
g>b[0<gXV`3Cl:00cnbL0>Sn/`2lcHL0g^b^0=3[Z038j9<0a^N@0=7QX`3Sc[<0oo[_0?cok@3@iJd0
aNfV0=SXZ@3OjJ`0f>RY0=ka/@3Cj:L0j_no0=C]Z@3<ij80b^RP0<WYX0D0o`0000P0b>ZM0<gYWP3;
ii`0b>:H0=?]X`3=k:00d_6U0<7SUP@0o`0000@0fO2Z0=K[YP3Cj:<0e^fW2@3o0000=P3?h9`0g>^X
0<WBT@3Rj:P0C58B09fXIP3BjJ<0bn:L0<gTWP3BjJ<0_MB>0=K]Y`39h9X0c^FO0=cc[@3;hY`0OiQD
0:S0PP3GiJX0e>:U0<oSY03BlJd0bN:N0=kLX@18?`H0]:ib0=od[`3:iY`0cNFK0=cbZ@3Ll:P0d>BL
0<oSV`3Ciil0d>RN0<cVW03:iY/0b^ZN0<oZX`3^n;`0cmZF0>3]W@2MZe`0g^ba0<WDZ@3coND0joGM
0?SogP3LkKT0cn6W0=OY[@25Ue/0aM^K0=G[ZP80b^RP0P39jIh0CP3:j:00bNVN0<WYWP3:j9h0b^RP
0<WYX038jYh0b_2M0<CWU@3@kj40bMjI0=_[[03Bh:D0joO70=GQ^@3aon80l_oZ0?CoiP3`om<0enJ[
08fKG@2KYFH0c]fH0<kRVP3;jY`0b>VJ0<;RUP34h9D0dnfT0<_]X`38ji/0`>6@0=_fZ@3/n/D0iNo:
0002001@DdX0h^g=0<_K[03AjIl0gOR[0=;^X@3>ji/0fOFX0=?_XP37hiH0b^BJ0<kXW`3@ij40bN2J
0=G/Z03=jj40_mnC0<SVW03Jm:/0`mVA0:NmM@3Hk:L0cN:M0<SOV@3Aj:@0Mi1<0<_OVP3IjZH0dNBR
0=CTY@3Di:H0a=>H04MA701LI340Eeh[0<O9VP3[j[h0`=:P0>Snc@3nonX0oooa0?onnP80o`0000D0
n?gf0?con`3ako80ooco0>OMgP020?olnP040?ofm@3nnOH0ookk0?onn`80ooom0P3nool01`3kood0
nogj09Z<S03gkN/0mmSM0<V_/P3oooX00P3oo?d07P3kool0ooko0?Omn@3nood0ooCk0?coo`3iooX0
/jnD0?oof03;j:D0bnVS0:RULP2FSf40anFO0<;/VP39lil0]]^;0<c^XP35hZP0l_oO0?Gok@3goo40
n?oa0>[fgP1PLDd0`]N^0=[``P2oeYh0gOFg0<[TW@/0oooo000:0?ooo`090?Kho`3lo_l0o_ko0?oo
nP3oooH0jNGJ0<[8_03oooX0o_oo0080nooo01/0m?;g0>?]b`30fJ00[^jP0;7mc00iME`0BFmR0<c3
aP0C1P00j>3C0?Wkn03on_h0mOom0?;onP3llnh0VH240?3hnP2Q^kX0eoWh0=k^kP3in_`0oo_j0?ol
nP3Yb/l0oo7f0?ono`3lool00P3on_l03@3alNl0n?ok0?okm`3on_P0C2h/02<;2@1^Ge`0oook0?_o
o03gmoL0oOWj0?ojn`3kl_<0103oo_/01P3Dd<d0oook0?kmn@3ooo/0n_We0?_lm`80n__f05h0oook
0?ogmP3om_@0ookf0>OPeP2m]j/01P40014?000/:`l0ZjZ<08V:JP1hNET0/jnD08R2HP3WhkH0g=nZ
0=c/[P2giYh0]?2Z06n^M`12NDl05cPU06j;M@3@lKP0f_6]07f0>@1LGA/0hnfk0=K]]@2mh9h0^NZ?
0<G`U`3JlkT0`]NO0=7[XP2V`7H0eNfO0<gUU`3DjjD0dnVY04QM903GkJl0eNZY0<oUVP3BjZ00PIMF
09F_I@3LoJH0fO^U0<CSW@3?kK40RZ9`06ElAP2V^W/0b]j90=GXUP2jd8l0[<F10<[VW02?[V80ZLal
0<S]W`31iih0_nNQ04af=`2jhjL0b^ni01hi3P1EOdl05UXQ05bVJ`2lolL0h_oS0?ooj03omml0nOoJ
0?7og@2li:l0_njg0;cf^`1o]800e?G:05QA=@2Y]Hl0^<nI0<GNW@3Cki/0b>J<0<ceU`2bgh@0ZmnE
0:CHVP1MTU`0^^Ve0P3o00000`3Ejj<0_/j?0=;RX@020?l0000F0<KST`3@j9`0fnnX0=;RY03=iZD0
`mj=0<gYU@3?gJ00kMFk0?omlP3nond0cNB/0;gWW`3:gih0d]fQ0<WLW03>hj80`MNF0=;YY@3;i:00
c>NP0<[XX0D0o`0000T0a^JJ0<KUV@39hiT0a=jD0<gUV`3>j9h0b^JK0<[YW@37ii/0103o00001039
gYT0dNFP0<_OVP2DZ6<40?l0000k0<GfY`2nkIl0o`000?l00038hi`0bMfH0=CSX03?fYP0gnRW0>_a
/@2V/Fl0QiiH07nFD03@ij40bn:L0=W`ZP34fiD0d^VS0<kUW`3=i9h0d^VS0=Wb[P3Hl[40gNf_0=GS
YP3DjJP0bNRT0<3GT`2VXFL0IEPQ0::HG@3Ah9d0amjF0;_AR03@i9`0c=fF0=KWX03Sm:d0dnBM0=?Y
X03@j9h0bnFK0<WUVP3>iIl0UIaV0>K_[P3Eh940[[][0<kHV@3BfZT0j_7B0?Woh`3noml0iNjo0>Wf
`03?hj@0Zkn00=kd]03Ll[400P39j:820<SZX01=0<WXXP38jZ00b>ZP0<WYX039jIh0b>ZN0<SZW@31
iYH0co2Q0;cKS@3PmK00cN2N0<CCV03<fZT0b]V`0>WjfP3Smm/0f^o>0=[a_@3Ljk00Pi5C07n9BP3C
hYd0en^S0<GVU`36jIT0c^jR0<_WW03=iid0anVM0<?VUP37iYP0e_2W0=7Q/P2e_id000<00=[Rd`3Q
lLX0dnR`0=?`X03?jj40`MnG0<KUV@3>kIl0e_JS0<GUTP3Lnj/0d>nQ0<k/Y03:j:80c^^X0<[ZW`36
iiP0a^FI0<oYW`2>Y5`0b^2H0=S/Y`3>hj00cnJR0;36Q@2?Z6H0enjZ0<3EU03<gZ00bMRM0>7[]`1N
ISD0PHIM08R=I@3Df;<0h^K50=7D]@3Eh;h0m?oO0?Kgi`3flnX0103o00002P3cnNl0ooco0?7Uk`3d
j>`0ooWh0?oln`3oo?d0o_Sh0?cfmP3oo_d20?ooo`80o_oo00L0noom0?koo@1?@D40oocj0?SIgP3o
loH0oooj0080oocm01h0nooo0?ono`3kool0m?Ke0?ofo@3knOX0oook0<?1ZP3noml0`=VO0=oa]`2<
OE80/Jb20=3]ZP2jh9<0bo:S08f_H`33hYh0eNfm0?GoiP3doo@0k?G`0?3fm03lool0k?kH0>Snc@36
gJL0d>RZ0<cWXP3Ro[<;0?ooo`002P3oool0103dom`0c=fa0<kJ/P3jnm`20?ooiP0f0<O6Z03Ig;d0
g^k70;kEZ@2of:h0f>G;0=ChdP2IbjP0AWia072PU03Xo?/0looe0827G@3oon`0o?Ca0?ogo`3om_l0
lOol0?3on`3omnh0ooKf0?ckn@3bool0[m??09N[ZP3lool0ooOj0?ohn@36[K<0ooOo0?CdmP3iool0
ooco0?gbn03nool0joOc0?ono@3on?X0LTI702D0001hHE/0oooh0>cck03_mO<0n_ko0?ono`3ooOl0
ooco0?cjn`3lo_/0n_[h0=KFe03no_`0moKd0P3oo_d0H03cknh0oo[j0?;/k03@alP0YiZQ0=?6c@3h
jNh0j=WN0=c=d00[7Ad0S7al08amNP1_GET03@0007MXI@3om_X0oocm0>WUf@3Th/d0ooWO07AZA`2=
Pel0HV0g09^RMP1_QeL0K8iK0561A@3Go;T0`<n:0>Wb/`1;EB<0bmfY0<_XZ037kiT0bnjJ0<;HVP30
eIX0[lf50<o]X`3Tok<0`]jA0<ORW@33gIh001H00<;JWP38hJ00d^bR0=?/V`32f8<0hOV]07nNH`2;
[WP0^>2[0;WRYP3:kZP0e?:X0:g5N@2kbGh0SYiE0;_DT03@jZ<0g_Z`0<KUV@3=kJ40b^ZO0;gNU`32
iZ00b^j^0<O[[@3@jJl0ZJ]i086@F@3<m;D0aoFd0<Cf/@37fK<0m?oQ0?Gog`3Dej`0g=V^0=kW^03G
ikH0hOO60<[Z^02Wci/0_>Rc07EnD@3Qk[H0bN:P0=Wo[P3;mY`0b>B=0=W_W@39h9`0PjIV0<Se^P@0
o`0000<0d^2R0?l0003o00000P3o00004`3@jZ00e^fW08bNHP2^`hP0c^BI0=?ZVP3LiZX0c[BI0?ok
kP3jonX0b^J/0<3^Y@3@jjP0eNNY0<kTX`3>ij<0cNJR0=C_ZP3:iIh00P3:j:040?l0000;0=;/XP39
hiT0cNFK0<oUW032f8l0fO6W0<GMT`3Nn:h0bN>I0<;NT`2Q_G800P3o00001P2ndhh0^<f80<OLU`3B
iZ40dNJQ08VSG080o`0003`0c^VR0=KUXP3Hij@0dnBP0=SYY@3BiZ40c>>M0=[d[@35hi/0gOfd0<;T
VP3>kZD0amjH0=gd[P33fY@0`=NA0:>jM026WEL0a=^E0=K]Y`3?iZ00iObf0<GOV037iIl0dNBT0=[Z
Z@3DjJH0do6[0<gRW`3LdIT0Sg]60;FRJP3Igil0eNJP0=CZX@3=hIT0e>FN0<GFS`3:fY<0d^:K0=7R
V`3@i9`0d>JM0<oWW@3?i:40XZmi092NH03?h900aMN30:RfJ`2BWUh0b=6T0<gE[03homL0e]fc08jJ
J02I/W00//^90>Ko_@3>jJ@40<SZWP040<SZX038jYh0b>ZM0<SZW@80b>^I04<0b>^K0<o]Y@37hY/0
eo>Y0;oGR@3AjI/0enjN0;;9N`3<hYL0d>ZQ0=7[Y037h9l0e>b^0=KX[027UEL0S9QH0=3OVP3<hYT0
b^^L0<GXV034i9P0b^VM0=3[WP36iiH0bnZL0<kZX03Bj:P0^<NN0;6nX0064P00gN_B0<_T[@39jJ00
`nBC0>7h`P3/o]@0h_K10<oWZ@38i9T0bNVF07FG@@2H^fL0a>VL0=;f[03Bm[00`N>F0=3aX03;jY`0
cnVO0:JlM033fI40bMfH0<gRW`3<hZ40Rj5P0<3IV03=jZL0b>FR0=O[[039eYh0QXQI0=SF[@3Bck00
ookU0?ook03Sk=/0n?od0080oood00<0dL[40?ojm03o00000`3o00002P3konP0d<Nn0=?1`@3omOL0
ooSi0?omo`3on_`0oogo0?ojoP3oo_l20?ooo`090?ooo@3nood0noom0?koo@2BQ8@0m^cZ0=2a]P3Q
alX0oooj0080oocm01h0nooo0?ono`3^m_P0nooo0?oio`3on_l0oo_k0?ool@3conT0gNo70=KB[@25
H4H0l>g:0>Kg``3Ijk40`M2E082>D`3AfjH0oooS0?glj03om?P0oo[o0?GWmP3nk_/0e=V`0<WEU`3A
gId0g>^V0<WIT03NlJ8;0?ooo`002P3oool0=`3Mo;00e>^W0=GWZ@3Ykl40mOK>0>CR_025Qel0bM:U
0=;/[`3=kJX0b_6`0<cY_@2mk/h0AWeZ0>3oo`3Uo?l0j>[Y02LZ6@3gomX0l_[U0?ono`3om?l0onko
0>Sil`3aoo/0oogd0?oTi03knoT0encW05n3O`3Nl_<0kO7d0?ofn`3ooOd0j]?K0?ORj@3nool0n?oo
0?[cnP3onol0n_ko0?Ooo`3bk^d0ooSj06Xl?0167aX0DcLc0?;bjP3koo/0nOoo0?_oo`3lnol0oO_o
0?omo`3oo_l00P3nood02@3;cLX0ooom0?ono03ln?L0oogl0?omo@3Vh>00iMcM0?olo`020?oko`03
0?OZl@3onol0oo_o0080oo[m05@0RGUj089_L@1IAdL0VHV:06IPI03FemT0mooo0?Son`3eno40i=S8
0=g;]`3Pd:`0hM^[0<SHU`37i:40B7Pl000D003>j:T0c^:U092OJ00kBQ40RieO0<SNUP3CjJ00eNFT
0=[][@32gIH0dnnU0;??Q03JmZ/0bNBQ0=;/[`003@00cnN]0=C/[P33gI@0d^^J0=;[T03<i9P0/=2O
082UNP1/UfT0b_Fm0<K_X@34iiD0d^fN0<cLU@3Mk:L0f>n[0=S_Z@3?jJ00cNNN0=3/X@3<j9h0c^bT
0;gLUP3Dl[80^]RJ0=;W[03blkX0c]JK0=OYZ`39gih0b>6O0=OP]@2kgZP0`>J]0=3HY@2QVFX0HETZ
04e96@0/:000dmn_0<S[/`1MVE/0c]ZZ04YA7P2@Y6T0aNVS0<;SW03>hY/0c]fJ07N7B020WEd50?l0
00030:fhO03o0000o`0000@0o`0001@0e>JZ08:FF`3;h9D0cnJF0>;//02lXHH0ooo_0?cok036i:P0
_>bP0<WVX`3?i:<0enjZ0<oXY03DkjX0h_ff0=G`Z@3:j:00b^RN0<WYWP80o`0003h0b^VM0=W_YP3=
hiX0bn6H0;gCRP2W_G@0b>2F09F]H`27XEL0N9980<o[X034h9D0i?nh0<7KU03JlJ/0aMbF0<oVX036
gIL0fO2Z0<;MUP3Bl:P0RjeS08NRF`2EUeP0`<F50=KOWP3Dh9h0d^>O0<oVX03<ij00a^ZP0<W_Y037
ljH0a>fQ0=of/037gYP0d>NQ0<oVX03HkjT0dNRR086HDP2_aX00]<^50;G<QP3=j:40b>NQ0<[OW03@
h9l0b]nL0<cZY01JKB/0jMbU0:jII02gXV/0UiaL096PG@2DZV40SJ5I0;O8P@2>WeP0fNVR0=SXX@80
dN:K00/0d>BL0=3VW@3>hj00enRa0::eM@3Nlj@0bMn<0=S[W03<gIL0SIYU08FAH@020:njS`0508ZH
I@3AjZH0c^NU0<SSWP3:iIh00`38ji/30<SZW@80b>^K04X0b>^G0<S/U@39jYT0c^VT0<CMV@3Jm:/0
bNBC0=[fXP20VT<0g?JM0=3ZT`31gHP0e?2L0<gWW@3@jJP0gNnc07B4A@1gQTD0f>VS0=7WWP3<kIh0
c_6Q0<SZW@3=k:00bNBG0<WZV@3>kIl0bN>L0=W_/@3Ljl@0mooV0007003Kk<`0b^JY0<c^X@3@lJ80
looM0?Wok@3^oMH0eNNg0<?LV03BkZ<0RJUD08JXE03>lJ40]]^>0=3dZP35j9P0doBS0<c[W@3@jZ00
b=jF0:2fKP3AiJ00f>fZ0=;XY`3<hZ40RZ=R0<CSW@3?kjH0b=fL0<gKWP3?cYh0hn2e0?ooh@3oonH0
nO_U0?Som03[nnh0oO[c0;6VXP3ooOP0o_O_0?;jhP80o`0000/0a=Z[0>Gdb`1NEd@0oo_a0?olnP3o
nOT0oogo0?oloP3ooOl0o?Ok0?ono`020?ooo`090?ooo@3noo/0noom0>[/j@3WfMT0oocj0:n@U@3G
_L00oooj0080oocm01h0nooo0?ono`3bn_`0o?oo0?oho`3on?/0ooKf0?oll03/onT0k_gN0>3F^`3=
X8d0k>O70<oJ[`3HhK80e]j]0<C;U`3GgZ/0g]jl0?omj@3onoX0lN;U0?oan@3onOl0f]f^0=_VY03X
ljl0/[mg09RVF`2<WDl;0?ooo`002P3oool0<`31hHh0c^VJ0<oVV02HYF00I6l]0;o=S`3:gId0d^^Z
0<O_Z@2ljZ80d?o70;Ck`@16Ng<0h_oo0?cno`1fJWP0fM:h0=3A/P3gool0n?oo0?Wmo`3on?l0ooWo
0>[flP3eoo/0oogj0?okn`1QMG@0Af]W0>Ooo`3eool0ooko0?olo@3ln?L0g/W@0>C?eP3kool0loko
0?olo`3omOl0nocn0??on`3oo_d0ooSj06/o?P2HLfd0_JBM0?[jlP3kooX0nOoo0?_oo`030?ono`09
0?koo`3lood0o?om0>odl03nood0ooom0?ono@3imO@0i^3P0080oocm00<0j>;R0?koo@3oool00P3o
ood0EP3oo_d0oocl0?olo@3omoH0no7`0?ohn03om_@0`/:j082:PP002@@0R:RS0=Cgl`3^ool0l?od
0?ooiP3/kLD0inJ^0=OQY02oijT0Y=2M086cPP2^gJH0cNRQ0=cWX`2@SU<0T85F08UnD01]MBX0MH8c
0=3SX`3?hih0am^D0=S^YP3FjZ/0bMjU000?002me9`0e^jb0<cWX03:iYT0eO2S0<CQWP1JOTh0Qjj2
0;KS^021[gh0a>b]09RkM`2`cXH0cN:G0=o`Z@1BIB<0YKUd0>Ch/@39gIH0f>VS0<kOV@3XnKD0f>VU
0<WLW034eiL0dNRT0<SVW03OkZT0fM6C09nAE02LTE<0d]>G0;SFT03Ook`0_mfE0;O3P@1<>`<0dkZ4
0>71T01XFbH0KWPk0<Kc[P1cSeD0eN6i07B0G02Q[Y80QYIk08NQOP22XGL0R[1c1@3o00000`3<gZ@0
o`000?l000080?l000090>KlZP31bh`0]9Uk0?oojP3lonH0bnVY0;c_X034hYX0c>>O0080bNBO00<0
c^bV0=_i/@3<jZ000P3o00002@38j9`0bNVM0<WYW@3;ii`0bmbE0<kOV02M/FT0cnFL0=7YW`050<gW
W@150<[YW@35jIl0bNfS0<k^Y@38iYh0an:K0<o]Y@3;jJ40`n>J0<7SV@35jIl0dNbU0=_PX03DfYX0
[k]i061_;01>HQd0O9I?0:[5OP3EmJ`0anVO0<CXWP39jJ00cnJP0<cSW@32fI<0fo:/0<GLUP3Om[00
fO2Z0<;IT`3KlZ`0`mZD0;G@R@1DMRX0OYE?0<[NV@2<Xed0/m690=;WXP3Md9T0K5LR08eh@`38c8l0
h_6^0<oWW@3AjIl0c^:J0=3QVP3EiIh0g>bU0:fnM`1gR440OY9:0<_QV03Lljd0cNZZ0<SSX01XQ3L0
d^nO0<CQT@31gI00cNJT0<gUY`3Djk<0c^F_0<gUZ`3:j:00c>NP0080b^RP05`0cO2F0<W[U037ji@0
`nJD0<GVU`36jIT0c>nM0<W[U`3@lY`0bnnE0<k^V@2_aX00U:UV08jUG`1ZQCH0NYM50<?SSP3>jiT0
bnNJ0<oYXP3?j:H0cN>U0=7Y[@3FjZd0amNH0;[9R03?h9X0c>BJ0<S[V`36ji/0a^^M0<WYW@3<j9/0
_mn<0=;^X`3;i:00amZR0?_og`3kon<0LGmK0=7T]`3Bl:X0b^fK0;;BR@3honh0o?cn0?ool`3SjLl0
e^Ba09j`LP1gSd<0NIA50<_XV03;jYX0cnjP0<WYW@3:jYh0e?>W0<WSV@36g9@0NHm70=CXX`3EjZD0
bN2L0<[QW@2H/Fd0fo^_0<3QTP3Jl:L0eNBO069S:@3KfZ@0blZN0>7S_P3DfKT0m?oZ0?;ol`3oooH0
eLS20?omm03onnd0c]Zf0<KJZ@3?kj`0anJR0<CMW034aiX0fmFa0<S5]P3kno40oOcg0?Sgm@<0ooko
0P3oool02@3oood0oook0?_oo@28RXL0oo_k0?K/jP3ee]/0hlW<0?oonP020?olo@0=0?_oo`3oo_l0
nooo0?GfnP3onOd0oo[j0?okn03kl^/0n?of0?_om02/WY<0k;^d0?oni0020?Koh`0?0?_oh@3Ull80
am>Q0=ST]03GgkH0b<f]0:JYS03FfKX0oooS0:>fM02Y`GD0/<Qj0;WAP`3>jIX0bNJF00/0oooo000:
0?ooo`0c0<oW[@31eiL0fNj[041A2P2FZ5h0^]:80=?^Y`35iJ@0`>bg0<Gea@3Hond0M<BM04EcIP3[
ooh0200005E;<03oonX0o_oc0?coo`3lnol0n?Oo0?comP3oo_l0n?oo0?Ooo03oo_d0kng`0>Coo`1n
[Zh0fo[o0?Woo`3im_d0n_Wg0?ckn@3okO@0`Jbc0?coo`3Zm?H0ooco0?ojo`3nool0look0?omo@3o
lO<0J40n071BBP2gY9d0oooh0?_on`3kool0o?oo0080ooko00l0o_oo0?coo`3kooh0n?[i0?WknP3o
ool0ooko0?WemP3MfMX0oogo0?cfn03oo?l0oogl0?_on`3lood00P3noo/00`3ooo/0nOSd0?Whm002
0?oonP1A0?oln03oo_P0nO[/0?oom0071000004001@I4P3/o_80l_of0>kojP3iond0nOON0=SL^@3>
l;@0_^Rj00Q04`2=a8d0_n6G0=3PV@3lo<00Z9I`06iO=03UjId0Tii?0=SRYP3Vl;40dn2K0<kMVP32
dIH0c]nY000?001;HR`0cnN]0=cg/P3:iJ00b>BW0<g//02`f9`0e?g50;_V^036lLH0F7eA092bO`23
XFD0i_n`0;O>O03DiJ40VZ]W0<[KU`3Gj:@0amJA0>Gd[`1?GQ/0@U4>09ZYJ03KijL0e^fW0;[YV030
g940i>2P0>WOX@3YhJ00GF@P0=kYY036fY80`>NH0<c^X@2YYFH0HE4F01/6002VX6@0GelQ0=OMX@3M
iK80HGY@0<_^aP1:MeX0CWUN059`EP004P00`]fV00@0o`0000<0g?6h0?l0003o00000P3o00000`3M
m:`0o`000?l000050?l0000<0=gXYP3SbJH0oooX0?[oh@3:jJD0_o2N0<KTVP3=i9h0b^FN0<[XX037
iih0bn^R103o00002@39jY/0anRI0<[VV@3BhY/0X;5Z03U=1@3>i9/0e>bR0<gWW@040<cXW@0?0<[Y
W@37kJ80_n>I0<OWWP38iYh0cNRQ0<GPV@3<ij00c^bT0<_YX@39jJ00b>JN0<_OVP3=hYd0gOB^0080
d^VS03@0hoZd0<cSW@1:GaX0>Dh90;G9Q03NlZd0a=^E0<SOV@34fiD0f_6[0=O^Z033fY@0cNBN0=3W
X@3>iIl0cNBN0<[UWP3CmJP0d>NO09jbJ`2G[VH0f?R]0<GLUP3aiZh0SGU40::>F@3Xk[00bmbH0<oY
W`3DkZ@0dNNN0<[NUP3Fij00c]nH04=D3@3Jjj@0e^ZR0<cRV@3;hYX0eO:_0<o]Y`1kVDl0M9=70=Sg
Z@3?kZ80a>:J0=;_[038i:L0`MfR0<gZZP39jIh0b^RN0P39jIh0G`3:ji00bNZA0<SZT`3<kI`0cnjR
0<o_X`37ii/0anJH0<SWU`39jiD0a^>A08nSGP32eI<0c>6L0;kJS`3Jn:h0c^jU0<cYZ@37hjT0k_oJ
0?GoiP3gon@0looF0<WMX03FiZL0d=nN0=CXX@3JlZP0a^^K0<G/V`36jid0bNVM0<cXV`3;jYX0b^JL
0<gVY03@i:T0c=V^0?Sog03Pl<<0_m6M0<oZX`35iYD0f_Nd0?OojP3kn_P0l_GT0?Cjh02N[7/0//B8
0<gSVP33fhl0e>nN0<WVU039iYH0`^:F0<OWW037iI/0b^BK0=kc[P2ndhh0eNVR0=S^YP3>iIl0bn:L
0;kHT@34hiD0^]V90<KLT@3?giH0G64O09JGF`3GfJL0g^Bf0<[EZ`3]on00m?o]0??_i02_YI`0oo[_
0?okj`3CgKX0e^Zi0<[[YP3;jj80b^FN0=OPY`3Mg:`0^[ZR0:b^X03dm^/0oooj0?Win@3fm_P0ooko
0080oooo00T0ooom0?oon`3cnOD0JF]X0>oQh@3omO<0n=WN0<N]/03oooX00P3oo?d07P3kool0ooko
0?OkoP3inO/0ooCf0?ogm03olnd0oo_h0?Sil`3ko_L0h]G?06<f<03aglT0l?gS0?Gok03ZomX0jOo=
0=O^]P36gZ@0c^F_0=;X]`31eJ@0KH5<0<OLY02A/FH0^mj>0=SkZ`3:kId0`>FE0<K]W0/0oooo000:
0?ooo`0e0<kO/P2HZg@0QYYK0=K^XP39hY40c^nP0=Cj/@34kZh0W<bR07BWQP1QWhP0?HQa0=;di01i
Q7H0[jB80<?4R`3`o]/0l?_[0?omo`3mn?l0oogo0?Sol@3loo/0nooo0?Chm`3gm_/0mooo0:?MgP1[
Z:T0iooo0?cno`3onOl0o_ok0?oon`3on?d0bKBk0?coo`3`n_/0ooWo0?ojo`3oool0m?ok0?ohn@3U
dM007P000;fTW@3on_40mo[a0?con`3lool0o_oo0?ono`3nool00P3lool04P3_lO00loGd0?koo`3i
nOT0ooko0>kZj`3Nf]/0oogo0?Wcm@3lm_P0ooko0?Woo@3kood0o?om0?con`3nood0o_ok0?cmn080
oooj02h0nOSc0?oomP3oon`0ooGU0<:YY01OAD@03`0008>4O`2d_kL0j?g^0?Oom03in^X0j>cA0;kI
Y03<l<@07E8V05N@F`2ojIl0c>JO0=?MX03Wg[<0dLVJ0=_RU02GX540k>fd0=?GW02IWel0CePG0>G`
]P3AgjX000/00;75T00<9000^mJA0<3MV`36i[D0_=nW0<S`/@2liZL0boG50<_ac00TARD0^m^b05Id
?P39jIH0e_:N0P2kchX07`2AYF00QIUD0:6bK029V5<0/l9o0>We/`1[McD0en>Q0;[AR@3?ojh0c>jQ
0=ONVP3YjZP0fMnI0;K2N02@Td`0fnFL0<?]V`2njIL0b]B?07ii>@0d;000_[em0;NcM021L3X0f=JU
061gB@26ZGl0JYMh06bGN`2G[iL00P3o00001@2mf9<0o`000?l0002nhid0k_oA00@0o`0000<0d^VS
0?l0003o00001@3o0000303SkZX0`j^50??^d@3ZmLd0aNBN0;oaVP3<j9d0d^RP0<_YX@3:jZ40a^JM
0<SXW@@0o`0000T0anRI0<KWV03;iiX0gNfV07f=AP3JkZH0d^ZP0<?MT`3<j9d00`3:jId0A03<j9d0
bNVM0<7WW036jZ00cNfT0<WTW@38hY/0dNRR0=;YX`36gIL0aMnH0=;]YP3Bk:D0an6J0=OaZP2lei00
an:K0=cf[`38giT0c^>N0=3QW@3Dhj00^/>209VUH`1KLR`0XKQb0<[QV`35g9H0dnZT0=_b[03@ij40
enjX0=C[Y@3CjZ@0bnNM0<CVV@3EkJ<0c>2I0<WPV03:jYl0g_F_0>cSZP2[VV@0]:=]0>?/[@3=hI`0
eO6V0;GAQP3Dk:80cN>J0=CUWP2Y^W<0h?6Z0<CHT03IkJD0GG<Z0;kFS033giD0bnNM0=ObZ`2ed8T0
`=jD0;cJT02iehd0c^jU0<SWX`32hIh0cNbX1039jIh01@39ihd0bnVC0<WYU03@kj<0d^fV0080cN^U
05L0d^fX0<[VW03>kJ40cNNM0:FfLP2]_G`0c^>N0>Oo^@2achL0`^6M0=7^]P34h;00m?o]0?Ool`3g
onl0l?oG0=7UZ03DijL0fn^Z0=?WX035giD0a^^K0<G/V`36jid0bNVM0<cXV`3ClZ80an6H0<kTX`3>
hZL0Kg];0=3L[P3=fjP0e>J/0<gWX032hI<0c>NT0?_oiP3noo<0n?oV0?coi02R/gl0j?[00<_PV`33
fi40a=n@0<OTU03AkYh0c^jS0=Gd[P35hi/0b^BM0=O/Y`3EjZD0[<1i0=?YX@3HkjL0bn>I0=G_Y@2/
b7/0dNbO0<OLT@3Gii`0Yk5Z05aS803Vk[D0e^2/0<cIZ`3Ah[h0d^O60?omkP3?a[d0ookc0?ool@3d
o]`0jO[=0;oPV`3<k:<0f_R^0=?SXP3HhZH0oooT0<kA_03fn>X0ooof0?_kn@3moOl00`3oool02@3o
ood0oook0?_oo@0<3P/0oo_k0?olnP3C];T0b[2c0?oonP020?olo@0N0?_oo`3oo_l0o_oo0?ono`3o
m_D0oogd0?onm03onOL0oo_k0?Wim`3on_P0QEiG0:F:N@3^m]l0mOo]0>_og03>ik00b>:U0=G_[P34
gZ40`=bQ0=Kb]`3<jJL0anBQ0<CVVP38kIl0]mb>0<K[W@3?m:H0bNnR2`3oool000X0oooo02H0S9EN
0<gKWP3Ik:X0cnnS0<_bX`2ml:D0__Fa0;Sb]`1VXW`0P;fN0<Wlk@3]ool05B860=g^]`32h800a^RA
0<KUXP3=i;H0lO?`0?oon03oooH0n?of0?Gon03hn?P0oogo0?_oo`1TRY<0J<K808oXkP3VnOl0ooCo
0?ojo`3^onl0o_oh0?oal`3gh^L0nogl0?Woo`80oo[o00d0ooom0?[oo03onOL0[I^I00d0003Bb[l0
moGY0?_on@3mooX0ooko0?omo`3oo_l0oooo0080nOoo0P3oool02@3dm?@0ooko0?ono`33`L80ooko
0?omoP3oo_l0o?Si0?ono`050?coo`1B0?;fm@3joo/0n_cg0?_mnP3noo/0nO[b0?K`h03ooO40onoa
0?oan03olol0B34i02DF6@26RGh0^/>b0?Sok03Ah<40cMbe0=S]`P37jk/0KIUV0;[`]P37oKl0_o:`
0<W_YP35hIL0aM670:R[IP2fZGD0a;V309RBF03EdiP0@dHA0=OM[@002@00hO?10<7FWP3Qo;T0/LnA
0<G^a01XTV@0CG=202mC8`2adZL0R:R101Ph4@37j;d0`N>`08V`K@2XcXD0e_:X0;cGT032g9D0b>:K
0<KMU`37g9L0d>BM0<oSW02V]g00U:EN0<[KU03<gIT0dNJQ0<WWW`2lgY80a^fN0=?SVP3Vl:T0V:=N
0<SVW03<kZ@0`MRD0=c/Z`2N[F`0aLfA0=oMY03JbYH0VYUP09^TJ`17DQX0KWY808nMJPP0o`0000@0
nooT0?l0003o0000]/>;103o00001`3@kJX0o`000?l0003>j940WJYR0::=H03@c:T00P3o00000`34
mIX0c>BF0=7VV`020?l000030<CVW03;kJ40a^JJ0080o`0000T0a^NH0<WZV`3<kIh0cn^N09BTG@3T
m:d0bMfE0=C^Y034h9D00`38jYd0AP39jId0b^VM0<[YW@34i9/0an:K0<cSW@3MlJ`0ho:_0=cWY@3F
gih0e=ZJ0=?LV`3DgI`0e]nN0=kYY`3IiJ<0dNFP0<oTW`35g9H0f?:[0<gWX03Aj:80dNJQ0<_OVP3E
jJ@0b^6K0=[aZ`2hchT0c^FO08^RG02G[VP0QYeG09jeK`2id8X0aMbF0<WUV`3>lJ40ennS0<OMU03E
kjD0_nBG0<kYXP3FdIL0X9EM09>8D03?gIl0f?>^0;[LS`3=kJ40aN6F0<OQU`2M/fX0RYiF0<OKT`3A
iih0e^bS0<[RV02I[f@0fNbK0=3RV03GijP0a=JH04iR8`3=i:00dnfS0<OSV03=jI`0cNVN0<SWV`38
ji/30<SZW@1N0<kWU03?ii/0b^BM0=S`]03Ik[H0cnJ`0<CJZ@3>h[40c^:]0<kU[@3;gj@0e^6W0<7?
T@2dahD0foZ^0<k^XP32iiX0b>^W0<GTZ@3]om`0mooX0?Soj03eomP0eN^]0<KIV@3Chj80c^:K0=cf
[036ji/0aNbK0<K[W@38jYd0c>RM0<g/WP36h9T0g?:a0=CVZP3HhjT0[[Um0=KRXP3OkZ/0cnFM0<?J
U03BjjL0b>6M0=Sa[@3AjZH0cnRV0>3k^032gIX0_]^H0<WXXP3?kj@0bn^O0<?UV038ij<0cNbY0<_X
Y@3EkZ`0dnRU0=K[YP1iSDD0cnFL0=C/X03>iYP0cNRI09fbK@1/Ocd0dnBN0<[KU03NkZL0eNFN04eM
703DhjP0g>fg0=k_``3AhKX0mO[V0?oom03ck^P0m?3W0?ook@3Pjl/0b^J/0<_[Z036ij00f_F^0<SO
V@3BgK80o_oT0=gRb`3Nh]40l_?]0??cl@<0oooo00T0ooom0?oon`0>5100IVQU0?ojnP3oo?X0d[>h
0?oam03oooX00P3oo?d07P3kool0ooko0?ooo`3oo?`0f/O10?ool@3noo40b:j_0=bha03fm?T0n_ck
0?SMeP2LM6P0oo;S0?oji@3ek]40g=bZ0=_NY@3@eYH0eMjO0<kIW@3Xm[T0c]jM0=GVXP3GiZ<0e>2P
0<cHV03LiZT0fnFX0=;LW`/0oooo000:0?ooo`0e0;>lJ`3LjY/0b]n@0;_PT`2kiI/0]^fZ0;[f^020
_hH0>ge=093DY@35l=@0KFQU0<W@Y037iYX0a_^?0<goV`34hil0c>>[0=CT_@3konX0nOo`0?koo`3g
oo/0ooom0?oko`3iool05TIB03NPY012XjX0lOoo0?oho`3onOl0m?od0?Snm03oko80hlg@0?kno03k
ool0oo_o0?ojo`3oo_d0o?om0?7Vi01jJ6H020000?7_h`3oooH0nOkg0?kon`3oo_l0oogo0?ono`3o
ool00P3hood01@3oo_l0n_Si0?Kdm@3oo_l0l>k_0080k^c]00@0n?Kg0?klo@3dl_<0oogo1`3nool0
D03nood0o_oo0?koo@3ln_l0ooWo0?olo`3hood0moof0>kli@3Gh<40f=nn00@8000l@BX0c]_90?Oo
l@3]n=H0n_oK0<;JYP37jKH0Iim^08_?UP2RjjH0XN:60<gnX`3Zn[<0cm2D0590401ZFRL0j=fU0?oi
`P1WIc<0XZEf01PS001aPE80c=nX0<7LV@3InKP0NjUh029=8P1@Le<0Rjb=00DS00003P00f?W20<?V
[037kK@0Z=2K03EL8`2be8P0d_BZ0=Og[P3;jJ40e_6Z0<cVW`3@iil0a]fE0=?YX02I[FD0Z;=^09jC
F`2SYfX0anRQ0<ok[P2dj9H0g^^U0<STV@3ClJL0DfPS0=k^[@3Cj:L0fo2_0;[8R`1mP4L0QhYA0=CR
Y03?gY/0cNBL0<KTVP2[d880a^RK2@3o00000`3hn=`0gMjl05]X<P040?l000060<g/Z03Cl;00`]^:
0<7NQ03=fi00_ZUj103o00000`3>iiH0o`000?l000020?l0000>0<W[W`34iYT0bNVM0<GUV@37j9T0
c>fN0<OVUP34gi80Ri]D0=;RV`3:gYH0f_J[0;CCQ`38jYd20<K[W@160<SZW@39jId0b^VM0<3KU03?
iZ00eNJR0=_ZY`33cX`0QHY:06a^;`15A@L0A4@607Qh>P2NW5l0D4L<04e9302`]WH0g>NU0>;c[`3=
j:40a>BK0<S/XP3?ljT0bNfS0<OYW`3;hY`0bN2J0=7XXP37gYP0d>NQ0<WPVP3;hY`0c^FO0:JmM`1O
MS00UK5W0<S[V@3EkJ40c>:I0;kHSP38kJ00cnZS0=gKX02>Pd/0J5lV0<[JV`3>k:H0_MnB0<KXV`34
h9D0c^RN08FMD`3HkZD0gO>Z0<?IT03@iYd0b>2F0=G/WP29UTH0Z;AZ0<cGV`3>g:40]LB909^^KP3=
hiX0d>RL0=ScXP3?jY/0a>>C0<K[V`<0b>^K05h0cN>H0<kSWP3<hZ40k?o;0?Gof@3`omH0dnFm0=_[
a03bomL0k_oC0=KV]@3Khk00T9]Q0;c?S@2ogXh0co>L0;gTR`38kYL0anZH0<kYYP3AijT0c^6Z0=3Y
[`3GkJl0fnj^0=c/Z`35fI80bN>I0<K[V`35k9/0a^^M0<SZW@3<j9d0eOBX08:LE@2O]G@0bmfO0?;n
`03Bg9d0XJaW07n<AP2GZfH0g?6^0<KPV@34iHh0dOBF0;gOR03:k9P0V;Q]0=3bZ03<kJP0doNa0<c`
Z034j9h0`nNM0?3oc@3Vol@0anBR0<WRX@3Bij@0cN:M0:o3N`2G[F80e^jP0=;[VP3@jiX0gO2^0;G5
Q`3Di:<0c]nK0=CXX@39gIH0D6<Q09NYK@2mcYL0jo_>0=WX_`3lonl0ooof0>_VhP3NfMH0oOk`0?Gm
i@3Hlkh0fo^l0=Wm]`36iYd0`MnG0<kK[@3Tk/T0g>;60>S]e`3@dlX0o_ok0`3oool02@3oood0oook
05ILF037bLH0oo_k0?K/jP3_d=D0b:ja0?oonP020?olo@0N0?_oo`3oo_l0o?[m0?ojn`2mZZ<0n?o[
0??li`3oj>X0omg/0?omo`3Zl?00oo[a08aMD`36X9D0m]W90>O;/`1NBA`0DD0<04Pl0P1OE1`0YIm[
09REH03PgjL0g]fT0=K?V02f[GH0T8M@05554@1DB1@0QWU52`3oool000X0oooo0340XLAN0;SGNP3?
k9P0`nRU0;o_]@2Be:H0HJIi07NlS@38nl<0_>:W02Hh002BXfl0dn2J0=S^V`3GoIX0bmf70<_YZ`3>
j[T0oOo[0?Wom03kooX0oo_o0?olo@3nn_T0ooko0?Woo`3Am?H0a_oo07:a^P3bool0ooOo0?kfo`3b
ood0m_Sc0?okn`3Re]H0ooom0?_oo03ioo/0nOoi0?kon03oooH0ZYNA034L5`1LCDP0oogh0?omnP3o
ooX0ooci0080ookm0P3oo_l0I@3oool0o_oo0?kon03mo_P0oooj0<_5a@3Bc<`0oo_m0?omo`3oood0
o?kk0??jl`3loo/0ooco0?oio`3fmol0n_go0?Smo`3oood0ookm0?oko`3mnol0n_o_0?kom@3ikol0
nooo0>_mk@3honl0o_o[0?ook03nonl0looe09n/XP0i:b/03`410?com03eo>X0iO?I0>?he`38kL40
]>2[000J0020]gH0Ok9g0<;/aP2ogkP0d=^O0;gBT@3?jZD0aMjJ0=7LY02`^8L00Pd005e]@03IjkT0
b=bQ0=;[/@2?]hD0KHiS0=7c`@32hJH0c=FD0=SKYP0H:`00`N6b0<Wh`@0_Pel0K;bG08^_K`1]Rd<0
NZaa07f/M@2``h<0c]RI0<[OYP39gil0c^N<0<WeWP34lJ00c=fG0=CYY03?jZ<0Q:9J08ZXHP2=XE`0
f>bW0=KWX`2GXf40TJ1M0<SVX038jJ80bnVS0;JoP02YYf`0M6Ta0>7MX03?gYT0e>^S0=ok/03;iI/0
`MnE00P0o`0000@0i?O:0<KMZ@3?iJL0amfM0P3o00001`3PjK80cMZR0<CUX03;mZH0_>>D0=;QWP3I
bIH0103o00000`3CeY<0o`000?l000020?l0001G0<kUW`3EjZD0eNZU0<CJTP3IkjL0bMfF0<oSW02<
XUX0cNNM0<cXW@3:jId0bNVM0<SZW@34iYT0bnfP0<g]X@3Em:P0b^BJ0=kdZ`2DXE/0UJIP09jjL039
j9`0cnnT0<gYW`3AjIl0c>2H0=CZXP3=iih0d^VQ0=[[Y`3HjJD0d^>O0;72OP2L[FT0TYiL0:6]J`3=
eYD0fn6Q0=cQX@3Gh9l0a=nH0=Wd[@3@kZH0b^ZQ0<?WW@30i9X0aN^P0<OaY@32k:00_n^N0<?/WP27
XeP0GVlX0=OVX@3Jl:P0anNL0<cSW@3He9L0Sh=9075V;P3GiZD0a>>M0;_TUP3NjZP0dmnM0<OHTP3;
hYX0`n>J0;[TV03:kj80fNZV0<KTW037k9l0b^2G09^ZI@3Ij:L0eNRV0=Sa[@3Hj:L0L6`_085k?@3O
l:X0aN^N0;k[VP3BlZH0b^ZN0080co6T08X0d^ZP0=?ZY03>hj80cMjX0>3`_`3^o/l0jo_<0?SofP3A
iZh0cNFY0=G[ZP28Tdl0e>BM0<_OU`2mg900e?JZ0<;WVP37jId0b>RM0=7UWP3Chi`0en2M0=KOX02i
`X<0RiID08nKF@3Sm:d0amfD0<SWV@3<kI`0bNbJ0<c_W@3Elid0d^J?05iD3@1`G240K58Q03L`1P1>
DBH000P00>SZ^@32`hT0VJ9O0=7aWP31kY40bOFF0=gXW03NhI`0eNRX0<OQXP3Pmkl0o?oF0=SN[P3C
gjd0bn:/0?_ol@3noo@0dn>o0<OM[03AjZT0c^FO0<[NU`3=gYP0amfD0=OaY`3<j9/0b]jG0=KUXP21
TE00e>RS0=7UWP3AiId0d=nL05AO8`2NYW<0oooV0?ook`3koo@0m_od0?CilP3Ogmd0hN3N0?oon`3n
oo40n?oW0>She03WoL`0foBm0<[WY@38iJ<0_=2M0=;N]P3<c[T0hMgA0?oil`3ono`0oocm0?ggm`3o
o_d0IVAW0?koo`3kooP0o_od0?oPi03T]K/0oo_h0?ono@3oo_`0nooj0?oomP3hl_H0oo_o0;>WV@3o
onX0n_SQ0?oimP3Tc]X0oo[o0?Seo`3oo?l0oocj0>WW`038cIL0fMjV0=SNX03GgId0en2O0=SQX03K
iZ@0fNBR09JSGP2@WEP0^<N40=3PW`3?gih0fNb/0<cOW`3;gYh;0?ooo`002P3oool0<@3=li00d?>I
0<c]WP2khjL0b?O303mmE01b/hT0_oc@01<j0`1]QdX0g^fZ0<SYY03<i9X0bn:@0<WZT@3>eXd0`MnY
0<g[a@3oo_/0m?gj0?Gnn`3on_h0mN[^0?ono`3oood0kOOf0>Ooo`3Kool0TL380?7oo`3noOl0oogo
0>cmm`3oood0oogk0>3HeP3onoX0nogj0?Son`3ao_@0o_of0?chk@1jHe/0BC0[07ARGP3omO<0ooOe
0?onnP3ooOX00P3oood0IP3oo_l0oogo0?omo`3oo_l0o_of0?oon03cln/0f]GB0?okn`3omoX0oogo
0?[jn03alnh0nooj0?konP3cj>`0oo[o0?3ao`3ko_l0k_?f0?onnP3ooO`0oo_o0?omo`3lonl0o_oa
0?omo`3_mO40nOo_0?_oj@3oonX0ooS[0?golP3aoo/0mOom0;:OX`0?000000800=3Gc`3hoo@0mOo_
0<o/`03:k;T0^N2W04ii@`004`006TTY08^eT@3PoKd0g?bi0;_OU`3<kJH0dNJ[0<gKZ00S:0000@H0
0=OP/`3Jjk@0`mRP0=Odb00J?Q00^nVX0<7_YP3KljT0g^R/0>G`a@2<YG/0[Mb^02R6H@1ecJD0/MFH
0=cj]02VfjD0b_k=092RIP3Oij`0e^Rd0=7WZ@3Fki<0_^nD0;7WT@3BlZL0a^:H0<3JT`3DjjD0cn>N
0:2_K03Lj:H0d]jL0<gNVP3Ek:H0SjeU0=?aZ@32g9D0b]2@0=GCUP1HBA00HeTN0>?YZ@30ch`0^=:;
0=;/Y@P0o`0000l0m_oS0>7ia`3:iZ`0eNn^0<[SX@3IijX0<3T004]@6P3Bfj@0bnVS0<;XW@3Fn:h0
gNNZ0>GEXP3:hj800P3o00000`15A@L0e]fJ02hi00020?l0000909V^J@35fI@0j_ji0=GVXP3Tn;<0
aMJB0>;c[`1AHQh0eNVR00<0bNVM0:@0b>ZM0<K[W@3:k9l0bnfP0<[YW@3<j9d0ennU0;oCR`38dXd0
c]nH0<_[W`3:kj40c?>T0<;TU`39jId0cn^P0<_WW037jI`0bnfP0<WYX033hIT0d>ZS0<WPVP36fiH0
e>>P0;c8QP1RJbX0DeTI0;RjN`3[lK40f>fX0<;GTP3:i9d0dNbU0<OWWP3CmJ/0b^jT0;OQU@32kZ40
c?R[0<3[W033gI<0fNVR08jMF011E`l0do>X0=3WX@0a:`00GU8H09jCF`2ncXd0e_N`0<SaY@3CgY`0
fMjN0>Sc/@3?jZ<0b>jS0<7]X03;kjD0a]NC0<k/Y035jj00g?N`0;[>R@1CGad0e^NS0;[AR`3>gi/0
knf`09RFF@30dHd0co6W0;gVVP38ii/0`^6E0<c/X033iIP0bnFK0<kUW`3Mlk80dnB]0<cJY`3komP0
nOoF0?Ood`3@iZP0e^n]0;K@Q`3DjI`0c^>F0<cRU`3<iYl0`]^G0=;]ZP39hZ00e^fY0<?DT03Xmk80
E64K05EP702@VeT0dMfK0>3_ZP37gID0cnNM0<g/WP3EmZL0anZH0<g`WP39iI40g>BA06ID4P2eX6T0
f<>F0:RXQ00oAR@010/006YX@P3Jej80XjQX0<gZV02kjI40a?2I0>OZY`3Fd980f>J[0<_SZ@3FkKT0
o_oK0>3L^@3Qhkh0e>Bm0?_lm`3ln_/0jOKJ0=W_`@3>ijH0d>NQ0=7RW031d8d0c^BL0;oIS`2ngI40
enfR0=;SW01IKBP0bn2K0=O]Y@3<hYT0c]fJ05=O8@2NYG40o_[Q0?oml@3ionl0k?kV0?_om03^lNP0
bLS60>kZj@3oooP0oooc0?[oj`80o`0001T0d>n/0<SYY03Djk<0eN:f0=_Ja@3Fd<80oogf0?c`lP3o
n?T0oogm0>[Vi@3mn?`0o_oo0?Gon03co>/0om_P0>F]]P3onOT0ooko0?ooo`3kooP0ooof0?oko`3n
lo/0/JNM0080ooo/01L0mnkY0=cAf@3il?l0oo_o0?gno`3/k^T0kOo90<ONVP3Ek:P0dNRR0;gDSP36
gIL0e>^S0<WPV03=i9`0cnNM0=;ZX03=iih0f?BZ0<[UWP32h9X0bNRR0<o`Z@0;0?ooo`002P3oool0
4`3:gH`0^=NA0<of]`0B@0l001<00<__`@1WQ5@0@eXV0=o`^@3>h:H0an6T0<G/Z`2ogYX0e?F`0<Wb
[P39gjh0iooa0>;on@3coOl00P3`ool0703doOl0hO7a0?omo`3gk_<0k_oo0;3Qf`1PT9@0P:F^0?;o
o`3cool0koWk0?oon`3onOL0ooGe0=W=c@3ono/0n?Oe0?Glm@3iooX0no_a0?omm00P1`00@BPS0?ok
n03oo?X0no?`0?oon`3nooX20?ooo@1V0?ooo`3oo_l0oogo0?ono@3oooH0oocf051=B03oo_d0o?[k
0?ono`3hm_L0n?Oe0?WelP3oooP0ookd0?ohj03on_X0oogo0?;enP3lood0oooj0?ono`3onOl0oO_o
0?Oom03gonl0ooo_0?Wlh@3]klX0dM>/0<oA[03jon@0l_kX0?Oon03^mNd0oogj0?omn`2e^KP00082
0:J_ZP2EXID0j_oP0<kW_`3ImL@0`n:Y0<SY]036ikX0^n6b062@EP2<]GT0_>FS0;CNW02liJT0d>jl
06IZA`1RGCd0dLj[0<WIZ03?gk80BeTh05R0CP0SHQ`0@8=00:SU[034lK00en:X0=;O/`005`00ZnJf
0;K`]P3In/40bnnb05F4C@1BPD/0b>N^03YA6@3MlKH0bn2O0<3MR`3:lY`0`^bH0<7OU@2kfHl0an6H
0=[dZ`3>i9`0h=jQ0<_LV03;iYl0fonf0;GIS`3>gi/0eMjM071b<`3?e9@0cmRG0<GDT@3=dY80EU@G
0<[<S@35giP0b>jS103o00008`3AgI/0o`000?l0003nond0nOoU0=g``P3Ck;<0_=^G0=gm/P36hYD0
cNRK0=K^XP0H;@00I74[0>G`[03FhId0knfb0:fFI033h9d0b_J[0<cSW@3CkjD0_^FF0=3gZ03<jZ00
c>>M0=cf[`3<hid0dnZT0=C[Y@1mU4h0c>>M0<KMU`3Lljd0e>jU00@0b>ZM01<0a^^M0<W[WP32hYH0
c>RM0<[RV02fc8<0VZ]T0=WYXP3Aiih0d?:U0<S]W`33jY/0b>NK0<STV@3Cjj40`mfC0<o^XP3?kj<0
bN^Q0080a^RN00@0b>ZP0<CVW02ohiT0`^JL0P37kJ80Q@3;lJH0do6Y0=;HV01?EAD0EUlN06=/:`0U
<000g^ZX0=GQW`3BhIh0e^NS0=?TX03Aiil0dnfS0=KVW`3Ah9/0f_2X0<W[W`39i9d0f]ZL05M>4`2U
WfD0h_Nd0;CHT02liIT0eO2Y0=WGVP1]Kc00`nVN0;o^X03:hI/0f>VU0<kSWP38giT0eNnX0<oYXP3E
jZD0h^^Z0:b^K`3DfIT0gNbY0<gcZ031jYh0e>^U0826AP3LhZ80cn^Q0<kZX03?jj40d^jT0<ORU@38
giL0bN2J04eO8`10DAX0Df@]0<OHXP3Dj:d0d>JU0=O`[033hiP0bo2R0=GgZP2edHL0@dl?04mG6`3M
hJH0inf_0=WRX`3CjJ40cnVO0<GTV03GkZH0dNJQ0=cc[@3GkZP0c^RQ0<[UWP3Bk:D0goVb0<WOU`3;
hIT0g^NV0:RFI03Rk;X0a>Bc0;o__`2fh[h0`N3100@8001=C300i^Nk09>EH`3;fYT0bNfS0<7VV@3B
f9P0U9IG0<[SXP39k:`0eoS30?7of`3oon`0o_o_0?Sol`3dmnh0oood0?Woh@3eomH0k?o10<gTW038
fI<0ho:_0=3TW`38giL0b>NK0<_XV035hY80bNFK0<SVX035hid0cnZS0<3GS`3CiZ@0TJ5S0=[Q]`3=
cZ`0cn6]0<gT[03NkL80mooN0?[kj@3Th]D00P3ooo@40?l0000a0<kW/03ioml0l__L0=cJc@3Sg=@0
o?Cb0?oko`3on_d0ooko0=CDe03elO80ooom0?OomP3koo@0e9bU0<>;V03onOl0oogo0?kmo`3iool0
oOgk0?oho`3oo?l0m>_/0:jVX`3onO@0ookf0?ohl02j^:/0oooa0?kok03nonX0jOo60=;aZ`3<jjD0
`>2G0<;RV@37iih0f?R]0;SHS@2lg940f?R/0=OgZ`3CkYl0cnZK0=3[W03@jZ00aN6G0<ORV`0;0?oo
o`002P3oool05`3VmK00cnjb0;[Q[01=O580PZf209neQ00kB180WjAZ0<38S@3LjZl0mOoD0;K:S`2I
Y6X0bMZS0>kog@3donP0g?om0=goo`3Vool0gOoo0=;oo`3Sool0i_oo0080ooco00@0LI2;05nDS034
m?P0eoco0P3dool02@3gool0oo_h0?oln`3ono/0dlG50?olo@3ooOd0m__e0?conP020?omm00702@9
0P1kHUd0oo7^0?okn03ooOX0oook0?clnP020?koo@090?koo`3oool0ooko0?ono@3llnh0m>[X0;Ze
/@3lnoT0oooo0080o`0005L0ookm0?onn`33^;@0N6aP0>WI`03oo?<0ooko0?;cm@3kooT0oooj0?on
o`3nnOl0no[o0?Won`3ioo40oOoO0?oog@2GTfH0fMRZ0=cR]P3HilH0ho?I0?_on03nooX0oooj0??b
kP3lool0XJFX01<H6`0A6QL0R9F107B5I@34fK00_]FQ0=Wa_@3;hk<0co6o08O8SP1MZFP0L<Ai07W5
N`33mKX0_>:a07NGKP10I3P0XlNI03iJ9`20Vfh0QZF306MnB01[PE/062`@0;?0U@33ei`0`N6_08>O
MP002@00^<NL0<[N[@39ik40H8MB07NRJP2C_XH0X<NB04MX<`3KkJl0amZH0<WWW@3<kYX0a>JB0<k/
Y03Bl:P0aMnF0=;/X`3FkZ@0e]^K0<gQW03DkjP0Zln50=oo]`3=g9T0i^b/0<?5QP2a_7X0eNJR0=3[
Y03AiJ000P3o00000`3DfYX0c>6L0<cZXP020?l0000308nEE@3o0000o`000080o`0001l0oooZ0=c]
`03Bjk80c_2V0:W;OP38jiL0bN^E0<?USP3IlYl0eN>H0=SSWP2?VUH0c<R;0=g6TP3Em:h0^>BI0=7[
Y037iI/0aO2P0;SQTP3Dm:T0b>:K0<COV03<iYl0d>ZS0=oi/P3?jJ80d^bU0=Wc[036h9T0`mnE0080
b>ZM0`36jid0X@3<kZ40aNFI0<_UV`3:h9L0MXM008nPF@3FjZ80e_2V0<CYV`3@mjP0`nRJ0<kZW`3?
iid0eNVQ0=3VW@3?jj00cNVN0<_UWP3=j:40anFM0<o]Y@3FmZd0c?2V0<K/X@2ojId0`^bP0;kZW@2l
iIT0f?>/0<;MUP2oeY00bMfH0<kJV02^]gH0W:9R0;FeM`36a8L0e]2D0>GWYP3<iY`0d>2I0>7`Z`3E
jj<0aNNK0<cZXP3Ff9T0`kn207]i?P3EkZX0bNfU0;WRUP3?lJL0aL64055?4P2mjI`0]NJG0=GQW`3I
hZ40c>6L09N[IP3?gY/0g>^X0=3UX03KjZL0d=VH09NGF@2DWed0a?2S0;;UUP3BkJH0YJMX09ZJG03B
k:D0`]bE0=Wc[03DkZL0b>FE0=;ZX035g9@0PIIE0:FgN`3Hj[00g>jd0<cPX`3=hj80d>VU0<CPUP32
gY@0`M^B065k=02_a840fnj^0<kQX@37eiH0b]ZI0<cMU`3LkJH0cmnH0=COW@3EgYl0d]bM0<gGV03N
j:T0f>:S0=_TY@3Aei/0a<F;0=[IX020NDD0KElh0;_J[P2cj;X0XnJj0:kK_P3=i]003@`008F7L@1L
Icl0Z[>80>C^^@35hZ00`n6K0=SQX02KY6<0bnRU0<?ZY`31i[00c^Bm0?_okP3gn^l0m_ch0?kom03d
nN<0fnbo0>Cl`P3To[L0e>ZR0=WXX`34d8h0d^JQ0<oVWP3In:`0do>P0<7QSP3=kJ80Q:=M0<WXY037
iIl0cnVP0<[PV02`a7l0VZMa0>cda@3;hJ00c^RQ0=GX/03Wm<H0h>?80<73[P3oo_80ooof00@0o`00
01H0ioW?0?_oiP3nond0a/:i0?S`kP3on?T0ooco0?oio@3lo?`0QXR70?ono`3oood0mooh0>oej@3o
dmh0]7^:0?oio`3ooOl0oOco0?_oo`3oood0oo_l0P3ooOl06@37`L<0oocm0?kgk@3oond0YjR808Z>
J`3noml0hNW20=KUZP3AhJ00eNFT0;72OP2AXUh0VJYV08:CC@31dX`0g^nY0<GFS`38fI80d>NG0<oX
U`2idX40RZ9H09VcJP34gYL02`3oool000X0oooo0340e_O00;gT^02bf[L0^Mg109njV@39dYT0e]VF
0=?@R@2:Sdd0FF@Z0=cY^`39`Xh0l^Rg0;6_QP3_onl0k_oo0=Soo`2Ncmd0?G:003amP`0fO7`0=gYa
07^f/03_o_l0n?oo0>?oo`0KAD<0Y^;P0=coo`3eool0nOoo0?[ln@3on?80oo_j0?ojn`3;^k`0oo[m
0?olo@3ooo/0moKa0?chk`2MSXL07`800<R_ZP3oo?P0n_We0?Wjm@3koOX0o?om0080noom00<0o_om
0?ooo@3oood00P3o00000`2_XJ40oO?b0?goo0040?l0000j0?okn@2COWd0l][@05Dm8`3on_40oo_m
0?ooo@3hno00nokc0?cnn@3no_l0o?oo0?Gol@3con80SYMP06IO:`1LBQP0XIMT0>7[]`3?jL@0e^gC
0?onnP3ooOd0l?Kb0?Woo@3nool0kNkb0?Kfo`3no_l0P8:104a?AP0T:1L020l00006001;DBl0F6Q4
05R5GP2[fZ`0[>:X07neN`1DP4d0RZj203=69P002000H75?0=3W^`2hf:T0BGe?06ZLM`30kLH0/mbb
0;WC[01TM5L0bmF`0:VfR02cah`0a^:U0;?<TP80o`0001T0S:ed0<SZ[P22]XD04Cl>0=GZY@3EjJ80
cNb`0<[NUP3Fj9`0Wkih06F3?@3CkjD0d>bR0=7]X03DmZ`0CfTR0=GYY03Qk:X0am:@0=7UX03FkJL0
a^6J096_I`2K]Vl0/lZ400@0o`0000D0QGTo0?l0003o0000`NFK0:G7O@040?l0000P0>?_a`3HkkL0
bnFT0<GWVP3=l:00c?2I0=SjY039ji@0cNnI0;gNS@2ogi<0e?>W0<O@S@1UEQd0aN>K0;WOU03Qk:P0
enBN0<_QUP3Dkj80d>bR0<[XX037iId0`=jF0<?QV@35hi/0i_nm0;gMU03>kZD0_]jE0<[ZW`38jYd3
0<K[W@2S0<SZW@39jId0a>>G0<[RV03JkZH0Y;A]0<gNU`36hYL0cNfQ0<S_X039kZ00b^bO0<3FS@3L
kJH0Z[Ma0::cK02R^W00dnVP0=3FUP3Efi/0eMjM0=ORX03Qk:X0cmjK0=?TX03Cj:<0c^>N0<gTWP3A
j:80dnBP0<kOV`39gYT0e>^U0<?NU`39iil0_mnF0<c`YP3?mJX0XLYn09:hJ`2[aG/0f>VR0=SYX`3C
jZ80^n6D0=?cZP3Jgil0c<Z=0;ZkO`3>k:H0`NVP0<O]XP31hiT0[;5a0=WRX@36lZD0b?BW0<oDU03R
h:<0h>^Y08FAC`1]LS80hMRM0=GPWP35iid0/]:90=[YYP3EhIl0X[Uc0=Oe[@33gYL0gO6/0<cMV@2Q
^7@0bN2L0<KMV@3@iJ80cnnL07jIC00Q>@00eNZU0;?6Q03Ej:P0bmjN0=GXZ039h9X0eNbT0=S^YP2@
Weh0Y;=b0<kQX@3Mn[L0cnjX0<CUWP3>k:H0T:YS09>NF@2W[VX0MgHf0:fWK@2=QTl0OGQ004e:4`0^
;`00AdLA096?G02IUfH0Xi]]09>8F`3JgK00cNnm0;;/^P2Cb9X07DLQ08B7M02_YiX01P0007N3K`00
3000GW]M0766G`35f:40f^Z[0<cGT`2V/fd0aNJG0<C]W`34k:d0`=f]0?col`3ooo/0ooSo09NKPP2J
YG/0d^N/0=gf/P3=iI/0e>RP07^7A@0U;`00_]6?09N^J02lfY00^MZ30=[kY03?kJ<0U[A^0<SQX03B
jjT0enfT0<[LTP3AhIP0^LF304EA4`3Fk:@0bN>J0=SZ/03Qkkh0lOGJ0?ook@3ThMP0n_Ob0?ckm`02
0?l0000b0?Wol03loo40n?[_0?oonP3:a<H0ooSm0?ceo03ooOl0nOOl08:3Q@16BTT0nOCj0?ono`3c
o_H0o?oh0=ZR[@3W[k`0ooWl0?ooo@3nooX0l?cX0>kcg03Ykm<0lOWQ0?Gfl03Th^<0g]gK0?Ccg`3i
n]P0lOJl0=?KW`3Nj;<0^lNI09NLI02FVUd0WJ5T0>CYZ@3Wk:`0hNJV0>GZZ03AeY@0_<5o08B9AP2<
TDh0SImC0;37M`3=i9H0c>2I0<GHUP3QlkD;0?ooo`002P3oool0;@2fiK40N:9l01m6:@1LN640>dh^
0?_ob@23RT@0U9Q<0=KQW@3<fJ40c]V^0>WT[03;bY@0d=N]0>_ol`3JnO@0CWF405=lSP2RcMd0eOoo
0=Soo`30o?@0CXJ30=gko@3Zool0f?Ce0>_oo`1b]k80]?Ga0>_bo03oo_l0ookk0?omm03om?80ooWj
0=S5a`3on?/0ooSj0?kimP3nnoH0ooge0:JGT01=<2X0dkZf0?olnP020?oon`060?coo@3kood0noom
0?_oo@3nood0ooom103o00000`3on?L0o?kk0?l000030?l0000i0?g_k03o0000o`0006I:=@3onO<0
ooco0?KfmP3looH0n_k`0?gon@3no_l0nooo0>Shg@3Tm/`0YJie04Hj1P3>^8L0RGe=0=SP/@3Im=<0
jOoZ0?Ocm03om_X0mO_i0?Kon`3ko?L0moOi0?omo`3imOl0oogo0?Sgm@3oooH0X9n;0:2ORP1CDSd0
;S8K000E000nE300XKf=0<?S/@2nh[80b^Fl07UmHP092@00g^760=3R^P3=ikP0V/BF05nJO01c^HL0
M;V009K;W`2lf/80UIEc0:>UM03Dj:T0c?6^00@0o`0001P0L8iB0?l0003o0000SjIR08RMF032hjX0
f>VS0=?PV02K^WH0Pj1M0<;MUP37hiT0aN6D0;_WVP39i9d0Cf0L0>KXZ@3TjJT0c>6L0<[XX030i9X0
d_J/0<[XX01eQT880?l0000T0<GYW`3:j:00o`000?l0003Cik@0amjX0=7^[P34hY`0c>bP0;_LS@33
hY80do2P0;gHR@3=jYX0c?:O0<keYP3:k9l0e^>N0:ZNI02?ZV<0aNVO0;VnO03Kh9d0cm^C0=W[X@34
gYD0dNbU0<GSV`3ClJT0cN^S0<SXW`30h9L0c>bS0<W[X@38jZ00c>jR0P38jYd20<K[W@2R0<SZW@3>
kJ40b>BI0<KLT`3Hk:@0d>2I0=OXX@3Gmj/0_MnB0<S_X02oi9H0c>bP0=gaZ@31dHX0DUdH08FECP25
WE<0V:iU04]@4014B@T0K74a09FJFP37cHd0f^2P0=GNW@3Dgid0f>>Q0=STXP3Ghj40e^NS0=GYY039
gYT0dnfV0<c/X`30i9X0b_2U0<7]X02ijY/0_>nP0;c[V`2=Yed0YKI_0=k_Z@3@jZ40c?:U0<3PU`3I
gil0YZIX07]l@033hI/0a^jU0;oSV@3Ak:D0]l:00>Wj]P38lZH0aNjR0=_QX@3Rh:<0clnA0>Wd/P3I
gYh0I5PN0;FjNP33iI/0b^jT0<7KU03AhYh0U:1N0:o0O03Ajj@0bnJO0<kYXP1LLbl0HWTe0=W^Z`3>
hj00Vk]X09jkJ`3@jih0c>:J0>;f/@3Ai:80c=bK0=;UX`3;hIT0eNbT08^RFP2dahD0enNX0=ka/@37
gI`0b=nK0=3YY@2;XU`0EVXU08jKEP2KYV80UiaL09FCFP2[ZW80ViaS09JKH@3CgZ@0cMZR0=KT[`3J
j;<0eMn]0=oW]P3Bi[<0]>Z`08g4S@10IcP0iOWD0?onjP3:^JT04P`002dh9`0]CCH0L9=k0:2mWP2D
Y7<0bMFG0>?^Z@3<g940do2N0<obX03Bmk80bNNa0?kok@3oooH0oo7d0:neT`3=fjP0d>JU0<CNU@3F
kZ80e>RP0=7MW@3Afil0RYYK0:c3O@3GmJ/0cN^E0=KdWP36h9H0g?Fc0;;6Q`3:gId0g>fV0<WFSP3P
kJD0RiIB05QQ8P38g9d0c^BV0>Shb@3koml0n_kW0>KYf03`kNP0ookk0P3oood01P3ooo/0nocd0?oo
n03ooo/0ookm0?3Yl0<0ooco0200ooko03<d=P0j?Sd0oo_o0?Odo@3eoo`0mOSa0>^c_03b^/<0oo[g
0?oom03nonl0i?;>0=WT^P3HiKL0g>_00?col@3mooL0oooj0<k@^03@eJd0e=fN0=7LVP3nom@0i>o4
09ZUJ`3;eiL0fNFU0<_GU@3JiZ@0en>Q0=7NV@80fNJQ00P0fnRR0=o/YP3DjIh0bn6F0=__Y`3NlJl0
YKMi0>7`]`/0oooo000:0?ooo`0]08_?WP0`GSX0HGmS0?cojP3>e;80//B80=3YY@39iid0cnVZ0>Gi
a03KikL0eN:L04UX903;l[/0h_ok07n^Z03Zool0ko_o0?Woo`3ooOl0ooko0?Coo`3Tool0JI^H0>3o
o`3dool0ooco03B<P001HE<0o?oo0?oho`3omoX0n?[]0?omnP3on_/0i=7C0?ofnP3on_d0oogk0?gh
m03FcLH0JeaE09=hL@3okn/0oocj0080ooom00H0o?om0?l0003o0000moch0?Kfm03ooo/40?l00003
0?olo@3nool0loWg0080o`0000<0ooWc0?l0003o00000P3o00000`3om?T0ooWo0?omo`020?l0000`
0?Wol`3lo_T0o?of0=GV^@3BiJh0SHmM06UK;P3ooM@0H50/0=KG]@3eoo<0joS^0?ofo`3on_l0l?3`
0?konP3ooo<0ookh0?olo`3ekOP0ooco0?Wcm@3oo?T0ookh0?onnP3ooOd0n_3^0?ocgP3Id[D0`/VM
09ZVMP1QKT00JGA<07=fF@011000T9Ai02Lb401eP5P0WjQm0=Kfc`2]n/H0T^^a06^iQ`1FSVT0DV8n
07R1EP1MIRl0fN^]2P3o00004@2a`H<0c]fL0?l0003o0000b^NT0=7_Y`3>jYd0`>JK0<[UWP3>hih0
VjMU09ZVI03Gk:L0bN>L0=cj/P3<k:<0aN>K00T0o`000<P0d>6M0<;LU@2kh9<0a^bO0;cUUP31j9T0
b>fO0<g]X@3;iid0h?Na0<WHU`3=f9`0fN>W0<_GV@3Mlj/0b>BI0=3ZX@3Gfih0d;b70=?/ZP2^dXX0
g^BT0<kETP27Ue00LHDm04IL501kTT`0Z/Am0<KQVP2mf940`n6I0=CbZP37iih0a^JM0<CTV`36iY/0
anJJ0<WXW03<k:00bn^O0<SXW036iIT0e?2U0<cTVP33ehl0f>VR0=S^Y@32iiT0dORY0<gbY03?kj<0
f?BY0=KSW@0mA`80joF`0;_;Q037hIL0eo>X0<[OVP3IkZT0b=bG0:fnNP2DXf00EV4O04YE4`1[LC40
bm6A0=kPX@3TjZX0eNZU0=ca[03?i9l0bN2J0<oYXP3>j:40eo6Z0=C_Z03=j:40f?J^0<;RU`2fdXL0
//In0;75OP3CkJ@0a^bO0<CTV`3Zkjl0`l640;ViO@33gYT0coF/0<g]Y03[m[@0_=J?0<KZX03:k:80
bnJO0=SWY03LgYl0/Z5Y0>3[Z@3BiZ40h^RX0;FeM`1hPD00f>bW0<CXWP3@lZP0a]6?0>gb/P2]_WX0
^M^A0<G[X03<hIh0g_>`08jQG`29W5X0g?f/0<7PT03FlZD0cNFK0>3f[P32eXl0PY=?08nSGP32eXl0
b^2H0=Sc[031hY/0c^VV0;oBT03_lkH0i>:W06YT:02KVE`0hNJV0<WPW03=k:H0doJb0=3XZP34g:00
a^BV0<ga/@2[g9X0`_Ve0;;]Z`32ok`0P[em04In?`1JSU00F8U80=?UZ`2YZgT0U8aM0:6PM02ATf/0
0@@007IeH03Xm>P0_=S:08ZfW@3Hjkd0XZea0=O[X`39h980amn;0<kWT`3?jj00anBQ0?cog@3nnM/0
hljm0<oGYP3EjJX0bnFL0<STU`3DjYl0cMjH0=CLX@3Hh:L0fn^/0=cc[@2keh`0e^nL0<3FQ03Kk:H0
Wji]0=CNX@3IhZ<0e=VG0>OZY`3KgI`0IF@/0>;P[`3Lhl80gnW@0?Sok@3dn^`0`/>n0>g]j`<0ooko
0P3ooo/0<P3oo_l0oogo0?cgn`3oo?l0noCk0?K_mP3flOP0ooko0?Cbm@1:Bdd0][Rg0?oho`3oo?l0
mooo0?oon`3oe]d0dIZM0?olk`3ion40i_770<kSXP3Ci9d0d^^J0<_VV@3WnLT0k?[G0?7lgP39d:h0
][nD09nXL@3Gh:T0o_oM0>K]cP3FmKT0`>RO0;GMU03Co;00i_o30;oXW03;m:H0a>fO0<7ZW039lZ<0
_^NH0<_VW`3Cj:D0d>FT0=KU[033dY/0g^Zj2`3oool000X0oooo02D0?WmD09BnV0002`00`lNV08^@
J03;gjX0cnfa0;oSY@3KnL<0l_oJ0>7Y^03Bf980YL9o0;gR[P3Joo80Bgaf0?7oo`3iool0m?Cn0?og
o`3onol0n?oo0>Soo`0]HEd0gOoo0?Soo`3omol0LLo101R3L@3lo_l0ooKo0?o_m03ho_00oogh0?oj
nP3Mb/`0ooCh0080o`0000H0ooch0:^RV`0h:B80^YnH0?ock`3oo?/20?ooo`@0o`000P3ooo/02P3k
m_80o`000?l0003oo?l0ooko0?koo`3jo_d0mO[f0?oon`3]i^040?l000030?obnP3on?l0o`0000<0
o`0002l0o?oh0?kol`3EiK@0dN2W09:?HP1dIC`0ong;06MF>03WhlP0nOod0?_on`3nmoh0o_?i0>cW
h`3oooH0oooa0?K_i`3fkNh0oogo0??]k@3oooX0o__b0<S6^P3/jN80ookm0?omn03onn80fMVc0=K]
]@38h:H0f^:a0=;G[P37ek<00QP00<_S_`3Fh[h0Xk6=03aD8P26U5T0GgYG05EfF`3KoMP0aO7001A9
7@1mYWX0^<BD05UC8@030?l0000307f<D`3o0000o`0000X0o`0000X0a^2F0=__ZP3>j:40dNbU0<SX
W`2mf940PiMB0:NfL`3=g9T0e^^V2@3o0000LP12?P40W:5Q0>Ke/P3An:T0aO6L0<C`U`2njY<0b_2M
0<GUV@37hIX0fNj[09fWJ`1ZLC/0JFhh0:NZL`2=Te<0en:N0>;[ZP3[iJ/0il^K0=7ZZ@3:kjT0f>NT
0=7RWP3Bl:H0_mfC0<SOV@3Nljh0`=F@09B[I@2G[VP0QImH0:c7P032h9P0anFM0=;`Z03EljT0b^BJ
0<[VV`3AkJ80b>NK0<CSU`3;jYh0cNVN09ZbJ02>Y5/0c>2H0=O_Y@3:kj40dORY0<GWVP34hiL0`=R>
06=]:02V[FT0c]RC0=7QVP2gdhP0d?2T0;kRV031iI/0eoV_0<_[XP3:j:00dNRR0<[OVP2HZFD0YKAa
049>302DVET0HE0H03DV001/HbP0WYYM092IF03Pk:X0//J10=C_Z03=kJ@0]=Z?0=7gZP3?kZ80d>JM
0:g1NP1mUdh0`nRK0<o]Y@3LgYl0j>:V0;6/LP3>iJ40_=fF0<kYXP3Cf9P0`n6I0<3YW@3FmZd0_]RA
0<WHU@3BdY@0MV4Z0=COW@34giP0e_2Y0>O/[02>Q4T0S8Y=0=Kd[039kJ<0c^>N0=3LVP2R/Fh0d>^T
0<7QV080c>6L0P37g9L0D@36jIT0d>nQ0<_WVP3BjZ00d^RP0=KZX`2L[FT0g>fY0>;f/@3IkZT0bn:L
0<[SW`3AiZ<0h_6`07Ai>@1FF1T0P8120<kCT`3GhJ80a]bL0=_h]P31gil0dNJ[0=_`]`36hZL0_N6S
0;c][02Hch`0A84n03Qe<P0nNCL0/NVX0=Kn`P3NkKH0KV@a081iA@2RXF/0cNFY0<;NX`1GGSD0Yif4
0<k<`03Jk>00H8id0;kHZ`27VEl0b^RP0<_WW03?i9D0c>:@0<oZW@39iid0m?o<0?3aa@36/i80e]nX
0<gTX039iIX0f?BW0:>iL01/OCT0OH9:04aA6`1/O3d0X[Uc0<;NT@39hY40f>fN04iM602i`h@0jo6c
0=7FUP3EeiH0jNV[08j>DP2j]XT0kn[40?gnkP3bmN`0o_ok0?koo@050?ooo`80o_ok00D0ooko0?oh
o`3km?/0ooco0?kgoP020?omo`0[0??am03no?d0e]KF0?ooo`3cj?H0oo_o0?;knP3ooo/0kKBk0?Jo
`P3oo>l0mokM0>C_a03=i9h0dNJG0<WWS@3<kIH0dNV[0=[^^`3homd0gnW40=CL/`3CfZh0P8MK0?co
h@3nonP0fOFj0<CXX038k:@0c_:X0<O[X@36jZ00]MZ=0;kSUP37k9l0coBV0<gbY03;iYl0d>NS0=;W
YP3ChZT0fnVd0>3Y^P0;0?ooo`002P3oool0902feKH08cX@0<KHZ03Oj;40a/jK0>?ac@3Ik<h0e>S?
0?7oj@3don@0e=^W0;FUI`3Pik40^/nV0:O7_003=Rl0m?oo0?_oo`3good0oooj0?_jm@3/ood0hooo
06RBSP3Pool0o_ko0?odo`1F/ZD0;i^;0?cno`3om?l0ooWm0?_nl`3mo?L0oo_k0?7Sh`D0o`0000H0
:b4H0>?<a03onO@0oocm0?ono`3oool40?l0000=0?;^j`3ooOX0oocj081hMP3inoX0nogl0?koo`3l
oOl0o_kn0?ono@3oo_/0_[Na0:fTW@020?l00003079>@P3omOL0ooWo00@0o`0002h0o?[m0?oonP3o
0000o`0009jDL@1;@Ah0oooO07e]D`25M680oocf0?onnP3oooP0m>gS0:NBP@2gXY40oo_b0?oil@2m
]JX0TH]m07alH02BUW<0U9]b04]F:`1fPU`0RYMk0::YRP2QTVL0[ii`05QD5@19CP/0SIaK09:KI026
N5D0500004de6`3Le[H0g>Nl0:[IT@39lJX0emBO09F<I@25UGP0LYQW0;;YZ022^h@0CXQR4P3o0000
2@3LhJ40c>6L0;WIT031kJ00^>:F0=O^Z02`_g`0Pha;0;BmO0070?l0003;0;kNU@3DlZX0_lZ807Uk
?01QHB<0fNJQ0<_ZVP37kIP0c>nM0<gYWP3=iih0T:=Q07n?CP3JiJT0b=:F0?7i`03IgZ@0e=BH06a]
<@25Q4/0kMn^0>k;X@3QmKX0dO6`0=3KW`3Chj@0c>ZT0=3[Y03?h9`0f^FS0>7]Z`3=g9T0eNJR0<oS
WP3GjjH0UJaV08FLEP2?ZF80U[1W08nSF`2@Y5`0U:YQ08fWG@2M^Fh0d_6U0<KUV@38hYP0`M^A0<kV
W03ElJH0a>JI0<GWVP3Al:@0cNNM0=CUWP1GGQX0emZG0=kXX`3>giP0c>bP0<K[W@37jIl0aNNM0=?c
ZP2feXd0gOfd0<g]Y03:jZ40bNNO0<_YX@2hdh`0dNJQ0=[OW`3Nh:40hN>T0>OYZP36b8T0EUPI03i0
0@3:c8d0jN^/0<S8RP3LiJ80_n6D0=geZ`3?iId0c>JM03aN4P2`bX<0j>BW0:RLHP2HSED0fnNW0<kS
X038fID0]kal0;oITP3:kZ@0a^bQ0<cWX03Jgil0YYeR05M63P3=fIL0a^JM0=3i[@31eY40fm:G09jD
F@2h`H00en^V0<kXX@2leXl0dnRS05Ya:`3KlZ`0g?>[0<[QV@3=i9`0b=nG0=;dZ03<k:40a^BJ0>Ck
/`3DjZ80RYiG0<kOV`3Chj80f>RW0>[m^`3JiZH0`/:409:@D`1BEaD0bmRB0=g^Y`3CjJ40b>6M09jg
MP29WVD0Oi9K08:@G@25Re/0TYYY06Ue@`1SMD40OIYP0<?UZ@3<k[80a^>Y0<gPZ@3HjK<0ShiR06eC
>03]f;T0h]fc0=CS[03KokT0XL9m0>7X/P3VgkD0k^[?0:jfW`1;L540010004Qb@02ikk40_^n^09BZ
JP3@h:40cnVP0<?YW03=kJ40cn>K0>?RX@3EiZ80c>NP0<_ZWP3<j9d0a]ZE0<KDUP3:c9X0h>:a0<KD
UP3Ek:H0_]Z=0;oJS@3EkJ<0dnNP0>3_[03Nj:<0f=nK08>5A01HFAl0ViYZ0?Obg03ooo@0ookk0?ok
n026PX<0i^;S0?[jo03oo_l00P3nool00`3lool0noom0?coo@020?l0000K0?ono`3oo?d0bLG60:bX
Y`3Xi><0fmOF07ahM@3mnOP0mo7a0?ojo`3onOh0nooj0?oon03U[;D0m[k70?oim03nonl0m_oS0=cc
_@3DiZX0co2O0<3VT@3;jil0an:K0=Wb/@3kom`0nooR0080o_oZ00H0b]6b0<K=Z`2`^h40dmnO0=cX
Z02IYF<209ZVI00;09:OFP2AWUT0T9eH09>PFP3=fY@0d>^N0<OSV03=iih0amZJ0=?SY@3Wl[P02`3o
ool000X0oooo02<0d=S106agC03Zml40bMRG0>?`^03lonX0mO_]0>gdk@3conl0mOoX0=CQZ@2KS540
bM>O0=G[a@1`U8X0Ah1g0?3oo`3hoOl0l_oe0?oon03oo_L0k?on0<?^i`3:j^L0j?oo0?kno`3ol_l0
97ib03RQTP3kool0ooWo0?oko`3kno40oooj0?oln`070?l000030?ogkP3mj^@0oocm0080ooko01L0
oooo0?l0003o0000mOC`0?onn`3oo?X0j]oM0:FMV`3hooh0n_on0?coo`3oool0o?[k0?SblP3ooO/0
Z:6I0;6ZX03kmNL0oog/075A?03omo<0oo_o0?ono`020?l000030?goo03mn_l0o`0000<0o`0000X0
HUTh0>WP`@2k[I<0Mf9A0?obk03llN/0n__]0>7Nb`3I_jH0QfQC0P3ono@04`1]I5D0Ee4k0=_N/`3U
k[T0ko[008NIF`2T]gl0f>jo0;k>W`3Thjd0hMbR0:R[I02AWE40bn:J0=;RX`3onM<05`000:22J03P
dk<00P3o0000103:ij@0n?Jk0=WBWP1bQ5h20?l000030<Gd`03o0000o`0000H0o`0000<0c=RX0?l0
003o0000203o00002P3PjJP0dnNR0<?NU`39kj@0^MnD0<GSV`3=i9h0ho:_07V2@@2LYF@20?l00004
0=SbZ`3o0000o`000?l00080cnfU0<T0cmjK09FKF`1YJB/0dmRF0=G[XP36hYL0bNFJ0=3WX@3Bij80
@E4@0761@03GiZD0dn:Q0<?BT@3IiJD0g>FV08F=D@1^LcT0Zim]0;BCJP34diX0^]BG0>;R[03Uj[00
`]2B0=SWYP3FhIl0e]bL0=GNW@3EhIl0gNVW0<oNV`3Kk:P0c>6L0=3UX03>iIl0d>JN0<cMUP3@hIX0
dNFM0<KNU03<iY`0cNbP0;OFRP3?jj00fOFZ0=C^Y03=jIh0bN^N0<[/W`34h9D0_]J<0=GUWP1=DPl0
i>NT0<WCSP3AhY/0b^bO0<?UV035fI@0cN6L0=?WXP3>hih0`mRC0<GOV03>j:40e_6Z0<;PV03Bl:P0
bNBM0=;YX`3<hI`0bMfH0=GTX@3BfiX0VImO08b>C`2@SU40Wi]N0>;IWP3XjZT0`nFH0>Cl/P3Bj:00
hofd08Z/H01oVE80fmFI0;Z[LP2JRe@0g>FV0=GUY03?fYP0bmBC0<cPV`2mfi<0bO>W0<g]Y03QgJ00
SWm606QL8P3KijD0dNbU0<_aYP2ogID0i>f/0;ZjO02CTE@0f]bM0=CUX@3CjZ@0e>nX0;?=QP1nV540
fO2X0<cSV`3GkZH0cnVP0<;TV03@l:D0]mF;0=C[X`37gID0JWhg0<gNVP3BhZ40g>b]0<3@T@2LZ6X0
MGDg05aK6`1IFQP0fnJQ0<KFS`3Fij40aMbH07N@C`3;hZX0eNbf0=c^_03Rjk`0KGU701<T00003000
foNm0<OTZP36gjD0g_6i0=CKY`3KfjL0ASXD07eSDP3oo^P0eMVf0?WofP3:h:00dNBR0=gPY`3;biL0
l?K@0=7L^P089@H001T0031X>@2[k;@0^_Bj06b5CP3DiJh0bnJQ0<7/W@33kIT0a^>A0>K^X@3=hIX0
bnVQ0<;QU@3BkZ<0`=>A09BOH`3fn<L0dM>R0=g[[P3Fk:@0f_JY0<o^XP3JmJh0`MJA0<OKU03EhYX0
e=jG05AK602?TU/0`/>I0?ool`3mo?X0oo[h0?omnP3Of]L0ookk0?omoP3oool00P3lool20?_oo`@0
o`0002l0mo?b0=gIeP3<b<D0dlo<0>COg01]J6D0elo=0>[QhP3gjnd0oogk0?_on03inNl0onKb0>F]
^P3omoP0o_oh0?_ol`3Yo]L0g^k10<KWX034ji`0bNbL0<7PU03?jJ80mOoF0?_oi03]l]h0o_o_0<gD
/`33bj@0L7Xn09RRH`2FX640DE`J08:=B`3Qk:X0hNbX0=gXY03BgIT0[[Ud0<[ET03:iIH0cNfJ0=3]
W@3Aiil0go2/0=?OW`0;0?ooo`002P3oool08P1NCSl0]kR<03i82`3=hiP0c=jP0?ook`3ooOd0ooOo
0?CilP3gon`0cnFW0;JfN03?j[L0Z]2Y09k<`P0hO740m?oo0?koo`3nooP0oo_h0?ojnP3]o_P0VLBm
0>Olo@3ao?h0o?oo0?oeo`0AIeh0CJnR0?Woo`3gn_l0oooo0?oon03oooX80?l000040?okl@3ono@0
oocm0?omo`80ooko01X0ooom0?oon`3oo_/0oo_h0>[PgP39^kP0oogj0?KooP3eooh0nOoo0?kno`3o
oOl0oocm0?omn`2c[:@0/JfR0?klk@3oonX0K4d`0?oej03onol0o_oo0?Son03loo/0oOko0?kho`@0
o`0001h0Xiek0=KA/@3om]X0iL^j0617@02AP7P0ooo]08f=L@3on]P0fkNM0?[Wh`3Xe]80RX9_0=WD
]P35cI@0e^>N0<SHS@3IlYl0e>nR0=?`[P3DkZl0c>:Q0<cZX02lihh0c?NM0<g^W@3=i9h0j>^l00l<
000:10040?l000030=7BV@3o0000o`0000/0o`0000<0M7Q606nIL@3o00001`3o00002@1mTU40[/=n
0:6eL03QmK00cnJP0<CRVP3@m:X0`nNM0<GUW0020?l000030;RdM`37dY00`>:H00@0o`000<X0c=NE
0<gIU`3Ym;80Y:YZ0:JVJ02W/g<0cn:P0=3SX@3>gYl0e^JW0761@02``Gd0d^JO0=CXX@3<hYT0cnJN
0<WRWP37h9l0hoNh08b9EP1dEbl0FF<^03532@1hJST0Rgi:08=lA@3Fe9T0LgDf0>CYZ@3TjZX0b]>B
0=;KVP3BgY`0e^FR0<oSWP3FjZD0b]nJ0<kRV`3Jij40f^ZS0=WZX`3?iid0bnFK0=;aY@3<jil0d>nS
0<?RUP3:iY/0b>NK0<SZW@3:jYh0d>bQ0=?[X@3Slj`0HfHS0=SKV03Zm:l0e^ZR0=?hZP32hID0ZJEX
08Z8B`1jNS`0i>JW0=KLW03KijD0d=nL0<WNV@3>iIl0e>jW0;gHT@36k:40b>bR0<_[XP3=j:40cN:M
0=c`Z`3:fIH0fNBR09NPG`1@EAD0NHI10<gbY02hdXP0dNNO0<7KTP3>kZ<0gOB^08Qn@`2HQDd0O6Pc
0<O=S`2kahL0SYMF0:jmNP3NjZP0cN:M0;c]WP30iY/0Y9EL08E`>@2ESe<0e>>P0<WMV038hi`0g?nf
0<_]X`39gYT0SXA906AC6`3DeYL0iOJb0<3RV03:k:80R:QO0<[RV03EkjD0a^2F0<_UV`39kJ<0_=bC
0=;`Z01iT4X0VZmZ0;kBS@3PlJd0b]VH0<OGV@1VMSP0S9YL0:2[J@3?e940k_6/0>7PW@3gm[D0/K1`
07Mo@`2EXfP0a^>[0<;X[`13JSD0NYER0:K1S029YW00PjA[0;WOXP31iJP0fOFj0;O:TP2GW6H0XIiY
0;jdT03KdlP0nOoa0?WojP3gomd0T8YF07ed>`3Ti:P0en:V0>3g``3fom`0_m:b0;OV`P1i_940I[:1
0;?f``2B[h40UZQh0<KTY02ljid0^nfD0<G/T`3Hii80[LEk0<SVWP34hYP0_MV?0=KYZ@3BgJ<0kNo0
0?ooeP3EhjH0^<j60=ok[P3:k:00^=NA0=K`Z@39h9P0d>2E07Z8?@2h`Gh0emjX0>GZ`P3[k>H0o_ko
0?onn035^k40ooSa0?onn03kn_H0mOGc0P3lool00`3kool0nOoo0?l000030?l0000_0?7`k03mo?L0
oooj0?oonP3oo?P0k^WU0?oln`3Xg]d0i]SE0?C]i@3koo@0n_[^0?oIi`3CVZ/0ooSo0?koo`3kood0
l_o/0>[ifP30hZD0a^jU0<3ST`36iID0eO6W0<SHZ@35d;00o?ob0?_ol03loml0joC50<kQX@3>hj00
b=fJ0=;WXP3Wo;L0aMZE0<gSV`3DjZ80fNnW0<7GSP2cbH00b>FA0=3aVP3?k9P0e>^M0<SJT03;fi@0
2`3oool000X0oooo01P0Q8E<07YoA`3Bfj@0h^o40=kWb03nooX0m_Kf0?ono`3oooX0n?[/0=[Na@2T
WXP0lO[W0?;on03?mnh0N:ZQ08F/Y`2:YjD0n?oo0?oko`3onOl0ooCm0?Ono`3mn?l30?oio`0703iV
KP0TFf00i_oo0>Woo`3hoo/0oo[Z0?_ol@070?l0000>03HW903omoD0ookk0?GinP3^l_<0n_ck0?Oc
l03oo_X0oo_i09>9Q`3hl>h0oo_k0?_gn03mno`20?coo@0B0?_oo@3lool0o_oo0?olo`3hk^l0/jNW
0<Jn^`3blnd0d/nl05A56P3ommL0noc^0?con03hooX0mOoo0?Coo`3kool0mo[o0P3o00007`3Yg/P0
ook[0?ool`3mm^`0ooch0?kgk`3^k=d0Q8i[07F1D`3CfId0^<:50<7FWP3>gJH0j_6k0=?KX03Ci:00
d>NO0<SWV`3Al:@0d>ZP05AO7@3NjJL0b>:I0:W8O01DNb`0`NJH0<[SW`38f9T0gnJb01lR00073@00
2P3o00000`19Db40o`000?l000040?l00006079kG02LVgl0gnG90<WI]@1cWVH0?GTm0P3o0000102C
YG/0Tjf607^GK`1LNe420?l0000507fLH03JlJd0o`000?l0003=iIL0103o00000`21TTh0Y[]f0?l0
00030?l0003:09^ZI`38g9L0eNVT0=__ZP3IiJ<0V:5R05IO802RZf`0RIEE08bKFP36fiH0f>nY0<GP
V@36i9X0a^JK0<[/X035iid0eo:]0<oXY03IjJP0dM^L0<SUXP3;k:D0bN:N0=;WY03>gI`0^LF309ZS
HP2MXf<0UI]K08>8B01=DQ80V9YK0:NYJP3QhJ<0fmVL0?Kd]`3@eID0cnVP0<oYXP3@jZ40c^ZP0<_V
W`37iId0b>JL0<[XWP39iil0b>JN0<_UWP3FhIl0i>n]0=STXP35dHl0NhM50=KRX03Dhj00cnJP0<gW
X038jZ00c>NP08N=C`2Z]7D0e>NU0;;7Q026VeP0Ff/Z08NFE@3FiJ@0e>BS0<7FT`3@jj@0c_FV0<7W
VP3:kj80`^NI0<_[W`3<k:40b>RL0<[YW@3>k:80`=bB0;S>QP1PHR40I6TW0=_WY@3EjJ@0cnZS0<gV
XP3Ei:<0^lF808R>DP3OiJT0dM^L0<gQW03AiJ00f^>R0=cUY03EhIl0fnJT06=U9P3GgId0fNZV0<OU
W@3@lZP0c?FY0<kh[03Amj`0`^:I0=CSX03Cg9/0`<b:0=GVXP3Fl:T0_=J?0=[aZ`1lSDT0R9UE0=SY
Y@3?h9`0ho>Z09jbJP29XEL0b^JL0<WTW@3>jJ80bMjI0=KVY@1PI2L0H60T0=kSX03Cm9T0cnZM0=7O
X@2QY6/0DeXG0;G2O02lg9d0_>:_01]05`0F=``0cN:W04YJ6`3?hi/0bn6F0<kVVP37fYP0dn2X0=OG
]@1gLU`0X9R;0?ool`3kno40nO_f0?kol`2MXHX0oooZ0?7Ya@2XVWl0m>OQ0<o=Y`2Y/GD0QHeB0=GN
/@34g:P0cnfg0<WU]00]A1H0;SPC00070019GcP0=5T]01E>6`0/J3@0OKV505YiD00gCb/0coG<0;GR
]`33k/40`^Vm08ZVOP2>Z8D0jooc0>Kon03LooT0i?og0>_om`38g<40a]Jb07R0C`2_/Gl0h=f`0?oo
g@3oo^@0oOSe0?olo`3Zi^L0^[Jc0?oon`3oood0lo?a0?ooo`D0o_oo0P3o00060?ooo@0Z0<o>c03o
ood0moGf0?oknP3cj^D0cMG:0?kon038UYT0aiZE0=KE^@3?iKL0c>Nd0<CU[039i[00a^ZR0<O]X035
jYd0c_2V0<GTWP3>iJd0eNVf0<[K[`3iomd0cM^X0>Oe`03Vn[D0f>fX0<cPX`3SlLd0looT0?Sol`3k
ooP0o?o_0?coiP3AfjL0Y[5g0<S[U`2miHd0c>fN0>[i_P2SZgP0g]Ze2`3oool000X0oooo02<0PH]6
0<C>TP3OjKD0o?oX0?[ok`3loo/0n?gi0?koo@3oooP0oood0?ool`3Ug=D0oooj0?Kon03]ool0eo[c
09Fi]@2Ra<<0looo0>g`m@3gl_T0ooco0?Ooo`3nool0ooco0?oko`3lnOl0jOoo05N2R`3@oOl0gogk
0>_kl@3oonl0o?od0>7Yg0020?l000160:jVV`3KdLP0QG9/02L?3@1[FET0oogk0?ooo@3iool0moom
0?coo@3dkn/0oogj0?kck`3>`kl0oogk0?olo@3inO/0oOko0?oon`3dm_40f=oH0?Kln03lool0ooco
0?olo@2cYjL0^Jn]0?oonP3oonl0F4dO0=79Y03^kMT0o_od0?_on03gool0kOWi0?[no`3hnol0lO3[
0?ool@3KekX0h]g70?ool`3mnO00oooj0?oomP3konh0W:R40:6^P03Hjj/0c>>O0:[<PP3Bk:D0fNBR
0>_f]03<h9/0M8m809>cJP2N_WD0SJAN0>?XZ03Jgid0e^bS0=[dZP2/bX80bnVQ059W9P3Vm;T0h>Ba
04mC8@@0o`0000<0fNZV0?l0003o00000`3o00000`3Mi;00YZik0?l000030?l0000>07k3U`29`I`0
3BH909RUR`1VKDh0QiEa07ZUL02=a8X0^njc0:6cP@1gSV00Dg=>07jPO`1^T6l;0?l000030>3g/@2F
Yf<0WJiZ0080o`000</0`]JA0:g1O03Cj:<0eNZU0<oTW`3Hk:L0e^6O0:6WI`2AVUT0SIUG0:NfL`3G
k:L0an6J0<OUW@3Dm:/0`>:H0<oaY`3FmZd0/lf60<kUW`3;h9/0enjX0<CVW038kZ<0_nRL0<3TVP3:
i9d0b=fH0=?TX03GiZ<0bMRE0>;]Z`3EgYd0WZAT09BIF@1YJb`0D50B0<g;SP3Sj:P0bn:L0<oVX03>
iIl0bN2J0<kUW`3Ek:H0d>NQ0<kUW`3BjJ<0d>NQ0<gQW03Hg9l0fMnQ079k?01@FQ/0GFTY0=7TXP3@
iJ80c>NR0<[XXP39j:80cNJR0;[6QP3Plk40^mVC0<g/YP3@kZP0^<n;0;S;R@1FIB@0Z[Yi09R_J`34
giP0cNnR0=?eZ038jYd0a^RK0<GWVP38jYd0a>JI0<KXV`3;kJ00aNNJ0<CNU03JfYX0_;im06Mb<02=
VEL0cN6L0<oTX@3>hJ40a=NG07R6B03@fYd0f>NV0<_VW`3FkJL0dmnM0=SQX03XjZ/0j>f]0=ORX033
e900enjX0<GUW031iI/0[MN;0;;KS`2ngYD0e?:Z0<kSWP3NlZd0HW<_09Z[I`38g9L0loo20<7ET039
gIP0a]ZE08>GDP2;WeX0RYYA0;[<PP3=hiX0an6H0<OQVP3CkJH0i_Ze0<oKV`1TIRL0R8I90=kTWP33
hXD0fOBW0=7TY02e`XX0enb[0<CQWP25/gD0K9aZ0:c?Y`2fcjL0WjQc0<[BUP3OjZD0VJUP06Ui<02B
VUh0T99Q04e2;03:_;<0oo_k0?onn`3nooX0o_oh09nSS03JgL80oOgS0?Oec`2PVX@01`0509:=K`31
aX@0e]fJ08nII01mRe00_LbA0=GR[026TV00RYM[09FTN`34gkH0bnk60;OZ_`2EcZ<0DHiR02Q6900^
ARH0RK6>03IX@P1VVfl0Q;F803aQ=P1:JDL0T[NV09K1^02>`;l0g_oo0>goo`3RmnH0g>cB0416803P
h[X0j^K30?;]d03oond0ookm0?_ho`34a<H0c/k>0>o_k`3`l?00oooo0?;blP0;0?ooo`0/0?gmo@3b
l_804a<C0?ooo`3jn_X0ooOg0?olnP3<dl/0XjJM0?oGd`1iCcl0g^Bh0<GRW`34i9/0a^bQ0<WXY035
iiX0aNZJ0<_]X`3<jjD0anJS0=;[/@38gjT0cN6^0?SofP3>gZl0fn^j0=;TYP3CiJL0fNZf0?CniP3k
ooP0n_go0?_ko`3ooo/0oooa0?_oe`34biL0b^ZN0<3UU`3In;80iO710:R/Q`3klm`;0?ooo`002P3o
ool0JP2DWV80cmVU0=SS^03lond0n_oc0?coo`3nool0m_Kf0?onn@3oooH0ZjBJ0?oll`3oooX0oook
0?ooo`3lnol0moko0?Ooo`3`ool0goWf0>?oo@3BoOH0[NKP06F@R@29Z:00mOoo0>goo03Vool0f_oo
04QcN@3Em?L0h?Ce07]lM`1fNgD0b/g60?okn03ogND0oocf0?S[h`2KQX40<1PH0;2NWP3el>d0ooom
0?;kn03ho_`0k?7]0?onn`3lm?40VXn;0?K/jP3oo?T0ooko0?ooo`3nool0n?Wd0?koo@3^lnl0noom
0?;dl@3ooO/0oocj0;6WWP3GdLD0o_o_0?_nh`2[WGH0LFA2075VE03ejn40oogh0?omo@3oo_d0oooj
0?oom03lnNH0Wj200=GPY03VkkX0o_oO0?koiP3lon`0en3;0>K`f03fon<0nOoO0>?d`03?i:T0eO2Y
0<_PV`33cX`0Mh900=7RWP3OnK80_M^C0<g[X`3DkZL0gNRV0=SSW`3@iYd0c>>K0<SVWP3<jZ80d^NV
08>>E03EfZ@:0?l0000402L^001PIc40UIaX0:2XM@80o`0000l0@U4Z0729HP1ZRF00/^>f01eE9P2P
eZD0Lj=c00dT002OZh<0gno20<om_`1OT5P0^>Rn0;;P^`24YhT01`3o00003`26WU00o`000?l0002d
chP0aMZE0>?d/03<gIT0]<F10<OKUP3PmK00^/n:0:FjM@2>YEl0Rj9L0=GZY@020=kZZ00a0=OSX@3B
hil0f^^W0=GZY@33fY@0`M^D0<kYXP3Mn;40gofe0=?aZ@3KlZ`0b=bG0=?TX038gIP0cnfU0<KXWP37
jj40c^jU0<gTWP3<hid0f?J^0;oQU`3@lZP0bNVP0=7aZ039iil0do6Y0=[e[P2leXl0V;9[08:GDP1J
Gal0Nh10092EE@2HWEd0Vj1P08fBDP1_M3@0<SL003@i001CF1P0FElO092OG02LZfP0fNZV0=kb[@32
ei80cnJP0<gWX0020<[XX00/0<WYX03=ij00d]jL0<;CS`3HmZh0`^:I0<SXW`34gYL0cNBN0<[NV@3D
jJ@0_M^C0<SVW03?jj00dnnT0=GaYP39j9`0c^fQ0<c[W`3;jil0anVL0<KXV`39jih0bnfP0<KRV03?
iYh0]l>109jTI01nO3l0^kUn0?7e^P38d9@0SYYL0=S^[@2ogIL0`>bO0;oXW03=j:40dnRS0:2/JP1J
IB<0`ln=0>?b[`37g9L20=7/Y@1N0<WTW@3Ilj`0e^ZU0=g^ZP3Mj:H0d]fK0;:kNP1VLBl0aM2>0<oJ
V03Mk:L0bNRJ0<CSU`3@kj<0`^6C0<g_X`32gY@0c>>K0<OBSP3LhJ40gn6R08b>C`1SJ2P0d=bJ0<_O
VP3@i9d0fN:O086>AP38h9H0]nBS0:kSZ`2fl;h0AWi=0=7oc01EIcD0^l6C0?oog`26P600LG5=0;6e
T03KgkX0oooT0?oojP3on_@0ooWf0?oklP3oo^l0Y:N<0<gH^03:fZd0dMj`0>ghc@3GhJ`0/;RA0=GJ
e03Fh[@0d>FF0<CKS@3?hJ<0cMNK0=_PYP25Ue/0_]RI0;kRXP37l:h0a^j_0<ga/`2^ahd0NHiE08NH
H@3Jk;80bn2U0<;XZ`3Gol@0`?6_0;SUXP29Zfh0PJ1W0<o_bP3:k]80`>OD08:XS`2A]IT0Dg9@08BP
NP0P<P`0jOWE0=cXd03]n^T0mook0?;oo`3Xn_l0koCh0>3Ph0<0oooo00<0nOWi0?ooo`3oool02`3o
ool0:P0b<S80n_[j0?ooo`3om_P0oock0?_on`3nooP0YgQ^0:=kHP3EejD0fO6S0=GaW032i8d0a^:>
0=S`XP37hYD0cNBN0<[PX03LkkL0k_oB0>Ccc03Ukm@0m_oW0>G^f@3Zl]d0iO3B0>cgf@3do^H0n_oi
0?[oo`3lool0o_oo0?oon03mond0oooM0<K<WP2GZg00fNjc0<;EW@3lomd0oOoP0<S8[0/0oooo000:
0?ooo`1Z09VSKP34d:80k_[D0?_ok`3bn^d0mo_l0?koo`3oo_l0oogk0?kel01KE4X0ooof0?kmn03o
o_/0oo[o0?oio`3on_l0ooko0>Gmo@2[d<T0dOof072^X@1GUXh08Te609Vh/P3good0gn_W0>_oo`3N
ool0Egj50<CUjP3]ool02A<D07Z0OP3oood0ooWk0?o:e@3omO00ooSc06eHE@1NATH0^:JV0?onn`3b
m?40nooo0>oel`3nood0m_7^0?omnP2k/Jl0oocj0?cgm03oo_l0oOgo0?gooP3fm_@0o_oo0?3dl`3l
ood0l_?^0?omn03oo?H0YYf>0=GB_`3konD0oooS0=74X@1@@b<0P75N0=k=``3on_H0oo[k0?oimP3o
n>P0`[fW09NFN01EFbl0b]nD0=o`[03_ol`0m_oI0?3nfP3Bgl<0j_OK0?Soi03hon40l?oD0=O/]035
giP0g?2[09:MF`2Q[6X0gNjZ0<ONV03CkZL0`=jF0=K`Z@3RlJh0d]nJ0<kRVP3@iil0bnVQ0<3KU03=
hZ40OXU?09RMI`X0o`0001D0Vj1X06=Z=01]M3h0IVdi0;VkR@2>P5T0Og==04a<9P085000RKN804F4
C`2<dIX0ZN>`06j5F`1:CR/0emVb0<[U[P26YW@0]n6i0;[X``1UUg@00P3o0000=@2ge980c^VR0?l0
003o0000c>BF0<kVVP2@Yel0bn:L0>co_`3FjZD0c]nK0=CUX@26VUD0cN6L0<OLU`3HkJP0]lj806V0
>P1AJ280bMjI0<gNVP3@gi`0h>n/0<[KU`3;g9P0dnRS0<?JU02jdH/0d^bU0<CNU`2X`W/0VKA]0<_P
V`3QmK00_<^80?;o_`3CkJH0bnVQ0<W[X@39iil0b=fH0<WPVP39iil0bnfS0;KHSP39jj40a>JL0<GU
W033hiX0bnVQ0<k/Y03?kJD0amjH0080XjQX00@0WjAT09BIF@2DVET0V9eM0P2EVUX0202JWel0W:5Q
09JOGP3;hIT0aM^C0<GLU036gID0a^2G0P3<j9h20<[XWP2?0<WYWP3=iih0gNZU0=;SW@3@kZ@0`nFI
0=Kh[03ElJL0`mfD0=S_Y`31fi80dO6V0<7QUP3Dk:80e>jT0<gWW@3:i9X0cNVN0<cXW@3<jil0b^ZN
0<OWV`35iiX0aNZL0<ObX`3;kJ40dn:O0>7VYP1/HbP0ShA<0>ORZP3PhJL0U9iQ0=C]Z`3Cm:d0_^nP
0;[VV@39jJ00d^bU08nNF`1?FaT0h^j/0<SIU@3GjjH0_mVB0=G_Z03Cij80`mB@08^GE@2[]W@0f=jN
0>3VYP3Ujj/0/[Qh08ZCDP3Yl[40_lb70=;_W`3Ckj80c>RK0<gZVP2gh9@0cnfU0=7VX@3QiZH0jNNZ
0>KPY01MFAX0VYaK0>7e[P3?jj40cNNP0=;AV`3=ei80`]jA0<Oo`@2MhK00I:^307nhS`2cgZT0]/69
0>?O[`2lZ8l0KV5>0=[E`@3^k=L0inKA0??[gP3oo?H0onk`0?ohn03hj=T0oooV0=SM]038eJX0d^F]
0=W]/P30dIX0f>Z/0::bP`3Fh]H0_=2K0=7^VP3AlI`0f?:a0>_i_P32cID0h_Rj0<o/[038kJP0]=bE
0=3d[03=jj<0SYeH065Z9`3Wk:X0c=VC0=kbZP2nh9H0b?2W0<C`X`2miYP0Z/Z10<cYY`36hK@0d>k:
0;KG^P2igkX0_nFl08ZZP`21WGL062d<08JJOP3dooH0l_om0?3oo`3Wool0i?oo0?Gmo`3Ti>@0oooo
0?7al@3lo?`03@3oool0:`3kno/030`<0?Cdm03oool0oo_o0>_Rh`3hooX0hnWO0<VJT01bB300c<bH
0<[OT03>iY00dNnG0=S_W@36f8h0d>BL0<kNW`3Hijh0o?oH0?7kf@3lonX0mok^0?[om03jooP0o_ok
0?comP3kooD0n_of0?WmoP3jo_l0o_ko0?koo`3ko?@0oooa0?ooh`3LhKT0ZKMi0=_/Z03RlK00i_Bi
0?7nb02>V6H02`3oool000X0oooo0340ho350?_oi03con@0n?oc0?coo@3in_h0n_Wn0?omo`3onod0
ooOf0:^RV`3nooP0oook0?onn`3on?l0ooGo0?o`nP3oo?l0j_on0>;oo`17NW40fOoo0>_oo`3bl_h0
ooco0?o]k`3mj^`0ooko0?Woo`0031<0:4]A06F<T`3Rool0mOoo0?clo03on?d0^Gn=0?ogm@3on_H0
Fd=1085/J`3Te=@0m_Ob0?Wnn03koo`0o_om0?ooo@3oo_/0lNWW0080oogk03P0oOWh0?kmn`3oood0
o_oo0?[jnP3lo_d0d]KE0?goo03kn_H0oogd0?oij`26OfD0oOgK0>Gc`P39eZP0jNS90?[ge03om=X0
GTdm0;FMV@3on?H0oo__06IS>P26R5H0fNJ`0<KHVP3=ji<0aN:@0<cWXP37hJ80`MRP0=?Y^P3MllD0
lOoF0?Gof03Ek;@0bn2U07Z;A`1EI240i_6_0<SCT@2AX5d0Yk]f0<KKUP3GlJX0_=J?0=gd[P26W5@0
`M:;0>7g[`3DkjP0dnjW0<WNW@3@gZ40fMjV0::YL`P0o`0004T0XJe_0<gEV@39dIH0l_Nm0=GJXP3P
hJP0Jf8Y05];5`1YE2L0gLnR02Tb0`2mejL0/^6]07^[N@1AN4/0]MBZ0>GldP0H8@00IGI<04QV@P1:
KTX0RK>=09>SI039gY/0iObf0=7]XP3;iiX0c>^M0<7MT03OnJl0g>n]0<7ATP1KJB/0VJUX0<OKUP3E
jJ@0DfLR08JKEP3?i9l0c>>M0=7XXP3DkZL0c>JO0<kUW`38gIP0EFTT08:GDP3@iJ00^<f80=[^Z@3<
h9/0a]^F0=W]Z03Gk:L0b]nJ0<OQVP0jCPT0fNRU0=SQX03?fYP0b=bG0<cVW`3=j:40c^VR0<cPV`32
dhl0E6<P04ED4@2GYV<0d^6N0=GVXP38fID0dN:N0080fNZV00L0a]NC0<SLU`3=ij00d>ZS0=?]YP3A
jj@0c>JO0080cNNP00T0c>JO0<gWX03DkZL0eo:[0;gOTP2feXX0dO6U0<CTV033hiL01@39jId0>P3=
iid0b]NA0<OKT`3?kj<0`NJH0<[_X@32hID0c^ZO0=?]X`3BlJD0a^^M0<_]X030e8`0_m>;0=__Y`3?
iI`0a^2F0<_UV`3:iY/0bNRL0<[YW@39jId0a>^L0;k_WP31jY`0bN2J0=gYY`3ThZD0h=ZP05mJ8P1M
Fb80Hf@Z0>7[[P3Ej:H0bnnU0<GWW@36h9T0dNJQ08BCD01EHAl0aMJB0=oc[P35g9H0f?J^0<CNU`3I
iJ<0FfHT0=?NW03EgYd0U9eL0=gSX`3DgI`0h^^Z08NBD01HHB00e>FQ0<7VV02nhiD20<[_X@1A0=Kf
/`3Km;<0b]fM05]P801ZJR`0gmjN0=SJV@3?f9D0`mfD0=?cZ03=j:D0VYIW0=GSZ02hgIX0OLN<03N4
FP10QfL001T007N>I03Wi[00knFb0>3A/03oonD0lo;N0?ook`3ooo<0o?Se0?olo`3onOl0g/c<04]5
:`3RhkT0o?o=0?_oc`3<gid083D00=ca/037gYX0_]:O0<OIb`34gjX0bnnH0<obWP3=k;00f_K60<_T
^P3gomd0gNfn0<WDW03EgJ80CePE05aS7@36dXH0i?6R0>?aXP3ChXl0eNNC0=?/V`32gY40RjaM0<OX
V@33gY40fNjY0=CT]@3ion40j_OI0>cofP36fk80c=fk04]K@03doo00mooj0?Coo`3aool0h?Sl01@a
=`0=:c<0HFU[0;Bd]03oool0j>SX00H0oooo0P3o00050?ooo`0M0?Shn03kno/03`l?0?gmo@3oool0
n_7f0?olo`3coO`0o?om0?[8a`23EDP0iN6k0<SFV@3<g9d0h?:h0>;/^03FfJX0eMR[05YL=`2CU7D0
o?cR0?ool`3kno<0ooko0?ooo`3oo_l0noSo0?koo`3mo_l00`3nool0303mo?l0o_ko0?oon`3oooP0
nO_]0?gok`3NhJX0XJIS0=SOV`34e8d0fNZS0=K/X`/0oooo000:0?ooo`1[0<KA[`3/nM/0m?oX0?Km
m@3lool0ooko0?Seo03oo?l0oo_m0?oknP2k/:`0o?oh0?kon`3ooO`0ooGj0?ofoP3on_l0moGj0>Gi
n02ogm`08Da50>?oo`3dool0oo[o0?o_o03oloT0ooOk0?oko@3imoP000H904IYK@1>Ngh0h?oo0?7o
o`3oool0ooGj0>:X]P3on_P0aK>_0140003fhN00ooKf0?oon`3go?H0o?om0?_kn@3jnOL0n_Ke0<Bo
_03ooO/0o?Od0?ooo@3lnoT0o_om0?Wkn03inOT0o_oo0?7em03nood0o?_g0?oml`3oo>`0KfY:0>?U
_@3Gj;40c^2/0=?J^@3Uj/80oooQ08MkI@2]V9<0ooCa0?ojjP27Qe<0h>Z[0=CXZ@3>ij<0b>RC0=7a
WP36i9`0d>fZ0<gWZP3Aj[40a=fV0=;Z/03?ij/0`=VH0=3VY@2EY640UjIS0=GQW`3Dh9h0JGPe0<_J
U`3BiZ40d^NR0=?ZY03GlJX0Z;mi09f^I`3Mlj/0bNBM0=3[Y03AiZ<0enFW0=[RZ@2EWF@01@3o0000
BP3;iIh0gOB^0=o_[P3?gYd0YJmb0;g5R@38d9@0h>>Z0=CHV`3Sj:H0f=JI08IiA01jK3/0U8eO00/>
0034gZh0d_?401A24`19NDT0ZmFW08VJKP1bR640b^[506F7HP35j[l0T9aL0=KWX`38g9D0fO>Y0;kJ
S@39j9X0cNVN0<;LT`3@hj40d^:S0<KDUP1?Gah0fnnZ0=3TW`2CZ6<0SjAO0=G/YP38giT0b^6K0=?]
YP34gYL0cNNP0=3WX@38gIP0VZmZ0<GJU@3XoKP0a]ZE0=c`Z`26VUD0S:1K092TG`3Kl:/0dNRR0=WZ
YP1^NSP0f=jN0>3YZ03HjJD0d^NR0<SSW03Ajj@0Yk]f07b;B03?fYP0e=fL0=cUY027T4l0_<N50P3I
i:802`3@g9X0e^:P0=7MV`3FjZD0b>RO0<KVW@35iI`0anNN0<_[XP39jJ00b>RO0080anNN00L0aNFL
0<?UV@3;l:80co6T0<7SUP37jI`0e?JY00D0bNVM0100cNNM0<cLU@3Jl:L0bN^N0<GZW038kIl0cnnS
0<OVVP3Dl:D0`^6E0<keYP36j9/0MhQ106Yk=03NlZX0am^C0P3Cjj40I@3>j9h0b^JK0<_WW03:jId0
a^RK0;gXV@37kJ00bNBM0<gRW@3=f9H0i>Z/0>g//`1cLST0E58I0=OFW@3GgIl0dNRR0<KKUP3ChYl0
fNFS05iY9`1bOC/0f>bW0<WNV@3>j:40bNVP0<cZXP3FiJ80TIeK0=[VY03=fIL0YK5_0=CPWP3;eiD0
fNFS0<kJV01fPT00BeXG0<KJU@3NlZd0am^F0<_OVP3<i:H0RieO02dm002@VeT0[kQe0=WRW`3IiZ40
d^>M0=7[XP34hYX0b^>R09>EI03Fj[D0_nR`05RNJP1AV6h0]?7?055^C`0V<Ph0e=2Q0=oGYP3Vh[<0
gMfg0=CK_03]m]T0m_kW0?oon02j^KD0Z9jO0>cQg@3?d;00d]ZY0<kRW@3@gZ40DV4N0;S9Q@39g9`0
Ae`K06]oCP003@<0c>Jf0=3aX02ngi00b^Na0>gohP3/on@0RYQg09nWPP2_[X80UiET0>;RYP3DeYD0
e>:G0<gPT@3@iiL0dN>A0=g[W02FZf00Tj]Q0080cNVO01H0hOR`0<KIV@3XllP0l?OE0?oojP3cn]/0
h^c:04aB>02;T7`0o_oj0?GjmP3/m_P0mooo0>kmo`3^ool0k?oo0:fc/`2][Jd0oooo0?knoP3oool0
no_k0`3oool40?l000@0oooo01h0oOgm0>g]k@000000o_kn0?gmo@3onol0n??i0??oo`3ioOh0on?X
0=BSWP3TgL40j_?60>[fb03QkLT0iNS;0?gigP3WhlP0hn7<0<g:^@28Q7P0moC_0?ono@3ooOl0ooko
0?omo`3lnOl0ooko0?koo`3oo_l20?glo`040?ooo`3moOd0ooom0?kno080oook00H0k>W00::QJ@2E
V5l0e^BW0=_][`3Bj:P;0?ooo`002P3oool03@3Rj]<0nOo^0?_om03koo`0nooo0?kmo`3nnOl0oogo
0?okn`3onoX0oo[f0?oon`3nood00P3lood01P3kool0m_on0?Cno@3Qk>h0QiFH08RFV@80m?oo01H0
mOoo0?;lo`3nool0jNCX0?olnP2ITHh0m?oj0>SooP2HaKh0[>7K0>goo`3eooL0oo?c0?6ia03on_H0
CC/g02081P3ii><0oo_j0?_mn03go?H0oook0P3oood00`2RWYd0a;jn0?ono`030?ooo@80o_ok01X0
no_k0?gmo@3nool01@D300<0003jkN@0oog/09:>J03Mi;40a]fI0<_UYP3_on40hOG20=SP/@3Ui/@0
YZ2D0=S?aP2ETGP0enFJ0=WaV`38j9d0_=fF0=7_Y`32h9X0bnVS0;WGT@80o`0001P0bnJO0<3LT@3C
kj80cNVE0=O`W`2S[fd0cmjK0<oPW03KjZL0c]ZH0<G@SP2Z]G<0cmjK0=S/Y`2lfY80e_6Z06Qg<P2>
XU/0_mVB0>oo``1KL2d0`]2B09^SJ02nb8`60?l0001F0<kZX03:hI/0e>RS0=?RW`2>VUP0SiUJ09nU
I`2Z]G40eo:U0=;^X@3Fk:@0UjIS059;5@2]Wg00MVY001hO002miK<0/^^f07fiP`1jXGD0I8mT03MT
>@27/XD0^=fY0=_XX`26UTl0W:eV09J^I029Y5L0a^:G0=?_Y@3;iI`0enZX0=WYZ02^_Wd0am^F0<[O
VP2oe8l0fNjY0:NnN03Ek:H0b^6K0=7[Y02ofI80an6J0<KPV@37gYP0dnZT0=;YX`2bbH<0V:eX08BH
D`2=XE`0fnbX0<OHU03Rljl0cn>N0<7KU03KkjX0a]:@07Ml?032b8P0eNBQ0=?WXP2ccHH0Qj5J09fb
K@3Dj:<0cMjJ0=KUXP3Ol:`0b]^G0>Kg/`3>hYd0Wk=^07jBC@1aQD00dNFP0=K[YP3BkJH0c>NP0<KQ
VP3@jj@0c^VR0<cWX03=j:420<KQVP2K0<SSW037iId0anbN0<_]X03>l:<0bN^N0<KXV`3<k:00cNfQ
0;gLT034hiL0i_ng05ih;P3@hIX0d^ZP0<_]X03<lJ<0`NRI0<_[W`3?jj00^]B:0<cXW@39jih0anNK
0?;o_P39gID0DFDM0:_1N03Ejj80c^JL0<WQU`39hiT0an6G0<oYW`3Fl:H0cNBL0<cVW@3;kJ<0_>:G
0=7eZ`3;jZ@0e>:T0<C:SP2BSED0O6Hd07aX<`2UXfH0e]BG0>WYZ`1jNS`0]kal0=SQX03@iJ00c>NP
0<WYX033k:00aN^P0<gTWP2DZfD0dN^T0=3ZX`36h9T0SZQQ0<cSW@3CjZ@0e^^V0=__ZP3EgYl0@B/0
02lI001/ERL0D3X;0:2PJP3AfIh0b=JH0=3ZX@38iY`0^M^?0;_MT036iY/0b>6M0;[?SP1lT5<0c^JZ
0<7X_03=nMD0V/ZT0;WT]P0Q@A00/kR@00h7003Pg;T0e]VZ0<[OU03FjZ<0e^b[0;gEV@36gjP0a]Zg
0>;`eP3foN/0o_o]0=;S]P3Hl[D0eO>Y0=KRY02m`hD0kOJg069[=036di/0]L6K0003103Xn=<0cNBN
0;oFTP2`_9@0[:ZM0?ogm03`k>00ooo]0?ooh03oom`0g^Rc0<ODW03>hZ<0d^RW0<_TXP1`PCd0Z[Id
0=oZ/03@gJL0b]^T0>?f_P3>hjX0c]n[0?ooh`3oonX0mn_O07MVG01/Fe40ooWg0?obm03omO`0oo[o
0?ofoP3kmOT0ooom0?Ojl@3amn/0cLk90>OWi`3oool0o_kn0?ooo`3moOd00`3oool40?l00080oooo
0P3inOT03`3emOD0IFEU0?ooo`3oool0l?3`0?_en@3imo`0mooo0?_oo`3obmP0UVA]0?O]i03noo<0
o_of0?Smo`020?olo`0?0?olo@3on_d0ooco0?omo`3iloL0hM_O0?oio@3onO/0oo_h0?oonP3oo_T0
oOcg0?onn@3noOP0mOC`0080ooom00X0l?3b0?ono`3oo_l0oogo0?onkP2c[ID0YJ>:0=OPa@3FhlT0
mOo]2`3oool000X0oooo00H0n?c[0?gol`3looP0oOon0?gno`3lnol20?omo`080?olnP3onoP0ooch
0?onn`3nood0noom0?Soo@3good20?Goo`0Q0?Soo`3iool0nooo0?Goo`3<ko40R;Rh09o=c@3Wool0
kOoo030a:`0k>c40nOof0>Wom@3MooH0PKFX0=7ai03eooP0oo[d0=2MXP3hjn<0:a`E02491`3onOP0
oocj0?[on`3io_P0nocg092<R@1SGeh0ooko0>gYjP3ooOl0ooko0080ooom0P3noo/20?ooo`0G0?Cf
m@3Qh=h0e<o<0?oll`3Od/40];2:0=;IY@3Bk:<0aNBQ0?7oh`3Nmkh0c]fV0>7Y`03HfLT0JFIM08f@
M@3?iI<0aN:60<CVVP3Bljh0eo6`0;oIV02mf9D0103o0000503FlJ00c>RD0<?OR03<iI80`m:?0<KG
T`3?hih0fNZV0=_VY030bHP0fn6Q0;BoO@3Gj:@0aN>K0<cWX03HiJ00b=VE0<;LU@2keXl0dNJS0P3o
00000`2?VE`0IgDg0?l000050?l0001L0<[TV`3@iil0fNZT0>Cc[P3JiZ@0TIYI096LF02mehd0do>W
0;;GRP35iIX0h>Z[0>COZ01QE2P0/jb004YR<P20Z7@0_^Zg0=7[a01HMU00TkJ<04mcA@3?l[X0cMfF
0>;c[03EjJ40gO>Z07nEC02^aGd0bnFL0<gTW03AiZ40f>fX09BYI03LlJ`0d^NR0=S]Z02`ah40dNRR
08JPF@1SOCH0QImH076<A@2M^740b>:K0<CKU@3Cj:<0fo2[0<_PV`3>hih0gO6/0<kRW@3EjJ@0a]ZE
0=O[YP3IkZT0e_6Z0=;VX@3Lj:H0e=VI0<36QP2>WEX0T:AO0<3JT`3Im:d0fO2Z0<oYXP34giP0cN^S
0<WYX02ngYD0a>BK0<_YX@38iYh0eoF]0;SFSP2J^700NIA=0:>bK`2GYV<0SYeJ09BSH02?WU/0U:=P
08>BC`2N[FX0eNBQ0>Ke/P3BiZ40_n6E0;[JS`3:jYl20<OWW02?0<g[X@30gY@0g?R^0=3/XP1NN2l0
TJQP0=KWX@3>iId0cNnS0<[`X`31iYT0cnfS0<CNU@3;hIT0dNRP0<[XWP3ClJL0d>JM0<[PU`36g9<0
/l^108nWG@1lU4X0Rj=I0<gUV`34g980`m^A0<oUW03BhI`0cnFM0<c^Y02miYX0_nVM0;gSVP3EjZT0
];j1096<E03D_H/0/iiY044m001lN3/0F5HI05iN803CfIT0en:P0<oVX03:j:00b>ZP0<;/X033k:00
e>nX09^iL@3=jj<0b^RP0<_[XP36i9`0[lZ30<KPV@35g9H0_]>>0>;e/`3:f9d0]L>80;6oQ03:f9d0
dM2H0>[b]P3?gYd0bNNM0=Ci[03?n:T0g_ni0<S/XP1HLC00U:IZ0<_NYP33ijT0VLJM05J2H@2mhK/0
JhMF06j1B@1QGbl020800>3Q_`38dZ00G7DT0=[cXP39i9D0c>ZP0<k]Z@2:Y7@0[lBM0>Sef@3ionH0
b=n[0<o][@36iYX0e=nS0=gSY`3KhjL0Jg@o0?3mb02mb:H0Jg9h0=[Xa`3Sm[@0f^f[059F<`3om>d0
onGX0?oml`3`kMX0`]:[0>_od`31gZ@0e_:g0>Ch_@2X]gh0CEXR0=?QX`3Agj80d=ZV0>Wb``3@h:l0
^lnJ0;cCW@3Bi;@0oooT0?ook03Fa;X0^jJS0?o]k03omoX0oo;i0?oho`3omOl0ooOl0?oko@3oo?X0
V9B80>[Xf@3cl^h00P3oool20?knoP030?_kn`3oool0oooo0080oooo0P3o00000`3oool0n?Sh0?kn
oP030?ooo`0>07IfMP3oool0k^k^0?ooo`3ooOl0ooko0?Ooo`3hoOl0onkk0>:`^@3ooO@0o?of0?co
nP3kool30?olo`090?[cn`3nmol0oogo0?oko`3ooOl0noOh0;6][03oo?H0noO^0080oood00l0oO[a
0?oon03oooP0n?Oc0?glnP3inOT0oooo0?Ken`3nool0ooo/0;BcU@2b/i@0en350>C`f03goo402`3o
ool000X0oooo03D0ooof0?onn@3oo_X0oooo0?kno`3no?l0oogo0?oin@3ooOP0imgD0?oklP3oo_/0
oooo0?koo@3koo/0nOok0?Soo@3hool0mooo0??lo`3hool0RIjS062ES@1BWIH0Plo;05JHU`3Lool0
mook0?Cfj03oonP0eNS:0<[/b`0QEc<0S;RG0=Kce`3oonl0bYjK0?ook`0F2P00DShg0?gYj03oo?X0
nool0?coo@3lnO@0lnk[0?onn`3oo_l0m_Cg0?ono`3oool0ooom0?koo@020?konP0I0?3`kP3oool0
oooo0?WemP3oo?d0g/o805Y=?03;b9l0en2[0<WWW@3;jZL0j?oG0>Go_@3Gk:L0`]>O0>Wbg`3kooL0
nooX0<WQR@3Hli80an:M0=?[[`34e9H0b]ZL0<oRX0040?l000050<7IR`3<iiP0d>^L0<kVVP2HZFD0
0P3o0000303<hid0eN2N06=U9P3De9H0H68S09fXIP38iYh0d>^T0=gXYP3IjZH0^]6;08RRF`/0o`00
03<0foN/0<cXW@3Lm:X0g?:Y0=OXX@23Td`0HG4Z08bSG`28YUh0Mi]A0:;6O03?jJ80amJE09nPI`1?
CAX0_;^;07MhC00O8P00_/BN0=OO^P1QId<0CU0Y08R1D`3Qnk40bN6G0<oUW03:fiD0]lJ10:o0NP3=
hIX0e^bS0<_WW035iIT0anNK06f7?P30ei40cNBN0<cSW@35giP0a^2I0<WSW03BkJH0c^VR0=;]YP3>
j:40`=F@08JJE@2N/Vd0g_:]0<GIU03?i9l00P3>hih0F@3DjJ@0j_nj09F/IP1jVU40jOnj06=d<03S
jJT0emfM0;;1OP3?hih0f?>/0<_VW`3?jZ<0b^RP0<KZX035kZ80_>FI0<?YWP2nhYP0eoV_0<OYW`3>
kZD0d?2W0<OUW@39hi`0gNRV0=COW@3=f9H0f>>Q0=GPWP3PjjT0a<n=0=cWY@3GhZ00U9mM0;2lNP3?
iZ00c>>M0<_RW03FkJL0dnZT0=_b[03FkJL0RZ5K086HDP3Aj:80cNBN0=7VX@3<iYl0b^jT0<;XW@31
iI/0bnFN0;gBS@3<fiP0AeHC0=GYY03OmZh0c>bP0=[i[@39iIX0dnnT0<oYW`3:i9X0eNfS0>3f[@2_
aG`0Oi=;09>WG`2N[fT0fnnX0<oZX`3;jj80`^BJ0<SVX039gYd0loo10:fcM`3/iJh0g=ZO0>3/ZP39
eI<0b=BB0=GTX@3:gYT0dNFP0<cWX03:j:00b>ZP0080aN^P05<0a^BL08f]I035iid0a^RN0<[/XP35
iI`0Yl5j06=j=038fID0g^fZ0<?HT`2niYd0`>RO0<ge[032jZ40eNFV0<OJV039gYT0an>F0<k]W`3G
mZP0Wkmd092^J038hJL0`]VS0<3N[01DQ50074TN08ndR@2aaI@0YK=h0=CNW`2DWUl0iNjg0=kX]03B
gjT0BUTF09JXG03ElId0anBB0<GTU03Ro;/0GgLm0=g]_P3Kjk`0`mfL0<SZWP37jYP0jOVh05AO7@2X
]gH0ioBl0<CEWP3?gkX000X<08:@K03DiIh0dn>L0;o0U02CPVP0U7mZ0>CT`03=f:d0bnj^0<;[Y@2l
iY`0d?B/0=S[Z`2BW600FehW0<kNW`3Kl:l0gNZd0=KP[P3[oLT0l?o?0?7od@3]ol`0eMR]0<_0XP2=
Mf80oo_d0?oln0020?olnP0=0?ogmP3on_T0VY:?0?ogm03oo_P0n?7W0?onm03oo_X0oooo0?clo03m
oOd0oooo0?clo0060?ooo`080?clo03oool0oooo0?Cdm03jn_X0MgMg0?ooo`3Zj^X20?ooo`0=0?oi
n@3oo_`0mOok0?Cnm@39VIT0lLBn0?ooiP3ion@0mOoU0?GomP3kood0moch0?WnnP030?koo`80oooo
01D0ooko0?Ofm03:al80cl[60?oomP3ooO@0oo_b0?onn03hmO00ooki0?;ak03moo@0oooc0?kok`2;
T7X0cMZT0=7OX@3iolh0b]N/0>Kac`3konl02`3oool000X0oooo00h0ookh0?omnP3oo_d0ooko0?om
o`3no?l0ooko0?gimP3oo_H0f=350?onm03oo_/0ooko0?ooo@80oook0240nOkj0?_oo`3dool0mOoo
0?;oo`003a80h?oo05nQW@3>ool0AXF:0=coo`3Xln/0oooa0=OF]`3Lk<D0b^_005N?HP1GQel0a>K5
0?cok02bRX80gMS502TP4@1XEDh0ooWh0?olnP3lool0o?om0?KckP3ooO/0mo;_0>o[k03oo_l00P3o
ool07P3oood0o_om0?konP3nooX0ooom0?ooo`3clo<0ooko0?_`m01XFE80l>3A0>SV_`3Cg:L0`MnE
0<GTX@3]omD0jonl0=_aZ03=h:T0g>SB0>gdk03jonT0d^VA0<cVQ@3@iJ@0gNjg0>7[[03NjZX0EVDR
09VZI080o`0000D0amfB0=og[@3Aj:00`mfD0=3WW`040?l0000;0=?NW01HFQ/0h]jQ08N7B@2FWeh0
b>>L0<ORV`3;eY@0I7Da04]R700oFA802`3o0000<01aT4@0bnNL0<;LTP37giD0f>fR0=7SV@3Ciil0
c>JU0<COW03IlZh0OIM@0<SMV03Sm[@0f>:U0>_`]P11>`/0PWM:0?G^`P033000Ff@i0=[L]@1eLD/0
RGQ=07ZIC@3KmJ/0a]jD0=k]Z02?W5L0dn2K0=SYX`3=hiX0c>^O0<;WU`38kId0b>:I0=?ZY03Il:X0
d^VS0<_UWP3=ij00g?J_0<;MUP3<ij00bNBM0<oYXP3<hI`0en^V04]O6P80cN6L04H0dNJQ0=K[YP3@
iJ00b]nJ0:k3OP1aRd@0ZLV00;_ESP3EjJ@0gN>S0=[PX034di00c>6L0<7OU`37iId0fOB]0<SVWP3;
jj80anVO0<k`YP3;jj80b^RP0<;MUP3<iYl0c>>M0<kSWP3Dj:<0dNFP0=WZYP3EiZ80d>6M0=OXY03C
i:00eNJR0=7RWP3;g9P0g^n[0;k?R`2K[6P0[/9m0=W]Z03:gYT0c^:M0=O[YP2odhh0h_Nb0<gRW@3A
iZ40bn:L0=kc[P3<hid0c>NP0<O[X@32iY`0a^RN0=K]Y`3Sm;00GVTW0<OBT03>gIX0ambG0<;WV@2i
fhh0c^jR0;oNTP3?jj00c^RN0<CNU03HkZD0gO6Y0P38g9@04@1SNC40=Td508bSG@3BjJ<0e^fW0=GZ
Y`3:fY/0b]RJ07An@@3Jh:@0hnf^0=7/Y@3BkJH0e>jW0<;LU@3Ilj`0cNNP0080b^RP05d0bNVP0<SZ
X038jZ00bnVQ092^IP39jJ00bN^Q0<SXW`3;jJ40_=>=0=O[YP2FXV00g>NU0=7RWP3@mJL0bo2S0;kS
UP37k9h0aN>M0=G`Z@3@jZ40e^jR0=3WV@3:gi@0EV`T0<cRX@3JlkX0b^F`08V]O@005`00DG]=0<GU
]03JjK00bmJJ0>;^[P22UU40_=6<0;K6R03Sk;D0EU/U08NCD@35g8h0dNbM0=;_W`30fID0bmnP0<kK
YP3@gZT0`=VE0<3QTP2ohh`0a]ZC0;[;Q02=XEX0`MFF0=GZ[`39fk<0FVIT00TI003LkZ@0fNVN0=SO
Z@3bkl@0gmbc03]54032eYT0bnfQ0;_PTP3Fnj/0^mb=0=;SW@3?fi/0a/n@09:XH03@jZ40a=BF0>gj
a031e9`0gONh0=;c[P39iZ<0fN2/0;6XO`1nIdP0ooc_0?Gej`3dm^/0m_K/0?oon03OgmL0j^[R0?oo
n03]j^<00P3oo_X01`3noO/0oOgm0?knoP3oool0o_kn0?clo03oool00P3o00020?ooo`040?knoP3i
nOT0oooo0?[jnP80oooo02`0=cLg0?_kn`3oool0nOWi0>g]k@3oo_/0oooj0?Gon03ioo@0on[O0>Ro
Z`3Jfk<0c=j/0<[N[@3Pm]80l?kU0?Wom03iooH0nooj0?_on`3hoOT0nogl0?cmo`3eloH0n?Kg0?on
o@3`j^X0mNgZ0?onn03oo_X0oogj0?onn`3mn_D0oooh0?kokP3dn>40l?OE09bTO@39g9`0f>fX0?So
cP3Hi;`0k?GH0?colP/0oooo000:0?ooo`0;0?olo03oo_d0ooko0?klo@3oo_l0ooom0?[im@3nnoH0
o?G]0;N`YP3onoD00P3oo_l0903oo_/0oogk0?olo@3oo_l0m?Ke0?;oo@3WooX0aNCO0>Woo`3XoOl0
NiBK0>?oo`0H>DP0c^3^0?ooo`3dkN<0hMjo0=KW^`30iJl0Q;n702]T>@2oj[l0dN:n0?7DaP2>Qg@0
2P000<:bX`3onoP0oo_o0<c<bP3@dL`0oooj0?onn`3nn?P0oogn0?cjo@80oooo00<0o_oo0?koo@3n
oo/00P3ooo/0803em?80ooko0?omo`3Pe]L0oocc0?oii`3gn=00nOo?0;kIUP3HmKD0dNF`0<OMTP3<
h9T0cM^V0?7ni03_n_80n?o]0=cbW`39fhD0`LJ<05EJ902__7H0U:5I0=SXW`3Fj9h0d>FJ0<oUW03H
kjL0IWlk09R^K@2fchh0S:ES103o0000303BgY`0WJ9R0?l0003o0000[;Qf07bJDP2W`W/0hNbX0<WH
T`3=i9h0`mfF0<3JT`X0o`000500Sj]P0;oKT037hiP0cNNM0<KNU03Bj9d0cnVP0;_IV@3CjJ/0e]jR
0=kRY@3Hhj40cn2L092UHP2AXF80g=VR0;RZN@1SG2P0bMbU07jBG`3Ej;/0IWE<079fD@26WV80cnFW
0<cPX@3?gYd0[Kai0<_KU03Ijj40d^NJ0<[/V036k9L0`^VF0<SXW039hiX0[/Em0;C:PP2@Y5d0cn2J
0=CXX@3AiZ40d>NQ0<kXX@3<iYl0d^NR0<kRW@3FjjH0QIYE09V^J@2E[6H0OYQA0<KQVP3?jJ80dnjW
0<OUW@2mhIL0a^BL0<_RW02JYF<0c=FD0;W8Q@3<gIT0dNRR0<gWX03DkZL0d>FP0=;SW`2`_g`0VZIT
03e81P28Te40T9UH07j4A02EVUX0WJ9R07=e=P1iQ480aNFL0<c/X`80b^ZQ03/0anNN0<SXW`3;jj80
a^JM0<[XX03<jZ80`]fF0=;SW`2gb8@0=TL303A50@1dQD40e^ZU0<cPV`3Cj:<0c^>N0=CYY03<hid0
b>JN0<SWX@35iZ40bnZV0=3^Z03=hYl0d^JQ0>3/ZP3:eY@0[kim0:k3P03=kJ80`^BH0<K[W@3?m:H0
a>BI0<WUV`3@jZ<0eN^S0<WOU`3<hYT0cNRK0<3PU03Jo:l0`]VA0=g^Z03Mj:H0gNVW0<kMW02@Weh0
LWhn0<_PW@3;jJ<0[m^<0<OcYP32k:00a>fO0<?YW035jj00b>ZP0<SZWP020<WYX01M0<[XWP3@iil0
Uk5Z0<cWX038iY`0bnVO0=cg/038gIP0f>VS0=CMVP1HGAd0X:MT0<cQUP3AhiT0c^2F0=_]X`3:lZT0
do>X0<cWVP2EXeH0VJEI0<gIS`3Ghj40enV[05ekA`0oHcD0AGA:08BbS@36l[D0a>RR0=[UX03Dj:<0
cnZU07fOD`1lUdH0b=jC0=gWZ`0=0000UYiU0=7UX03Aiil0hOR`0=c/[@3FhJD0RXmI0=cQZ@3@hI/0
d^ZL0<gaVP3<j9d0d>^L0;7=P02:YF00b^FR0<cT]0001@00dNBf0<KKS02L/F80HWLf06B1?P36iIl0
eo6X0<cTV02ebgP0RYi90<oQS@3KkI/0d^FF0<_PT`3AiY/0cNbL0<GUTP3Aiih0JGdh0<kSWP3=iih0
dO:S0<SWV@3EhIl0fmbP0::HH`3Lg[T0_/bY0;_C[`3Sn=L0mooY0=SOc@3iooH0koW`0?_oo@3clO@0
oogo0080o_kn0P3oool00`3ooOl0ooko0?l000030?l00080oooo00L0l_;b0?ooo`3gmoL0inOW07in
OP21PH40n?Sh0080oooo02P0mOGe0?chk`3ooo00bMjo0<cM^@2TP5h0d[>70=CNW`3>jYl0b^JL0<SW
Y03=iJT0bMna0<ON]03Smm@0l_oU0?Koj`3iooH0nOoh0?ooo`3mo?l0nOCk0?omo`3_i^T0^k6b0;J[
/@3ooOl0lng_0<K6_03Del80VjIn0<kJZP39fid0cn:R0<oZY@36h:40`]VS0?_ok@3bmN`0ooco2`3o
ool000X0oooo00<0ooko0?ooo`3oool00P3oood0:03oo_/0oO[e0?onn`3ooO/0Z:2N0?omo`3oo?l0
o?_g0?oom@3oooX0o_oo0?[oo`3do_d0l_of0?3on035hMD0j_oo0<k]k`2oe=T0l?oo05EVK@3ajOH0
ooko0?koo`3^kM/0foGB0<K``026_8X0BhIX0;oZ_@3;h[H0e/>b08]iK@0b8PT0f<Z`0?olnP3onol0
dLc80>o/h`3oo_/30?ooo@H0oooo02<0ooko0?oimP3oo?d0ooOj0?olo`3VgMh0o?KV0?ooiP3Ykl<0
g>Vd0=kc^P2of9h0bNVV0=7^WP3@gjH0f>>h0>[ed`3eoo/0koo/0<GKT03AgYH0d<^C05UG7P38h9H0
a^2F0<;NT`32hID0eoN[0=CfZ@32hYH0dNnU0=C`YP3Ajj@0dnjW0;WRUP020?l000030=C_Z03Fij<0
o`0000<0o`0000H0an^Q0<?SV03BgIP0b]ZC0=kh[`3CkZL70?l0001R0<;PV03o0000o`000=K`Y`2@
Yel0b=nG0=?]Y03@jZ40`=bB0<k/XP3=j:40b=fL0=W^[@3=h9h0c>6N0<WPW03<iJ40W[=`0:2`K`2E
VEh0inF/0:6LI@2NW6`0^;^>0<[L]P2E[H/0H85T065M@03EfK@0cMJ[0=_]/`3;h9l0_mN;0=WbX@3B
jiP0foNR0=OcWP3>kYT0a^bI0<o^X03Ak9l0/l1h0:6XHP2NXEh0[[5^0>[c/03AgI/0c]nK0<WPW039
hi`0e_2Y0=7/Y@37hY/0foJ_08bZHP1mWE@0bN^Q0=3`Y`37jIl0bnnU0<gcYP2ff8`0e_BZ09>TH03I
iJD0[KMh0<gGV03Hhj40cmbG0>?`Z`3:ei80c=RF0:ZfM02LZ6H0RYUF0=WXY@3Dhj00/L1m09JUHP2A
X5d0LX<o07>7@P35giP0d^bU0<3JT`25W5H0R9mI0;K;QP2ldH`0d^NR0<[NV@3;giX0eNZU0<gYW`3=
iih0PI]B08bSF`2ecH<20=3VW@<0cnJN08d0c>RN0<S^X@3@m:`0an6P0=?/Z`39gih0dN^T0<STV@3B
kZ<0cNVN0=O`[01TNCP0f>RY0=3YY@37l:80_nbK0<;XW@39j:@0cNJU0=3UY03?iZ00bNZK0<WZV@3:
jI/0`nfK0<SZW@3<j9d0cnJN0<SXW@38hY/0d=nL09>HF03CgY`0e^bT0=3eY`35jYd0d?JY0<SaXP31
k9`0`>^L0;cUU`39lZ<0`NNJ0;cRU@3@l:@0f^^T086ECP3>j9l0`mnD0<g]X@32hYL0cn^Q0<KNU03G
j:40Xk1[05IU803PnKL0bMnO0=c`/@39gIh0e^^Z0;c9Q02HY5`0SYe<0=S^V`35hH`0aN>I0<?PX00E
=0P0X/JR05B0G03Dm/<0/>ZM0<[m[P3DgiX0d>jT0;gVV03>j9l0GEdM0=[a[@34fY`0;RH009:SG@37
iYP0bNFK0=K_Z`3Pj[D0g>2^09NCIP3PgZh0JW@g0<cPV`38ji/0bNjQ0<GVU@3@kj40bN>L0;gBS`3K
jk`000800=SS^@3Fjj00Sj=K000=00004000K8A:0<SNX038g9d0cn>N0=O[Y02/_GH0hO>Y0<cNU03R
m:X0aMN=0<KUU`35iYD0a=nB0;38OP2K[fL0cN6I0=CZX@3Ejj80c]nI0>?b[`2?VeT0_;Mo0>;U[02l
hZD0j_oE0?Wcf`3Cb[T0lO_`0?Oon`3dooT0nNkd0?ojo`3oool0o_oo0?kmo`3oo_l00P3ooOl40?l0
000c0?omo`3fm?L0ooko0?ono`3fm?D0^kVj06MUIP3>c<d0ooko0?Wgn03oo_l0noWj0?ook`3oonP0
a>2_0=;[/P2_UF@0el:;0=;UX`3AlZ/0cNjW0<[[Y035h9/0a^FR0<?VY03Lnl00l?oI0?;og@3donD0
mOo/0?con03moo`0ooko0?omo`3oo?d0ooGe0;nc]`2XWj@0XinN0;k3[03CgkL0d>BU0<gVXP3:j:80
bNRT0<SWV`3>jZ00dnR]0?coj03ooo<0oogo00/0oooo000:0?ooo`<0o_oo0P3oood0:03imO80ookk
0?KakP3on?T0g=?D0?San03oo?l0oook0?ool`3loo@0n?oj0?Ooo@3dooP0ho_K0>kojP3Won/0Tjb`
07NFV03GjNd0m?oo0>clo03onol0m_go0?Coo`3nooH0k?oX0<GZ_P2Ud:80G9Qo0<3]`P3=ikP0l>?@
03/T7017=QX0ooKH0?onn`3ckO/0gMK@0?onm03ooo/40?ooo@<0oooo0`3oo_l09P3nnOD0ooWj0?ol
o`3oo?l0lNWW0<k<]@3_lm80g>Jd0=GT[@39gZD0dnbb0<S^Y@39jIH0d^2]0=gX`03[mm40looi0>[o
k03Ek:@0h^j/0=cAV@1YIBP0bNRL0=3_X`3<kZ40anbN0=7hZ@2dfh`0c?6S0<_[W`3Dl:D0b>2F0<KR
U`3IokL0]M^@0=om]@3?jJ80f>bW103o00001@39kJ<0c>ZP0=CKU@3SkZT0`=B=00T0o`0005@0cnZS
0=[aZ`36gIL0RYiI0=ga[033f9<0an6J0=G_Z035hi/0bnJO0<gMW03GjZP0eNjZ0<WTW`3Eljd0b^FP
0=GZY`36eYD0[KIg09RLG`3[jK00UHAF0;bcR00b?QP0b^2l05EjF`0L4P00em^h0=KS]`32h:00a^NP
09FaI02P]fL0VjiO0<_LSP39fhl0dnjQ0=OjZP34iIH0`=b?0=KXW03>fi<0h>ZS09ZTG`2@WEP0UZER
08nPG02>YF40Y/1i0<gXX@39i9d0aN>K0<o]Y@35iI`0dO6X0<c^Y02mgiD0`^BJ0<CVVP33j9/0b^bP
0<k/XP3Hk:L0S9]J0:ffM`3SjJ/0dmbK0=SSW`3>fiD0RYMA069a;P3ChYl0a]FB0=k_Z`37fiH0g_>^
0<gRW@3:hI/0c>>M0<;LU@3:i9d0dNRR0=C[Y@3BjJ<20<SMV00;0=GYY02BYV40dN:N0=[[Y`3Rljl0
a=VD0<KVV`3BlJD0an>H0<_WW03El:<00P3=j9/20<gWW@2A0<gWWP39jIh0/mj?0;?GS`3Bj:X0b]bP
0?3o``38hYT0Z<Uj0<KYU`36j9/0`mjI09BYJ03Bg:00e>VV0<3[V`2lk9P0`^bP0<SYY03<iZD0d>BU
0<oVXP36k9T0b>^G0<cYV@31kY/0`nfK0<WZV`3:jId0aO2P0=3`Y@3Sm:h0Ti9B09>JE`2?WUT0_]Z?
0<STV@39jih0anbN0<SaXP34kIh0_nRI0<[cY02niiP0`NRI0<_[W`3RkjT0VJYS0>Gm/`3?jj00`N>F
0<3RU@3?kj<0bNFJ0=[`Y`3Kk:D0c]nI07Z<CP2<WV80Tj9W0;W8S@27T4l0]kik0<[DS`3:g900fo>U
0=?_XP3=lJ/0d?:e06:7F`0ZD2T0/=J]0;7:T02fmZ00]_2L0>3WX`30hYD0bOJU0<_QV@2PTe`0bn6Q
0<gUY`0o>040b^2E0<;UU@3:jZ40eNn^0<OAW`3Mg[@0NW=907mhC02?U5`0MhI50;_KT02ni9T0_>6A
0<CUUP3Bk:D0L84m08NCI@000@00fN6h0<WJT`3CjJ40f^ng08RMI@1_Q4`0Wk9j03iB5`36f9X0dnJV
0<7DTP2=WUX0e^NP0<WKT@3Umjd0d^jQ0<OXV@3BkZ40d>^N0;?7O`1hS4@0dnBM0<3AR`3MlJX0^m69
0=K/Y026PCd0d]>?0<caZ`33gj@0hmbo0;FXU@3looH0h>gS0>Sck@3onol0mnOa0?ono`3lool0o_oo
0?omo`3onol0ooco0?ghm0040?l00080ooko0300oO_l0?klo@20OWl00@000>cZj`3oo_l0oogn0?on
o`3ln_/0oog/0?koi03=j[80c>VW0:NBF@2eXVL0e^^V0<WZY@32hih0bnfS0=;/X`3@lZD0bO2Q0<KZ
XP39jJP0b^R/0<GJ[`3Ei/80nOoa0?_omP3moo`0oooo0?ohl`3oo?P0ooWh0?omo@3oooX0o?oT0=7Q
/03=iid0b^VI0<SZWP36jZ@0a^JJ0<cXW@3@iJX0o_oZ0?ool`3onoh;0?ooo`002P3oool30?koo`0Z
0?ooo`3oo_l0o?Si0?Wem03kmOD0iMoQ0=K@dP3ooOl0o_go0?_onP3jon`0nOoO0?Soh@34fZT0dNZa
0<gZZP2jeJ80c>K30=GZk@3Aj?00jooo0>3io@3[ool0l?oo0>koo`3`ool0n?oc0?Coi03BhkL0bNBg
08BlX`3Rond0bnO10?C[g00e81/0HU<n0?ohh`3oo_l0ooco0=[@cP3ono<0ookm2@3oool0:03nood0
nooj0?con`3nood0oo_h0?onmP2?SVl0c=:V0=OWZ03;hY`0fo^b0>kobP3;kjL0anNB0>Gf`03comL0
n?oP0?7om@3doo40b=jE0=gYY`3XhZP0FUPK0<gYWP38i9T0`^:F0<OYW032i9L0cNfQ0<GUV@3ElJH0
b^BJ0;kDR`3;hiT0b>:K0=W`ZP3<fiP0dmnM0=KOWP3Ki:<20?l000060=W]Z035giP0/<N10;>nN@3>
fI@0LWlj103o00000`3Ghj<0o`000?l000020?l0001>0>7e/03DiJ40d=nL09fYI`3Eh9h0cmjK0>Si
]@2W^gH0RYmJ08RMF03Ik:X0goBa0<;KU`2<Yf80do6[0=7/Y`37g9T0g>b[0=cVY`2]/gD0SXiB06iL
:P1dISD0GEHX01`K003AejT0K6Xj04QQ9`1lYf80YnNC0:cWT`3Qnk80e^6M0=;@T`3IgZH0Wjie07:>
D@2Y_7`0b=bG0=_b[02jfXl0b>fP0<CZW@32j9/0c_2T0=Sf[03?jj40e^bT03Y>2@3YoKP0go>^0=GY
Y038gIP0`=F@0<cQW03Ek:H0fo:/0<SOV@3Aj:00e>ZR0=GVX03FiJ00h>^Y0;g6Q`1TKRl0bMFE08fQ
G02=Y5`0eOBX0<c[W`3]ol00`mfF0>?m]P2nf940h?^d0<KTW03<jZ80b>RO0P33hiX01P32hYT0b^ZQ
0<WYX037iih0a^BL0<SVWP80b>>L00X0Yl9k04mY8P3Pn[<0^]B;0<_WW038i9T0a^:E0<CPT`39iIP0
c>RK0P3:jI/0T`3:jId0bNVM0<SZW@3Fnjd0anFK0=7TXP3GijH0e^NS07ZBB02Q_G00b^^L0<k]X@3B
jJ40f^jW0=CTW@3Dk9h0b?2G0;gZS`35ki/0bNVM0<cWX03@iJ80cNNN0<K/U`39jiD0cNRK0<?]V`36
ji/0c>RK0<cXW@2gh940d?2U0=WZY02VYVP0`lj<09JWH@3LkJH0g_:Z0<kTV`3DkZ@0cn^P0<WXW035
i9P0bnNL0<CPU@3DkZ@0c>BJ0>gn]`2;XEP0cn^P0<GUV@2ceHP0bo2R0<?SU`3>kJ40dNVO0<kRVP3D
hI/0a/N30?Kg/`3HgYH0g>BK0=oWW03Nm:`0cNRU0<gU/@3Gj;`0=D@M0=7W`02M`I40^nR]0;cYZ038
iJ80f>RW0;g^W`3<mZX0g]jN0=7YW`3;kJ00e>6L08Ea?03KjJ`0eNFW04Lk1`2S]g80b^^T0<SXY`2f
eIX0mooK0?kog02RWGL0Y9ec0>GS/03Wjk00b]fK0=3^Z039jId0eO6V0<_RWP003000=d<E00@90`1O
JSl0`MR:0=7YW@3AjJd0cN:W0<kTYP3AijT0_M6D0=;VY`1NLc80b]fK0=[[Y`2jbhL0VJYT0=3QV`3<
i9X0eNnU0<cVW03Mmjd0_mV?0=OaY`20V4h0OiE=0=3TW@3NkjT0cn2J0;[7P@2OZVD0cmVJ0=KUZP3D
i[H0e>2h0<g:]`3in^`0jnkU0?koo`3on_l0o?[k0?coo`3nool0ooco0?oko`3ooOl0oOSb0?_gkP04
0?l0000a0?omoP3ln_/0ooko09NEUP020040ooko0?[hn@3oo_l0noWj0?ono`3oo_P0oooa0<[V]P38
hJL0YXeD05e72`3Bhi`0b>JN0<CRW039ij40eNZU0<gZVP3<kYX0d>nQ0=7]X`3?jZD0cnN]0<7HXP3@
hKL0bm^f0?Koi@3ionX0oooZ0?ooj@3`lMl0b/jm0=;J``3domP0cnB/0<cXW@3:jIT0b>ZM0<SZX039
j:@0c>JW0<gS/P3loo40oook0?omo`0;0?ooo`002P3oool0103nool0oooo0?ooo`3oool20?ono`0W
0?3^k`3oo_l0Z:BS0;>_[P3imo`0moWo0>;_gP3Ch/40c^>[0<gRZ@3IlZh0c>RM0=SgZ@3:ijL0b>6g
0>GooP3Sool0f?oo0>Coo`3PmOP0jOco0<S@d`3ho_`0n?o_0>clf03CiKD0^^6/07jjX03@oml0d_3>
0<c4]`0M2PH0^:^K0?onk`3hm_T0ooco0<g3`@3oo_H0ookm00H0oooo0`3oood0<@3loo/0mooj0?So
n`3ho_X0oooj0?ool`28QF80UYUZ0=o`ZP3@j9`0b>^K0<K/W`36jZ80aNF@0=?V[P3Hik`0enJm0?3o
l@3donl0gO>X0=?OW@38aX/0FedN0=;/XP35giD0a^:G0<o^XP36iIT0d_6U0<OSV03CkJ<0_=B:09^a
J013E`l0d>6M0<;ASP3_n;L0c=:B0=cQX@3Cf9P0IF/[0<[FU03Ij:D0cnBO08VSG02jgi80f_b`0<;R
U`2ifHh00P3o00000`37iId0bNVP0<g]Y0020?l000180=CUX@3Hij@0f>BR0>cg]@1;EQ@0UYmN0=3K
V@3Cgid06RT00=OXY03Rljl0am^F0<OLU`3SoKH0a^6J08j/I03;iYl0eNZU0=WZYP3Eh9h0gN>S06=T
:`3gk/L0oooK05I=;01JE380MFm?0>K<^`001`0001D00;cm^@35okX0`MjK0=;QX03JgZ40f>f/0<od
[P2jjJ40AUHG0=[NX`3<e9P0d^:Q0<[NV@3NmJl0e>^S0<KMU@3CjJ00dnNO0=7RV`2HYf80a]FB0<gL
V@3Pkj`0fnbX0=CXX`3Oljh0am^F0=W^Z@3<hI`0E6PQ04ED3`1AG1P0gNJS0<[@T03Ni:H0`/b=0=;Q
X02me8h0anFK0;GLS@39kZ00^]R@0P39iil06P34hYX0c^jU0<c/X`3>l:H0b>ZP0<OYW`3;kJ<0a^RN
0<W[X@3<kZ@0bnfS0<OYW`3;jj80d?2W0<k^Y@3<jZ80b^RP0=7/Y@3GljT0c^VL0=;]X03@k9l0b^JI
0<WXVP3:jI/0bNZK1038ji/06@2ohI@0`]jC0=[[Y@3?gYT0`m:=0;WAQ`3FlZL0c^fQ0=GaYP3CjJ00
`MF=0=SZWP3<iI80d?NJ0;o[S038kYL0bNZK0<cXWP3?iZ00c>RN0<K/U`39jiL0cnNK0<G/V`38jYd0
0P3=iid0M@31jY`0anNN0<KJU@2NX640k_Zh0=KWX@3=fY@0gNfV0=CUWP3Aiih0cNFK0=_cZ@3EkJ<0
d^ZP0=;XW`3AiId0cN6I000?002=YE/0^]V=0<;RUP3<lJ<0a>VK0<_[W`3:jId0cNFK0=G[XP3Ll:P0
bMnF0=7WW03;hiD0e>bN0=[UU`3;iYl0_MfN0<cV_`001`00D5U409BXS0003`00aoJb0=?o/P3@jIP0
eN:M0<OaY@2jgY@0fmZJ0;[>QP3MnJh0g>FR05Y64@3=ei/0c=JJ05a>7@3<f9X0`n6Q0<g//033hJ/0
mOoM0=WX_@3OgKL0FE@/0=cIYP3KfZ80h^j^0=G`[@3?jj40aMnF0<_PW@0]?@0000T00002003<fJ/0
LX/j0=KaXP3>j:L0d^^Z0<_QX@3AijL0d>JV0<[OWP3DjJP0e^VW0=CWY@2ochh0RIYF04aM6@3?hi`0
dnVQ0<?JTP39hiX0bnVO0<;PUP3?jJ00EfhV0<kRV`32dhd0ho2[0<kTW03Ci9h0IV4W0=SPY03@kK<0
_mNU0;fgW@3oond0oood0?Gkn`3ll_d0o?cl0?coo@3loOl0oO[o0?oko`3ooOl0ookh0?oomP040?l0
0080ooko02l0o_cm0?Gcm02ASi00lNo`0?Kdm@3oo_l0noWj0?ono`3ooOd0oooh0=K_a`38gjT0/YEM
071F6@3<fI40b>:I0<_UWP3>ij<0e^NS0<kVV03;iYD0bnJG0<gXV`3=iih0b^>Q0=;Z[03>hj/0bMfX
0?OofP3eom`0n_oN0?7keP3Yl]<0bmJh0=WWaP3fomT0cNFY0<[YW@3:jIT0bNVM0<WYX039iZH0c>F/
0<gS]@3koo@0o_om0?omo`0;0?ooo`002P3oool00`3oood0oooo0?ooo`030?ono`0W0?ooo`3oo_l0
emKB0?oonP3`lnP0m?o`0=keb@3;hjl0cNNZ0<oX[P3El:/0cnbL0<[VT@3eolX0m?oL0>3onP2^j^/0
>7in05F=SP1nS9D07c8h089bO@24MGX0m?o]0?GogP3;hZ`0_o>e076bU03RooX0^mO10?WbjP0O40d0
h=;?0?cdl@3oo_l0oo[o0:FJUP2h[jX0ookm00H0oooo01/0ooom0?oon`3oooX0o?oj0?Goo`3coO`0
nooo0?omnP3ono80j>2l09VEI@2d_gX0bMjC0<_/W@3?m:L0b>VR0<_[UP3AjJd0e>Rg0=?V^03goo<0
lOoV0<oTU`25U4l0e=ZL0>Sa/03@j9h00P3<i9X0S`3Ajj40bN>I0<SPUP3Lm:X0Mhe407N;@`3Kk:D0
cMfF0;:kNP1CG1/0?T@404I<303Igil0g^BT04iG5P3OjZP0g>RV0;c;R02=XUd0bNnT0<7SU`3IlJL0
_]::09>SFP2CX5X0bMfE0<oWW@3=jj40e_b_0<OYW@3;g9P0d=nL0=SWY03BgY`0RIEC03a81P2CWed0
fnZW0<[IUP3Ij:D0f^^W0<oVX03Ek:H0aN2I0;gHT@2>ZF80f?:[0=3UX039gIP0i?2^0=;MV`1BH2D0
hoWC0=W]bP3lonl0h>;D0?WdkP1SIeP0Y/NX0;3S^015Rd`0UMN@0<[^YP3@j9h0e^BI0<GNRP34j900
__2G0<GUXP3VmKh0RI9M0::JJ@2KSE`0jm^X09^@FP36bhT0fNJP0<?ISP3FlZD0f>bU0<GDT@3GiZ<0
TJ9N09>TH02L[FT0QIUD0<OKUP3NlZd0e>VT0<gQVP34dhh0iO2/09fVH`3GgId0g>:T0<kHV@3@gih0
bnFN0<OUV`2jhI80^Mj@0<g]Y02lfY80do6Y0<_YX@3Bl:P0cN^S0<WYX03:jZ40bn^R0<WYX038jZ00
bnfS0<W[X@3:k:80c^jU0<[ZX@36i9`0c>ZR0<o]Y@3CkZL0Z<=l08fWGP3BjI/0dn^O0<cXW@3>kJ40
b>RL0<SZWP36jid0aNbM0<G/V`35k9T0a^^K0;cHSP3:hYP0WJ]P08>AAP3EiI`0`mZB0<kYXP3;jJ<0
a=nH0080e>RP08H0aMnE0<WXV03:kY@0a^Z@0<OXU`3:j9h0b^NT0<[WY`39ijL0aN^R0<WYX03AiId0
a^^M0<[YW@3@iYd0d>JN0<GZW@3;jj80enbW09FKG@3<g9/0eNZU08FBC02IYV00f>VR0=3TW03@iYd0
e^jT0=CZX@35fi80cn2I07N7@02;W5D0dNfR0<g/X033hiL0co6T0=7hZ@35jY`0`n>G0<c[W`3KmJ/0
e^jT0<SVW02nljD0`_NY0;o_X`2bh9D0Z=f?00<D000M8P00TYj6045SB`0E@BH07D0P0<kL^03QjZ/0
d>JD0;OUP`2aaGd0HH8k07^ID@2d]WD0am^D0=?]Y03Ii:00UheB0=kXZ`3PjZd0HE<R0=OCX`002@00
K7a=0<OM[`2oeZX0g_380?Soe`3Ig[D0=SX70>;W[`3IijT0fNn_0<gTWP3@iJ00`=:D0;;2P@2d`Y40
00<00=7Q/03Ln:@0]]=o0<g[Y@3Ajj@0eo6Z086KE03/okd0`]VE0=G/Z02X_GX0QIQH0:>fMP33eYH0
d>:T0;o;R@2CWed0S:5L0<KPV@3@lZH0cNnS0;gMTP3<j9h0RYiF08ZJD`3RkJP0e_B^0<kUX@3_h:L0
NGPh0=Gg[@36jZ@0bLnS0=;;[P3?ak@0o_om0>OXk03jooT0o?ok0?_lo`3ooOl0o_Oo0>oYk@3TgmT0
cl_00<W5^P80o`000P3oo_l09`3no?d0ooko0?[hn@1oOGh0YJ>T0?ono`3knOX0o?[k0?ono`3on_l0
ooko0?Cok03>gk<0/hmM0<fZLP3Bf900S:1H08ZNE`2FZVD0R9AB0=3PU`3Eii/0f>fR0=?WW`3=hiX0
bN>I0<CNU@3@k:80cnfU0<WYX03=kJ@0bNJT0<[VZ@3:hjT0hoc50?CoeP3Pn[d0b^NT0<[YW@020<[Y
V`070<[YW@3:i:D0d>Vb0=G[_@3gonl0n_oe0?koo@0;0?ooo`002P3oool00`3oood0oooo0?ooo`03
0?ono`0X0?Kfn03oool0oooh0??ejP3lond0mOoS0>7m`P3=jJ`0cNJ_0<gU]@37h:L0cNRU0<cWV03e
ol`0looJ0>_oo`20]k`0OlK807^e]`3^ool000P;0=;8d@29OX80k_oZ0?Woh@3:gJH0_Nf_0;7^c`3R
ood0^mK70<W2^P0J30T0lnOY0?omo`3oool0ooko0:NLUP2:PGX0ookk0?ooo@D0oooo0P3ooo/0W@3o
ooP0o?oj0?Soo`3hoOl0ooko0?O[j`3ono@0i=Ng0;J_P@2W[V/0dn>L0=WeZP31hIP0b^ZQ0<SZT`3;
iJH0c>>_0<_Q/03eonl0n?oZ0<WKS`1fQSl0e=jO0=GQW`3Dk:80d^ZP0<SPUP3>iY`0dNVO0=K/X`37
gI@0Ef/S0:ZnMP3DiIh0e>BM0=7JV@2DWE`0UIiM08fFE@3LijD0dmjL061/:P32cX`0gnj[08ZIEP2D
ZF@0_>2F0=Sf[03Bhi`0h^nY09^RG02FW5H0eN:L0=;SW037gYH0c?2V0;kPUP3QmK00cn2L0=SYY@3B
hil0UjQT03Y;1`3DiJ40d>6M0=_/Z03Cij80c^:M0<cVW`3CkJH0d>^T0=_f[`28Xe`0b^BM0<SMV03P
m:l0cmjK0>?_[@11DaD0_Mj_0<GR]P3honX0noo_0?Wik`30b;/0FgAN0<gbd`0ICR00Jj1/0;oV[@32
i:P0c>Z^0<?XY@34kjP0/>RO0;?XY02nhJL0a]nX059D8`1SFb`0X99Q04i23P2RZfX0d>JM0<o`X@2o
iYD0cnJN0=?TX03Bhil0Y[Ye09FYI029WUT0T:EP0<cQW039h9X0c^FO0<oVWP3Cij00`]6<0=[WXP3C
gY`0d=VJ0<gGV03Hi:@0f>fX0<cVW@3JnZh0d?2T0<g[X`2hdh`0RJAM07JABP2mf940bnJO0<SSW03A
k:D0d>^T0<[UWP3=jj<0bNVP0<g[X`3:j:00`n6I0<_VW`38hi`0e_6Z0=K`Z@32g9D0cNNP0:[1N@34
fHh0f_2U0<kXWP3;jIl0aNFL0<KZX036jih00P35k9d0V035k9/0a^^K0<WSW03LlZT0X[1U0;k<P@3D
i9/0cnJP0=3]ZP39j:D0g_Vf0=?WW`2I[fL0_mjH0=GeZP35ii<0anVE0<?SV03:ij@0bNNY0<SW[P36
ijh0`nZY0<SXY@3AiId0b>ZM0<cXW@3@iYd0dNFN0<W[W`3<jZ80b]nJ08nEE`3DijD0cNBN0:fnM`22
Td`0[L=j09J^I01XP3H0Ih4g08nWG@2M]F/0b]jF08ZKE02aaGd0cNbP0<3PU030hYD0cO:T0<7XV@35
jY`0c^jR0<c[W`2acH80`=R>0=;^X`2bgHd0bOBU0<oeZP34iIh0FHU;03aB902OZH@0Tj>8039C=P1]
U7D0RJQo0=SX^`3HhJ00aMR70:G:K@1^PS/0S:]W0=7_Z@2IXV40OYA<0<OQV03JjJ@0Q8950=?OW`3=
fid0FThL08=hB`0h=Pd0=CXA06EbA`3?i;/0j?[@0>kkd03AfZd0ZkF008jLH@2FZfX0[L>50=3UX03E
jZD0e^RZ0=GUY03>g:/000@00<kP[02ofhH0e?:L0<WWW`3CkjD0^M>9096[HP2/`g/0fo:/0<_RW03J
kj`0aMRH02`n003DiZP0dN>U0=?OW`3JiZ@0AUXE0=?]YP33iI/0a^^N0<k`Y031giD0fnnW09NWH02W
/Vd0a^6L0=K/Z`3Wgj40WYYJ0;oIS`3:k:80eN>^0?oog@2eZi80oOge0?Woo@3iooH0o?oh0?cmo`3o
oOl0mo3h0>;Lh03`jnD0`knd0:jZW`3oooP0ooki0?omoP3ln_/0oogn0P3oo_l09@24PX<0QhF60?on
o`3bl?40o?[k0?ono`3onol0m_Co0>ooj`3Ch[/0Zh9F0=>^NP28RdP0MHI009FVHP2DZ6<0EV8P092M
F02U]6l0d^>M0=;VW`3?iId0cnVP0=;/X`38ii/0c>^O0<KVVP35iiX0b>ZP0<WZX`32hih0iOo30?7o
c`3;j:H0b^NT0<[XX03:j9h00P3:jI/01P3=ijH0eNje0=cb`@3honX0nOo_0?com0/0oooo000:0?oo
o`030?oonP3oood0oooo00<0ooko0200o_oo0?_nm`3en^H0o_oZ0?Oof03Qnk80b^JI0<oZY`3Kkm<0
lOof0?Gom03gonX0cnBY0<kR[@3?hKT0kooo09Vg`@3<oOl0OZj`0>;oo`3Lool0l?oo0?;oo`3[ond0
mooS0<OEY03Em[l0O:n@0>Koo`3bool0hMSA01d>1`80oo_o00L0nO_h0?oom03Ec[h0[ZRJ0?gml`3n
ooT0o_oj00@0oooo05H0ooom0?oon`3oooP0oooj0>gWj`3onol0n^og0?oin`3ok^L0ookQ0>KM]01C
E1X0RY9F0<_JW`3Nl[D0aN>K0<g_V036iJ40d>fc0<OPY`3iond0mooR0=GVUP2AXEP0f^nZ0<WPVP3K
mJ/0d>RN0=O]Y01HKRD0=d/30<cPV03KkjL0enRQ0<oPV@3DiIh0f>VR0=k]ZP3IjZH0c^:M0<kSWP39
h9X0B5lI0=7XXP3IkJP0e^ZU08^LF03DjjD0_N>H0<7SV@3:h9L0fn^R0<3:P@3PjZ<0VZYS0>7f/@33
gYT0^=fH0<3SW`2AZf@0`=ZC0<OQVP35h9T0f_F^0<?NU`3Im:d0eNnX0=7[Y036gIL0c^RQ0<gYW`38
i9X0b^JL0=?_Y@23WeD0dN^R0;S>QP3Unk<0amRB09ZYI03AhYh0cnVX0>goa`3NjkH0f^2`0>o`b080
oogd02P0DDLm0<W9_@3Sk^00F89^000C0017R700:71J03AiIP0?DCD025PM04:=BP2_m;<0]>J[0:_D
W03<jk80bnV]0=3c[`2ggiH0co^/0<7/VP3?kJ<0b^6K0=?]YP3:i9d0f?:[0=3[Y03;jJ40anFM0<k/
Y03Bl:P0^=R=0;kNT`37hiT0`mfD04MH503KijL0Y:e^0=OPX@3Dgid0fnZU0P37fi<0^`3VnkH0f>fX
0<gRW@34fI@0GW8]0<3DS`3IkJP0enRT0<gNVP3EiZ80d^JQ0=O^Z01dRD@0?U<>05AY901lT4/0c>2K
0=KZY@3DiJ40enRT0=g/Z@3ChYd0`=6:09Z^I`2leI40b^NT0<WXY@2jgIT0cO:]0<GYX@39kJ<0co6T
0<SXW`3CkJh0HWTe0<oQU@3@iIP0b=jE0<GSY@2oh:L0bNbf0;WHW`2D[F/0RZMU0;WT[P2mhjX0dNn_
0=Gb/02nfYl0^MNS000A003>mLT0]]nc01e75`25Z780`]R?0<odYP22WU@0eNVR0>7b[P3Dm:/0`=^F
0<WLVP2LX6<0c^6O0=cf[`3=jIh0c>^O0<[ZWP39jId0anVL0<g_XP3=kJ40d>nS0=3/X@38hYP0a^:G
0<KXV`3Bm:L0b^nQ0<S]W`3;kJ00`N>F0<OVVP3>jYl0T:YP0<KNU03Ijj40g=nH0=kQW02i_Wh0Ifda
0=KNaP1?N500E8QH0<K/^@28V6T0gn6`0=[UZ@2kg9L0`^^M07bHCP3Hf9P0hnna0<_ZY`3BlJd0f^nZ
0=3/XP1<JR00d>NO092LFP3?i:40b=fJ0=oLY@1YE2T0ZIMa0>WP]`3Ce:X01A80000:0011DB80jO_7
0=[d]`2ieiL0bnbW0<7KVP3CjJ4073800>Ci]P3FjZD0c]j]0009003Bi[40aMn80=GaW03DkZL0d>ZP
0=3[WP3=j9/0f?:X07F<A03HkjT0aMbH0>Sm_03Hk:d0Q9QI000<003>g9l0h^j`0=;UY@0jD0l0a^BN
0=Og[P3HmZ`0`MfC0<gSVP3>hYX0a]N@0<SKV@3=h:00a]6=0=gNW02BVE<0a]ZB0=;a[P3Li[80ViI`
0?[bg@3donl0n?o]0?_okP3nooX0ooko0?olo`3nn?`0ookh0?[fk@3oo_<0moC]0>c[i`3oo_l0oO_l
0?cjn`3imoP0oogn0?ono`1nO7d00P3oo_l02@3ooOh0ooko0?ojo`3oo?l0mooc0?coj03K[H`0M4PQ
0=cIY0020=KTYP0N0<kTW03BhY/0gnf_0<WIV`3^ol40^/f=05AY:02C[6P0foB`0<STVP3Bl:H0a>BH
0=KfZP38kId0`nZI0<3WU03:kil0cO:T0<SYXP36iJ40bNJT0<[WY03<j9d0c>VI0<WUV`3PnkH0k_o8
0<oS/P3<gK40f^_12`3oool000X0oooo00l0oooj0?ooo@3oool0ooko0?kno`3nool0nogj0?Ojk`3A
f[l0fN?00>Gd_@3JlZ@0an:E0=7Y[@3Yn^X00P3gool08@3hoo<0cn6]0<kP[P3>g[L0kool09Zk`03J
ool0U/2o0>Soo`2Yd<d0l_oo0>ooo03Em]/0^mF`0<CN[P2gh:H0R[bI0>_oo`3eool0YYbC00d0003o
mOd0oo_o0?Wll`3oond0f=>m0;2[V03ooo<0oOod0?gnmP3oood0oooo0?ono`020?ooo`2:0?oon`3o
ooP0oooh0?c]l03on_d0nn_^05E6@`1MCd@0Edh]05UD:P1kOTL0]Kf40=GOZP3<gJH0b>JN0=CfW`34
iJ00cNb`0=Sd^@3gonP0nOoQ0=CSTP21TdT0c>JO0<?NU`3FlZL0]<j403eC2P3>i9/0dnNO0=SYXP3G
j:40go2Y0=?WW`3:gYH0e^ZR0<GIU032ei80PIQB06An=`1oVU<0Q9mH0<oYXP3:giX0]/Z50;;1OP3B
jJ<0dOnb0;_UV@2mgI40an:E0=O/W`3:gi@0_mVB06^:A02jgiX0a_>b0<?/ZP1[QCh0cNNP0<WTW@3P
o[H0_]bD0<cZXP2jf900b>>L0<_VW`3HlZ/0b^BM0<[XWP34hYP0c>RN0<gYW`2H/VT0RJ1H0>Om]@3C
jJ40e^NQ0:^lMP1CHR40nOo?0?ooe03FeJD0hmn_0>SP/@3Qn/<0h>bj0=kU/P082`00fnNe0<C_]`2V
gZ40^ofo0<_ocP2`iJl0aNnm0<?j`01UXVH05U<G06BQI@2UhJD0_O2e0;;RY01VRdP0`^6M0=?^Y`3E
kJ<0_]F=0<gWX03Ak:D0bNBM0=3[Y032h9P0`MnG0<?SVP34i9/0_=bC0<k^X`3:k:00fON]0<7MT`3O
l:`0RYIF06ig>02?V5T0U9mM09NTG`28V540Oi190724?`35fI@0c>2K0=KZY@39fYH0[Kij0>Wj]P3>
gIX0cmjK0P2AX5d0>@25VUD0W[9]0=oc[P2odhh0c]nK09VZIP29VUH0UJAQ0<SGU03Zm[@0cm^I0=[Y
Y02R/fl0//^:0<o/[03=jjd0b^f]0=co_`2mgIX0dO2Z0;WGS@3AkjT0Qj=Y08NPG`3Aii`0b>2D0=Ga
Y`1OPTP0MIaW09RoT03=l[h0KHY:0;cNX@1>ODl0RK>1086NIP2I]G/0eo:m09BdP`004000/]bf0<?`
b@29]Xd0b^jn0=ccZ`31iYT0X[id0:JgL@3GiZ<0aN>M0=3YY@3>gYd0T95G0<[JV`36gi/0b>RL0<SZ
W@020<S]W`070<?XVP32iiT0bnfP0<_[W`3:jId0c>RM0<WUVP020<CVV@0j0<?UV037jI`0bNVM0<g/
X035hIH0dnfS09J^I03AjIl0c>:Q08:ML01mVV`0HhIN0:79Y01XQFL0KhYW0<3K/02?Zg40PYaK0<WR
WP3?iI`0gO6Y08ZIEP2EXF40d=jQ0<kPY03=jZP0^mRE0<cSW@3<j9h0UkE[0<gWW@36fY<0e>VT0=_`
Z`3QhZP0ZiU[06QG;03Gcj40f]V[08N?H02FWg00b]RU0=3QZ`3Sol80c_6_0<CYX`3Dkj`0bn>I0:_3
N@21V580d^NR0<oQ[@001@00^lfI0<WQS@3Ck9P0b>:K0<WSV@80cNVL02<0c^RN0;C>Q@3<iYd0eNbV
0<SOV`35fYT0d>FT0=CYZ03Di:H0e^JX0<SKV`2oe9<0b^>O0<GOV03?jZ<0aMnF0=geZ`36gY@0cnFJ
092OG03Mk:/0fNfV0>GZY`1JFaT0g>NR0<;SWP31d9L0j>Zk0>7L_03con<0j?OF0>Wbe`3loo@0ooom
0?oio@020?l000060?onn03kmnh0oooh0?oon`3Mfm`0jnWZ0P3oo_l00`3ooOh0inGV07ekO0020?on
o`0Y0?omoP3oo_l0ooKo0?oko`3gooD0X:F>0?oA^P3GZ8X0fmNZ0=OT[03FiJX0c^FM0=;TV03Ai:@0
d>BW0<GIVP3CijP0d^RW0;C=R@2L]G40//b50=gh/@3AkJ<0a>2F0<O/WP34jiP0`n^E0<G[UP36k9T0
a>FN0<WWY`39iJP0bNJV0<kZW`3=jYX0dNbO0>Oo^03colP0dNV_0<_PZ03Cj;002`3oool000X0oooo
00h0oooj0?ooo@3oo_l0ooko0?kno`3dn?L0o?oh0?Soj`2a_Y<0i?:m0<KHVP3<gZ00hO720>_if0<0
nOoo0200n?o/0=7SY`3Bhj`0e>>h0?;oo`1EOWP0<5A@0>_oo`3]nOT0ooko0?coo`3hool0c^WF0;GS
_`1d/7`0BH]>03MZ@@3]oOX0o_oo0<Zh[00h9AH0oo[o0?olo`3ionh0k?C=09nOO@2c/Y@0o_oX0?ko
kP3ooo<0oook0?knoP80ooko0P3oool0P03ooo/0ooof06]FA@2CPW80l>?B0=?C^@3Bf;H0kog80=SZ
/03BiJD0g_2d0?_oeP3_ol`0c^VR0;[MP`35jj80b>^[0<_YZ`2mb:X0^/2L0=o/VP2K[F40_=bC0<SZ
X03FmJT0b^VM0=3XWP3HkZD0b=bD0=c]YP3HjJ80TjMO08>ID02H/6H0KXHl0;35P03?i9l0bNBM0<7O
U`30h9L0`n6I0<cVW`25U540_LR60=OIVP3EfYX0CETG07Z5@`1RJBD0TYQB0>OXY03EeID0g=nV0;Jk
Q@2KXG4000L00;c8V02DZ6<0ZKii0=_b[03Nn;40RjUQ08nZH`2B[6D0V:mY09BYI03@i9l0e^fW0<WY
W@37ii/0bNFJ0<;NT`3CkJ<0cNFK0=?YX03:h9L0dNNN0=7UW@2iahT0`<6O0;2`S03Lf;80fMB/09jF
J03EhjP0embT0=kOYP2QXVP0KGLh05Ui;P2kiYH0eOnd0<coZ02iji80`N6E0=SW/03:gJl0a^:a0:KE
X@1g[7P0DhYC0:7BVP2^bi40T9mV07f3A`3NgZ00f>BR0;_@R`3Gk:L0cN:M0=G/YP3CjZ@0c>>M0<kX
X@33gIH0dN^T0=3/XP3CkJ@0d>JN0=7UWP3>fYP0iNn`0<_DU@3KiJH0dnBP0<oUW@3Fl:H0c>RM0P3>
j:40RP3DkZL0b=nI0=?XX`33ei80g_:]0<cPV`3:fiL0cn2L0<_OVP3DjjD0a]fG0<ONV03=i9h0ambG
0=O/Y`3FjjH0c>2K0=KZY@3>gi/0hO:^0<_JV@3>gZ00]LZA03iG7P004000?5TS05=`>03Hl[D0aM^M
0=CWY@1PMSP0`n:f0=Of_@32h9P0]]J=0<?XX`3;mlH0[=Zc0<Ked@36llX0/]RO082[L`2BcZP0MjZ1
0<7N[P3?j[L0Tk5o0:O;W@2bgK00F8aU06fTO02ci[d0c?K40>3l/P39lZ@0]]B<061d;`3AgId0f?6]
0;_@S`3DgZ40X9iU0=7MW`3Aj:@0b>ZM0<KXV`34jI/0a^^M0<O/WP34jI/0b>RL0<CSU`34h9D0bn>I
0<SRV037jI`0`^BG0<_[W`2ogY80an6G0<_UV`36gY@0dnVP09b`J03MlJT0c>2I0;gCU@37gIl000l0
03MF6P36jkP0OYEQ0<kOZ03AiZ40dnnT0<o^WP31eXL0VZAM0=7AT`3UjJh0c=^P0=?RZ@3GijT0amZJ
0=?XX`3EjZD0bMnG06=i<03Aiil0[Kij0=CSX03NijH0g]jR0<G6S01/L3D0EUhS06ic>`2`/g`0dm>O
0=OJX`35eiT0eo2_0<[[Y034hYX0b^FF0<kYVP3;iI`0PieD09faO0013@40RYaZ0<KLRP3FjIX0a=NG
0<KPU`34h9D0`MfB0;oKT@80f?:Y01l0EW0Y07:9@`3CjZ@0c^FO0<?HU@38gZ00g_Bf000=002M[Fl0
^/R:05=R8@37f9@0f_2X0=OcZ03BlZH0^mj>09VVH@22ST`0f>nY0>?d/02l_Wl0C4h?0<oOWP3:gih0
cN:Q0=g][`1VO3h0_lbN0>khd`3nonl0oooh00@0o`0000/0ookj0?ono@3ln_/0e=;C09jLW@3knOX0
ooko0>KTi@3ln_/0Ph620?ono`020?klo@0X0?ono`3omol0ooWn0?Sol`2VZIP0omOA0:QfJ`3aj/h0
d>2c0<_NY`3;jil0cNZF0;WGS@32hI/0d>jX0<oZY@31g9L0g_Ra0;kHT@2=XUd0^Lj90=;VX@3?hih0
bNVN0<O/WP3;kY`0bNfF0<S[U`3<jjL0b^J[0<OR[@37hZ/0c>RN0<cYU`3?jYT0cnZK0<cXW@3<ij80
dNbY0<o]Y@/0oooo000:0?ooo`0V0?oonP3oood0ooko0?ono`3no_l0o?om0?comP3kond0`m6P0<_J
W`3?hZ80f^Ni0?Soi03ionl0nooo0?Kio`3jooL0mooR0=;VX@3Bi:H0eNFh0?Coo@3Uool0h?_f0>_o
n`3gool0oogo0?Ooo`3Nl?00^]G60<3dd000>@T0YnR^0<;aa`3gool0l>k_09Z7N00P2`020?ojo`09
0?cok@3Vkl80T95Y0<S8YP3Xjlh0mo[U0?kol03ooo/0o_kn00<0ooko0?l0oooo0?ooo@3oo_@0KeXo
0?WYc`1@BB`0fn>n0<[K[P3[olP0d>fZ0=3[YP3NmkH0lOo<0>WjaP3EkjP0b>^A0<cbZ@2nhj00a^BT
0;S1XP2<T6d0SIY808RJCP3Bm:X0_nFJ0<KVVP2bdXH0e_2V0<oWW@36g9<0bMZC09ncJ`2I[fH0Y[id
0<kXWP38hYP0g_:]0<SMV03=j:40b^RP0=7_Y`38hi`0RZ5K0<WDTP3@eID0[:Q[08j:C@2OXF80jN^Z
0;:eLP2VYf<0UiIE0=OEV03ShZ`0emJV05]I<0060`00Zjf50:flN@24UE40X;A_08FLEP3=ij00bN>L
0>7f/@3AiZ40b]^G07f<B@1QMBh0c_2S0<;RUP3=k:00b>BI0<_UV`35gI<0TZQO0=CZX@3CjJ00gO6Y
0=ka[`3Fgk80cmR[0=cR]03^lL80W9aZ0=;KXP3MiJ`0ooo?0=;KXP3Agj@0]lf=000H001JNSL0bNnV
0<O]Y03GlK00b=2M0=KR]03FjK`0]mj_0;cZ^`2cj;@0L:5Z0:k?UP3Cjk40ho6f08V?D@26TU00E6DQ
0:RiM@2ibXH0_m>>0<CHT`3IkJP0enbW0<gRW@3Kl:/0Z/1h08JGD@3FiJ00enBO0>G^[@3Cg9d0Z[Ae
0=7MW@3<hI`0b^JL0<OYW02ohI@0eOF/0;oMU@3:j:00d^fV0=?]YP3HkjT0`=NA0<_RW03FjjH0fNjY
0=[aZ`2jeHh0e_6Z0=Sc[02lei00f?:[0<GOV034gYL0cnJP0<[QV`2G[6L0PIE@0=g[[@3Ah:D0AEXR
0:BmQP2R_HX0O9QW08^VL`0C:000I7Hl08NEE`3EiZl0g?cC0;SHYP3AlZd0eOVa0<of/`0oKT00KIml
08>fU`2JbJD0Qjmj05f<EP19RF@0034:05EeAP0N>@H0/LnM0<[`_`2nk;h0K:Ej031Y?P2kl<@0/N2/
0=?cZ031k9d0aN>K0=7UX02GXf<0_mRD0=ob/P3Ggj<0UI1H0=OQY03?i:40c^jR0<g]X@36j9/0aNNJ
0<W[WP3<k:00bnZN0=;^X`3Fl:H0e>ZQ0=?[X@3CmJP0]]R;0=OfZP39iIX0dNVO0=WaY`3@iYd0dNFM
0:>gK`3AiId0`mN@0=__/02T^7T0?50A09^aL@2U`h<0Z<600>;g]P3>i9`0d^RO0<[PU@2JZV40T9YC
0>7VYP3FfYd0e^2T06Yc>P3LiJ`0joJj0=;VX@35eY80fnbV09j_J02X_7D0NhM507R3@@3>fYP0c=NC
0=7MV`3>gIX0gNVY08N=D@1TIB/0WiYS0>o/]@3Fh:@0e>JX0<k/YP39iI/002l0bnRF0;cIQ`3:iY/0
bN>I0<KMY@001@00cmn^09Z]GP2a`GH0g^j`0<gWX03Hm:T0d^jS0=;^Y034gYD0`=ZA0>?m]P3DjjD0
Z;mi0=G/YP3PmK00d>Z[0;cFV@2fbXd0H70b0:fgNP3DgIh0g^ZX0<kOV@2geXX0^]b?0<ofY@3Ci9d0
RiIB0;oDS`3<hI`0f^2R05QG7P3MhjD0a]VG0=7/Y@32gY@0bMfF0:NdO`3Sk/@0mocV0?gml@040?l0
00060?onn`3oo_l0ooko0?omoP3KfMX0noWj0P3oo_l0;@3dl_<0RHN80?ono`3oo_l0oO_l0?ono`3o
nol0oocm0=kTf031`[@0olk?0?6n^`3omn80enJm0<cS[`37k9h0b^bE0=[mZ`3HoK00^]Z?0<GUVP3@
kZ@0an6H0=O^YP3>hYd0J7Te0>?b[`33dXl0anFM0<OYW038jiT0b>bE0<WZV@3<jjP0b^J/0<_U]@39
i:l0bNBM0<cYU`37hY40c>NH0=3/X@3:iJ00a>:J0<CRV00;0?ooo`002P3oool0<`3ooo/0ooko0?on
o`3oo_l0o_oo0?kon`3loo<0o?oZ08bJI`2GYfT0eN:Z0>cafP3lo_T0mOOf0?ono`3hnOh0o_oT0?[o
d@3?iYH0c>FQ0<cT/P3boo/0mOoo0>C]lP3`ool0g?oo0<kdm@2D_[X0d?S_05UfI02AajL0Y^No0;?[
_P2lj[/0fNSE0>o_i@2nYiT0<QP90?ojo@3oo?h0o?oV0>Ca^`2AVF00g>:b0=7I/03goN40ooo]0?ko
m`3moO/0o_oo0?kno`020?koo`2;0?ono`3oo_<0[9U^0=gAZ@051P00cNB^0;oOX03>lZP0a>VK0<[Y
V`3Dl:D0dn^a0<SMY@2jcXT0SJYF0<3TW037ijH0d>f[0=[Q^02IVVh0e=f<0=OWW032iY`0_nFL0<?R
UP39iI/0a]fE0=7YW`3PmZh0amfE0;O=Q03;hIP0bn:J0<cVW@2U_7@0Lh@n0727?`23WUL0TZaU06Mn
>02X_gT0e^ZU0=?HV02o^gh0NW@h0<30PP3HjJD0d^JQ0<gSVP3IkjH0OXm807F2?@3Rj[40gNBa0=SO
]@001`00K7A?0=SSX@3ChYl0c^:M0<oTW`3;h9/0d>FP0=KWX`3?gY/0e>>P0<kJV02mc8T0cNFK0<_W
W@3>kZ<0a>BH0=3ZX03CjJ40Wk1Z06Ef;`3Nm:/0c>>K0=?_Y032iI<0bnjN0=7`Y02ofi00b>:K0:Vo
MP2ccXT0_MbI0<;OY`36g:/0g^C00=?B]03Rg<H0L6UQ06AOG025R840i>gB0??ogP3eon@0cnk50;[M
/`2kiKL0_nfl04b2B01m]GH0^_Fc0:_RX@30iZd0c^Zg0=;]^P30ej40d^N^0;35Q026VUD0B5`D05IZ
8`0eB@80f^^W0=7NV01:EA40aLj?0=kQZ03OhZT0Q8iA0=7PW`31g9D0bN^O0;o[W032kIh0coBW0<W[
W`32i9P0dO6V0;KFR`36iY/0c>bS0<7QV03AkjL0a^BL0<c/X`020<O[X@2Q0<KZX03=lJL0_n6E0;kP
U03@l:@0c>^O0<OVVP3?kZ80a^2G05][;@1;GB40I7]30<cU[P33gZT0aN6^0=3[]P3>iZ`0cN6V0=[X
Z`38gJD0<Edi07nYN`2oiJP0c_:e0;[MY@19LTX0b_KC0;SUaP1CPEd0bOG00:kOZ01GTEl0?Fdk0<o^
/`1LN3d0b>N/0;CJX@3Holh0G95M0;_a_@1QTeh0HhmD0<KQVP3=kjD0^mVA0=3WX@3@g9X0d^NR08FI
E02S[6/0O7<h07Yk?`2HXf40a]NA0=;SW@3?iId0bn6I0=;XW`37fi<0T:5J096QFP2CWUT0SIM@09RU
G`36gIL0e^ZU0<3<RP1fPCl0];mj09:OF@2Z^g@0_=280=K/Y03Hk:L0`mbR01a68P0B=Q80e>o609nd
R@3:jYD0e>fL0=[aX`3>i9`0O8]80;>oO@3?gYd0g>fY0=?LV@35bXP0MGXh08nIG01lOdH0;c000=SM
W@3IfiX0i>VW0=WTW`2?X5T0TIaG0;S2O@3?hi/0dO2R0<_/W@39iIP0f>jU0<[ASP3XjZ/0jnJ/0:>N
I00g=P00WZ9W0;W5Q@3DjZ80fOFQ0<;OR`3?jj00d>bQ0<GNY0003`00cN6/0=O/X@3Eiid0S9eI092U
H01dRd<0d>ZQ0<[UWP36hIX0b>JL0<cXWP3ElJL0Mhi6096XH03=hi/0do:^0;[JU`3<hZ80cmnQ0:>[
K`1WKC40LG/l0<KETP39iid0_^>E0<G^W`3?kJ<0b]^E0=[LW@3@iJ80hoRg0<kHV`1GCQD0VImO0=Oc
Z@34lj80bMVB09VPK@31b9l0i>OB0?oom03hm?D00P3o00003@3oo_/0n_Kc0?chn@3ooOl0ookm0<>o
_03imO@0ookm0?omo03mo?X0LW5_0?_jn03oo_`00P3oood09`3onod0oock0<oEa`2][Z00k;Bg0?C0
a03ooO<0looU0>7fc@32iZ00anRG0<S`VP3=mj<0`>FE0<OZVP39k9`0bNRJ0<GQU037gi<0d^JN07J1
?`2^]gP0d>VX0<[YYP39j:@0c>VW0<oY[03;h[@0m?oT0?;oh@3Tnld0bNBO0<WVU03>iYX0[/Al08fR
G@2N]G40^m:<0=?]X`0;0?ooo`002P3oool00`3oood0oooo0?ooo`020?ono`1_0?Wjm03noo@0o_o]
08ZBJ@2AVV/0dMZ]0>cbf03nooX0oooo0?omo`3mn_D0o_oL0?Gob`3?k:X0b>Vb0<O/``3Yool0k_oo
0>Woo`2VfNX0<I>N029lQ026[Zd0f^oV000C000:?A`0CY5^0:O]b02hm;P0a^>e0=oZb02ZUhT0@bLS
0?ohn03oo_H0mOoI0>Kh_P1mSdD0f^^W0=SZ]P3ion40o_oZ0?oomP3nood0nooo0?Ono`3iool0o?oo
0?omo`3om^d0/Ye`0=kD/@011@00anB/0<SWY03LlJh0VJQU0:>^H03GiYD0f?2f0=?W/P18DA00e>FO
04EN7@3@jJP0eNZY0=oSZ02NWV00f^6D0=KTV@2igID0bnbU0>3aZ`36ei<0FFdX0<_OV03DjJ@0[lAo
0<gSV`3;hIT0f^nZ0<oTW`0R=P00f_2U0;oTUP3<k:40bnFN0=KVY@3Jkj`0_m:@07=d>00]9`00S9EB
0=o`ZP36h9T0bnVQ0<k`YP3>kZ<0e^JO05QN603GdIL0j>6]0>KQ]`001@00L7YE0<7ET03Ek:H0anFM
0;cJTP2lei00d>NQ0080e^NS0?D0cN6L0=K]Y`3@i9l0e=^H0=KWX`39kJ<0_nRJ0=?aY`3Kk:P0TIMG
06A[:03DjZ80^mVA0<[_XP3<lJ@0doFY0<[XWP34hYP0c^VR0=7VU`2<XUX0a=^G0>3e_02ndIT0h>Zf
0=7GZ@3GfK80oOW^0?kho022NHX03`H90>7Qe`3noo<0k_gP0=_/b039i;L0bnbm0;?S[`0GDQX0?X99
03^9E@0dOUT0L;6I0:kZd@2ei/P0`N_50<?WY`31hiT0dO6N0<SWU`37iYX0eO>]0<KUV@36gi/0Wk5c
09FKJ`3Ff:T0c]6L0<cDV@3?hih0cNVO0<O`XP38kZ40e?2U0=S`Y03@jih0bNFJ0=?_Y03=kJ40aNFJ
0<g_X`36jZ00^]jD0<_aYP37kJ@0bNnV0<K/X@32j9/0a^^M0<;XU@32iI40bn^H0<CTS`3?k9P0bNBE
0=?YZ@3;i:<0Ih520<;NX@3>k:h0_mfO0=7a/02mg9T0cnj[0<CQWP30iZ/01T@O05F>I@2mh[L0eo;7
0<?E[@002@00:CTD0<;M/P0QAAL0`o2i0<7]/02]d8`0c^fW000A00005P00d>jX0<[XZ02kfYh0EWU1
0=7d^P32i:L0b^VV0=GRW@3NjJD0an>I0<GTV03AhY/0f>ZP0<WQU@3DhIT0YIaK05QC3`1RHAh0I6@V
05=C5@042@00dmRH05ML6P1HGA/0BT/906ET8@1NFaP0H5/G061M6P1HFb80G5HR069<7@1]EBD0KV8V
05UJ5P3Jkj@0f?:X0=7/Z@3AjJ/0anFa04f3G`0A@AT0^mf[08RSK034nZ@0c]jE0=?HU@3?gYT0UZMS
0<SMV03Hlj`0bNNO0>7QX@2CSe00c^:K0<WTW`32cY00YJIZ0=kBV03[gj<0h]bN0=gZY039hID0CfXM
041H302ofXd0bNjN0<c]WP3;iYT0a]R>0>3[YP3?fYH0f>NT0=OVY@3IgJ80Ee@M034Z001VKbh0f>jL
0<[QT`3Bj:L0c>ZR0<_YZ@003000do6c0<SVW035hI@0cnRD0=;RV`2GXf40f>bW0<WRWP32hi`0`nNM
0<GYW`3@l:D0dnfS0=?YX02ld8P0aNFI0<K[WP3Ak:D0cnJR0<WIVP002`00OXa?0=S[Z`3<iJ40dNnW
0;cNTP33ljL0c^bV0:fFH03PkJP0anVL0<gWW@2NVUd0Ie`T09BHG@3:nKD0cMZT0<W6Y@2_Zi80noW]
0?oon`3eloH0ooko0:JUX@3oooX0o?Wd0?kfm03oo?l0ooSe0=[Cb`020?onn0040?G`k03oooX0JfMT
0?Whl`80oooj02P0oooh0?ojo`3mm?T0d=_;0=?Ha03of]H0m<C20?okl03ioo<0n?o]0>3hb03Dijl0
aNVO0<7ZWP36jZ80bNZS0<W[X@34jiP0annG0<kbV`3?kYh0e^:R092EG@3GjkH0_m^X0>_of03ZoN40
mooa0>gik`3cooD0lOoW0?Goh@34hYX0bNVD0=?TW@2?VUP0c]RI0=o[Z`3Ghj<0Ae@?2`3oool000d0
oooo0P3oo_l0SP3oood0nO[b0?Wkk@3MhLH0`lVW0?koi03noo<0nooo0?koo`3noo@0e=g00<CIUP3@
k9l0aNfW0:SBX023[Y00Nj>R04AQG@1FPHP0L:ji04jc_@2fool0h?oo0?Con`3@hlD0_NG00<3id00J
Gc80;6h`0<[__03Gj<@0SGYc01d51@3on_X0ookd0=o]bP3=gjl0aMRF07J8BP3Nl<00n?oT0?kok@3o
ooX0o_kn0?Wno`3gool0m_go0?coo`3oo?l0ooS]09n?GP3Uh<000@X00<OV[@3;jZL0eN>V0:>WK02J
WE00i?2J05mi?02hciL0k?Fd0<oMW`3>i:H0PYYL06Ij>`3@fIH0iN^U0:ZbJ@3=gIH0_=nK0<CTX@2=
V5H0]<1n0>ck^038g9L0aMVD0=7XXP2Q^780_=6<08FIE03HjJD0a]NA0<WQT`3;mJ<0bnfQ0=?ZXP3K
iJH0MhY:041C4`3_kk<0hM^O0=7RW02<YUd0TZUQ0:O5O`3Jo[H0eoV_0<gRU`2FX5T0k>^[0=?BV@3B
f:P00180069iC`3<hI`0goZc0=7cZ@1DN2h0ZlV10=3WX@1jRdL0f>bW0=GZY@3<jZ80cnBO09nOH@3=
fIL0`NFK0<cfZP38iYh0c=fI0<W;S01eNSX0d^NR0<_]X`3;kjD0[L^30;oJT`3:hI/0cNBN0<;GTP3E
k9`0TjUP08BIEP29Vel0SYiP09VXI`2lb8X0UZ1[0?oojP3oooH20?olo`3M0?koo`2RYZL0;CPZ06Ub
G`3kon`0nOoZ0?7ojP2ae[@0_^g90;Wba@2hk:h0_>Re04mhD01XR740KX]e07ZLN`1_Tfd064HH01Y:
80005P00EI9a01YQ@`15Q6l00cPX01/g:`0F9aL00@D001TJ003Mgj00aLZ708NCB@1eO3T0XiiW07E]
?P1JERH0QHQC06]b?02M[gD0b>2T0<OWZ036jJT0bo:a0;oWX@3:jiX0cNjM0=7bX`33i9D0aNJG0<WY
W@2mfi40aN6G0=7]X`36h9T0a>6Q0<[]``2jfk00A6Hd0<k_^P3=k[D0R:MT0<;PVP33hY@0fOJT0<ST
S`31fi40PY9[05m`AP3Bg[00bmBU0=kX]02^_H@0e>R[0<c/Z`2ZdHh0_O2[0<cm^`3:k[40`^VX0<[c
[@35kZP0`NZ^0:kFX@3?m/L0:U4U02YA9030j;@0`^n^0<ckW`3IoJD0ZNJ90;3_U02niIH0d?:V0;WM
U`3Jlk80SHYE0=[CW`3MgJL0e>>X0<OIW@3>hZD0e>Z/0;_DT`3=iZD0dNNV0<?IV03NlK40enNV0<_O
V03;hiD0c>JL0<_VW`33gIH0h?J^0<SLU@3PnkH0/]FC0<coc028b9H0B8EK0<S`b`2Q`IX0c^:]08RJ
GP3=lZ80a>BH0<SNU@1NHb00b]NB0<WOU`38iY`0fO2X0<WPV025UU00i>VW0=KYY`38fi/0b=NF09VO
G`1gNCX0HV@S0>ce/P3Ch9/0eNfS0=KbY@3@kj<0amjF0=C`YP2mgI40^M^>0<WXW03=iI/0[kQe07am
@@2CT5T0Xj9Z09NJH@2?Ved0dN>G0=W^X`3EjJ`0b>:K0=[d/`002P00cN6/0<[KY@3Ljk80UJ=H08^E
D035d8`0Z[ii0>Go^02nhYP0`^RM0<CZW@3<kZ80cnNM0<SNU@3Bhi`0c^nP0;kST`3<jZ00b>>L0>3d
]@2a`hD0fnf_0<GIVP3Bj:L0dnbX0<;MUP2fjI`0co>[0:^EG03:dHd0`nVF0<OZV03^kZh0FTdH065K
9`30hJX0nooJ0?ooj03Ke<80oo[f0?ono`3in?d0no_m0;2aZ`3oooP0oocc0?omnP3oo?d0m^k/0?on
n`3ooOd0oo_k0?[fm`3lmo/0CDQ<0?omo`3no?l00P3oo_l08`3on?l0ooKo0<S>a03ooo<0onS[0?Fn
a03on_X0oooo0?ooo@3gond0n?cS0>kod03Pol40cNV/0=?`[P3:jJ<0aN^F0<?^U038l9P0a>FF0=CQ
Z`2RYGX0o?oT0?WojP3fonX0o_oj0?ooo`3jnOh0o?cj0>3Xd03Xm<`0]/f70=;]W01>I1/0`]JA0080
fNfX00<0en^T0=kbZ`3oool02P3oool000d0oooo0P3oo_l0o`3oool0oooj0?oomP3`m=d0dMFj0?oo
jP3nooX0mOSm0?coo`3ionl0cMjd0<c[V`39kID0`njV08ZfP`14Ke@0NijT07fGUP3Qool0NK>g04NG
WP20bm00d?C`0>[om03Ej<X0bNW00;CR/`1/[GD07f0V07fTN03FjL/0SWah020:303on?L0ookf0>?]
dP3NkLH0e>:]06Me@P2mc:D0nooY0?ool@3oo_/0ooko0??hoP3iool0nooo0?_loP3oo?/0ooOW0:FI
I`3Rgkh000L00<KU[039j:D0^LJ>08bAE`2JXE@0Sie80::nP@3:hjX0_LZ50=OZZ02eci00^mFF08ZP
H02R[fX0VZAO08JBBP3Hk:D0anZX0=?c/P2DWed0g^ZX0=;QWP2ndXd0g?2[092WH@2K/V`0bn2K09b`
J`3Fij<0f>VS0=?[W@2ojIL0d?2U0<WOU`2a^g`0AEPH04eP803IfId0g]RL09faJP1/QSd0dnNP0;C;
Q`2jfI<0^m^B0=O]XP2V/f/0f=nL0=kXZ`3Fi;4000d005ejCP3>hih0_]RA08j`IP1BM2X0[<Z20<7H
TP1GJ2@0fnnZ0=?XX`3>k:@0c^FO065Q8`2P[6X0`nNM0<G^XP3@kZH0ioRd09:GE`1oQDD0b^6K0<OW
WP38jZ00hoff0<kUW`2FZfH0Y[Ye0=_/Z03CjY`0e^bT0=CYYP3:g9h0i?Be0=7RWP3NkJX0W:Y]0?3g
e@3konX0o_oo0>c_mP3iool0j_Ce07^6OP1^MV/0OX1b0;2cXP3fonh0e^cE0;oM``2nikd0bo2Z0<SX
Z@3Gll<0m?od0>cnlP3Fk=l0e_7N04M^D@19M5P0E89V06ZRR@1MW8L0Nk>V05B3N@1aRXH0HW=Y034j
7`1SJTP0a=2N0<;@V`3IkKP0NhaH09FGIP2NW6`0]KB60;FmS02=VFT0TjUj0=G_`01?Ld<0Ukf<0;;N
[@2mikD0`>JY0;cRY@2lhZL0aN^`0<G[/P3=lkX0b>je0;_QYP3;k[@0bNbb0<;Y/P3;m/T0]Mna02UA
7`2B^H@0bo6h08NWJ02D/Fl0`M^D0=gd[034fXl0i_Fb081oC`1/KS`0emnV0=GPY03Pk[00V[5[0<?N
U`3CmJ/0a^ZR0<C/Y@2mi:40`NBZ0<O[[@2af9D0e_fj0<[b]P3;l[d0/=JW00/`1@019`00^n>^0<?[
[@2E^6@0_]V80;c`V`2klYh0b^bR0=G`Z@3?kj`0dnV[09JCGP3Nf:H0e=NP0>Ko_@32g9/0_=VG0<o^
Z`3?lZh0a>RR0<CUX032hih0a^FQ0<CRW03:jZ40a^nQ0<?aYP00E038oKD0_O:/0;KOV`3=kJ`0[LZ@
0:G:UP2ThkP0=h=L00=99@3;jlH0Uk:90=k/]`2P[W40`mV>0<WbX`3<kZ40Ri1=0=COV`3PlJ/0`mfD
0=O]Y@2ni9L0UkE[0=OCUP3IhJD0i?Ng0=gb/@3;h9d0_/j=055M6`3BeiD0f^2P0=k_Z@36h9H0cN^Q
0=?RW`3?iZ00anNL0<ohZP32iiT0dNfR07Ih=`1GDaH0j^R_0>?TZ`3Iij`0dn>U0=O/X@36g9<0a=RK
0=7XX038gYd000P00=cZ^@3LhkT0h^Rj05aR8P2FWe`0[KYd0=S^YP3@k:80`^NJ0<K/W`2lhI@0c^jS
0=C/XP3>hYX0d>2I0<[YV`2ohY80cN^Q0<_VW`3Cj:L0e^RZ0;_=S`1NLS<0eNbX0;[CS`33gIH0_nfR
0<KZX03Ici80^l1m0<W/VP80o`0000D0/ZUb05iK9P3?hk00nooJ0?Sfg@020?l0000?0?chn@3oo_l0
oooo0;fn^03oooP0mOG[0?okm@3onOL0[jVY0<g9bP3ono`0oogo0?[en`3ako@0M79g0080oogo00T0
o?Wo0?Odo@3on?l0ooKo0;Ri/`3bk^<0olWA0?>g``3on?l00P3ooOl07P3nooP0oooc0?Sog03Uo/L0
cNF[0=CZ[030fIL0a>NC0<_bV@34jYD0`^:F0=g[^P3Ff[L0oOoY0?Ghi@3em^P0l^oZ0?G_k`3oo_/0
ooof0>?XbP3Ki;T0gO6/0<CIS01BK280dnnU0=?^Y`3Hm:X0dnnU0<7MT`/0oooo000:0?ooo`030?oo
o@3oool0oooo0080ooko0:P0o_ko0?ooo@3oooX0oooa0>c_fP3ko^d0oooo0?Kfo`3hoOl0mOo/0<CO
ZP3=mYX0`o6>0<7`XP2Pc9T0OjN?0>Ooo`3^ool0cOOc05F<Q`2Nf]X0LjV[06Z=R@26XYH0`mJh0<CM
/`39k;H0Y=nO0;;c^`005`00TjN>0964OP0i9BH0oo_j0?chk`3doNP0l_oS0=SR_@3AfkP0F6560?co
kP3ooo@0ooko0?_ioP3lool0n?go0>c`l@3oood0j=gI0?omk02[Y700dmBb0008003<jk80bNRU096N
J03:dI/0b=27092OC03GmKD0a>2U0=CXX03CjZ@0cnb/0=?`/03DkZd0d>BO0:BdK@2?X5T0`mZD0;OL
V@2hf9L0S9ME0=_WY@3Dhj00f>bW0=kb[@1QN380UjiX0<SMV02;WeX0dnBP0<kOV@3OmjT0aNbK0<[Z
W`3;hIT0I6d^0;G5QP33di@0b/Z>0>[TZ028W5D0an6H0=WXX`2ic8X0foJa0=3^YP3Cjil0VZaR0=GT
W`3Ai:@0dnZd000B001WR5/0[L5l07>:A02ZbX40cNfT0;WDS@3@iJ00b]^G0<OHU03?hih0bnVQ0<gT
WP1JG1d0RiME0<GWW@37kJ80c^bT0<kRW@25Rd/0WJIU0=;YX`3No[D0^mfC0:RoN@2dbH@0WZm[08jM
FP3KijD0b^2G0=3UX038gIX0eNZY0<3DS`3AiId0`M:;0=?TX02;VFP0PXiX0?WolP3iool0hnkd0?Go
o`3bo?/0nooo0>_Wi01dKf/0N7E^07n2M`37d/@0kOoT0<_^[P3Em;/0lOoT0>onm`3eool0n?oo0?3k
m`3@hLh0`MRn0=K_d@37iL<0b^G20>7hf`3Nl=P20>kfi`2X0;g;]02odkX002H;03YWD02>b;T0bogR
0<OX/`3Lm;H0^=:E0=?a^`2hf:L0UK^B01Q27P08=QT002/A01Y>>01IS7T0=6UI01Y??`0GC3`0@gQX
02EJB004>R<0DhU_0;G]b02mmlh0^??50;gh`P31n;@0`oRd05J7AP1FQ4@0X/^?0;[KY035hZ`0Rj5`
000;002EYGP0a=2N0<kCT`3CfIT0c=fF0<gSV039i9L0PYm?0<WVUP38gY<0dnNO0=;OVP3AgI/0a]bK
0<WPVP2<Y5X0b>:H0<cUX`3MmKT0an2W09R`O01LMCh0L8e=08FIFP2[XF`0Xi5O0=;MX@3<hJ00f>6R
0=CJW035fYD0X[5^09ZAEP3UhJ80iNZX0=3VV`3AjIl0cn^P0<KUV@36j9/0e?V[0>?o^@3AljL0_^2D
0<3PU@3Dn;80^^ng09WDWP1TY7004U0M029B8P12J3T0K8aS07^QO01TXhH0DYb308c@]`3Fm/d0N9=X
0<cJY@2b_H40hNbW0;ORTP2miYL0`/b7079l=`3Hhih0bn6H0<KPU`2okYh0^=f@085h?@3Heih0hoFg
0?Coc02hg9H0e?>_0<CKU`1CF1P0TY9F0<SCT@3>hY/0cnZS0=?OX@39g9`0b^RR0<7WW01SQCT0IGlf
07Ai=`3CdI@0f]VP0=?HWP3Ah:D0gNne0=S^Y@3Nm:/0e>R[0<kRVP3DijD000H00=CL[@3el/l0RHER
0=?DV`3Sk:/0_Lf40<oWW@2gdhP0bNjP0<S_X033iIP0c^fQ0<kTW03HjJ<0g^^V0<WTU`37iYP0b^JL
0<cVW`37g9/0d^NV0<OKW01[P3l0JX4m0:k5P@3=i:00a>fQ0;kRV03JgIX0NG`g103o00000`2:R5D0
dm^/0?[of@040?l00080ooko00`0iNKP0?oomP3ooo@0Wi^B0=cEc`3He]L0n?Sj0?gmo`3oo_l0oogo
0:bY/02NVj820?omo`090?kko`3on_l0ooKo0>oKiP3LfmH0ookf0=RFY02[Jg`0oo?o0080ooOo01h0
oogo0?oln`3hon00iOK90=[[]`3Ij;40`=>C0=7^W039kID0`>JC0<c/X`3/nm00oooX0;VbZ03ooOH0
oocg0?ohmP3oo?X0mNcS0?ook`3>d:/0gN>c0=[YYP2eaG`0c>bP0;cQT`38kJ00`^NI0;oTUP3=kj8;
0?ooo`002P3oool00`3oood0oooo0?ooo`030?ono`3M0?[ioP3oool0oooj0?oon03?c<D0hmSL0?om
o`3nool0m?o]0<?Q[`38mY`0b_bI0;GQTP31i[00do7E0>7dn`3Sl_L0>F5H0=coo03^ool0n?oo0>Wo
o`2ge]00mOo[0??ke03>fj<0^>RL0;[f`P2E_Yh0D6M=07M]H@0b8AL0o_CZ0?ool`3an^T0nooc0?[l
kP3Ad/@0gMgA0?onnP3nmOH0oo_o0?ggo`3dmoh0nooo0?konP3ln>l0k=c=07ebEP3EgJ@0eN2h00HH
003;iZl0bnFV092LKP3@ej/0c=RH0=W^W`3LoKP0aNVS0;cJQ03?kYh0anJP0<g^Z@35i:00bnNM0=Oc
YP3LnJT0bNZK0<G[XP2ogYP0WZUW0>Kb/03ChYl0f>bW0<KJU@31f980d>NQ0>co_02jcXT0go2/0=;S
W@3<hiD0`>NF0<[XWP3:gYL0Yje_0=CPXP3Bh:80];Ei0:fWJ`3:hIT0c>RN0=?RW@2DY6<0d^NT0=7V
X@3HkJ80RieC0:BeK`3Ml;00dnNb000;000K<PP0XkA`0<kRW@3Hlj`0_M^C0<?JU03:gYT0A5<@0=o`
[03Cij80cN^S0<cVW`3?eID0U:=P0<CTV`3>l:H0a>:J0<;GTP3Lj:H0am>A0<WPVP3No;@0^]R@0=C[
Y@3=hYd0bMfH0=_/Z01EI240gOB`0=ke/@3;hYh0a]^F0<kRVP3<hiD0cNBF0<oVV03@jJD0b^>R09RZ
P03Ii=H0nOoo0?Soo`3iool0o?oo0?ojo`3on_d0lnCQ0?olmP3YhmL0OgmU07=`A@2;QV00Q7eS0?gc
l@1iKWH0^K>m08:0Q@38d/X0lOo`0>Ski`3Zoo00g?oa0=?gk@3[ool0moof0?_ok`3@e:l0koG70=WS
[`3Eh[@0e>Jn09J^RP1fT7D05C<K04APB@057`H0Lh]a08nVRP32e[X0dN740>Gde`3JjLX0cNBh0<7`
X037ljP0aO:]0<3//@33jkL0c_S:0;oZ_@1kZGP0RKZ304Eh?@1<PdT0[^Zd0<?ob@2dkKH0Vm2J08Ni
Q024/7/0P:Qd05MiAP25Z780c>Zf0<c[[`34hi<0cNjM0<O]V033jiD0bo>M0;;EP`1`S3l0U:EO09JO
H03Qh:L0dMZS0<[a^P2niZX00P35k:d0LP34jk@0c?;10;oT^02khKP0`NZn0;7MZ03EolP0c>V_0=O[
^02biJd0^oJn0:GH[@2aj<00U^2k04B9JP0kK5H0YMk;072XS@1FNe00Nj9e03=Q<P006@005T`K000d
1P0=AAP0BX5G07>ZP024^980OK>?03QaCP1KS6`0g?_L0;cE]@37gjd0d_2d0<O/YP2bei40d?>c0<o/
]039jkP0:el^045]?02ieZ00k?o;0>[f]03Dj:<0fO>Z0<;NT`3UkjP0FE`G0<_MT`3:kj40a^JK0=W`
Z02TZV`0X9mV0>cg^`35fi/0cO:]0<SXY@36hIh0iNfa0:2OIP3Ng:<0hnBX0<CBU03?gZ<0]<:705MQ
9@14C@h0f^NR0=;SW@3HlZT0^mF>0?7o`P2h`XH0=SX805iY?P3Fj:X0W[5a06Ih?P2baGH0^<Z00:N`
P`27T5T0?dDI0=[L]03Ggj<0b=NB0=kdZ@35h940do:R0<CZU`3Bn:D0`>6B0<o[X03Fij40f>NR0=SS
X@3>i9/0eo6W0<gWWP37hIX0c>FQ0<oVXP24VUT0Rj1O0=?XY`2FZfX0?e8B0=3^YP36j9`0c^RN0<31
O`@0o`0000<0h>2/0;JTOP3Eh[@0103o00001@3ooOl0ooko0?onn@2d]:P0bLZl0080oood00L0o?od
0>kfi`3koo@0o?od06ecI`1XJf00noke0080oooj00T0ooom0?Gal033]:l0n^gT0?_ol03ooo40omCL
0;EiQ@3on?d00P3oo?l07P3ooOl0oo_o0?ook`3]kM40VIUe0:RYO@3Sjk80`=F80<gYU@35iiX0cnj[
0??oh@3eo^d0oo_o08elQ02KRhh0nnkX0?onk`3IeKP0gMfg0>7X]02PZVh0NHY60>;c[02lhi80cOZU
0<KcX034kY`0c?JT0<keY0/0oooo000:0?ooo`030?ooo@3oool0oooo00<0ooko00l0m_Gk0?ono`3k
no/0ooom0?olm`2n/:l0oo_o0?_inP3eoo<0`]be0;cWV032kYL0eO^^0>KocP3/on800P3eool0o`1A
MVl0co?Y0?coo`3lmoh0f^ob0>[oo`3aon/0oooQ0=WPZP34l:<0Yn6^000@002id;@0XIZ700d0003m
m><0ook/0?col`3joo80ooof0=GBb`3nno@0oocm0?ohn`3onol0m>kh0?coo`3kool0nO[b0?ool`0>
0000I5Ti0=;PY@37eZ/000`00<7JX@3AjJd0_/VO0=WQ^P3Fi:L0e>^M0<3QW037jj<0c_6E0<OYT`38
jYh0aNNM0<GVW`3<k:00b^^J0;kPS03DmjD0`^NJ0<o]Y@11C0X0V:AR0<_JU`3>hYd0i_Ze0<cSW@3I
l:X0`]NB0=oc[P2GZ6@0dN:L0>7hZP2cfXT0`]jD08RID`3FfYd0fNFW0=CPXP2ZZVh0UY9E0=ke[@32
h9H0dnBN08ZJF@3>gYd0cMjJ0=;TVP3RlZT0Df8M0>3^/02jaY@01a8005]U@03Pk:X0a]NC0<[TW@3@
jj@0eNbV0=?WXP1AH1d0cMjJ0=?WXP3:j:00d>ZS0>K_[P26UE80b>JN0<3PU`3=jj<0dnZT0=CUX@3E
iZ80dNRR0<GPV@3ClJT0`]bE0=C[Y@3Bij80c>6L09FYI00A9`00?UDA04UP703CjJ40dnNO0=S_X@3>
iIL0cNFI0<gYW`38iYh0bN2Z09NLR03jo?T0moch0>kbl@3nool0oock0?obl@3on?40ooKZ0?ojj03o
onX0j]_609b:O02?OG<03@000<Rh^@070000;R/V00@;00002@0000P004mYCP002`00a>;J0=;Yh@3k
oo@0nOgV09fJL@3?bi/0f=NQ0>CT/03/kl80o?oS0>ook@35f//0b]c<0=?Td@3cond0[[RO0>7Zc`2]
/Y800@D00=WK]P3BfZT0a>F>0<?ST03;jYh0`MfP0=C_^03Wom80eO710=3a^P2ohjH0Bg@`04mm?@0o
N4/0Ql2C0;Wa`02fk;/0ao_:0;_]^02ij[<0`O6g0<;_]02okJl0^nRW0;_TU@3=mZL0`>VJ0;kWV03<
lj@0`>:F0=Ge[03<iJ@0enba0=OZ/P35h:/0]>Jc0;KW/02ijJl0QkMm04mmC0004P0001X002ED<018
NUD0Dh]L0:?LZ@2ahjP0_NF`07ZnQ@0mQTl0ChaR041lF000?b0002`@000@001JSX40AWUX051]C`35
i<D0_N300;3H]@2dh[h0_>_90;_Yc02jj<`001<0000D00004@00gooh0=Ski`3Gh]40g^;;0=kW^P3A
iJX0d>nS0=?bY03DiJ40dMVM0<oPZ@3=om40EXAC08bZN031g:L0AEXI0<gFU`3FiJ@0f?R]0;k>Q`00
?03Pij40dN>I0<?XVP34f940gNbW0<GEU01FG200`lfA0=_[[@37hJ00dN^Z0=7WY`38e9H0g>:V09jI
H@3Ie9`0i>F/06Uh?`0V<@00V9eS0>3OYP3Efi/0f>NR0;cLT`3Jnk@0`MNG06Qc>@3oom@0mOgH0:>e
N`3HjZ`0m_o@0=K/VP3Ej9T0b=JS0<oOWP3GiK00dn6/0=;SW`3CjJ00d>RL0<k[V`3BlJ40`NB@0<K/
U`36iiH0cn^N0=CUW`3>gIX0eMnP0<cPV@3Il:P0fO>Z0<WSW03=iZ80c^NS0=CZZ@16G1/0c^6Q0=ob
/P80o`0000@0`nFI0<?SU`3FeiD0SZ9J0P3o00001@3Nk[00f=RT0;nUP03?gJ`0fnG00080o`0000D0
oOch0?klo`3oo_l0oooj0?oom0020?ool`0c0>cZgP3kond0n?o/0?WojP3fonL0NhEZ0?Ooi@3jonP0
o_o/0?[mj03ooo40o?g_0?ook03oonP0l_oS0?Oki03og=`0kKJk0?okmP3ooo/0o_kl0?gooP3ooOh0
oooa0?oojP24OUh0KV]20<W9U@3MkJ@0cNJE0<CTV039ijL0mooX0?Ool@3oo?l0oo[o0?ojo@31^J`0
/ZfG08R:HP3Igjl0DehR04eM7037gID0dNNO0<S_WP32kiX0_^ZE0<O^W@33j9P0anZJ00/0oooo000:
0?ooo`030?ooo@3oool0oooo00L0ooko0180oogj0?KSe03onO80oo_k0?_oo`3hooX0bN>d0<STZ@3C
k:X0d^BZ0=kZ_03jo^l0nooo0>Cio03bool0ooKn0?oboP3gool20?l0000@0?koiP3<eJP0S;Ec03M^
=`31i[/0e>S30::KOP0_8@L0/JZ@0=?A^P3nonl0o_ob0?onn03QemD0oocm0?ofo080oo_o0?l0ooWo
0?Kjn`3kood0m_WX0?ook01MC300YYef0=7YZ`35fj`000/00=3SZ`33dYT0]kjO0?[oiP3Bh:d0cNBL
0<g]Y02mhYD0a>b<0<[^UP36i9X0bnVQ0=?cZP30iID0d_RS0;oVS@31iHd0c>VG0=O]XP3Ag9X0]<1n
0=_ZY`37fiH0eNVT0;37P@3Aj:80bMjI0<oSWP37f9@0UZEP0<OLS`37jYX0bn:J0=?PV`2[Zfl0f^:V
0=WSYP1VIRX0ViMJ0<gWWP36j9`0f?BZ0<KMV@3?gih0fnNU0=WUW@3PjZ<0WjIS05=D6P0i<PH0@S0J
03//3`3MiZD0f^JT0<kSWP3:hI/0b=fH0=7RWP1>FQP0d=nL0=KZY@3:iIh0c>JO0<cKV02L[FT0cNNP
0<KQVP3Pnk@0bNBM0=K]Y`3?iZ00a=jG0=C^Y`3Qo;D0b>RO0<?QV@31giL0cnfU0<cZXP33gI`0dNbW
0<SRV`33fI00Qi]D0=;VX@3Qm[<0i_bk0<7LU`3:j:00en^^0<FnY03olnL0ooo_0?ook@3jonP0dMBg
0:NXR@2QXX00/[JA0<S@Y`3?ekl0ooco0?ojo`3onol0m>cO08n7LP39`j<0oOOC0?oog03oomX0i=ng
0;F`R02HSV/0Y9=i0;RSSP1:<b<0L5U704ln9027NEh0ViYn0?[mj03iooP0eMg@0>WXeP3Fe;d0[J^B
0?ooiP35bZX0Hfe806eiD@3?g[<0cn2c0;G8VP2K[7l0EV0m071iFP1ZKeT0T9690>[Yi@3mo?L0ooof
0?OohP3homd0b^:T0=;b/`2mkKT0WLfI05j@F`2Bai40X]RT09cGX@2YiJl0M[En08S9T@2ko<H0/O2g
0;S/[P2ahJD0`NN/0:W:T@33h:P0co2i0;?HXP38nl<0QlB;04:;E01AV600P[=k05n?D`3;mkP0]N6T
0<Wa_`2_eJ`0_>C10<;]c`1NSF/0Y]^a05R>G@1iZW80Ukb80;3SZP2ciZ/0h?C30=;N/03Gi;H0i^Vn
0=o9Y01^ES80hm>b0?oij@3oond0ooo/0?cniP3lonX0logR0?_ok`3koo40nood0?_on03Zm^X0G7AT
00<E1`22Q7L0b/Nf0>OT`@3mom<0gNF/0=OOY03Th[80oOS>0?oog02og[80c>Nl0<OI[`2^`9H0bNB_
08F9E`2PXW00fNn^0<7OV@36i9X0SJEK06Qi<P3DeYD0g>NS0=Kj/03NmK40?D<706AU:`3PgjH0d]RL
0=KRY02P]WH0dnNX061O9`2GRUH0Ie4R0<S8UP3BfJ<0g>6Y0>S^/P3?fYH0b]^E0=KaZP34gi`00280
e>N_0=OU/P3foM@0mooO0<SFX@33eI/0b=VS0=?ZV03Fki`0^]BE0=OfYP39kJ<0]=Z=0<cbV`39iI/0
_]FA0=OcZ@39j9X0_n2?0<_]V@3=k9`0e_6T0;kBR`37f9@0f>BT0:FfLP2CYf80X;E`0<gWX03:j:00
c>ZR0<[UWP38hId0h?2a103o0000=@3Jo[@0l?2b0<??S@35g9P0b^6M0=7TY03IfZ40YhmS0=GW[@3I
jKP0g^Bn0?ook`3gmnl0nOOj0?ono`3oooX0oOgc0?oom03ooo<0o_oc0<3AY`3Ll;/0DFH^02Dh002m
ci<0fN^]0=g_/@3_o/<0V:E]0=cY]03Tk[`0en:Z0<kPYP3AkkT0f?300=ZfWP3heKl0i^[70>[je@3Z
nMP0jogS0?Wok`3oonl0oo[Z09Z<LP3ml=00K6Di0<oJV03HkJ80c^bR0<CSX03Qmm00jo_Q0080oooh
00l0oooc0??mf`3VllP0c^:U0<SQW@36iIT0anJJ0<SXW039jIh0a^^K0<S^V`37jYP0c^VL0<kVVP3C
j9d02`3oool000h0oooo1P3oo_l03`3ooOX0oocX0?ojl@3om?D0ooko0?Omo@39f[H0dnNd0=7TY03;
f:00dm^Z0?ook@3ioOh0mOoo0?Ooo`020?oio`@0o`000?l0b]bb04ii@@0WG2@0a^Nh0=g^a02LTg@0
<B470;VbV03AckP0o_oa0?Wkk@3ooOP0f<k<0?oko03on?h0oo[o0?olo`3ooOl0nooo0?WonP3bmn40
oooV06]K>P2MUVX0cnb/0<KN[P002`00gNbe0<OAW02i_J@0n_oY0=KV]`3?iZ00dO6V0<?UV030ihh0
c>fL0<ORW`35gih0bNJT0<GZW@3=m:<0^^290=;dWP3:hI40dN>I0=_VY03BgY`0d=nL0=[^Z@3Hk:L0
IG`f0:k5O`3=hYd0e^ZU0>;c[`2ea7l0Zl1c0<c_W`3>iId0g^VU08J4B@3Ni:P0f>2T05aL802>S4l0
b^JL0<O]X03Gmj`0_mRD0;K5Q03AgI/0cm^C0=KRVP3Lhj00WiiU05587@1/DCh04P000=GKV`36dHl0
d>BO0<_PV`3@i9l0cmjK04YE4`3Hi:80dNFP0<gXX@3<iYl0dnBP09BXH`3Il:X0e>jW0<GPV@3Ak:D0
cNRQ0<oZX`3EkjP0dnfV0;WCS03CljX0a>BK0<OWWP3=kjD0c>jT0<SUXP3:iIh0b>:I0=?YX02CYf80
cMbQ0?Ooc@3iom<0`MVK0=3[Z032e9X0Y9R00?olk@3oonT0o_oS0>WccP2>VV`0Hf`m08ZDHP2GXg40
]lRD0;W@Y02O/Yl0mOoc0??oi@3Oj;/0FV0`0:n/P`3<`j80oo7R0?ohk@3ff]H0dKRa0:bMR02eYID0
j=K:0;VPW03cf]D0G4@h08IcI01aIU@0S8Ee0<c<`P3el^d0oo7`0?obk@3fk>80QHM_06E/BP1JLCd0
c^b`0<?^W`2oki/0[^F80<_kY@25VV40IGM702`j5P0R:1`0JVa[07inQP2`/kP0nOoj0?Oom03Nm]@0
]]>U0<cg/P31jjT0M:ET04n1A027^Wl02D8=03Yd@P0iMTX0<g5808_;YP2hnm00/OJm0:[Y/P2ah:`0
i?oI0=_kbP2_c9`0Y<BE04QfA`1TW6/0Nkn>0;Sg`P36jJL0a^NR0<SVX03Mn;D0a=^U0>Omc`3Rn=40
dnk=09noVP37k<40`NRa0=[m[@2kdHH0b_2U0<?WW`3@eId0eM>R0>3Q]`2UVgP0UG5I0;>>N`3on^X0
ooom0?Sjm@3kooX0logb0>3ah@3boo<0kOgb0?Gon`3boo`0m_oo0?3nl@005000JH180>3i`03eom<0
dn:Q0?ooaP3VijD0gn6P0=WRZ`3komH0nOoJ0=gX_@3Ih;H0gnFo0>G]aP2bai`0[;V=07R0D@37dYX0
f_^f0;GOT`2V_W@0<S<00=kSX03MlJT0/mN=0=G`Z@1DGAh003<0@D450::LHP2GUe/0W:EV055Z:01k
U580Ce8I09^?F`2YSV40fljQ0>S_^@3SlK@0amZH0?7o`03@iil0gNb[08>>DP3Dh:h0c]j_0??og@3i
on<0cn2Y0=W[/@3HjK<0dnZJ0<7IR`3Dl;D0b^ZN0<;XW@2njIX0^N690=7/Y@39gil0`mjI08^WG@1h
UdL0VKQX09ZiJ@3:iIP0gO>[0=CXX`3>gYd0gnj]0<kMW015FQD0^mF<0;GCR@3AlJH0b^RP0=?/Z03@
h:40103o00004@3<jjD0d=6E0=gWZ03:gi`0`mbH0=g][P3Qh:L0Z9AR0=GYZP3Bhj`0joC70?Oki03o
oo@0noOh0?oko`3oo_/0o?cd0080oood03<0o?kc0=GV^@3NlkX0@ELI09Z`K`3Aiil0c>:I0<;HS@2m
dHT0CEhH0<oOWP3BhZ<0b]jI0=3ZX`2oiZD0b>N^0<nbT03B]I<0e^2^0=3Y/P3;hjl0gOK<0?OoiP3o
on`0oo;Q0<BdW@3^gl80HUTb0<gEV@3Fij40d_2V0<WXY03Djkd0h?CA0?Ooj`3kond0nooZ0>Ceb@3D
jkD0b>JP0<[ZW`39k9`0a^^K0<K[W@37jId0a>NG0<k_WP3;jY`0eN^R0<kNU`36d8/02`3oool001@0
oooo0140ookk0?okk@2TU9@0oo[o0?Sbo03oood0nooQ0?OodP3Hjj/0e>>/0=;O/`3enNP0o_oj0?gl
o`3noOl0nooo0?coo@040?l0001=0:kH/01DQeh0MZId0=7X^P3noml0=R@<02LB003Xg<h0iMoA0?go
m03oooP0oo_k0=75a@3SfmT0oocm0?olo`3mnoh0o_oo0?Kon@3Xm^L0i^oB0=?C/@1LCB@0ViQU0<S[
Z`38hk0000d00<gDX03MhJh0oooa0?oomP3ion40jOno0<GQUP3?kJ<0a>BQ0=gf_03Sl/L0enJm0=7S
^@37iZ/0anbY0=;dZP39iI/0n_o10=GKV`3?fYP0cMVG08ZIEP3@i9l0d^JQ0=G/YP2]a7h0bn2K0=CX
X`39fYH0g^fX08FJC@30hi<0dNFN0=GNV`2XXfT0gN6V0=_QY@1]KC40WI]N0<SVW036kj40`N6F0=C]
Z@2f`X80Uj=Q0=KXWP3Dk:00f>nW0<_KW03<dZ800P0@0@00gP2FV5T0N7hn0=7RWP3AiJ00dnBP0=OS
X@1<EaD0h^j/0<oPW03<ij00b^FN09J[IP2>XUd0dNFP0=?XX`35h9T0KXi50:[:P@39jJ00d>ZS0<7F
T@2>Xeh0a=^E0<oYXP36i9`0c^jU0<k`YP35iYl0do:V0<[VV@3Tn;40VZQZ0=SQ]P3mon80o?oV0>Gd
c@3Gj;/0W:Um0<:gY@3on^P0nOcO09^_NP1[QDH0b>:I0=7YW`3@iYh0c^FQ0<WRX03Llkl0hnW?0;>d
U@3Ef[80f^>/0=kW/03Nj[X0j_O<08ZHM@2Q[h/0gno80>ood`3Yn<d0mooQ0>gbg03im>h0knKQ0<c0
]03llMl0m^oB0?G`d02^[X`0K6I4099kF`1jH3l0ZI=^0?S]`03[iKD0e=bS0<_IW03Gl:`0do6Y0;oT
U`35hYl0d=F/0=WJ^P3oon`0ooOn0?oho`3ok?l0oNSg061FC@0/9a40?d8G02Pd101CL480X[nA0;7A
X03:k;X0`^Nd0<?Z]@2cfjH0_^Va0<7/]027]7/0RL2706ViQ01HXVl02dLD04=hA00JAQ<0/LjN0<cS
]@3?h;@0bmb`0=g^a01aQeT001`005ak@P36gjP0cN>b0>Gfe03_onL0m?od0?3oo`3DknH0g?k^0=7/
f@2cZiP0C3TZ07EgH@27S7D0l>GA0>_Sd03fo^H0ooo/0>7A`@1dKEX0P7iW07imG`1oOUl0RXmW0:>Z
OP2T/7h0Mh=A079kCP20Qed0MWaF08n@L@2LWWL0c]RI0=__/02[bh`0f?Ri0:RnOP2AWEl0TIAK096H
I03?i[`0`n>n0<o^a02na8H0VY]Q0:NVMP2d]hX0iN[F09>]RP36gkP0UjMf0<KUZ@34jJ@0i_F`09J>
C`3=fY@0h?R^0=7]XP3ElJH0d>JN0=3QV`3JiJ40eN6O0=;SW`3CjZH0amjJ0<[HVP3Hh:@0UI9K05iF
9@2g_hH0i?Ng0<?NU`3:jId0aMnE0<oGV`26QU80k_G;0<OC[@3_on00l_oJ0<_VW`3Ck:P0c>6Y0=S]
ZP36f9`000P00<[JZ@39g:h0cN6^0<cRX@3<gjP0^<ZH0<[OYP3AjZT0eO6W0;_GRP3DlJ40cn^N0<OQ
V02Y`7X0NY5=09>OH@2OZFX0>dl:08VSFP80bN^N00@0d_:W0;cFS`3IijT0f>2U0P3o0000A`38hZ<0
g>^`0=cTZ`2SZ6h0d>2Q0<cZY03Jh:80blF90:f]K@36gY@0a=VF0>Kd^@2oaJ<0o_o]0?ono@3ooOh0
ookm0?_jm@3oooP0oOog0?[omP3KjlH0b=ZX0=[^/`2kdI40aMfC0=_cY@2cc7/0d^^H0<kWUP2meHT0
eNfQ0=WbX@32hXl0ao:Z0<W][@2^UVX0c[N50=WZYP39j9X0e?>W0<GSX`3;h:P0h]nn0:RNP`3XfL80
oogS0?oog`2FVVL0bmVK0<WXW035iIX0b>FS0<[QZ@3?hk80c^Fa0<oV/03;j:P0b>VT0<G/W@34jiX0
a>^H0<G/V@38jYd0b>ZN0<g]X@34hiL0d>ZP0=GRW@3Pij@0PX1300/0oooo000D0?ooo`0=0?ono@3o
oOH0k^?W0?[`n@3hm_/0oooh0=;N/03GiZ/0d>FT0<_MZ@3AhKX0nOof0?kon0020?olo`030?;noP3e
ooP0m_7C0080o`000?l0b_C20;C[`@13NEL09eDT0;oBY@3ooml0JEA101d6003ah]/0ooK_0?oon`3o
o?T0oo_m0?O[j`3EcLX0oocj0?omo@3moOd0o?oo0?OonP3eoo@0iNk?0>WYa@1=?Q<0[:Uf0<GXZ033
gZ/000l00=CIX`3Ogjd0oo__0?oon03domh0i?Zj0=G_Y@3:j:00cnbd0>Omc`3lonH0n?oT0?Woj037
hk<0anRa0<[ZY`37h9h0g>2U08N8CP1cOS`0KWXh059Q7P3@i9l0hoNb0<gTWP39h9X0d^NR0=O[YP3L
kJT0a=>>0;W;O`3<kIh0c>2I0>O^Z`2MUed0h>BY0=WOX`1RHRH0TY1C0<GUVP3:ljD0a>:H0<WPW03K
ijL0d=bJ0;cDR034hiD0eON[0=;_[03Eik<0K6Q=00P2003?dI80Vj5Q0<WJUP34f9<0enJS0=WUX`1A
G1X0h>bZ0<kOV`3:iIh0bnJO0;cCS@2@YF00_m>>0<cQW02@Zf@0`n>J0<k`YP3<kZ@0cNNP0=ca[03A
iJ00b]jI0=[^Z@38hY/0b^RP0<OWWP37jj<0bn^O0=;^X@3FjZ<0OXaA0=[P_P3nonT0o_o]0>WdeP3=
fkL0bMF_07A/G`2UY980VZ>40<KTZ03;k:D0bnfI0=KcW`37gi40e>^S0<kWX`3Cik80oooV0?ooh@3U
ikl0e]nZ0>?`^`36fJ/0iO[?0;_FZ@3AkkT0_mnP0;oQU`30gi/0dnZf0=CV_P3@f<<0i^WH0=;B^P3j
nm`0b]2T0=WO/@3OjKD0f=n[0=ODW`3oo/P0ooo=0=CCV`3EeYd0fn>X09NQI@2a_h80E6<X0=k`]037
fIl0fNFg0=WO_@3oon`0oo[o0?oho`3omOl0ooSo0?gci`3oon@0b]6M0=CQZ`2B[H00KXYJ06F1D@0k
EbL0=U8Q05ahA@1XQDl0F7Do05Yg?`2I]Wh0_nB^0<Cod`2XhkD0`?K40<Cf`@2_fjH0_MjY0<WT[`1f
PU00P8IH089oE02RYGP0Y/6<09V`NP1[O4P0RYMY05URA@0d>bT0]knd04YHF01AI6800A/B02Lk;`27
OVd0RgQY07IjH`0W<1D0>38J05UE>P1gQf<0MH=P040m7P29Sfd0IVi7092CIP2QZ7D0iNnc0<cHV03:
fI@0cmjI0<kJV03Egj00c]JK0>;V/`3Lh:d0gnJ`0=;LY`3Ij[@0_M2I0:k0Q02=Veh0e^6U0=g//`33
gK00a>:l0<;O/@32e8P0enBN0=OOY02BVFD0oood09ngW@0/C2L0>5@S0<OTZP3CkJh0bM:?0>?RXP3>
gYL0b^2G0<oWW@36hYL003H0gOV^0<_WW03Fl:L0`M^B0=S_Y`32eY40f>^Y0<gPX03LlK00d^:S0;g2
RP19DaL0Be/L061e<03IljT0dNNN0=_YZ`2X/G`0o_oO0?_oi03>hk`0b^V]0<[]V`3<jil0bN6W0:k0
Q01kREH000<00=gR`P3/l=D0f=fm0=OQ[`3DhKD0cmnb0?7oc@3<hJH0`=ZC0=_g[03>ji/0bNFH0<kZ
X03?jj40cNJR0=WUY`3<eYT0hOF`0;gGSP3GnJ`0_nBF0<c/X034gYL0c=RJ0=WQYP2CUV420?l00016
06U`>P3AfZ<0MW]30=;PX`3=k:H0h>:S0;bdMP3=e8h0b^:F0<GKT`3JjZ/0`<RS0?7egP3oo_/0o?Si
0?ono@3lnoL0oooj0?Wnm`3kooX0i?7C07^<HP3@h[00bmjV0=G/YP3:hYP0QimA0=G`W`38iID0go^^
0;[FR`3:hi00cNfJ0;oZXP35j:P0XHII08ig@`3FiYd0d>fI0=OdX034hY`0dnNZ0=CD[P2OV7/0ookT
0?omi03gjL`0NG]:0;c:S@3;ii`0`^>D0<SVWP3:iJ80cNFW0<[RY038hZ40bn^R0<c^XP36kI`0`^VF
0<?ZU`34jYL0bNZK0<[YW@3>kZ80`N2D0=3ZX03HiJ00cmFE08Z5B`/0oooo000:0?ooo`80ooko0P3o
ool20?ono`030?ooo@3oo_l0ooko00<0oooo0?l0oogo0:FRZ`3oooX0o?oZ0=SXZ@39giH0cnRT0=3X
]P3TnMX0mooo0?konP3on_l0oo_o0>Ooo`3Qond0en2e0<[AWP3BlKP0EXEA000S002Cbih0`>V_0<oO
^03monD08`L004TP6P3;^KL0mo7a0?glo`3oo_l0ooKm0?oko`3`kNP0oooj0?onn`3oood0nOok0?Go
nP3XnNT0lOcN0=?D/P3Se:T0O7U60<k`/`3>i[H000X00=SMY@3Hf:80/:nK0<K8^P3GjKl0b>6O0=3a
XP35iid0a^:a0=odc@3noo<0oOog0?Wnm`3doo<0i_oQ0?7ofP3iomX0WI][0=[HY@3Ei:40d=nL0<OL
U`3Lljd0enjZ0=KUY03@h9l0`=VE0<oZY@3BhZ40[k]i0<WMU@31hIH0f^VV0;BiN@2j^Wh0gNFY0=KP
X@1UIbP0T9IF0<SRV@3BlZL0bNFK0<WNV@3Mk:/0b]ZI0<_WW036ji/0bOBU0<ge[P35i:T0f>K200XB
003Vjj/0T8iC0=[TY@3?h9`0go2/0=CPWP1DH1h0dN2M0<gNVP36hIX0c>bS0;cHSP3EkjP0bMjI0=;W
XP34giP0b^ZQ0<CVW037jIl0cNRQ0<OQVP3?i9l0dN:N0<OHU03?iZ00bnFN0<k/Y030hYD0cNbP0<[T
VP3JkZT0JWPk0=[N^`3oon`0n_c_0?Cfj`3MhM80o_o[0?_ik03Zl]X0d^:m0=Cb/P35ii/0e?:L0<;N
R@3HkIh0a=F>0<kOV`3;g:D0nOoJ0=7S[`2oe9/0c>BZ0=K]^@3Vo=P0m?oZ0<kU^@3;i:X0an>I0<;P
OP3<jXP0d_BM0<[ZWP3@ijl0g_300:nmS03iom@0cNJT0<cWX036gID0a^:H0;oSV`30j9l0_>BK0<OX
X@15I1h0`mbJ0=[_[P3>fIl0EUlX0>7S/@3@fZD0b^b_0<KU[03Vom40lOoW0?Gol@3gooX0l_oe0>go
i`3Xo]P0cNV^0<cVY@3OkZ/0eNBQ0<SFV03Pk[40e>6Y0=_U/`3;e:D0e=^b0=_O^P2LX7d0Vimn01PL
001]ME00d^Ri0<7LY`33hZT0EgXj02a:2P3Ml[40SYaN06a`=@2PXFD0TiED09ZKF@2/YfL0LfX_04Tk
3P3Ocjd0oo_Q0?omk@3djm`0l>_H01HO0030hil0e>ZR0;oORP3CmIl0`mV>0<SLU03<iiX0c>6D0:^c
JP36dhh0dnRS0;[JU`38jJ@0^n2C0=?jZ`2niY00`NF>0<GUTP38hi@0dNVO0<KFU@27UeT0V:E_09fT
L@2KUFD0_kN60>3VZ03Chi`0eoJV0<o`W`3Ek:@004L0l?no0?SoaP2nji00`NVC0<ORV`3Jl;00bL6n
0=oXe`30fK`0S[Z907fEH`3OjK@0io2a0<WSW03@i9d0U:AM09Z`J03Dk:80c?6S0<ohZP1TST@0T;A/
0:W6P`3KijT0d]ZN0=KYY`3;iZ40a>bU0<S[Z@3GijT0[K=g09fIG02NWE`0e]fJ0<GRX03;jZh0P9EZ
0?coi03EfkL0dO2/0<;ZTP3DmjL0a^:W0<CAX`3non@02`870?ojn03FalX0/:2Q0?ooi`3<f;80eN^l
0=cc^`3<i:H0d>^T0<OSV033gi80anJH0<OUV`3=jj<0eO>]0<oRX03DiJ40d^VQ0<cZX034jIT0`>FE
0<g_X`36hIX0fNNZ08N?EP040?l0000d0=KNZ`1:CaT0fnJ/0<[UXP3GdID0Ed/?0<kVVP3>ji/0go:b
0>[g`@3LhL40WIj<0?G_k`3ooOl0ooko0?oln`3oood0m__g0?_oo@2]^:L0;SXR0=KQ_`3?fk<0eNJ_
0;77Q`2]aX80`n6G0=KdZP3DlZX0do6Y0=?`WP33iI40a^nS0<k[Z@2_Tf@0_ZE_0=KRVP3CiYD0c]n?
0>7bZ`2obhd0DEX[09NNM@3gm]P0oooT0>CQ`P2NY7H0D5hS0<_VU`3<k9L0a^FE0<gYWP80c>JL00l0
bnNL0<SYVP36jIT0a>VI0<O/W036jid0b>ZM0<[YW@39iid0anFK0<k]X@3?jJ00fNZV06ah=P2l`8<0
2`3oool000X0oooo0P3ooOl20?ono`80oogo0840ooko0?omo`3ooOl0ooko0?ooo@3looP0no_i0;Jd
]@3oooH0oOoV0<oTX`3=iid0anFO0<SP[P3eonX0m?Wm0?ono`3omol0nOgo0<cokP2fk/T0/M^c07VS
O@2C`Yh0^mni0<?X]@2jjiX0a^^K0??oiP3ioo807@0007Tg:`3oo>`0n_od0?ono`3gn?`0oo[o0<Fj
`03Jf]X0oook0?_lm`3nood0n?cm0?7mn`3eool0hNSF0?Cbf@1LCB@0jN>c0<?QZ`1SO58000X00<oM
W`3JiZ@0dMbb0=KT`03>jZl0`>FE0;cYUP33l9l0bN^O0=Wb^03joo00nool0?Smo`3dool0looi0?So
j03koml0T91N0=oRZ`36gIT0d^FS0=3^Z032hI/0fOBa09bMH`2][W@0doB_0;SVW@3HjZ`0YJeb0>oo
`P2ngIT0MWXo07Qf?@3ChJ<0cn:P0=7QX02RZ6P0Z;ag0;>nNP3LjJ<0cn^N0=3ZX@3Rmk@0_]>@0<gT
WP3FkZ@0K8<k0<[OW03AhjT0fn>j04IA9P3WlK80Y9=O0=cMX`3GijH0d>NS0=gXYP32dHh0bmbH0=k]
Z02jf8h0bo2S0;kSU@34iYX0c>ZP0<KRV037hiT0an:K0<[XX036i9`0^mZD0<GTWP3ClZ`0_]bF0=?a
Z`35i9h00P39j:80P@37gH/0am^F0=OZZP10Da<0^/^50=WT[03lom/0ooo]0?omo@3ilo<0ooo_0?oo
iP3cn]40gNJg0=KTZ@3FiJ@0E64I09BPF039dhh0U9eJ0:Z`L03Cg:<0o?oJ0=?T[P3CijX0d^RW0<SP
YP3bon<0mOo/0=CU``3<gZh0e^Z[0=3ST@3BgY@0c>>M0;kKV03AiZh0lo_:0<;1T`3Nh[00c]fR0=g[
[P2:R4l0ZJA/0>CUZ`2KYFP0TYiN09f/J@3?h9`0cMfL0=g][`3Dh:h0_lRK0?_ofP3oon<0o_oZ0?Go
fP3Jj[/0ennc0<kW[@37h;H0l_oT0<_Q^P39gk00d>NQ0=KSW@2TUf00]:Ua0:>NIP2JV5l0_Kj50=[O
Y`3IhJP0gNJ_0=3JY@3Ji:l0cmNV0=7?Z02GV700GfDg02dg1@095P00QIMM09jbM@2CZFT0a]bK0=cb
/@31f9@0dN2K0=?PVP3KhYh0gN:P0=cKXP2l^XL0W9YZ09>AJ`2_[8T0];>D08FBMP3PonX0b^Na0=?/
V039ii40a^ZP0<GTX@3Pn:X0cnFC0;K8MP2neHl0d_6]0<_jZP30kj40aOF[0<7aY`34l:<0_NJH0=7]
XP3<hI`0dMnQ08b@G@1aO4@0_^2C0<cZX032ei80enZX0>?f]03BiJ<0dnZT0<[TW@020=O^Z0160>co
_@3Ln[80_=ZB0=Oh/`2ogih0oo_d0<C1/P2naZh09D4H07>?G`3<jK<0bn^/0<S]Z03Em:h0a^6L096Z
IP2:Xel0KhY706=m?P2=Y6`0PiMT09FUM02:TV40Q8]H08ZBE`24STl0cN>R0<O_/03?i:/0g^>]0>cP
[01bHbX0QGm30=kd/`32h:80]<bL0=7M]`3Jg[T0e^j`0<[XWP3=j:<0^m>I0?Wog`3eon@02@T;0?[h
n`3oo?l0oo[n0?WnjP3:i[<0_nJS0<W_YP35jIl0_=f>0=3aX03:jIT0d>nQ0<k/XP2ogID0a^FO0<WY
WP3<k:00bNjN0<W`W`2mi9<0b_6P0<W[W`3Im:l0BEPM0>?^]P@0o`0004D0emVZ0<G9U`34dI/0fNf`
0:>AG`1WDb00_mnF0<KZX03ioml0o_o[0?ool`3Uh]d0oogo0?kdo03ooOl0lnkb0?ooo`3fnoL0noom
07V4M01^NV@0fN310=[P_02Q[WT0LXA80=CZZ@38j9d0c>bQ0<OUV`37hiT0c?:M0;oZT@36k9T0b^BJ
0:nDG`2WSUP0f>>O0>CYY`3RhJ40@T<705QK8P35gZL0bNNe0>?id`3^oMh0eN?20=ST]02BXV@0Zl9b
0<kWT`3JmZT0bnJO0<cVW`3@jZ<0bnJO0<WWW`3Fm:`0`>:H0<g_Y@3;kjD0an^Q0<gaY`33iid0`mfC
0>3fZ`3?iI`0XKU_05A/8P3:hYP02`3oool000X0oooo2P3iool0o`3iood0nooj0?[hn@3ooOl0[jZW
0?ool@3Um/80fNn_0=3Z[@3=h;<0m_oX0?kon`3nooH0ooko0>Cbl`0gMU/0`__B0;g`^02ej[80c?o?
0<cX^033fj40`NbC0=SeY@3ZnN@0mogi02l71@22<b`0kmW;0?oomP3ooOl0o_oo0>;Eg`3<`<X0oogn
0?oon`3kn_D0o?_i0?Sin`3iool0n?oo0?oomP3onnL0DClI0:2HJP3;i[40HgQ?000:003@hId0cmnH
09j[MP3Chk@0`MbI0<_^VP36lJ40`NZL0<WVUP3AiJP0o?oZ0?oonP3oo_l0o_oo0?7fk`3`mmP0mO[B
03Lc0`3`kKX00@P003M02@3Jjk@0d=nX0;6cP@0K2000JUdc0<7CW`0eDQ`0:b`003Pc2@3DhJ`0fNZc
01hJ001<AQ@0dmjT0:VkO@2L[6d0d]fK0=;VX@2oa8@0U9]H0<CUUP37iYX0f_F`0<CMV`2@Yf40]lf5
08RID`2]_7/0cmfR08ZCJ00fB1H0bNBQ085d?`3Afih0e_>`0;kRVP2BYf80e>jW0<[UWP3^okd0]=f?
0;cWV03Lo[40bNVM0<3JT@3FkJD0c]nI0=[[Y`3Kk:P0eNJR0<cOW@2DZFH0_<n=0=GOX03CgIh0h>VZ
0=;KW03HhJ80c=N90=OOY02EWVT0dMbP0>Wf/@3Ggj<0dmJY0?ook03on_l0onoi0?oik@3Uh[l0em^Y
0>K[]@2IWV@0Vj5U0<gCT`3WkZ/0h>NT0:BZJP28STh0hNV^0=cR]03AfZ<0joNi0=o^Z@35eIL0hno;
0?_oj03dnm`0k_G;0=gV[@3Jh9H0XYaP05EM901CHBH0dmRR0=cAX`2o[X80mNZl065/=02S[W@0i]nY
0?3V/@3WiZh0e]jR0=gVY`3<fI@0fnZU0=WXY`3DhZ@0gNFb0>7W^`1RHT00mO7F0>gUdP3MfKH0g=j]
0=WVX@3Dhj00eNNc0?Sog@3Ch[L0_<ZG0<kNT`2HXeL0eljG0>GLY@3OgJ@0h=nV0>;SZ@2@UUX0MWa0
096GF`2IWf<0P8I:081oB@0l:@40DChF091mD`1eI3P0VheP0;jdP@3NfJ80jnnd0=GMX@3NkJ`0aMVD
0<_UW03=iid0c>2H0<gNU`3Eh9`0hNbZ0=GNW`3noll0l?O40=GM[P3Nkl/0`^gI0<KW^03HjIT0f^bJ
0<g/Z02hfiT0cmnF0>?[WP2c]f/0dNBT0<WOW`3SkZT0h>fX0<oOX03<gil0d>>S0=3PW`3RjjX0em^N
0=;?V01SERT0UiMS0=;m[@2miYP0c>fV0;_HU@3=ijP0hOVm0=C/[P00BP35gj00d>fZ0<WXY01NLBl0
Wi9M0:>II03Jfj80emnV0?o^i`3oo_40ooo]0>;ad02BZGl0A64a0<O]]03:l;D0ZM2A0<W][`3:jJH0
fON]0=[h[P30giT0g_o40;KIX@2XcY/0BWE7076QL@1eZGP0TLNE07>YM@1k[WD0SjYc0<kKY@3DdIh0
h]VR08^9CP2R]7H0a]jP0=O[^038f:/0kO;90??oaP3KjjX0eN>U0=;PY@2la9d0cmFi00`<103jm_<0
o_[g0?okm@3joN80d=nX0<OKU03@hI/0e^>N0=_RWP3LhIh0bL^:0=CFU@2DUUL0cM:B0>7VYP3?fiT0
d^6L0>3_ZP3>giP0enJQ0<SGU03JhZH0g^6X059<703oom@0ookD0P3o0000=P3oom80ThmR0=cKZ`31
biH0b]FM06Y=8@2QPU@0e_B^0<[XXP3oon@0o?WX0?Oai@2JTHX0oo_k0?kbm03onol0ooco0?omo`3i
n?H0ookj06EVH03dm>X0ooo/0??/d02>SF40fN2Z0=GSY@3HlZ/0c>RN0<WPV03=hi/0c>fN0<KYV@2n
eX`0gNZU0;6@G@1cEB<0dmVK069M9P2=P4`0j>>/0>GV[@3;i:80bnRX0>Oib@3_nm<0e=Zd0>GW]P3Z
jk40NX0h06=[8P3KiJH0joJn0=7ZZ080anFO00h0b>JP0<;QV`3OokT0dO:[0=?g[`3>lZX0`nNO0<O[
X`3FhIl0ko6b0=7GU`23Sdd0`=6=0<ONV0/0oooo000:0?ooo`80nooo0P3kood20?_oo`030?_oo@3k
ool0nooo0080noom0280n_ok0?omo`3ilO`0clK;0=SDb`3lomd0go:k0<oT[03BhkT0nooZ0?[nl03k
onP0o_of0<_Je@0ABC00^Nc10;_XY`31kZ/0^^RX0<;JX03FjZ/0aN^H0<[QV@3ioo<0o_oo0240002O
DT`0km?80?ojm03lmod0oooo0=kAf`3>`L/0ookm0P3oooX0o`3oo_d0oogo0>7Tj@3kool0knoU0?oo
k01bH3`0Vi1R0<oV[P1TMT`000X00=WXY@3EhY`0WZQd0>Wea@3:hId0cNZF0<c^XP36j9h0c^FM0=OV
[@3lo^P0oood0?omnP3oooP0mOWX0>[`c03Si[/0JV@d0<S0S`081000HfLe0<gEY034aYL0Ge<[02/C
001mJTT0iNg4008?000k<Q404`T00>;Z^`3Jh[40;BT000X3003VjkD0UJ1V0=_Y[03;eiL0f>NV0>O/
[02Z/g00`nBE0<_[W`38iZ00b>>P0<CNU`3Bj:00^LZ4069b<@2EXfP0FF8g02Lg1P3Cj:L0Ie<P0=KJ
W`3;hJ00bNNQ08BCD03;g9P0a]NC0=GRW@3@kZ@0co6U0=WeZP2keH/0cnFM0>7b[03WlZh0dmjL0=3I
V03IhZ40_lV:082<C03HhJ80^kb00;FeN@36aXX0Zj]_0;JfNP2j`G@0XjQ^051G9029TEP0[KIe0:R]
L`2QXWH0mNkK0<nna033/;H0j]g=08R6H02[[g`0Zk1j06I/<01iOd40W:=P09fVH`2EWU/0MWln07Ao
?@3KhjL0gn:c0>CY/@2e^gd0e]nL0=oY[03Oil00oooT0?ooh`3=d:<0b/nE0:naJ020MS/0P85805eU
;02l^HH0j=FZ09n8GP2RU6D0JgHl08VGG02JVF00/k9i0;k6R`2P[W00X;1_0:RiL`2nchT0a]NC0::a
L02@Uf40aLNH06YV@02XXX80^kBH0;2[Q@3DdZ40VIiN0:R^L03Mi;P0^/:K0:ngSP2PZWH0Tj5F08VE
B@2TYF/0^[^10;VmPP2<TUH0XJU]0<S@U01=EAT0Z:ib09:FF`2DUE/0ShYC069A9P1KBQl0IUDY069D
9@2[WFh0U8eG0:FPJ030a8L0UYmP0:BcL02[_gX0R:IL09FaIP2G[fD0TjMO09>SG02__7L0Uj=Q0;[5
R@2f`HT0S9UT08FGK`1;Le/0RZin0>3`Y@36dh@0bn6P0<SXY`3=f9<0h=fF09fCCP3>fId0f^R[0=G=
S`3LeYX0][Ij09ZNH@22Rd`0LGXi0>CVY`3NgZ80VIAL0:ZNK02o_8D0aMjJ0<cRX@3AhjL0kOc10=OT
[P3jom40f^Vb0;o>U@37fi`0[l>402/g002TTel0[9aY0<BjQ@3]j;40iMS?0?C^gP3oond0cM^j0<cN
^01ILdH0co2k0<OZ/P3@m[/0bo6f0<c^/P3=ijP0cNFW0=;/[`2H]gh0/mBO072EH@1IPe40J9IU03U[
>P1YWF`0^nfj0:;8U@1cQE40fN:]0?7__03mm;d0/Jad04aA5`00:P3JiJ/0cMFT0?oofP3oomD0ooo?
0>7[[038dYD0dmfQ0<cBYP3<d:l010400?okl03`k>00ooo_0?oog`3EfZ00i>jY0>[_[@3GeiT0j^JY
09F?E@3^iJ`0i]^S0;F/L@38_h@0/Za`0:JWJ`2BV5X0UI]K09^QH@3/lK40f]jQ0>KS[03DcYX0GU0S
0?SW_03hh[d0gN2a09jXMP3oom80ZJEf0>OW]@80o`000440ITDH0;bJK02jdHd0f?:[0>3T_`3ooN@0
eljm0;N]X@3oo?H0oo_h0?__k`3omOL0oo_l0?Wdl@3<b<D0_kZg0?olnP3olN@0oogX0:FPMP3Mh:/0
eMnS0<gRW@34fi<0fnnX0=c]Y`3Aj:80b^BM0<[KU`3Ujjd0Yh5B06i<7P2i_H80IF0Y0;BXM03Qh:P0
f]nU0=SWXP3Ij:D0m?_70?kmd@3Of[00j^2_0>SMY`31^GX0F5<C0;>`N`3>c9`0cM^N0=3SX@3Ai:80
d^FS0=GXYP2kd8d0bn2M0=3UXP38gIX0eNZW0<kSX03Pfj<0akb60:FLI@2f]G`0h^J[0=7MW`0;0?oo
o`002P3oool20?omo@80ookk0P3ooOd0mP3oo_/0oogm0?omo@3oo_/0ookm0?Sfm`3onol0n^gn0?k`
o@3:`;l0oooT0>Caa@3@h:l0dmng0?coj03jonP0n?oH0>?`eP3:g<h0F8Q^0:G@X`33iid0`^NG0<?W
W@3;h9d0e>NU0;gMTP36fIT0o?of0?ono`0]0`D0_W=`0?o^j03om_<0em7A09FDS`3olod0ooWo0?ol
n@3on_@0ookh0?ojn03oo?h0o_oo0?cmo`3oooH0oogZ06IB;`2MT6<0cN6V06AdA`002@00fnNU0=GP
V`3:dih0Y:ak0=g^ZP3>iI<0cNNP0<OPWP3?i:40e^>]0?7ae`3im^D0oo__0?ook@3bm]/0g^Fi0=;F
Y02SWF/0m>Vk07U/@P17B1`0g=nd0?G]aP1L@b@0IDX_01@1003BdK801P<00>[J`@1?@BH0dM>[05eH
<02i]8X0HUdc0=cHZ@2`/gh0c]NN0>Wi^P3;diL0in^^08F@CP38ji/0b>RL0;cJU038hj00h?Zc0=7W
W`35eY00g>b[09NUJP3doM80@4`L0:RWKP2<HcL0WXiJ0<_?U01oR4T0MW0d061J7P29PdL0^[1c08>8
AP29UU40QIeC05Y`9`1mS4L0HFhY079i=P1>Da<0E5HG07eo@01eMSX0/;5e09NHG02d]7H0/Jmb09jL
G`2RX6<0She@04eA1`2CUUl0g^2a09nSL02=TeL0]KIm09VFK@3Rf/L0c;bo0<fj_P3Od/40WIUc0:f_
O@2`/g`0V9iR0:ZcM02CW5T0UZ5M0:^hL`2:UU@0M80n05IP8`1ZK3X0CTlF08J8B@2QYV<0GV@V0;:d
S02h^IL0ZJV50:2OK`3>ciD0GU/D085e>`3CdYX0^[f408EkB03hh;@0aZIm065<7`2LYfd0/l:709bR
IP2W[G40cmnQ0;;7QP2^aH40Zl5i0:g3NP2od8X0X:m/08R@E@2SYW40cLZM07ehD03CcZP0e=2Q09FB
G@2QWf@0e]>L0?Wgd@3WilD0Wj5j0827E03Fi9L0_lf00;g7RP2g`H@0X:a^0<C@TP37diD0c=JI0;S2
Q@33ah`0V9UO0>SV[@2BSeP0blVF0<c:U`2k^X@0bLZA0>[[/P2LY6P0VJ=T0>Kj]@3@iJ00X[id0:g;
P@2mgi<0bNVN0<kZW`3;hiT0bmnG0=k_Z03AhY`0fNVX0=3PXP3Bi:P0dNNh03iPA@2M`i00S9aC06]c
:P2GYfH0XL1m09NNFP2YWUh0MeXP09BIH@2GX6L0B3<009J5C@2JTEH0Z:AW09JKF`80WZ=S05T0RXa=
0=7AU@27PTP0THaD06iX=02?R5@0akb>0=;5V033]XX0ZIia07E]?P2;QE<0J6L_08Z9D@2NWFD0d]2G
09:@E`2MUUl0Bd@=0:nYV@3Fdl00YjVC0:VcT@24TVh0U:Il000>001?Kcd0R[5j05R1B@1RPe@0HW=A
00lH000Y<Q<0TYih0:JcR01KJ3`0OXiM06YkA`2:VfD0RY]T059P;@043@00?3dA05A@8@1MDR@0GdlL
06AD801JBQL0DD<B06II;03GbZ00WiAW06e/=01mPT80FelR0:ncN02XZW/0L71:00L2000c;QX0]K6F
0<c9ZP26QEL0XjEV09RKEP2OWf40Yj9X06eS;P1VFRP0_[1o0<g0S03LciP0fm6F0;fcN02FUE`0Z:aa
09NKGP1HG1l0T95E09fMH@2ZYFh0WIIR06AF:@2o[X<0/ieh09>IJ@28TUh0YjMe06IR<P040?l00010
07MC8`2M/6h0QIYE09jQM02VXWl0]ZnC07Y_F@2LSX40mnWP0<o0_@3Da<@0c/2o0>gShP1^IV@0h]KJ
0=71a03@_;D0]jBC0;fdR`2=ReP0e]^Q09faK02@Y5d0Z;Mb096MF`1hR4X0Pi=E09:LH02a/7P0WW=9
079=8012@`T0MG0h0968D@1eNCh0RYAG07b2?01nOSP0`kZ30?CV]`3XeJX0_ZIf0;6JIP3YdiX0^JA]
07MU=`1E@QX0N6hi07ei?027PdH0]Jmc0=K@U03ajjl0hM^O0>cVZP3IdiL0c/R<09>=D@2]TV<0GChB
09AgB`3agjl0cl6@0?3Z]P/0oooo000:0?ooo`X0o?oj0?l0o_ok0?ono`3olOh0ooSo0?oao@3ono/0
oooU0>S^b03=fJT0dMZ]0?oog`3]m</0fO:a0=Oba@2fdK80WL6M0=Oc`03KkJ<0a]N90=CSX03Nj:/0
e^BV0<oTX@3LiK00ooof0?olo@0P0000WU]C0?oKe`3om_40a/6]0?ooi@3ol^/0oo[j0?omn03ooOH0
oocf0?oin03onod0oogo0>g[kP3ooo<0ooSS0<nlU02SUF@0cM^N079nD0043000gNFY0=WRW`3MhZ`0
H6@a0;BnN@3Ag8d0g>JY0=7T[02nj:H0`nJ/0=Wda`3Mm/`0g_O=0=gob03?mkT0`n^T0;gQV`3Fl;40
:C/10>3X]`35jk0001H0051M;`1HD2/0IFe600DJ002gd:T0<3hM0=CO_`2DWW`0NG=C06Q>=@2cZhL0
DDdW075R>`2/Y7H0f]j[0=KZZ`3JfJ40blbB09ZVI03;iYT0bnFK0<_RWP30eI@0g?2[0=SWXP3=f9@0
g>JW0?Cl``3CeJd0?dPI0>Wc]P1^DR80mO2h0<SFV035f9H0f]nO07Ai>@2OXF80U91A0>7XY@3Ei9l0
f_:X0=G[XP39f9<0hNjY0=3GU03@dY<0MG<f0;JbM@3GdIL0lN^a0=3@U03;hY`0bN2J0=S]Z03:giX0
e^^V08nGCP26RUL0NGaA0=kT]P3?e9`0fn2Z0=cM/`3oonX0oogh0?omm03oo^00dm:V0>3S[P2NXFP0
e=fN0=KOWP3>fiH0b=NB0=3TW@3AiJ00e^ZU0=KTYP2m`8L0`<:309:GE02IX5X0KgHc09fQKP3Ef:T0
h>:a0>KY/P3Ifi`0a/Qo0=;DT`3KjJ/0d^2R0<6jQ032YgX0]Y=Y06A<7P3HhZH0d>:T0=gWZ03AgId0
dNJU0<kWY@3:hil0dnZR0=G]X`35fi00g?2X0>7`Z`3>fYX0j_Bg0<SBU@2]]GT0VImQ0=SJV`3DciL0
Yim`0?oog`3oon<0GEhf04E>5`3Yo:d0a=Z80=7PW`3QlK00Sj9P08^NG01oTU00cn:P0=;RX@24T500
O8I706ae=P1`O3`0W[Me0<[SX@3Km;00bnBP0;cET@39iil0cNfR0<W`X@3Bnj`0_^fL0;[WUP38kZ40
a^bO0<SXW03;jYh0d^jQ0=;]X03<iiX0eNnU0=?_Y03>k:80_MVL0:C4W`2:_HD0d^RX0=;KVP3KijD0
coF/0=_PWP2dWVD0RULZ0>ob_@38fZ00ZZa]0>7VYP3TlJ`0d>6K0=[aZ`3FkJT0b^>Q0=[c[`34gYL0
e^jT0=WZY03FdZ80f]JV0<O3T`2ETf00hn>_0=GHX@3LhJL004h0h>Z^0<[FUP3Dhj80enZX0=Ke/@3E
l:d0dmfP0=3AU`3PilD0kO??0?Gke@3Uk/<0loc?0=OU]02kdY`0d>^f0<;Y/02WdYX0_>Rc0=_oe03Q
om@0gO[:0=[f_03EkK40c^:U0=?NYP3Gh:/0h>6e0=KDZ`3Ng;H0f=fd09BVM01]Q4h0Xkb30<KKX03J
jJh0/;5h06eZ<`3FeIl0f=^T0<gEW03KhJD0DEHF0>kc/@3HgId0fmjU0;BhQ@3NhKH0cM2U09NNJP3Y
lKH0gNZR0<oTU@3SnZX0`]>?0=o]/01`N4D0fn6a0=GKZ`3@eZH0h>V`0=KPX`3FhZ00cnBQ0<gVY037
h9`0c^FO0=S_Z@3=hYd0QIUD08FEE03Fi:L0gNR^0<[EW@3=h:P0e>N_0<G>U@2:SeL40?l00010099b
?`3IkZ/0c>6N0=WTZ03QjK00i^Rg0<W8W01NF3P0mo3D0?onk`3ooO<0l^WP05M?C01nMW@0ooGo0?og
o`3?]kD0lmg@0?O^a`3Ng:T0d]ZO0=oc[P3HkJP0b=RJ0=COY@3>eZ<0d=NT0>OY]`3<bIH0Oe@Y06a:
6P3Ni:@0emjK0=cNW@34eHl0bN>J0;gRTP3=lZ80bn^R0=C_ZP3>ijD0d^NT0<7ET034fI@0g?>]0<SQ
X03KmKH0dmnO0=;KVP3Ni:@0c]>C0:BYJ@2LWUl0U9IG0:2PHP2LW5h0[Za_092>D@2]X6`0[im/09f?
GP2RVfL0Ti1I0:f^M@/0oooo000:0?ooo`X0oooj0?l0oook0?oln`3on_l0oo3j0?;Oh`3Od</0oooR
0=cS^P2d`8h0b]:S0?oofP35c:00Tje^0:g=WP0XB240SJb00;K=U@3;eY80_<:209RJJ@2X[g`0a]6I
0:>cLP3BeJH0jNGJ0>kSh@0L0000Qde10=nZYP2fT8L0kN[90<kDZ03Zgld0imSA0=cCc03hkNL0m^WS
0>gMg@3ci>L0o_Sl0>OSi03Sh=40ookT0<nlTP2ZWVX0`lnA071gC@001P00fN6X0=_QX@3EfZ@0k?2m
09^RG03Fgi00g>6Y0=CNZP39ij/0dnbe0?7oe03Zn/d0f>Zj0<KRY@38ij<0b^ZO0<gXX@3=gj40C5DL
00H6001LNcl001@006mgAP1UERl06b00000:003Di[h0X:B303Lm6`1;DBl0Yiio06U;<`0h<0`09B40
06]I<`2KSfD0fMfZ0<oSYP3RgjP0Nga208>?C@3HkZ<0`]R?0=k^[@3BhZ<0eN6O0=[UX@3Qj:D0e]bN
09JIHP3ShKX000P00<CIV01[Eb@0g>:V0<oXYP3>k:H0d^6N0<SDTP3IiJ<0Zk1^0=7PV`3?iId0a^2F
0=7YW`3Cij00bmbF0=oZYP3Mhj<0Vi]M0:^YK02XXfT0^kEk0=WMX03>lZP0a^ZP0<W[X@3=kjD0a^RN
0=g[X03Ji;00S9EZ0<oFZP3LiJh0d]^T0=cR]P3nonH0oooc0?ook`3Ti;h0oooD0=CGX02FVf40hNbZ
0<G@S03GiZ40f>VS0=K/Y03Cj:<0`mZD0=CWY@3YlKD0d]RH0>7[YP3NjZ80d=^G08jGGP23S5D0VZ9Y
0=;JWP3Ih9d0e]jC0=[WX@35h9/0an2N0>?TZ`2GPU<0ZhYO06==703GhJ@0eNRX0:NbL02LYfD0bmjN
0=K]Z@3?iZ00cN>J0=3VW@3GkJ80cN>H0<kRVP3AiIh0c>2K0=O[YP39fI80g>NS0=3IUP3]k;@0i^2`
08ElF`1_JDT0dMNY0=CRY`2me8@0fO2P02@`002DX600dNBR0<SMVP3IkZ/0SZEQ0:_2OP3PmK80bMbJ
0=3PW`3CiZ@0VkE^09:[I`24VeD0cnJP0=;/Y@31gI<0foZ^0<[/W`30iiP0^nJD0<ObX034kIl0a^bO
0<[/W`3:jYh0aNBF0<kZW@38i9L0c^fO0<KUU`3<kIh0c>^W0<kaa`1i/7T0_=ZN0=cWZ`3<fiP0^NBE
0=_PWP2eW6H0TUde0<c@W@1EKc80enZX0=K/Y03;ii`0e?>W0;oQU`39jZD0`^6N0<c[Y`36iYd0b^VI
0<KNU03Ki:d0gnJ`079k@P3CgZ80d^2R0=CTY@2mdXl004l0d>NQ0<?MUP3Dl:H0b>JN0<CXXP30gi/0
e>:T0=cRYP2d`I<0dmn_0=CN[03DgZT0en6/0=?PZP3Cj:d0c^N]0<;XZ`2jhjL0aO6f0>_og031h:L0
bNR/0<GRX02ZaH00Rj9N08ZJF`2R/7D0];b=09>JL01[KdX0`<FL0;K8U03?j[<0YlV=0<c[[`36h:<0
kOFl0:f]M`1nOdH0VYmU0=[UZ@3Hh:@0hnVY08nHE@2>Ue@0f>2T0=OPY`3Ggj`0f^:_0;G1P`2[^780
bn6?0<k[U`33iI40goZc0<GNW@25Uf<0fNVh0?Soe`3iomP0b=bQ0<gSX`3Il:`0anJP0=3aZP34iY`0
anVM0<GUV@37ii/0`=nC0<gYW`36hIX0b>>N0<kWY@3Dk[40_mNK0=?QYP2e_h<0eNBS0080o`000340
Hd`F0:fBG@37gYX0eN^Z0<OKUP3JjjL0d]fQ0>;[]02PXGL0]kBA0?omi`3Xh]80fmO;06QSG@3oo?L0
ooWo0?kYn03D`;l0ooSZ0?oof@3oom<0fNNZ0<_RWP3?j:H0e>F^0=CQ[03QjKX0f>2_0>?U/`22Od`0
NU4U0?3BWP3@fiL0fnRR0=CNU`38hYP0eoV/0;[VV@3;mj`0_NFN0<K[Y@35jJ<0`n:L0=7`ZP3=kJ@0
`nFK0<[^Y037kJ80c>JO0080cnBO00h0dNFP0=?WXP3Bhil0h>n/0=WUX`3BgY`0f>>Q0=WTXP3Afi`0
d=ZM0=kZ[03<fY`0e^JW0<kNW`/0oooo000:0?ooo`1i0?kQi@3ojnl0on__0?oUj@3jgN40onKZ0?of
nP3oin/0on[^0?ofnP3omO@0oogf0?ohkP3ooO40ooGP0<[1XP37bYd0g>Ba0=;OY`3HhZd0cMFR0=KO
/P32g:d0^N:f000A0033g:<0cnFU0>cc`03gl]80k]oH0<W7^03Eg;/0e=fT0>;S^`3onN/0oogc04X[
5`188P/0n;bd08eLC@3PiZP0fNVP0=oP]P3ekmT0mO7V0?omn03onoL0oo[j0?okn`3ooOd0oook0?oo
k@3oo=/0i]bW07ed>@2f^H00Si5/00L7002h_Y00]Kj509^TK`2X[gT0PHLo07Mn;P36aY@0RhIL0;2M
LP3B^i80eKBA0;fMM`2oY7T0[imS09nDDP2UW5L0X9EE0:^FH@1jFb`0QF4a06=M8`1kLS/0V85?095V
?02bUF/0XY5S06EG:P28K4D0Gd4M06]E<02i]8h0ZY5b089jD`2ETVL0ZY]`07M_@01iOTP0Nhm@09BC
F`34aH/0X:UX09b/H`34dH/0X:Y[09bVJ@3Efi/0bLj<09:BDP3ThZL0G5HR0=K<Z00B5@00b]nN06AC
7`3DgZ40anJR0<?YX039gYT0e>RS0<CET@1eOS/0b]jG0=;/X`020<WYW@0:0<[XWP3<j9h0cnJN0<kR
W@3Cgid0e=nM0>K/[P3>dYD0=T800<;]WP<0`nbN0?l0aN^N0<ORT`3EkK<0`MBV0?SofP3fom40n?o@
0?Sof03aom`0c]fn0:2`R`2ibi40YK1f0::/K`2:U5D0i?>^0=k]Z034f900iofd0=K]Y@3=ij00d>ZS
0<[SW`3@hId0f^^T0<[NUP3=hiX0cnJN0<[QW@3Hkj/0[/=n09b`J@2M[VL0goJX0<O/WP2kl:00`?6R
0=CYZ031`8P0[9YX0=;5T03Ojj/0bmnJ05AM6P3OiZ<0gNRV09VXI@2^_GX0J7Tc09^/I@2R^6d0b>>D
0<k_WP3?lZ80a^^M0;WNSP3JmjD0c^JH0<cRV@3FhJD0h>Vd0?Ckc`3eoLh0c]nX0=S^[@3GmZH0aMf?
05IH6@3RijL0c]ZH0=[[Y`3:giX0eoF]0<g]Y02kgiD0`^JL0<S/XP3;jj80g>^V0>Od[`3Hhil0ZkIb
0<[ET02LYf80W:US0>;dZP2oe8T0dNNL0;OAQ`35jih0_N>F0<GWV`3<k:40b^VM0<c[W`3:jI/0`>6@
0;oRT038kYT0c?6T0=Woc`2PgjP0`>^f0<WV[P3Bl:H0]n^F0=oUY@3TcY`0ZWeF0<KCV`3Hok`0`>ZP
0;SST`2liY00cONS0<c`Z036i:H0a=^U0=K[/`3:gZ40Oi9303U<001UO3H0C6<M0;SDRP3ClZH0d_>T
0<_/V`3?lZ00bnjL0<[]V`38jiT0`>:E0<gWZ033fid0f>Z/0=7QXP3=hYl0g_:]09Z^I`1UMRl0i_N`
0<SITP3?iid0d>ZQ0=Wk/@2jh9L0_mnN0<cJY@3PjK@0d=ZN09:QG01YNc40d^NJ0<gXV@3BkJ00d>jX
0<k]Z@34fIh0cm:M0=?GY02gaXl0RZ=Z000C001lV5h0c=VQ0<O<UP2_[7D0FELN0<W=T03Dh:00bmnJ
0=7UWP3EjJ40BEdH04aQ803Kkk@0e>R[0=3VW@24VdT0anB:0<SZU03<kil0d_2X0<COW02AZFl0c>>]
0?Koe@3eomH0bN:X0<GQY03=jj/0cNjY0;cMUP36iY/0f?R/0<[YV@38j9D0d?2M0<c[V`3;k9d0cO2P
0<KXV`31hJ00I8960>[o`P1gRd`0c>FQ0<7UV`2ifI00hMFK07]Z=03;jZL0b^RX0<c]WP34iY80c^ZO
0<KOV`3Bhj`0[[b;0?koi03Vk=80cmC00?kon03noo/0ooco0?oko`3on_80/:^G0=OP/@3Bi:X0d>RZ
0<c/[@36iJX0mOoQ0?GohP3kon40j_G;0<C<W@13AA@0JTXK0?OPZP3IkJH0c>:I0<cQUP39kZ00eonc
0=;^^`3Bj;X0kOo<0>Sma@3Gjk00e>RY0=3SX`3Qm[<000X0b^2H0=SaX03;i900eoRY0<[_XP36j9`0
b>ZN0<KXW037ii`0b^RN0P3<j9h20<gWWP060<_o[02ckIH0/nfH0;CXU@30l9`0[mZ82`3oool000X0
oooo203ono/0L@3olo<0oo_k0?oglP3/j=`0ooo/0>cTc@3DbZH0EE4T0=gU[03JiJ/0ioJm0?Sod03S
kK/0emnf0=?/a02;^8l002H00=ke_@2neiH0m?_B0?ooj`3omOl0n_We0?cok`3momD0oooS0?ool`3o
oO40?bL?03LL0@3OX9T0L3/Y0=7MU@3Cji<0e=^X0>c[c`3ooo@0oogj0?oim`3onoX0oo_k0?onn`3j
noD0h^C<0>7S_03Mf9h0F5@E0<k>VP3[j//00`<00=oV_@3HhZh0gnVd0<cGW@3FhI<0SYM60=gMZ`3Y
j[h0e]^S0?oocP3NeZP0hMVZ0>gZ]@3Nj:40c]b?0=GVUP3Jj9d0gN:R0=?>U03Me9T0e>FQ0>7e/03K
hJ40gmBL0>3NY@3JhZH0cMfO0=OLXP1SH2T0dLjK0=SGZ`3Zfk@0clRL0?Ga`P25NT`0G5TV061X;`3i
old0c]6H04e>503Fgih0JGT`08NGD02DWUl0>T@70::XJ01DFAL0I6@T0;FeN@1KF2<0Z:1k00@5003G
hJ@0N5`/0>SY[`3Jl:l0g?Zd0=c[Z03KijD0g^VW09^MG03Tkj/0_]:;0080b>ZM0P38jYh01`3:j9h0
an6J0;c@R`3Bhil0c]RI0>?/[@0nC@X00P39jIh20<[XWP1M0<cXWP37ii@0bnBZ0<oW]`3eomP0ioc3
0?Goc03dom40lOoI0<;G/02L]8@0foB`0=[ZZ`1IIbT0R9MF0<[KU@2kc8H0fNfU0<3FS@2J/FT0_]RA
0<kWX`3@jJD0dNNO0<;HS`3NmZ`0f?:Y0<[VW039iI/0dNfS0=_e[032fY00c^BK0<;MT034ji`0]>^H
0;S_WP37hYd0eM^O0:fRK03^ik00d>2O0>7f/@1DFaP0e]^I0=?NVP3Ch9/0h_6/0>Gf/03PlJX0XkU`
0<cWVP35iYL0`nJF0<ofY@37kY/0f_ZW0<cYV@3=iid0iONi0<KEW03_oLP0nOoC0<cRXP3?j:@0bNRJ
0<gUV@1FEQP0g^2Q0=COW@3@gi`0c^>N0;SFSP35iid0doV^0;kWV`31jil0`NNL0<oYW`3<i9X0en^S
0<GIT@3Sm:d0bmbE08NKD`33fI00k?nj0<?MT`3FmJT0bo2R0<CYV`32hYL0cnfS0080b^JL0:P0bnZN
0=?dY@3Am:80`NNB0;cQU03?ml80Um6O0:kL[P39k[X0_^BG0;caV@3WkZ/0JeLT07=<9@3@hZH0^^:L
0;SNU@3HoJl0_n6;0<k^V`3CjJP0f>Vc0=GM]03Gg[80h>Ba0:jaJP3=eHX0cnFM0<SNU@3Dk:00aN2A
0<cYU`2nfhT0b>>B0;oJR@3@jIP0a]f?0<WSV@3AmKD0`^FU0<_YZ@3^olT0g?BZ0=W_YP3:h9D0eNbL
03eD103CjYX0fO6S0=G`X@3DljL0_=bA0<KUXP3:hZh0/l^G0<WRZ@0cD@/0V;I/0=3_X@3>l9T0b>ZC
0;kPR@37ji<0bNRH0>?f]03Bj:X0aNFV0;SPX@2nl[00Mj]Y0=;o_P3IoKd0e^b/0=ob/P20Sd`0d^FS
0=7VX@3Ejj<0amfD0;W>R@3;hJ00ambQ0<[PXP3FkJD0f?6P0=[dW@3?j9L0fO6W0=3UX03Plk40Gfdb
0=o/]03kom80nooC0=3QZ`3@hj/0e>V`0<WMX03GjJ/0cMfL0=c]Z@3Di9/0e>BI0<SJSP39gY40d>JK
0<CLT03=iI/0fOFh0;oKX02kdI<0e^Z[0=;]Z034jYl0f_bb0=W>UP1iJCD0a^JW0<?RYP34jiX0aNfG
0<W/W038iYh0d^RZ0=3R[P3Xm=00mOkS0<oG`P2i_kD0m?Wc0?WhoP3jmoh0oood0;JfWP3Fi;40d>FZ
0<SUY@3:k[40b^Zh0?GojP3ionl0io;D0?Cog03/m</0Z:^006A36P3WdJ00dnRW0=ca[03Tn;<0`>6J
0<OaY`2ee:P0`]be0?7of`3TolP0`]^Q0=[d]@3:i:L0^=:A0=Ob[@33hi00c^nF0;SGR@3@kZ@0foN]
0<7MT`3<j9h20<gWWP@0cnJN00H0^NBB0;;TS@2ehXl0bNjN0<?TT`3CkYl;0?ooo`002P3oool0103o
mo`0oo[o0?oin`3on_`20?ojo`1]0?oko@3on_l0oo[o0?ogn@3oo?/0nOW]0?ooiP3alL/0h>6U05IK
6@3<fiH0cnBQ0>_obP3eomX0lOgI0=_VaP3@i[l0P[::0=_oi@36g;D0do6m0>Ggc`3oond0ooGo0?kn
o`3iool0ooo_0?oomP3nn_L0ookh085bG@0E2P00YVIW07e3>03;hHh0_N1l0<cMYP3NilX0n_oi0?on
o`3oo_d0oogk0?onn`3joOH0moo`0<kJ]P3Fh[80e]jE04]>1`3Lejd0c/Vf00@2003lonP0ho?60=O[
]P3:gZ40h_FS0>OiX`1VKCX0TYY[0=CZXP2;WUh0f>>[0=WT[03QlK<0bNFJ0=3cX@30j900a>ZE0<CP
UP3?i9l0E60N09B[I@34j9h0anVO0<cSV`2HYF00cn2J0<K/W`2mi9D0eN2K09FJF03Fh:@0h^b`03hl
0`1hLc/0g>:V0=7MW`3Pk[00bMFE0>;a/039cI00e]bL0<gXV`38hYP0dNRT0<CIV03Ci:00gNbW0>Od
[`2>V5T0d=RO0=_M]@002@00fNn^09R;EP3Ej:P0annX0;[]X0020<__Y@040=Kh[P2=Y5`0anVM0;_P
T`80bNVM0`38jYh01P3Dm:/0d>ZS0<oVX03=gI`0RiYI0<[KU`<0cnNM0P3@iYd0o`31gXX0]/jD0?Oo
fP39fj/0fNZc0<SJW03EjJh0_LnO0<gU/@3KmkX0bnRF0<kUW@38gIX0e>VT0=?YX039giH0AelC05=[
8@37gYH0hOZf0<_TX03=iZ80_]J<07>;@@18HQT0`mjG0<_VW`3ElJH0d>bO0<ORU@3>iY`0bn:J0=K/
Y02ebh80`>FG0<ceY`3=ij00gNNX0=SHW03KhJ<0cNNP0=?_Y@3EgiX0cm^C0<SPUP3@jZ00g_R^08FK
D`1RLbd0hO:/0=CUW`3Dj:00f_2X0<7HT03AjIl0bN6G0>;i/@3Nn;40`=^H0<WTW`3@jj@0a^:H0=G_
Y@3KljT0TZMR0;k?R`3>ei@0c]VE0<_LUP35fi<0c^RO0<;RU`31hIH0doFY0<[/X034iYX0b_2S0;o`
WP2ljiX0`^fM0;cWU`30jI/0`^RK0<[`X`3?n:X0ao2R0=Ko/P2bfh`0b^^L0<3OT`35hIL0e>jW0<?L
V03GkZX0c^NS0<o[X@3>kJ40a^NH0<OYW@3Poll0fooN08ZfU@2/fJh0b?VW0;o/T@3QgId0Ie4O07aQ
=P3@hj<0d?:X0>So^`3BkIh0e>ZE051S4P3VkkH0j>g40?ooj02<R6/020@00=OFUP3LiYl0_n^L0<;a
X038n:@0_NfG0;KTS03?njH0`nZI0=cn/@2lei00f?:[0;[GU02fhZ<0_>RY0>Ood@34kJ/0e^jT0<;M
T03;j9P0bn^F0;SJQ03=kiT0bNVD0=?`WP3Gk:40b=Z@0=KXWP3GkY`0d>NE0=CYVP3IiId0eMZH0>[Z
[03XgjP0mNFb0:>=GP1]DRL0IU8P05ME602DVU`0gnV]0<KEVP2hfJ00]^:W07V`K`39o;X0_]JH0>Oa
]02JUUT0GF`[0;oFT03:hIT0`MN?0>Ci^01LKS80cMjX09:PJ`3Agj40f^VT0:>eJ@3DiIl0`M6@0=OV
X@3DhI/0a<j905IP6`3LiZL0fnJZ0<kKYP3komP0kOg@0>O/``3[k<80I6<e07UgA`3Sh:/0EeHN0<g>
TP3Wjjh0am2A0=[TY`3Skk40`m6L0>Kd`@002P00IW4g09>XI@3BlZT0do6[06]K9`2fXG80i?o70=Sc
_P30iYT0b_BP0<OYW03>k:80eNV/0?Woe03Rk<L0i^c@0=7F`P000@00m_Kd0?koo`3nood0ooo/0?oo
h`3@hj/0dNV[0<SVZ03^omd0lOoV0?Won@3oo_l0o_ok0>cbi03oond0oooZ07=:=P1SA2P0U9eb0>;Y
_@3Ef:d0dnBh0;_EZ03Qil/0o?cR0?oog03eo<T0fN:]000800022000Ce@[05=K;000200S;@00b=>?
0<;WV@3:mjH0c?VX0;[WUP31kYd0_nbK0`31kYd20;o^W@060<gWWP3@hI/0e^>N0;o4PP3ZjZX0IelQ
2`3oool000X0oooo00<0ooKj0?oko`3onol00P3onol0:P3omo/0oo_o0?oio@3onol0ooGi0?omo@3n
ooH0oOoS0>SZ`P2e^WP0C5H=0=W^X`3>iIl0g_K40?Ooi03honX0c]_10<kS^02;_YD0NZ^;0=?Zc@3=
k/<0dnc20?Koi03olO/0nooo0?Soo`3oo_/0ooko0?gkoP3oo_/0]:RH00`9002VIFd0T5=>0<kWT`3H
oYT0dnR`0>Sef`3ioo/0moSj0?_inP80ookk04/0nOoe0?Wol`3@h;T0e^B_0<kKS01XL2D0XYeg085k
K@0G50l0m_oW0=k_a@38gjT0cNFW0<OOR`3?hh`0YZik07N3D`12FPh0]/Z5082>D`3Sl;P0amVM0<;P
UP3>lj<0`>bE0;oVT`34i9P0bN>J08NCD`1mSD`0an^S0=?i[P3DlZX0][ml0=SUW`3;lZ<0]N2>0=7K
U034aH40cMbI0<_OVP1<BPd0ThmB0<cHUP3?hih0eNFT06E_<02Q]780hNFX0=WOW`3DmJH0bNVM0=Cb
[03BkJX0fO2Z0=;XX03BiYl0SIeL0=CRY`36cj@000X00=7VY@2UUF40e^JW0;oWX02ik9l0anfR0<c`
YP2ohIL0P9YA0<SZWP3Io[40c>RM0<[YW@39jIh00P38jYh01`2mgI@0eo:[0<?JU03KkZ`0/l:10=GY
Y03<j9d00`3=iid0o`3?iid0f?BP08RMHP1fR5P0Xk220:ZgO`2EYFH0c]fR05i_>`37g:@0d^^Y0=7_
V@3>j9h0c>>M0=C^Y@3Cjj40dNVM0<WQU@3Hl:@0iObd0;oHU02nei<0hORd0=K/X`3CjJ40cNBN096Z
IP2E[fP0ZlEk0<[UUP35gHl0f?2V0=S^YP2__W/0[;Ia02e5002O_W80dNJQ0<SATP2c]7P0FF8S05mm
<`1]SD40f>FM0>3`Y`3>kZ80anbN0;WIS@3CjZ80_M6:09^ZI@2R[fX0d]fI0=STXP2?W5L0QiIA07Z>
A`2DZF@0c>>O0<COVP3Elj/0`n:D0<_ZVP32fX`0dNJK0<3?SP3KjZT0fnZU0=GVX02cbH40W[Q_05ij
<02C/FL0Y/Aj0<?QU`3Hm:X0`mfD0<WYWP2gj9H0^NRG0;WTU02oj9T0c?:U0<[_XP2oi9L0YL]n0<[`
X`2jhiD0eO^^0<OTU03;iiX0foF/0<GLUP24VeL0N8e<086GEP2leXl0d>bR0<WXW036iYd0h_o<0>go
k02YckH0]nFn0;CXU@38ki@0e<Z<05]44P29LTH0b]jI0<;PUP37gYP0amnA0=CZU@2AY580gNR`0?Cl
e@3fn>80in[?09^MN03Xk[00c]jG0;_WVP37mZH0`>nN0;3PS038lj40_nVG0=3`Y@3>jJ80eNNY0<OG
V@3QlkT0d>fe0=Gd^`3Zom00`^JX0;oFSP3GljP0anJH0<[`W@33jI@0eonY0<CVTP3;j9P0dn>J0=GP
V`2KYE`0dnN@0=W]V02DYED0h^VV0>;SY`3Kf:40Ge8U03h]0P1UC2@0R6a50:bFI`2ZYVT0G5`N09BC
FP2RYFh0gOJo0;[QZ01m^7P0^o>b0=3XZP3Rj:`0JEXQ04YD5@3AiZ40d^RP0>_o^02mcHl0R9MN0=KR
/P1fOe00en2Y0=GOX02Y]W00EVTW0<gRX@36fY<0e>JL0>gn/03<gHl0]/N00=WYZ033eJ40mooJ0?Oo
g`3iomd0kno=03Dc3@1mNE<02@H00>3N[@2^/G`0OX==02Xc000J9`00=4<:06ihAP2BV6P0@4<>03i1
2P3;fiX0cNRQ07VDD@1^FRP0dKV;0=Wb^`3]om80`nNM0<_bX@39jId0d>^T0=CVZP3gom00e]bh0?ko
iP3oonl00`000?ono`3mooh0ko;[0?oojP3Hg[P0a]RN0=3XZP38i:L0k?oJ0>koiP3ko?l0oo[o0?[i
oP3koOX0n?G/0?okl03b`k/0ooGV05YK?02n_Ih0o_WL0?Omh@3fonH0oooZ0?ooiP3Lh[@0d]VU0=7J
X`0>5P0000L00;o5X`002P2b^9@0TIUV0:beO024Y5T0/]^<0=3iZP2hhI80bOBT0;gXV032kId20<7^
W@80_njM00H0f_6[0=GTX`3EhJ40i>R[0>?SY`2SWF<;0?ooo`002P3oool00`3Xmn@0mook0?Ooo`02
0?Soo@0M0?Woo`3bn_`0nooo0?_omP3ioo40i>oQ0;[</P3Bf[40dm^X0=KUX03Ci9d0e>^W0<GOXP3X
o=T0n_ob0?con`3Ag]@0a>2j0;[`cP0cHTh0io_`0>kol@3MlL`0nOoQ0?oim@3fo_l0mOoo0?Wgo`3o
oOl00P3oo_l0F03Ke<`03`l507e6C03?WI@0enfR0;_PP`3?k;@0fNk=0?7olP3kood0o_om0?[hn`3m
noh0mOWh0?Won03Fil<0cN6/0=CYVP3EhYX0M6e@0?;[h@030000nOof0?OojP3Km/<0c>VY0<CPR@3G
lIP0dn:[0<gNZ03Gl9l0d>JK0<_KW01cQDL0T:9T0=3[Y03:j9h0d_RU0;kUTP2oiYD0a^JK0=[TZ02d
_800bnBR0<_YX`3Hljh0`<F509bQG`3EmJT0ao2Q0>OaZP2n`G`0d>JK0<GVU`1`LBl0IV4Q0=;QW03:
hIT0`M^D0<KETP2`bHD0PX]<0;_6Q02nhi<0b>fO0<;TVP33i9d0c>bQ0<GUVP35hiT0PIaG0=;/[@38
gj/000`00>;QZ02_Tf<0UI=J0=WYZ03CkZL0dnBP0=OXY02IZ6<0RiAA0=GRW@3Kk:D0cNNM0<cXWP39
jIh20<SZWP070=3`Y`3DkZL0c>6L07n;B`38dY<0f>VU0<?/WP030<G[WP3o0<G/W@3Ej9L0h_:d0<WH
X@3KjK@0c=bN08ZKE`2O[g00FFP_0<kNX03Kk:H0YkeX08^QEP2oeXh0f_B[08^ZGP1lV4d0bN>I0=;Z
X03Cij80bMZF0=SXY`2P[f`0f>FO0<GBS@3Pkj`0fNbZ0<SMVP3CjJ40aM^@0=;TVP3HiIl0fNBR04a@
4`2MUeT0i>VV09fXI03;e9<0hN>T055B5P3Eh9h0`^:G0<k`Y03HkZD0an6G0;SRT02di900_>NG0<OY
W@3AkJ<0bMfH0>;a[P1XKRh0GV<S0=KHV@3Sj:P0dmnO06Qg=P3DijD0d>ZS0<3LTP3?ki`0^]N308nV
EP2:VU40eMnR0=STYP3:hIT0a=jE0<gYW`3;jIl0a^BJ0<[XWP3>jZ00G78Z0;O8PP3Ok:L0e>>N0<CP
U@3AkJ<0bn:J0=7WW`3JkZL0f>VS0=?TWP1GJb@0bn2K0=_`Z`3;hYX0bN:A0=K^X02AYeh0IW/f0=S]
[03Lk[00c^:S0=3VY@3Ck:X0c>NR0=7/Y`3AkK<0l_oT09nkXP1fWWT0[NZJ0<KUU@2[T5T0QfDg09V1
D`30e8l0anFK0<WSW03JnJT0Z<Yc0<[/V03Dk;00hoK80>gog`3aon<0a>2`0=ci]P3<iYl0d>2Q0=CT
Y@3EiJH0bm^L0=[VYP2GXV00XZ=W06QW;P25OD`0T8QI09F9G`2YVgP0`[ZC0=WL[@3CgJT0d]bO0<KI
U`3CjZ@0`NJH0<C^W039m:80aNZJ0<OVVP3NjjH0e]^K0;g2PP3@h9l0R9eL0<gQXP3Un<00b=^T0<SL
Y`2?Z6l0bN>V0<WTW`3BkJH0b>2D0=_^W`3]kJd0_[Uo079/>034iJh0_O2e09cJU`2_j:@0c>2Q0:>W
JP3Qgj@0gNR/0=k^[`3ChJ<0Hfhb096GJ@1gNE80Vi]i0=SI/@2DU5h0lO:f0=cWY@3GkJ`0FgPe0;kN
TP3<kI`0bNZC0<g^U`2B/F40aNBH0=Cg]`31i:X0`>F_0>Gef`3Uk]/0Y:V;0<gH/03@g:`0f^Rc06ao
B00`?@P0^lbH0=O^^03=jJl0e]b/09fLKP2KUfL0hn2]0=_PYP3@gZ00RiUK06aG:02XSfH0io;70?Wo
g03;j:P0b>ZP0<gYW`3Aj:80d^:T0=WT[03Be:d0jNS<0?ghi@2GSH`0HeQN0?Ofm03oooP0m_SP0>O]
b@2=VV@0f>Z`0<gPZ03hon@0nOoa0?_eo`3on?l0ooco0?GcoP3onol0nnke0?C2b`3ok^l0ooo]0:jQ
T023L680ookc0?olm03Zm=/0c=fi0<3KY03Jn;P0_mjK0:g9SP1kUV<0?UPe000D024n7`2Xd:/0_Nc2
0<3NUP3Ikid0b]nB08jOF02`_g`0f^JX0=KRY03Chj80dNFP0<oVWP3?iid0b^VS0<KVX`39j:D0YlB2
08RUHP3El:d;0?ooo`002P3oool07`36hZP0g_7M0?Con`3fooL0mOoc0?[mo`3no_l0nO[d0>GW`P3?
cjT0HfY90<KXZ`3WmKL0dM^N0<WUZ037h:H0amn]0>kofP3honl0oo_o0?oio`3Zo_l0hooo0<_ol`1?
NW40mOoo0?Won03ooo<0oocc0?oln`3kool00P3dool0W@3jo_d0oooo0?ono`3onOH0AChf04T^7@3/
d[L0f^FS0<oUW035j:@0cN^e0=3V`03goo40o?oj0?omo`3onol0ooco0?KfoP3ionl0n?oQ0<kWY@3A
hjD0_;BO069IDP030000nooo0?SomP3MmlL0b^NU0<o]U`3;ii80dNFV0=7WZ@3Cl9h0d>bO0=3ZX`2a
bXH0TjQU0=?VY03Cij80bNFJ0<kaX@30kIP0a_2N0=[VYP3Ihj@0S9aK0=7UX03JjjL0e^:P09^WI@2j
eX`0f?R]0<;IT@3Dj:40S:1K0<o]Y@3Jg9d0X9ML0;blOP3?i9l0cNjW0;kMU`3?j:@0fn^Z08ZKE`34
gY@0foF[0=OaY`3<iY`0d^jS0=7]XP34hYP0SJ]U0<o/ZP3?kJl000l00=3LWP3ShZT0Vj5S0=KUY03G
kZP0c^FO0<_RVP2>Y5/0fNVR0=3JU@3HiIl0anVM0=7cZ@31ii`0`nbP0<_aYP3=kjD0c>>M0<cKV02U
YfP0g=ZM0=OMW@3=kZL0c>fV0<S/XP2ohiT0^MjA0=k[X`3?hih0e^^X0>Oo_@2gehh0_MfB0=GcZ@36
h9T0e>>P0>7/Y`1bNS40fnBQ07:3?`2E[6H0anNL0=3bYP3:i9/0d>JN0<cGU@2Z/700TiUI0=KKV`2k
_W/0`<N409>LF`3<fiX0e^JW0<kQX@3KjjX0T9UF0<?8QP3:c8/0eMFE0=WPW@3GhYh0bmJD0<35Q@3P
h:80V9YK0=[PX03<hid0e_6Z0<_[X030hYH0d?:U0<?XVP33jY/0a^fN0<3WV038jYh0b^RN0=3VWP3C
i9h00P3GhYh05P3LkJT0P9A?0=O/Y`3=i9h0e>^U0<_SV@2`b7h0cnFL0<cPV@32dY40h_:a05UX9@2@
Y5l0e_2W0<;PUP34i9P0cnnS0<GTV03Ejj<0UJIR0=_TX`3Dh9h20<[YW@80c>RM00@0cNNM0<OQU`3>
j9h0d^jS0P2kehd0N@3Im:L0dNND0=7WU@3@iiT0d>JM0<oVXP3>hj80eNVZ086EF038gZ00g_:g0<oU
Y@3>kjP0]n6Q0=GW_@2adZ<0ZOZ^0;kSX01fCB40ZgYA08MV>@2kf9D0annV0<7FT@2@]FP0]NBC0;oZ
VP3Bj:L0d^BX0<cX[@30h:40`nJT0<GPV`3HkJP0g>JW0=OQY@3Lhjd0OhIB03m7300X<@00TYeI09>P
F`3EiJ@0dn>U0?OocP20OEX0CdlY092CIP2IX6d0ZYmY0=cLX03Fgih0b^JK0;[OS`37lIl0a^fL0<oa
Y03@gi`0h^^/0=_QX`2EZVT0bMjM0<oOX03BgJ40fnV^07^:C`3WoKl0^]2@0<oTX`3;gY`0d^>M0=W^
X@32_X40H5<O07e[@`2`gjT0PlF70;[RX`3Fk:`0lNFY05I<3P3EkjP0bmjV0<gJXP1NJC40/KB70=_D
`@2;PgP0TXaf0;jlT`2e_7P0aM240<OGSP37eY40WK5/0<[TVP36iID0]mN20=WfXP27XU40bNBG0;[J
T@3CnK00`>RQ08jTS`2]]jh0SiEa0=?X[`35giD0e_FW0<WYX03BfYh0fN>W0=3RY03>jJH0f^R]0=7J
Y@3BeZ@0i>>c0>3P[03MgJL00P3o0000@01YG300inW40?[kg03TnlL0bNFX0<_VX@3<hid0d>BM0=?T
X02_]h@0ko7<0?Kdg@3llo@01`050?oko`3mno`0oOk/0>S[cP0e?@h0RI=Q0=oX^@3nonH0o_oa0?ol
o`3on_l0o?oo0?_no`3on_l0ooSo0<FRZ@3olNd0oooZ0?gbeP21LEL0_KBU0?okm03ckN40j>[E0>Kg
b`3JlkT0b^FR0=O[YP3Pk[00TjIi08BRO00UIDX0HKBH0;khX`2jih00`nZ=0;gDS03Ijjl0KgE905MM
<@2CWF/0SiiU0<oYXP32hI<0`]VA0>Gj]@2U_7H0RZEN0<SVW036j9`;0?ooo`002P3oool03`35ii<0
b>:c0<kVa03DiL40ho;A0?coo`3no_l0mOGc0?oofP2YZWh0dm^d0<CTX`3Yk;D0jNNg0>KkdP020?Go
i00:0?Ooj03koo40oo_f0?C`k`3Lo_l0BW5f03aMHP3[ool0n?oo0?[ln@80oooj06P0ooom0?koo`3k
ool0nooo0?koo@3no_h0n_[j0?okn02MTX`06`d00;^_R@3:cY<0e^FR0;_OU@39k:P0bNB]0?Soi03i
on`0oOol0?kmo`3ooOl0no_k0?Wok03goml0bNJT0<cQYP3bkMT0Ee1600D1003loOl0kOC/0>Ceb03>
ijH0d>fI0<k[V@3;jJ<0anFO0<SWU`37j9T0dO6V0<[XWP2cc8P0fnZY0=KRX03>hYX0`MfB0;o/U`2n
j9H0`mB@0=[[Y`1;FQL0U:=P0=OVX`3<gIT0f^jY09>ZI034gYL0d>^T0<ONV01oR4T0a]JE0=Wh/P2j
f980O89408j8CP39a8X0eo2/0<G[XP3<iJ40d^JQ06^1>@2cbH00c^BI0=geZ@3Ak9l0d^bR0=Wd[@1l
VU@0bNJS0:g:RP0:9000bm^L0=CSXP1PJR/0d=bL0<cQW03AkJ<0_mjB08fYGP3EkJ<0e>2H0=GPV`3D
kZL0bnFN0<[XX031hIP0d_:Y0<[ZX@3;iIh0b^6K09ZYIP2KYfD0QYEB0<7GUP80d^VU03<0e^n[0=7[
Y03;fi@0b=jE0=cf[03AlJD0]]R;0<;TU`3No[80_=J<0=;SW02Z]g40a]6<0<gRW@3?jJ80an6J0<?H
T`3HjJD0V:5P09fVI@3<fiP0e^^V0<cWX031hiL0a>2E0=;^X`33hIL0FGPb092_J@3=k:P0c^fW0=;/
Y@36gID0QieD0<_QV03<j9h0amjH0<WMV03BfiX0[kAd0:naLP3@eID0g>RV0=S/Y`25X5T0@elE09R^
IP2O]fd0d>ZP0<_[W`31hiH00`36jid06@38jYd0bNVM0<[YW@39h9X0dNRR07F?B02neHl0dNRR0=K]
Y`25W5H0dNJQ0<GJU@3EjZD0cN:M0;kAS`3EjZD0e?2V0<g[X@32hYH0b^ZN0<[YW@3?iId0RY]G0=KO
X03Hi:801039jId0OP3:jId0aNBH0<k]X@3:jId0c>^O0=3/X@32hI<0bN^G0<[ZU`3:jIT0b^VK0<cX
WP3;iI`0amjF03iC3P26VUD0d^>O0=3UX032kIh0_N^R0<oKZ@3UnlX0O/^70;OSZ02`RV<0dJ1h07IJ
:P3DlJh0_n>M0::^K032h9P0aO6T0<3YW@3JiZ@0f^>R0<oTW`37hY/0^MV@0=CXX`3FiJ80e^6O08nI
G02;TUh0iNbh0=7IX03OjJX0f>VR0=?YX03@jj@0eoBb0;oIVP3Hik00gnjg0<_KW@3KjJ/0j]VU05aF
703Kh:00cNFK0<o`X@3?mZD0b_6P0<;RUP3BiZ40io6b09RNHP3EhjD0hN^^0=7GV`2<SE<0KW8g09RN
HP3[nK/0f>RY04=?4@2EWf80gnRW0=7VV`27OTD0^jel0=3BX`2]dYh0]>JY0:O<R@3Jf9d0Q7@i096@
D039ij40bnBS07>8@`3QlK00g>Ja0?cki`2JV8`0i>C<0;2hQ`2gbW/0eNfI0<cTV037eY40Phm=0<[Q
V@35hIL0d^jS0<_WW03Fk:@0`mRC0<WTX@32hId0a^VU05]aG01]Mf`0VYii0<?KW`32ghl0`NBB0<kb
Z03JfJ00c]BF0<;CS`0`BP00BV0G04]L6022SE40OXI=069U;P@0o`0003l0fMbm0?ook03dom`0c>^_
0<c[Y`3;jIl0b>>D0=7YW@27UeT0cm^[0??jf03jo?40RHR60?gko`3jn?/0oooe0>?TdP3:cJh0a<RU
0?Kje`3oon`0oooc0?ono`3cl?T0nOoo0?coo@3omod0o?Om0<B/ZP3on^/0oooQ0?O`a03Ug;40SX]Z
0:VJQ@3omoT0o?Ok0?Gol`3[oNL0h??G0?3fdP3cl<d0lo?=06A`B02Pe:<0U=ZT00Y79@1o]YL0/^Bn
0;OOX@35jJ40a^270<cUR@3BjHl0d^ZF0>[o_P3:ijD0an:E0=;[VP39i9<0c>VI0<kZW@3?kZ802`3o
ool000X0oooo0;`0b>ZC0<STZ@3:h[00cNB`0>;eb03jooh0j^gd0?koo`3fo=P0jNk50<kI/@3<j:h0
d/fS0?[]c@3kon`0noo]0?Sok03_on80k?[P0?ook`3loo<0FH=e09Jh^P3`ool0h_7h0??in@3lood0
nook0?Won`3kood0o_oo0?ono`3oo?l0ooko0?ooo`3knod0oogm0=kCc@0=0000XIE_09nSJ03:fIH0
bN^O0<W]Y@37hjP0lOoG0?Soi03loo<0o_of0?[mm03`m^P0lOoL0?7oeP38ij<0a]jR0?oojP2WXiL0
0`000?ooo@3nooH0i?730<kRX`3<jIL0b^VI0<c]YP36ij00anJF0<[[W03;jj00aN>I0;3:P`3Pkjh0
e>2N0=;VW`3@jZ00dO^Y0<;YV030eI00f>fX04]L601lSDT0eNBQ0=KWX`3IjZH0B5dH0=[aZ`3:i9d0
eNZU0=7KW00<5@00doB]0<_cZP33f9D0F5<I0>GHX@3>f9T0`N2J0<7OV@3Hkj/0bMnG08RNEP3Snk40
`m^?0<gXV`34gY@0bnJO08BOF03Hlk00g_Rg0;K?SP3>gYl0c]fL04A>3`3=fIT0cN:M0<cXWP3>kZ80
^MR<04mY7`2CX5P0fnRR0>;f/@37fiH0bn:L0<oVX030fi@0bnJO0<cZXP3AkjL0bnJO0<oZX`3>j:40
=dX:06=f=03>hIl0e>NU0=7UX03JkZH0bn>I0<SRV03@kj<0cNbP0=KeZ@30g940dNVO061a:P0oC`P0
i_Na0=7/Y@3@jj@0b>:K0<_JU`3CgY`0hNJV0=OPW`3Bij80c^jU0<K_X`38nJP0a^nP0<?ZV`34ji`0
]]bA04Q^8`3EnK40]MV?0=CfZP37ii/0bnbM0<o_X`39jil0c>ZR0<_UWP3Lj:H0c=FD0<G:RP3RijL0
f^FS0=CSX03PmK00c>6L0;k?R@2IZV<0d>BL0<oYW`3<j9d0b>ZM0<K[W@<0`nbM01L0aN^N0<SSW03>
jJ80_MRA0>[o_@0M=`00GgH`08jUG`2ldH`0e>VT08JKEP1:GaX0j?nm0<WTW@3Imjd0`MnE0<?RUP3=
k:00b^JK0=;XX02M[VX0g>RX0<oPW0040<WYW@070<[YW@38ii/0d>nS0<o[X03;ii`0d^bR0<o^XP02
0<G/V`80b>^K07<0b^VM0=3/X@38hiH0UjeR02]0003CiI/0cNFK0;o[X037kjT0c]JU0<7CX@10PD40
`o2e0:B7G@2/PUX0L5`Z0<kWY@35h9/0UieM0<kUW`31jYh0a^RN0=kTY03Yjj`0f^VV0=W`ZP3CkJH0
c]fJ0=;MV@1EHQd0A50@0>?/]@3Cg:D0i>jb0<[FUP3IkJH0a]bD0<kYYP39iZH0a>6Q0=7VY@3=hZ40
eNZU0<SNUP3Tej80Hf4V0=GKV`3FkZ@0_mnC0;[OS`3@mJD0anNK0<?GTP3IiJD0h^Z^0=;LW`3MhjL0
dmBJ065O9P1JFB00iNV^0<SDUP3Fi:H0hnf`0<[BUP1DFQ`0e^JO061J803glKd0^lVD0=Se_`25Zfh0
d_Nb09RFF`2cZVl0gn>V0=GZZ@3AjZH0j?nb0<OMTP3QlK80o?oV0>W/f`36cJh0f>Jc0<gVU@35hhd0
d^jS0<kOV`3BgYh0dnZT0<gXX@3;iYl0cNNP0<KIV@3Bi:H0bMjS0=Wb^02if9`0FFeD07V2L@3Ifk@0
d>F/0<WSW03HmZ`0anRS0>gZ/`1GFb00E6DQ09F_I@3FkIl0e>VN0<_JV@3EhJ<0iNfb00@0o`0000d0
mOkO0?Cli@3aomd0anV]0<WZY@3:jYl0anBD0=7/W`23UeP0h>jk0<gI/@3eo>`0IfYS0080ooko02/0
oooh0?ool`3oonX0m_WN0:NZS`3oonl0oood0?OemP3oo_l0n_oj0?[on03oo?d0ookm0=6j/P3oo>P0
oooM0<c:U`3^jkP0T9IX06UQ?@3onoT0ooco0?Soo`3dood0looh0?_mk`3oo>`0jn760=kN^P28ZG80
_>b^08W2/@0lLfd0AgaX0<Kg`037mJ`0c?BA0<O/P`3>kXT0aNB60;SDRP3MmkH0f?BY0080c>VI00<0
dnnR0<WXW032h9H02`3oool000X0oooo06<0`nB=0<_XV03:iiL0bnJG0=S^[@3`on`0io;^0?Soo`3J
j<L0g^g20=g__@3Jl/80ooGQ0?obj03kmOD0ookm0?kon030c;P0W:f;08bFL`2oeZ`0?WM>0>_oo`3f
n_l0lo3k0?olo`3oo_l0l_om0?3on`3dood0o?oo0?oko`3om_l0ooco0?ono`3mo?l0oo[l0?oln00>
0000F4XU0;:bMP3_o;L0`n>G0<O/W`3;jZ@0a=jM0<CLX03Mkkd0iOG60>Ogb03Bi;80_]RK0<_ZY`38
kJ00b>NT0?coi03=d;/00@800=gIc@3oond0k_720=kZ[03?jY/0aNJG0<S`Y`33jj80cn^P0<OWV`36
j9`0bNVN0=ObZ`3IjZH0h^j/0<;AS034fY40`nFH0<W[WP3KnK40a=nH09:YH`2EZVD0d>BO0=OXY03O
l:`0a]NC086BCP3Pm:l0dnfV0<7PVP3OiJL0]KIj0<oOWP2mjj00b^VS0=[VYP2?P4T0UI1F0<g/YP2m
hiX00P3BjJ<0L@1/Q3X0c>BJ0=;ZWP3;iI/0cNNN08BNE`3:hil0a=fL0=?YZ03FjJL0e^FT05AO7@3K
ijD0d^NR0=;^Y030hYH0bN^O0<[YW@3Rn:l0^lb60=[VY03NjZP0QI1>0<?>S03ChYl0c>2K0<KTW033
iid0_NbN0;_/W@3<mJT0c]ZJ09BPH03BgY`0lOfk07=o?@2<Z5h0<Th40<SRV@3Ejj<0a]bD0=CXX@28
W5D0^Ln70<[PV03;hYX0hoZb0<WSW035g9H0d^NR09Z[I`2HZFD0en^V0=3UX02ogID0a>BK0<[^Y03:
ljD0eOn]0<S_WP39k9`0`^2F0=ch[P2AZf80e>jU0=7]XP33hY@0b^^L0<caX@3Iok@0c?2V0<c/X`3K
kjX0h>bZ09RNGP3LhZ80QI1>06Mc<@3MkZX0c]nK0<_JU@3Jij80iO:]0<gLU`3Fij40cNNN0<[XWP33
k9h0_njN0;[aWP2ll9h0]mV?0=7aZ03;jj80fON_0;_IT@33gIH0g?J_0<?JU03=hYd0dNJQ0<_UWP2o
iI`0_N6G0<GUVP3<jZ00cn^P0<kXWP3?iid0cnFM08NLE`3?hZ00dNRR0080b>ZM0P39jId0O`3:jId0
bnNL0<CPU@3>j9h0c^JL0<OOU@3<jil0_njN0<7^W@33k9d0aNbM0<K[V`3;k9d0_n2A0=km[`3;iiX0
Z/Ik06J;?P0aI1l0i?o50<oCX@3]mL@0eOc501U=3`3HdJ<0L5/`071_>@3>gI`0hNbZ065O8P3=gYX0
b>JN0<WPVP34`XD0QX1409fVI@29VUH0S:5L08:=B`2`^GH0e^RL0<SIT`34e9H0d>2R09>SI029VEP0
WK=[0<CKU@32fYh0dnbe0<;KXP3Ak:D0dnnU0<_WW03<jid0k^nc08jGEP19EA<0e^fU0<CPU@34hiL0
`n:F0<;NU03FjjH0enRT0=oYZP3CfId0I68Y06]V;P3QfZ<0knfd0=_LXP2>W5h0/<210=[VZ03Li:P0
V9UM0=;GU`2R[6l0bmnR0:30P@39hj@0`]^J09neK@1KI240h^Z_0=SOZ`3Khk00d>FR0<CPS03Gl9l0
dNNO0?Woi01hQ6`0cMjj0<gT[03<ki/0c_BM0<?UV@38fiT0SYeL0<kUW`37hYd0f_>_0<_QX03Gi:`0
c=JQ0?WoeP3Yn/d0mOoM09>RP@16CBh0Wi]f0<kK[@3>gjT0`mZR0<GNY`1IDR@0cljE0>Ke/03Pn:X0
fO6S0<oUVP3?hih0e>NU0=3SX`3FjJL00P3o00004`33fj40i?[C0?;ojP3]omd0c^bj0<OVZ`35hj<0
c>NR0=7/Y`2bah`0b=ZV0=7P]`3kond0j_?R08j>S03jn?T0m??a0?oon`3oooX00P3oooP0:`2VYYh0
inOO0??bk@3oo_T0nood0?kom03om_00n?CY0::=O03EaJ/0h^^n0<oEV@3Xk[00dnJT0>Sb]P2n^iP0
dm>g0>cii`3/o_80looo0?coo`3onol0ooGd0?okk`3oomd0VZ1b0<C`c02gl<d0^_C<06^UL`1=QTl0
Ulj;0:cNU`2ihiL0`>NH0<[YV@3@kId0d>VW0<_TX`3;iJ@0c>^W0=7b[@2cehd02`3oool000X0oooo
0280bnRH0=;_W@3AkiT0cnfG0=?]Y03Ej<`0mooh0?OonP3Ah[h0j?c;0=C//02nfZL0oogZ0?obkP3o
nOl0ooco0?oon`3Ni=H0e>?209bTO`3Ejk`0@ge=0:70^03inol0o?Co0?oio`3[h>H0mOom0?7oo@3b
ood0nooo0?olo`3om_l0ooco0P3oo_l0]03ooOl0oo_i0180001FAR80]KEi0=COV`39jId0b>fO0<[Z
WP3>k:@0c^VR0=G[ZP3@iZH0dNNW0<WRX039ij40doF[0<O/WP33i9l0nooT0<;;/00?4P00NgIS09ZD
O03Ri;<0f^:V0=?[W`35iYL0ao6W0<;ZX@3Fl:L0a>:H0<OYW@33hiP0d_2X0=3QW@3Dhj00TZ5L0:o3
O032h9H0eoN/0<[ZX@3Bl:P0c>JO08BKE@3MlJ`0c]nK0=;SW`3Wn;@0RiaH0<_LV037hY/0b_BZ0<KI
U`1aJ2l0[JQ^0<CXX032l:D0b_:Y06QR:01IBQ<0fo2]0=Of/032fI<0b=nI0:NoM@1nUT`0a=b@0<kV
W03HkjL0TZUS0=C[Y`3DjZT0c^BS0=3TW`3=g9T0CUTG0<kJV03Cj:<0`mnE0=CfZP2ohID0gO^a0<kU
W@2ld8T0iOJb0<_JU`1TKbd0b]>B0=gYY`3Ij:D0c^VR0<k`YP31l:80]NRI0;o[WP3Yn;D0/l9o0?;o
_P2lbhP0Tj9O0<CRV01PO380GWP_0<?GT03?h9X0f>VS0:FfL03Hk:D0bn:J0<WSVP35g9@0fnbX0=OV
X`3Kk:P0LHQ207>>A`2jg980a^RN0=?^Y`3FjjH0enRT0<SGTP2nf8h0foJY0<gUV@3BhY/0e>6K09>N
F@3CgYT0eNFL0<cNU03:gi@0`MfB0;kPU02kgI<0^mJ?0=CUX@38ei@0Yk9`0>3[Z@2GXf40SIaI0=7V
X@3?i9l0f^jW0;K5P03ChYd0h>fX0=?RW@3AiIh0cNNN0<K[WP32kIh0^o2N0;k_WP32iY`0dO>Y0<;T
VP3>kZD0^]R@0=7/Y@3:iIh0d>ZS0=;YX`3PmK00cnZS0=Go]@2/eHT0co6U0<;PUP39iIX0dNVO0<oU
W03@iYh0PiQC0<gRW`3Ajj@0a^^M0<SZW@80bNVM09P0b^VM0=3/X@3>j9h0a]jD0<GKTP3Ejj80foN/
0<;]W@33k9d0aNbM0<K[W@36jih0bo2S0<W^X@2TbX40b^nY0;kVX01NSDL0020008FLIP3Xkk`0c=:R
0?;of01=P4D0iNRi04e55P1NIRd0bMBB0>3WY01eMCL0cn2L0=3^YP3?iZ00W9YM0517303Gh9l0d>6M
0=7VX@3;eiD0j_Nb0=3UUP3>hYX0h?>c0<gPX01LKbd0M8Q30<OLU`35g9P0X[V10<kT/`3JlKd0b^:T
0<WRX@39i9l0anFM0=3IV02]^GL0EVLS0=7XX03DkZD0c>RN0=3/XP3>j9l0a]^F0<cPV`3BgY`0dMNI
05QH702BSE<0h=^Q0=GEV@2X[W00VJaZ0<WNV`3?gih0e>2P0>GY[03Vi:T0/lV90;gMW02N_Wl0eOFb
0<oXY022RDH0DFDN0=_V[P3@dj@0dMBY0;?5R`3BjZ00bMnF0<cQX03ionP0W:RB0<?D/P3@ijl0`>:>
0;oUSP3@l:D0enbW092QG@3DkZD0bnJO0=G_Z03<hIh0h^fc0=oX/`3aoLd0hO740>CgbP2]_9<0AT`V
09B?J@3Cg[<0iO;60>kodP3;hK00FE0U0>OV[@32dH`0bn>E0<[TV`3<hil0e^Z[0=CXZ`3Mlk<0iofl
0=;/Y@33gYT0h_no0=[faP3Fl/X0l_oT0>7gd03AjKT0b=n[0<oTZ@3@iJX0/lB@0=?S]P3EhKd0o?o_
0=OMc`2TYJ00ooko0?gko03oo_l0nOOj0?klo@3oo_l0emKB0;Rg/P80ooof02L0n?k`0?gom03oo?H0
ookd0;VTT`3[fl80d=^`0>;[/P3Afih0`=ZC0<WJUP2SY6P0bljE0>kmdP3Qm=@0h??M0?Koo03knOh0
ooWo0?oin`3ooO40YIj<0;SLWP3<okH0Zn2J09;9T01[XFl0LJIl08k1UP31kKX0gOo<0<k_Z03MoK40
b^6K0=CYY03DjjD0`>2G0<;VW03<mJL02`3oool000X0oooo0;h0bNBM0<o/VP3=jiD0bNJB0<[TV`3S
mm80e>K>0>gnj`35f[<0_=>M0<OUW`32iJ/0ooSU0?ojm03ooOl0mNgj0?oko03dmNd0h>W:08J7I@3>
g[407U@S05AhK03iool0o?Ko0?ogo`3on?l0nooo0?Goo@3dool0nooo0?omo`3on?l0ooco0?kmo`3o
o_l0oogo0?oclP0A0000Gdl[09ZHG@2JXf00dNnU0<GWVP37j9T0b^VK0<KUU`3=iid0dN^Q0<_UV`37
hiP0`n>G0<W/W036kI`0bnbU0=c/a@1fPF4000D00:2NQ@25P680dm>Q0=3FVP3Bj9l0a^FI0<OaY`35
jj80e^fU0<CNU@3CljP0a^JK0<k/Y03AiJ00e>>P08nNF@39fY@0a^2G0<_YW`34iY`0aNNM0=7/Y@24
WUL0eNZU0=WZYP36ei<0c=^H0=GVXP2eaX80e^fW0<;/XP38ij40/[1e07E/<`3;gY`0`>ZP0;WWW03:
e9D0]:]b05QQ8P3>hIl0amjJ0>3g/`3>iId0h_Z`0=K^XP3?iid0d^VQ092WG`36gIL0c^BS0<oVXP3<
hI`0eNJR069]:`3Dh9h0cN6L0<cVW@2mgi<0b>ZN0<OUV`3FkJD0e^bT0<OLU`3?hih0Qi=A09nZJ03M
j:H0dmnM0<KMU`3;jj80bOFX0;g^W`33kJ40`]JA0<kOV`3<gIT0TZ=O0=GVXP39jIh0c^ZP08BNE@3G
jj@0fNRS0:jmN02AXU`0d>6K0=?ZXP37hiT0c^RO09FTH@2IYF<0Q9=@0;oITP3InK00bNnT0<[^Y03;
h9/0cMJE0<;0P`1jM3H0Y;A]0;O<P@3MkjD0eMnH0=kSX03GfYL0e]^H0=_UWP3BgYH0ho2X09fcJP1d
T4H0SjYS0=S_Z@3Ah9d0gNVW0;6lNP3<f9H0cMjJ0<kSWP3;iIh0cnVR0<cSV`0_A@00L8@m0=KUX03@
giX0dnBN0=3VWP39jIh0a^^N0P31kIh05P33iid0aNVO0<7UV`3;jj80e?:Z0<gXX@38hi`0dN^T0=?Z
Y03:giX0b^FN0;;LTP3Bnjl0/mF90=Sf[035hIH0eNfS0<_QV03Ejj<0TJQR0=;YY@3;iIh20<SZW@80
bNVM00L0b^VM0=?]X`2leX`0TZYP0:VoMP3Aiih0`M^A0080b>^K0P38jYd0]P36jZ00a^bS0;WQV`39
m[D0a?:d05f?E01g[W@0_ONl0:BjR@2_]h@0e]j[0>Gea028^Wl0e>:a051B8@21SUH0d]^H0=_NV`2F
V5T0b=bG0=3^YP3DjjD0NGTk06AN8P3JiJ<0b]nJ0=OaZP3Gj:@0cMjG0=;YV@3:h9D0`=FB0;K;RP3>
hj00bn6I0<_RW03Ll[40f^ji0<?FZ03Ml<<0j?[:0>7c`@3=iJ/0dnf^0=KUXP3EiZ80PYIA0;[@R03E
jj<0cNBL0=3VWP3IkjL0f>bW0=W]Z02FYF80AU0A0>7RYP3IfId0i^N[0:R^L02HY6@0e^fY0<SSWP3?
i:40dn>R0=?IV`2ESeD0aNBQ0=3i]@24YfL0a>RR09N^J01fMSH0b>>L0=KX[P3]llD0WY]h0<C@XP3<
gZ00cn6S0>3^^@3do^H0Ri>40=3O`03AiK00a^FE0=3bWP33hIL0c^:K0;W:P`3Bk:80cNVN0<OQV03G
k:L0Yk9f0=7HXP3<eZ@0d=j]0=c]`03Fi[L0HVPl0::JM@3Pj;l0i_790?SogP37fZ`0GU8X0=KFVP3D
i9d0fOBU0<cUY03LlKT0bMfZ0<KJY`3dom80m?o=0>7o]`3Dm:/0]mJB0<[Y/032gjl0mooZ0?;oi03K
jlL0cMbe0=?P]03?g:h0]l:J0<_E/P3Ih/D0o_oc0?kon03=c<P0n?Oe0?gkoP3oo_l0n_On0?omo`3a
ko@0mO?d0?oon`34a;X0f]_=0?[omP3nooL0ooWc0?onm02hX9@0imK20=WS_P3AfjL0e>:W0=CdZ`38
giL0Gf<G09bND`3GijT0amjX0<_R^03foo80nooh0?K`lP3llOD0ooSj0?ojn`2@ZFL0aN^D0<K_X039
mkT0]>B`05nBJ@23]I00R[V?0;;M[`3;k[@0]]RK0<oWW@3DjI`0cnJH0<o^X03<kil0`NZK2`3oool0
00X0oooo0240b^>/0<_VW`3<j9d0h?^f0=Wb^03;hk40bn>c0=gdb03<i;80`mfP0<;TU`2jj:L0o?oU
0?onl@3lool0oO_o0?[en@3oooX0mNoI0:^JP01IDBd0iooV000X603Zool0hNkd0?c_n@3fh>`0oo[o
0?ono`3kool0nOoo0?_oo`3kooh00P3nool02P3oo_l0ooco0?oknP0P2`00J5De09:=EP2AUeT0bN:N
0=3`Y`39jId20<WZV@3o0<[ZU`3:jYD0d?2K0<[/UP3;kYX0b>jI0<?ZU`38k:80bN2b07:5F0002@00
gn:g0=OIZP0l?`P0h^R/0=c]Y`3=i9`0_MnE0=gk]@3@g9X0b=bG0<ORV`3>k:@0`n6G0<CJTP2fbX<0
hO2]0<CET@3AiZ40dnjW0<O]XP35iid0b>JN0<OQVP0W?P00dnNR0=_/Z03@gi`0fNRU0;K7P`2=W5T0
d^:Q0;gYWP31jj40d>NS08Ai@@2NWV80eNFT0<C^Y038ij40`KIn06mR:`3/okl0enZZ0=7UX038gYH0
c>:I08BJC`2N]V`0Q9aB0=7XX03;hYh0S:IO0<cSV`3Cij00>dH20=ORWP3;g9H0`MJA0=G`Z@3:j:00
d>^T0<kSWP3Il:X0aNVO0=[j/@2kdX`0j?bg096PG@2:VEH0b]jI0=W`ZP3Mnk<0aNNM0;kPUP3DlZP0
anFK09fiK`2R_W@0d^bS0=;]YP2ofI80fO2Z0=7UX029VUH0RiaH0:joN`3FjZD0cNNP0=7/Y@1NO3@0
[LR10=3TW`3Ij:D0j_Jd0;_:Q`3IkZT0_m>>079d=@2?PdT0/9EP07=E8@1AF1D0a=^C0=oe[03IjJ80
dMjH0;2lM02V/VX0SY]E08fMEP25UU00d>6K0=GTX@3/mkD0^<>108:;BP2`^GP0KGTg092QG@3EkjP0
cN^S0<c`YP2nhYP0_n6G0<WWW`3>jJ80UJYU0:BhL`29VUH0Z[]g0=__ZP38g9L0dNJQ0<[TW@2ngYD0
d?2W0<KVW@3:j:00`n6I0<KQVP3?jZ<0g?J_09:/I@3?jJ80a^6J0;oSV`34j9h0`n>H0=7aYP32hID0
cNNM0=7[X@34fi<0QIaF0<gRW`3Lljd0Z<Mk0>7o]035i9P0d^jS0=[fZ`1TOS@0LXa20<cTVP3Omjd0
UZiT08fSF03FiiT0j_Z_0<CISP3Ek:@0`^6N0;GIV`3HolL0Bh5@04=nDP2ho=L0YNg505:@G`2R_I80
]/^C09FVK`3Fh:h0aNjf082MK@2;Wfh0CF0X0=CNV@3PiZ00SYYH0=?^Y`3<lZL0b>RO09VOG`1SHbD0
e^ZU0;cJTP34j9h0b^ZQ0=;^Y034gH`0c^JJ055X8P2oeY80b=nG0=C/XP31ehl0amZJ0>WgaP3koml0
l?[H0?kok`3lonX0joOC0>7`a@3JmZ`0aMnF0<gTW03IjZH0a]:@0<_FU03JiJ<0`/j<06io>@18G1D0
TZQP0=g^ZP3Hi:80en>Q09f/J@33ei80an6J0<c`YP31ii`0bn^R0=7/Y@3Ul:h0X9]Q0<k/[02ehYl0
R[Ab0=K`/@25TE<0h^BU000/0=ObZ`39iJX0j?S70?omh03oonX0kO??0>kdcP3Wj//0oOcg0;:b/P36
b;X0gNFn0<KEU03<gIT0cMfO0=GTX@1aPS/0cnZM0<7MT03@jih0d>JK09BQG02BWE/0fNNZ0=3RYP3E
jZl0d^BV0<WAV00i<0T0oOoM0?ooh`3lon40l_oB05U<7`3Nh:40dN:K0<o^XP3gon@0mOo[0?Sok@3g
on`0dnRo0<kV]03Kn;D20?l0000B0<cYZ@2jeY`0lOCS0?onnP3ooO80oooc0?Gbh@3oond0g]_<0?oo
m03km_00oOOg0?omo`030000n?Oe0?ono`3hmO`0oogo0P3mn_l0:`3oo_l0nOOh0?oon03Jf/h0/kNf
0?ooo`3olO@0oocj0;:FU@3mjN80o?o]0?[ohP3Kikl0`nJT0<cWXP2`/VL0L6hS0>GbXP3BiiP0e_6T
0<3PW@3VolX0m?oV0?CokP3iood0nOoo0<K6X03?ciT0[kMl0>So^`2lfiD0_>NO0:kMU`3;nl40R;N3
05^3H024Z8`0]M2=0=_bX03AjYT0`]f>0<oZV`3?jIl02`3oool000X0oooo01/0bN6]0<WTX@3@jjH0
k?o>0>?ibP3?iZh0a]jT0<oV/03?iK@0b^6Y0<OYW`2okJl0n_kS0?ool`3iool0noko0?glnP3oooH0
k^K?0:nGO`1JBRT0kOoV000A0031jnL0jooo0??dn@3on_l00P3o00004@3oool0nooo0?Soo`3eoo/0
nooo0?koo`3oo_l0oo_n0?oknP0H0`00H4d]0:FNJP2TZ6d0cN>R0<WWX@3=jj40cNbP0080cNbN0?l0
c>fL0<WZV@36iiH0anZF0<K/U`37kIP0bo2S0=[da031ejH042800<[DX03Mi:h0XZQ/0=7JV`39f9D0
cN6L0=G_Z036fiP0e=ZL07b8B02mei00cnfU0=7_Y@3=i9`0h?B]0<kMVP3EiJ@0`=FB0<[UX037kJ80
aNNM0<g[X`3DkZL0B5lI0<cPV`2mdH`0cn2L0<OHU036fYD0V:AR0=WRX`3DlZ`0bOj`0;WWW03MhjD0
@ST00?Oa]`33hI/0e_Zb0=?AUP2PUeh0QYAF0=7QXP3IjZH0hOF^0=gaZ@3DjYl0RZ9H0=SbZ039hiX0
dN^T06Ao>03?jIl0bmnG05EP703YlZl0c]^F0>7b[P3Bk:D0a^2I0<7HU03>gYd0c>6N0;oSV@2kgI<0
a^6J0=;YX`3Cij80Ff`X0=7UX03EjZD0eNnX0<SRV`3=jj<0bN^N0<?UV02jfXl0cnnT0<GSV@39h9X0
d>NQ0<[OVP3?i9l0iOVd0<OKUP3DjJ@0`=F@0;kHT@3@jj@0Pj=J0<K_X`3GlZ/0f>NT0=SFV@3^jZd0
g=jO05IH6@3AcI00f<V@0>[AV`1]F240MX900<g]Y034i9T0anJJ0>?o]038i9T0^mN<0=SbZ@3IljX0
bnFN0=?XX`3@g9X0`lb;0=?LV`2Y[fl0B54@0<_GU@3BhIh0dNRR0<cWX03:k:80e?J/0<o_YP32h9P0
`=jF0<oYXP3BjJ<0e^^V08jRG@3?h9`0j_Vf0;o;R@3Yn[H0e>nX0<WTW@3<ij00f_F^0;kITP3Ak:D0
d>^T0<_VW`1;IQl0`MbE0=ObZ`3BkJP0foJ_0<GUVP3<k:40a^JJ0=7`Y03;jYh0c^RO0=gd[P34eiD0
d>FP0=7]XP34h9D0a^:G0<KPUP2leX`0dN^Q0<[TVP31fi40a^2F0<cVW03<hYL0XZiR0;c8OP3Giih0
cMjG0=C^[@30hZD0boBl000F00009P00?HAR00MA;P006000c>c30=7^]032g9l0cm^Y0<_[^@1WR5T0
UK6004EH803>fi<0f>BJ09BSH03DlZX0c_N[0<CVW02@VEP0IFLX0=[aZ`39jj40c?FY0<?WW@36iY/0
fO6S0=cdZP3<iYl0cnRT0=W`Z02ne8/0gO6Z0=c/Z`3Vl/80mOgF0?ooiP2^[Z80oooa0?koiP3Bg;L0
`^BG0=WeZ`3HkjL0e>2N0>G^[`3Pi:L0e]ZM0?Om_@1?GQT0T:5K0<cRVP3EjZD0f>VU0;72OP3=hI`0
a=jG0=Sf[P37l:@0`NZN0<SZX03:iIh0e>2N0>3NX`3=hJ@0`NFU0931P039f:40RhiG0=SWYP39g9X0
02D0bNVZ0<KRZ03oon40moKQ0?KifP3oon<0oooX0?ono@3[jNh0dM790?coh024ReD0FV<Z061X=@00
2`00VZUV0<cSV`3JmZ/0a^6D0<kVVP2<W5<0VjQR0=SYY@3AiZ<0d^^W0=_`[@3Afih0GUD/0<?8X03M
hKh0o?oO0>3c_01NE240hNJV0=3TW@3;jj00n?o]0080nOoh00<0m?o`0<oP`037g;<0103o00004@3:
gZ/0oood0?gal`3onoT0ooOb0?ohl@2[XY/0ookh0?omn`3onOX0ooOo0?oko`2LV9T0K6]Y0?gkoP3_
k?<0oogo0080oO[o02/0ooko0?Wgn03oooX0l_;X09fQXP3RhNL0oNcb0?oln`1mGV<0ooSh0?oomP3o
ond0l?WJ0<[/[`3:ij@0fMZN0:ZXK@3Ji9d0fNbM0<KOS03:l9/0_^FF0<?WZ@31hJl0eNc@0>OjiP3o
onP0oo_K09RDKP3:eI/0g?6/0<[_W`37lIl0^^RP0<We]P2B_8h001000=7/_`3Fk[`0_mJR0=3W[`3E
jZl0TZAV00/0oooo000:0?ooo`0J0<gWYP3;iYl0cNNX0?;oj@3eonl0iOZo0=7XX03?iZ80looN0??o
h`3bon00kOoU0?omm03ono/0l_kn0?Soo`3fo^l0m?cT0?;/b03bf[P0MV0i0<SO]@2<]J<09f1G07B]
Y03Oool40?l0000>0?olo@3kood0m?ok0?[on@3nood0oooo0?ojo@3onOP0;AH4054l8@3Yg[40W9aZ
0=KY/@36h:<30<kXY`3o0<cYZ@3;jJT0bn^X0<g^Z@3<kZ80b^fM0<GXU032i9P0d^fh06F1A`004P00
enbY0<oSWP3LjjX0S9]J071j>`23SDh0>D8107Mk?P2LUEh0ADH<0;kBS@38hY/0c^ZP0<gWW@38giL0
O91;0=GXYP3Mlk<0c>NT0<?UV`3CmJ/0b>JN0<gWX03GkZP0MHU40:BhL`38gIP0dnRS0=_`Z`34fI@0
//6009nUI`3;jJ<0aO6V0;_UV`3Mk:/0g]bQ0;6_M03Qjj`0a]JE0=GSY@2Y/GH0GFDY0<kJVP3Ah9/0
e>RP0>3fZ`3@jih0fOFX0<WXW03<k:40_=bA0<?RU033fI00CEPC07Ak=`0_=P00Ef8P08NGEP0iB@P0
HW4`0:F]L@3OjJX0e^fW0=G/YP39hi`0d>ZS0;gHT@2ofY<0Z/Am06f7@03Qn;80bn:L0<KPU`34iiL0
f_b_0<?SU`36iIT0a>:H0;2jN`2O[Vd0JWdk0>3i]@30fiH0^mVC0=Cb[035hid0SJIR08>JEP3@jJD0
^MnD0=of/03NijH0V8U@08Ig?P2?SE00h^NW0<[@T03`k[40iM^P0:nRJ`2_^G`0`=VH0<gZY`3@mZ/0
^>6C0:SAP`3:l:<0`=jH0<gVY03CiZH0enFW0<oOWP3TmK40a=>@0=[UX`3Yl[40Uj1O0=WRX@3FhIl0
hNbZ0=[VY03RkZ`0fnFV0=KRXP3AhJ00d>VU0<WWX@3QokX0cN^U0:BkM`3EiJ@0e=jO0=;LW@3;g9P0
eNVT0<cPV`0`A@00SjAO0;G?R01_RD80O9M@0<?QV@3>k:@0d>NQ0=cUYP3Lj:H0b^JL0<OWW03:kj40
c?FV0<;YVP3Bl:H0aMbF0:VeM@2@W5X0`]J>0=K/X`3?iI`0SZIL08nWG@3?jIl0bnFK0<GTV037iYX0
d>nS0=_eZ`3Dhih0`Lj809VVH03@h9T0`=F@0=3[Z03:jZ/0_njh0;7U]02jmld0_OkF0:;O_P3?oMH0
02/000dj0029WVH0Z[V>0;;I[01FO4/0D5hY0=?ZW03Hkid0TimM09RfKP33jIh0cNfT0<kCT`2?Se40
d^VS0<GWW@31jil0aN^P0<c/X`3Ejj<0K84l0=;YY@3@ij<0dn^Q0<kTV@3MkJH0h>bZ0>S[_03oom/0
oooS0?Okh03oon@0X:Qo0<WEY`2cgH/0_Mb@0>Km]@1?EAL0UI=J0>cU[P2WWVD0DdhD0<_DT@3Hj:40
ennU0=_aZ@1HJB<0bmbF0>Cj/P39hiX0aNFJ0<7WVP39kj80bnNM0<kTW03[lZl0h>2P03m83`3>iZ`0
cOJn0=;K/01>DB@0d^N/000[0>Kd]`2mh9`0f?^g08BAG02AW780eMj_0=;K[03IgkT0nO[d0>7Pi@0;
2@X0`Kn`0?ckg03oon@0g=[50=GJ/P2obIL0enbc0<WSY01TOcX0RjEN0<;FSP3AiId0b^:H0<GQUP3=
kj80dnfS0<SET01WH380HfY00=cQ^03Dh;00bN2L05aF603HhIh0cNBN0<7UW`3ioo@0oOgo0?koo`3l
ool0moo`0?Coj0040?l0000n0?ook03nlo40oo_k0<6e]@2fZZX0Zj6P0?_bl`3oo?h0m>k`0?omo`3n
nOl0oo[o0?ono`2;RXH0ooom0??alP3knO`0ooko0?klo`3ooOl0o_co0?glnP3oood0n?go0?ono`3:
]kT0oocj0<NW[03om_/0ooko0?oon03monh0b^Rb0<GOWP3Khk80eM^]05aU;03@gi`0d^NL0=;bW@36
kI@0`>ZD0;kWV034i:40bnV[0>K]a03Lg;P0nO_D0;>mR`3Wm[l0^mBC0<OTX@3GnJl0_N:E0<kdY`3C
o:h0KHM^06IkLP1]PgH0//Zb0<_TaP3<ikh;0?ooo`002P3oool06P3=jIl0b^JI0<gWZ03eoo<0mOoh
0>Gk_@3DjYl0d^RP0?WojP3eonl0m_o_0?Gom03omoX0ooSo0??no`3gool0moo_0>gkfP3RhKD0g/VN
06aG:P39g:l0J8Yi019>A015RG`0XNSH103o00003`3oo?l0o_kl0?Gon`3kooP0o_ok0?ooo@3ono`0
oo_h02@=0014;a@0kN6g0:BSL`3<gjP0d^Va0<cTZ0020<_TZP3o0<WT[@38iJl0_mjS0<?SY034iIh0
a^RL0<S[V@36iYX0eo:k04m[<0005`00bnFL0<[QV@37fiH0d>2O04iF6P1KHBD0IfLY0=3;T@1TF2@0
RXQ?0>Kf]@3GlJP0b^JL0<[TVP3NmZ`0HGD`0<GHV03<hZ80bnJS0<GWW@3?kjH0d>^T0<[TW@3<hid0
NHe806=h<`3DjjD0a]fG0<?JU03Fl:T0e^^X0826B03Tlk80b>>N0<C^Y035hid0gNb[0:VWK02f^Wd0
d>>Q0>3c/`3]l[X0GF8X08^EEP3Ch9/0cN6I0<OMTP3<j9/0a>>E0<OWV`3<kZ80d?:U0<SYVP3MmJ/0
A4l:02dd001_M380_LJ50=3LW01mRDT0BE<D08F9CP2b]WT0c=RF0<cMV@3HkjT0an6J0=CdZ`3>kZD0
b>RO0;CBRP2fdHX0bN2J0=K`Y`34iIH0bn^O0<_ZWP3;ii`0bnFL07Mm?`1BGQh03al00<CMV@3Dljd0
bnbU0<g^Y`39j:80U:eY08NLF@3CiZ@0dnjW0;C0OP2GVEX0JUhT07]b=`3OjjT0dNFP0<KJU@3Oj:L0
/Je`0>3AVP3Mg:@0fNN/0<OKW034hid0^MfC0=Kl[`35iid0f_2_0<gKWP3EgJ@0g^>Y0=c_[@37gYP0
gO:]0=SWY038di40XJMW0<[?S`3KgIh0g]jP092@DP2DTUD0h]fS0=cMX@3;eIH0dNZV0;gLUP2gfi<0
_n>K0:6lM`2=XUl0S9QH0:6[K03GiZ<0fnZW0<KGT`20U4l0bmnJ0<7HTP3Pn[<0bnJO0=7_Y`39iil0
e>VT0=;BUP32b8P0c>>K0<OWW036kIh0_^VI0;SST`36i9X0fo:/0<G?T01JHb80h_>/0=_/Y@2]`GT0
SZAK0<[PU`3;iI/0aN6F0<KUV@3BlZH0`^:F0;SFS03Qm;80g_:]08bLE@2N[VL0d^JN0=W`Z036hI`0
`>RZ0<;_]02djK<0Ql:D0:c[c02ReZl0E8e904f2>P3?j:l0KGA;0;[S]`12K3X0@dlM0<cWUP38iI40
V:=Q08JPF@30i9X0dNbU0>?SY@2d/WD0fnnZ0<k^Y@36kj<0aNVO0<KVW@3FjjH0OY=@0<?IV03Hkj/0
fo6X0<[OU03;f900h^f[0=kP/@3clL/0k>c80?gog03XllP0gNVg0:VhP@35l9h0cnnS0<_RVP1ZJbl0
OgQ10>?HXP2LSeX0I5/R0>K]ZP3AgYP0b^2E0<[NU`0jB`D0iOB_0<WMUP3>iId0c>RN0;kSUP3@lZH0
enfU0=KUX037bHP0emJF06A]=02K[WL0^]RV0?3le01^MTd0a=NP000/0=[//03<jjL0d?6Z07V?C`1Z
Nd@0enNY0=7QX`3Hi;80o?of0>GVj00200<0[JfQ0?oojP3dk]h0o_O_0=[M`03_mm00aMVX0;cEWP1k
UEH0`]fJ0=GZY@3Bj:00bNFJ0<_/W@3;l:00`mjA0=KSWP2]YgL0HfXn0=GL/03Kj;<0c>>K05QC3`3D
gYT0c>JO0;oTW`3koo<0ooko0?kno`3nool0o?oh0?col`3nonP20?l000080?ool`3ooOP0oocj0?ca
k`2]Xj40bKnm0?G]j`3ooOd20?ono`0e0?_io03oo_l0ooko0?ooo@2=S8P0mOC`0?oon`3oood0knk/
0?glnP3mno`0ooko0?cjo@3oo_l0n_oo0?koo`22L6h0oocf0;NDVP3om_/0ooko0?oonP3monl0bnRb
0<OPW`39ej80hnnm082;D@2U/G<0dnBP0<7LS@3>kY/0b_2K0<_aWP37ii`0b^FN0;O8TP3JikT0loo?
0=o]^P32did0f^nd0<?IV@2mf940c>bP0;SKR@35jiH0Q9ik0<CKa`2E[IL0JHM[09o2X@2af[802`3o
ool000X0oooo01/0bnbA0<KTSP3>jJH0l_oh0>Sdl03FjZd0c>>E0=GVW`3loo@0mo[o0?coo`3knol0
on_o0?odo`3_n?d0mOoo0<[R`P39h;@0iNnc0:2AF01VEa`0l_oA0>golP12OW8004`i08?Zc`009@h0
0P3o00020?oio`030?ojn`3iooX0o?of0080o_oj0?l0oocm0?okn00B0000I4ld0?oof03oomH0EVHe
07F9E03fomD0m?oG0??of@3aomh0l?oP0?7og@3aomX0e?:b0<_ZY039jYT0a>BH0<KRZ01SPD<001<0
0<CUUP3@kil0c>JM0<_PW@3QjJh0e]FL0>GLX@3Seid0Fd/H0:ZUKP3FiJ@0b^6I0=3/XP3@jZ00dnfS
0=_`Z`3=hZ40QieO0<oYZ03AlJP0c^bT0=SbZ`3=ij00_M:=0=_`Z`34fI@0Bf8L0<[TW@38hi`0cNRQ
0<CMV@3:iJ00e=FI0>GPYP27UeH0aNnU0;?VV@3BjjL0d]JI051D5`3Fg:00g]jX0=[KXP3<dY@0FVDQ
0=CUWP3CjIh0b^JI0<g^W`32hYH0b^nR0<3WV038jIX0cnZM0=;MV03GgYX0hNJT0>ca/@3EgYl0f^>T
0=cRYP3PgjH0hn6V05QF6@3BeiL0aMJB0<WSW035jIl0`nVN0<O`Y028[V<0a^RN0=3^YP3?kJ<0eo>V
0<cXV`3Hl:H0cNFK08^QF@3ViZX0dmbM0=g/Z`1:J280a^NP0<3XW`39kjH0c^nX07nFDP3Ai:80fn6S
09jNH03Qei`0k^BY0=OGV@3RkZ`0`o:T0;?ZV@3<mZX0c>6L0=?CU@1ZCQ`0IThR02HJ001iMSl0bMRG
0<kQW`3?i9l0f>VU05=D6P1RF2D0K5XZ06AH9P17GA`0^=bB0=;bZ@3Cj:<0eN6O0<?5QP3OgJ00HUHL
061A603^fj<0iM2I0>K?V`1ZGBH0E58G0727@`3@kjT0`N^Q0<3/X@3Cmjl0bnVS0>3c/@3Dhj80FF8Q
0=?NW01FHR00dN:N0<KGT`3EjZD0aMnH0=GcZ`33hIT0d?2W0<kSWP1EBQ80EE<F0=3VWP3BlZL0^nJF
0<;cX@2fiI@0`N6F0=7VX@3?eIL0g^>S0=gZY03>gYL0a]N@0<kRVP3KkjL0aMfC0=GaYP3;jil0aNFI
0<W^X02jgY@0d^n_0<SRX@3Rn;00cnBI055R503CiYD0f^nP0;cHS@36j9h0QJiX08BfN`005P00^oS?
0;?e[P21`GD0a^FZ0=oM]`3IomH0R[J509ZRL@38jYH0d?BL0:2VIP2CYf80d>jV0=?XX`3Mei/0kNBY
0=o[Z@3>j:40`nNM0<[ZX@3<ij00b=bG09>XI`3:h9l0cNBP0<KLT`1>H1@0g^^S0<oHU@3GeJD0[JR2
05EC:P3@hj<0dnJT0=K[YP3DjJ@0b_NT0<CTV03@iYh0fMVM0>WNZ02VUV80/j9^05mD703PiJ<0dn2J
0=7VV`3>giT0RIA@0=kYY@3EhYd0c>2I0=C[X`39iid00380c^RO0=7NV@3EfYP0D4/;0=gIV@37eY/0
CUl[03Hn5`003@008SdD0>S``@3Lm[T0cNBN0=3ZX@36jid0do:T0<o[UP3>jIP0moo80>gih@3OjN40
e]OK0:f^Z03ooO@0ookk0?olo`3lo?00o_oZ0?Ooi01:HCD0e>nh0<OPYP3AijH0e>^W0<KVV`33j9X0
`njN0<WUV02DY5d0DDhK0=cT]@1MIC80gNba0=_cY@1ED`T0eN2K0=;]Z02miZ@0o_oa0?onn`80ooko
00D0oook0?oon02GUHP0FeM<0?omn0040?l0000k0?okl03oooP0oooj0?oonP3fn?<0o?oo0?OknP3f
o?`0mooo0?ooo@3ooo/00@000?oom`3gmnl0o_kf0?oonP3gm_@0ooko0?Sfn`3ooOl0m?[h0?kon`3o
no<0[J>G0?GAd`3oloP0oo_m0?omnP3mnn`0cNRa0<[PW`3=i9h0c>>M0=CSXP0T<000DEdO0=SXZ@3D
jZT0b^FP0<_YX@3;hYX0c^:J0<_ZYP2mh9`0b>RU01Pc003<iJ<0c>6N0=;UX`3;h9/0d>ZS0<?NU`3F
m:`0bnFL08VSFP2mgI@0cO^k0;3Z[`11REL02`3oool000X0oooo0><0b^^T0<gZZP3Cjjl0k_o:0>;g
_036i9h0c>^U0<SVZ03honH0nooa0?ooo@3ioo40lOoP0?CogP3dom@0k_o;0<cUX@3<iYl0bn2O09BV
J03<fj00o?oD0?_og03Il]8000l009WN_`2el<80IIZ0045kI@2^kmL0h_oo0>Koo`3[ooL0mooo0?ol
o`3mmoL0m?ok0>_om00;3@P0?3`j0=olm`3Mool0]>_X0;CLg02:UYH09S0a065dLP3<kn/0i?oo0>;o
o`3Oool0Y^C=0:cce@2HklD0/ooG0<Chb023]H@001L00<Si^02bgiX0a_2T0;oZVP30jiT0ao:P0<;]
V`36hYD0KV<U0:2EE`3ShZ40c]RC0=?TWP34jI/0a^nP0;gRU03Dkj80XZaU08jHD`3Om:l0c^FO0=;/
Y@37hIX0cNNP0<cVW`37hIX0SJAN09jbK@3JjjL0e>RS0<_UWP3=ij00f_6[0<?JU02/`gd0LhQ30<cQ
W03=hI`0e>RS0:k2O@2GZ6@0d]jN0=W`ZP3Fl:T0b]jI04m;3P2TX6<0eNRV0<cZY030giT0dn>T0<cL
V`3BlZT0d>jV0=3ZX@3?jJ00cnNM0=;]X03Ckj80`N:C0<kaW`35k9T0bNZK05IO802AW5X0b=bE0=7X
X03@k:40d_6U0=WeZ`1nVU00d^VS0<CGU@3AhJ00c=NE0;6jN@3Zkjl0cM:B071b<`37m:40a>fN0<[_
XP2=YV80QIQH0=oZ[P36dID0h^j`0<KEU03Okjh0c]nK03m;2`3Cgid0fNZV0<oVWP3EkjD0_mjB0<[Z
WP3:k:00cNnU0<_]X`3GmJd0T:AO09NRGP2CWUX0YJaY092ED`1;D0h0GfHS08JCCP2V]G00_]:;09>Y
H@2EZ6H0/I]Y0<bfQ03DhZD0cM2G0:N@GP2[Uf80/L9l0<gQVP3;jY`0cO2P0<OUV`3DjZ80a]NA07B1
?00c@000dNRR0<?NU`2mgI@0e?:Z0=3WX@3;giX0d^>M092WG`37iI/0bO:S0<;[W02nh9<0e_:W0=WR
X@3Qgj@0SWi:05]B6`3FiJ@0J74b0=CDUP3RhZ@0i^RY0=3QV`3>j9l0_N>F0<S_X035k9d0b>NK0=oX
Y`2`^gT0cnFM0<oYX03<jZ00a^^M0<G/W@33kI/0aNbK0<K[V`39jYT0cnRG0<cXV`020<G/W@1g0<gW
WP2EYV80QY9B0>;d`032gK00;5hh01A97@20Z6T0gOo302iC7`06=0<0P;RA09k<[`3hoo40<3@K038c
4@3Vol40`>BN0<3SX@2=YV80eNJO0<gUV@31iYT0d>jX03Hi0P2QX6P0e]FL0<STV@33j9X0d>NQ05YD
5P3?iId0bN^O0=CUW`28RTT0cNNP0<7SV@3<jZ80c^VT0<WPW03Fhih0c]fH0=c`Z@39fIP0eM[60=WR
``3Bg[H0enJ]0=3NX`39diL0CU<K05aQ:@3FjJL0d>bR0;oTU03?lJD0cNBN04]O6P39fYH0bMZD0=;X
X03=kJ80bNVN0<WWW@3BkZ@0WK=X0:^nK`3Bg9<0^l1m081n@`1_JT806a/00<SG^03Fj/D0b>F[0<CS
W@3=hi/0][V>0=oO``3Pi</0l_WW0?kon`3Ti>H0f/oM09B6U@3on?l0ooko0?oonP3jl_00oo_k07ad
LP3mm?D0ookm0?onn`3@d<H0kNkL0>CV`@2XZgh0SY9O092VGP2abGl0fNV[0:nlQ01DFbD0iNfb0:bi
L`1;F100fNnV0<[TV`3?jJ80bNJ^0<7M[03ion40l_WH0?[ofP3=eZT0/<>;0<kP[03Ah[D0103o0009
0?ooo`040?[jnP3oool0>c/k0>OWi`H0oooo02P0o_kn0?koo`3oo_l0oo_h0?;MfP3ji>L0ooOm0?oj
o`3lool0n?of0=K]^@3>iJ40b^FN0<o]Y`39g9X0/JQ]05Y>503Ij:D0b>BJ0=3/XP35ii/0_NbK0<cX
W@3Bf9X0hNFZ0<gFU`2ebH80b>2F0<c_W`30hi40d_FU0<W/W02Yb7`0lOo20=7/W@1oW4X0cNZJ0<SY
V035jiP0V;m/2`3oool000X0oooo0=/0aNNM0=ol^@3]olD0cN>S0<WOWP38iJ80bNNW0<OT[03hon`0
noof0?oon`3honP0e>bl0<SQZP38iJD0bnRU0=_f[`2ofI00]<V60:RjO035e9T0l_c80?kofP39gL40
_=k507B_T@31nm80]^OD0;[[f02CaZD0U;Rh0>Woo`3Tooh0hooo0>koo`3Tn_L0ioom0=3ei00A4P`0
9A/J07f1PP2>XZ40]LO;0=[Qi`3Vh^<0o_oo0>Sbl@1bSHP0<4m9045WFP1_VXL0BHAT02EY@P0nUF00
?8eR02MNF003>300018507^bV`1o]I/0QknL07bdS`1m]hh0O[N>09_DZ`31lL40dmfN07=g?02ZXFX0
c<6;0;R_N03Ni:H0bMRE0;OCR038iiT0_Mj=0=CcY@2@YF00MXe709B[I@2=Y5h0NY5;0<_RW038giT0
cnJP0=?XX`2<XE`0QIYE0:g4OP2;XU`0dnZT0<[QV`3;h9/0h_Ja0;oCSP2^`Wd0g^n[0<KGT`3JjJH0
Qi5B0;C;Q@34h9H0d>BM0=KFUP28QdL0Ef`Y06n:A@3Im[<0d]fQ0=OQY@3Lmk@0eo2^0=7VX`3Rmk80
e^ZS0<WMUP33gI<0d^jQ0=SiZP3=m:40`nBE0>?/[@0h@`40g_:[0<kUW@3<jil0a>>G0<SVW03=jIl0
P9MA0;gBS`1XNcT0_/f:0<GDT@29V5D0UZ9P0=OSX@3>n:H0`nRJ0=3`Y@3;h9d0cMfN0;_6RP1VLCD0
Xjma0<_JV@3IjJP0A5PC0:6`K`3LjjP0d>6M0<cRVP31ehh0a=jD0=C^Y03BkZ@0c>ZR0<CRVP3CkZL0
eNZU0=7RW03Hij80e>6L0=cWX`3EhYd0e^>N0<SLU@36g9@0bn:J0<kYXP35h9/0ZiYV06eI9P3Sk[80
g^6X06mI9`1[G2D0dNRP0<[TVP2nhI40b^fM0<SZW@39hiT0c>:I0=GTW`1dPch0e>^U0<;MUP3;iYl0
a]nK0>Wi^03BhIh0cMjG0=S`YP3?kZ80_^FF0=7fZ@3?iYh0f>VU0=?HV02MWV80YjM[0>O][`3>hj00
Kghm05MI6P1OGb40QXQ90=?RW@3>i9`0bN^O0<_bX`2oi9H0d_6U05a[:02S]700b=nG0<kZX03?kJ<0
0P36jid20<K[V`1n0<S[V`39jY/0cnNI0<WZV@32kYT0`^fK0<cXWP3?hih0fNFW0;c:U@36gJT0CWY9
0970RP3Jok`0_MfL0;_QZ02chZh0]?78062FMP1`Pfl0;SPP00PB003Em;P0`NZX0<CXZ02H/G00gnnX
0=;XW@3=lZ@0anVO09RRIP17B0l0VY]Q0<kTV`3=k:00c^FO06aX:@39hIL0`nFH0=?TW@1TIb@0c^VR
0<O[X@35hid0a^>P0=?YZ02DWe/0^/V40<gSV`3;h9d0blbl0?coj03lon@0dMbb0=;K/03Ffk80emVa
0>7T]`3BiZL0b^RP0<3WU039kZ40foJ_0<CIU03HijH0f^ZY0<gPWP3<ij80c>^W0<_XY@3@jJL0cnBQ
06j4>`3Wm:`0aLn:0<[?S`3HfZP0UYi_05aaB02jeJX0c^fd0<g][02mdi80Vj9f0?ooh@3non<0lokP
0?com03Tin00Ee1H0;2V[`3elO00oooh0>K]g@3mnO00lncV0?onmP3oo_P0ooci0?oon`3Rhmh0][R]
0?GjfP3FgK<0gnVd0=oc[03Ciil0cmfP079m@`3QjK00];b007b9@@3/o[80bn>G0<OSV03;jj80b>N[
0<gZ/P3gomT0d]na09NPL@37eJ80en^f0<_O[P3Lk/H0nOoa0P3o000;0?ooo`050?clo03bl_80Hf=S
0?ooo`3gmoL01@3oool09`3nool0m?Cf0?oml`2fZIT0i]K70?oml@3oo_D0nOod0?Ook@3Ek[D0b^>O
0<ORV`3<jZ@0eNRV0=gDV@1ODaT0cMbI0<kZX039iI/0bN^O0<?bX@3=jIh0g>FV092FFP2@VU/0d>JN
0=GaYP3:kId0aN^H0<g`X037iYP0d>RN0<[PV02R^FT0/lai0<_VU@2ogXh0`^>B0<g`X00;0?ooo`00
2P3oool0W03<kZ@0bnVS0=C]Z@3@ij<0c^FQ0<SUXP36i:H0b^Jc0?Kok@3hooL0oOoj0=WZaP3:hjX0
a^:U0<k/YP3?kJD0^]J<0=_g[@0gC0L0d^FU0>Sh^P3nom@0nooF0>goi038i/h0AGYL00]37P2okN00
^nSD0:_E[`14IVD0Xl7;0:C>a02`hm`0bNcX0=Whl`2B_:h0FX5_00<0000d92@0ooWj0?_oo`3oo_l0
oo_o0?oko@2o^kX0Ri2<0?7oo`3To_D0gok_06R;M`2:_9T0^oS<0:Wg_@2_mlL0Y=7:0:cJd0006`h0
Lj>=03m_E@18NeX0@7A@07J]Q@25_9@0CXEM04MhB@33gj80hoBm05iH:01IC1l0GU0S04e:5@37c980
d^VS0>3n]02oi9@0_=jA0=?XX`2^aGl0QIaF0;[AR`35g9H0]<^50<[QV`35g9H0a]^F0;cAS03CjZ@0
aMbF09J]I`2>YEl0]/f70>7f/@37fiH0bmnJ06j2?@1WN3@0f>VU0=STXP3=eiP0IWdg0=WeZ`36g9@0
iNNV0>WYZ@3Cj:D0FG@a04MQ8020R4l02a<00=;XZ033fIT0d^FU0<WIV03GiZ<0d^>O0<_RVP3<j9d0
_]fA0<3WUP35iIT0d]^L08:=B`3Hk:D0dNRP0=GdZ03>kZ80`MnE0=3/XP36gIL0QIYG08:GE03=hI`0
eNVT0>Kj]@3Tn;<0a]ZE0;cQT@38j9`0c>RN0=c/Z`3Rk[00g^R/0=?MX@3Fh:<0i?>b0:noOP1kSdX0
bMVH0<GFTP30dHd0VZiW09faJ@3<hYT0bn6H0<[QV@80fO>/0400b^BM0=S_Y`3=hIX0e^ZS0=GVX03?
gYT0enRR0=CXX@3Ejj<0d^VQ0<kXW`3DlZX0doB]0>;EX02/VfL0/;]o096DF`2hYg<0cL::0<cXWP33
hYH0d?JS0<CZU`3:kil0d>bQ0<oWW@3Kk:H0WJiX09F/IP27XEX0FgD^09jcL035dI40h^f[0<[NUP3A
jj40aNBH0<g_XP3;jIl0bmbH0=3KV@1YKRh0CU8E0=KPX@3BhZ40b^>O0;?3PP2m`X80];Af09FGF03H
iJ00eNVR0<;RU`39kZ00a^^M0<c/X03>hYd0e^^V0<SRV@3GljT0c>ZP0<SZW@36jid0a^^K0P38ji/0
0`3:jI/0cNRK0<S[V@020<7^V@1h0<[YW@3KkjX0bMFG086;EP1GJS<0a^fd0<C`/@34jJ<0c>^X0=Kl
`@32lk`0/_3705>:JP2D[IP0LH1Y045@;`2dfYl0a?6`0<S_/023Ved0a]J?0=gbY`34jI/0`nNM0=;N
X02]/GH0Hf@X0=?WW`34h9D0c>JO09B@D@3BjZ00aNZL0=?WW`2i_W/0eO6W0;oSV@36hj00`n2N0=3V
YP2OZFX0K7/h0=SbZ@38hId0_kb]0?SkiP3nonX0o_oT0?7ff03oonD0lO;C0=CH/`3Dj:d0eoF]0<kh
XP3:lJ80eO2Y0<_RW03;fYT0amNF0=OZZP37hJ00`n2P0<kXZ@3=iJL0bmnP0<_PW@2Y^G80io:]0>G/
Z@3Sjk00d]nY0;kHZ01NNd/0`nJ^0;cNX@31fI/0Qi1Q0<W@Y03Ki[/0c]fd0<kH_`3Af<P04`l@09:<
T03oooP0j^kO0?_ok03akn00mO7U0?;_h03ooo40ooog0?oonP2YZjH0/kJ]0?coiP3Pjl00amBN0<SI
T`3=gYL0j?>g0=KOYP1EGB80G6DV0>;`Y@2ndH80d>fM0<WYW@2lgY@0anNV0;kLWP3Yo<D0SYaW0:^h
PP3Ij;40dnNb0=cb``3bomh0o?of0P3o000:0?ooo`050?Win@3hn?P0oooo034a<@3emOD01P3oool0
9`3lool0n_ci0?ook@2WWH@0d<FY0>SSaP3_kmL0i_GH0>Gie03CkK00cNRQ0<SVWP38iZ00cN2N0>SO
Y01REQ`0g>^X0=7]X`39iI/0bN^O0;g/V`39iIX0d=VJ06=[;`2b_7d0cNBL0=KbY`3Am:@0anfJ0<WZ
V`3<j9/0bMfE0=g^Z01gRCd0b=f>0=;WVP3Dk:00f_BZ0<CPUP0;0?ooo`002P3oool0f`32i9L0dO2R
0<[UV03@j9h0dNVO0<_XYP3>jk40hokA0?Som03iood0o_oj0=?V^03<jZ80c>ZP0<g^W`3;k9d0a>2C
0=KbY@3Kl:/0dnJT0;?3Q@3LiK00gN2e0?Ook03_oo80i?od0=gom02=^:l0iook0;oL[P2K][40jOoo
0>?oo`3Rool0k_oo0=7Vj@3Zool0ioog02`N7@1<<S<0oo[j0?omn`3onOl0ooSm0?ohnP3[hMl0oocg
0?[on@3iooX0nOoc0<3<]03HkLH0dNfm0<;[[`3BmK/0fnJl0<gH[P002@00d^F^0=7V[@33gI`0c>VV
0<?SVP39j:80[Ln507bSH02ikkd0]N2c0;W=Z03JiL<0g^C20=gS_@2f_i@0DV<]0<oQY`33eYH0enZX
0=;WXP3<hI`0d>FP0<GJU@3AiZ40UJYU09Z_JP3<hid0h?Na0<oYXP3:i9d0`MRB0<CKU@3>hih0bn2K
07Z?BP3FjZD0`MF@0<oPW03<gIT0Kh0l0;S4PP3Bfi`0amjH0:S6O02K/fT0i>VV0=KKV@32fI<0b^NT
0=ce]02RYG001PH008>EF`2CXV/0<CX303Q01`2`^7`0gnV/0=c]Z@32fI40bnNM0<;WV@39iid0f>:S
08bHEP3Aiil0aMnF0<GTV037ii/0f?J/0;WGS@39hi`0g_>`0<SOV@30g980`mnE0<OSV@3@kZ@0^]Z?
0=k`YP3Chi`0e^6M09^OHP2_[WD0k>Vb0=gJX`3NgJ@0LgTk08jGF03@gi`0b=^I0:2dK`2FZVD0`mB>
0>7bZ`3Jjj@0TJ5J09VXH`3GiZ<0f>VU0=W]Z03:hIT0b^BJ0<_UV`3?iid0b^:H0<cTVP37hIL0bNRL
0<c[W`3<k:00c?6T0<S`Y`3Wh:X0ckn<07=nA030`hX0W8mJ0>WTZP32iiT0bNjN0;SPRP3:m9h0aNnK
0<3RU@3=k:00c^BK0=3VWP3DkZL0c^RQ0>Gj]`3Ah9l0HfL/065W:@3KlJH0d>bQ0<SWV`3@k:80cN:M
0=_MWP2SXF@0[:ea0<_EUP3?kJL0^mnG0<;SW039hYh0fn6Q0=;DU@3`l;80JW4^0;;1O03=jIl0`>2D
0<c/X037ii/0c>NP0<3KU03>k:80_mnD0=CdZ@020<SZW@80bNZK00@0b^VK0<cXW@3:jId0aNbK0P2n
lID0M`38ji/0n?o80?kobP39dIH0//220<KUW`37jj40cNnR0<SVWP2;/g@0LZEZ07VnTP2YjLL0SJjK
0=K^f023VWd0RKR208ZnP02jhZH0Y[j20;2mN032e8X0`^NG0<W_XP3@h:40fn6U0=GFVP2kb880cNFK
0;oITP3UhJ80RZ9F0<O/W03@iIX0eM^E0<kZX036jZ80bNRU0<cYZ@3]olL0gNJ_0;;0Q@3?kJL0anJP
0?C^gP2h]jD0]KJV08V;OP3/k>@0iNCO0?oomP3koNP0fnnj0=3_Z@32kYD0`nfK0<?QV@3DkZL0gN^]
0>Gc]P3<fj00goNm0?;odP3Vo/X0dnZf0=3T/@2neY`0]LR604iO6036e8T0e>JL0=K/Y03<k[40_^B[
07ZQJP1mY6d0g?Rn0=WX[@29V5L0f>bW0<gTX03>h:`0Z[J>00D80034aKL0lOOK0?Gof@3>gZd0lOOC
0??de@2d^9D0k_;?0?3df`3moo00o?oh0;Fm[P3gon40c=jZ0=3UY03Chi`0d=^G0=GMX@1;D1P0Y:Y^
0?7j^@39fX`0fNnM0<CUU039kZ00c_J]0<W]Y@3?kjH0b^6M0<3CT@36fIT0e>RY0>Kmb@3eoml0k_oO
00@0o`002P3oool0103[jn/0oooo0?ooo`3Rh^860?ooo`0W0?Kkm@3ennd0k^k80:VVL`3>cXh0jo2`
0=GQX`3:hZP0a^:U0<OWV`3:jYL0c^bR0<GSW@3@hj40i]fR05a@5P3=g9T0b^JL0<kZX038jYh0`o:Q
0<o[X02?Ve/0dM^N0=_ZZ@3=iih0cNbP0<?XV032j9D0cNbN0=7YW@3DhI/0N84n0=;DU@3emkP0fMfP
0=[PY03Fh:@0en6/00/0oooo000:0?ooo`1?0<GXV03@kil0dNbM0<gUU`3=iI/0b>FU0=3]]@3^omh0
n?of0?Klo03nooX0c^:_0<GUV@36iiP0bN^G0<[/V03?k9`0bnNJ0=;WXP31e980k_k005IO:P3XjKl0
m_oZ0?;ol`3Bn]l0goof09O2^`3Yoo/0e>bl0=;[i`3Yool0i_oo0>_oo`3ko_l0n?co0>gooP3dool0
3@0002H92`3on?P0oooj0?omn`3olo<0oo[j0?oglP3oo_P0l_G/0?komP3oonh0f=[20<oE[`3AgJl0
d^Z^0<WMZ03RkLl0dMbn00080037g;<0g_G90<o]^@34iJh0a^b_0<_a]P36k:l0a>ng000F0001<`h0
DWEE000=000J=A@0aMnj0;gF[P1;GBd0JG=10>k[]P3PhJP0enjX0<SMV0020<kSWP1J0<kRW@32ei80
TjQS0=O^Z038hY/0^]B=0=oi/P3JlJ/0dNJQ0;kCSP3AiZ40Qi]F08ZNF@3Oljh0f^^W0>7b[P3;g9P0
UZ9P0>K_/03=i9h0d?2U09NaI`3BfI<0h^VU0<CKU@3Vol00`]^J0=[MZ0061P00fnZc0<_HX`3VkKL0
bm2H065V;00d?000enJU0=;WXP3VokL0`>:F0=;`YP2nb8T0Wj]Y0=O]Y@3Bk:<0b^VM0<?SU`3>k:80
_mfC0<KPV@3FjjP0cnJP0<g[X@3Jn:h0aNFJ0;OIS@3@mJP0c]ZB0<kET@1WJBP0BdH<05UB6`0_9@00
KfPb05eH803NgZ80g^:U0=GPWP3Ai:80>Dh90<;FT@3Kk:H0aMF>0=WYXP3Kj:80FfPS07f9A`3Cgid0
aMJB0<kXW`35hIH0cNVN0<GOU@30fY00cNVN0<c[W`37ii/0aNFI0<KXV`35jih0`njV0P3oold09`3B
gJ<0embR09nDGP3Fe9T0_nJG0<C[VP2ji8h0cONQ0<WeX034jIT0co2Q0<WQU`3@iil0b>:K0<WSW03D
jJH0b]JH0<c;TP1FFQd0[lMk0<kZW`3>kJ40bnFL0=c]Z@1JF1d0JF<Y0=OGV`3NjZP0^mnE0<[dZ033
iil0cNRS0=?LV`3Be9D0k>b^04A;202FXeh0cNNN0<CSU`020<c[W`050<[XX03AkjL0_=bA0<_[X03M
oK800P39jId20<[YV`040<cXV`3<j9d0bNVN0<?]V`80_?6E07L0a^bI0=7XX03EhJ40fMnS0>G_/03>
jYl0bnbM0<3QT033gi@0aNj/0;CXZP2[llD0DI9`02=6<P2B[YP0Pif00;CV/@1j/WD0d?Vm0<WQY@2K
YV80cMfD0<?XV03<lZD0f>RY0>G]/@3Jfil0UjAN0<WOUP35giP0i^:S051X7030iID0c^>F0<kDSP33
giD0b>bT0<SWY03<jZX0mOoC0=cT/`3EhZX0anFO0=Gg[@3gl>00inCE0?ool`3gn?<0oO_l0:bZ[@3o
o_/0nO[/0=O[^02lfiD0a_>H0<3ZV037iId0cnVR0<CBU03Agj80cmjS0=of_P3domP0m?oL0>OmcP37
fZ`0e>^e0<OLV@3UmZl0Ri]@0=odY@3;hiL0`>FR0<O_/`37kkX001@00<3MY@37eiP0>4X00>Ck[@39
i9D0cnFU0<?CXP062P00`<:/0??neP3Okkh0fNf`0<oHZ`3^ll/0LgU;0=SN/P3Sj<P0m__T0?[olP2U
[Yd0n?oO0<WNY@3=ij00ioB^05eV8`2JX6@0Ngi70>3VZP3;e9<0g^nQ0<GLRP39jYT0`^VJ0<7[X@37
kJ80a^RL0=cdZP37gID0^ln:0>3e]03Om/80mOoQ0??oi0040?l000T0oooo00H0m_Kf0?ooo`3fm_H0
o_kn07YjNP3lo?`30?ooo`0Y0?gmo@3lo?`0nooh0?;ji@3:cIh0WimQ0:6UF03@fHX0e^NI0<gXX@3:
jZ40bnfI0<_/T`3<jil0`MnI0=OZZ03RfIh0HeLM0=;QWP38i9X0cNVO0<GWV`39n:L0bNFJ08VEE@3T
l;80cmnN0=C^Y@38j9`0`nZI0<7WU033gi80d>RL0=WTW`1FGAX0F5<K069K9@1DCQX0G5TV09bLJP3h
nLd02`3oool000X0oooo01d0a^JC0<?SSP34iHh0c^^G0=CaX@3=ijH0cnJ`0?Goh@3jooD0o?oo0?_o
mP39iZ@0aNbC0<__V039jY/0b>JL0<OUW@3;jJ40b>RO0<SXW@3<k:00anJJ0<_RW01/Mcd0go:j0<W_
_P38h<00[/?40=[lo@020?l0003o0?3oo`3kood0n__o0?ono`3ko?l0o?oo0?_mnP0N40l0<alP0?od
lP3gk^T0n?G^0?oon03oo_X0ookk0?gin03ooOh0o_Wm0?omo`3ono`0oooj0?oon03noo<0o?oc0?[o
n@3LhND00@D>0?Won`3eoo@0moom0?3om@3Pnm00aNBX0<[^[P2jg:00cNB`0<gUZ`3=iih0c^VL0<c[
V`39lZ@0^^NR06BLK`0nNET0FYR=07ZgZ02;/8L0U:Ek09ZEGP2<R4T0hNRT0<OKU03GjZP0CeDI0<?4
R03JiYh0bn6F0<WZX`33hY`0b>6M0=cc[`3GjZP0Z;ej09N/J@3FlJ`0anNN0<7UV`36j9`0PiYB0;C?
R03;iZ<0fO:`0=c/Z`2daGl0Zkaf0=OWYP3AhJ<0i>^h00hF003Om;T0amfO0;WBT@3>jJH0d^fV0<oY
X02:WUL0TjAP05MV8`2LYfD0/kMj0=gFW`2IWF80dnRS0<OQV03Ah9/0i>^X07AZ;`2;P4P0WIQP09JG
G@1IFR40FeDU079_?03Dg:40f^JX0>3g/@2g]gT0MgPl0=OKX03@fY/0f^JT0=3RUP3JkIh0cN2A0=3M
U`3NjZX0e^2S09VXH`35gI40c^ZM0<?UV@36iY/0bnJQ0<kWX`3Aj:80cnJP0<cWX03<jjD0bNVZ0<[Y
YP3Fm:`0c>VI0<oZV@3El:<0bNBG0<g/X03Blj@0d?>Q0<?TW@3Ml/T0oooX0?_jf`3Rj[T0eMfT0:^b
K`3Njj<0b^bH0;gSSP31jiD0a?2I0;oYU`34j9h0eOVa0<OXX@37iZ00b^VM0<[YV`3<j9/0cnNM0=3U
XP3DhZ@0E58G06AU:@3Pi:L0g>FR08VBC`3GhYd0e^>M0=3VWP3<j9h0aN^P0<?/WP35k9d0b>ZN0=3U
Y03FhJD0fmjU05YG8P2XYFh0e=nM0=S^YP35k9T0ao6M0=7aY@35iIX0bnZN0<c[W`3?kZ80`^:F0<W[
WP33k9d0aO:Q0;[YV032kId0a^FI0<WYW@34jiX0_NNE0<G/W@39jih0bNNM0<WPV03>iY`0JH<i0=7[
XP3QnKd0fOBm0=Kmd@3Eomh044DW0<OigP2kg/00Mi5^02Tk4@34dYL0fO6e08c2SP1k[GX0ZM>Q0;gR
[P2[ah`0cnFW0=STXP3KhYl0kNf]05aF701dMCT0goZc0<?DT03EjJ80J7`e0=k[YP3Dgi/0E6PS04iX
8@3;jZ@0co2Y0=Wh]03Wo<<0i?No0=SW[P2@Vf40e_NP0>Sh^@3Uk[l0kN_N0?SblP3oo_l0[KVg08Ik
M@3an<`0dNRT0;kTS@3:jYl0eN^[000o0=;TYP2BX6<0UZIX0<CHV@3?jJ`0dNZc0?Ooi`3konl0k^kR
0?_mi`3^m<P0gNB`0=gUZ@3HiIl0[[eh08fSHP3:hZH0e?2f0;[FW01kVV40SkZ50<_dYP37j9L0SZEO
0=kX[02f_8`0G6150=o[^@1iSUD0c^F]0<OQY03GkJ`0^Lj90=S]ZP2W_7/0f^jc0<SKY03comH0n?oM
0?Oof@3Mkkd0d>:^0:bYP01kKT/0KUe108=bF03FdK<0hNO30=?`^034ijL0bnfQ0<WXVP3Ak9/0bnbM
0<?UV03>iIl0Sj9P0=WXY@3@i9l0bnJQ0<GRXP3;ijd0cn2n0080o`0000P0no[h0?ooo@3oo_l0o?cn
0?ooo`3oo_l0o_oo0?gno`80noco01d0n__m0?Sin`3ko?h0oOco09JFUP3nooX0o_oh0?Cli@3konP0
d>6g0=SY_038fJD0g>Vd0:2SJP3@dY<0YjaY0=CPV03AiY/0b^VM0<SZW@38jiT0bN^G0<S`Y`30iJ00
d^2R0::PI@1`JRh0g^VT0<kXWP020<W`X@0C0=kj[`39eY40eNJO0=K/X`3CjJ40a^:H0<cZX033hiP0
`N>G0;gOT`36j9`0cnnT0;cLT@3GjY/0enFH0=g[X03?giP0h>n/0=CTY@0;0?ooo`002P3oool07037
hY<0`Mj<0=7aWP2mgHX0bNRJ0<[SXP3?hjh0n?oQ0?[om@3lool0nOod0<WVY038k9@0bNbH0<GSV`39
iZ<0cnVX0<cYY`37j:40anVM0<GZVP38kY/0e?>W0;K3O@2hc8L0`^Z^0=[ZaP1iQhL40?l0000@0??b
kP3ooOh0oooo0?cno@3nood0no[h01H81`0D10@0oo[h0?olmP3ak^D0ooof0<g<a`3oo_d0oOWh0?om
o`80ooco0;80oogo0?ono`3oool0o_om0?[mmP3loo/0o_ko00003P3nool0o?ki0?coo`3am_T0kooN
0<oV[P3@k;80gOG30=7M[`3DhJ`0e^NP0=?XV@3@iiD0^=f=0<cj/@2akk`0BY1/01QYFP0dOVd0Q:b:
0;K7X`1JDR40BdD90=OIV03Kk:P0enZX09JNHP1fNc/0b=:90=SXW@3?kJL0cNRS0=_d/036gi/0d^^W
0=oh]01^RD@0^=J>0=3^YP36iYd0cNfR0=ok[P11G1D0cnRW0<CJVP35fYT0`mNB08nPFP2KZVL0e^6U
0<SBX00M:@00_=:D0<SQX03In;@0doF[0<;TV033hiL0_mJ>0>7b[02;UeD0GV8U07em@@3OfZ80R8aA
0=W]Z039gYT0];mk09bLG00l;@00DT4=05U?6P28QE00WiaY0:6DJP2<PE@0inFb0=oRZ@3>f9T0LFld
0:jbM`3YlKD0gnn^0<WOU`35hXh0`^2:0<kZU@3?hi/0cMfL09ZUJ@2``7T0cNFG0<o^WP31jY/0aN^N
0<WXXP3;jJ<0c>NP0<_VW`38j9d0a>ZO0<c_[`36iJ80cnfU0=;]W03Ck9/0cNFI0<oWW@3;iid0`n>H
0<3RU@3Cl:h0h_7B0?kok@3fn]l0dmV[0<gEW02IYUh0dN>G0=3]V@35ii<0_nVE0<3ZUP3>mJ@0]m^A
0<;VWP3:jjH0a^NP0<WZV`39jYT0b^VI0<cXW@3<ij@0dN>U0:ZSK@1SG2D0SheB0=WNW01iPSl0e>BK
0=3VV`3:jId0bNVN0<KZX035jih0aNbK0<K[W@3=iZ80dN>U0=SPY`1BC1P0VIAM0=[PXP3EiZ00^N2=
0<7]V039kZ00b^bO0<_[W`39j9`0anJJ0=?bYP3=kj80`>VJ0<3[V`30lIl0a?6P0<CTV03>kZ80`nFH
0`35jY`0M@38jYd0b^JK0=;/XP24V500am^F0>Kma@3/omD0iooX0=ooj`0KCC00`_?F0;KN^`1/SF80
GgM50>3[[`3Bi:H0]nZb0;O`^`2;`Hl0_>Rg096XLP3?gZD0c=fG0=OWX034cHX0SX==065L902keHh0
g_F_0=?TX01aP3d0bMFC0=WUX`30dHd0BEhI0=3^YP2adHP0d>n[0?CofP3gomX0hnc10<c>YP2Kb6<0
c^>H0=WRZ@3Ui<l0lN[R0?koo@38g=40KV5H08F6G01cQDT0e_NV0<[UWP31eIH0f>Z/0<;BU02FZFT0
/LJ30<KPW`38hJL0nOoX0?OnkP3km_<0n_KZ0?ooh`3Ff;00dmNU0>7[[038e9@0Kgm00;32QP3AiJX0
c>:T09^jO`1WUfL0`>jS0;[MS@3TnKP0cM:J0;:eR00?5@00dN2W08FMH@39hZT0e>ja0;gGT03Vok@0
]<j40;SBR`38gYd0eN^[0>?f_P3Un<40aMFT0<;BX@3?gk00lNg:0;6SR01gHTd0X8Ug0?okiP3Pi<T0
h?g?0<K//`3<kZ@0b^JI0=;YU`3Blj80_n6D0<oVXP2]_Gh0dN2M0=;SW@3ElJH0cnfU0<OVX`020?l0
00080?gon@3oo_l0oooo0?klo@3oool0oOon0?cno@3nool30?coo`0b0?coo@3Wk>H0o_om0?[ln@2L
WIL0m?K[0?OkjP3]mmD0enJk0=kc^02mdi<0e^VY0:VgN@2k`HD0gMjR0;c2PP3Mj:H0dNFN0<WYW@38
jYd0b>^K0<WZV`30j:40aNZW0=SRY@2CTeL0E50A0=WTW`3@jih0`njL0<7[V@3@iYd0_/F20=?YX034
h9<0`]jC0=SdZP3@kZ@0anFM0<WYX03CmJ/0bnfS0<CVVP34jI`0a=^G0<_NW03HkJ`0f>ba0=7T[03>
hj/;0?ooo`002P3oool0703Ek:P0c^RO0<_WW@3<j9h0d>^T0<SPYP3?hk80m?oP0?[om`3lool0noof
0<cUZ`3:ji`0b^RN0<GOWP3=ijX0hOVo0=C]/`3;jZL0bN^Q0<;WVP3<kil0c^ZP0=gZY01XO3D0`^VZ
0;_<XP1bPWP40?l0000?0?ooo@3oo_l0oooo0?gooP3nood0no[h01X<2`0O3`l0oo;`0?obk03oooH0
m?CZ08V8P`3in?H0ooom00@0oogo0?l0n?Kg0?ooo@3ko?@0o_oc0?oom03Yin`01`@=0?onn`3]j^40
oogo0?ono`3kon`0kocA0>3`b`3=g[h0ho7H0>OdeP3Sl/L0g>bk0=GV/037hjH0a>JY0<Sj_`2Of:40
Wn>`0;Cca01jWWP03BH00=_R[`2>TEP0IFT^0<gLV`39gY/0eo6Z0<_QV@2S/fP0VjMM06ef=`3Vl[80
`mZD0<[XX02mhIL0`>BJ0=co]P2@ZV40X;I^0=[UX@3IjJ80dNbM0;kHS`3HkZd0b^2O0=?XY@3RmZl0
cMjH0:joN`1/NSd0fnNg0009003CjJ/0g?Fd0;cIUP2mgI@0cNnS0=;bYP35g9@0i_Zc0=_ZY`2c^G/0
UieO02Tc000f@P@0en>Q0<oKV@19DQ40UYaL0<k?U@3Qh:P0cljH0=[HY@3IejH0h^6c0=GDY03Ddid0
WIaT0:NRJ02=SDl0f^2R0=cVY`2odhh0fO6W0<gZV03PoJT0e_:N0;W=Q@2K[6P0RYQJ0<SHT@3AjI/0
cNbL0<7XU`32jIP0c>bQ0<_YX@3<j9h0c>RM0<WZV`33j9P0cNnU0<GUVP3;jY`0e?2L0<kWUP3@iYd0
dnZT0<OPW`3=ijH0c>VW0=7Z/@3Nkll0nooZ0?Soh03FgZd0g^R/09>PF03=gi<0dNbK0<SWU`33jY/0
`nZI0=?fY03;kJ00c>jR0<OWWP3=kJ80bNZK0<WZV@3:jI/0b^RN0<[WY@3@i:L0jNJ_0<W7SP2ATUH0
F5lL07J1?@3CiI/0d>JK0<[YW@39jIh0a^ZP0<K[WP36ji/0b>ZM0<cWX03@iJ80e>:T065P9`1GEA`0
cmBD0<kMV03=l:00bO2O0<;[W@38kZ40`^:G0<SVW03=jj40c>JM0<GQU`3<jZ00bNVN0<[_XP31iYT0
anjO0<C[W039l:40cOBU0<;WV@37ii/0bnZN0=;XW`3Jjj@0XjiY0:fiM`3ImKX0hOo90<_fb@3=oMD0
34@O0:kV`@2KcZD023H701Hn2P3@kk<0^=JF0<;YYP30m;80T<Z=05>3B@2;W6H0OXaA0>Co^03?kj@0
a^2I0;2YLP1fLCT0`MRB0=GZY@3Fij<0d^6N0=?RW`3Pkj`0^/j90=W^Z@2K]Fh0foJ_0<?OXP3eonX0
mooZ0>WafP3cmN00h?nk08bJG@2OYW<0b/f^0?ook03^lml0j_oY0?omk@3IfK<0g>Zg072=BP3FlJX0
b]nL0<oRXP3JjZ/0b=^I08nVH03>k:H0`MjN0>3`b`3^m]l0oooj0?oomP3oon`0jNg<0>gbb@3an/<0
hnjb0<[JW02>X6@0L8A706Ei>P3Cl;H002T0`o720<_f[P3>l:<0`=BE0=oW[P31aiT000H00=?UZ`2C
ZF/0enbc0>Cj_03<iYl0b^BJ0=OaY`2H/V/0fNn^0<cRXP3Dj:d0bmjV0<?DWP3Ei[80g>bk0?oog03=
ajD0PW9H06mMA@3lm=d0o_oT0>cof039k;80c>fV0<KUU`3@jIP0d?6P0<;TU`39h9X0bMVH0=3OW03B
hid0d>bQ0<WWW`040?l000050?ono`3ko?h0n?Sj0?cnn`3looX00P3kooD0=@3joo<0nOo_0?Wok`3N
im@0nooc0?com03/l>80bLfl0?kok@3nonX0c]V_0=[[]`3?iJ@0dNRR06f0?P28V5T0hnb]0=OKWP2Q
YfL0cm^I0=3VWP39jId0a^^M0<SZW@39jY/0b^jX0<o][@3Hh:@0VYYN04Q71`3Hj:40c>RK0<3[V@2n
j9H0c>2H0:fbL03>j9h0d?>S0=3bY@2lg940_]jC0=CbZP3=jj<0bNBM0<oZX`33gIH0eo6Z0=CT`03i
ond0nOo_0>Sdh03goo80n?oc00/0oooo000:0?ooo`0M0>3_aP3fomT0ioW90>7e`P3Rm/D0g>k60>?b
d@3gon/0o?ok0?coo`3looX0d>:h0<gT[P3Fk;/0iOO?0>Shd`3hon40hO?90<cS[@3?jjh0bNRT0<KV
W@36hIh0f^jY0<SOU`1[S4D0dN2Y0>Ojg03BmMd00P3o00004@3bool0lo7f0?omo`3oool0o_oo0?ko
o@3oood0@C<b03PX:03on_P0oocf0?oomP3Bd/X0nOSc0?ooo@3knOX0oogo0080ooko08P0nOSf0?cl
lP3ooo40kNoI0?Gef`33_jH0Vi:900`3002VWXT0^:jE0?okn`3mlOD0oogf0?ook@3elNh0o_ko0??o
o`3gool0nooo0?coo`3noo/0n?_X0>W`d@3Umkd0c^>N0<OUS@3>kY/0b^Fb0<?U/`31g;40VJZ004a>
9P3Bfj@0_mRF0;S_V`2mm:00cN^Q0=_XX`1SGB<0f=RL0=;SW`3DkZL0_n6G0=7cY`3BlZL0f>VR0<OA
S01iM3@0d]>?0=;[V03Fk:40YKYe0;kCSP3?iId0d^JN0=c`Z03Dj:<0b]bN0=CQ/`002@00SYeR0:fo
P@3Km;80Z/En0<WWW@35i9P0gON^0<cSV`3@i9l0bmZI0=kc/03Bn:l0bN:N0=oQXP2/ZVd0TiaM0>3`
/@39ijL0_mnP0<_LZ03AfJX0gN2c0??ja`3oom<0[;Mk09BRI03MkZX0d=ND0=KQW@3NkJP0P9Q>08JR
E@2[bWX0YlIf09BcH`3Fl:H0fo:Z0<KIU`3Chj@0cnJN0<_ZW037kiT0a^jH0<WYW@3;ii`0cNNM0<gY
W03<k9T0anjE0<?WS`3<kI@0cNjE0<gYU@3;hY@0OY5?0;oAU@3=gJ`0d^>f0=7R]P3eon40fo7:0<kS
^03GjKT0d^6V0<oNW@2M[F@0eNNM0=7XX037hIX0b>NT0<[YY@3>j9h0`mj?0=[eYP3KmjX0cNVL0P3:
jI/09@39jIh0bNRT0<WWY`3<iZL0cmVM0=WSYP3EhJ40b]VD0=c]Y`3?ii/0cNRK0<[YW@39jIh0b>ZP
0<SZWP3:jId0bNZK0<S[V`39jY/0cNRK0=GQV@26SDT0VIiL0=3IUP3EjJ@0b>>L0;WSU`3>m:T0bNVP
0=3[Y036gIL0f^^W0=SWY03GhZ00d=^I0=_TX`3LjJ@00P3Djj<0N03=jIl0an>I0=[f[03>jZ00c^RO
0=7WW`3Cij00`M:<08JEDP3>fId0c=^R0<_T[@31gj/0`N^i04moC@1]Yg@0P;b802YV<P1SXV/0R[am
0>?jXP34iY80[=N@0<S`/@3<jZh0^]RJ0<ge[035kj<0e?R^0<_IV`3NiZX0HFd[0<GAS`3NkJX0go2/
04aP6`3Rm[40cn>N0<gQW02/`7/0T:AO0<_MX@3Vn]L0h?7A0?Woj`3lonl0hOkj0>o[d03Ccj00V:]L
09RTG03Vm;T0h?;J0?gdk`3cl=d0fnG00=3ZX`2?Zf00goN]0>7g[`2AYEh0HWP_076<?`2jfh`0`>2E
0=3T[`3aoMD0j>WG0;Ni[P1=DD80W:B=0;6jW@3boM80l?k;0>3_]P3?gZ<0bMVK0<cNX03Fk[@0cO;6
05Ml=P3;jj00`]RJ0<?BV`3FhkL000P00<cQYP2md900fNR]0=OUY`3EjZD0c^RO0<;LT`37hIX0^m:<
0<oVXP3EjZT0cN6R09b^L02S]GL0^lfA0=[[]03AgjX08b@009^EL@33_i`0nOWE0>kocP3<iJ`0b^VS
0<?SU`3=jYX0a>NE0<_^WP38giT0enNV0;70O@3Gj:40cn^N0<c[W`@0o`0003`0nooo0?Sno03koo/0
n?ob0>okh`3]oMP0h_?70=OY^@3@hj/0dnNZ0<GIYP35f:X0g>g106IeBP3@fk00e>2b0=7MZ`3Zn;/0
cmnN0;;9N@1gSS`0cnJN0=W^Z`39eID0fnBS09bWI@3JjJH0d>JN0<SZWP36jih0b>ZM0<WYW@3=hZ40
fNNZ0=WJWP1TI2P0aLZ80=7YW`3:kId0a?6P0<S_X03GiZ40Jf/]0<g]X@2fhi00^NBD0<kcY@33iIP0
gOV_0<SRV`33eY@0eNFT0=?MX038dYD0l_O`0?_oo`3go?l0n_on0?WonP3EhL/;0?ooo`002P3oool0
803_n=d0n_oU0?Soh@3hon<0jo_F0>Whf@3ao^@0nOoc0?coo@3nool0o?ok0=KSa@3Fi[l0i?C@0?So
j@3jon/0nOoZ0>;ad03>h[40cnR_0<_XZ038iZ00d>ZY0=_b[039hiX0eoF[04=A4`32ej`0_^Bo03Ue
G02WclH0k_oo0P3ooOl07P3oool0o_oo0?koo@3oood05PP701h>3P3omoD0oocf0>_Xg`2`/:P0oooj
0?ono`3no?d0ooko0?cjo`3oood0n?Ob0?kok`3oon`0gn310;bmV`15@200Dd`j00P0001ME3D0G58_
0?ofk@3onoP0n^gU0?ohi`80oo_o05D0mOoo0?Koo`3lool0ooko0?omo`3oo?H0ooo_0?oof03molL0
d=f=0=[XV@2ndYd0aN:b0>Soh03>hL<0D5Dg0=?L[@3DkZl0Z>JA0;;`V`2nhYX0e>VX09BEF@0?5@00
Tj9Q04iR7@1WOSP0d>NQ0<;HT03IjJ80fN>N0=SKV02RZ680bn:@0<gRU@3LlZX0d>JN0=[`Y`3AiY/0
bmnG0=7UX03GjJ/0g>bo024a0P3KjJh0EfLY0<;HU`3VokT0`n6G0<c[W`3<j9h0bN>J0=K[YP3AhJ00
`=VE0<C`Y@3=jjD0dM>D0>7OXP0X;P00a]VI0<ga/@2lh:80g?>o0?OoeP3nomP0io6l0=GRZP36f9X0
eNbX0<[UWP3OjZH0d=fG0<SITP1:HQH0dNfP0<c]WP2lgHh0c>^O0;cHSP35giH0c^>P0<kMY039gil0
b>>L0080anjK0<<0aNFI0<[UWP3<iYl0bnFK0<SWU`39kI<0bNbB0<SYTP3;jI<0c>BF0=S^Y@2FYVL0
g^fd0=3M[`3DhKH0cm^e0>_me`3Lm/T0_mZU0<[QZ@3Ik:`0d^>O09JVG`3BhY/0enZX0<gSX`36hZL0
an6T0<oTX`3Bj:00enfT0<[RU03<iiP0c>RK0<[YV`39jJ00b>VR0<SXY@3:ijD0g^j`0=?SY03FjJL0
dNNO0<cSV`3=j9/0c>RK0<[YW@39jIh0b>ZP0<WYX03<j9d0bNZK0<K/V@38jiL0b^ZG0=W/W@38e8X0
DULE0:J/K03HhjL0g>n_0;oUVP3;kJ<0d>^T0=gd[P3;giX0c=RF0=SSX@3IgYh0h>FU0=[LW@3QiZH0
i^n/0=_VXP3GiZ40g_:[0<KMU@3@jZ40bN>J0<_WW@3?jj40bNFK09fbK@3KhjL0eMnS0<oNY@3Bijh0
^mVS0;oT[P31kkh06ThM00Tn402ZiKT0F8]B0<SPPP3UoJT0g?Vg0=7c]P3;mkX0^^RW0;oTWP2hfI80
`mjG0=K]Z@33eY@0LgTi0=kWYP3Ei:40c=fI0=K[YP16FaH0fNfX0<cPV`3KjZL0Si]I0=;PX`3FjK`0
bMVb0?OohP3konP0kOoo0?CWe`3Qdjh0c^FG09n]HP3=gI`0cn?00?ook`3mnnH0o_oT0<oUY`35hIH0
`mjA0<cTVP3Aiih0]ln50<?NS`3Emj<0dO:S0<[OY032dZ40][ZO0?Kmj`3koo40noo]0=cWb@3koml0
nooJ0<KEW03Ljk00h?2b0=CTYP2?Y6`0]MBZ0=Ch/P15HaT0hOJk0<CGX03Ol<@000T00=7Y[@2J[F/0
bmVL0=GOX03HkJP0_mV@0=3ZX@3>j:40OYE?0<_RW03>hj00c>6N0:ZmN`2R]G<0aMRH0<GOWP37gj40
TYYW08J7F`0@3000hN:j0>Sf``3Cj:l0c>ZT0<GUV@3:jiX0c_6O0<GXV03Ek:@0enNV09FTH@3DiIh0
anBD0<SWV@3>kZ<00P3o0000?@3ano00nOoo0>gik`3aoNl0mOoY0=CU`@3EjKH0e>V`0=3YZ03<iYd0
b^BJ0<oXY`3@j:`0d^N^000<003SlK`0cmbV0<gKX02jbHH0d^>L065g9@2O]F00cnVO0<;KU`3Dhj80
e^6O0<kJV038fID0cnJN0<SZWP36jih0b>ZM0<[YW@3Pk[00f=jR0:FVJP2FV5T0jo:_0=;^X`34jiX0
a_6Q0<ccY03Kj:<0P8120<GUV@3;mZH0boBU0;gRU03<kZ40`=bB0=3WX@1VMSD0CE`K04UC5P1gOd@0
o_oa0?_onP3hooL0nOob0?[ol034dK<02`3oool000X0oooo0480KFYU0?oon03oooH0o_od0?com03i
oo<0o?oh0?_on@3moo`0nO[l0?ooo`3joo80oOob0?komP3lo_T0oOki0?kon03loo40i?;>0=?T]`3>
hj/0cnVX0<OQXP3Hmk40^m^@0<_SU@3;fHh0b^2P0<kd^@0nN580Q[>O0>_oo`3oo?l0oogo0?ooo`3n
ool0oOol0?ooo@0O4A002`000?ojn03oo?H0c/_20?Wil@3oo_X0ooko0?ShnP3lnol0o?cn0?gnn@3o
oo@0oooT0?ooh@3Qh;80C4hM0=OL/`22PVH010<00=cKY@3RhZ@0][6;08AmH01RGCd0TXiY0<K0]03i
m>h20?onl`1C0?onn03ooOP0ooch0?ohl03Xf]40IeY709fAN@2KT780WIQb0<;;W03fomh0fNCD05aV
F`1IHE@0K7]J069lC@2ljJH0_>jY0=Soa`2fgj<0cO2^0<k/[03EijT0h>^_0=oSZ030`HD0UIYJ0<oN
V@3IkjL0eoN/0<GTUP3;gXd0MXPl0<_OU`3Dj:00d^NJ09fdI02?YEX0Z[mj0=7WZ@37fZ`000h00=_V
[03EhjH0f^f]0=ca[02_bh40RjML069n=032gY@0Z/Am0<GNVP3;iZ40`>:H0=KaZP3FhIl0iN^[0;Bj
O01@FQd0`mJN0=K]]@3Ckk`0lOoL0?;ofP3Dj:/0bn6S0=3^Z034i9/0bnfQ0=WYXP3HkJ00DFPH0<CQ
S`3MnJ`0d>nY0<c[Y`2ogY/0`^2H0=GdZ034gI/0nOoO0>OhcP3HlKP00P36jih08`3@kJ/0fO6g0=W^
]P3=iJL0a^BN0<k_X03<j9/0a=jG0=CZZ@3:gJD0dN:[09RWKP3aolL0ho2j0?7jb`3TkL80ho;70>7n
aP37jZP0a>>O0=S^YP3Gjj<0VJIP0=;NW03DhJ/0cMf/0=k_a@3Um<d0l_[E0>ceaP2T/GT0T:5K0<kR
VP3=iid0c>RM0080bNVN0;d0b>^I0<S[V`3Qo[`0do2]0=gk]@31giD0d>jT0<[YV`39jY/0bNVM0<WY
WP39jJ00b^RP0<oVWP3:jId0aNbI0<?]U`35kID0fO6S0=7SV@3YkK00BDTC0>SW]`3=e:00dnJT0=c/
Z`3RlK00bmNG07b8B02EWUl0U9YL03Pl001CEaX0?d<605eM8@1VFQh0GU@G05aK6`10@P40]<=n0=K/
Y02ofI00`>FH0<;[W@33kj00bNnR0:^jM`1bOcX0gNJS0=oXY@3GhJ80KgY008>DI`2FZh@0Pi]k07bI
P`1JOUP0;5H00;G1O`3Jh;80a]f_083:S@1GXV40cnNY07=g>P3YijX0bN^O0<?XV`3PhZ<0LgPh0=kZ
Z03Fij<0dnZT0<[QV`1[OcX0_<f90=7LVP3QjZT0UZ1Q0<cOY`3Dik00l_o@0=?W]03Jm<d0ooG/0?o/
iP3Vnm`0kooJ0<oQ[`2/`gd0W:=P0=[Q[P3Vk/T0n?oT0<COW039i9L0f?2V0=7WW`33fi40d^jQ0<__
V03BmYl0dnZR0>7d]03Ok;L0c=jZ0<?IZ03<gk40g>o20<GFZ@3EiK@0UZEZ0;?1Q02nc940e^>[0<[J
Z`2bbj<0PiiI0=3ZX@3BiZ/0]/ZE07N<H`002P00aN6V0=W/ZP1HI2@0gNJU0=KZY@37hIX0dN^T0;WC
RP2neHd0UZeU0<kTV`3IkjH0b=bD09b`J03:gYH0anbO0<S^X`3=iZ@0h_6f04144P0n@0l0b]6M0=?N
Y03<iJ40bNNM0<g_XP2mhY80doJV0=3WX@3=gI`0/L1m0;[;Q03@kI/0anJF0<3QTP3BjjX0cnB[0=OX
a035f;P0k_oM0>oof`33fZH0d>V_0<_YX`3:j9h0b>VJ0<W[U03;k9<0_mnC0=_k/P0M>000T:UW0=_`
[`3@hj<0dn>R096RF`2;WE<0c>:@0=;XUP34hiL0fON_0<KJU@3Cgid0[;]h0=CUX@3?iYh00P38jYh0
7P39jIh0c>RN0=cPX`3XiZ/0GV0Q0<G>R`3JjZ<0anVL0<C^W02niiP0`^:G0:F^K@36a8T0e>RS0<SS
W03?jZ<0Z<Aj08:LDP39hIL0d>NO0=7VX@35f9H0a]RJ0<gOX`3Fi:L0e>:W0=o/]P2S[X<0ko_E0>gh
fP/0oooo000:0?ooo`0;0:jTY@3jm?@0ookk0?Gdk`3oooX0o_ok0?_mn03inoP0oooo0?clo03oool0
0P3oooX08P3oood0oooo0?ono`3oood0oOoe0>cjf@3Fik/0a]ZU0>Cm_03Nn;T0`nNO0;GGR`3Fji`0
b]N809nfKP38kJX0X]V_08BfW@3Vool0n?Go0?olo`3oool0o_oo0?cnn`3kn_P06`d<03XZ:P3olo40
oocf092=Q03oooP0ookk0?ono`3oool20?koo`2D0?konP3noo80iNK70>k_a`2=ReP0P8=>0<oJ[`1V
KD`00`T00=oUY@3RjZ40h>>^0:naPP2PY740K74g07AhE`38ak<0oo_d0?oek03on^X0ook/0?olj02`
YHl0RGiZ0:VMS@12=RP0ZYfD08AmJ`1UK4<0a/JZ0?oomP34al00T9ZA0765JP1HL4`0bnJc0<WW/`2b
gZT0`_>k0:[FU`3;lk@0e>ja0<gQYP3JhjX0fN6V09^UJ02V^gP0bnVS0<;[W`39kZ40cMnC07N9?`3:
gYL0d>BL0=GZW@3BjIT0KhDj059X803<hZ@0b]f`000@003BgJ<0f>JY0<[MW@3?i9l0cnVP0=C`Y@3;
iid0b>BJ0:O2N`2Q_7L0dNZV0<[PV03Jl:P0c^:K0<[KU@3AfY/0D5@I0=;GX@3JhZl0h_[80>kog03Y
om<0eNj]0=;[ZP31giT0f?R_0<?XV`3NkjT0Z;e`0:2gI`3AkY`0a^:E0<c[Z035hjD0bNNY0<OVXP39
jIh0b>6O0?Woj03fonH0h?S80<?WX@3;kjL0aMjT0>Glb03Ol/@0dNRb0<[TY`3:jZ40bnBR0<WNYP3E
ikD0c=fa0=CT]`2Y^840c]fR0:2^L@3ao<80d]bW0=?T/037iJL0bNfW0<[ZX@3CjJ00dN>I06ik=P2C
WF00e=j/0=SS^@3konH0n?oW0?ook`3oon@0Z[6708nMG`3Sm;00c^FM0<_UW03:j9h0bNVM0<S/U03=
l9`0jOo60>?o_`3=kZL0b>RM0<g]XP80bNZK09P0bNVM0<WYWP39jJ00b^RP0=3WW`3;jYh0a_2N0<Oa
W@37kY/0d^bR0<[KU@3^lKP0OWi<0=?BYP3LgZl0eMjO0>7ZZ`2AVU/0RY=D02df001GHB80NhE608VC
E02R[6d0RYAE09bRI02NVUd0XImR09fOH02FW5`0U:1N05m`;03LlJ`0_mZC0=Sh[`36jZ00bn^R0<kM
V02e`W`0UZ1I0;>mMP2MZ6@0ZkUk09J/N`38hKT0R:J408jaW@0cGc`0O[1W08ZOI`2NZ8D0c>K109_T
[@1OYVX0d>BY07Qg?P3PfY`0f_V]0<7QU@3Sj:P0_lF509n[J@36ei<0a=VD0=?XX`1iSDP0T:5M0=7M
V`3BgI/0eN6S0=;R/@3=gJ`0n?oJ0<KJZ@3=iK<0dJ6C0?W:a03[onT0i?OG0>oof@3@i:D0c=JG0<SA
VP3>ejP0gNg00<_TX03<iY`0c^FO0>3e/P2me8h0d>ZP0<7SS@3>l9X0bn>G0:NkMP3Agj40dNRP0<oZ
Y`3<i:H0b^6Y0<oS[P3@hj`0dnJV0:ZjN`3Ul[X0g>Vd0=KU^P3=h[T0Qj5J07F;@`3QlkT0MhUG06Ih
DP002@00a^:X0<SMVP2__Wd0fNBP0<OLU`3DkZL0d>ZS0<_UW038giL0DVTQ0<cRV@39giH0c>6F09V^
H`3LlJH0bNjN0;;KS03;jJ<0b^2O07f6C`0F6`00Z:]f0=OOYP3DjJH0cNRQ0<[/X032iiL0d_BW0=3W
X`3NkZl0dN2O09NXHP3?k9`0a>BA0=?dY@3?j:H0cN>U0<kU/@80o`0003X0kOo=0<SRX`3;j:D0bNVN
0<WYW@38ji/0b>^G0<W[U@3;kJ40_MbF06^9@`39hZ00cnBS0=3SX`37fYP0Uj]T0;kBRP3Ek9h0cnJH
0<[YW@3;jj00b=jF0=[YY02[^WD0e>FO0<kUW`3=kJ@0a>BK0=3[Y032fI<0h^>W0:^YKP1dNCT0c=NC
0=c`Z030iID0_nRI0<cbY@35hiT0TIYK0>_Z/@3EhJ<0e>NW0<oRX01NLRd0/lV10=;ZX03?iid0cNNP
0<cWXP3<iZD0c>JW0<kQX@3Jj:/0a]FL07j;G`3eomd0nOo]2`3oool000X0oooo00L0nnS/0?ojo@1>
@T@0ooco0?ono`3no?l0o_ko0080oooo00D0no_k0?ooo@3ooo/0ooko0?omo`020?olo`0O0?ono`3n
oo/0m_oU0?Sog@3gom@0f?>`0;[ETP2njYd0^>6C0=CNU@3Sjj00T:QJ0;[NU02ai[80EHa/0=Gol`3g
m?l0ooco0?ooo`3nool0oOol0?kmn`0M3`h05PH60?ojn03ml>X0c/_20?knmP3oooX0ooko0?ooo`02
0?coo`2D0?SmmP3moo80g]nm0=OFZP1JEA/0[Zme0=oc`P37ek8001400<oPV@38fXH0kOff0<3AS@3E
jiT0c>F:0=G/Y02<UFP0ooKo0?[UhP1WG400UiA[0=cLZP39dIH0j>ni0>?Y``3oonX0o_gh0?oon03o
onD0ookZ05eB?P39bkD0e^S>05I^E00T=1X02@L007IkF`2cgZT0_>ff01Hn301YTEl0cOW40<?b^`32
kk@0[M^M0<Sd]@2cfYT0^mnO07NGEP3Cl:h0e>VT0=KYY`2ndi00DVLR0<SNT`39gXl0dnRK0=7UWP3C
iJT0bmZ_00XJ0030ci@0g^j`0<CGU`3Ll:/0bn:J0=K^Y03EkjH0b>:I0<3KU03DkjX0d^NR00/@003E
i9l0cnjR0;kNTP3:fIH0h>6U0:jRKP3EcYX0gN^f0<COZ038iJ/0c^BS0<KLV`3;iIh0c>RN0<g/X01J
KB/0]lj00<ONSP3>jIP0c>JM0<gV[`3:i;@0d^bm0<WWZ`38j9l0bnFT0?Wom03hoo<0iO[C0<OXX`3<
kJP0bN6_0>Gjd@3eonH0l_oN0>7ib@3:hjT0e>Fh0?_ojP3ionl0m?o]0?Sok03?hJd0cN:Q0<WNT@3H
jZ00`M2;0=KZZ`36iIl0_]jC0<[VV`3NljP0bMJ@06Q^<P2m`X`0l?C?0?SkgP3noo40oooh0?ojo`3o
ooH0iNS=0=gW/P3Bh:D0cMnU0<oRZP3:hZH0bNBQ0<SXU@33iI40anZV0<KZY036jZ80a^^N0<O/W`80
b>^K09L0b>ZM0<WYWP39jJ00b^RP0=;YX@3>jZ00a>RP0<?XXP39jJH0bmjV0>Od_`3BeJX0WIif0=WN
]P1HFbh0EeLI08nADP3Mhj<0a]6?0>Sd/P3;g9P0dNFP0<KMU`3?iZ00eNbV0<WTW@2oiIX0]mV?0<[U
WP3DjjD0eN6O0=7JV@3QijL0Fe/M05mO8@3Vi:L0e^6O0<7fY02`i940aoBQ0<C^W03<l:H0bnbW0<cX
]@1OO50000d00<SUc`2lh<H0/>Je0<Gec@1>MeT0]Mbo0<W_bP3Dn<X0`MVO0=[^[`16EQL0f^ZY0=;R
X@3NjZP0gn^Y0>[f]01@G1X0d^6N0<kOV`3Um[80U:EQ0=3QW@3@i9l0c]nK0<gKW@3<fY`0fNj]0<KL
V`3YlMT0PcXW07lm7@2lhI@0a^FR0<kV]03honl0m?o]0=;O/@2T/g00>5000<ORT`36fY/0Sj5W0=7O
ZP3<gZ@0h_Rh0=[i[@33hY80OYE703Y:0@3@g980cNR90<c]U038iiT0b^BS0<_RZP39gZD0ambI0<kT
W027VEd0d>6[0?Wog@3aomH0fo2U0>;bY`1DGB@0C5DZ05EP@0076PL0^mJQ0=Wd/@3;i:80fNnW0<ON
V01hTT/0eNnX0<7KU03;hYX0Z;mg0=oe[038gYD0bMfE0=S/Y01>HQX0d_6S0<7TU037jIl0`=nI0=3R
Y02EX6@0c]6H0<oBV@0<60002b000;??Q@3:k:00^mfA0<CJVP3PkkH0fnV/0=OWYP3Onjh0cnjN0<WZ
V`3;iIh0g_Bc00@0o`0000<0a^JJ0<[ZWP38jYd00P38jYh20<KZX00b0<KWXP38j:D001000=C^[@3C
jJT0bn6P0:JkNP3Bij@0hoZd0=;/Y@39hiX0c>bP0<[ZWP3Jl:L0eNBO0=3KU`3BhI`0cn>N0>7k]03C
kJH0g?6^0=_[ZP0^=000UieM0<kMV03=hiX0cn^P0<S[V`31iYP0b>JL09>ZI03Pk:h0j^ne0=[NZ`1M
I300RY5K0=?QX`3BhZ40c>BJ0<cXW@38jYd0a^^N0<?[XP32k:@0bn6S0=7SY`3CiJ/0T:5Z08bOI`3A
i:d;0?ooo`002P3oool03P3onOP0/j6Q081`L@3onol0o??f0?ojoP3ln_d0oO_n0?knoP3no_`0oook
0?onn`3oo_l0oogo0P3oo?l07`3oo_l0o_ok0?OoiP3homd0mOoD0<[UX038iYh0_NjO0<OaY@3Nhj00
f^:I0:c4MP3=kj<0`?:m04EnF`38mnL0oO[o0?kko`3oool0o_oo0?koo@3oood02P000551@@3on_P0
oocf0?oomP3oooL0oooj0?ono`3nool00P3kool0U03dnO80o_oc0>3Q_`3NgK40HU`R0=KFVP38g:L0
d>:j000:003KkjL0d^FC0;K:P`3Nljh0c^RA0=WgU`3Bkid0gNjh08miO01YETl0UI5[0>?W]02mahP0
f>VR0<gNVP3Agjh0fN?10?comP3dmn`0ooo]0?C]d`2RX7X0>44F041G:`0/A2@0MH=Z0>cWe03oonP0
e?_40<3`]P38kl<001400:oQ/032n<@0X=ZP04EoA01UVel0`>b_0=7g_036hZP0Mi5D0=3VYP37fih0
hoNh0=O/Z`1mTdP0^m210=?XV`3NlZ/0d>:V0<WFZ`002P00LhE909BTIP3Ml;00aMVD0=[`Z03NmZ`0
`=N?0=3ZX@3CkJH0b>>N0=7TXP19B`X0gnbW0<KVVP37jI`0c^BL0=SQX015?PL0Mg8k0;o8T@3Ai:`0
f_:f0<[QW@3;hYh0b=jF0<[PU`2X_7@0QYUI0>_o]P3Ek9`0d^^J0<?JU036g:d0dNRn0>Kle@3CkkD0
anJR0<WSY03goO<0mooa0>;gcP36j9h0cNnU0<WQ[@3Tm]00n?oZ0?Koi@3Qn<X0bN:[0=?O]`3loo40
noof0?Son03goo40jOg:0=[`[`3Ek9X0gO:U0<;FSP2DZVT0_]bF0=Sf[035giD0bm^D0:F`K02BUE`0
hnFd0>SYb@3lnnH0o_oe0?ooo@3kmOl0oooh0>[ZdP3Cg:L0cMRP0?7oc03?gk00iOS:0>Cka@39i9d0
iOni0<S[Y`34j:80bNfU0<GZW@34jI`20<S[V`2G0<SZW@39jIh0bNVP0<[XWP3AjIl0c>NP0<KVY@36
iJT0c>Va0=KV^@3QjL00o?gK0>O[b02OYh00X:Mk0>CYZ@3DfYX0f>BR0<SGU03JkZT0cNBN0=;YX`3D
kZL0d^bU0=S_Z@2ng9@0bOZ[0<C`X`2ohIL0bnJO0=o[Z@3Cg9/0i^RY0:^UJ@1iL3D0FU0E08f=C`2n
hYP0e_^^0;3EQ`30iIL0_>:I0<O^Z`31j[80FXAD01I36P2hiLH0_>_;082eR`1GTFP0PKNE0;cXa`2f
bZL0b=V_09bhO@36iZD0d_:a09f_M@3>g:40aMVD0=_/Z03Ghj40Lglm0=3KV@3KijD0ho:_0;g>RP3E
k:H0c^FO0<cRVP3HiId0fnRP0=GZW`3<hYL0d=Bk084Z5P2ICBT0dOVQ0<;TV03Jm[/0h>kG0?7ok@3N
l;h0dnFK0;O@J`3@j9`0c]nX0=SV/`3Rk/00bmVX0<;EW@39i9d0dNfP09FZG@21STH0d=b@0<oZR@3<
kI@0anJJ0<_UYP3Ek;H0d>N_0<gTWP3Cjj40]lb;0764C03bomH0iOW60>3aX`39eHT0bm2F0=[L]039
cK8000H0072:FP34hj00anJR0<oZX`3HlZ/0Uk5Z0<oYXP3LmZl0amjF0<oVWP3Ejj<0amfE0=c`Z@3?
hi`0]<R10<KPUP39j9`0d?2W0<g^Y`3=iZ@0d^:T06e`=`3PhJL0h>Z[0<OHU03BjJ<0VK]_04e^9`30
eYP0c=^T0=o/]03>gYl0Eg<X0<[YV`2jfh`0f_B]0=3VY@040?l000030<[[W037j9T0b>ZM0080b>ZP
0P36jZ802@30h9d0cnf]008L003Lm;H0a]bL0=CZZ@1HKRd0c^FQ0<CMV@020<cWX00W0<OWV`3FmZX0
en^S0=KSWP3=f9@0dn2K0=OXY03<hid0a=^E0=?SXP2HY6@0IW4_0;o<Q`3:h9L0d>bQ0<[YW@3;kYh0
do>W0=?]YP0nD`h0bMNI08B>DP2i`I00jo?40?koe@34diP0hOBd0<CNU03<j9/0b>^K0<K[W@32k:00
`NfR0<KOV`39gYd0f>^[08NLF`3=hj80dNRT00/0oooo000:0?ooo`050?ohk@2ORGh0oo?/0?ojn@3b
i^P00`3ooOl01P3oo_`0ooom0?kmn03oooH0ookk0?ono`80ooco0;D0n?Sj0?konP3Ok/d0b=^]0<CM
X`3<jZ00`^6C0;G/V@3:nJ/0dm>G0=WNWP3;hIP0c>bS0;GT[@14PUT0UL^d0?gjo`3ooOl0oooo0?ko
o`3nood0ooom03h`;`0;0000oo[h0>7DcP3oooH0oOge0?oonP3oood0o_oo0?_oo`3iool0n?kj0?co
m03JfkT0h=fb06IM903If9P0^<Z>0>Kfb@002P00Lh=205U[8@0fB0h0_]6I0<KQTP34hhH0`>6@0=C]
Z`3NgkD0oooF0<kQW`32fY00]=>30<o`X@3;jj80_mNS0<_M]@3honh0nOg_0?ook`3lomd0bN^E0;cQ
Q02ngXT0e>6c0=3F^P3nonl0h>k=0=7`[039l:d0[=^i0<3_b`0GBB<0?G1705J7FP2=_8h0Z]RY07RR
L026[WX0DgQ405Mh@`26WFL0P9MS0<kSZ`3Om;T0^m690=CYWP2=WeD0]<Eo0=?QY03Cg[<000T00<SL
W`3Tn;T0SjAS08^PF`2:X5P0V:iU08JME@24Ve<0X;Ma0=ce/@3>iJ40`]>?06Ei<P3CkJ<0_]Z=0<;S
U03Ko:d0c^FM0:FiM00i?`40TiAJ0=WMXP34fI@0bmnJ0=;OV@3Yljh0MGHb0=GWZ@3KkjL0e>VL0=GZ
W`3Ai:@0hO7<0>gmh03eon`0dNVi0<7NW03HlK00o?of0?Wok03Vn/L0aNVA0<c`V@3=iJ/0f^g00?3o
hP3bomh0gO?40<oW[@3Jh[/0oood0?[on@3hool0l_oe0=cda02ge980eoBR0<KST`3Dl:H0[lR709^f
L@3JlJ/0f^jW0:B_K@2UZF`0S8YI0>KS^P3el=X0oog^0?gin03ooOl0oOOo0??ai03HfKX0bm:L0=SQ
ZP3gomX0inoG0?Wom03ioo40g>c80>3fa`3<k:T0aNJQ0<SYXP36j9`0anVM0080b>^K0180b>ZM0<SZ
WP38jZ00bNVN0<cWVP3=j:<0gOS30>3gb`3VmmD0m__W0?ool@3bm=l0m?[P0=W[a@3Ll/40aMnF0<kZ
X038j9d20<GUVP220<SXW@34hYP0c>JM0<cSV`3>giT0dnVQ0>Oo`@3=jjD062l005IY9`3QkJd0c=JG
0=_TY@3?f9T0am2A0>gg^03De9P0^iYW09=e@@0l<@00FUTP08bQIP28YF/001@00<?h`P1i/Wl05E<T
03=^@02`i[D0Y^Bc0=Woh03Zon<0oooJ0>oa`02ngYl0X/j?05>5B02M_I@0Mi9U0<;RV@39i9d0j?Nd
07f6A@3HgId0dmRH0<cHUP3Hk:L0_MfD0<G[X037jI`0/Ki^0=7NS`3ChiX0fnbV0=OEXP2<8`h0SS0F
0;oYW@38kZ<0d?2W0<_RWP31hIP0dnjW0=;YX@39gYT0gO2h0?CoeP3^m]40XjR809FLNP36djP0gO:g
0<;HU`2;VUD0NH8o0>;YX`3Aii80cNRQ0<WRZ@3FkL<0mOoT0?Gog@3DkZL0an:E0>7k/@33g9P0/<F=
061e>P3GiY<0eMb<0=_IX03oom`0oooY0?Ckl`36gK40[MBC0;KQW03Nokd0cN^S09:/I@3CkJH0^=:;
0<gTWP3<hid0bn2K0<oTW`35f9H0d^FS0<kQX@22ST`0_/f:0<cZY03@m:`0b>VT0=Sa[`3?ei/0TI9H
08nEE@3RkJ/0a]NC0<[YX`2ngY/0DVL_01LU002V/gh0amJM0=;]YP3@kj<0CVhR0=G_Z0@0o`0000D0
a^FE0<_/W@3:ji`0bNVM0<SZWP030<SZX00X0<cYZ@35hJ@000l00<GNW@3Ll[40/LR40=;[Y`3CkZL0
fON]0<oaY032i9P0a>NG0<[YV`3>giP0Z[E`0<O@S@3IhYl0aM6?0<gMW022TU40FfDV09>IG@3<hI`0
cNVO0;OIS02nhi<0eob/0<KUU`3JlZP0`mB@0;;1P03Jk:h0l?o60=W_`@3Kl<L0k_oF0<oX[P3Lm[D0
c^fQ0<[YV`80bNZI0P38jYd01P3<jIL0e?2L0<_TT`2N^F`0`=Z@0<kYXP/0oooo000:0?ooo`0P0;VN
S@3F_k40oo[_0<>d/@2<OWh0no;e0?olo`3oo_l0o_gk0?ono03oooP0oood0?oonP3oo_d0oogo0?ol
o`3oool0o?oh0>She03Ll;l0dnf`0<3PU035i9@0_?>P0;OWV`3AciH0H64U0=G[X`3<jZ80_>^d06ZY
OP2@aZh20?omo`2Q0?ooo`3nool0o_om0?ooo@1JC4/03`000?ojn02QU8h0ooof0?oon03oooX0ooom
0?koo`3kool0nOoo0?Won`3ioo<0hN;20=kK/P1VGB@0hmnP0<[JW02O[7h000T00<oMW`35e8l0c=fY
09naO`3>j:40`n6;0<GUVP3;jJ40dN6F0=?XV@3<jY@0dOFM0<gcW02khI@0c>n[0=[a``3fonD0n_ob
0>k^iP3If<H0j?o;0;[]Q03Joi/0^Maf0>7Z]@3]l=40fn[C0=;X`@3Dl:<0]mfB07^hUP0oN5D0/n2o
0<?[b@3KnML0i?oL0=Wec`2ohkL0b?;20<Ge`@33kkX0DVXh0<cT/P20Uf40bn2W0=;XX03?i9T0dnFK
0;W8P`2CWV80eMjc00PC003Hk[00_mFE0=?XY`3Gk:L0e>ZR0<_QV03Fk:@0dnZR0<3GT@32fID0eNjZ
0=G_Z02L/f/0aM^B0=7YW@34jYL0_>VD0<_fYP2mgI80fn2P0=;9T01JDAP0HFXY0;G0OP3Ch9X0d^:K
0<OGSP1PKc@0d>6K0<GGR`3HkJ80dnFW0?7og`3eon/0mOo_0=7Y^@34hJ40dnb[0?OnkP3ionP0ioc4
0<OZS03<ki<0bnBS0<kR/@3Um=<0looL0>7gaP3?i:T0f^6h0?ool`3noo/0n?oo0??on02gdJ80foVi
0=3_W`37iYX0`MnI0<_TZP32fiT0GW8]0721?@33c8/0f=VM09^IJ@3TgkT0l^_H0?_ej@3oo_l0oogo
0?Scn@3[j]H0c]:_09bTJ`3LiJh0o_oV0?col@3kool0nook0?3lj03LkL/0bNRU0<OVXP38ij400P39
jIh20<S[V`0?0<SZW@38jYh0b>ZP0<WYWP3;iiX0c^bV0>kof03bon40m_oZ0?gml`3gm>/0oooa0?7i
hP3Ail40_=RW0080a^fN08@0^^>D0<SaXP3>mjP0b>ZM0<?SU`3BjZ00dNFM08jKE@2FXEd0Mh5209ZS
I03Ujjd0]K]m09NQHP2Q[Fd0fNVX0=K_Z`3AkjT0/mN?0<o]Y`3>f9T0dmfN0:>aM02U/gP0TieY09ZP
L01EDB`0CD8R061?=@0j7``0d<V]0<;i`02?aXl0]N2[0<OU/`3Uk[T0e=fT01lk003AnKd0[mjX06ZH
L`26/HH0dOF[0<g]Y038ei@0RY=B0>c/[P3Lg9h0fNBR0=CXX`30i9X0`nfQ0<gaY`2PZVd0dmfQ0=gZ
]@3komX0]k6108dN3@2Q?BD0aO2N0<_cW@33iHl0g?FT0<[]V`3:j9h0d>ZS0=c`/`38fZH0nOoN0?ko
iP3oonX0bLnc0<oI]P3=h:T0a]ZK09ZVI01TKB`0dMRE0=;WVP3>iZ`0b=fb0=CWb@3don`0l?oO0=C_
ZP3@kId0h_n_0<3LT@38h:@0cNJU09FSCP2PYE<0i^6W0<2cT03Md[h0k_?]0=W^a@1nYVL0e?no0:gI
SP2ogiH0d>ZQ0<OQV03[okh0aMbH0=7XY03Jkj`0aMZG0=g`/03DijL0bmfO0;[3Q01oRDX0d>^X0;oS
W@2Xc8H0dNj[0<oIW03UjJ`0BDh>08nHE`3JiZ@0dO2/0;_KVP3Ik[H0`m6P020/001RLCX0d^fX0<?Q
U`2YbGd40?l000040<cXW@3:jI/0c>^O0<o^XP80bNVM02d0bNVN0<SZWP38jYh0b>FS0<WSYP003`00
dnVX0=[aZ`2gcXH0T:YQ0<[YW@2ifHd0g?na0;oVU`34iiL0e_FW0<SJT03RkJP0`<N40=[QWP3SkZ`0
M8=2086@C`3JhZH0h^J[0<gWX03Fn:`0^N2A0=?jZ@3?m:@0eo>V0<cRV@3FhZ00f>BT0;?5Q`3Rn;X0
c>Vk0<OV_03`oml0bNR]0;[JV@35iIT0b^VI0<[ZU`3<jIT00P3<j9/01P3:iY/0c>RM0<OQV02E/6T0
^MB?0<k/YP/0oooo000:0?ooo`0>0>kEcP3A^k00GDLj0?ojk@3onnd0UXEk0?okm03oo?H0oOOg0?on
o`3ooOl0ooom0?oonP3ooo/20?omo`0@0?komP3Wl]80cNRK0<c]UP38k9@0bNZS0<kVZP2nlYl0_>jI
08B=EP3Cg:L0_=f40<KbT`2_jJh0GJ210976_P80ooco06d0o?km0?Soo03gooX0nook04@i=`0=0000
ooWh0>SFe03oooX0m_Oa0?oonP3nood0o?oo0?Woo`3kool0o_gk0?oomP3Bck00eMJ/0;_3R03Hi:@0
e^^`0<oQ/@002P00f^b`0<_PU@2DZEX0cnFJ0;kITP3=kJ40^N250<obWP3bolh0e^^Z0=[[W@3LjY/0
Z;AX0=[QZ`3Oi[`0joGL0?Gok03doo40b=fn0<7IW@36iIl0cNnI0<o`V@39hXl0g>n_0>Gj`@37i;H0
c?320<K^_01VUF/0K[FS03:8K`3CoNl0e>oX0>koo`3gonP0o?oL0<c`/033kK/0/mb@0<SgYP2cm;80
BH160:_AX022Wfl0Igi60<gSY@3DjZ40c^>H0<oPV@2>UeH031800=kVZ`3LiJ`0dN>Y0<_QX`35hZ00
d_6]0<KUV@3XokL0_]V80=W_VP3;hHh0fo2[0<?QV@1:H1P0amJA0<cMU`3:j9h0do6W0<[NV@3IgYh0
am:@0=oYZP2c]7X0Oh160=[PXP3Hhj40cnFM092OG03Ah9/0eNBQ0=k/]`3Xm=00nOoi0080nOoo0500
kO_R0>7bb03Eijd0e^6g0?Kof03Tm/80b=jM0<[TW@3;hY`0eNbX0>koc03hom`0looL0<[E/`3IgKX0
nOST0?oom03gn?80oood09>KMP3Fh:h0`ln?07R4AP3Eh:H0gnVg0>Ca^`3FjZ/0b=jM0=c_[`34cIH0
l^W80?omj03on_H0oo[i0?Sno03noo/0ooO[07j0F`2UXWL0WXIH0=WIY`3oon40oooV0=OW``34ejX0
c]jP0=KUY03IiJD0f^NQ0<[HR`3Nk9d0aMF>0=CW/033fJX0b>Bc0<g_/`2mj9H0b_>U0<OJ[@3GjL40
lO_S0?komP3oood0ooco0?omo`3looH0m_oW0<cU[03?kZ/0do>W0;oOT`3<jil0d_6U0;_GS03?jIl0
cNFK08ZNEP2;W5D0b]ZC0=GTW`80dNFP03d0dnBM0=?UV`3CiI/0bM^A09FVG`2=W5/0TImR0;;0Q@3C
hjD0fo6Y0<?IT@3:giX0dnRS0<cOW@3>gYl0fNBX0>Ka]`29TEP0inbf05]R;00B7@00e=j/0=3M[`3D
i;<0dNNW0<kTW035fXd0V;1V08RUHP3<ml40R[5j0=?_Y02djYH0cO>X0<WLVP2:PDP0f^2T0<WTW`3?
jZ<0TZ=L0<oUW03@iYd0^<N60=3OY03?g[D0n?oV0<J5K`1c9`d0^WiI0<gDT03KlJP0`^6E0<;/XP2o
kJD0`NbU0<?[Y036jZ80a>RR0<OPZ@3GjKl0ooo]0080oooa03X0/j^F0:jWRP2OVFL0L6/a0=oVV@3E
k940dN^T0<GLZ03:fk/0n?oa0<CC]P3=hjD0c>JL0<_/U@37jI<0cN^Q0=CYY03>hih0cNBL0=3XVP3S
lZl0jo7304U0@@35aKd0_n>c03=Z:@2fn;00a>bU0=SbZ`3FkJD0cN>K0=SYXP3=gYL0a]ZB0=W_Y`3:
iIh0anFO0<WXXP3@iJ80enRT06Mn>03@jJD0c^NS0<ONV03EiZ80h>^Y09^QH@1IGal0dMNG0<_YW`35
jYd0b^BM0<kSWP3DjJ@0c>>M0<_YX`3Dljd08Ch0103o0000>`3>ii@0anF?0<OWU039jIh0bnZ^0<c[
/P39j:d0a^NR0<WYX03Fkjh0`]NL000=003?i:T0cn:Z0<gPZ02caXh0eNV^0=W]/03Jk[40b^2P0<WQ
Y@3Qm[d0gnR_0;k4R02l_Wl0embI0=SRV`1eQSP0Ria>0=gYW@3Dg940cNjG0<3[TP3:ljD0_^JO0;gT
X@39k:`0a>BU0=?b[`32hId0bnZW0;[JV@32jJX0b_6b0;CIUP3Hn:d0aNBF0<cXT`3;ii80cnbH0<?S
T03?lJ@0`^NJ0<SVWP38hY/0dnZT08nSGP3EjJ@0cNBN00/0oooo000:0?ooo`090?oim02]VI00dK^`
0?o/gP2;M6H0nNKH0?odj03on?40oocm0080oogo0200o_co0?kmn03oo_X0ooko0?omo`3moo<0iO7;
0<[XT03:kXh0a^f@0<[ZY`3=hZX0[]j:0<[gXP3Fh:/0c]^V0>So[P2Ve740/^bb03EeF`2@`[l0o?[o
0?oio`3nool0nOom0?;on03eooH0Fe9=01/91`3VdM00k=[J0?Sel080oooj06P0o_om0?_oo`3kool0
o?oo0?onn`3_j=h0jNK705YL=03GiJP0c^6Q0<gWZP3EjKP000/00=;VZ`39gY<0U:aD0<?JR03El:d0
do:^0<O^U@37jYP0mOoJ0<[NX`3BgY@0SYI;06Y]:03IeZT0jnS70?kol@3ioo40l_o]0<CO]P39jIh0
eO>Y0<SPU03:hYH0`mV@0=;YY@3>j:L0`N:]0;cP/02egkL0FH]X0:[egP0bRgL0hOon0>koo`3Am?H0
h?7O0?_og`33hYh0co:l0<K/U@31kY40WMnH0;7][@1;NDP0dOS90<;P[P1=IRd0fNj[0<WMV03QlZh0
d=bL000:001?DQT0f>2U0=W[[`3Cj:d0e?>`0<7RW@3BlZL0/M220=WdX`2=Y4`0f>^I0=3TW`3<k:<0
WKA^0::aKP3Hhj40dN^T0=G/YP3Hij@0fn2P0>Ch/`38gIX0j^jc0=7BV03Tj:/0g>FT0=;WXP2FYUl0
gnjY0=?RX@3GhkD0eN320?[ooP3kool0n?oo0?Wol`3^o=/0cM^V0<oKZ`80mooH0<H0dnJ_0=GY[03E
k:@0e^fU0<SLW`3<g:/0kokG0=SQa03@e[00e]Vl0?cnj@3ooo<0FEY80>;W_`3?eZ<0d]^L0=SPY01E
GB@0e=bY0=;LY`3Ejj/0_mRF0;C:RP3_nL@0XYIl0?oij`3onOX0o_Ce0?Oon`3_mN/0oo[X061R>`2P
Vg40`Imj0>CS]@3jn]P0i>?40=WZ_P3EkK<0_M210>;`X`1BGA/0DUhF05=O4`3?fi40eN2N0>?`a@3i
on<0i?gE0<k/]P3AnjT0_>:G0=7R`03bon40o_oc0?oonP3ooOl0o_So0?gjo`3kooH0n?oX0<WSY038
iYh0c^ZO0=WeZP37hIL0`]bB0>3h[P3CjJ00a=ZA0=[^YP3Fij00hO:[0=KZX`3<ij00c>RN0<gXV`3=
j9T0cnRG0>3gZ@38gI80i_:`0<_EV01FFbD0e]jS0=_/Y@3?h9T0eNVR0<?IT@3@iil0enjX0<CNU`38
hi`0S:MR0;WGT@2O]W80DUDL0>GU/`3@dJL0d]RZ0<cRX@3DkZ@0eo>N0<3KRP3>jZ00]]VO09FbN037
gi<0^>nK0<cfZP3?hZ00]Zef0=OQY037iIl0cnZS09NQG03ChiX0dnFK0<?BS`3IjJ/0b]^^0?Ooh`3o
k=<0I3HB0>_<W@3Wk:T0dnNP0<OWWP31k:D0_nbY0<?[Y@36jZ@0b>ZN0<caY03?kJl0f>nk0?_oi@3n
oN/0oooa0=kC`@2FS740TXiN0:BTJ03=fHL0e>n>0<_WW03Cj[80e^O50?Sol@3Ij</0cnBY0<cVW03:
k9D0a^ZC0<_[W`3CjJ00c>JU0<OXX`35jiH0cnZK0=SU[`0@10H0W96E0<KQ^02A`hH0X^FP0;[SW`31
gY/0b^>O0<cQW02odh`0g_:Z07:8?`37gI@0_m^A0<?QV@3Jn[40c^RQ0<oTW`3CjZ@0TjYT0<kSWP3J
kjX0aMVD0=g/Z@3;e9<0GF<S0=;GU`3@iYh0c^RO0=KZXP3Jjj@0bmnG0=S_Y`3FmJl0a^FQ01/h002m
cYL20?l0000l0<cOW@3?j9D0b^J?0<OWTP37ii/0a^JW0<OVZ`38ij`0bn^R0<WZV@3BjZ`0ambT06Um
BP39gJX0c]nb0>KgbP3Nk/40[[j?0<OEY03Rl;d0f>Jc0<WM[03VmlX0nOo?0=WKZ@3<cI<0iNZZ0=7K
UP2P/6D0CEdB0=gYW@3KhiX0bnVC0<7WT033ij40b>Z]0=_l``3Bl;X0gok50=oo_P37ij@0dNn_0<3N
X034ijD0a^VU0=_l]`30g940cnZK0=O_V`3BjYH0f_>R0=3]W@3BlZT0a>FP0<k/YP3>j:40dNJQ08RG
DP3DiIl0e>ZR2`3oool000X0oooo00`0oo[b08]jLP3om>X0oncP0?ohk@1UCD<0FT<k06ACC03oo?d0
ooko0?Kgo03oo_l20?ooo@0?0?ono`3ooOl0noof0>Cbc`39iYH0bN^D0<G[UP39k:`0cnR_0<7XU`27
Z5T0bljI0>[i`02niXh0`nnF0080o`000?l0ao?b0?;jo`3nool0o?oo0?Gnn@3hoo/0o?oj0:nTX00M
2`T0_:RW0:fMW@3oo_/0o_oj0?oonP3nood0o?oo0?_oo`3nool0ookj0?ojl02c/940H6<h0=KVZ03;
h9/0`mjI0=W`^0004`00fNbd0=O[YP34fHh0eNRV0<kP]P3;h;L0c^N^0<KPX`34fJ00e>VX08BDB`3H
iId0h>Z[0>3T_`3[k]<0nOg^0?col@3ionP0b]f`0;kLTP3@k:80c>:I0=GZW`3:gYH000d0024g001>
JcD0<U8Q000@0032lL<0/?[901mVE03bool0X[Fc01QAB`1mXIl0c^GE0=g][P3EjZD0`n^;0<K^SP33
fY@0`=jN0=Wod@1=OdX0^nZf0;oU/P2AZGT0d>>e0=3R^03<h[`05BX00=GXZ035f9H0@ULB00lV0034
gYL0cNNP0<cVW`3Ilj`0b^6K0<;IU@3<hI`0a^2I0<G[X03Imjl0e^^V0<SIU@3@l:L0aN>K09jcKP0d
?`00a=jG0=7/Y@3Ei:40en>S04YE4`3Vljh0cN6J0=?RW`1>GaT0h?6]0<KDW`3eomT0m_o^0?_on03h
ooX0nOoa0?;oh`3domH0mO_E02@Z103_mlh0c=fY0<OIW`18GaL0GWH/0=G/YP3AiJP0hoG10>;ba@3B
hJX0e>2^0<[EZP3lon40o?oM0=GRZP3BhJ00iOFZ0=;RV@33dXd0E6@U09FUIP3@iJ@0e^b[0;c;U03o
omX0mNGE0?ojl`3omOD0oogh0<3;^`3Uk]T0oogW0<;=Z`3Qh/80[Hii0=KF^P3^kMT0ooo_0>Ogd`34
fjL0GVhU0<GERP36hIX0`]^I0<[PXP3:fZT0ioC909NNO@3NiL@0n_oK0=OS/@3Chj80aMNK0?3og@3i
onP0oOo`0?oomP3oood0oogo0?ono`3hoo40mooU0=3ZZ`3?jZ<0aMfC0=_cZ@1HL2H0^]:80<?KT@36
g9<0d^RO0<SNU@3Ejj80g?:Y0<;IT@36jZ80b>ZP0<SZW@38ji/0bNZI0=?bXP3=k9`0c>JL0<?MUP3N
mK40amjJ0=_aZ02mdhX0RZ1H04iT702mdh/0dNJQ0<WNV@3Nljh0SJ9O0>?h]@38hId0XKmi05AO9@3P
dJH0KEhc0=3FVP3@jZ40^nfF0<SlZ@2mjIh0a=bX0<cMZ@3Bj9d0aNbM0<7KU03Lj:P0MWLm0=?SY03<
hil0e^NS09VPG03@i9`0d>JM08nHE`3>f9/0e^:`0?WofP3@fJ@0cn:R0<cSV`2ef8@0bo>M0<[aWP38
jYh0b^RR0=CSWP3Ghi/0en>G0<_XUP39jIh003P0an:O0<oP[03Ch;@0gn[00?_og03iomH0e^n^0<k/
Y03<kI`0b>ZC0<cYY`31g:T0bMnk0?OojP3con40d^fZ0<SWV@3:kYL0a^bI0<CYW038ii/0a^^V0<?^
YP32lY`0b>^K0<oRZP080000o>g`0>;Ya`2<XW<0?FDa051c?@2ifZ<0IXQ<0<3RY@3:j:P0b^VV0;[E
T03Fl:T0OI=;0=CXX@3JkZL0hOJa0;oFT02leXl0fO>/0<GOV02BZF<0`mRC0<_LV03OjjT0cMRF04aE
502_XVd0]Z9`06MF8P80o`0004<0eN6O0;kLU03<kJH0f?Vd08fSH`1ZNCh0g>fg0<CGW`2>Z5l0dNbK
0<o_VP3<kI`0bNVN0<OWW039j9X0c>^>0<g]R03Lk[`0IgIE0<WF^03ionX0noo/0?_ok@3jon`0o?o/
0?Gnh`3lonH0o?oT0?Wok03kon`0k^cC0<g8Z`30^YH0g]^b0=?DZ03KiK40io6m09ROJ`3WjKL0cmfO
0=W[[@3Chk80enJm0=CS_03gomd0lOkB0>Oe`03Dhj`0d^6Z0?OocP3bolX0nooD0=WX/@33diD0eNFT
0<_OV03@hI/0cMbK0=3NX03^nL40o_oC0=W_[P3;iIh0a=VD092OFP37f980f_2X00/0oooo000:0?oo
o`0>0?kgk`3Aa;`0Z9N?0?oik@3F^Zl0bjjV0<V`Z`1D@C/0n?3^0??alP3lool0o?co0?kno03nooX2
0?koo`0<0?Wom03Vm]80bNRJ0<[/V035jYX0b>Z]0<o[/02hfHX0Z<1b0=WHX03Hijh0aNnM103o0000
o`3`ool0nooo0?Woo@3bnoH0nOok0?konP2AQX804@000<6_[@2bY:<0ookk0?_jmP3oooX0o_om0?co
o`3kool0o_oo0?okn03ooO@0C4TZ0?oofP3Ai:@0c^FM0<gYW`32fYh06bl00<gPZ03KkZ`0Z;Ue0<oN
Y@3@gKl0m?oV0??of`3gomP0e>RY0<OLU`1mSdD0g^nY0<;BU03BfKL0i>WC0?kom03noo40o_oT0<OD
YP31fi80d>NO04IJ4P1ZNc@0YkQa0=ga[03?hj@0cNRa082NK01RPeP0/]VZ093;V`1AUHH01b<G000:
000?A3@0HH1k07V>O`24XU`0`N:C0<KSS`3@k9P0cNFI0=[_[031f:@0`mn_01@n3P0gJCH0Z=ZY09K1
U017IT@0eMk;00060039hj80a=fK0<CKT`3:hYP0LhTn0:FiL@2ndhh0eNZW0=W_[`2S^7d0cN>U0<GO
V03=mZX0b>JN0<OLU`3>hYd0_=jD0<?QV@38gIP0RYID0;kHT@35hi/0c^:K0=CUX@15DPd0d]nJ0=_/
Y@3JjZT0?50;0<[NV@38fZ00fNVj0>cig`3ioo40io;R0?KokP3fonT0o?oS0?ooh`3Mh<40i^c:0<_G
Z@3JjkD0f>nY0:c4NP24Ve<0P9IE09ndN`2nd9`0bn2O0<oSY03Un<00n?oF0=S[]03Bij@0cnFL0<WP
SP3=i9@0enjP0:FkL`29WEP0eNZW0<cQX03MikD0oooN0<JeZ`3onOH0[inO0;jg[@3Lj=00g>K;0:n_
U@3Gi/D0emjo09QkK@3DeL<0oood0?ool`37e[D0g_C308>DC@3NljH0bNfU0=7_/@3Ck[T0^<NV0>ci
g`2?TgP0dmJg0?goe@3IgJ/0embR0>O`^`3eon80nOoV0?;jh`3ooo@0oooj0?glo`3nool0mOo_0?Go
h`3>j:/0bnJQ0<OMU03Rn:l0HgT`0>;h[`34g980d^ZP0>7i[`3Rn[00_]J<0<_SV@3MnJl0aN^R0<KZ
X036jid0a^^K0<S[V`2dehD0bnjL0<3PU03FmZX0^=Z>0=Sh[@3@j9h0i_jd0=3VWP3GkJD0f^jW0=?W
XP3@hId0e^NS08fLF`3Ah9l0bn2K0;cNU039gYd0m>Zi0=C6U`2o`8H0b]jI0;3QS`2[h900_>^S0<kY
]02O/Gd0d^RO0<SVW03FiJ80c=FD096KG03?iZ80c^6O0=[UX`2IX5`0c^JL0<gXV`2SZV@0f=jN0=KP
[03lomX0do:f0;WNV035jih0aO6H0;kZT@34kYP0bNZK0<gWWP3Di9/0f>:I0=OTU03?jiL0c>^M0<_W
W@00=P3CjJT0cnFW0=GZ[`39hjH0cNZZ0<7VX038lZH0`>^L0<GWVP3:iZ/0a^2`0=?Y``3eon@0jooC
0=;]YP38iiL0b^fI0<K[V`34j:00b>RL0<?[Y@30kZD0`?:K0<W`W`3AjJl03P@20?7QhP3oo=d0^/6H
0=7Z`02I]XX0TK6206^@G02QaY00coFj0<W][`3BlZl0dNbY0:^oNP2mc8L0cMZD0<3FSP3GkZP0e>jW
0<[TW@3:iIh0SjUR0<ONV03YoKP0cmjK0=cXYP38di40MU<Y05TY1@@0o`000480`n6I0<k`YP2ohi/0
bN:P045C5@3LkKL0^ljG07J?B`2N^6h0c>^M0<OUV`3<jJH0do2^0=Wd/@3;iYL0bNFA0<gK]`2Y]Il0
jO;Q0?Gnk@3joo@0k?;V0?SnlP3bm^P0o_oc0<gA`03gn^T0nOoa0?Wmk`3on^`0ln[I0>;G`@3fkm<0
mO;C0=kT_P39cjT0M7IA0>k[b03Uj;T0nOoA0>W]c03Kg/40oooY0?ooiP3oon40iN^k0>3W]03Hgj`0
o_oB0?oof03en</0e=ZZ0<oJXP21Se80SIeN09bZK00c?P80<CT005MI:03@cJ00d^NV0<cVW`3Om:l0
dn:M0>;c[@3Bj:0;0?ooo`002P3oool0703oooP0oogf0:nRVP2?Mfd0PVEM0?oWh@3Sb/D0GTU40?om
n`3kn_P0l_Oj0?gmo`3ooo/0o_of0?conP3lool0n?oa0>?ec`3:jId0c>fL0<SZW@36j:/0a^BT0=Ga
Y02BXUL0hmjV0;k@U02kiIT40?l0000>0=Wbm`3ao?l0nOoo0?Gnn@3looX0mOG]069EC`0>0000cK^i
0>?Ee03mnOH0oook0?oonP3nood20?coo`3o0?ooo`3ooOX0oOGZ08b9J03/l/@0fNj[0<SRV03ElJL0
IGe102i23@3?hZX0a]VG09VYJ03BhJX0i>kC0?_ok@3Hi/80i_K70=GZY@2`aWd0fNnT0<gSV`3Kkk@0
dMbn0>K_fP3noo@0o?o/0?ooh@3Tk;/0@UTA06Ek<`3Ol:T0a]N@0<kNU`35eY80go:b0<[QZ@0Q?0T0
CFXl09FfQ`0WER`001D703]NB02D]YD0S/6P08VVTP38gl<0Qk1R082YFP35fI@0enJQ0=W`XP3Ci9h0
dN:/0=CX]`2igjh0RKV704b2D@1STVP0Y/VY07R3M@0@70H0eOBh0<k/[03KmJh0amfD06Qj;P2KZf00
d^>M0<kRW@3AiJH0HgY20:6fO@32g9D0cOJZ0<cZXP3Kl:/0fnnZ0=7aZ03Bl:P0f>fX06ag=@39hi`0
dNnW0<oUW@3Pm:d0C5TD0=GUWP38fI80dNBR0724?`3Vn[D0fN^]0=3QZ`3WmM40kocN0=3La03conT0
n?o/0?7jg@36aZ`0oooX0?;efP3Mj<00e^>e0<CIV03BjJ40enjV0=3WX`3QmkT0fo2e0<[TW@3=ij00
_MJD0<gUY`3@jJP0a^2F0<gXV@2ieH40i_n^0<GPS`3Snjl0hoV`08NLE`25V5P0f>2a0?ooh`3JbL80
oo3_0?okn03onnd0ZkJD0>[fdP3oon@0jooM0>WdeP3oi=/0oooc0?Gek@3ooo@0b]Vh06QnC@3PlJX0
b]nB0<gaZ`2if9l0^MBY0?Ool`3iooH0mOWR08J:J@2i^h`0fMVW07ekB02^/H80e>Bo0?7og03Jh/X0
j^oK0?Sjk`3jn_X0o_om0?Wol@3hon@0c^R[0<WTW`3@iYd0a]bC0=;XW`34fY40dn^Q0;cDRP31fi40
^mF;0=_eZ`3Fl:H0/Ln50<KZXP36jZ00a^^N0<K[W@36ji/0d?>S0=[o[`2lhI40bo2P0<C[VP2jghl0
^]B:0;?=P`3?iYh0f>jV08nSG02[_7P0jORe0<OCT@2X/W<0c]RI0=OXY038jYh0c>JO0<g@U`3Og:L0
WIaS09RTI00oJ1`0hoo90<Cc[@1_T5/0]<fF0<kTV`3Cij00g>:R09bQH@3BhZ40c>NR0=?OW@3Nhj<0
VYmM0<cVW03<j9/0WjMN0=;IUP3BfZL0n_oI0=?i_P3@n;80`^^O0=GoY`2bfX80b>jG0<WZV`3<j9d0
d>JK0=?UV@3Aii@0anB@0<CUU035i9@0cNVO0<OQVP37hYd0`=nK0=Sl]P2fhIT0`NnV0<3[X`37j:<0
bnB]0>3gb@3[omT0gO330=of`03?jj00b^NG000V0<[[VP39jId0b>VT0<c[W`32jZ@0_nZS0;c^V@34
kIh0c>R]00@0003jk>T0oooS0=_I/`3Eh;h0bMnk082JL`1_T6D084HG08R`O027/7P0/mNI0=kl_03C
j:<0^LR308fJE03Ejj<0cnJP0<kXX@2mf940dNbU05ag<039hi`0dnRS0=k_Z`3<fiP0gNVW064Z2`1Z
7`P40?l0000B0=7/Y@2mgiD0a^ZP0=;]Z03AiZ<0K8150>_oa021UeH0]m6:0<kYY03:ijD0dNbg0>;j
b03]om80e>Rc0<gRZP3Ylm/0FV9E0P3looX0;P3nood0oOol0?koo@3ooo/0moSb0=3Ab@3Jf]80o_ok
0?Sim03on_<0oo?/0??SeP3on>P0noGO0?ooj03Ef;d0Gee40?ooj03oon40oooO0?ook03oonl0k^SJ
0?Kaf`3akM00dm6X0=SJZ`3WjKP0oooC0=cI[P2MVVl0Ti9T07=lA@1bP4D0T:9T08nOH@2JXf`0e=RU
07QaA@2cZX40dNBT0<CNU`3:giX0`]6<0<gNV03@iYh;0?ooo`002P3oool07@3looX0no_c0?ojlP2a
W9L0ooOc0=Nk]`2?MW80oo[f0?_dkP3lnoH0l_Sd0?coo`3gonX0l_gM0>Sfd`3TlmH0j?gF0=G]^@37
jID0bnnH0<W/VP38j:L0anRQ0=3VW@3KhYh0akb40=CVZ033jjd0e?2o0080o`0000l0g?ol08J^[P3K
l?<0n?oo0?Kln03oooP0no;[0:2ARP0=0000oo_h0?okn@3oo_l0no[h0?oon`3oood00P3nool0/@3o
o_l0oo[d0?onl@2JVWH0emn^0<gWX03;ii`0Xkah0<kSZ`004@00f>^c0=__ZP2gb880dMnR0=SR_`2l
`j80c=FV0=_Y[P2?Y5L0[lIf0<[UUP3=j:40cNJ]0?3oi`3conh0o_oc0?oojP2o_Y00IFPa0<gQVP3D
j:40eNFN0=SXX@3AgYT0g^fZ0<;@TP3Nl;H0//N?0=K^^P35fZl09D4[0526MP33ik/0c>ne08K2O035
kZ`0`>6L0;[WUP29/7L031H006AY@01hT4@0Qj9K07:DF027Z740QZ5^08nUM02O/8<0amba0=7Z``1>
LE40014008bcQ`22Xg@0dnf`0=K[Z03@gY40X:eN0=CRU@3Eiid0d>JN0:JoOP2AYfL0enRT0<;PV02Q
]G00SiYH0=_TX`3<hid0e^^V0=GQW`2DUUL0hO2]0<gTW03GkjD0b]jF0=;OV@3Kjj@0eNZO0<gRW`3C
j:<0CF8M0<cQWP3DijL0iOJo0?Wof03Hik`0d=^m0=7K`P3nonl0/ZnP0?ool`3oo_40o_o/0?_oi03=
hJ`0`MVK0=C_ZP36gid0a]jP0=3ZZ`3@l:D0b^^L0=;dY`3:k9l0`N6E0<OXV@3:kId0eORV0;SIR03?
lZ00anRG0<WXV038gYH0^lV;0=?AZP3oonH0mnGQ0?ojnP3ooo40oooX0<cMZ@38fj@0`mFQ0<GZ]`34
f[<0m^3E0?com03ooo@0knkL0;C7VP37h:H0eNNK0<cNTP3dom@0kooM0?;okP3`n_/0nooo0?kok03n
oml0g^F_0=kS[@2/[H40J6e40?Kof`3ioml0c]Zf0=[Sa03Ni/h0n_oa0?_ol`3RlM@0enW10<OQXP3@
jJD0a]ZB0;O;P`3DjZ40d>JM0=3XWP3:i9X0c^ZO0<OVVP3>kJ40d>nS0<[YW@020<[XX0<0c>NP06`0
`MfC0=OeZ`31i9@0d?JS0;WTR`34k9H0c^fQ0<c[W`3Fl:L0cnJN0=CUW`3GiZ<0Jg@c0>O][@2OXfH0
eMJJ0=_PX03@j9`0^mf@0<?YWP3<ij80^[V0071[=03FiJ`0PZ1T08bdMP3>nl00^nFV0=O[Y03IgY`0
Ui=F07Uk?035hi/0bNVP0=OMW@3Rh:<0VJ1M0<cVW@3:j9h0W:MS0=WSY03Ih;@0m?[F07Z2G@2obi/0
WZ]c0=7UW@3KlJH0`m^?0<WYWP36jZ80`NfP0;o^W@2okiT0_nVG0<K[V`36jIL0bNVF0<KVT`3=k9`0
f_R^0=3^Z03Fm[L0_^2T0<cZ]P3@h[80k?W=0>[gb`3VllP0cmjW0=?SY03?i9L0cnJF0=3XWP3=i:00
dnRW0=3UVP3>ijH0bnVY0<S^X@38kIl0bnNZ00040036a;D0inC10>SV`03bl]X0mOOR0>W^fP2T]Yh0
a]o20;[P^`31j/00Mj9]07ZQJ02bdHh0c>JO0<oUW02ab800a^2I0>Oo^P30fi@0eoF]0<?QV@24WeP0
eo6Z0<GJU@3>hYd20?l000170:0c;P3GOV`0o`000?l0003Qf:40eNnX0;oPV@3?ljT0`N2J0<oXY03G
k:T0bn2M0:VoOP2fc8h0d^Ve0?Cog@3bon/0lOo`0?OonP3bo?d0m_ko0?3dl`0o@Ch0moWh0?kno`3o
o_l0n_Wo0?gjo`3ooOl0noWl0?;^k@3oo_d0gMSL0=WDf03on_d0ooWj0?KSg`3om^l0oo_a0?ool`3d
mNL0ViN<061GCP1EBd40S89i0:RMV`2o]K@0/ZRW0:ZRU@2QWH@0WI]d06IU=`1AD200I6<e09bJJ@3K
fjL0fmjW0<kNX03@iJ@0cNJT0<WRX03Rl;D0d=RO09fEIP2NSf@0e>BU0=3ZX`30eI00VjYU0<?DSP3A
iil02`3oool000X0oooo02`0m?_d0?Cek`3el>X0TGmk0=c4`P1WCTX0jm??0?k/j03on_@0oO[c0?co
nP3go?P0kOSJ0>_jc`3;gJT0b=^^0<cT/P3:iZT0bN^D0<S/TP38k9D0b>VT0<?SVP3:h9P0hnZW0:>I
GP3Ml;00g_o=0??oh`3ooO40lOok0=con`1jZ:H0dNg^0?7ko03lool0ookh0>?Fd01[FU<060T20?of
lP3ooOX0ooko0?Sfm`80ooom07L0o_oo0?ono`3ooOl0oogh0?kdj02KVgD0b=:N0<o[X@3<jil0X;If
0;c@W@002`00c^>Z0=;XX025VT/0h_>/0=7M[@2HXG80eMnP0=gZY03DjI`0amj>0<KQTP3:iIh0`=VO
0=W/cP3Him80o?o_0?koi01HF2@0f]jS0=CUW`3AhY`0dN6J0=?SW03PkJP0CUdJ08fLF`3;gJ40cn6W
0<GJXP39gk0073XP000L0033e:L0cnRa02ig<01l]FH0coZX0=C`YP3:gkP0KWmM0<WO/03>mj/0^>2J
0<g^]@37i:h0g>Ze09>KJ016CAT0MH9=0<[N[@3:kl<0014008bdTP27ZH@0bn>_0<gSY@38eX/0fnRI
0>;aX03FjIP0aMZ=0=cf[@3:h9P0FVDS04EO601DHb00G68R0=cQX@3@i9l0e>FQ0=cUY02SXF@0cmZH
0=W]YP3Jl:D0cn6G0=CQV`3AgYP0e>ZQ0<GLUP3Il:X0b^6K0=S_Z@3<hIh0jO^m0>ooa`3?h:`0cMVe
0<_F^03noo40`Knb0?chk`3oooH0o?oa0>olh03>h[40amnU0=3]ZP3Bk:/0b^BU0<cXZ`3<kJH0bnfQ
0<_`XP36jid0d?:U0<SZWP020<K[WP150<SZWP36jih0b>^K0<[[VP3Bj9l0g^f/0=kK/P3oon@0m^GN
0?olmP3oond0oooS0=7UZP3EjjX0cnFU0<3X[039hk@0oN[K0?cok`3oon`0emNm0=3T[`3Ekjh0eNZM
0<oQU`3jomL0nooV0?Ook`3kool0n?kl0?_ojP3homX0e^BY0=SU[@3Nj[`0RYM[0?Oof@3_om00fnRm
0=7M]`3>fKL0noo]0>[fgP3Tlm80e>Nj0<cVY@3HlZ/0T:AL04eQ6@3KlJP0dNNN0;gER`3:i9X0b^JK
0<OVVP35i9P0d_:V0<KUV@3Ek:@0c^FO0=gb[`35fYT0dNJU0=_`[@34fiD0anJJ0=7bX@30iXl0a^bE
0080bNVM06<0cNNN0<oVWP3Ci9h0gNbY06Yc<P39chl0WYmS0=;BUP3PhZ<0cnNK0<S_WP2ojYX0a^JK
09bJH@1QFRH0bMZT06:1AP2ihZH0^nBZ0<?WZ@37fiH0hN6S03D_002IWU`0_]jC0<WWW@3>eI80jNRX
09JOGP3Aj:80cnZS096QH`3AgZH0emjd0?oog`3oonT0moOC0<[=X034cXl0iO6_0<OHTP3BkJP0a^JS
0;WTW03:nj`0^nnM0;[TV03:kj80bnfP0<WXV03Nnj/0a=n@0>?j]03aolD0c>6Y0<cP[`3>gk<0emnf
0?oog03@ej/0f>6b0=7OXP2GYV<0Ff`N08NJB`1DIAl0EfLV0=?QX`3Dh9H0e>BV0<cRY036i9`0cNfQ
0<[WY`034000c=Bl0=oV_03bn<`0oooZ0?ook@3on^d0nOo^0?Ool`2ngl@0`>G40;OR]037kk/0Fglo
0=?d[`3>k:@0GWPa05ed;P3Ajj@0bNBM0=Wg[`32h9P0QJ1I0<WSW03@iJ00103o00006`2;;b00K24:
0:f<H@3XfjH0dnZV0<OVXP31iId0bnZV0<kYYP3:gI/0h?2_05Q/;@3Cij`0b=n[0<_Q/`3eonP0kOcU
0<WGaP3hool0nOoo0?koo`1gN7<0nOWi0?ooo`3oo_l0oogo0?ono`020?omo`090?ono@3ooOd0oogn
0;Na/`3on_/0ooSj0?;Of`3omo00oogd0080oood00@0nOG/06iUGP3onoH0oo[h0P3oo?l0603[h^<0
OW]/05MG?@1CFBd0E5XZ0=cS/035bi/0f]nU0=SQXP3GhJ80cnJP0<cXWP39jIh0d>jV0<[MW@3Lj:X0
UiIP0;F^NP3Lkjd0an6J0=3UX025U4l0f>VS0=K/Y0/0oooo000:0?ooo`0B0?gooP3oood0ookk0?oj
m`3om?80oocf0?ojm03oo?H0d/O10?omm03oooH0o?oh0=3P/`3BiZL0cnZK0<WWW`39j:@0b>ZN0P38
kHh0o`38k9@0b^RP0<WQU`3<iJ<0cMfN09bKF`3>gYd0iOKF0?_om03hnO@0d_7O0;WZe00bIed0@VIT
0?Goo`3fn_T0oo;]09b8P@1]Fe402`000?onn03oo_/0oogo0?oko`3oood0oooo0?koo`3oo_l0oogo
0?ojm03oo^l0]kR@0<kKX`30hI80bnbM0<GHX03?h;<0c]ne0<OLX`3;hiL0d>Z?08bTCP26VUD0X[=_
0=7TR`3NlYT0d>RL0=?/V`3?j9L0e^jR0;S>SP3=gKH0h>g?0=cWa`1GGcH0e^6O0=?NV@3Bhid0h?6[
0<;CS@1OL2X0^/^50=SYY@2AXUh0jOVj0<cLW@3JjZ`0DF<W02<o103>nkX0bmBU0>3_b000>AD0QK5l
0<[]Z`3<j:d0EFa@0;_CW`2nhj00^?Zc01a>3`3EiKH0eMR[0=gMZ@3JhZH0cnFL0=gg[P2leI40FFdb
000<001KNf@0Hh5U09F_PP3<i;00c^>P0=GVW`1DIaH0UJ]H0<?KQ`35gXX0enZK0=;HV03;h9/0gNRV
09RJF`3Fe9L0dN2M0=COW@3DeYL0a;j20=_QX@3>gIP0e>RP0=SXX@3Gh9d0e^6M0>3d[@3;ii`0b^JL
0;_FS`3<iJ40V:mY0<GKT`3JkjX0g_6_0=SV]@3QkLD0o_oX0;>gWP3oonl0o?oa0?OokP3fon/0looK
0>3l`P37iZ<0aN:P0<SUX`3Uol@0joo>0;oOW038jZ00a>NG0<W/W038jZ00b>VT0<SXY`38j:D0b>VR
0<K[W@2khY40cNNM0=[YYP3JdjD0h=>a0;R]V@3oo>P0b]Jb0<3BXP3Bk:D0bNBG0<oZW@3;m:h0bnN]
09J5J`3ion40c]2Y0>GX^`3KlK40a>:L0<ONUP3AhJ80oooR0?ooj@3fmnD0n?o_0?Ooj`3Yo<l0dnZd
0<[TY@3GlK@0kOoA0?Gof030dIX0cn6W0=?UZ`3EiZl0b=RW0?Kog@3eomh0go;50<oV/036h9T0f_BZ
08NOE@38h9H0`m^A0;_ER`3?jIl0`mnD0<cXW@36iIT0c^fQ0<GTV03JmZ/0:S/00=?TWP1BGB40FV<Z
04eF8@0j@`h0a]6I0<KKV03WokD0_Mf:0<_]V@36jid0b>ZM0<[XWP3<j9h0dNFN0=OVX`3TkJ`0Be4A
04U:3P3emKT0cM>C0<_ZWP2ghHl0d>nO0=GUWP1PE200UiET05J1B@2bjZd0]^Z/0<G>U`3OhZT0D6<Q
09jNH03en[P0dN2K0=?cY`3<i9X0VJ9O09JOG03`okd0b]VH0=S[Z@31fI/0bn2W0=OP]@3cm=80l_GZ
0?7gg@00?P3Fg[T0d=fW0<CBU@3ChjD0>D/?0;c@T`3AijT0dnb[0;[GU034iJ00_MjG0<c/X`3ElJL0
bN2H0=7UWP3Hi:H0gNJ]0??fb@3WjL80oOgI0?oofP3Ih:d0Ff8/09bVJP3Kj:<0cmnF0<gOU@3CiI/0
f>NR0=SWY02@VeT0XZYO04iF7@3DgZT0dN6R0<cRU`3:hId000/00=W_`@3>hjP0gO:i0?koiP3oo^`0
nnWK0?onl`3oooH0mOoh0>[ok`3/on`0jooV0=7d_P3>l[@0b>^W09N^JP1nTTd0dnZT0<WPVP3<iYl0
e>jW0<_UWP31f980AEXE103o00006P3oajd0m[^M07II;@1KCad0XkEi0<cVY`34hZ@0an>X0=C[/`3n
om@0hNVh08JBHP0fA1<0b=^S0=3VYP3FkJD0cnVP0<KOV`3<hJP0amVW0<O>_02=T8T0o_ok0?ooo@3j
n_X0n?Sh0P3oo_l0:P3oood0oooj0?oonP3oo_X0oo_h0?_Yi`3;][<0gl[50?okl`3oo?80o?c`0?Wk
kP3oo?D0oogj0?ono@3oo_l0mO?h0?_ko@3oood0o_o_0?coi03GiK80fnfc0=S/[`3GjJl0d>JM0<oX
U`3<jIL0bNZI0<K/V@36ji/0eoZZ0<gWW@3Ejj<0<ch00=GKW@3FjjH0d^bU0=CYY028Ue80fnbV0=G[
X`/0oooo000:0?ooo`80ooko0100mOCb0?onn`3oo_/0ookh0?onmP3ooOH0[ZBK0?okl`3om^d0o_oh
0<_M[@3=i:00cnfG0<SYV038jZ00b>ZM0P38kI00o`38k9@0c>NP0<oSV`34hJ40g?Bf09NIF03Ojj/0
joGM0?Gfl@3lood0g?o[0:[Ra@1ERgh0FH1k0>_knP3`m?<0oo[f09ElM`0h91/02`000?olmP3nn_L0
oogo0?[en@3oood0oooo0?koo`3oo_l0oogo0?olmP3onn/0XjAl0>Ca^@3;k9d0b^^L0<kOZ03=gK00
00X00=?[[`2mf8/0b>F80<_XSP1:H1P0a=R@0=caUP3;hXL0bnFK0=G]W`3@iiD0c^FE0;?7PP3Eh[H0
hNg70=OS_@29UfH0_<f60>;dZ03JjjD0d>6K06Ae;`2_`7X0h_>]0=KWX`2:VeL0gnn^0<OGUP23Te80
XK9^0<[TVP2kjil0b]RU0=GS`01MRWD0@5hj0;gGY`2;[WH09dPY0=7Z/@3FmK80GYIG03YU;@1;G2l0
GFTk09FNI`0b?P00c^BK0<kVW03AiZ40_/bA000;002jek/0?EXk0;kI[P1:IC80dnb[0<kUW`39h980
KhHf0=C[V@3=iI40g_6R0=[SXP3@ij40c]ZH0::TI@3ZjZ`0d^6N0=KRX03BeiL0YZ1T0=KOWP3Ci:00
eNVQ0=OWX01AF1D0e=^H0<gJU@3:iiL0eO6W0=7/Y`3Gl:h0[L>209neK@3Jl:L0_=290=GTZ`2mbiX0
ZK>@0<[B[@3boMd0nOoX0>GhfP3CjLD0bnJc0<OUZ@3>kJL0cnfW0<[XXP39iZH0cNZ`0<GSX`39jZ<0
a^VG0<[[VP39jJ00b>RU0<SXY`39j:D0b>VR0<K[W@30jiT0bnNL0=;SW@30^XP0im^c0>;K_`3oon@0
dN:f0=3W[`3<j9d0bnRF0=7/V`38lZX0d^^a0:FBM03noml0X:=d0>CW/P3DjjL0a>6N0=G[Z`3@gZT0
o_kV0?;dg03Nh/T0h>_90>OhcP3So<D0b>BY0<cXZ`3]olh0joo?0?CoeP3:g9h0h_Fe0<_NWP34f9T0
gO6f0<SJZ03[olh0bmn/0<oW[@1dSTD0cNRK0=SbZ032g980c^RN0=;/XP3HlZP0eO6V0<WUVP24X5D0
W;Q]07VEBP21Ve40//In08JGD@2GXFD0`lZD0=WO[`1nQ5@0[[J30=OYZ`3EjZD0dnnR0<_/V`35k9d0
a^^M0<WYWP3<j9h0d>JN0=c]Z@3=f9H0XJYY08N;CP3=cY80f^2R0=;`YP2nj9H0cNZJ0<kJTP1IC1P0
J6Xi062FG02ZjZd0_oNh0:RSK02GS5H0QYUG0=;FV@3@gIP0a]jD0<KVVP3?h9T0Mh8n0;W8P`37g9L0
d=ZK0=SRX`3BkJX0cN>U0=?N/`2[[h`0n?oh0>cjh000=`3MkLP0g>ng0=W]/03=hZ40PiEG09VXK@3>
g:40b]RK0=3PW`3DkJT0dNnY0<3KU03?iZ00c>:J0=CUX@3Ag:00WjQa0;JiS03;c:80/;6909nUM@2@
VF00R9AF0:^jM`3@iIX0g_>X0<[PU`3Jl:L0h_Ja0=3QW@3EiIh0f^JJ0=_TZ`3Xl[d0am>E096VF`3K
l:/01ad00<WRZ`3AjZH0f?6`0>;^bP3onN80ooc/0?onl@3oooH0n?oi0?;om@3boo40lOo/0;SEY@3@
k[P0`n6U0<SKV@26Ue<00P3AiZ401P3Lljd0b>:K0<cVW`3Pmk40go>^08bPF`80o`0001T0JBh@0<6<
JP2:GCH0_jMi0:2DHP2Z]gl0dNJ]0<CMY03AjKD0fnnl0?CkdP3GfK@0hNO309ZRN`1RLcd0enb[0=Sa
W@3@k9D0cn^D0<gUV@3GkZP0IViG08R;PP3jo?L0m?Kc0080oooo0P3oo_l0403oood0oooj0?oonP3i
m?00oogj0?o`kP3omO80e/>m0?oll`3mm>/0oood0?oomP3em>l0ookk0?[im`3no_h20?koo`080?co
n`3fonL0enG10=;U[@3?iJD0e>ZY0;gCU@3:jIT20<W[U@0>0<S[U`36k9L0a^^K0<?TU@31fi40hOR`
05YY9P3OjjT0dNRR0<3JT`3:giX0EfHQ0=_/YP3Aiil;0?ooo`002P3oool0403jkoD0oo_l0?ooo`3k
ool0nOom0?_onP3looP0ooof0;RZX@1G@cX0oo[d0?gnn@3Ai;H0d^bU0<[]S`35jI820<K[WP0K0<K/
U@39jiL0bNZK0<oUY@3Cg9/0`NBZ02983@3?fiT0fnBU0?7Xh@3onol0lOol0=col@35on80M:^H02eJ
D`3bool0o_oo0;FKVP3omo<04@0006]MDP3oooH0oook0?kio`3mn?h0ooko0080oooo0:/0oogo0?ol
o`3onoD0oog]08:5FP3:fIh0`nVF0<W/VP2?WV<0b]Z[000<003;iJP0`^6C0=[kXP33hhh0fO>b0=O`
[`3AjYL0`]j:0<KSX03<j9d0enfH0<cNRP3@g900c]JK0=CLZ@2a`X`0]L^=0=?cX03Clih0g?2X096U
GP36fY<0e^ZS0=oc[P3Hk:L0^ln:0:FiLP2O/6X0c=fG0>GcZ035gHT0aoVb092SK01OJcd0DVaC0;2i
YP2:U7T0CgQ006bIKP0?:@00TYeb04A47P3?fk<0e_c=0<Gd_P0HA0L0SK5a0:FhN02IY6P0gNJ_0=ST
]P0A7P00MXaM0;K>WP0A;@00V[R40<OX[`3FmKT0`]nM0<3KV01iT4`0eNJO0=CTW@37fiH0bNVP0<gR
W@2MZFL0e^6O0=7[Y036gIL0gNbY09FJFP3HjJD0b^BM0=[dZ`3Pm:l0Ff0P0:b]L@3MgJ40d_BM0<OU
V`34hIh0b^>Y0<WQY@2]`g/0SJAF0;O<O@3Ci9h0eNFV049A6P36fiX0e^j`0<SQY`3;j;80b^V`0<g]
ZP3:k:80aNRD0<KXU038jYH0cnfU0<kZ/03bold0dNnU0<WZT`3=jiD0c>RN0<[XXP3:ijD0c>NR0<[Y
W@36k9L0_NjL0<c^X@3Dj:00V99H0>oU/039b9X0nooE0<STZ@32hih0bNbH0<_[UP38hi@0anbW0<CI
X03;/Y<0n_oD09bOJP2EVEh0dNZX0<cZ[P2mdZT0n?oZ0?_om03Zmm/0dnBh0<_VW`39j9X0c^jU0<k]
Z@38hJP0cnJ^0=CY/03<h:<0kOnj0;34O01[PS@0V;1T0=G/Y03Gkk40f?2d0:BlOP2H/Fl0dnjO0<cY
U`3<k:00c>^O0<[YW@36iIT00P3=jIh0U03Dl:D0`]bB0<[TVP3DkZ@0e>nR0=kj[@3IljX0gnje0>7[
^@3[l/T0lOS?0=7J[`3Un<40_=:D0=CbZP2ngY<0aNbM0<K[W@39jIh0b^RN0<gWWP38gIP0fnZW0>kj
^02mahP0TiUK0;FiO03MijP0a^RL0<K`W03Ak9d0RH9<05mQ<P2ijkH0U<nE0<;d]@1mKSD0el:90<oT
X`32dI00b^bP0=Km[P3>jI`0emfG0<kOV02iehd0eO>]092?EP2VXVD0d^fL0<[PU`1jRE80f>6d0?So
mP3`onD0i?_?0=?b[`3Fmk00bnfQ0>;o]P38hY/0f^^W09NTG`2DWUL0M84i0=o_Z023U4d0X;A]08FI
E02db8<0dnRW0<SLW@3/o/80hO>i0=;VZ@3DjJH0b^:F0<GRTP2feX<0^Mb:0<W^WP3<l:H0a>FN0<[Z
X@3>kJ40anND0<[/UP2oei/0a]VR0>Og^@0jB000=dL00=S//@3:h9l0c>FD0=7YW@3@gK40_lFO0=?G
]P3oond0oooc0?omnP3oo_d0^[N`0>g^h03Kh/40LGaB0=KR]02lb8X0l?bj04YI5P3AhYh0c^>N0=G/
YP36gIL0d>FP0=GVXP23U500gNbY0=[JWP3bk;80V8UB0<RgP`3Tf:@0K6Hb0?Woc`3iomP0looH0?Oo
h@3`om/0ooo]0?cbj02e/JH0i>GG0?_oh`3Di;<0g?NZ0<gXU`3:iiD0aN2K0>3j_@2HY900/KJ`0?co
o@3lool0loCf0?koo`3oo_l20?ooo`80oook02L0oogj0?onn`3on_X0ooSi0=c:b02eYj@0ookh0?ko
nP3am_00mOOf0?Sfn@3ooo/0oooj0?kon`3en?40l?KX0?7lfP3eomH0_mBA0=;YX@36h9L0e_6Z0<G]
U`33kYD0aNfE0<S[V@39jY/0cNNM0<_RVP34fIH0HWDc0;O:RP3Ai:@0aMnH0<cVW`39gYT0Y;=^09Z[
I@3?iId02`3oool000X0oooo02d0oo[o0?oio@3jn_`0k?Oc0?Ooo@3/n>h0nooh0?Cfj`3oo?<0d;Va
0<:]Z03oood0c^6d0<kYY03<ki40b>bE0<KZXP35jj80a^^K0<WZV`39jIh0d>BY0=WMX02B^7l0`>ba
0=[[Y`3Ni:H0oo_j0?oio`3aool0cOoT05BPL@0WGTT0RKJ_0>_mo@3^l>l0XhV80?o_jP0G0@00DD<h
0?Sek03mo?P0oogo0?ojo`3oo_l00P3oool0]P3ooOl0ooco0?olmP3on^X0FUd`0=k]/P3CnJ@0a>ZE
0;c<S@3JjkL0dN>c0;[DU`3Hmj/0^]b60=3aXP38i:X0_MVO0<;LT`3ImJX0bnVY0<_WW@3Hk9L0d^6<
0=[UUP3Fg9h0g>B[0<GGW@3RnkT0bo6J0;KJP`2<XUT0Zl5i0<gSV`3Aiil0`]NB0<cRVP3Ejj<0_]:;
0=SYXP38f940Rii?0<CQT@1AN4<0^kf;0<[=UP37k[l0cN;308fLO@0M>0<0NIQ^07BEMP15F3`0Z9]i
0;biUP21V6h0BVi00;;X[02_j:@0aoBa0<SWZ`16ERD0k>?400P2003@iJX0Rj=Y0;[GW`0[C1<0Z<jE
0;;EW@35hZP0c>JY0=G[[@3ChJ<0g>^Z0<ONV030i9X0`mfF0:ZkM`3Ah9d0b>JN0<ORV`3@i9l0Uj1O
0<kUW`33hiX0aN>K0<[OW03UjJ`0NgY109RAFP3:kI<0aNFJ0=_h]P3?j;40fo>i0<oUW@2W_W00;480
0=_]X`34di00Z;]k0<OOT@3>kJ40`N2J0<OWYP39k:X0aNZM0<O]VP39kI<0b^fC0<W/TP37iYP0b^>Y
0=oh]`38i9T0cnfC0<kZT`3=j9/0c>NP0<cWY03=iih0c>VI0<S/U@38o:T0b^bP0<[NUP2NV5X0gMBK
0:nbO@3dol/0b>JV0;gQV@3>lId0bn^F0=3XW03?l[00e>Jb0?3G^03nomH0g]jX09^LHP38h:80c>Va
0<gR`@3eoo40mOoh0>Cif03?j[D0c>jH0<O/S`34iIH0anFO0<kU[`3>hZd0m_o<0>Wi^P39gID0e>VL
0<;IQ`2`bGP0RJ5E08BMF`27X5l0Z/>10<cVW`3;iYD0cnbJ0<GWVP39jId0`^:F0<k^XP3;jYh0bnNL
0;kJS`3>j9h0d^ZP0<_SV@3?jYd0aNJE0<KTVP36fYl0enFb0P3noml0R03lomd0]LVF0=;Z/03:jJ<0
dO>Y0<G/W@36jid0bNVN0<[XWP3=iih0d^NR0<_JU`2lb8H0dmnO0>3YZP2LVf80hMbT0=Wg[@2gkiH0
_NZE0;:cNP1oO4l0d_K607ZYL`2ki:P0]je`0=O9S03?i:<0fnj/0;3IR`2agXd0e^jR059C3`3<h9P0
eON[0;oNV02XXf/0g=:G0<gTTP3:hI<0OHe>0<cIX@3ooo@0h>_;0=[[_`31h9X0b>jQ0;KPSP35kid0
^n2B0=3/X@3@j9`0go2R09nZGP1]Mbh0/;ab0<cMUP3Pm:d0`MJA0<SQW@33gY/0cnbY0<WWX@3AkjL0
bNRL0=_mZ@39kIH0bO2G0<3/U@2hhi40_NNM0<G]YP33jIh0a^^M0<K^UP2]g800b>Z]0;gFW`34eYP0
hNnR0=?QUP3Nl;80bMjI0<kVTP3>hi@0dn2b0=?P]028U6`0l?GN0?gnkP3ooO/0ooCh0?O[j`3oo?H0
oogT0?oogP2a/h`0/k^00=_VY02/^gP0Y;Ea0=S/Y`39gYT0bn2K0=__ZP3@hId0j?Ve06Qg=035e940
]L5o0?Kf^03GdYP0ooo=08j;EP3Ggjh0c]^]0<_L/03<gKT0fNS70?oll03onoP0^;2^0?onn`3lonl0
joWH0=cc^`2meIT0W;Ek06b5G@3<i<@0Mh5h0867P`3amoL0o?oo0?Chn`3lool30?koo`0>0?ooo`3o
ood0ookm0?ggm`3omOH0oo?e0?;Ph03Lc/d0mno/0?koo@3iood0o_oo0?ono`3noOT20?oon00A0?Ki
kP3Xkml0i?3<0=WY^02T^G@0f?2V07jHCP1eSdH0aNbI0<;^U`33kIT0bNVM0<cXWP3@iJ00d>2O02`l
000lC0d00P3CiJL01P3@jJD0e>jW0<cQW03=g9L0U:EO0>?i/@/0oooo000:0?ooo`0^0?oko`3ooOl0
ookk0?oon03nooX0l_[m0?Woo`3dmol0oo_o0?o`l02;Mfh0oooc0=CQ]P3Gjjh0b^^D0<?WS`35k9d0
aN^R0<SYY03:j:80c>NR0=3UY03Gi:l0o_oX09>IO`3foM/0m_oS0?;nm03kooP0e>>h0=7`]`0JAQ<0
^>?I0<kRh@3nool0QX5n0?oil`2cWI80A`l>0=FSXP3nooP0nOom0?ggo`3onol0ooWo0?ono`80o_oo
06L0ooom0?ohj`3ooNH0WYa[0=_WY`34k9<0aN^D0=CNXP2>W64000`00<?PWP3DmJh0`>VK0<?^W`34
jZ40aNVQ0<W[WP38ii/0dNFP0=W_Y`3Ejj80c^BK0<oUW03golP0PIAB0=SXY`3DiJ40Wk5W08nUFP36
j9h0`>:H0<SSW039hi`0e>^U0=KZY@33ei80dNFP08FJE@2J/FT0cNBL0<ORV`34hJ40cmnP09f`KP3A
l:d0b>2T0<cQYP3GjJ/0b=bO0<SMY@2_`8X0d]bW0=?//`32jK0094L?08jRL@3@i[D0c_K2062:F000
5@00cM:b034a3@3DhZ@0`mjK08bWI03?j:L001L004me?03?kKL0a]^S0=OPY`2c`g`0TZIN06f6A02D
[Vd0c^NU0<SNW@2cbHP0dNZV0<WPVP3IkjL0SIiG0;75O@3Cjj40d>ZQ0=?ZXP3IkJH0eNJP08nNF@1R
F1X0gN>S0=OZZ030i9h0aNZT0<ORV`3Bj:00enRQ06b0>@1XPS/0cNnU0<?UV`36iYd0bnVS0080c>FQ
03L0cNVO0<gYWP2gfXP0c_BQ0<7[U@2fhHl0c?FY0;WOU03:l:<0bNbL0<3QTP3=jIh0_MN>0<[PV03B
iYl0en^S0<_SU`36jih0_njP0<GaY03FjjP0TIMK0;2_M`3[l;H0dNbW0<[XX03;giL0eN:M0=[SY02K
ZF/0JG@h0?gob`3dolL0f>Z/0<SJX02=Wfl0bMR_0?kojP3WkM40i_O30>gna`2nd980dNNO0<7HT02E
[6H0cN>R0<oUY@36g9h0koo50=oh]039jih0b>^K0<W/W03:kId0b>ZM00<0b>ZN05D0b>ZM0<S[V`39
jYT0a^>C0=G`X`38giL0cnJP0<oTX@2BZF<0XKQb0<gXV`3=jYX0`^:=0<_]UP36ki40bO2E0<OXV@3D
lZX0l?o?0?OofP3hom`0^LNF0;k=UP3Sm;00bMfE0<STV@35iiX0`>nO0;kWV@3>hY/0eo6Z0<?NU`3I
jZH0`kj40<KFU@3GkZP0RIeF0<KUV@2bfHP0anbN0<gRX@3<fYl0JWI60=CM/01bN4`0Q7A@0;bdQP38
j9`0a>VK0<[lY`2hj9@0bnNL08REC`3Fg9`0cm^K0=GYZP2P/780FF`/0=3/XP3Ilj`0K8E10<cSW`3R
n/X0fO:i0<CQX@35jY`0a>ZG0<K^UP3GoZD0`NF=0;oQR`38j9D0cNRI0=3VW@3Bj9d0f_6S0<COT03;
iYT0e>jU0<SNWP3:h:00c^>P0<WMV03Hl:@0anbL0080_nZH04H0b?FR0;SUTP37m:<0c?NX0;cWV037
lZ<0_^VI0;gYTP2ehXD0bO:T0<W^Z035iZ40dO>E0=7_V@3>i;<0cnRT0=K^X03;hiT0dnN/0=K[/036
fYd0UIiY0?ooe03nomP0_<BK0>[if03:fK`0o_oc0?omm03omo<0jNc10=cVZP1CHb@0GG0^0=?]Y031
gI80cN^Q0<WUV`33gIH0e^fY0<WNW@2QZGP0oooJ0?KlcP3oomH0dMRT04iE7`3DgjL0cMbS0=GZ/@3;
kk80_NJZ0=SR_@3dl]T0gMK<0?omnP3oooH0m_g]0=OVa`3Wn=P0n?o/0?koo@0n>d@000040?Khm`3b
m?<0o_oo0?Gem`3oool0o_ko0P3oool0:@3bl_80oooo0?gno`3`lOD0noSa0?oom03Zi=P0ookd0>3K
e@3oo_l0nOOj0?ooo`3oo_l0ooo]0?ooi02n`IH0^K^F0:fcT@26Uf/0Tj]_0<GMX@3Cik80cMB[0;>e
Q03VlKL0k_o40<7QWP35kJL0`N2L0>;SZ@3Meid0UY]K0=?RW`39iI/0c>RN0<OWW03Dm:T0_MV?0=_`
Z`2^`Wd0enJS00/0oooo000:0?ooo`0^0?olo`3ooOl0oogj0?oomP3oooX0nooo0?Woo`3jo?l0oo_o
0?ojn`2]Vhl0ooo]0<gJ[P3?hjP0d?2K0<W]U@35k9d0aN^P0<WWY`3:ijD0cNJR0<oVXP3Cj;00oooX
0<6kY@3JgL80h^kF0?Gon03eoo00cMNS0<CIWP1VReP0a?7/0?Ooo`3oo_d0WI>A0?[Sf`0A0000BPP:
0?oCe@3^m>X0mooo0?olo`3ll?`0oo_o0?ono`80o?oo0:00oook0?oik034]Ih0/Jmn0<gIV@35kI@0
b>jI0<gGV`2HXfL0<d<50<CQWP3AlZ/0_nVM0<;/X032ji`0a>^L0<g`X03>kIl0go>[0;_AR@38giT0
cnVR0<[UX03[ol00`]^G0<;FT@3LkJL0SY]E0<WJT`38k:80c_2V0<WTW@3:hI/0jOji0<OHU03Vmk<0
W;1[0:6fL@3@ij40aMnH0=C]Z@3EkZX0e^n[07RAC@36gIT0dnZV0=gb[`3<gid0fNVX0;S7QP2e`hD0
e>Z/0;?JV@0jJ2L0QZa_08VBH`28TF@0^=b/03m]?02_fjX0<D8N0007003Wm[l0c^b/0=ci]`1nUUP0
Tjac02A<403:jk@0cNF[0=oW[03@hYH0f?2R0;K<S02I[fl0a=ZJ0=gf]@1:Hb40d>NS0=K/Y03>i9`0
i_Zb05U[8@3EjYl0`=R>0=cdZP2oehd0hOV_0=[`Y`3=_8@0JVX/0=7MV`34i9/0cO6W0=C_Z035g9H0
bmnJ0=C[Y@3:iIh0_^:H0<[[Y03;jZH0cN^U0<_TX03@ij40aMbD0=K`Y`3EmJT0^mf@0;gTT`39lZ<0
^^>E0<S]X034jI`0cnnT0=;^Y03@iil0hoVa0<[KU@3Dhih0SY]F0=OXXP32gY@0]nJH0;g/WP3FlJ`0
emnT07A_>02QXVP0a=nJ0<SXW`21TT`0OhY8096IG@3LiZT0c]fL0=S_Z@3eolP0_=FD0=O_/`28UFT0
XZZ50>g]d`2TZ8L0amNH0=SVZ03EiJH0MHQ808jQH@3@iJ@0Zl1o0<KLV`37h9h0/LZ80=Cb[035jY`0
a>VK0<?XVP34ji`0b>fO1@36jid0S038ji/0cnZK0<_SU`3CjJ40eNZU0<kQW`2J[f`0YKaf0<[VV`3<
j9/0aNNA0<kbVP2miXX0`>N<0<3ST@38j9`0e>ja0<[QZ`3GjKT0cM^Z0<KCV`38eI00gNfT0<WOUP37
iYX0[=f<0<ObX`3Sm:h0`=ZC0<c/X`3FjZD0f]6H0>7f/`2ifi40/<Ql09fgK@3Hm:T0bNFJ0<oXY03E
jJX0C5HR08:5EP3LfK00EdXZ07EbB@3>ljH0`NbM0;SYU`32lJ00anFK0=S/Y@3Vjj/0f=fM0<cLV`3K
m;80bnRU0=ki]035gYX0eNjZ07><B035hjL0anNT0<CUX037k9h0a^bG0<?YTP31iHd0bnfF0<g]VP37
i9@0bN>I0=3ZX`35giD0_]V<0=GbXP3:iYT0bnNM0=G[Z`3Dj:/0fNVZ0=o^Z@38fXh0`N2B0<oaY03>
ljD0_nBF0=KhZ`2ohI@0]]R;0=?eZ02kgI00b>ZM0<c_W@3Am9X0/]630<o]Y`3El[00e?JH0;gMR000
3000d^n]0=GdZ03;jJ40f?:c0<cRX@3Kjj`0VIeP0;RiO`3MiJX0f>N`0;WDY`37hkd0jOKU0?kon`3o
o?l0o?gM0>_e``3JjK00gO6d0<COVP3Jn;00foV_0;kLTP3FlJX0cnVR0=C[Y`2V[800g=jg0>G/`03d
olh0cmZR05aW;@3AgIl0f>JX0=O/Z`3;ljd0aOB/0=CV]03[klX0gMS40P3ooo<04@3WjmX0h>oB0=_Z
c@3iond0ooko0?oho`081P/0h>3P0?ooo`3dm?@0n_[j0?clo03no_h0no_k0?clo03oool0o?cl0080
o_oo02D0m_O_0?ool`3fln@0lnoS0=oKdP3onod0ooko0?Kel`3in?@0n_WT0;^kV@3>dI`0m?G;0?ko
g`3EiKh0a]fU0=;Y]@3?h;H0gM_40=S@[03moL/0o?oA0<o_/035l:/0bNVV0;JdN@1GC1@0e=VG0=k]
Z037ii/0anJH0<GUVP33hiP0c^bR0;oFT03AiJ00VjMW00/0oooo000:0?ooo`0^0?omo`3oo_l0ookk
0?onnP3oood0nOko0?Woo`3ko_l0oocm0?ojm02cY940[[2J0=7R]P3DjK00`>6B0<c_V`35k9d0aN^R
0<SXY@3:ijD0c>NT0<[XWP31jY`0nOoD0=?FZ@3TgkT0d]6c0?oonP3oooH0d=fb0=Wga@2:^Y00E8n=
0?Coo`1IEE@0oocj0::>Q@0I1`00Y6=W0>ja]P3cno00moom0?olo`3olol0ooco0?ono`80o_oo0:00
ookm0?okk`1ODSl0k>^o0=ORZ039kYh0a>NG0>3Y/02KYVX03al00=G`[@32hI/0a^ZP0<W]X`36j9`0
anJJ0<kYW03;iYT0a>2E0<g[X@2feXd0dO>Y0<SYXP32hi`0a^FO0<oZX`3=iih0WK=Z0<_SV@3Ilj`0
a=^E0=O[YP3:fiL0a=>@0:nkN@1QKB/0d=nL0<;ASP3>hYd0VZmZ0<SOV`3Qm[<0cN:O0;C9QP24UeD0
UJQV0:JfM@1YNCP0K7/j0;o;R`3Jj:X0_MNH0:cET`30lJl0dofm0=KZ]@2W_XX0T[f706NJHP2XfZD0
g?W=0;O;YP0@:0H0KIAX0<G[^031hk00[]>M0;c_]03Bol00a>VV0<?JU032iX`0co>K0=S]ZP1[OS`0
hOBb0<SMVP2aaX40RYmJ0=7WW`3:h9P0bMfE0=?WW`2<XUT0^=260<7IS`3Cjj40_mN=0<?KT@3Ah9d0
ZkAc05UO7`3?eID0i_6_0<kYXP3DmZ`0b^jT0;oOUP3:j:00bN2J0<_VW`36iYd0bn^R0<WYX036i9`0
e?2V0<7KTP38giL0d^RP0=GYXP3Um[00bMRE0<SDTP35dHl0gnZX09RQH01OI2@0XJ=T05QH6P1kNC`0
XZ1S0:BTIP3@fIH0]<n80<_YX@3ChZ40lo:j09VBG03Tj:d0`nBM0;SQU@3@kZ@0e_2Y0=C]Z`3=j:D0
aN>M0<o_Y03;jj00bnVS0;gFU@3Qk[T0e]b`0?7^c@3Kg;@0Ykag09V^J@2S^7<0cnBO0=?XX`38gIP0
b]nJ08ZQF`29X5X0b^6K0<[TW@38ii/0bnZN0<g]X@3:jYh0anNK0P38jYd30<K[W@250<SZW@36h9L0
T:MO09N]I@1gSD@0VjmW0=S^Y@3EkJ<0d^fV0<gXX@36iIl0cNbX0<;OW`3;iJH0bN>T0<_UYP38h:H0
mOoD0>gobP32eih0go>d0:RnMP22Td`0QHm:09f^I`31iiX0bNjQ0>Ca[02oeY00fofc0<cSW@2ZYF/0
^mVC0<S/XP3EgiX0UZ5L0<WJT`3BiYh0c^FM0=_b[P3Pm;L0Z[V209bVLP10AQP0;3P808JZK02`fYX0
`o:/0;_ZXP33iI/0`mfF09:NEP2ha7X0g?6R0=;]W038hi@0X;1_0=OWYP34e9<0e>>R0=3ZZ@36i9h0
cnfU0<CUUP3AlZ40bN^G0<g]VP3?kZ00`=ZC0=W`[03>hZ<0eN^]0<oXY02mehh0KXXm06b8?@2/b7h0
eO2]0<gVY@2AYV40TjMO09>QEP1bNC<0XZMT0:2UHP2V[FT0TIQD0>S_Z`3GhI`0[;Ia09RSGP2=V5<0
b]6;08^=@P0R8000NgU60>3Q]@3MjZ@0b]ZK0009002Q_H<0]M^>0<;[W@2df900d>FR0=GQX@3Kgj80
g]nS0=oY[@37eYd0_MVY0<CS^@3bonl0j?CV0?kon`3ooo@0oooa0>Sae03Xm]<0cN6`0=3W[`2jeI80
fO>/0<[TVP3?ii/0dNVM08NBF03eolX0cmjS0=3PXP3Mk:T0a<n;06I`:`020?l0000j0<o_X`2/eHH0
cN:Q0=KQZ@3Nh;P0oooS0?coh03Hh[l0kOoG0>;dcP3fonH0oooj02hX;03ln_d0ADE50000001kNg/0
Shn?0:VYZ@20P800TI6A08N7Q`1^KVh0EEEE08R7S01hMWT0m_?^0?oomP3MfM00ookh0?onn`3ln?L0
aLBo0?gol03en^@0ZjjC08j>K03SiKH0jNS90?ook03koo40l?oL0?Woj03moo00oo_h0>3:_03Ph:h0
c=nO0;cMV02mjIh0`nBM0:2PHP1FD1@0f^FQ0=;XX037k9h0`N6E0=;`YP80a^:H00<0bn:L0;O<Q`2<
WET02`3oool000X0oooo0P3oo_l0c`3oo_d0ookk0?ono`3kool0nOoo0?coo`3ooOL0ooO[0:ZNQP2S
Yh`0bMb^0<cTZP2nh9<0cO>P0<G/W@35jj00b>VT0<[WY03<ij80bNVM0;c/UP3`olD0e]^U0>cS^03F
dK40o?_f0>OXhP3Rl/d0/M:U08:iTP2?c<d0m?oo085kN`3oo?X0^ZJM02HF2@3CTYH0kK:f0?[om`3g
ood0ooco0?oeo`3ooOl0oooo0?koo`3oool0oogm0=O:`@1mL5l0f]^c0=KS[@3>l:@0c>bQ0=OPY`2H
XfT0<4020=[c/@3?kJL0a^JM0<SXW`3<jZ00dnfS0=CZX@3;hiT0cNfQ0;gMTP38jZ00_N6G0=Kj/P3B
mZh0anRQ0=7_Y`2jeX`0X;Y`0<GMT`34fI@0dnNR0=CUX@3Dhj00gn^Y09JQG`1^NSP0fnZW0=k]ZP3B
hil0FflZ0<[OW03@hj40g_6_0<;ET`1fQTD0Ff/Z03m>3@2LZfX0]/:20=KRXP3EhjD0QjAR08nhM035
m;00/M^K0;cEWP1dSeP0Dh170:cOYP2ejk40_N6a0=7[a0002`00CWYI08ZeRP3<ll@0eOg90;C^/`1g
ZfT0_^VT0<_[X02agGh0d_fQ0=O[YP1iRTH0aMJB0=[^Z@3BiYl0EVXS0<SNUP39giL0enfU0=_aZ@39
h9P0R:1F08>KD@37giD0f_:X0=og[@3Bl:P0dMfK09fRHP2]ZF`0_kn10<3JT`38k:80`N^O0<kbZ03D
lZX0cn>N0=3ZX@3;jj00e_R/0=[l/03=kj<0^]R@0=cf[`3Fij<0j?Bb0<cEU03OhJ80alR<09NGF`37
ah/0h^2U05=A5P1OFR00PWa205==4`2NUE`0kNB[07Qb=P39bHT0iOVd0<gRW@3>eiP0iMjX0;6WLP3L
h:D0co>[0<oi[@30hYH0b>JN0;GDT037j:<0`nBM0<GZW@2cf8/0cN^S0<SSWP3Ij:l0eMfZ0?oof`3L
gk00aMbD0<cSV`2oeXh0amjF0=;YX@3CjZ80goJ^0::hL02I[fL0e>ZR0=7XX038hYP0a^:G0<gYWP3=
k:00c>^O0<WYW@030<SZW@250<K[W@38jYh0dnbX08nVH03Fk:<0i_ba0=7VV@3Bj9d0cnNK0<cWXP3;
iJ@0do6c0=kj`03@hkH0f^^o0<gQ/03<h:d0d>Na0>_obP3eom<0e>f/0<_VX`3=jIl0c^:K09bOG01`
NcH0N9Y>06J6>`3GhYh0iObf0<SZX03Lljd0YjEZ0=7_Z@33iI/0fmfL0;>jM`3IiZ00dN:K0=G/Y037
gYH0eN^Z0<3DU`3@hZP0M85<06=d@00UBQ@0JY=K0<cj^P2hiZD0anbV0=?aZ@2CYET0UJIH0<WQS@3D
l9T0dnnK0:6`K@2b`Gh0enJS0=OSX@3>ij<0c^RQ0=;^Y033hY@0d_6Q0<_ZVP3:jI/0c^ZP0=O][@33
ei`0dnB^0<7DW033g9X0SjUR0;OCQP3TokL0`^2F0<gXX`3=j:D0dNRP0<OMTP2CY5H0Ad`9096AD@2G
UeL0W9iM06]`;P2g_7X0gNBQ0868A@37d8d0[KIc08B;A@2g]fl0YZ5Z09RDI`2JUg@0dm^P0=_U/000
1P00d^Rg0=;bY`31hiH0g?nd0<S/Y035iYl0e>^W0<cOW@3Bi:H0cn>X0=oeaP3Di[h0mo[U0?ool`3l
knT0mNo_0?[jn03nooH0noo^0=c/a`3Ik;l0]lnC0<_QX03;hYX0h?J[0<OMTP2MZfd0`<jA0=GXYP3A
iJ00g^jW0=KRVP040?l0000n0<CWU`3;hiT0dN2M0=KMZ@3oomP0m_gD0=SS^@3Gj[d0i_S@0>kog@3C
eLX0J6AS0?[hn@39bLT0IfMW02`/;0000000>3Ph01DE5@1WIfL04A4A02@T901VIVH0CD]>03/f>P2<
Qh<0o?Oa0=_Cd03ooO/0kNOW0?3_j`2BTh/0WjR=0>G`cP2>U780Vief0=[M[P3_l=40ooo_0?Sol`3i
on`0o?o_0?oon03onOl0d[N`0=gPZ`3AiZ40`^JL0;kXW03=kjD0O7hm06EQ8P3Ql:/0eo6W0<C[W03>
l:<0^]J<0=kh/@39hi`0c^FM0:NmM@2icHH;0?ooo`002P3oool0;@3lool0ooom0?oon`3oo_d0ooko
0?Kko`3go?l0n_ko0?kjk`3oo^d0]jb@0=[Q`03:h:l0bnFX0<OYW03;lIh0aNbK0<G/W@38jZ00bNVP
0<[XX038jYd0_nnI0=K[ZP3QiZh0h=RZ0=kK^P3nood0o?oo0;W<[P34ikl0S<:R0<Woo`3`ool0/jf]
0?oim`25LFX05`H00?o1a02RIf/0nooh0>cgl@3onOl0oo[o0?oko`020?ooo`2S0?ono`3oo?l0/:>K
0<:fYP3?dJX0dmn]0<[YX`3>k:H0eN2V08RCF@044`00bn6Q0=7/Z@3<ij80c>NP0<kXW`3CjJ40_=28
0:VoMP12I1L0e?BY0<oaY`38jZ00Yl^30<;SW03<kJH0c^bT0<GSV@2:Y5X0cnNM0<_OVP3Fij<0CEhJ
09BSH02HY680UZ9P0=_WY@3BhIh0b]VF07J7@`39gIP0<D@20=g`[P3=gI`0f>NV0<SGUP3Mk:/0dN2O
0=OVY@3>fYX0fNFU09:RH@2N^gT0QJYU0;ORW@2_eYD0dNfc08j[L@0C?`@0]>JY0;c^/`30ik80O9]b
06=oL@2KbJl0S;ZC08J_P`2kik@0]_6g04Mo?P3;n[H0bNZS0<CeV@2ch8D0c=fI0;72O03?h9X0eNJP
0=KZXP2=XEX0g?:Z0=;XX033fY80amjF0=?ZXP3?iid0`=R>09ZbJ02[`gT0a=bB0<3VV`3?h9`0g^BT
05Q?501UHB@0enbW0=;bZ@2ki9P0b>jS0<CRVP3MlJX0dN^Q0<c/X03HnZd0f_nc0<kcYP3:j:00g_Ra
04iI5`1<D1<0IF<X0=W@U`2OUUd0iMbU09J=E03FcI@0J5dW0>[OZ@2;P4P0YIYR06MJ9@3Dai00XYMO
09RDE`38ei@0e>FQ0=OMW`3LdYd0Z9aX0>KW[@3;k:D0`nfQ0<_[X03@kZH0fORd0;oPV@2ohiT0b>fP
0<7VV03:jYl0an:K0<[LWP3AgZH0o?o@0=[S[P3:iY/0c^ZO0<gYWP3;iI/0d^bR0<CLTP36gY@0kOnj
0<?IT02EZf80b^2G0=K^Y03@j9h0c>JL0<gYWP3>jYl0b^VM0<WYW@030<SZW@240<SZWP34gI/0V[5]
0=;XW`37gY00a=V:0<oVUP3?ii/0c>NT0<gWZP3Oo<H0k_oG0?OoiP3jonT0eN>o0<_L/P3>hZl0mOoD
0?;ocP3:j:80anFM0<SXW@3?iYh0g^6N0>G`Z`31hiL0`=jD0;>nNP2[`7/0`n>J0<gRW@3JeI/0c>NR
0=7`ZP3]kjh0cM:@0<gJU03Ol:T0c^JL0=K`YP3IlZh0c>:Q0=7UYP32dIP0f^ff0<GZ]P36k[T0NZM/
09K4Q032jjD0b^^T0<WQU@2gcWh0d>ZC0<[VS`34gHT0_Lb908NCD@3KijD0cm^I0;35P03>iId0dN^Q
0<KUU`3?kYh0bNRJ0<WUV`3?j:@0b]fU07:3C`28UFL0Wk5m0729B029XUh0e?>U0<;QU@38ii/0a^BN
0<?NV`3EkjH0dn^O0=3SU03LiZ40f=fK0=gTX@3OiZ<0d=VF0;K1O@2IYV40amB?0=CSWP3Gj:80dMjH
0<WAR03Yk;L0c<jV09:CM03bn/L0j_?6010H2`2O[840e>ZR0<GKT034hiL0`>bO0;[ZWP36jZ80`N2J
0<kTY03Wnl00gNfn0=SS^`3jm=h0jmk>08igK`3Jd=P0c/_D0??cl@3am>/0m_oW0>3^b`3/o/`0c=nW
0<?HU`3AiZ40d>JN0:NgN01?Gb00cnBQ0=CZXP3Kjj80dMfE103o0000?P3ElJ@0cNFI0=;VWP35ci<0
j_6m0>K_`03Dh;80^LbO0>7fc@3PlLl0UiZ?0;bh]@3no?d0oooo0?Cdm03oool0fm_K0=SHf03^k^h0
oooo0?Cdm03oool0m_Kf0?omo`3Ecm4061<@0?_cl03klo40oo_l0?omo`3fmO40nOg_0=kZaP3Di;L0
NXEJ09JNK`3BfjH0k_;?0?_nj@3iooP0looW0?_ol@3noOP0ooSo0;bPW03Gg:@0f_:X0<K]WP2ojYX0
gOfa05=E503Qh:00b]^D0<[YW@34kIh0doFX0<gWX03;hY`0enjX08:ID@2Y`7P0cN>K2`3oool000X0
oooo02X0mooc0?_om03nooP0ooom0?ooo`3ho?/0m_gf0?_om@3Mfl80g]Nj05IA9`3GiK00_]^K0<o]
Y`38ji/0`^RC0<K]U036k9D0b>^G0<WZV@3:jI/0b^RN0<WYYP3DfZh0`[nF0?Ggd03eonL0jOoo0>Oo
o`3;im00W[fM00<Y403Lo_l0n?go0?omn`3ooOP070T3069DB`3oh>D0Yfid0?_onP3co_P20?oko`<0
ooom01l0ooSk0?kbm01_I5h0oooa0?ooh`3Ym/P0c>JY0<[RY03?f:40]/6706Id>@3KkJl0eNVZ0=;W
Y03?i:40e^NS0=_ZY@2V/fd0P95:0=WeZP25XEL0b^FN0<ORV`3:iJ00koo40<KOV`37gYP0a]fE08^Q
F03CjJ00b=nI0080cnBO00d0f^nZ0=7VX@3:giX0g?6/0<_PV`2G[VP0aMbF0=K[YP39fIP0WJa[0<kJ
VP3Dh:00d=ZK0080f>:S07<0hNf]0=GTX`2LZfX0SimN0=;XY`2C[6X0a^6N0<WSXP3=jZX0[l^>05el
@032iZP0an^^0=;c^P1fTfD04RdL08VfV@2liK/0IHUK0;_Q[P2il;T0/NB/0<[e_@37iZd0_>ZQ0;_W
W03Wo;L0cN6L07B5?P3IjZ<0gNfT0=[/XP1^PSX0_=:90<[TV`3Ilj`0a^2I0<gSVP3<i9X0h?R^0<CL
TP1?Iad0b^bR0=W`ZP3IjZH0g^>S0;NiNP1=F1H0_/f:0>Gj]@2ogID0c^jU0<cZX03?jj00b>NI0<KY
V@2liIH0`nVL0<SXW`3?iZ00^Kf006AK9020L3`0kmVW0:6?G@2`Xfl0hMBP06=F8P29O4P0k^:^0=c@
W03Mdih0Y9QT09:8D`2l]Gh0PH530=GYY00dB@@0Y:Y/08Z0B`2STf00hmbU0=;YY@3>jJ80dNFN0=OX
Y03Gk:T0cnRT0;oJT`36iY/0cNnR0<KXV`34iYT0a>BK0=C_ZP38hJ00e>nZ0<CUUP36iiP0co2Q0<CS
U@37hiH0b^FH0=?^X@3Cjil0eN^P0<OMTP2dbGh0X[I^0<7ES@3Bj9l0c^BK0<oWW@3=iid0c>RM0080
b^VM08H0bNVM0<WYX033fid0eN^Z0=[`Y@2me8@0f>jL0<cST@3AjI/0d>ZY0<gV[@3So]40mOoX0?_j
mP3ooo/0n?c^0?KojP3eomX0cN:Z0=?][02ig8`0d?:U0<oeZ033hiP0cmnH0=K^Y032jid0`nRK0=KQ
W@3JjjL0I7/e0=;MV`3_fjH0en>S0=G/Z03<f9H0f>NR06Il<`2L]6X0eO2S09fhJ`3:h9L0d>6K0=GT
W`3LiJH0c]jP0=7g^P3;lkD0_^b/0<[h^02<^WT0`nf[0;_OV@3>kZD0J88h0;O?P`34fXl0e^ZU0<CH
T`3:gYT0bMfH09JWH03Gk:40bn6F0<[WU`3<j9/0cNbP0=gh]@3=hjD0[[^=0?kog@3non40dN2e0<cT
ZP3<iJ@0dO2T0<c[W@3;jil0anNN0<CRW03=iih0d>^N0<gXU`3:iY/0anFK0<SVW03AlJH0_^2D0<g_
X`37kJ00`NNJ0<C]W`2liiP0_^NI0<ccY034hjX0d>_00=offP2]`9<0UjF20000002WZ8P0];Af0;fm
M`2h`7L0d_2V0<K/X`2kg9D0e?:/0<?IV03/ol<0RiUV096JK@2i^YP0j^O80?;/dP3ooOd0blK=0?Ob
mP2g][@0o?kc0?_ol02ka:T0^/BR0>3/a03Fi[T0V:Ei08nMJ03=gZL0fnnd0<oSYP3AgIl0g^BV0>OU
[080o`0000`0d=VP0=7SZ@3:hj40enjZ0:FcN02obY80eMj_0=GR]P3Ol<h0Zk^P02/j9@3looX20?on
o`0a0?clo03oool0n_[j0?ooo`3moOd0oooo0?Gem@3oool0o_kn0?ooo`3ooOl0mNc]0?omn`1;@T<0
i]gR0?omo`3oo?l0n__e0?col@3Fi[L0a=NO0=?/ZP3Ajj80d>RJ0<7FV`3Gj[d0`=Ff0>?ldP3gonP0
nOo]0?olmP2iY9<0f^BU0<o/W02niI80anbL0;gHR`2FVE@0fMZH0=SbZ02dfh`0`njO0<oaY@3AiJ00
dN:N0;S9Q@3GkJD0dNRP0<;NT`0;0?ooo`002P3oool0403VnM/0joOQ0?[olP3oood0oooo0?OlmP3k
ooH0o?oa0=KE]P3Kek80OWa;0=;TYP39iil0b^RN0<_^W038k9D20<O[T@1b0<W[U@3;jiP0c>^K0<cU
X`3Bi;@0k>K<0:6JOP3lon@0h_oV0:CEf@27][`09dPc08VTQ@2S^j<0kooo0?ono`3onOH0o_?_01d:
102RU8/0onK]0>nh_P3dno<0l_ge0?[`n03onol0n?Sf0?[jn03oo_d0ooSl0?oko@2FSHH0oooa0?ko
h`3iom`0c^R[0=3VZ01TKCH0bMBL06Yh?@3ChjD0fNV[09:UH`18FaT0dnBP0=WXX`3AgYT0d^6L0<GM
T`2]a7`0`MJA0=S]Z03Bij@0nOo:0=KYY`3MkZX0bmbF0=k_Z03:gYH0cnZS0=;]YP2ofY<0d>^T0<SS
W03>jJ80dNbU01Xd002echP0d>ZS0<cSW@3?gih0e>>R09>OG`2=UeP0D5TJ09BMGP2LYVL0e^:R0>3_
[P1:FQT0e>NU0<cOW@2HZfT0`]:A0=g`/02meYD0Tj]]08RPI03Gkk<0b>2V0<kZ[`1gTF40A5]10:S@
Z`39kKd0b^Rf0<OX/`2ij[<08e8N08Z^OP36h;40`^^_0;SRXP3>iJ40f>fZ06f1>P3>hYX0bM^A0<cN
TP2=XET0VJmV0<WSVP3?jZ<0an:K0P3@iYd0?`3>iY`0bN6G0<kXWP1mU4h0a^2I0<kUW`31eI00fNFS
079h>02`]WH0dMZI0=3UX03<jZ80bNjQ0<cXW@35hI@0b>VJ0<_bX`34jI`0dNnW0<oVX03FfYd0j=nX
0=g=V@1SCA/0XiIR05Q>6@3KdI`0F54K0=WBW03;a8h0dLbE0:ZWL03Hdi`0FULP03Xk0@1jPd80eo6Z
0=;]YP2PZV/0Qge806ME8`2UVV@0f>NV0<[NV@3Jhj00dmVI0=WSY03@h9l0g_:]0=7[XP3<j9d0b^ZN
0=3bY@2mhYD0coBW0<7UW@38k:80a^VG0<CWU@35j9H0b^^J0<c[V`020<cYV@2E0<gXV@3?iiT0cnNI
0=3VV`37fi<0S:9I0<_QV03Fk:<0`]Z@0<gWW@3AkJ80b^VM0<o^XP39j9`0c^bT0;S@TP3Mlk80KX@i
0<[QT@3Jl9h0e>^I0<oWV@3Bk:/0cnR_0=_fb@3eonP0ookm0?ono`3noo/0nooc0?Soh@3AiK00a=jM
0<kaW`3Hnj/0`^RK0<OYW@3<iY`0b^ZN0;_/V`2ki9H0h^fY0>3a[@3MlJ`0SHm@0<JZN03YjZh0c=bK
0<gRW@3FkJD0dNfR0;WHS02N^f/0dnjO09b^I02CX5X0T9UF0>3PXP3HhJ80`NVS0<7ZYP2mijD0_>VX
0:OHU`0LBPX0]n2N0<c_[@23W5X0bMjM0=?XY@3GlJP0aMnF0=;/X`3@jZ40JWXa0=7VV`3;hY@0c>VI
0=OcYP32hID0bNBQ0=GZ[`1>FBh0emnh0?Cjf03VmL`0b^:X0<WRX@36iIT0bnZL0<c[W`38iYh0d>^V
0=7[XP3Cjj40cNRI0<GUVP3?lJL0a^RN0<7UV`3=ljP0`NNL0<7[W`2ojId0^N>G0<WeZ035lJ80`NbM
0<7T[03>kL<0kOo/0?Gog`35e;<000020:^^S`3LhJ40gn:K09BEC`2MXV00e]bL0=KQW`2c_gl0X;1a
08ZLGP2=X6P0TjMb0=G]_@32g:l0cnZo0?kom@3oo_/0n_Gb0?7/j03@cLH0clo50>W/f`3NhLh0o?o/
0?_ojP2S[940c=N]0=GR]03Jj[T0a]NS0=SP[@3GfJL0jnBf0=gDZ@1nNTd00P3o0000303FkKL0_mJN
0;S6T@2]]hD0emnf0=SR_@3]nn80B5M407F1M@3nool0ooko0?omoP<0oooo00D0n_[j0?ooo`3oool0
o?cl0?ooo`020?gmo@0W0?omo`3omoP0oogk0=K=cP2<PhP0o_Sl0?gfo@3oooX0mok/0<gM[P34eil0
`n>H0<[^U`3:ji00gO^a0?7od`30gJl0bNZa0<gW^03@gkh0oo_X0<FgVP3AgI/0d^nO0;kTT@35j9P0
amnC09RIE@3Mh9d0b^VM0<?/W@32kIh0b>ZN0<SIU@2ha880TJ1M0=G[X`38hYT0c^fQ00/0oooo000:
0?ooo`0Z0<o//P3Cj;l0ho3D0?comP3noo/0o?od0?Woj`3VlLl0gN2a0=3@WP2BTeT0dNNL0<_ZW03:
jId0b>NK0<WXVP3<k9L0b^^D0=3]V`3<iY`0b>6M0>3``@3MhLX0ooSa09n>Q03/on<0]NG=0839c`2o
ool0iooj0?GojP3oond0oo[o0>7Ee`3on_L0BChj01L4003_h]X0omcV08E=EP3^mNd0n?ok0P3onol0
U@3loo/0o_ok0?oln@3on_d0c[k10?3Wh03oonl0ioK?0>3b`P3CjJ/0f>Z/0:ZcOP3Gh:T000X00=o]
/P3?gJ00^<R90=_[ZP21TTh0jOZf0;[;Q`3Dj:40go>[0=KZX`0mC0T0bmNE0>3ZZ`3CgIh0bmFF05mZ
:01XLbl0Oha60<KGT036iYd0`^:I0<c/X`37jIl0`>2G0=CdZ`2>[6@0f_B]0=[aZ`3:giX0d^NR0<7D
TP3KjjX0i?2`0=OQXP3?f9T0c=FF0>[d]@2P[fh0LhI40<_RWP35gYX0e^NQ08RACP3Oi:@0fN:Q0=[a
[@35g9P0WjU/0>3VZP3Kh:H0hOFf041C6`1NKdD0LY=N08BNG`3Cj:L0a=ZL0;gQY034j;P0/ljS04aL
=`1MOU<0Y<ZG0<;QY@2kfI/0i_nk08NNF03HkJ80f^nR0<gSV03JlZP0RZIL0:G3O@34hYX0k?ni0=gc
ZP3>iY`0bn>I0=K`YP3LiJ@0_MB>0=;bZ@2mhiP0aN>K0=_QX@2RX6<0E50C09RSH@3Lljd0bo6T0<cV
W037gI@0_]J<0=SdZP3:iY`0e>^U0<OKUP3LiJ@0OWm3065L8P1PFR00V9UM0:N]L@1UJbd0EedO0>[`
]026SU80WjQY0=SRX`3:e9L0iNn`0=OVY@3Dj:<0a^RN0<[^Y03Sl[40h]^U0;RTLP3KcYT0U9eN075l
>P1/J2T0RhE709VHF02KX5h0Q8]80<CAS03@hI/0fOF[0<g[X@2ffhh0]=Z?0<G_X`31k9d0bNbL0080
c>nO0P38jIX20<[YV`<0c>RK0940cNRK0=;/XP37hIL0dN^Q0;gGS@2T_W@0f?:X09VcJ@39hiT0e_2V
0<OQU`3GlJP0`mbJ0=?ZYP3<hYT0X;MY08FJB`2oeXH0gOFY0=;]ZP35gj80eoBn0=K[`03loNl0ooog
0?gooP3koo`0n?oZ0=;U]`3?ijT0b^ZG0=3`W@3?kj@0`N>G0;oTUP2hhi<0^o:O0<7`X03HiJ00c]nK
0=?RW`3CdiD0]IET0=OAU`36dY80_mnF0;kPUP3Injh0cNnR0<GTUP34gi80dn>L06Yd;`26QTH0J5lV
03<e0037kJ00b_2W0=3e/P2oijP0`_:f0;[//@2bhZP0_NJ/0=ga_01hQE00f>F]0<[ZW`36i9X0S:aQ
0<KVV`3>fiH0cMjG0=3VV`34h9<0a>FF0<_[W`3Bkj`0a]jP0=ST]038cjD0oooO0?Sog@3Ek;@0bnFT
0<WUV03=jI`0b^JI0<CMV@3Ikjh0dN6P0=3QW@2FYUl0eNVT0<cPV`3=hYd0a]^F0>_o^`3;h9/0e^^V
0=GZY@3Kl:/0_mB?0=ga[03Hij@0nooI0?coh`3kon`0bMVZ0=GU_P002000YkjD0<KTW02ogY80cnFL
0<k@S`2c[G40Y:UY0=3IVP3Ojjd0`lnA0<_IWP3BhJP0bNF[0;SJWP2li:P0lOSG0?khhP3oond0mnoR
0?ommP3ooOP0ookk0?ono@3oood0l?;_0?koo`3mo^`0oooX0?_ohP3PiLL0];>G04Do9@1SE3l0QgYW
00@0o`0000`0l_o[0?Goh02RYhT0mo[O0?ook@2Z/JX0WjRW0>C/kP3oo_l0oogo0?Cbm@3no_h20?oo
o`030?_kn`3gmoL0o_kn0080oooo02T0oOgm0?knoP3ooOl0n?;d0?onn`3ooOX0HUYH00H0003Zi>H0
oook0?kom03>f[H0i_K90<WZX`35kIL0`^Z90<S[U`3;kJ<0_NFO0<G`X036jJD0`=VR0??de@2m^980
eNFT0=KbY`39jih0cNNM0<kNU`2OVe`0gMnN0<SZW@2okYd0`NjM0<[YW@3GhZ00?dP7096MF`30e8d0
fO2X0<KVV`0;0?ooo`002P3oool0JP37jj<0b^:`0=WYa@3io?40o_oj0?Kmj`3konP0f>Bl0=CKY`2L
W6H0XJ=T0<oVV03;jY`0b^RN0<[UXP3=j:<0dNbO0<kYVP3BjZ00c^BS0<kSZP3aomT0o_o^0?okm02c
XYP0mOoZ08blXP2eool0cOoo0>Won`3/nMl0ooo/0<nka01oLG40ooSc038W8`1SDDd0ooO^0?oVk`2S
KWP0m_ge0?Soo@3onol0ooGg0?_on`3noo/0n_Gb0?o/l02PSHl0ookd0?ook@3Ei[`0bMfZ0=CYZ037
eiP0bmBO0>;[]00C7000a]6G0>C_]@3AhJ80c]jO07Z=B`3:gYT0Q9UD0=G[X`3:h9L0c>2I07>2?`3M
jJL0b]BE06mh>@2MYfP0VZES09VTH02@WEL0eNVQ0=?cZP33hiX0`N6H0<_[XP2mgI@0d>jV06n:@`39
gYT0a=RC0<cKV03Mk:T0hoRe0<cOW@2:UUH0T9YK07Z3A03Oj:T0cmVJ0<gMW02X_GX0jOno0<KTW03A
iil0X:]W0=7FU03BfiX0_mVB0=7[Y02OYFL20=WIW@0i0<;BT@12EQT0Tj1d05Ic>@28WeT0UJIP0=3T
W`36jJL0b^^f0;C>X@2haj00;DhS06bDHP3Dn/40doNj0<KSX@2?Z6@0e>ZQ0<3ERP3LlZL0d>RL0;SF
S01UPcd0c^bT0;77OP3<hYT0b>2F0<;JT039hiT0f^>R049I4`34i9/0f?jc0<[ZX@3Hhj40hnRX09VI
F`1LIbD0S:1K0<OWWP3:h9P0g_:[0=GYXP39h9P0d>NO0<[OVP2`a7l0VZIT06ae=00^=000AT/;0:jh
N@3FhZ80/[in0:VeM@3EhJ40i?>b0080c=^J01`0h_6`0=7QX03PlJd0d>BM0<_]X`39jj40d=nN0>;K
Y@2PS5X0j=^V0>7[[03Ghj40W9]K09nKG02IV5P0CE8@03]2002S[VX0WjiY08jTG032g9<0f?R_0<g_
Y@2dfXl0coFX0<KYV@37jYX0a^VI0P3:ji`40<WZV`80b^VK0900aNBH0<KUV@3FlZL0d^jS0<[VV`2`
bX00T:YP0:O1M`2fd8H0f_BZ0;gGSP3<iJ40iojh0=7WWP3Bj9d0SJ9E0=oeZP33fhl0`mjI0=3ZZ@39
ijT0d^^d0?Gih03noo<0o?oo0?Sno03iond0b]^_0=;W[03<iiH0_mb:0<OUV`3@kZ@0cO:T0<ceYP2l
lj00_NbL0=OTW`3?hih0hOF`0=7CU035ZGL0UYAI0:BdL`3?kjH0gond0<OYW039jih0d_6S0=KaY03:
fY<0T9UF09bNG`2g/7T0U9EI0=Gi[`2YcHL0b^b_0<?Y[02jj[00`oJm06jOI`39m;`0a=JR07b4D@3P
jk<0c>ZP0;_IS`1LO340`N6F0=STXP2od8X0b^2G0<CSU@3<kil0`nFH0<?RW03>ijH0aM>P0;S0T@3m
omX0looG0<oX[P37hJ00bNJF0<o/W03<iiX0goJb0<gPX02NZV`0VJ=T04eF5@2BWU`0VJES08B@CP2m
bHL0b=BB0=GPWP3Cg9/0d]^J0=KOWP3]m[D0f^2P0>_][P3oomP0kNc=0>GWc`3Qk[T0dn>f000>0025
Wg00bnnU0<[aXP3?kj@0h^f[0;VnOP2iaH<0e>BS0=CRY03JiZP0e=VO0>3UZ`3ChZT0d>FZ0=_g^P3R
i/40oooT0?gegP3onNH0nnkV0?oln03oo?d0oOOi0?ono`3kn_l0ooko0?oom03mmnL0ooo]0<S7/P1I
E400]ZfL09:2M@3Lc/<40?l0000?0?;on03o0000o`000?ook@3ooo<0Zjn^0;2e^@3kool0nOSn0?kh
o03oo_l0oooo0?clo03oool0nOWi0080oooo00@0moOg0?ooo`3oool0oooo0P3ooOl09@3flNd0oocf
0<Bl^@0_9bD0VI>C0??bkP3`lNT0i>gB0=SS`@3HmK/0bnnW0<W/TP39jYT0a>JL0<7YXP2ihhl0b>VR
0<oX[`3oon<0X9Yh0=7QX`3?jZ<0c^jU0<gRW@2b_G/0WYQJ0=kNWP36jih0_^nM0<;]W@3<j9d0e]nL
06U_;`2GXV00cn>L0<cSV`35iIX02`3oool000X0oooo0<D0ao>D0<GTX03?iK@0n?o]0?kom03honP0
nooS0=SV]@2V[W80FEhN0>GZZ03Aii`0c>NT0<kVZP3BiKL0d>Bc0<kQZP3DiZ`0d^:a0=_Z`@3]n]`0
n?oa0>?ff03oonH0Z9n00<SCZ@3Am=<03dY@06fW/`3]ood0jo?K0>OQb`3ok?<0o>c/00T0000<0@00
i]OB0?ommP3oi>l0ikBm0?WonP3boOD0oo_o0?oko@3ioo/0o_ok0?omn`3on?/0BcDg0?ool@3goN<0
d>Bc0<_PY`3BiYl0SIaI0=WP[03/lkl01Pd009JOJ00lA`d0gnna0<?FUP3Lljl0]m2<0<KQVP3>k:80
h?nc0;[DR`3Kl:/0BUhI05YY:03?gYd0fNRW0=KWX`3@i9d0h?J]0<7GSP3Ek:H0`]bE0<oYXP32g9D0
hoZd08ZKE`2IZ6D0fMnO0:JXJ@1GDaH0F5XK0=S_Z`2hcHX0dN2O0=OSX`2DWUl0P8Y;0=o[Z`30eI80
aMjJ0<KWX02mhiP0_^>E0>?g[`3?fI@0/l=l0<CYW038jYh0fn:O0>o^[P3UhJ80HgL`07J<C03JikT0
c^b`0;kFRP3Rlj<0c^6@0<kaX@33iZ80d^ja0<CGX03NolT0[=VP06FEH`2;]h80bnnb0<GUY01>J1l0
e>bR0=K^XP3CkZ40d_2V0<OUW@3KnK40S:1H059X7`3Lm:X0e^jT0=K`YP3IkZT0bMjI04UP6P36h9T0
f?>/0<KQVP3Fl:T0cnJP0<oNV`3LijD0CU@D05iW:022S4d0dmfN0=[UX`2JYV@0HG0[08JGD@39giH0
c^JL0=7[X@3FlZL0_=>;0=ca[03AiZ40eNZU0=?WXP3=hI`0e>RS051T7`2H[6L0g?2[09BSH03RkJT0
dNJQ0<oVX03HhJ80W99M0::@GP3Ke9d0dNJS0=SbZ`3Dhih0f^FP0=GRVP3IiZ00g>VS0=;OVP3OjjT0
UJ5Q03i:2P3;eiL0e>2R0>7_/@3:gI/0c^fQ0<c[W`36iYX0c^jR0<_[W`020<SZW@<0a^^M0980aNbM
0<;YVP31iYP0anVL0<c/X03:jYh0bnNL0<STV@3<iY`0c^JL09F[HP13FA00^]F80<SPUP3GkJD0a]bD
0=;VX@0mDPd0Rj9J0<kZX035hIH0dO:S0<cXWP3Mk[L0kogI0?WonP3good0nOoc0=KV`P3>h:`0`]V;
0=7VU`3Fk:<0dNNO0=?YX033hYH0^NZI0<G`X@3Dhih0dNRR0=?aZ@38fID0eLZB0<oRX03ClJ/0fNfX
0=S^YP2K]F/0eO6V0<SWV`3DlZP0cNBN0=7TXP38eYT0h>R_0=COY`003`00CFPc03E?7`0@;@00`_6m
0;?X/020]WP0E8920=CWY`2DV5/0hnRV0=K^Y03?iid0RjEK0<KPUP3GhZH0^lj<0=3ZX`38jYd0aNZJ
0<G/V`2ifhh0`n6I0;K8RP36dIT0gnVg0=3T/@3=ijX0b>>N0<[WU`3Ak9/0c^JH0<kNW@1OJRh0d]FN
0>;R[03DeI`0c]JJ0<gIV@3NjZX0eMnP06=Y:`1DF1/0:R/00>7RYP2PWV<0HElT0=oJX03CcY@0CDTL
05UE<03Sg/00alf?0>;//0001P00IgQ40<_RW03HlZ/0f_>a0<3GT@3=iih0bnfS0<[[Y03HkJX0e^2Q
034V001UEB40IU/S05mM8P3BeYT0iN:i0<o9Y`1QEc`0EDPe05e?AP1YFUD0oo_k0?oko@3lm_P0o?[k
0?ono`3onoH0oo_d06iQF02IShD0oocc0?okm03om_<0oo_k0?K]kP80o`0000<0gO3f0?l0003o0000
0P3o00003`3oo_P0j>G/0?Sfo`3ooOl0e];C0?oimP3oood0VIVI09bLW03=cLd0000000/;2`1EEED0
000000T92@020000000W0000100k>Sl00@4000`<0026PWH030P00>_Vh0030000oOWh0?gnmP3ooo@0
ho3L0=KWa`3FjZd0e^Va0<cQZ@38iJD0eoRY0>Cn_@3eomT0ookc06EEAP3Rk[`0dNV[0<kXZ@3ChJ@0
ViaR0>_PZ03NgZ80aN^N0;k_WP33k9d0cnNM0=kUXP1?E180UIiK0<GIU03FkJL0cNfT00/0oooo000:
0?ooo`370<GdSP36iY/0cnJ`0?_okP3noo<0k?GJ0>Kbc03MjkP0RI9C06Y_;@3EfYP0dNFM0<kVZ03F
kKT0ioOB0>Cdc`3QlL@0joS:0>;^aP3/mmT0nooa0>;`h@3ImLl0l?O=0:6LLP3DfZX0^=:]05^<T`26
]/@0kool0?cok@2XXhl0ooWo0?ojnP080000Ac`h0?oim03ooOH0on[e0;>0R@3iooX0m?og0?ojo@3o
moT0nOok0?Oim03ooO/0i<kA079LGP3oonl0o_oX0<WP[03;hjL0g>fV09^XH`3Tj;D0eMbX0048002R
Zg@0LWe30=_[[@2fbHT0d>NS0=Ob[@3>k:@0a^JK0<CVV@39iid0`]bE0;?:Q024UeD0i?Bc0<[MV`3>
hih0d>NO0<OQU`3@jZ00`]JA0:o4O`3@iJ00aMZE0>3d[`2V/W00^<600=3>T@2;QDT0ZIeS0=gIW03A
jZH0d^NT0=g/Z`3@g9`0SYQI0:ZdM@30chh0eNbX0=;]Z03AmJd0`nbP0;ORT03=iIT0gNZR0<OLT@2h
hI80dORY0=?MV03ShZ40hMfM0<KLT`2N]gD0bm^^0<3OY03CkZ40enZH0;K<M`2ni8d0bo6T0<OVX03B
j:P0/MZD0<Oj^02Ld:00BWY80<?[[`2nhJ40V;9[08VPF03BjYh0_MR;0=Sf[02`cXH0c^bT0=7UW@3O
mJ`0FG4W09bdJP30fY00anFM0>3e/03DiJ40HG8^0<SMV031hiT0doN]0<CXWP3JkZT0f=jN0>_UZ@3>
dYD0U9aP09BMGP2AUeT0VZ=R0<SET03Bhid0cnVO0<WXW03>lJ40_nBF0=gi[`2oeXh0d^VQ0<SOU`3=
hi/0ZKef0;;6O`1nTT/0eNJP0;G6P02f`gh0TiQF09j]JP2Q]G00gnFW0:FII@3C`i00dljF0;_FT@3=
kjD0b^6I0<[NUP3=hiP0eNZO0=GVW`3BhI`0dmjL0<kFVP30aXX0JFdb04U:4@3HfJ00f^:V0<OUV`3?
kJ<0bnVO0<cZX03;jj00b>ZN0<K[WP030<G[WP130<?/WP36kj00c_FV0<CYV`31iYP0a^RK0=3_X`39
iIX0e^jT0=CZX@3?hi/0enfR0:g8N@3IlJD0`]R@0=[_ZP3@hj40hoRe0:[1N`32gY<0g_Z]0;gOR@3>
kY/0dnRW0=c]`03doo@0n?oo0?Som@3>fkd0e>Bc09:WG02HZe`0c=jD0=3PV@3Fhid0e^bS0<?^W`34
kIl0d^>M0<SRV`33iid0e>^U0=WGW03?kJL0^=bD0>ki]`32chX0GgD/08FOE@38ii/0b>JL0<gXX`38
hIl0en^^0=CSZP3CiZl0EG5107fDJ03;h[P0e_;904QfA@2nmKh0]^f/06nNF03Gj:80M7Lb0<oBR`02
0<gQV@1@0:NmM02S^G00e^BY0<KKVP2@ZFD0aNZL0;_RT@39lil0b>fM0;[JS`3Ml;00eN>V0:fgPP2k
ciX0b^NW0<WWW`3:iiD0d>^J0<kUU`2T/g80@d`C0?oocP3PgJX0hN2Z0=;PXP3@iJ80e^^X0<oRX03>
gI`0SIUI0829BP0^=000N7Tm08f>DP3IfYh0h>JZ0=_N[`2NX7P0FU`g0>7XY03HgZ004Q8009:FH`3=
dY80e=ZL0=;GW@3NijH0fNJQ0<kUW`3DkZL0UZIU06=/;@2j[gL0XIAM0:2LG`3[lK40c=^H0=SI[`3U
gkd0ookV0=W:]`2ZVHl0OVeV0>3@d03om?80ookj0?glm`3oo_T0ooC`0?oim01OD4T0oocc0?[]i@3o
no@0oo_h0?okn`3nn?X0jO?e0?;oo`3aool40?l000090?K_j@3mnol0i^G]07MfOP3km_<0oogd0?Wh
m03oool0nOWi00@0oooo02/0m?Cd0?ooo`3oool0oooo0?gno`3loOl0JFYR09RIR`1JEdP0HUiB02HR
6@0<1PP0LFe^0?ooo@3em?00o?oo0?WomP3eomD0jOC90=SU^@3@iJ`0aN6G0=3U[03Ji/80oo_k09Ao
O03nomX0j_o40=?[[`3Gh:L0ViYR0=_>U`3OgJ80aN^N0;k_WP35k9d0d>JK0=WNW02RYfD0dmZG0<kR
W@3GkZP0b^VS00/0oooo000:0?ooo`1J0>7ac03KkL<0bMna0>;i``3Un/80f^V`0=cZ[`3FhJL0M812
0;O6Q@37fiH0c^FQ0>7e`03^omD0nooa0?con03lood0o_ok0?_ol`3hond0o?o_0=_Va03Kj[<0dOVS
0<G]U`2?YVh0`N?204UQI@1nRHl0XYF=0:2ST03joo80cl;<081aKP13<RX0bKJ`0?olmP3bn^l0oo;j
0;f>V03oo_P0m^oW0?olm03ol>T0o?;X0?ohlP3onoP0F4Q;0?7Ui@3ooo@0ooo]0=gZ_P3Gj;40dnNO
08ZNEP3?fYh0f]fX05eM:`2JY700amnU0<OZYP38jJ80e>ZR0<oVWP3:l:L0_>JL0;oZVP34kIh0c?6T
0<W[W`39iil0h_Ve0;?8Q@2faXL0S9aM08VGF@1RLC00SZ=F0;O>P03SnJh0eNZO0;O7P02DVeL0jo2^
0=3ET`2LYf<0am^F0=3TW`3HiZP0f>^[0P3AjZP0?@2AVeh0WYeT0=cCW03gi[80^j]g09^DG@2GUEX0
eN2N0<7KTP3?iid0cn6G0<OGS03Gkj<0e>BK0>3ZX`3Eg9P0`_>R0;o^X01JGbL0a]JG0<k^XP3:kId0
Y<Aa09:_G@3LlJH0d^>L0<?DS@36i9X0ao:[0<3ma019OTH0b>>^0=;T/03FjZl0c>2S0<;QWP3>kJT0
`mFG0=CRY@3EhJ<0aLj;0>C]ZP3DgIX0_/B40=gRXP3?lJD0e?2V0<WSVP3DjZ80T:MO0<_UW039iIX0
d^bR0=3XW03Fk:40dnRM0<?MT`3Hm:X0a^:H0=7[XP3Fl:L00P3>jYl01@3=k:00c>bP0<[/W`35iIT0
f?2V0080dNFM00@0amfD0=[`Y`3=iid0cNNM0`3<j9d09@3:j9h0dNbY0=3VYP3GjJ/0^[f409BAFP1=
C1@0IVT`075o@P1AGb809Rh004=83P1>EQ/0@T`?05IR903MkJh0c=bM0<WLW03Ej:P0e^VY0=GSYP1=
F1`0E68W08:CG03;g:D0e^N`0<cNY03Jk;00dNZX0=7/Z@33iid0_>FI0<7]WP2njIX0b>JL0<OUW@3:
j:000P3<jZ80T03;jJ40`>2G0<GUW036j9h0anRQ0<ORW@3>f9T0Y[Ug0<?RWP32hId0c^^Y0<oOX@3D
h:80WZQ[08ZIF03:iIh0a>BK0<[WY03>j:/0e>bh0>;jb03TnlL0bMjV0=[_]02V^gP0dNJS0<;EU@2o
ci00VImS09^JH@2Z`h40`]fJ0=KTYP3IjJX0b>bV0<SWX`3QkJl0`M^J0=7bZ`3JnJd0a>2E0<7HT03?
i9l0MhM809NVJ`2HYFl0QiAO08NCH@39eJL0QYAO0<WPVP3Ek:P0an6R0<gY[02XbhL0OZ9L0<_`X`3?
kj@0d>FT0;71P`3GjJ/0aN>I0<cXWP3:hYP0SZAI0=S][03=hYl0Vk1[0<CKT`3GkZH0cnNM0<KRU`3@
k:40anFK0=;bY`2`bh@0EV/V0=oe[@39i9L0bNBC0=S`XP39gY<0/;Ih05iM9`3XhKL0oocG0?3bbP3[
olL0cN^U0<[YW@2ogXh0cnbL0<o[WP3<ij00cNJT0<WRX036gi/0e^fW0<cRVP3DhjX0d^2]0?cofP1i
Q480CEHO0082000?4`00MGi50;BnP@2DV5d0HEPQ065D7`3Ke9d0fmRQ04a?5P1HH2@0dn:O0=;SW@3=
jI`0b^fK0<C[V03<i:H0dnB`0?_ofP3oon<0ook/0?okl@1PB4P0ooOj0?ofn`34ZJh0:@hC05U9B@1L
DDl0oo_o0?olo`3ll_X0ooco0?oln@3hlnd0o__d0?oonP3=cl`0<ca10?Ooo`80o`0000H0k_Cb06U[
JP3onOd040L<03H]<03bknX20?oomP030?oom@3oooH0ooof0080oooj02`0oogj0?ono@3blNl0ooko
0?omo`3fnoh0nooo0?onn`3ooOX0j^7L0>KOf@3Qg]L0k>kY0<W;b020P800O7Yk0?7hl@3iooH0nooS
0>Shb@3<gjL0c^ZP0<k]W`35gYd0e>Bc0?ook02IQG`0noo]0?7oiP3=f;P0j^S209nLK`2GWF40cn2L
0;gWU@34lIh0c>nM0<oZV`23Ve40`mfD0<[QV`3Ll[40amfM0?Ood@/0oooo000:0?ooo`0X0?Glk03[
n]T0dNNi0=3]Z`3@jjH0e>BS0=GQX`3>f9`0SYaO0<OJVP3BjJD0cnFW0>oodP3ion@0noog0?cno@3o
oOl0ooko0?goo03mooD0o?o_0=GP^03IhZT0_Nb>0<;hV02_d9L0bo3A0=_]k`2?T9D0o^[Q0?ool@3k
ooL0ETYD02<I3`17=bL0oo_]0?ogk03hooH0onS/0>Ji`080oocf06l0oO3W0?oll`3ono40oo_d0?of
l`1VFU`0n_3a0?cilP3ooo40bmJ^0=KT[`3>hYd0UZaS0>?c/P3DfIl0EEDQ0<[GXP3ClKD0a?2U0<7Z
W032f8d0amfD0<G]Y032lJ<0]N:A0<G`X02_eXL0a^^N0=;bY`36h9T0i_^f09ZZJ@3Pk:h0dmfQ0=gW
Z03Cj9T0a]f=0;kEQ`3HkJ00ho2X0;>hM@3VjJH0Be8?08nNF@3Fm:`0dnjY09ZRIP22TU<0an:O0<oZ
Y`2?VE`0ZZQ_0>?FX@20JCL0KULU0;jaO024ND<0g]bQ0=gb[`35g9@0f>VR09ZRF@23V4d0Zk]b0=KS
W@3JiJ00`_NU0;GVU`2ZZG00eMnP0<KVV`36kIh0a^VI082HC03AgYH0fNFM0=o_Z03EkjH0^>2I0:gX
[P0kLCL0a>Na0=Ca^`3FkkH0eo2f06b4AP1<H240f>:U0>7WZ@3Ni:H0j_^e0=3OVP3UlJl0am:@05MM
7@34iYT0d_2V0<;NU036h9L0c^FM09:XG`2CZF00aM^@0<_SU`39i9D0d^nO0=CeYP35iIT0cNfQ0<3P
U034i9P00P36iYX02@34i9P0aNFI0<OWV`3?kZ80a=ZA0=GVW`3<h9P0`MN>07bDBP020<cXW@<0bNVM
0400a^^N0<GZY038hZ40d^FU0=oUZ@3>ciD0h>BY0=KNXP3?fId0fN>W0=;GW`3OhZ/0g>6Y0=[RY`3R
k;00O8a=0:6fL`3Km;00c^NS0<ONVP3?i:40cN2P0<[JV`2<Uel0@T/D02@]002QZW40[KIm0=3KW`3C
hj@0eNj/0<g[Y@35jJ40bNZS0=?YZ03@iZD0an:M0<CRW035hid0d?2W0;CFRP35ii/0`^BG0=Wk[P3:
iY`0en>U0=k^[`2<Yf@0ZLJ30=Ka[P3NlK40bMNI0=OSY@2JZV/0fNn^0=;]ZP3<jjL0aN:O0=7^Z`3@
kJX0`mjK0=?/ZP34gI/0bn6P0P3@iJ@09`36fIT0en6T0=;AV02AYfH0Tji[0<[HVP3Bh:80d?6/0<g/
Z02kahT0go:b0;gKT`31iYH0`NBD0<oYX03Mm:h0_<Z=09FPIP2EWfX0/K^70:B`OP2FXW80MhI?0>Cl
/03<iYd0`M^J0<[WY@2G]W80d_:Y0;cJT03Ak:D0d>RZ0<GJX@11FAl0`nFK0<WYX03Fl:H0J80d0<WP
W0020=CYY02709:VH@3?h9X0cn>L0<kUW@3?jIl0`nFH0<O/WP3>l:<0[L=j0<OMU03?ii/0c>VG0<gU
U`3MlZL0h>JV06m`=`3Zikh0k>S30?oog`3aolh0d?2W0<o_X`37jID0b^bH0<SYVP3:jJD0b^RX0=;a
[P3<jjL0a>:H0=GaYP3Jl;00`]FM0=7Q/02ocXT0e^>[0002001HHSl0dMnT0=KVY@3KiZ@0hmfS0;^^
N@16?`P0B4<<0::XK03Fh:<0d>NQ0<gYWP35jiP0aNfG0<;]U038jJ@0bnNZ0=KX^03RkLD0ookX0?oj
jP1H@d00=AdM0654B@21HVP0on3V0?oknP3ekNX0ooco0?gfoP3onol0n?7h0?onnP3oooH0ooke08n<
Q@3Og=L0OhN90?Goo`3aool0hOGd0?Goo`0R:R`0MW1b0927R03ooO/0oooh0?gom`3ooo@0oooc0?oo
m03oooH0ooce0?oonP3oo_/0oogl0?ono@3imOH0n??g0?SnoP3iood0ookk0?ojn@3_i>80oo[d0?Wf
l@3kooT0nooj0<G5``1HE5D0nooj0?Wom03MjlP0gno20=?V[P38hi`0a^JK0<SPXP3Di;<0oooX0:6=
PP3bn^/0mooc0?7ii03Wh/@0dLfW0:2ZKP3Ek:H0a>^J0;cVTP33i9<0`]f@08BRF03:jZ40dNnW0<kW
Y@3?iJL0i_W100/0oooo000:0?ooo`2?0>[gf`3Om<T0an:[0<SXW`3<j9h0d>2O07=n@P1?ER00g^Jc
0=?PZ`3@h:l0dMfi0?Smj@3ooo<0o_cm0?omo`3oo?l0oo_o0?ono`3no_`0o_oj0=oXc@3KikD0e_^[
0;gZV@1eYVl001d104EGF@2W[;00ooW`0?ool`3hlnd03P/60006003KfZ`0iN2h0=SE]P3Wm=H0hKVg
06Lf>P2dYZ<0YifK05M?C@2;PGl0l>7J0=W:a@1jK6T0nNo`0?olo`3oooP0n_c^0<oI]P3LjK/0cMnQ
082GD@3<iYd0j_Vh06=]<032eYT0_>6L0;k_W@2njYD0_mJ60=O^X034jYd0a_6R0=CiZ@34iiL0bNRJ
0;gLSP31gI00bMnD0:6fJ`3<gIH0c]jG0;G0N`2BWeT0g_>X0<kTV@3LlZT0XkM_04AA2`3Ri:<0alN9
05eO8023ST`0`]VE0:JiM`37aH`0Ee/P0=?VYP3Bj:L0bmjN09FQH`2X[W80^kn40<cDV03CiZH0/l63
08AmAP3Bf9`0bmnJ0=K/Y03Bhi`0eNJP0;6nN@2CXUd0e^NS0<?TW`1WQ440THiG0>3X[@3:iJ00`^BJ
0<_[W`1mUdd0amRA0>Cc[P3?hi`0c>NP0<cYY`36h[80_NFa06jbM@2Cfi/0^_:c0;[XZ031ci40dmZG
07j6>@31bW/0OY4o0;CSTP2oji`0_>:E0<_`X`3ClJL0R:QL0<WUVP32g980cnFL0<;HT03<h9P00P3F
jZ805P1[PCP0W[I/0=cf[034h9D0c>RM0<STV@3Em:P0do:V0<WXW03:jYh0c>bP0<_[W`39jId0a^FI
0=og[@3:gYH0g?:Y0<CLTP3DkZ@0c>RM0<[YW@39jId20<SZW@3b0<G/W@2ljIP0cO2P0<kVVP3Pij40
a/V40;>jMP3<ei80en^S0=3VWP39giL0f^jW0=c[Z03>gi/0f^^U0<gSVP3<i9X0WkY]0<WTU`35g8h0
k_nf0;o?Q03Nk9l0dMZ;0=SPT`3Ih9<0ViaF075`;@1MFA`0Ee8H09>@F@3JfJ<0UYIR07AfA01kPT`0
Qi1I08jHG02:U5D0Qi=A0=?SVP3Hji`0a=Z50=O`U@3:iHP0e_BJ0;gNS`3MmJ/0c]RC0:V`JP1MJ2<0
^mN<0<obXP3<lj80gOb`0:NbK@2kagl0anJH0;oNTP3ImJX0b>BG0<kYW036gY@0gOFY069j;P2cbH00
cnFL0<cWVP36hYD0c=fF0=;gZ@3;lZ40WJmU09:RF`3Kmj`0a=Z?0=?DTP3HgIX0f>ZP0<7WTP39k9X0
bnZJ0<gXV`3GkJD0b]nJ0=;WY037g9/0bMnN0;gFU@1/QD@0bnNZ0=3]]@28YGT0CFa20<CU]P2J^XP0
Ki5E08RWJ`1KN3h0aN2Y07jJH030fiP0gOJb0<OKU03DiIh0d>NS0=;WY032ei@0`mNB0;S<Q`2Q]G00
f_6Y0<3JT039jId0co6T0<CVVP38hY/0UJmV0=SgZ`38jIP0foZZ0<;NT@3:gYT0cMfN07EoB`2j`i@0
d=f_0=G]/@37hY/0b>JL0<_WW@38hj00d^ja0=3[]P3@j;H0b>6X0<cXZ`3bolH0iOnd0<SZWP3;jZH0
bnNZ0<[STP36gIT02QL30:FfR@3>i9`0fo>W0=C/WP3IkZ<0g_2V0<OKU03@i9d0f>fX0=_b[03<iY`0
cNNM0<cYU`39iY80bnRD0;SJT034ij<0`mnU0<cP[@3Tk/T0o_oU0?gji`3oonl0oo[`0?oml`3mlnT0
oooc0?onm03oo?T0oocm0?omo`3lm_X0RXB40=_Fd`3oo_X0nOCa0?onn`3hool0QYFJ06j3Q02V_;X0
IGEd0;c6a@3oo_d0ooSf0?WakP3oooH0ko7V0;ji]@2YWih0KVIT061GF01aJf/0PWal0:ZTY03He=D0
ooko0?oko03ooOl0o_om0?gonP3oo?X0oo?c0>[KeP3onO<0oo[b0?oom`3oooX0ookk0?3Wj03nood0
mokf0=SOc@3Sk=40ko[H0>?fb@3Ikl40h_;=0>K_d03om^/0Z92<0?konP3hooT0o_od0>_Uc@3ak<`0
TYUV0=[Y[P2Zb800e?BY0<[TV`3Aiil0[LR10;cLT`37iId0d^VU0<WNW@3;gIl;0?ooo`002P3oool0
403hon@0hOW70<_WZP3<k:40cNVN0=_[[015D1H0j_6n0<_CY03DgK00n?oL0?Cli@3oooP0oook0?om
o`3onol20?olo`2E0?ono`3knod0o_om0?3ii03bom40bn^R0<K`Z02ek[/07ddc0::f]`3gool0m?3W
0?cbj@2:OgT00@D002Hg0`3<eYX0fmjY0>g[a03fomh0Mda5070l?P3om?<0oOGc0?omoP1VHEh0HUE?
05A5@02@PX40oO?d0?C[kP3oooX0moW/0??mf`3bom@0h?:h08VOGP3=k:00c>2K0<_IV`3Gkk40`n^T
0<3aW`32kYT0amb=0=SZWP39kJ<0aN^P0=KeY`2ofhh0fOBW0=[eZ03]okT0AE/@0;76N@3Mkj<0gNfR
0:2^H`1=FQ80`]J>0=[`Y`2jd8P0Y[Yc05QU803Ifi`0mO>h051@503MhjD0b]fM08jLGP3]i:d0GedT
0=CRY03Hjj/0hOJe0=GXZ038f9T0f>^[0<oUY02eeY40bnBR08j7D@3`k[D0eNFT0<SOV@3<iYd0dnBP
0=kYY`2EY6<0e>VX0<_QX@1JJBh0JVLb0=oT[03=iZ@0dNnY0<CTV@3<iYd0fNfV0=?WXP004000B6<N
055S9`3FcZT0fnZo0>Gog@0=APl0[_Jf0;kb]038lj`0c_NY0=SfX033j8T0coRL0<ohZP35kYl0aNZL
0<oaY03>kZ80eoJZ045M4P3LmZ`0_=:90>3d[03QlZ`0bmbF0<oPVP3<hYX0R9iF07V@B03BjJ40bN>J
0=;/X`30g980_]Z@0<KTVP35hiT0anNL0<[/X03;kJ40anFK0<gTW03Mlj/0fO2X0<SOU`2ccH@0c>RN
0<[XWP39jIh00P38jYh0]P35k9d0_>bF0<S[U`37h8l0jo6W0=[KU@39chT0e^:J0<_SU`3<j9/0c>^O
0=;^X`39h9P0g_B/0<[PU`3NmZX0^mJ90;WAP`1;I1<0`mZ:0<KLRP3Gj9P0f^fL0<OQRP3NmZ80fo6O
0<KDQ`3Ojj40fn:N09fRH01@E1L0BU0D05ML8P1JGB@0FU<M06MJ9P1^DR00K4/H06e8501[C1<0KEXH
0=kWV032fX@0d?nO0;CVQ`37jYP0goZ]0=GOV03>eXd0GVXR0=gi[032j9D0aNbI0<o^X035dXX0S9Y?
0<_XV03BkZ40cNRK0=C_X02lehP0`]Z>0=[bY01CJad0S:9G0<SNT`3:iiL0anjK0<kYW032kI/0a_:M
0=;WVP3Di9/0d^fP0<OLS`3XiJ80hN2M0=STVP3:kIT0aNRD0<WYUP3>ji/0bn>G0<[RV03?jJ00e>jU
0=3/XP3ClJT0aN:O0;7>V03DlL40@V0n09nnW`0J?1T0BVY30;CFX`1eUUl0[ljE09fjPP3FkkH0d^2S
0=?MX03Sj:P0g=jM0<[OW03Jkj`0a]^H0>?f]030e8l0VJeX0<3GS`3>j9l0`>2D0<OYW03>kZ<0d>^V
09NbJ`2ddXP0^mb=0=;cY03Al:80foF^0<cRX@1KK3D0EV@a0<gNZP3CjJT0c^RQ0<gXX@3>ijD0d>N_
0>_od@3?i[`0cN:k0<[P[`3=iZ`0j?nl0=oo[`3:lJ00cO6W0<3PW@3?k9P0dN^R000>001`Q5<0d^ZP
0;gHQ`3>jiL0aNFB0<?TT`35iYL0cNbP0;oMT`3;iid0bN>I0<_UV`3AjI/0cNJE0<kWU03AljL0bNnV
0<SVZ03>j[00hoC70?_oh@3nonH0oooX0?cnj03dm^00ooo]0?cij03ooo40oOW^0?onn03onoP0al71
0?omo`3ilo<0m_3`0?ofm`3on?T0oogo0P3o00002P3hool0nooo06e]K@3einH0ooWg0?ojmP1UEdh0
c/6h0?kbm03om?/20?oko`80ooco02`0oo[l0?[en@2d[k<0X9bM0>WWj03clo40o?_g0?olnP3on_P0
nnST0?odk@3ooO@0o_[a0?oon03ooOX0oo_k02`/:P1fN7D0o_of0?col@3jond0n?o/0?Ook03gon/0
m__W0?obj`2NQ8D0ooom0?_oo@3jnoD0ooo]0?khgP26REh0e=jZ0>Gk^`2meY@0dNJS01`/003@jj@0
bNVP0<CRVP3:hI/0c>6N0=GUYP/0oooo000:0?ooo`2T0=GY^03<j:/0a>>O0<S[V`37iYP0d>2Q07b5
D01IG2l0oooO0?;he03fon<0nOoh0?Slo@3ioO`0o_oo0?ooo`3nool0oOon0?_oo`3eo_/0n?oo0?Ko
l`3Yom40c^F]0=;e_`2>djL0FX]e0?;oo`3gool0o_oh0;BSW00Q3PL0MXEX0=Gd^03AijH0fnJ/08>4
F01EHSL0oo?Z0:A^KP3onoP0ookk0?Kjn`3oood0oo[e0?ofl`3oo?X0o??f0?omo`3noOT0mOO/0=cU
b03IiKl0IGI20:BiOP2ogYP0enV[0<OBVP3>hZL0fojl0<[cY`36iYX0XjYV06ic<`3;gj80d>R/0<kS
X03Ai:80dnJT0=?WXP31eI00cn2J0=7RV`3AhIP0U:AK0=;RV@3Hj:40/<1o092SH@2FZFL0X[9a0?7m
_`2HUeh0GU`S0=KAVP3NgjH0gNR/09>KG`3XgJD0Ee8H0=SQXP3Cgil0a=VF0<WNV`3DjjL0d>^V0<c[
Y@38kZD0`MjK0:bRK`1VE280k?Ji0<GPV`3:jj@0gNb[09RPI02`_X40a]bN0=[JYP0Y8`00RHMF0;g1
SP39fid0`mVH0=Gc[@34giX0`MZF0=?YZ03Il[00bnBS0=cb]03Ljk@0PXiL0=7b``3:lL@0:EPZ07g2
R`2onK`0]nZW0=So]03AkYh0d>2E09BFE`3;d900e]fJ0=;MV@3IjZ<0b>BJ0<_UW03Qnk80U:YQ0:jo
N03Hij80fnZU0=?TX03?hZ00d^FU0=O/Z@3BiZ40]LV205E[8`26WED0cnJN0<7KTP37hiT0cNfR0<[Z
W`37ii`0b^RN0<?MU02E[6@0NY590<7KTP38i9X20<[XWP<0bNVN0;D0a^^M0;cXT@3>kY/0fNbM0>KS
WP30^gT0/k=c0=GLV@3Djj<0d>nS0<odYP3=lZD0b>RM0=gk/`38iYh0dnjW0<7LU@3EkjH0`MV?0<_Q
UP3<gY80FVdN08>ICP3Dm;40eOFb0<?RWP36hI`0`mjI0<_RVP39hIL0a]jB0<kVVP3Gkj40fOBU0<[W
U@39i9D0cN:G0=7RV`3HiJ00k_Ri0;g5R@2k`hP0FV8Y0=[QZ`3Ag:00`MN<0=C^Y038j9`0a^NH0=;^
X`1NLRX0QYQ>0<[LTP3LlZT0^MV=0<c]WP2;YUT0SJEK0>?k/@34g900f?2T0=geZ`31fHd0fo>W0:Vo
MP37gI@0d^jQ0<K`WP38hYP0^>FD0;o_V`3DjYl0enRQ0<OSV02oe8T0m_Fd09bMF`2BW5L0PIU?096Y
G`2@YUd0RImF0<OOU@3=iI/0a^2F0<OSV03Dl:D0e_FW0<KTW01LLdD0bnBm0>Knj02gd;d0GGUS0;oL
`03<jKd0a>2]09:^L`1ONC`0P9iP0:kKUP35l:/0a>VS0=co^01eR4P0cn:R0>?f]P36fiP0dnRU0=;W
XP2AZ680c>JM0<o[X@3EljT0_mfE0<oXYP3NmK40MHa60=K^Y03Bk:80an>H0<7OU@3Elj/0f>j^0=3R
YP3GiZ/0dnRS0=7VX@3=hj80d^F]0<gM^03gonX0mooa0?OokP3fomd0iOW40<CPUP3CnJ@0`^VJ0<;V
WP34hj00foNS0=?ZY0002@00Gfm00=?WW`3>iIL0a]n>0<KWUP3<lJ40b^bP0<c^Y03<jZ@0f_F`0=;[
Z@3;hYh0e>RS0=3TW@3?hi`0cN^Q0<_]X@3QokT0/Lj<0=K^]038gJD0e^Rf0=o_`P3RlLH0i_G:08:A
J02e^9T0VIUm0;>cV@3De;`0jnOK0?oomP3dk_00ooco0?gfo@3oo?l0ooKi00@0o`0000T0DGYX07nR
SP3Rn><0k?_V0=[Xd@3Kjm40h_GI0?W`l@3nk_P00P3on_l00`3onol0ooco0?olo`020?omo`0Y0?[f
m`3knOX0d<c90=;:a`38][80]j:O0:>;Q`30[:D0^jZR0>CKdP3lln`0oo_h0?ocl`2]Z:D0LW5]0?on
n`3ooOd0noOf0?koo@3goOT0o_ok0?oonP3on_H0/9JE0?cfnP3oo_l0oOWj0?oll`3on>P0LfmB08R8
I03Ggk00fN>a0>3Z]@2<UV40_]NE0=3^Z03=j:40f>jV0=CXX@25TTd02`3oool000X0oooo00l0a=RU
0<_WZP37iZ00anZH0<KUU`3IjJX0S9EP05eP=@3oon00oooS0?WojP3hooP0n?om0?Won`3kooX00P3k
ooP0U03fooD0mook0?ConP3dood0joo/0?7og`3?iKH0_N6e05VONP0A@Rl0l?oo0?Cno`3go?D0JeQB
02@@1`2Z^iL0`nNZ0<[TY`3Fi:l0NWaD09fYP`3okNL0Lcdm0?ohm03^kNT0nooo0?Smn@3oo_P0oocj
0?gclP3ooOl0ooko0?oonP3loo@0bmBg0=KR_P0lCAT0d^N^0<SRX@3Ei:/0e]j[0=g[]P2/b8d0bnbW
0<CNU`2>SU80@3/40<SBX03DiK40dN2U0=CSZ03Tm;H0Z;Qj065a<P3IjJP0c=fI0=CSWP2BXE`0eNFN
0=;QW03EhjD0//:30<oRXP3@h:40e^:T07Ef?01MFb80knZc0<k=U@3:eIT0UYiR0>3JX01JF1d0gnFW
0<kHV@3@hj40enZX0<SMVP3;i:00bnJQ0<CRW03Ikjh0iMjZ065=6`3IhJD0a=nL0<KZXP36e9H0PH]?
0>?b]`3=iJT0jN>c03HY002m_8`0RXiK0=WX[@3Hk:d0an:O0<OUW`3Km[<0a=nL0<_TX`3Bj:X0a=jO
0<[ZY`2/`HP0b^Be0<gX_`2O`I`04T/N0:kX]@2jkkL0]=jL0<[TX`3KjZT0UYIJ08Z;C`3WkJd0g>NU
0=GVX03CkZL0c>JO0;gGSP25Ve80UZMP0=KUX037eY40eNFT0=S[Z`3EijT0c^6Q0=;SW`3Gj:80RIeF
07>9@@2G[FD0UZeU0:[4N`3?kJ<0cN^Q0<OUV`3>jZ00SZQO0;O>QP2P]fl0eNnV0<cVW@3<j9h30<[X
WP2f0<WYWP38jYd0bo:O0<_SU@3BgiL0h=ZL0<FkP035`8H0gn>X0<kSX03=j:<0c>fV0<?TW@39jZ<0
aNBP0<_ZYP36hj40d^b[0<oXY`3?j:H0eNZU0=3UX02@Y5`0SJ9M09:YL@2le9X0cNF[0<gRY`3CjJ/0
d>JU0=;YY@3?iZ00d^VQ0<kXWP36h9H0c>NJ0<gYWP3;l:<0bNnV0<?[Y030hj40f_Ji0<gJY@1nP540
aKVA0>OP/P3NkjT0c^RO0<_aY02gh980c>jR0;o>R@25ST/0d=^G0<cPV@3:l:<0`NNJ0:g4O02F[FD0
b^6I0=G/Y03>iId0cnJN0<ONUP3@iil0d>JN0;77O`37hIP0bN^O0=K/Y035kZ00a>nP0<kTW03BiYl0
do6W0=O^YP3KgI`0kOBa0<oKV@3>gIX0e^FT08BED@1AHQh0V:aU0<OMU@3@iil0dnZR0=7[XP3:iY/0
cNJR0=CW^@3gon<0m?oc0>ool`2DZIH0b=o309F/P03>i[80bMjS0=O][`25Xf<0Ij1I09WARP34n:h0
[=nD08ZMG@3GjZX0`mJF0=W^Z`36fiP0dnRU08NNF03GlJX0c^RO0<_WW@3FlJX0b^2O0=S[Z@3>gYd0
cn2J0<gQVP3Aiih0e?2V0<7LU@33f9L0gNf_0=cXZP3EiZ00c^>N0<kRX`3Gj[<0c]fl0?Sok@3hoo@0
n?oc0=g]aP3>h:`0eo6X0;kQS`3<kZ80bNRT0<KPX`3Aj9X0bmjL00D>001dOe@0cMjJ0<oPV@3LlJH0
dN^Q0<GQU`38hih0bnJS0<oXY`3eoll0fo6c0<gQY03BiZL0cnBS0<kSXP39iI/0eO6W0<_VW`1]QT80
d>VX0<oUY`39g:@0c^6Z06Af@P2?XFl0OHeL0::XPP2NXX40TIEb0<gA/03oond0n?KY0?omo`3onol0
ooco0<>j_@3on_/40?l0000i07Z_T`21[i80`N;30<?N_`3Bjl/0b>?00>7of`3oo_X0oo[o0?oko`3o
n_l0ooSl0?olo`3onO`0noGg0?ojo03oo_l0oO_l0?onn`3il^`0cK^g0:N?R`23JVD0]IjH08]jLP1c
JF00XIR?0?ockP3on_X0n??]06aYHP3gknd0oocm0?olo`3oo_l0o_oo0?ooo@3oo_/0oo[f0:bCSP3o
o?l0o__o0?_fnP3onoD0oogb0:NQR`1KEcX0nOWC0?Wkd`3SjK/0TYQZ0=S^[P3DkjX0`M^D0=W]Z034
eHl0QY==00/0oooo000:0?ooo`0L0=KX^036h:<0b>NQ0<?TU@35i9H0e>BU0;W2S@1BF2X0fMfj0=7I
]03LjlX0cN3<0??om@3^onh0mooc0>kmj03goo40l?o/0>Wlj@30eLH0l?og0>kok`3^on40aM^d0=7e
d@0JGCh0`>oO0??oo`80o`000?l0>bPQ054o<@3JklH0c?6m0=kfa02AWW80QHUV0>[he@3ol^d0[g]m
0?oil`3oooX0m?gh0?coo@3oo_X0oocj0?omn`3onod0oo_j0?oon03jo_00cmRi0=3L]P3;fJH0d^F^
0<cQZ03@f:L0>CX>0=7H[03GjkP0e^j`0<cLWP3>a940>BX00>GS_@3Gg[D0h>fh0<cIY03EhZ`0[kb4
0=KSZ`3EhjP0d^2S09BRI03>gYl0eNFT0<oNW@3GhZH0d^2S0=g_/@3AhJ<0cmfP07]l@`2l^H80fMJO
0=WJX01ePD<0f^BW0>;RY01CEAH0h^RX0=OPW`3Mk:T0f>NT0<kOV`3>hYd0f>VU0<WET`3Ukk00fMJQ
0:JBH02GWF40bnBR0<OXX`3<fY`0Yk9f0<kMXP3MmK/0nNk1034O003>dZ00UIUV0=;PY@3:g9h0c>NT
0<CQWP3AkZ/0b>FR0=Oa/03EjJ`0cNJU0;oYW@2[d8/0en2c0=GM^039ilD0`]o108>lT`2Ed:80^>2^
0;oV/@35iZl0en^/0;?7R03=iZ@0bnJS0<OUW`3>jjP0cNJR0<[SW`33fI40enRR05e^:01_P3X0bm^J
0<oRXP3CijP0g_2b0=;RX@3?h9`0fNZV0<kRW@3<h9/0d^NR0<gTWP2abh@0S:IO07RCC039hi`0b=nI
0=G/YP36gIL0dnfV0<7KU03=ij00b^FN0<COV03@jj@0aN>K0<[XWP38j9`0enRQ0<kETP2BQe40PWE1
07]e@`2JVVH0XK=i08RPI02<ZFT0RZQX096_K`2mgIh0dO6b0<k[/@3:iZ`0bN:[0<GNY@3AjJd0cnNY
0<oXYP3<h:40g^:`07IjB01FGBX0f^:_0<oGY03NjkD0c=VS0>?b^`3Dhj`0YKMm07R1BP2ZX6l0WieZ
0:o2RP38iZX0`^R[0;oYZP2lhZL0eNJb0<W?X@1gJD80I5T/0<SHV@3PnKL0`NJP0<K[Y@3Al:`0gN^]
0<kFVP2MYFT0Z[Yk0<kc[@30iIl0enb[0<gRX@20UE@0b]nN0<WNW@3BijH0ambK0<OMW03Bj:L0[/B3
0:>lNP3>ijD0f^JX0<_/Y`34jJ<0b]fM0<gMWP2mg9P0eo:_0<gCU`3EhJ<0d>2Q0=OOY03GgjH0en:V
0=OSY@3@gZ00_ln@096THP2L/Fh0_=6<0=GZY@3@hj<0aM6O0?_og@3?fl<0fNKB06QhGP3?h<00SZ1`
0:bmQP3IjJ/0e^BV0<_TX`37o[X0SlJ20:GJU02^hYX0dNBT08JIF@3:gId0c^>R0=3WX`3<hil0]lj8
020g003Il:X0dnfV0<_RW03IkZ/00480d]jN0=cVY`1kQ440Z[Mb0=?TWP3;iI`0c>JO0<_KVP2[]GP0
fn6S0=7PV`32eI<0i_Rl0=OX]03Agkh0nOo]0?Kol`3/mnH0g>_20=KW/`3?iYh0fOFX0=3[Z03KlkL0
`mFQ0=GVW`3>g9l0008007n5H@3DgZ40e=nM0=[WXP3FiJ@0Wje_0=7PY@3Mk;<0f^^d0??ocP3Yo<D0
f>^d0=;W[P3Bij`0bN6U07R?B@2Y_gL0RIiI09fdKP1_QT80enb[0=SZ[P3GjJd0RieS0;c=UP36eIh0
gNJk0<kE[03Mi;P0d]V_0?Ghf`3Zk=L0ookm0?omo`3Yi>X0l>[Z0?onnP3`ool20?l0000:0=_om@31
l]80o`000?l00033gKH0d>W20<SQ^@3JmL`0o_c`0?ogm@80o`0000<0oock0?ojn03oo?d00P3ooOd0
6@3oo_d0ooom0?ojm`3oo_P0oo3/0?ohm03Wc/T0ooWc0?okl`3on>l0oogd0<Ff/@3giND0oo[`0<C2
]P2f[:X0mN_Z0?oko`3gl_P0o_ko0?oon`3oo_X0ooWb0:28OP3jkoD00P3ooOl03P3oo_X0ookf0>3I
a`1JDSd0oo[M0?oog`3YjL<0TiE^0=S/[`33g9P0gOB`0<_OVP3Bhid0en:N2`3oool000X0oooo01/0
E60l03eA7P0Q>@00GW`b08NSF02=WEh0?DP>07EmBP0g@aD0JGI805Yb@P1SPe@0JX]N05akC`1RO5D0
Efm;065iE`1NMUH0HGUO05]cF`23W8H0JXMY05UoD01JNe`0B71H03QZGP1UQW/0103o0000N01LECT0
HW]2055a@01]OeL08B/807QmG@1[O5X0RVEL05X]:P2DSHD0Si2809fVX@2`]K40V9BC09bFUP2NV9X0
XYjM0:BPW@2RY9L0/;FQ0:^eTP1lQed0Z;J108RIHP2?Wfh0Q8EM02LS002/[8H0I75303Q94P0c?0D0
?R/104H]3P1VFT80JVU;02@b000U<`009S@002/i100Q;`009SD002Dd000eA0/0OhaD02Pf000J9@00
Lg]205AM900P<0006RX002Tg002BV5`0Yj]`09>DF01<DQ@0U:=R09NZJ02IZVH0@dl=0:ZcLP2FW5`0
LG`j08^GE@2GYV<0=D0006EZ:P2e[740YJ1V0::ZKP2LUel0?D<703]:2@1<Hal0G6`]02dl0@0iBa40
:ST2030T000I3000=T0<05MQ;01>FB409cL0049K6@1fUDl0KHi905Eb;`1BJbX0MX57061Z;@0c@`00
IG4_06Ii@@0V=PL0L7=D06UfFP1gRG40I85U00a@9`0[NTd0K[:106QlA`1DIS80MGm=06=W=@0b;P00
Hh1606N3AP1HLS<0Fg8^05eb;@1JKRH0KX@l02Di001JKbh0H7Hf05]a<@1/Ocd0JGXf08RIE@80K7di
0<T0QiQD08nSGP27VeH0RIeH08nSGP1aQD00QY]F08>HD`22Ue80OY=>06Yo>P2BYf80T:MQ08FLEP1i
T4X0SjIP09Z_JP2I[VT0WjM[01hO002OUV/0P7M@09RFK`2MXWT0H71306AdA@0oCah00100000C000L
=`0000h002<j30005P008c`D04IQ>00iERP0Tk>404md@01DLcX0JGPc071o?01XN3T0HgPo05I]>@1[
Q5X0=4`X076:K@1HL5P0Bf9@01lo:P00;10001@002IP>01@SF40?WY705>9C`1APDD0Ggdm06^0?`1a
McL0NXA5018`000P>000LWe5075h@P1nQDl0KGa303Q<4@1KMCP0?eLK000=0019Fb40>T`B05UX;`0[
?@<00Q@004MI7`003@00:3`1000=000?900062d000LL00002P00;Rh001Xb000?:`008Bh002Hc000J
>0006CD002df000/?P@0>ddC02/]000[;`008bX0024Z000R<000;ch502hm0P0Z>P008S8002Dc000a
?0008BL0030g0@0_=Pd01`l002D`1@0H9000:cH002D_000V;P00;34003Hn1@0mB1009S<001DS000g
B1@0HG4c06Eg>@0eA`T0:3d005id<`1RN3L0JH0l0766@`0Z?`00DFDP08:FD@1jTD/0Lghl0::WI`1T
Hb<0NWlm08ZED@1oUU00UJmX08nNF`1]LS80Z:AW09ZVI029WU/0RimP09b_M`2@X7T0C5/l08>AN02C
XXD0SIm]09R/K`2;XEH0W[9Z092OIP1:ER@09c0306ef=@1BER<02@H102l_4`0M900092`007R0A@1e
MD40OGe;07EgB01RICP0?dPK06ijC01XNTP0HGE2059[<P1NNT00FGLk0723@`1DHb80HG8^05mc;P21
UDh0>4`50765@01DI2<0IW@f061^<01]Nch0PY1K05Y[=@1TM3H0Gfl`06mkB`0S:PP0I6EO08R8R021
Oh80OWif08>1LP2OSXL0R7E_07iiIP2>T7P0103o0000100h:@80D48M030T0013@2440?l0000]09VG
R02XYYT0U96809fJT`2g/k00[:RW02PT8@0[9R80>R/X03HS7`0W4Pd0?b`V06QIDP0^9al0KfQP07]`
KP1jJVX0Ee5508V5N@070000R7ek08b0P01dJf`0PWim0861N@27QGT0V8Ym05I3=@25Ng`0MG1d07Ab
M@2KW9L0RhZ509B;PP1^H5L0Th5c0:FDQ02ESgT0Wif607N8D@1PMC@0MX]:05a/;@1KJRT0T9YK00/0
oooo000:0?ooo`0K0>oef`3]o=<0d^Ja0=3[YP3?jJ00a=BE0=WWZP3FhJT0[K^60=3S[03@k[80`nNZ
0<cb^@34ik40b^Fh0<7J/P3;h;l0_]:f0=W]e03:h<T0jOoZ0<;L_`2jhK80a>g?0;ORc`2Pb<00k_oo
00@0o`0007T0a/NU0=?][03El;/0cMba04UA:P3non40^<bW0>[8_01=91h0k^[Q0?oonP3ho_`0mo_j
0?ono`3ooOl0ooko0?ooo@3ooo/0oooc0?Gjh`3>fK40e>2b0<[IX03@hZP0aMFT0>[]`P1RGSP0d]B/
0=[X]`3Jk;80hNZa0=g:X02FOed0o?;I0?oohP002`00TJ9[0<SIXP3;fZ<0ho:k0=k]]03:fJ00WJac
0<gJXP3BgjL0gNR^0<g@V@3DgJ@0C5`N08FGF@3Di:H0e^2S0=SNX03SjJ/0T9YK0<[MV`2jdH/0amjH
0<SLU`15CPd0Ae0?0=?OW@3Um[80bmbH09NSH@1OI2@0gM>H0>CNXP3OkZd0c=:F0:R/K`18DA80f^ZY
0=7QXP32e9H0RIQO04QB7@3^iKX0?3D90<7BV`3Fhjd0Xjid0<[HV`3=iZ80c^fW0>Oo``36iJ40e>ZZ
0<_CVP3LhZH0`m2;0>3/ZP3Dl[80RjM]0=cN]`3Li/40gN350>[gf`1c[hT003P>05ZLKP2/ciT0f?K2
0<_O[P3Ii[P0EUT^05Eb?03@kK<0bNFX0>Cm^`3Om[00g?:Y0<WQU`3HkZH0c>>O09J_K@1TOC`0b]fK
0=?TX03EiZ80cMjJ0080dnBP0<P0gNbY0=3OW03@gi`0f^VV0=?RW`3;giX0f^jY0<cQW03FjZD0dnNR
0<[NV@3IkJP0dNFP0<OKUP3Hk:L0`]JA0<kOV`3IhJD0ViiW0>o/`@2^[8D0e]jg0<gI/@00300000h0
0<kJ[033dJ00`]NN0<GLY02AZ7@0^m2U0<KL]@003000=E4[0<7T^P30iKT0c_S80<[c^`3CmJ/0`N:K
0<?VXP3:l;<0^^6Z0;;I[@2oiL00dOGI04QYE0002`0000d004Z0J@2bj/l0?g]G000h401>RE/0:5dU
07RXK038jjT0fOBa0<kMV03@iJ00/mJF082EFP061P00emBQ0<;0S@3?gZD0`MVM0=[h^P2ofI`0RIIN
08nJHP3Ah:L0h>nf0=g//`3=gjD0e^R^0=__]039gJ80c^>X0<OLX@3;h:D0d>FZ09NTK03<ciX0f?2d
0=7]/03IiZh0bMBL0<o[[P3;hjL0g>6[0=KSZ`3@gjH0gN:/0=gT[P3KiZ`0enFZ0=3RYP3Fj:`0_]2D
0=3RY03Mk;40cMbQ0=CPXP3Rj:P0e=VO0=GM[03Ki;D0bmRS0=;MX`38e9@0c=JG0?Kk``27ReP0emVX
0;k1S03IgJX0g^Rf0=;P[`3EiJL0dnFW0;_=S`3@iZD0d^RW0<oUY03>iJ40`mRE03eA303PlJd0g?2[
0=OaZ03?gYT0jO2]05IE5@2NX5l0gNRT0<;MUP3;iYl0fNRU09nQHP3<aXX0fnNU0=K[Z03Cj:L0dnN/
0=?T]`3domd0n?oV0>oof`39g:@0c^>P0<gTU03AhiT0e^BY0<kHY03CfZh0cMJE0=?GY003000092L8
0::[LP3JiZP0d=ZM0<c?VP3Mg:`0c]6R0>oea`3Oj;/0c]^]0<cN[03JlK/0e?2e0;oKWP3=jjd0c^2R
0=KTY`3HjjT0gO2^0;cBRP3Ejj<0`mVA0>;f/@3EiJ@0enJU0<oKW@2kci@0enba0<kSWP3KlJT0Q9=L
07n<H@3goO40o_om0?Oin03ooo@0oOoZ0?kXf`3om>T0i][00<W4Y0@0o`0000@0HE0T05A56P2JSF40
IFHj103o0000;@3oonT0ooo]0?WgjP3oooH0m_?^0?omnP3mo?P0oook0?odlP3on_P0mN;N0?ojl`3o
nO00n_K]0?olm@33^kP0`KFe0:^WWP1dL6D0HUUB03`^:`2n/k40]:bZ0:jZY`2/[:@0[:ZN0:RLT01c
HED0]Zb[0;2/[@2o_kd0o_ok0?Skm03ooOP0oo_d05]4?03cgmH0ook_0=WFa@2<VVD0jObl0<_NWP3E
hjH0Qi9F0<oIW@0;0?ooo`002P3oool04`3oooH0locQ0>[jd`38h:80aM^J0=W/ZP2ochh0fNNY0:>f
M03<iYl0a^RK0<K]W033iil0a>:R0=G[_@3Rlll0n?o/0?col`3fo>h00P3looH01`3Vn>00f?o@08S3
Y@1n/:@0kOko0?Ooo`2NTHT00P3o00003@3Th//0c^2`0=[fXP3Fij00io2a04E;3`3HhZd0c^^c0?of
gP3VaKH0ooof0?Wim`3kn_l0103ooOl0o`3oood0oooj0?kok@3]m=D0fNFg04IC7@3Pl:l0_]>@0<gU
Y`3>ej00JV`j0=cV/@33fid0eO>[0<_OV02=QU00bKb@06IWA@1dOeD0g?J]0>_o^P34fi<0d^NR0;gB
S@3CiZ@0f^f[0<KFU`3Tl[@0dMnQ07Eo@P22PDT0`lR>0;o?T03KkZh0c^6Q06Ie=01nRTP0cMbG0<gQ
VP2edHL0cnfS0=7aYP2gcXH0hnjZ0=?NVP3Dj:40eO6W0<SXW@3Dl:H0fNfV0:n_K`2oa880`]fF0<SV
WP3IgY`0JVHW0=SHVP36fIL0_mRG0;W8S@3VjK@0`;nA02D]0037gj<0dNFX0=WUY`3>fYX0b>:K0<GU
W035jJ40cnjX0<cQX02BTET0OWm60;kKV`37k:L0b^^T0=?eZ`3>k:@0d=bL092GH@2DVfP0[jn90>Wa
bP32gK80[OBl0:od_@22`Xh0K:Qe0:kT/`34hkL0^MVW08f/L`3=jZP0bNBO0=G_Y@3:i9X0^mF<0=G`
Z@2bd8X0cNZW0:o6PP24VEH0SJ9O09>VI02faH@0f^JV0=KPX@3QjZ/0fN:S0<gCU@3Zlk@0cMVI0=;R
X@3NkZd0fnZY0<oNW@3RlK00bMRG0=3OWP3;eiL0T9aL09>RG`2DYEl0TJEP0=GUY`35ej<0h?K502];
70003`00`=f]0>3fa`1QJS/0^/:?0::`L`3MkJl0a=FN0>Sic@3Xn]80lOoX0;;A[`1iYWl0P;2608c6
UP1e/Gh0NKb709GJY01j_hP0I:Ma06BUK@0NFB<0DhUE08nnRP3EoL/0]]RV0<ON/02CSF/0VIIc09NM
M`2=VVl0//>G09F_P01<JSP0K8aJ0:g@VP3Nol/0`nB[0;kIUP39gYd0c]BH09FFG01IF1l0][j20=3L
WP3Wn[X0cN:Q0<_KW03HiZP0Lh530<OEU`3UmKH0c=bM0=W/[01BIbH0d^NV0<?IV03Jl:l0d^^Y0<oZ
Y`2idY00Y;1b0<GTX039jZD0iNnb0=[RYP3`ol<0e>2R0=oFW`3[i:d0g^:U0=O[YP3?i9l0bN>L0<_V
W`3:jZ40a>:L0<cZY03GlZd0e>fY0<SMVP3AiJ00iO2/0=gYY`1YMcT0[Ken0<cPV@3:gYH0i_Nc0<oM
W`3nomX0i>[60=KN]`2M/G@0I7a00<3U[`33k[T0dn>U06Qj?01EJBX0fNn_0<kWY@3:hj40e^n]0;oD
T@1OKbh0bmZI0<WOU`35jYX0dNbO0=[ZX@28SDX0WZMT0<kOV@3@m:X0b>jU0>[m^`3>dYD0XiaU0=o]
[`3GkZX0amjJ0=G/Z03Ll[@0j_o60=GY]P00=@3Cj;00g_F_0=7YV`36gXP0gO2O0=3OW02jb8/0S9IQ
0<gJTP3?fid000D006=bA`3=i:00bN>I0<kXW`3Fk:/0a=RK0>3e^P3/olP0mooC0<WQY@38hZ<0cNNV
0<k/Y02mfi40aN>I0<gUY`3@iJ`0e>j_0<[UXP37iId0]]B:0<OVVP3IljX0h_Nb08fNFP2FYVL0`M^L
0<o/ZP2ddGl0c>ZD0=C^Y`3<h:/0joOS0?OomP3kooX0k_KN0=WP_P2[ZH<0Wieg0<KGX`2W`8H0MYM@
0080o`0000H0bn:J0<WPVP34fYT0c^NV0<WOUP3LlJ@20?l0000>0:6]N`2OZ7d0SiEa0?ook@3akn00
ookh0?ojm`3go?P0nool0?omn`3ono/0RG]h0?ommP3onoD20?oonP080?ooo@3onOT0n_Wg0?onn`3X
g]d0BCdm00P0003mmO820?oon00D0?knmP3on_H0oNk[0?G/i`3oo_L0oOog0?Oon03kooX0oogj0?oi
n@1_DU@0onk_0?olmP3^j^40/Kf;0=OWZ03ChJ@0aM2H08^EH03_nLL;0?ooo`002P3oool0o`3oo_/0
oOo/0?Goh03Gk;<0dNNV0=3TW`3AhYh0dn>R0>Om]@3<j9d0_nF@0<W_V037ii/0bnRU0>7baP3con00
o_oc0?Cfj`3oooX0o_kf0??cj`30c;H0^=n`09OH^P1l/ZD0n?oo0?;kn01XEdl05P000:j<R`3OglD0
cnJ`0<?MPP3Mki/0W:9H05AG403?fi/0f_Zi0?omg`3P`Jl0nOWa0?clo03bk_`0ooco0?ojo`3no?l0
oogo0?onnP3nooL0kO;K0=KM_03IiKD0DUlW0<kMVP3Bj:00b^FR0??oa02<U5T0f^Z/0=Gc[@2ceXH0
goZ]09^KG@3/i[80Nh=J06=e@`3AkYh0]<n00=ghZ@3Dk:00dNVM0<gQV@39gID0bmbF0>?b[`2mbHT0
:c@00=WHX035bhl0loo40<kQX@3:gi`0U:AS0;[9QP3;g9H0g_B/0=Wh[02nh9<0`^:G0=ke[@3TlJ`0
cmbG0=S_Y`39jIh0aN^N0;SNT@33hIL0en:N092MF03RokL0a>ZM0>C[Z01JDQ<0j>:T0=W]Z03;iJ@0
iOBi0=kLZ@3Jg:d0<Ch90<7MX03GkJl0cm^M0=;NWP39hi`0cNfT0<W]X`3=jj<0e>NU0=3;T`2QWVT0
aMBM0=3MY@3LjjP0_m>;0<?PSP3Blj80a^JJ0:c6O`13BQ@0f=JV0=[P]02Yd:@0bo780<7W`00UBb@0
R;2;08^/P@2kfjX0LHmK06B1@@2kfI<0b>BI0<CPT`3BkZ<0`^2H0=?b[02ogYP0`]^G0;C;Q`2=XUl0
X;=a0;;1P02CWel0U9iO09ZPHP29SE00PHE80<G9S03BgYh0d^6P0<[IV02EXF40RIEE08^GE`2EXF40
fnNW0=GOX02Y/g@0Uj=Q0;35NP3;hYX0e^fY0<KRZ02Zbi@002D005J2C@2nhjl0Tjik08ZDHP2f_hP0
a]:B0<oNW@3@gj@0ioO80?Oog`3QoML0d_;=0;[X`@2_i;P0>WY804b>H00CDcT0@7mT035`D@0LFC00
Ij1c06RIHP2lj:/0`N2L0<;LU@2a`gT0WJmU08^SF@2L[FL0QhQ>0<2jQP2JSf80V9=]09JGM@19Hd00
BG5>08k:Y02cikT0dN:N0=;VX@3Dj:<0fNZV09:MF`1eMCL0S8Y=0<oDU03Wl[00dNbU0=?]YP2AWE/0
Tj9O0<?DT035eY80b]jI08ZOFP2J[fX0g_F_0<oVX036h9T0c^bT0=;bZ@2_`gh0b^jT0<?WW@3SkZ`0
SiEE06Yf=03PiJD0jmZR0>CCV`3Mg9`0an:E0<o[WP3;kYh0anbL0<W`X@35jY`0a^RL0;_KT000W031
giL0eo6Z0<_RVP3Ij:<0^/^70<WLVP22Ue80gO>Z0=[`Y@31eI00k?k00>7]a`3gon<0eMnm0=3RYP37
g:40Z<fG0<Ga_P3>g:40CV0T09>WJP30eYH0foBb0<[SX@37h9h0hoRe06Yj>@3VmK@0b=jF0<7[V@35
iYD0f_2U0:2ZI@2@WEP0c^BL0;WQV03<mZ`0_mBC0>K^/P1ED1P0T9iQ0=3YY`39hYh0cnVR0=C]Z`3Y
ol40d>R/0<KNX037hIL0b^JB0=C^T`3?iI00iOJ_06Ee=03Ljk00f>^L0=k_Z`001`00L8AC0<3NU03=
kYd0`nJF0<g^Y`2ifIH0aNFR0=gm_03Em;40c^^Y0<OUW`3HmZh0eo>V0<[WU`3NnjT0gONh0=[c^P2m
fid0eOBa0<;VW03@mJP0`N>F0;oMT`34fiD0OY=>0=[][@3=jZX0d_6]0<WYU03Cm9T0b^BK0<kSZP3X
m]l0mood0?Kom@3Tkm40`<^S05YH;`2CU6P0/lN<09^hMP2ih940anjM0=KgYP2ddhD0fOR/0=[h/02n
giX0foNS0<;LQ@36gHl0g_:Z0=cY/@2f`8h0IFa30>;RbP3oonl0ookh0?ohm@3lool0nooo0?onn`3o
mO@0SX>10?ojm03oooX0o?oj0?con`3oood0nOGf0?ono`3no?l0oo_o08MkO@0<0000oogj0?_jm@3e
n?40nocf0?oln`3ono/0iMcG0?omm03nooH0moog0?Won03mn?@0ooSh05i1A@3om_X0o_3]0?oon02?
VfT0ho6c0=?NXP3Ym;`0VjEa0?kof0/0oooo000:0?ooo`3o0?ogo`3Pk]L0eOK;0<SdZ@3=jIh0e=^H
0=;HVP1EHbD0b>VR0=Om/P3CljL0an:O0<Gc]@3=n<00lo[K0?kok@3loo@0mO_]0?Sol`3`oo<0lOo^
0=SLb`19ME`0DhUb0>Kon`3lo?80ooS^02hL401PCT00o_OM0?Cld`3DjK40cnFJ0=SVV`1OH2@0g]ZZ
0>?D]`3omn80oo;]06Q6A@3onO/0ooWo0>gNl@3on_l0oogk0?ommP3ono80o?CY0?ook`3mo>00oooQ
092HI`3NjK40eNFT0=[VY03ShjL0O7Lo04]43P3RhJP0b]:F0=3WX@3<iJ40S9eY0>3Za@3loNd0o?o/
0=?`[@2nfiT0a=jM0=;/Z`3Gkk40c>2S0=?UZ`3;fZ<0bMJP0=;LY`1FFRL0k>:a0>;U[P3Vkk00d^>O
03iN4`38f940fnRR0=O/Y`3EhJ<0d>:V0<cPX`3<gid0d>>Q0<kNW@2BXV40RYIH02@^003Egj80en6U
0=CRY@37eiT0UJ=V0=STYP3Lmk80bnVO0<WOUP1CEQ<0UIYG0<OFT@3Bhil0gn^]05MJ8`0X<000_mFD
0=oj]`35iYl0a^ZR0<g[Y@32fiL0cN:O0<;IU@3DkjX0anfT0<_/Y@3Hi:H0TYaP0=o]/P38ei`0cNJU
0<[WY`3=jZL0`]fJ0<SMVP3Ci:00i_:d0:JWO@39bZ80hN320?[hg`3oond0oog]0=gZd01LMeP0ao;7
07jNM@3Gdjd0jMN_0?3EZP3Se9T0g=bF0=GZW@3Ki:D0f>6R0=SSX@3Ch9X0cmjI0<oNW@3YmkT0dMVM
0>?YZ`3HfYT0fmbR0=GK[`3OeJ80k>:_0=kQ]03NfjP0inFb0<kDYP3QkLL0dm6Q0=O?WP2P[XX0Dg]I
0<SR]@2R[h400PH0030Y3@3W_940o/bK09]oD02]YWP0e=BF0>kX[03TdjL0k^:b0=cGX03UiJT0h=^T
0>WG/@3on]T0i=Fh0=cF/P3Iik80d=fX0=kJ]03Hf[80i>Fk0=_5X03We:`0lMR_0>31U@3YaiT0jmbU
0>GKWP3Ugj<0aLn@0>W[[03WeYh0k=2N0?CBY@3ld;<0omc30?oYdP3Te;X0K6a:00@8003IfkH0fMNa
0=_BZ`3QeJd0j=^_0=cBW`3YhZ`0G5/K059C4@3FfI@0i>FQ0>ORXP3OgYh0EedO0<oGV`3QiZ`0f]^R
0>SW[`2HUel0VY]R0=WQY@3@fYd0eMjM0:6KH@3<g9/0fn^Z0>WPY`2^Xf/0f^2T0=KGW@3VcYh0ooO3
0>3IX`2@Re40GUXJ0>WVW`3Kf940g]VR0=OBZ03DdJh0h>6i002L0<kBW`3GhYH0g^FH0>GHX@3]hZX0
f]JI0>OSYP3SfYl0gm2I0=c4UP3ZdJT0oo;D0?gUb`3on^<0oo7N0?oii03om=`0RGeS04Ti:P3RekL0
hmb`0>o^[P3FeiD0gMfM0>CS[@3Acih0hMj[096>F@3Gei/0hNNW0=7=T03Pdi`0g;j<09n1C`3:[W`0
aKB00:JII02m[7P0ckV70>gAXP1/Cb<0f/JD0=[=V02DRe@0m_Bi0=KDU`3PeId0kMjW0>gLYP3`hJP0
i]NL0>gNX`3/gJH0glnL0?;T]@3HcYd0j^:d00@4001^MTL0bMfP0>3i]`3;iZ40a=fK0=Wb/@3<hj/0
b=j]0=?X_`3>h[d000/0000>0033gZ/0e_6j0;cHW@3Ym/P0NX1J00<3003Rg/<0gmJe0=oF[@3/hjX0
no>e0>[OZ@3Jd9l0i]Z`0>OH[`3VeJT0jMjV0>KLX@3UgIl0hmZO0=?7U@3_hK@0onk40:^DJ`3K`YT0
c:^80>c;ZP3WaJ`0l/ni0?oefP3D[8T0ono10?G3TP3nbY/0OT8P0?JhW`3b^YT0Z79@0=6LO@3JZ8d0
fJ^D0?K7]@37VHT0[X1`07M9>@3;WX/0n/fh0;BSR@1[GdD0oo[U0?ohjP2ILV/0oo?a0?o^kP3ol>h0
oo;_0?ock`3on?<0ooSa0?ojl`3onO@0flS20?ojm03omo00oo?/0?okl`3eh]/0ooKa0?ogl`39ZIX0
ongK0?ohi@3om_40oo?d0?o_m@3onO/0Gde;0?o_kP3ok>`0ooKa0;JVPP3Zgk40jn2b0>[M/02/Wg80
g]6T2`3oool000X0oooo0?l0oncf0>c/e035f:/0a>:H0>3/Y03[gjD0/jIa05UF8@38ei`0ambK0=OQ
XP3OgJd0h?O;0>Wne`3oo>d0onoU0?okl`3oooH0nOod0=7]eP3]ond0m^oU07ZDR`3[ooD0jo?X0?oh
k`20HUX0;Pd408eaIP3ol=L0l>K20<[3U@2o^X00MFT_0>7:X03oiLD0onKK0?oak@3ok>/0dj2O0?o/
kP3oin/0oo?o0?oYlP3ok^h0ooC`0?o]jP3om_40on?K0?ojiP3onn<0SX1I0>cQ]03ak;D0e<fF0>CG
XP2HS5P0KVLc0>_[]@3JgjL0e^JW0<gOX@2AXG00cMVe0?kol`3gonT0aN6T0=?_/P3<iJ/0bN:X0<CL
XP3Tml00a]VR0<cJY`3QkK/0cm^Y0:2TLP39_8l0bLbG0<_AT`3BhI`0eOZ/0=OWWP3SkZT0_mJB0::Z
K`2FXfd0VZab08RHE`2X^gT0S9mO09^^KP3Pj:d0f]fT0:ZYL@3Cdid0b]:I0=OY[@3:fJ80i^S00;K:
V@38k:l0aN>W05MK:02DTV40f>2]0=3NZ@36eZD0gMng01@A002VY6T0d]JI0=[ZZ@3JkJ/0fN:S0>CT
Z03KeI/0j^R]0<S>T03El:/0cN:O0>GOY@3Gd9T0MFlm0<>oS`3Bd:00fMRX09fMI`2m_XD0gN:R0;:g
M@2b/7<0JdlW0:B8H`2hV7l0on?@0?oJd@2lQ8D0ooK/0>cYfP0M<AP0UZJ<06eMA02WQfh0/hY/0;bL
J`2cWf@0YJAS0:RNJ`2`YW<0^;=k0:NWJ@2OXfH0WZ5/08^=F`2WXg<0V95M0:BKI01NEb40XZ9n0:>G
K@1eJSd0RheV03Lc1P2<Rel0N7iH07b9J`1FE2d0@S/A03M5900O@RX08c<>03/m5@0k<QD0IE4i08]@
9P22@0h0PETX06AC9`1RFAP0KUhS09j6HP1fIch0DDTH05=A5P1RFb@0I4PQ06E28P1UARX0YXm]08b<
FP1;BAH0SGI<09R=G`16=@T0^Xe/07eE<P22Ec@0`8m^08UG=P1XDBD0F4XI061D8P1MFbP0KVTb08eh
@@1ZCQ`0JdHJ06e08@2hRW00X7]Q08=QA@21JD<0ETLP018?00080@00FD`/07]]BP1<?1P0^jQn09J4
EP2?Od/0I5DN0962B@2VUEd0[IMN09j;D`1CBQ<0X9UR0:RLJP2UUF@0e;n@05Y45@1YEbL0ThMC08j7
D@2TVF40PfTf09ZEF`2QWf@0UWa;07eS<P2OUF00NVhj09elD@2CODh0aK>309AiCP1hG2X0ECP00:B6
D02aT6d0^9R10<ndX`2]UGd009`0/9ij08Em?01aJ2D0`jml0:6AG@2PUeh0S8=807a]=P2MQED0WWaF
0:9nFP2OOF40Zhea09alI@3O/jH0^Hn10<j_VP1/DST06`L007IWBP1UF2h0QWho09VAD01NEQL0S89A
030S001KCB00UhUH07Ya=P1XIbh0MFhg05i>6P1lGBh0KdlP05hn3`1]ER@0IU8O06A@7@1XE240KU8S
04@O001iFR`0OfTg079R;P2^Z6`0WYEJ05a;4`2KQ500LeTX05m85P2EOdh0Q6lj09b8E@1oJcT0SgY=
07UZ@@2BQE/03P/000H<00003000^=2B0<SSX03Ikjh0bMjM00LI00002P0000P0000700002@000P/0
0:^fSP3Ul<D0eMj_0:>XO`14AB<04@X000/0001hHe00HTd`06aF901cGRD0U8=?085^@`1>?1P0KeLa
06A;8P1I@a80S7Q5065@601UEQ/0P70e05A12@1ZDal0L54S085P=@1]DB80HD@J06]7;@1^B3D0IC@S
08A@>P1j?ad0Jb`908i<;01[7a80U4E109aCC@2<B3l0Y6=M0855?@1`>C80JCL^081@AP1gBCT0MDPc
07Y><`28G3l0Y8IR07iR?@2=J4d0WFiJ09AID@2^LF`0UEEE0>2TY03ofMH0om?=0?oGcP3oi=h0k<6k
0=b`[`31V9H0aIfM0:MoO`3oe]P0fZj_0?o_k`3CXJ00WV]Z0<>6P@2]LVX0^h^10=RHV@3UWZ@0gYnW
0?WAd@1kF5@0]8N40?o3aP2dMgH0Sfi?0:N@IP1aFS00Qg1607iW>`21JC/;0?ooo`002P3oool0o`29
E480Z89N07UH:`1`EQd0Fch604/Z001_CBP0KTd^05Lj6P1VBRD0ESDD08=IB@2KOWP0AbhZ08eUKP1V
=dL0>A@U03/S<00X;2d04ahH03Ll=P13:2d0NUIR0751C@1W<S`0IBP]02d0001h@4<0O4A707Dj=P2H
FTl0S4Ti06PP2P28@380^W5[08Hl>@2GBd/0MBLS09E9>@1l=1h0NS@K095:=02NFd/0O3Ta074^=@2J
F6@0RdUC07Ld?@3LVYh0L30^09EID@2RJeL0OT`a06Tm6P1iDb`0FTXI06EN<00X:@00;c`@000:000R
;0006b@004M?5P0kAA00DVHe061hA00P>P00K8E403QA401LM3H0J7i006n3B01bQT/0AULP06Ef?`1I
J340PHYE02`T0010A@d0fmnR0=KQW@3CljL0T9eE0:ZeL03On;@0Q8mC03a94@3Ijjl0cN6J0>Ci]02n
eHl0]Lb605=R8@0e?P0051X001lU000M9`00=4X:01PX000h=c806BTL01/k9P0P>B@0:BXL034[7`0V
;1h04alA020^8@0];RP0BSX[07=4601bAaX0LU0P07ME9@2@ICP0OD`Q07M05`27DRP0UVXm06mA7`20
I380LDTH058W002kRf<0]hMQ07M58P3>W7T0SF0g08aQ=P2gUFD0]YIS0:MoCP2OGCd0/6e@0<R1J`3B
RgT0ol>h0?nNZ`3?M7d0[5mU06Y1?@2QRX809BHD06U^E`1eNEh0HUDe06YC<`2EM5D0[99g09N6J02/
WG`0XiYi09^AMP2XX8d0T8Ad0::AO@2?Nf80W8QW0;f^P`20PUX0QYYe0:2aS@2@VFh0KGeI024i6@0H
;@`08c<<01L]1`3Fjl@0gNVi0<WL[`3Xi[l0a[VF0=o:[@3RdK<0g]^`05MI:P3@fZP0fMna0>KHZ@3V
eJT0hMRa0<gDZ`2iaY/0QYU[0<3=X@3Yi;X0f<bT0:RON00`;PP0d^:n0:VgU01YI4H0dmVe0=cM^`3S
bJh0oogM0?o]b@3]ek80VX=J0:BSL`3Bej40f=RT0=3=VP3Xhj`0f<jC0<o0Q@3D`8/0kMB[0?;J]03V
d:/0dl2H0=W;VP3XhJd0h>ji0<kP[00?9`00D6Lc0<OGZ02RVWD0fl^Y0;JKP02PQ6`0V8=X08M/C`33
Ug80^IAZ0:bAHP2mYW@0YXYH09=c@P2/RUX0^iEX0:f8G03O`9@0d[J70>37T@3D]X@0^Ie[0;:FI03m
fjd0^IMY0=VjS03:ZG`0d:Un0?oJ[P3S`9P0h;JM0?[>]@3R/il0om2n0;^;P@33TXd0oncS0?o[g@00
LP3ojMH0V7MH0=BkT`2l]h00gMjU0=OOX`3IhZ<0emRN0>ORZP3NdZ00kn>c0928FP2?Reh0k>Fi0=o<
XP3TdjP0l^Zk0>?P[@3JiKd0/[n:0<kIW@3DgYT0cMB@0>[/[@2VXg00VI5R0?onc03@`h`0f=NF0<kU
X@2ac8T0fo2_0<gIV`3FhZ@0TImQ0=S][03DjZT0eNRX0=o][`3BdiT0JehZ0?7X/@3UiJT0f^2R0<OB
T03PjJP0moNi0=[EV`3FciT0k^Rd09^JHP3IgYh0f=fM0>?WZP3Lh:D0embT0>?Z]03Fhjd0jog30=7[
[02mfYP0_=^E0<WWW@2ofi40b=jP0<kOZ@3Sj/40;bl;0=kC/`3Uek@0ookC0?onc`3egjh0loO50<SD
YP3Gf[l02`D00=oC``3Nd[P0hm^Z0=WCV@3Kfil0hn>]0<[9V@3?diP0g>6O0>7RYP3`l;@0b/R?0?Ka
^P3Mf:40X9YV0<BnRP3Yhjl0cLNC0=?WTP3:ih/0d>JN0=3RYP37d:40oooJ0=gK]@3ck]00ooST0?od
nP3okOh0ooKo0?oio`3onOP0ookf0?Khh`3monH0o_oT0>ojc`80o`0002P0cmbT0>GDWP3ffjH0j/>H
0?oL^02]MEX0_H=[0?oTc`3X[i/0ml>]0=R/T@3BZY00ij>T0?nb_03oe>00j9bY0<QkR`3BQIL0olWK
0?o>gP3eY;<0lIfZ0?o0c@3UPi`0omK]0?Z`_@3ocLX0n:RO0?nhYP3o_jL0JAX908T_9P3cS900olW>
08]R@P2aUVT0^Ia`0:66F@25JS/0b:im2`3oool000X0oooo0?l0_;^50:2JH02@R4X0TXi>051B4`2Q
ZgT0X:Un0<K<Z02UY8D0UYIb0=cX`P2<[i40EhMa0:GD`P1]S8H000<706][M@1SK7<000P70392@@00
0P80ZiRN0?cRj`3om_X0oo3`03TM6@0G0000ooC]0?KUgP3on>l0ooOX0;bAP03ol^<0onKW0?odo`3o
jo<0ooKh0?o`j@3oo>40ooCC0=o=Y`3Zf;@0ooSO0?o_f@3om^H0oo[[0=o?`03oo>X0ooCP0?ooh@3o
omd0iN:e0=GEX`3Gg:80bM6E0=;GX@3AcZ40F5<]01H?00071`00a]RX0=ce_03=jZP0a]nM08fHGP2h
`hT0an2N0>Cj^@3?iJ@0e^b/0<CJVP31eiT0goFg08VMHP3AiJX0enV_0<oJXP1mNTL0OhM>0=SIW@3I
hYl0b^VM092ME`1fPC`0`mjI0<??T@1dPDT0c]fR0<cPV035g9@0dNfS0<OQV03IkJP0e>2N0>gf]`2N
YfP0VjMW0<;HU`3FjZd0DEP_0<[R/P2gg:H0`=jX0=WO/@1@Cb<0g>Rj0<KHZ03Hk[l0cmN^0=kQ]03R
hZ@0hNJV0>;]Z`3Hhj40emVJ0=gIW02OUEX0fM2E0>SVZ@3Eh9h0f>NT0>Wd/P3TjZ`0g]fT0=gJX`1H
DAd0h=VU0<S7S`3NhZL0d=nN0<_LV03Qjj`0Th5A08ekB`3[f:d0oo[@0:2:H`2:G4d0RUa?0:R0M03e
iMH0gnKD05nEM@1d]Y00^OoF096oV01FLDh0/KRI0<;K]02F^i00Miib07^WP`1[UWP0MZ2<02I=>P23
YH`0IXES06V5G01GKc/0LXIC07FHM`2F^9D0U:=h0<?N_@3GnMh0ZLNU0>?fb037il00cNg40<kU[@2c
fZ/0bnG:0=;Mc03omnh0d<Jl06R1KP1USGD0OJj>06VCK`2abZ`0eNK60=ST_00]@QT0AF4i0;cL]`2g
dJX0b=>X0=kT]P20PeP0?TTQ0=Sbe@13G3l0Qi1U0=___P3?g:h0lnJl0=??W`3RhJT0iN2X0:ZTIP2o
d8X0jofc0=7JU`3`j[P0i^6Z06IP8P2CSDl0SXE:0::HI@2NTfD0nNk10?O/_P3/hj`0eMnP0;OjZ`2W
hiT0`oBb07JTI029^Gd0TLB<07>ULP2ih[P0a>;00=cVc@32`ZP0/JEk0>?O/03;diX0e>2R0=CMW01>
Da<0i^JX0=KAU`3Vi:/0WIeW0=_PYP3LiJ@0c=RF0;FiO03Oh:@0g>:T0=SNXP2WYVd0f=NN0=SKXP3Z
jk80eM>P0=WD]03Rfl40ooCT0?oll@3Fb;d0YiV<0?olj03oonP00740f=:j0>GQaP3De;80dmRP0>C]
]03FiZP0f>RY0=OQY03Fg:00gmjV0>3PZP3JhJ/0_/RC08bEGP3TgjL0h=jU0=gQY03CfI/0^nbZ07^Z
HP27]FX0boBV0<GYW`38ij<0Pi]Q0=[]]P30cY40hNf[0=gbY`32hYT0doB_0=7^Z`1dSD/0V[Eb07fJ
E`33ij40_^:L0<[UXP3BijH0g^JZ05=A603Kgj@0d]jN0<[MV`3Cj:<0cn>N0=;MV`3=diD0h^F/0<_@
V03BgJ40d>6K0<cMUP3@hI/0fnbX0=GUYP3@h:40d>BU0;;8R037i:80anJR0=Wi/03HlZP0d>RN0<OL
V`2M/G@0//2=0=OS/`3Tk;/0dMRU0<76S03cnK/0hNNW0=?SY@3Gj;80aLn]0043003bkm`0oooV0=CD
XP3NhZL0g>NU0=STY03Nk;40f^jV0=caY03=fIL0eMnR0=_NZ@3:bIT0VYU[0=OIZ03FfZP0f>6/0=gX
/03?liT0]>1o0<S_X037jjD0lOoD0=[e`03=h[L0g>g;0?Sok`3kool0n_ko0?coo`3loo/0nOoa0=[X
cP3=iKD0cnbb0<[ZY`040?l0000W0<3RSP3ClZ80g?2X0=7PW@3Ae9/0KFdg0>SX/P3Cej@0m?_70<SJ
X03BiJd0m^KF0?oak@3ok>/0k=;A0?ohn02nYJP0onS[0?odmP3om_H0ooGc0?o`k`3od]l0on_f0?of
l@3oon40oo?90?SQZ`3RciD0Dc4108IH=03od/00ooGR09J9G@3PfJ<0gM>N09bEG`2LUEh0in6W00/0
oooo000:0?ooo`0?0;geU03<hXl0jO6X08^FFP39j[<0^??708:nV02E`jL0Eg1M06QmJP2Z_:`0jO;]
0?omo`3io?l0iOCk0080oo[o05h0koco06nTW02A];00jOoo0=k^k@3nool0ookh0?oklP061`00DUQ:
0?;om`3eooX0mood0?ool@3^im@0QG9Q09Z2OP3ol>`0oocd0?ooj03lon40cn>V0<oTX@3HiZP0cmZR
0=3BZ`3CeJh0`lnO0<ODWP3BgjT0h>^a0=?NXP3JjJH0ho>/0;C9NP3:hi00eo>L0<SQS@3Dg:40e=b[
0<?9X`0B6PD00PT00?Kni`3konH0jO[60=g_]@39gih0b^6M09Z`J03;giX0d>FP0=7VX@31eY<0enjZ
0<SNW@27WE`0aM^J0=O][@3Fj:X0`l^@0:jlO`0i>@00a/^90<CKT`3CgYT0eN2K0<_ZY032d980`<^?
07:2@`3BjYh0d>bO0<KYV@3:k9l0`=Z@0=O[X`3Kk:H0f^VT0::fK`3;iYl0b^:H07n=@030h8/0coZQ
0<;VS`3Mj9T0F5`@0<OMR`2ofhL0f_ZU0<cQTP3KkJ40c>JO0P3Ajj@0o`3?iZ00dN:N0<kJV021S4X0
WJUW0=;QWP34fI@0b^BM0<[ZX@38hi`0dN2M0;BmOP3Gf9`0d=BG0<G?T034e9<0^mRE0<__Z@30gi`0
dmfX0=KPZ`3FhJT0joJn0=3KX@3?k[80hnJg0>WM]`2bV840X8mk0>coj`2J`JH0Tl6U07ZEPP1iQ7H0
6Q@406f6G`2hgk00R;>60=coi`3Ooo@0Nj>J0=3ek@3Dln40jOoX0=3/``3=iZ`0e>j]0;CR/`3<nLh0
doO;00hj6@2Mb:X0SK:906N0AP1kXV/0a^nc0:_4P01nTUd000X008>KSP3^m^L0mOoc03j2L`2Un^L0
`_oS0;_Y^`3?k<d0_mfi0<7R[@005P00:U`i08:hX02DaZT0b>bl0<;QZ00kFR400100000D0@10KET0
d>Rf0=Oh`@0oFR<0inR_0<gIV@3<hiD0cN>A0=OYT`3<ki40^mIi0>GdX`3OfJD0THmF0>K]Z@3DgiX0
bmRB0<GEUP3`ol80PHaB069Z;P2`/fh0f^BK0<KUU`3@mJL0^o2R0<go^`2jn[00]Obj0:_c]01`]Gl0
IjUi05ZGKP1YUVl0K7=:05eZ?P33g:80d>n/0<_WW@22VU00cN6I0<SET03`o;`0S9aN09^^KP35giH0
`^RM06en>P2;UeD0c^fW0=ck]@2^^7/0j_Rj0;oPV`3AiZD0cmjU0?SoiP3hoo40lO[i0?Wno`3looX0
o?o_0=OQ_03Vl</0b=6b0>W_h`3lonl0nooA0<_OY03CkJh0`mfL0<CIV03?gih0j?Nf0?[ob`3JmK80
e_Fa0;_IT@2@WU40U:9G0=KXW03PmJP0/nVE0;3QT02okZ00Mj1N09FiO023XF/0cNNg08RPKP3Cj:d0
enf/0=C/XP2ldhd0c>6N08ZMF`3Zok`0a]nK0=Cb[036ij00b^VS0=GUY03=eYL0UiMK04iD5P3Ml:h0
dNZV0<OWWP30hYP0`n>J0>?h]`36eYP0SiiW0>?d_P3eom40eOFZ0=CgY@35iYD0c>fN0=?_Y03:iY/0
aMnF0<kXX@3Bk:D0cnRT0<gTW03?i9L0P9=40;_AR03@iYh0d>VU0=C_[03:jj@0dOF[0<ccY031jiL0
a?2I0<OZUP35i9P0enZl0008003do^D0dmjn0<_MX`34fI@0aNFB0<KXU03;kYh0d_VX0<7XV@31fi`0
n?oF0?ooh`3gn]d0[[2H0??ig@3fon40jooF0<;N[P3`om@0a>>W0<KUZP34hjP0e?6g0<?QY@2ogJ40
bnR^0<_V/@32fk40b^:n0>;[jP3iool0moof0?Gok@3@jkH0`>2O0<_/Y@060?l0000U0=KcW`3@jIP0
l?nh041@1`3MkJH0b=VC0=G[X`39iil0b^ZQ0>7Vc`3oooP0lO3[0;Vj]@3oood0k^k/0?gmo@3oo_d0
ookk0?onn03ooOP0VHR00?ook03Dl<X0d?Zk0<CXXP3;eh/0bM23071J7P2]S5T0d;B?0?oofP2cahP0
d>NQ0=[aZ`3Il:X0TZaU0=3/XP0;0?ooo`002P3oool0o`2ekhT0e^VG0=7DS`3OikH0_]fa0<;og@15
Q6L001400?7oo`3aooT0mOoj0?ono`3om_l0oo[o0?Woo`3omol0oo;o0?Kno`15NW80cno/0>koo`3b
ool0loWg0?Odk@2^ZYl010000;Rh[P3ioo/0m_oj0?Oon@3loo@0nocZ08IkI@1D@C80HU4o08n8KP38
djT0eNNc0=3[YP36hYP0b=fJ0=WX/@3lomd0m?[D0=g/]@3Fj:X0enZZ04aM6@3@hI/0c=jB0<oRT`3C
jiD0do2F0;_JO@3Ili`0f>6R0=SU/03Mk<D000H00009003nooH0nocZ0?gog@3Gi;H0b>BW0=3]Z`17
Fa@0LHDn0=W_Y`3;h9/0d>FP0=3WX@36gIT0P9MC08ZSG`3:hj40cN:Q0>;`/P3=h:00CT`?08f=C`3W
nk@0gNNR0=7NV@3<kZ@0cmnN0<KAU@1BHR40bnJG0=GaY03;l:00`NJF0=KbY`39hIL0cn>K0<WJU03=
hIX0d>jT0<oYW`21Sd80fo^V0;oZT@3=lIX0en:D09^OD`2H[U`0bNJB0<KXTP37h8l0c>>E0<CTV`3;
jj80bNBM0<[TW@3>hih0dNFP05a]:@3;giX0dNFP0<?JU03Im:d0cNnU0<OUW@2O[V/0SiQG0=[LV`3Y
jj`0b=:C0=k^[@39iZ@0bNbX0<o_[P39fjL0f^bh0<kQZ@3@i:T0dNNW0;GZW03>ijH0d]NQ0>;>[@2h
Y8T0hNG<0?Sok`3YonP0bm?40>STf`1TF4P0d^>g0;3AVP34jKH0bo7<0>Wol`1INF`0do7U0=C]e`3:
gkh0c^Be0<cRX@3>j:40d__10;_W]00NBb00BGQF0<7[a@2oiKH0_]bL000D00004`00QZIM0<OPY`1G
OFP0g?ob0?Ool`3[n^<04Tm0031jJ`0^Jd40U;f50;_U]@1lZ7L0_^N[05>4E`2Zh[l0@h5Z01=><P2f
iK40a>fa0<;Z[P2likT001<404EhJ@3?j<00d?740?;og@3GeZH0e^>[0=KaZP32g980b^2>0<S_UP3P
nZ<0b]J:0=cIY01_L3H0e^>M0=?UV`3>i9/0dnbX0<SQW`3CiJL0dN2O05IP5`3Siid0gmbG0=_RW036
j9h0^>BI0;[/X`2dj:H0^nna0<?h`02`ik00N;B001Q65`1^L4/0CeL^0=S_]`3;iJH0dN^T0=kbZ`15
E@h0e=fJ0=;KVP3@fYd0FV@W0=[^Y`3?lJL0X:UX05iT903:iJ00_MRC0=kRY`2>UUX0anBQ0=7QXP3o
om40mooS0?Onk03dn?/0o_oo0?_nl`3non/0b]6W0=ON]000LP1PIT@0ooof0?ool@3;gJ<0e>V^0<WS
Y03<iZD0eNZY0=g][03Ql:l0dNFP0=[h/02hg980cNfR0=GXV@3JkIh0V:eP0<ONT038lYh0c_BW0<O[
Y@3=j[80cnVi0<CK[`2FZh80dNNi000D0032g9d0bN>L0=c_[@3nolX0Ce/K0=;QX03?hZ00d^VU0<k/
YP37h9`0g>FV0=[JWP1KEA/0De`M0<_RWP33gYT0d_BZ0;cNU03Em:h0d^JW0=CSZ03DhZd0b=VU0?Co
e03Tok`0_N:B0=SkZ`2ffHL0anJF0<_WVP3DkZ@0`m^A0;oES@3AiZ40BelH05AY7036fh`0b=jC0<cR
V@3;hYX0bnFL0<?OU@33gi@0bnZL0<OXU`3;kIT0d_FK0<?US`35gZL000h00=;O`@3Gil80c^BV0<kZ
W`3EnJ40`NV@0<SbW02ii9D0cOF/0<cU[P3homl0lO?M0?ook`3Dd/D0oooc0?_ok`3VnmX0bNFm0?Co
h`39g[D0cN>d0<kU/@2idiH0dnf/0;kIU03FlJX0cNRS0=Kc/@36h:40i>_S0?coo`3[m^H0n?oZ0<KM
Y`3GlK80bNNQ0<[ZWPH0o`0000d0fo6O0<gKT01JIQ`0dMfE0<kNU`3?h9X0bnFL0=3ZX`3Tk=@0oooh
0?oon`3Ff=D0o?om0080o?oo01D0no_k0?ooo@3oo?P0oogj0<_4ZP3Pj;l0^^6X0;_aYP31l:80enNN
0=oYX01OBA00MEDT0<N`Q03oom@0UjiZ0<OQV037gYH0a^2G082LDP31gI<02`3oool000X0oooo05X0
b>RC0:bZK@1IBah0eLne0=SZdP0fHdh0fOod0=onmP3joOl0oogo0?coo`3bool0m?oo0?7oo`3]ool0
ooko0?oko`3iool0@VaR092TXP3cnod0o_oo0?coo@3oo_P02P0005@k=`3oinH0ooCh0?oko`3oood0
m_O_0?kom03Bd[P0elfZ07MbBP041@0093H4069k@P1TQdL0^mfP0?3og@3eonP0mOcd0?Wom03eoml0
b^>Z0=7Y[`2ne9H0i_Zk06Yo?030ei40^]J<0=3/X@33hiL0e?>U0=S`Y03BiZT0k_gB01@I4P0B4AH0
ooko0?Gem@3dnnT0nOoZ0=odb`3Qn<@0e>ZQ0<3DS02L/VT0_M>:0=[`Z03Aj:00f>nW0=;YX`38giT0
UZeY0<gVXP3:hil0d>VU05I@502UWf<0fNRS09FNF`1[N3<0co>Y0<gPWP3@g9`0eNJR0;C?P033hY82
0<C[V03o0<SYVP3=jIh0dNVO09BXH024VU80d>jT0<kXX@2?Ved0d>fZ0<kc[P38ij@0j^fd0?7`^01]
OCl0U:m/0<7RW@3Im;40d>jX0;OXU`3?nZ/0`NJI0<_[X03=kJ80YLMk0;KKSP39kZ40a>JJ0<;RU`3<
k:<0fOZe0:G4P03QmK00amJA0=[TW`3CgIP0_/f:0=W/[03?j:h0gO[00=klaP3Tom<0l?oM0>7ob`34
j:/0bo:_0;caU@31kIP0a>^J0=C_[03Qm[/0i?C50=;O]03Dg;L0mo[O0?gmh`3oon40dNNV0<[/W`3=
ljX0`>R/0<G]^@2ni;l0V;bH0<7Q/P3El[X0d^fZ0<_TT`2`b7X0HgT^0:c<R`00>180/>6d0<c_]@2f
f9/0aNVS0<cTT03NmYh0__:Z0;gi``0kRG40LKRV0=WfhP3Ji]80`]?=03iEC@1KNe80Pje[02j6>P20
eX/0a?Vc07V[MP12Ne80IJJ607:bS@1ERe40`_>b0;cZ[02kkkh0]?;K0:3Da`2__k@0f>oO0?Sol`2m
/Yh0TiQh0;cFYP2D[g`0fN^g0<_X[P3Dg:T0fMNV05YP9031bh`0_M>80=3]W@3Blj@0^MfC0<CXXP38
iJ80b^BM0=3UV03Bf8h0`:I]0;RRJ01cJbd0k>^[0=;GU@3Hi:80g^fZ0<_JU`3KjZL0]LB109FOH`1J
F380<SL>06UmB02M]Wd0_=:D0<kQX@36dY80cmBD0=_MWP3Kh:00Vj1N0=7JU`3YokL0VYYJ06UX:03@
i9l0c=nM0=gMX@2//7<0Y[]j0>3Z[@3oolh0oooS0>_ZeP3_knL0ooof0?ooj03`mLd0e=VS0=_PZP3P
hKD0jnK@0=CD^02P/W@0Zkn00?7oa`3QmkL0dn>T0=;LW@3/mkD0f>FP0=?^X@3=kYl0bnbM0=3VV`38
gYD0eNVQ0;S<Q03Hl:80f>f/0<3CV`3Zn]D0l_oP0<cM_@2meZl0^mRZ08RaN@0jIb`0coRf0<gVY03K
jZL0^LF30=OVX`2kchX0cnJP0<?NU`3HlZ/0LG`j069T9@3oolX0m_k20<oUY038hj00b>NS0<WVY03A
jJ/0moo?0;JnS@3Tk<<0o?oO0=KY_03>ijd0b>JP0=?aZ@38i9T0h_f^0<7JR@3cokT0a]R<0;O4OP3<
eiD0d=bJ0>?i/02gdXD0f_2U0<gRU`26Tdd0E5dJ075a<@1QH200PgXo0<6gO03Tf9h0dnZB0;[KPP3H
lKL000/00<OG/P3Um/X0aMjL0=WeZ03LojX0_NR>0<3/T`3Hmkh0i_oE0>3]d`3noo40oocm0=kAf03o
n_l0k>KZ000E0?ooo@3iooH0jOOV0>[fgP3don40b=RY0;W:T`3Ejj<0dNVK0=OcW`3@k9P0do6K0<c]
TP35iX/0gNZn0>;/bP3Xn<T0iOS00=3ZX@39i9L0c>VI0080o`0000<0cNJU0?l0003o00000P3o0000
8032fXh0/lQm0;c@R03BiYh0d^VQ0<_UWP3:ij@0bNRT0?3li03hooL0nOok0<G>b`3iool0n?oo0?Wo
o`3kool0o?om0>KWhP2WYZ40gNNZ0<cXU02omId0cOnh0;KYW03?hjP0hnjf05e?803WdJ80[Z=]0<gM
WP2CY5h0bMJ@0P3EhY`00`3@gIL0_<V30?ooo`0:0?ooo`002P3oool0o`3;hIT0KG0k09VFK@3GglP0
YKjX06VFO`3RooX0jOok0>cgl`3lool0n_go0?Soo`3good0m?om0?;oo`3oo_l0oogo0>7]k@1EPgP0
[Lc60=[^k03^n_P0j?O`0<G8_`0400007P/50<B_[03`hN@0l^c^0>[_j`3iooP0loo_071fFP1dIdL0
:Q/002lV1`1KHCl0Ef<m000;001QLd/0Wj^C0<oEb@3oo?l0Shf@07R0J01VLTX0K7M=0>3Y_02g_i00
Yjml09^SL03Ok;H0b]NR0=GV/034gI`0[=610>coaP3lomd0200002PK903in?h0n?oo0?7ok`3fon/0
n_oR0?Sof039hIL0eN^R065i;`35gI<0c^FM0=;YX@3@iil0d>FP0=CYY02BYf@0bN:N0;gMU03@jj@0
FeDI09nFF`3JiJ40XjYW08fJE@36k:40aMZE0>Kb/02__WT0_mN90<[YV@35k9/0`^bJ0<[/W`3;ii`0
d>RN08^OF01gSDD0dNfS0<oVWP1VLbh0c>RN0<W]X`3:j:00emRL0<_9SP2<WET0SjYS0<7SV@3CkjD0
`MnE0<3VV@37ii`0d^RP0=CXX@2^a7`0U:iU0=Sf[03>k:80a>2F0=7WW`3Bij80]lV=0;_;S@3KiZ@0
gNBQ0=oRW@3>dHh0g>2S0=GJX03`n/P0o?oH0?Oof03gon40k_oD0?Gof03Ck;<0_]^K0=GWU@3?jiL0
aNRF0<7]WP3=nJh0dO6b0<KOYP3@h:l0m_kE0>cdc@3Lk;/0cNBL0<WYUP38jiT0b>fW0<S_/037kK`0
UKV90<cZ]03<jZX0bNFK09B]F@2R]fX0^/]m0<SUXP0?CBH0h?oQ0<[ZZ@31hIh0b^nY0<KMQ@3<hhT0
__:d0;G^``0aNVH0HZfI0:SPa`2YeK`0/=K708N/V`0SB1d0J95G04F>B@2KhI/0`>VU0<K_]`2IbiX0
Pl2F08K4U@1j[W00_^b[0;WUZ03>ol/0[>W:0=[om`3^oNX0k?kX0>C^e@3Ve[`0Z:Z309ZeOP26XVP0
dnB]0<kZ[`3IfJL0al6?09bVI`3Mk:T0a=b>0=7^WP36iiP0b^jV0<O[Y@3=k:T0c>NR0<oWV`3KlZ@0
cMbG0<oHU@1>C@d0g]fM0=GHU@3>hiP0cNFI0=O_X@3AhIH0IV<L05]L6P0oER80S:Qe01a83@0TE1H0
a_Bd0<Wa/P3BmK<0e^n[0<oVX03IlJL0PIU=0=;/XP2ifhh0XkUa061f;P3;kJ40`nFK0<GLV03BjjL0
Z<j50<o^Z03[olP0mOoV0>3ce@3Hk=40kooW0>oog03Nnl<0bNJT0=C^[`00L03EkK<0looM0>Wlc`24
UeL0S:5P0?GobP3Yo[d0cm^M0>3YZP3?eID0b]>@0=O_X`31h980a>FF0<gUV`3Djj<0fnnX0<;FS`3=
j9/0`MZI0=O^^03bon40fo7=0<_S_`2adZD0c_K20;_a/`1QW5`0]nj[0<GZY03@jZ<0dNRR0=K]Y`3=
ij00f?J^0=;dZP38j9l0FFdX07B0?P3nolH0m_o30<cPX@3=iZD0cnbZ0<_SY@3?hjP0i>bm0:^`Q`3N
h[l0o?oQ0=3N^P31eJ@0iO^m0<cRX@37gYP0`MV;0=?ZVP2ndh@0/L5f0=SSWP3EgYd0en6R0<gQW03G
kZH0dnVQ08NKE02Z^G@0U:=P09ZTI@2JXf@0]kZ10=cOZ03Wik40f_6Q0<3MR`3GjkH000T00:FcT02k
bZ40d^RX0<SRV02lghd0a^fJ0<C]WP3`omd0n?o/0?Okk@3oooX0m^_a0=?3c@3olod0oo_o0?cfnP3^
knT0o?oh0?Soj02ibj40j_o20<OQVP3ElZ00a>B?0<KYU@2ohY00bNnL0<[bW034k9@0b^FP0<gVY@3?
jj40cNbN0<KZT032jH`40?l0000X0<WYX03o0000o`000<cSV`3>iY`0Uj]S0=?WX03CjJ40dNRR0<gV
XP38iJ<0bnZW0?ook`3hlnl0o?Se0=[Fe`3jn?T0o?[m0?WgnP3ooOl0oocm0?ojn@2k/:h0fM^L0<kP
S033ji<0_^NK0<[WY@3Kgjd0L6m10;>MM03/cjD0XheK0<[?S`2aaGd0SZ=H09:VGP3BiYh0fnnW0;W=
QP/0oooo000:0?ooo`3o0;BgOP1_L4H0g^:o0:bnYP1VPV/0iOob0>Ool`3UonT0n?oh0?_onP3oool0
o_om0?Son`3eoo/0n?om0?ono`3[ko00l_oo07naY@1PSX@0fOkg0?;oo`3good0S8f500H0002QT8T0
SWah02PN7`0^:R/00`P406E]HP0P:AP0LgIK08aoG@1WF3T0a[fN0=WJ^`3;d;00j?O@08nNM`1WL5D0
B4`k04E3A01UI600Q8Uc07ElF`1eO5X0LgMB08F7H03@djP0a<ZN08J=H@3?f:d0f^Fj0;[=UP1MPS80
gONh0=o/`@0;0P0020020;Rc]`3Xj^D0n?o]0<oN_`3Yllh0jOO60<KPUP3Rn[00cNFK07^CB@1YP3P0
bn:J0=3WW`3;h9/0e^^V08RKF@39hYh0`nNM0=;`Z01UG240Y9YO0=oXY@2MY640b]VD0<SaY@3Bij80
f^JT05a[9P3<i9H0d>fM0<G/V`34kY`0b>fO0<[VV`3EkJ<0TZIO0:BhL@3:iY`0cNBL04mJ5P38hY/0
`nBM0<WTW`3BdIP0mo2i04mN7@2W`7`0fOV`0;gIS`3FlZP0d?:V0<;NU03BhI`0dn2K06]j=@2[`GT0
d_2V0<OUV`3:iY`0d^JO0=7PW@3BgJD0XZ]b0>K_[P3Pij@0hnVS0=gRW`2QYFP0iNRa0=_N/`3oom`0
ko?>0=WU_@3ao]<0g^nk0<[MY@3AjZT0g=jC0=CYVP3:jiX0]^bH0;O^V`33kZH0`^FQ0<KPX`3BiJh0
dNF`0<[TY`3CkZ40c^nH0<KXTP36k9l0_>JN0;CKXP2niJh0cO6d0;[MV@38jYh0a>2<0=OWW03MjZ80
anBT000^1`2ZgZd0`^JP0<SYXP37kJ@0eNfI0=K_W02ai:/0]>Nl000O002Ge;<0W]B`09?1W01EN5L0
OYii0<OU/`3@m;L0/n^T0;SZX`37hJ00_=^P0=?la02/hj`0]nje0<Wg]`36l;00b?2d0;k]]`1>Rf40
d?oN0?WoiP3Ql/h0b]:]0?;P^03Adj40f?Fc0;kKV03AiZD0an:O09VFG`1KE1h0bMVH0<gQVP3Ak9d0
d^nM0;kOSP39jZ<0`N6N0<cZZP3AkZ/0an6G0<GQUP3BlZT0dnfV09ZUH@2MY640h>NS0=GRVP3LkZ80
HFlP04eH2P2UXEL0]KI`0=Of^P35jk00[>:T076[KP2BbXd0^>Z]0:C@T`30h9d0b>RO0<[[VP25Y5@0
d>nS0<SZW@2]bh40GG/a0<GZW@35jIl0^MZC0=;c[02?]fh0`NNN0=Kf]`3_onL0i_oM0<CP^03;jk`0
b>^a0<CXZ031iZ40_N:O001`0<g`/03:jK00g_[00<oSWP38gIX0SjET07jCDP2FX6<0i>Z/0=[OW`3X
kj`0e>ZO0<GRTP3Al:80a^:H0<oYXP3Cj:<0goB_0:FkL02Y_H00c=fY0?Ooh@3gon<0m?oP0<kZ]`35
j;00PK5c09cCTP1PUeH0ao:[0=7aZ034hYX0`]bE0=?]YP2mfi<0bnfS0<?UV`22W5D0_=2;0=gYZ@3K
jJ`0cN6T0=og^@3SoKh0cNF[0<_NY`3<dJP0e=Ja0?3ce03ioN80gN[<0>Whc`33e:00c>2U0=__/03F
k:40c^FE09Z_H02mcH80e^6L0=;KVP3Fh:<0c]bN0=OZZ02FZfP0_]:=0<WNV`37g9T0d^RX0=3VZ03J
kkL0dnNb0<OKZ037h9`0a]nK0<gN/@002000/KZM09>MNP3>gJ@0g?6^0;oJT`3ClZ`0d_:a0?Wok03k
o_<0oooj0?G_k`3Yg>D0lNC]0?ojo`3onol0oOCg0?onn`3oooX0looQ0>[od@2`bhP0cNbN0;cNQ`3>
lYX0coBT0<?YW03=mZX0a_6Q0;gXUP36j9/0anNK0<OZV036k9L0a>nE0<?`U@@0o`0002P0aN^P0<CR
W03Im:l0`M^D0>;l/`2>YEd0e>^S0=C[Y@3>jJ@0bnVS0<GUXP3:jZT0ooo_0?kdlP3ooO/0h]WJ0>SR
i03on_h0ooco0?oen@3om?H0oo_k0;VYZ@3JfJ40e>:G0=Sh[033gY/0h_2e07QdA@1HEBP0m>>g0>kF
ZP2RReL0l?2b0=?[X@2M^F`0SJUN0;kJS`33gi@0d^bS2`3oool000X0oooo00h0VG9E0?ooh`3RlM@0
BVe?08RWQ`3=i;P0c^6c0=[a_@3?h;H0io3A0?ohk`3onoX0mook0?Goo@80ooko0?l0lOoo0>koo`2E
b<408fEK00E2>P3eool0ooKj030H601A?3L0oocc0?omm03ooo/0m_Se0?oonP3ooOH0oo_a095lI`1P
Fc/0o_oQ0?ooi@3_mMT0n?oP0=CT/`3LkkL0c>6P0=CYZ03Dj:/0c^6Y0=W]^P33ejH0f^bh0<gLY@3I
j;40Q99G05YY;P1XND80TJ9[0<GHX@2dbHh0dNRR0:g6S03Aj;X000L00002003hj]l0oocZ09V@J@3F
fZP0YlB20=[k]02lf8d0dnnU0<cVW@3;iI`0jonl0=GZY@3:giX0cn:P0=CTX`2BXV40e^fY0<?^W`2k
gI40OgDj09j?EP3DeYL0fn2P0=g/Z@32k:00`]VA09JSGP3IiZ00enbQ0<kXWP35jY`0a^nP0<GWV`3>
jZ00d>NO08JGD`3Oljh0b=nK0=c_[@2b^7`0d>JU0<cYZ@3DjJh0Yj1b06AG:`3Ki:d0fNna0<;QWP3P
nkP0_=NB0;oQU038hYP0a<n:04iH4`37f940eNnU0;cSU039l:40cNnR0=;ZX03Ej:H0FfDc0=SU[`3O
m;<0fo:Z0=3ZX03CjZ80[Kn10<[GX@3emm80n_WJ09^JN`2RZWT0SIMS08JDF@2GZVX0e^^V0=GUY039
i9d0`nRK0<3aX031l:00^n6D0<c^XP3?kJ<0a^JK0<kcYP38kZ40eO6W0=?_XP38jIP0b_>T0<;^X@3G
ol@0a_Bf07bXJ`2]eiL0_^NQ08ZXGP3Bg9L0a]ZU0<7U]@13OU0065HU0<;e/P36l:H0d?:V0;[QWP36
l[L0`_Bo0;WSY02mcH80d]Z=0:njMP2`_gh0hNZK0<SAOP3XoK00_]RA0=gUVP3Lg9@0UHaA0=cUY03D
jZ80boBU0<ObX`3`old0d^ja0<?PZ038jk<0Gi=E0;?SY@3<gZ00cnBS0=KOWP1bHb80g>2D0<_^U03>
lYP0d^^H0<_XV02TW5d0Fe<E0<7LU@3@k:40a^6@0<WTT`3BkIh0c^NU0>coaP3Qn/00bN>T0<WWX@39
iil0c>JO0=3^YP37iI/0BfDL096RG03Qg9`0[:5S0=cDU@3cm;80_]B90<?OU02edh/0co:^0;?UZP31
m/005dHJ0;_T^02nh[80fO>f0<kUW`39hHd0[/Ib0>?c[03VkJT0dNNN0<CNU03@gIP0e^:P0=?aZ@33
hIT0Wji]0=3WX`3=i:`0o_oa0>[ceP3=h:P0e>f[0<o]Y`3AkZ`0joo>0?;od`37hjH0eo:]0<[VW033
gi@0b^VM0<SSW03=i:00g>RZ0>;XZP1kOCh0Ff8O0=GZW`2nfHX0e_NX0;cRU@3>l:H00640gO^a0<cX
W@3DhYL0Xj]_0=oS/02UXgX0FUL/05UH:01bN3X0RIA@0<WNV`3Cjjd0d>nd0<?[Y036iY/0e_2W0:Vf
L@3DhI`0g^^V0<cPV@3PmZh0SZAL0=CXX@3<g9/0d>:V0=7[[P3bom<0lOoB0<gT/03=gjl0`lVU0?7b
d`3Nh</0o_o_0?Sol03_mml0io??0>Cda`3:g:P0Rj9L0;K@QP3?j9L0fo>U0>3d[@3Hj:L0ZkUn08VF
GP2c`XT0a]RL0=S/[`36h:<0cn^`0=[ma@3Pom40g?oG0=ooh03Gom/0goK<0>[idP3_mn808B<F0?Oe
j03Yim80_/2H09:HJP3[m/`0i?;>0=WXb`3oo?d0oo[o0?gdn@3NeMP0ookk0?ghm03hlNT0oogf0?gd
k@35^;80nnkX0?_okP3Wm]D0fo2e0<;LT`3>jiL0c>bI0<OVX038j:L0aNRX0<O/Y`37kJ@0anRQ0<SY
Y036jJD0aNZW0<;YZ031j:L0`^^Y0080o`0002T0aNZT0<KZY03o0000o`000=;`Z02kfHl0JXTm0<KU
V@3:jYh0bnfQ0<CXWP33jjD0`NVS0?Olj03oooX0ookj0<;1_`1TI680oooo0?_inP3onoX0oogm0?ol
nP2k/Jl0o_o/0?Soi032gK80g^Jg09RDI02h/WP0gnRW0<oHU@3QhJ40[J9Z0<c=T`29Yed0Zm220<?X
VP34i9T0^m^@0<ORV`0;0?ooo`002P3oool0o`3;XH/0o_oX0>gok01LTf`0YmBY0=C_^02fd9<0a>>P
0;cIW`3Pm/L0ooo]0?ojn03hood0n?oo0?oio`3on_l0nooo0=gZl01RQ8H0?gIc0=coo`3ln_l0l=_T
03hV9P2dXi`0oooc0>O_h03`ooP0l_ok0>kck03km>X0T7aa09MmL03Pf/h0o_oj0?[lm`3jooT0noof
0<GC/03;g:l0j?jn0<ONVP3Pn[<0a=fI0<cWY03>ijD0c>JO0<KLT`3NlZX0F6XN0<SMT03@i9`0bn6I
0<KMU`3El:T0hono0<;KY03Kk<80;B`J06mWFP3oo^P0oocL0=CIX@1BG1d0cN:G0=3XW03?kJ<0c>ZP
0=7/Y@2hdh`0a=jG0=CYYP36fiP0dN6P0=;PXP2CXF<0d>NS0<SeY03=lZD0a[ao0;6RI`3OhJ80Y:UY
08VHE@31kIh0d>ZQ08VFD03Kj:80cn>K0<gWWP34jI`0aN^N0<?UV`3<ij00cNBN0::bL@3EiJ@0dNJS
0<gNVP34bhD0d^RO0<_VW`3HkJX0H5TR0::EH03?fIX0c^>N0=;`YP3FlJ@0bnNJ0<o_X`3Nm:/0BU4=
0>?XY@3EiIh0an6G0;oVU`3:lJ80a^RK0=[bZ030d8l0i>fn0=KT[`3]ol@0]]6:0<WYW@35hiT0bMnQ
0=o`^P2k_9X0`[jQ0?olg@3Pi;40b<nI055K7P1FIB80c=fF0<O^Z`34jJ@0`^JP0<KQW03<hI`0g>NS
0=SRW@3>fI@0c>:G0<[VV@3:jId0g>n]0=k_Z`3Ejj<0b^ZO0;kRVP39l;40anje08^`NP2;[W@0cNnc
0=7WYP1OHB00e_?70;[T_P2hl;l0?X1@0;;][@2ehiX0bNVM0<Ge^`2YhK80/^6c0<3SZ`3[k:00Ui53
0<SGU03FmK40anjC0<O_S`2_fi00a>Z_07MZ=@1UC1H0K5DQ09bKF03AgI40a^RA0;SLQ@3Hljh0b]nT
0<CKY@3HmKd0]>JQ0<;_ZP3Bhj`0am^P0>O_]02YVUl0j>jX0<3ST@3>lj<0d^bS0<KTWP2QUf@0GeDR
0<KVV`32hI<0dNbK0<WRT@3>iIL0a=VH0=oc]P3Rn/00e>ja0<gZY`33hY`0bNVN0>;l/`3Cgid0UYmN
05iS8`3Df9/0Yk1a0<SKV@3@jjH0d_Na0<ocZ@3FlZL0g?ff0<Cd^P39nlP07D/T08B]Q@3:kL<0enne
0<;GTP3SnJ@0b=j90<OBS@3KfYT0`mV@0=cf[03Xkj`0f^6N0=7_Y`3>jJ80`/^:0=7VX`3Bi[40mOGY
0>O[d03AhJ<0d>JN0<[UWP3<jJT0l?oF0?;oeP00@@31fZ00e>jU0<WTU@39jYT0`nJF0<?SVP35h9/0
cmfO0=_QY@3RijL0e=^H09FZG`2M^6T0`^FE0<C_W`32j9/0c>jQ0<OXV@3;kYX0bnVS0;C<SP2lcIL0
g^^e0>;`/`3=gi<0d^RF0<GQUP35i:00_n6T0<kbZP3FkJD0bmZE06IV9P2UY6@0b<N70>?XYP3EgY/0
WJQT0=?NVP3UlK40d^BX0<KRY`3`om<0l?oD0=;Z]P3BiKL0l?KD0>k^dP3Yk=T0o?oc0?Wol`3jonl0
nooV0?Gog@004P00dnjY0;oKT@2jehL0g?R[0;gDSP38gIX0TjE[05]^=P3@hj`0e>F^0080f>Vb0200
c=ZU0??oe03jon00mooU0?cok@3koo00n_o[0?_oj`3oooP0=C4`0?onn03oo_40n?GF0;BdT03oonH0
o_o]0?Oml@3onol0ooWo0?_bm`3IdmD0oooh0?Ogj`3ooo40nO?U0>WQe01jK6<0T7mg02h[9P3;cl40
a]6W0=o^/`80o`0000D0b^2O0=;Z[035gj00bnJQ0=3/X@020<cWV0060<[VV`38iY`0b>RO0<OYW`38
jZ00bNZK1P3o0000903Bj:00dNNL0=gcZ03<i9P0dN^Q0<OSV@3=k:P0a>>O0?_ojP3nno@0nOSd0=CC
d@000000o_oo0?ooo`3mo?X0n_Ke0?ohm@3Ld]00loSb0?OonP3ZonT0i^K009V>H02TW5/0e>:C0>7d
X`3Fh9L0WYEL0:j]M@3;g9P0eN^R0>3d[@3NkJX0f>NT09FOH0/0oooo000:0?ooo`0O0>kWkP3aood0
i?of04j<G@2_j;40b^j^0=G[Z`1YMCL0YI]Z0;FRN03P`Jd0ooKd0?oko`3bk?P0oo_o0?Okk@3gnN/0
oooh0>Koo`0nPh00Y>KR0?ono`28OgX0?C@]0>OSfP3nooX0n_oi0?Woo@3_mO40oooj05I;A@020?ok
l`070?oon`3lool0o?oo0?konP3nooP0kNoQ0>g`g@020>caf`1;0>[bg@3YlmP0go770=WV/@2a^X<0
RYiG0=CeYP3>m9d0^MV40=OUVP3>fI@0`=F@0:K0N@1bS4D0ZKb40=KS]`3Gfl@0dMK00=o^c@3eoml0
X[mm0:O3N@3CjYX0c>>C0=SbZ`3FjjH0d=nL0>C`[P3@gi`0c^:M0=K[YP3@iJ00b]^G09>MGP3Ci:00
d?J[0<3PU`3_mKD0V9YK0=3EU@2BVeX0DUhL0=cf[`3?i9l0Xk9_0=g/Y`36fiH0goVb0<;^X@36lZD0
cN:M0>_][P3Lg9h0cnBO0<g[X`3NijH0LgXg0<gUU`39giH0_l^=0=3HW01<CA40e]fJ0<_PT`3?jY/0
eo6W0<gTWP3;h9/0Ohm60;g:Q@3HiZT0eN>X0<gRX@3@jZ<0b^VM0080bNRL0<L0bN>L0<_PW`2JYfl0
TJ1W08NIG`3Hik00emf]09FFK02SWX40jnG?0?Ohj03noo@0en350<gIV@3Qjj`0cMJE0>G^[@1^MC80
a]nM0<kSX03AhJ00f>>Q0=gSX`2^]gH0SIQD0=CUW`2lfY00cO:U0<WYWP2d_Wl0UiUH0;VnN`3Lj:00
e^JM0<[TW@34hil0b?:b0;KTYP2KcI00^>NQ0=3^UP1?J1L0`M^B0=K[/039i;40HhEC07VLIP28[W40
SKUn08nlP@2mhJ<0b^BS0<SITP3Cj9d0`n6I0<[[Y03?jIl0g?BX07^>C01JJR`0SI=E0>KPYP3bg:X0
JV4X09nTI03JlJT0a]fE0<[OW03EjZT0c]jO0=7KWP2@RU00CDP>09>QI029UeX0UYYO06E96@1hKCD0
fnNW0=KUY03EgJ40g>b^0:BHI01PEah0c>VI0=W`Z03?hZX0c=b[0<gL/@3gon40iOG>0<_R[P39iZH0
bN^N0<S]W`3?lj/0`=jD0=GVUP3XljD0@dT00>7SY02HWV80fn^]0<SOV@3=ki/0anjO0<3RYP3MkjD0
cnRT0<CY]@0BAb/0`n_90<OV_02=XUl0a^2F0=;`UP35hh/0X[I_0=CSX03>iIl0cnJP04UM603<h9/0
c>JO0<CKU@3KkjX0e>VT0=cZ]`3onoT0oooc0?Woh`3Xnlh0cnRa0<[QZ`3gomP0looD0=cb`@2ofZD0
c>Z/0<SXU@3;jiP0bNRJ0=;^X@3>giP0g>NS0<78Q@3IhYl0b^6I0<KTVP3:jYl0U[AZ0=?aZ@39iid0
d>nS0;g]V@32kId0a>fO0<KVV`34hiL0dNfP0=olZP30ghl0a>NG0<W^X@2lh9H0aNFI0=K]W`3>gi40
VJAF09VTE@3;f8P0dN:D0=;RV@2>UeH0C50E0=[MZ03Ej[40a>>Z0?7oeP3bomP0nooJ0?oofP3>c:H0
gmnk0>_gd`3don@0k_oS0?Gog@3Aej/0WJIg0=K[/`3<l:X0`n6G0<gHS03SlJ@0Vk]`0<SWX`3QlL@0
o?o]00<0o_od0P3ooo@0703oooH0oooh0?oonP3ooo/0ooom0?konP3nooP0oook030`;P3mnOH0oooj
0?omm03ooO80ookh0=OBcP2b[JX0oo_n0?oio03ono`0e/c;0?ohl`3onoD0ookh0::KU@3ooOX0oo_k
0??]k@3oo?`60?l0000608ROF@2=Xe/0TJ9N09NVI@2FYF00N8Q10P3o00000`34gYD0cNVO0<?MU007
0?l0000406Ei<@3Rn[00bN6E0<gWW@80b^VM0P38jYh07034fZT0e^Jo0>KZc`3HeL80NG=U0?gfl03o
o_/0o_om0?Wkn03ooo/0ookk0?ofoP3onol0nOom0<[Tb`3?f[`0TGA<06QD7`3KhIT0f=^D0?3IX`2J
TEX0d>6M0=oe[@3<hYT0cmnH0>;]Z@2PYf@;0?ooo`002P3oool0o`3]ool0jOoo0<gdh@2?_Hl0^NJ_
0<?PX01ML30092T005124`1UD2D0NE]10=bk]P3on_l0m^km0?gdm`3koo40o_o]0?kol`3Qo_l0@Y6;
09k[h`3imOH0@3Ta04e9?P3lnO80oook0?[jnP3oool0ooom0?omnP1JCd/0oo7Z0?oil@3oood0o?oo
0?con`3nooP0ooof0?gml@3moO<0oOge0?cmm`3lo?X0nOoc0?Soj03;d:P0Y:Ei0=3SX`3@lZH0`^jG
0<kaW@3?fi<0gNBP07F:A`2cc8P0X[Mb0=7SZ@3Ag[00d][20=o[d`3Wo=/0lOoO0<_[Z036i9`0c^FE
0=7XVP2dbhD0T:AO096LFP2FXEl0SIQF0=?WXP3<hid0gOB^0=;VX@2S[V`0cMjJ0;oSV@3NnK80Phm=
0:V_K`3Oi:@0^<6007b8AP32eY40b]jI0<gNVP2Y^WH0`mZD0<?MUP2ljid0_NbN0<cPV`3OfId0fM2E
0=?XX`35iid0f=fM07Yl>`3FmJL0cN>K0>Wa]P3RiJ`0F64R0=SUW`3:hY@0an:C0<;LTP3Gl:h0f>fZ
07J3>`31d8d0dnFY0<cQYP3Ak:T0b^RP0<WXV03:jIT0c>^O0=7/Y`3BjjT0`]2E0>7`]`1PK3X0[KJ9
09VDMP2<P6P0iMG60??Wf@3ooo80o?oc0<7@/@3:hI/0e>^U0<[NV@3Nkj/0Y;=`08NHE02CXUl0T9aJ
0=3IV03]m[D0V:AR0;31O@3<hid0anVO0<C]X@37jIl0f^NR0<74P@2QYf40am680>7]X`3Bj9l0cNRS
0<G][P2`gJ80a?No0<Oi^P2jh8/0]lmi0:^nK`37dYH0f^Na0;kFXP36i;00`NV]0;kVY`2hgi`0cNjY
0=3YY@3=ij00do6Y0<OYW`3=jj<0f^jY0<_GU@0lA@@0M7dl0=3OW03/mKH0imjW09VBF`1nOD@0a]JG
0<[OW03DjjL0ambI0;o:R02NWV00MVX`0967C03HhZD0g^R[0>SW[P1eDbD0MF4^0:2QI`3FfYl0c/fD
0<SBU@3=_HT0P7Hk0<7LR`3?iYh0dn>b0=KU_03NjLT0m_oU0>Cdd03:hZh0bnRV0<S[U`35k9T0dON^
0<_[X03;h940cM^<06A/8@3PhZ<0Si=H0<_GV@39gIH0c^bF0;oRTP30hJ`0g^VM0=OWX034hZ`0;V17
0;gR`@33g[<0[l=n0=kj[`2lgH@0d>jF0=7XXP3CjZ@0d>NQ0<7HTP1>IAl0fo:/0=7XXP3>iIl0cNBN
0<oVX036eIh0oo_b0?ool@3`omh0kooK0<cT/P3EjKH0m?oC0?WofP00?`3homd0e>_10=?[^@3ElZ80
cnjN0<k]W@3>jYd0fnfS0=7NV03?f9D0e>6L0<gWX03>kZD0bNVP055[902bbH<0e_2W0<WUV`30ji/0
a>jL0;[QT03DmJH0anJH0<cYV@2fdXD0e?>U0<g]X@2lgY80e?JZ0<kZX039gY<0g_2T08ZIB02DXe80
g>jL0<gTU03@iIX0XZ]/07Ef?@3Ph:h0b=fT0=3]/`3Nnl40g_O00>gia`3[lL<0oooG0=[K/@3Ol<<0
e_300=;e_`3HlKP0]k^80=gV/@30eI`0d_R_0=?aY`3NhYH0XjiP0<_[XP3;kZX0jOSA0?kom00:0?oo
o`060?koo@3noo/0o_ok01LH4`3Wi^80o_gi0`3oo_/02P3UgM/0ZZ:P0?ojnP3ooOd0oo[h0?O]j`2c
Z:H0ooKd0?olnP2n]KH20?l000030?ono`3o0000o`0000D0o`0000D0d>ZP0=gcZ03GiZ<0a]6E08ZF
EP040?l000030<GOV03LmZl0o`0000D0o`0002D0[L5i0:k4N`3>j9h0a=jD0<cXW@3:jId0bNVM0<SZ
W@36jid0d>fe0<;HZP3oon@0WIR200L0003ooOP0ookj0?koo@3joo/0nocg0??bkP3ok_@0ooOk0?Ol
n03>k]T0d>C;0:j<L01YCBD0l?2b0>?OXP3J^hd0ThII0=W^Z`2dd8H0f?BZ0=_aZ03KkjL0V:EM00/0
oooo000:0?ooo`0T0<Coo`1YY8P074<T0=_K]@3?aiT0G5`P0=3IV03=gYX0e>f/0=[b]03Zl<80b[:J
092?RP3iool0ooom0?Wgj`3ho_00nOok0>Goo`16WID0VN_O0>7>d00Y71H0S8=l0?onn03noO/0ooko
0?ooo`3oo_l0ooSf06=HE03on_<0oo[d0?ono@3nool0o_om0P3oooX20?oon03o0?oon`3oood0oooo
0?kon`3bnnX0_kfT0=7>[`34dI`0bNRU0;oZVP2nhi<0f>FM0=_UX02gdHX0c^bT0<_RWP2lcIH05B80
0>_`f@3Zl]/0mooV0=S_``39iZH0dNZV0=SXW`3@hYP0TjiW0;kCSP3EhIl0g^ZX0=3OW03=hYd0_mVB
0=_e[P3MlZd0`/f;05MV8`3Elj/0/lZ405UR8@2HWEd0h>FU0=gXYP3:fiL0i?^e0<_RW03AiZ40QY]F
0=;WXP3>iIl0`O2R0;o^X03IkJP0h]jQ06eT:@3Gk:L0anVO0=oTY02j_7/0fob]0=gd[03Fh:@0e]jS
04MA4P3QlZ/0`Mb=0<GTU037iYX0d>^X08nXIP3@j9h0cNBN0<oZY@3=kJ@0_>:?0<C/U034ki<0a>nE
0<C[V032j9l0anJR0>3[[`3PkKP0mooO0?Oki03ooOP0ooSe0?GTg03oo^`0nooJ0>gib`2idIL0_NbN
0;c[W@32kZ40_nVM0<[cY`3Lljd0cnBO0=ga[02>WEX0JWHd0::aKP3Smk80b^6K0=;dZP30i9X0`nVL
0<KUU`3Hlj@0ennQ0=7WW02odh/07C400;O:TP3Ai[d0lOoW0>Ooh`2E[i@0[lZW0<kT]P3GjKT0LWm7
09Z]K@37iI/0_n6E0<7/W@33k:00anfT0<_XY@3Cj:D0dnZT0<WTW@36i9`0dNbU0>Oh]026TU00cmZH
0=7MV`3:giX0h_Vc0=C]Z`2]]gX0LGDj0=CJWP3>fYX0d>2O0::^K01HGAd0TYME0>7g[`37g9L0gn>X
0=[PY03RgJD0Me8U0<J_O@1lNd80H5lV05eH801GGB40FdXF06QI803?jYd0d>ZS0=O/]03XnL`0mOoN
0?Soh`3Umld0bN:X0<_YX`38k9D0a>ZC0<;YVP2kgI<0e>R[0<kKX`3[m;d0SiAJ096JF`3HjJ80c^BI
0<_XV02achL0_LbE09BHB`1cPcX0c>F[02U7;@2ld:d05B@00<[UXP3<lJ/0c>RD0=3VU02V_GL0`MRB
0=W`ZP2oeY00g?>]09bcK@3CjZ@0b^6K0<;IT`2H[fT0Z;am0<gM/03Tn<D0gO[00<OUZ@3<i:X0dn6/
0>3S^03Jf;80oooS0?oojP3non40bNFJ0<OUV`3?kj@0cN^Q0=7WW`3Ei9l0ZkQc0<cMU`38j9l0`^RM
0<KZX03Qm[40X[Mb07bBBP3?iId0eO6T0;kJS@3>jI`0c>:I0=;XW`3Dj:40a]bD0=;WXP3@jJD0^]F@
0<_TX`3Qm;`0f>F]0=;LX02BVeX0W:MS0<_HTP3Bj:00d^JQ0=_UZ@3GfZ<0Vi]W000G0=cZ[@32f9L0
b^>Q0=7[ZP3>hZ<0dN6S07j8C03Mij/0en^/0<;OW@38j:L0d>VX0:ndOP3=eYl0enf_0<[`Y`30gY@0
e]VB0:B/H`3=jZP0aNBY0>kif@3nooH02P3oool20?gmn`040?Sgm@0@3`d0j^WW0?ooo@80ookm00D0
n_Ke0?ono@3oo_d0/J^[0?ojnP020?l000030?olnP3LdLl0oogj00X0o`0000H0bNNO0<[VV@34gi00
d^JO0=SXY`3Nkj/40?l000030;_IT@3RoKH0^=><0080o`0000P0Yk]f08ZNEP2DZ600`]R?0=K^Y03C
kJ<0cNVN0<cXW@80bNVM01h0b>ZM0<K[W@2keJP0g>c?0?ook`3Abkl0e/_50?odm03ono`0ooom0?Oi
m03oooP0ooof0<^n^03hkNT0ooog0>col03ioo<0bk6P08YiG@3oomd0oogO0?oReP3ooNd0[/JD0=Cd
]@33hj80`>6J0<c^Y03>l:@;0?ooo`002P3oool06P1PaI/0H9ah0=_mfP2MSfP0L5/^0<70P03TlJ/0
anFK0<K^Y@2hh9T0jo[30?omfP2VZIP0kO[`0?clnP3oo_P0oOoi0?;ln`3Bmol07GA/09SUf`0i8bD0
9aPA0:nVW`3oo_P0oogl0P3oo_l01P3ono`0o_Cb09nASP2bXi`0oo_f0?omo@80oooo0P3ooo/0j@3o
ooX0oook0?ooo@3oood0oooo0?koo@3looX0dL^k0<S2[03KikT0f_Rl0<OaY@2nhiD0f>FM0<kIU03E
lJL0`n>J0=O`[`3Ej;4000T00>[_f03nond0n?oV0=gba`39hJ<0dnRU0:biL`1dQ3d0`n6I0>7h/P3:
fIH0e>>P0<oNV`3=i9h0dnfV0<;MUP31f980f^JT05ET8@3?jJ80eNVT05AJ6P33b8P0g^>S0=KRX03I
kJP0f?:[0<CNU`3BjJ<0d>FP08NLE`2oeY00a_:U0;_ZW03=hI`0i^:U0517303Bij80an^Q0>O/[02f
^gT0bnbM0<OQV03Dgj<0f^BX05]W9`3:fi@0e?6Q0=?dX`30h9@0`=^H08JQGP3GlZ/0dNbW0<_[XP32
iiT0`njD0;cYRP34lY00a_>F0<K`VP35kJH0c>ZZ0=7JX`3Bfj`0n?gW0?oom03onol0ooWo09Z9P@28
OFL0Jg8o08nMG`3?i9l0d?:X0<g]Y03>kZD0cN^S0<[XX02mf940c^RQ0<KMU`3Hk:L0cMjJ0<SIU@3B
iZ40cnJP0<WYX034j9h0a>ZM0<W`W@2jh8/0a>NC0<o[WP3?jJ00am^P08JGH`3/n]T0nOo]0?Ool@38
e/T0?UA70;;6[@3Kk<`0b=JQ09FXJ03@l9d0`nN@0<7[U`37kYd0b_2S0=7/Z@3HjjT0e^^V0=3ZX`33
hIT0c>NP0<cMV@1?FaT0gNRV0=7PW@38giT0b^BM0<SQW`3bol`0foRe0:2_KP1gMc/0HedQ07=c=@3?
iYh0e_BZ0<7KTP3Gk:L0f^JX0<oMW`3NgjD0Ke<S0<ViQ@3>eYX0cmNK0=[NX`3GijP0`KR10:>MH`3>
jYl0bnJO0<gT[03Tn<L0mOoK0?Oog`3Tn//0anBT0<WYX038k9@0aNbA0<G[V034iIh0e>Re0>;_``3U
k/<0lO[10=kZZ036fh`0cnNI0<c[W`28Xf00gNFZ0=GHR@3?hY<0GWPi0;C9ZP0[=A807RL00;gMW033
kZT0d^ZL0=CUU`2dbhD0dNRR0<KMU`31f980aMbF07nFD03CjZ@0c>>M0=3WX@2:XE/0T:MS0=G_[P3>
kJX0eo^e0<g^Z@3AijL0eN2X04a77`12>QH0[Z>70?okj@3lnmd0a=fI0=gh/@38iYh0b>>L0<kRW@3F
iJ80[Kai0<kRW@34i9T0`>JI0<S]X03=hI`0dnNR0080SJ5J02d0c>>E0<cRU`3MlZL0a]N@0>?d[P34
eI40dN6P0=GUYP2FZV/0TjUY09fbN@2:VVT0a<fN0=cT/@35cI80T9YM0>Of]@3>iIl0a]^H0=KTY`3D
g:<0E5LP0<_CU`3<gid0c^FQ0=C_Z03>j:40d>NQ06=d<03Hij@0c>>M0>Co^03CljX0b>6M0<K;T@3D
gZ80e>ZZ0<_aYP3>kJ40HF@M09jSH038i:L0`MfZ0>O_e`3nooP02P3oool20?ooo@0:0?Kbl@0d<2l0
lO3^0?WhmP3lnoT0ooom0?_jn03in?H0ooom0?ono@@0o`0000<0oocj0?omnP3o00000`3o00003@3o
oo/0o`000?l0003ioo<0kOoK0<cT/P3<jZ80d>nQ0=KcX`3Aiih0b]nJ0<KKUP3@iil00P3o00003P3?
kJ<0cNfR0<?QU`3>k:80dNfS0=[aZ@3@iYh0gO>Z0<KLT`3MmJ/0c>BJ0=SbZ03;ii`0c>RM0P39jId2
0<SZW@0L0>GneP3gond0oOga0=C=a@3llNl0oo_o0?olo`3oood0oook0?oon03oooH0k^OM0=kGc`3C
d<T0n?oh0>cbiP3onN/0ookZ04a1:`3mi]P0onCZ0?oem@3con@0KhIJ0;K=W`3aomD0e_>i0;kQW`/0
oooo000:0?ooo`0R07ZZP02fdJH0VJUl0>KV/03MhZ80b^VI0<okYP2mlYX0^^FF0<OYW`3MhjL0]:=[
0?GlfP3doo40n?oo0?omo@3om_h0n?oo09SIg@08C4/0c__h00l0000>0000m>OQ0?oln03ono/0ooko
0?olo`3oo_l0ooSg0?oknP1SE4l0ooC_0?olo@<0ooko00@0oooo0?koo`3nool0oooo0`3oo_l0g`3k
n_l0oo_o0=S;a@3non@0foG50;cUW`3@m:X0d>2I0=k[Y@2mg900d_BX0=[f^@34f:D000P0010B000]
;aL0nOoQ0>Kfb@3Bi:P0f>JX0;:kNP2f`X00c_2V0;gKT`3AiJ00c^:M0=7UX03Ajj@0R:=L08>NE`2J
/F/0TYiL09JRH03FjZD0b]JD096CE01WJBX0WJ9R0<oNV`3Kl:/0bNVP0=?aZ@39i9d0a]fG0=KZY@3H
kJP0`NfP0;k]W`3KkjX0^[Ii0:JPI03<hid0an^Q0;NmO@2b^GH0bNbL0=?_Y@2kbH`0V:=W0=g/Z`3B
iYh0a^FE0<OZV03:k9l0XL1l06n;CP1jTEd0XKR20;OEU`3DmJh0_nN?0<O`U036ki<0`^ZD0;oSV@39
ik40e>^o0<_>[`3gnn80j_3R0?Ojl@2d[:T0mN[V0>gQb`3ajlL0eMjO0=3PU`2D[5h0aNVO0<CXWP34
iY`0an^Q0<GYW`2mgiD0cnnV0<g]Y03;iIh0f_6[0=S]Z034fiD0dN^T0<KTW039jJ00bNjQ0:oJR037
lId0bo:Q0<g]X@3CkZL0b]jQ0<kOZ02a_9@0l_WH0<34Z@27T7d0`MS>04MOC`2ld;L0e>Fh0<gPZ03;
jYh0b>^I0<;ZU03>m:40a>NG0<oYX037f9@0VjmZ0<;IT`3@jZ<0dNRR0<oNV`1?FaT0]/F20>Sl]`35
hi/0dO>Y0<_cZP3<kJH0aN>M0=7TXP3LjjP0eN6O0=?RW`3Djj<0cNbP0;kWV030jI/0c?:Y0;oWWP3:
j:80CT`A09RTI02nhYX0_N>J0<k_Z035lJH0cN:O0=OVY@37iI/0c>ZT0<_UZ03PnL00l_oD0=Wb^`3?
jk00bnVS0<_[W`38jY<0bNjA0<c_V`3Akjl0e>O;0?Gok@3_oN@0hNnj0=gaZP3Aji@0cn^G0=7^Z`2]
`XL0jn^[0<W>NP3JmZ80cNbV09^XO@2LWVl09Rl009O9S02cl;@0b>JP0<cMUP2fcHL0SjIP0>;i/`2m
e8h0cnJP0>On^02^aGl0b=nI0<gTWP3@ij40e^fU09JcH`30hI00anZH0<?TT`3Gj:80e=fN061H:@3M
d:H0f/bY08b1H`1cKdX0d>2R0>Kh^P3EjJX0eNRX0=_UYP3HgZ00b<j>0=KQW`3:iY`00P3;jj00<@3O
m[00enbW0<;HT02dbh<0R9]<0>3bZ03;gI<0VJYT09BTH`1^PD40TJEX0=7UZP3Cj:l0cnN]0>Wmb03Q
m<L0d=fb0:VeQ`2EXV`0Pi9G09ndL`3?kjH0anNN0<oYXP3;giX0U9eN05eM8@3Rjj`0dN:N0<[TW@3=
kJ80bNVN0<kZW@2<Y5P0`=R<0=G`X@3;j9P0c^RO0:^dM@2c_Gh0`=VE0<oeZ02ogY80FU/I0=kOX`38
h:h0h?WA0?SlkP3ooo/02P3oool0303oo_l0oogo0?omo`1^JV/0dLo@0?ono`3oool0mOGe0?WknP3a
mO@0o?oo0?ooo@@0o`0000<0_K>a0?gelP3ooOd00P3o00007P3jnOh0oOki0?oonP3hooD0n?oc0<gQ
_038h[80d?2W0<_/W@38j9D0d>fM0<WSV@34hYP0cN^Q0<_[X036iY/0anVM0=GgZ`3>l:@0co6U0<g]
XP3=jj40d>jT0<;LTP3EkjD0dnfS0=;/XP2mfHh0cn^P0<[YW@<0bNVM00l0b>ZM0>7kcP3gonP0ooo_
0?onm03Sf=@0BSi20:JMXP3mnoh0oooo0?kmn`3oo_d0o_oh0?oomP3bj>H00P3oo_/0303fknD0o_oa
069IB02?L6/0nlGC0?ojo`3oo?l0mN[`0?oio@1hM6/0oooc0>O]d`/0oooo000:0?ooo`0I0=_W`@15
C200F60_0=;QX03EkJ<0`o6I0;7VS02nli/0_N:D0<cSW@2UYFT0Ge4D0<kF[@3Zo^<0kOcg0?ooo`3o
m_l0koGo046BT`2/gn<0l?oo01@1000Y6140ooOd0?olnP020?omo`080?ojoP3ooOl0ooGd0?oknP36
]k80oo;]0?oln`3ooOl20?ono`040?ooo`3nool0o_oo0?ooo`80ooko0P3ooOl0o`3onOl0oo[k0?co
i@3Om/X0`^VV0<W]Y@3Chi`0eN:L0<k]X@2nh9@0_m^N0=KZ]`003@00MGQM09FHO@3lon40j_O90=k]
/P3@gZ00X:IX0=;NWP3EnJl0b^RP0=K[YP3@i9l0cnBO07F?B02^bH80an:K0<SOV@3JiZ@0dMfK0=c[
Z03<eiD0g=jO0;VkO01FFa/0e^NS0<SOV@3;jj80`^:I0<gXX@39hi`0en^V0;gBS@38lZH0`>bO0<cP
V`2ZYVT0c<J:0<kUW`3:l:D0V:5P0=WPW@3;l:00an>I0::`L`2DWf<0cMbK0<SNU@35iYD0a^VG0=7c
YP3Dljl0b>BY0<SH/@3bom/0Z<2<0<GQY03AlZ<0b>ZF0<SYV037ii`0bnRX0>Soe@3honP0oooa0?Gh
i`3ioo40W:2B0>SWe@3Vgl`0dlfY0=CAY03Ihj@0V:US0<[RV033hiX0bNVP0<_[XP37jIl0b>bR0<CX
WP34iY`0^MV@0=?^Y`31fi@0amjH0=3WX@3@jZ<0c^VR0<SVWP3<kZ@0e_b_0;oVU`36jid0b>JL0<kZ
X03>i:<0c^:S0=OU/P3YmLL0fN:g0=?Q_P2/b:l0bN?:07J=L02``IL0cMn]0<CQW`37j:40`NRI0<od
Y02nhI40b>:H0>7b[02<X5/0^<n90=7XXP3@iJ00gNbY0<WET`3NkJX0bmnJ0<;RV@3;kjD0_^JM0<KT
WP3<hil0c^FO0;kITP3;jJ40d^jT0<WOU`39hIL0b_6R0<3[W02jiY/0_NVN0=7bZ`1PI2L0XkId0<Sb
Z036lZL0`^ZQ0;W^X03?jZD0dnRS0<KTW03>k:H0an6R0=K_]@3So<80an>V0<GRXP3=jj<0cnjR0<WY
U039ji@0]]N60=3//@3eoo40l_oc0?Kol03?hZ/0d>JN0=KcV@33h8`0b>FU0<_PY@2j_GX0gNNA0;gO
R@3;kJ<0dn6^0=SMY`3=fZ806E<H03Z1B@33iZ80d^RP0<_RW02K/V`0bn:L0=W`ZP3@ij40`mZD08VP
FP37gYP0cNBN0;cCS@3Ek:@0RZ9D09njJ`3?kYh0bNJF0=;RV`3Hgi`0FE8L0??Y^03JdZ<0`[nD09JH
J@2?V5l0TYeS0<_IW03Nk:l0f=jR0>GVZP2][Fl0eMZJ0=7WW`37hiT0bNNM0<KPV@3;iIh0fO>Z0<_U
W02cb7T0WkAW09Z^IP3Gk:L0dnRW0=cb/P3JkkH0cNF[0=C[/`3:hjX0lOoB0?Gog03hom`0nOoH08^M
H`2DZ6T0Y;mj0<S]X037kYl0d>nS0=3ZX03PjjL0A4@80<[@U03ChZ40fO:^0<GYW`004P3:kj80fOR/
0;C?PP3IlJD0dNVM0=G`X`3Ajj40h>VX07b7A@3;iIh0anjO0<WXW01JFQX0ViaR0=CZ_03Ml]40o_oh
0?ooo@X0oooo00H0ooko0?oko@3oo_l0HUiO09RFU`3_knl20?koo`050?coo`3ho?/0nooo0?kmn`3o
o_d00P3o0000903oo?X0mng[0<k9a@3ilo<0ooom0?ooo`3nool0n__f0?oonP3do?40nOod0<kR_`3<
i;@0koo80=_l[@32i900c^fM0<OVV039jIh0a^RL0<;TV03:k:00_^2D0<KXW03@lZH0aNNK0=GgZ`35
ii/0do>X0=KbY`3<iY`0c>RM0<_WW03Ckj@0a^FI0<[YW@<0bNVM01d0b>ZM0=7/]`3Wo=<0h^K;0?[e
hP3on_00NFe]00h52P3oo_l0nOSm0?_jo`3on_l0nooj0?Cgl03Ld=00oo_l0?khn03ooo<0locW0>OQ
b`1K?c<0onK/0?ohm`3mlOd0ooSo0?oio`3ikNl0c<>n0?onkP0;0?ooo`002P3oool09P1R?QX0cl>A
0=gSY`3<lJ<0^n^E0;KWSP34kYP0dO:Q0=cXYP3KhJ<0PX5809NFE@3Df;<0noo_0?;oo`3hool0ooOo
0?Coo`1P`kh0mOoo0?oZnP0V8180?C0W0?okn03oo?X0n_Ch0?omo`3no?l0n?Kk0?omo@3mlo40ooch
05E8@P2fZ:L0oock0?oinP3ooOh0n_[l0P3lool0o`3nool0ooko0?omo`3ooOl0n_Ko0?oho`3onOd0
oooZ0>?jcP35jJT0dO:]0=;OVP1`NcH0d>bQ0<OYW`3>k:h0eNbf000:003?dk80hnC40?kofP3Pk[T0
b]fM0<WIV02>VU`0d^:Q0;kTV@3;jj80_M:=0=GYY027W5L0`mfF0=KaZP3Ajj@0bMjI0=WTXP3EgYd0
/[il06ae=01CEAH0VI]L0:N]K@3JkZT0gON`0<7SV@2jfY40fOB]0<CKU@3@hId0bmnJ0<C^XP2mjI`0
d>6M09fIG02PVUh0c>JO0<?YWP2CWU`0eMjK0<g`X02he8X0CU`O0=WTZ03Ei:<0bMfE0<3OS`37jYP0
cNnR0<o^ZP37gZX0oood0>GWf@3non`0locM0=_[^P3Ol;T0dN2Y0>;^_P3loml0o_oa0?oon03Ke]X0
moSc0?Soi`3OjlD0f>:]0<_@UP3:cY40g^BV0=GSYP2AYFP0H7@g0=OPW`3EgYd0fnBS0=[UX`3=f9H0
d?:X0;oQU`3Dm:/0cN^S0<?NU`33gIH0dN^T0=kh/@36hIX0c>NP0=C]Z@3=hj80b=fL0=?ZYP39h9P0
eNnU0=3/W`3;j9P0c>VI0<_VU`3Dkj00cNbP0<;ZX`39j:d0PiiY0;C5V`3?hK/0:dHK086QL030ijH0
`>FO0;_PTP35hY80gO6Z0<gRW@2G[VP0g_F_0=7VX@3KijD0d]fK0=WUX`3EjJ@0c>bS0<KTW03;h9d0
c^>P0<?LV03=ljP0_^VJ0=;n[`2Ye8D0dO6U0<cVW03?h9T0i?R`0<[XX03Hn:l0e>RS09F;D035bXX0
cN^S0<;RV@38iYh0c?FY0=SYY@3EhIl0gORc0<3KV03Bkj`0b^NT0=?`[@3<jJH0cnfW0<WTW@3Mmjh0
_]J<0=G]X`3@jJP0bMn`0?Gol`3`onl0loo]0<SPYP3?jJ00bNN?0<OTTP3>j:/0c>BZ0;_8PP3;gHT0
`NND0<SaY@38hj00e^NQ0<GNW02XjkH0J;N:07b`L03<l:X0f_6[0;W@RP2`ah40dNRR0<[QV`3;hY`0
`mZD0:JmM`3=i9h0d^VS0=;VX@3@fIP0VZIT0=?WX038g9@0fNJN0=cSW@1FFA@0aL^50>kh/`3DiIh0
gNjZ0=oRZ@3@eI/0Xj]`079h?01MFb00Y9iT0::IGP3OfId0en2M0=?TWP3Nm:`0cNRQ0=gh/@3?jj40
b^RN0<_XU034hI40aNBH0<g/Z03:jJH0a^BV0=Ca]`3aom@0a>2U0<;NX`3?jk00c>V_0<?LXP3;hjL0
dNZX0=?aZ@3CmJT0b?>Q0<WeX03<ki/0`n>>0=CTV`005@3KfZ40Q8UA0=?RY`3<iZD0_N:M0=3e[`3>
k:H0^]>?0;78PP3@ij40b>:I0<gWWP32bhX0Z;=a0=WcZP31iYP0cn^N08V8B02SXVX0kOgI0?Cok007
0?ooo`80oOgm0`3oool30?ono`0507AbL`21PH40m_Kf0?koo`3lool00`3kool02`3oood0ookm0?on
n`3oo_X0oogj0<S0_@3ooOT0ookm0>g/jP3nool0l?Cg0080ooom00T0oOoj0?_onP3UmMP0dNJm0<cY
Y`3;jIl0b>VH0<WZV@3;k9d00`36jid60<SZW@80a^^M1P3:jId50<WYW@0L0<g]Y036hIh0c=JR0?7a
b`3oon@0oo[^0>_VhP1[K700o?oo0?[jo`3ooOl0koSg0?_oo03llOL0bl;70?ojn`3ooo40m?oV0<gC
[@3Pd:l0W6aH0?CVb`3ooo<0ooof0?Ogj`3oond0hN770::SP@/0oooo000:0?ooo`0V08Q[?`3Rfj@0
e^2Q0;kST`31jiL0cNjM0<kYVP3?h9T0h>JX0=KKX@1=EAX0^lB50=KG]`3ooo<0mOoo0?Soo`3ajOH0
kOoo06>n^@3mnol0oo;o02XY5`13=Rh0oo_h0?ohm`3oo?l0ooko0?[io`3oo_l0ookm0?oim`3nmO00
MFQR081aKP3onOL0oocj0?Kdm@3no_l20?coo`030?koo`3oo_l0oogo0080oogo0;l0oo[o0?ofmP3o
onP0jOoD0<O/Z@3;k:D0en:N02Xc003=iih0bnZT0<[XZP3>iJl000/00<oC[P3?dJ`0oOoE0??ob@3F
jjH0bMjI0;K6Q@3Cj:D0an^Q0=Oe[@3FjjH0cN6L08RLE`39h9X0dN^T0<_RW03MlJ`0i>f/0=[PX02F
XEl0ATl>0:2RH`3DfIT0hnb[0<oTW`2nfI80eoV_0<c/X`3Bk:D0bn2K0=;QWP3=gYX0boFY0;kZW@3E
iZ80X9aO05aF6P3DkZL0`NNL09:MF`3Jhj00c_6Q0=3/XP1;FA`0fN>W0<gLV`3IkJD0b>NG0<o`W`39
jId0d>fZ0<_O[03oo_X0oocg0?oom03oonl0m?_I0=OO]P3Oi[`0gN6l0?ooiP3imn/0ookk0<g;c03h
no80mOoP0<kP[P3=gYX0gnbT0<7;Q036dH`0enV[09ndN`0_@@L0W9IJ0:ZTJ03IdiL0in6U0>;NX@31
hIP0b>RO0=3^YP3CkZL0cnZS0=;/Y@3?jJ80`M^D0<oYXP3Bk:D0`MRD0<KFV03DhZD0gnn`0=CZXP33
fi40a>BA0<GUT036jHl0bNbB0<W/T03>lYP0aO2G0<k`YP3>j:L0X[>608RJLP005@00?Ulb0<K//@31
jJ<0e_ba0<[YV`36gID0e>^U09NaJP34fiD0go>^0=kYY`3AfYT0`ln=0=__ZP39jJ00c>JO0=SNWP3B
ij80cNnU0;oYW@3Go:l0anVL0=7fZ03;mZH0^mj>0??i/`36ahD0dmnM0<[IUP3Ffi/0OVD_0=36R`3G
iZ<0dnBP0=_ZY`3;iIh0d=:C0=kNX03>ijD0dNZV0=Ka[02ofYD0e?:/07RCCP2O^WD0eo2/0<kUX@3E
j:H0bmfO0<[LZP3:f[<0mOo[0>;dfP3UnMH0f_Be0<gYWP3?kIL0e_6R0<[RYP38h:H0NHe60:6bHP3E
mjX0bO:V0<gaY`3;iYT0aN>K0;Gda`1e`i`0O[Qk0;gXX@020=K]Y`1?092WH@30ei40cNBN0=3WX@3K
lZ`0WKA^0=S_Z@2neHl0fnj/0>K//02@VUd0cmnN0=;SW`3?fYD0f>:K05eU703:e8/0e>:E0<kYV039
hID0g>BX0=KPX`3HhZD0/KYk06ES:01GDAL0OW@i0<c6RP3Mi:40e>6L0=3TW@3>iIl0c^RQ0<oYX034
h9H0b^ZE0<OXU`37jI`0b^^V0<WYZ038j:T0hoo70=[h_03AkK00e_2a0;_EUP3@kJd0e>j_0=C][03>
iJ40cNRQ0<3PU@2niI@0a>^H0<CVTP38hi80gnbT0=[KX@2DWF@0e^R/0<[TY@35j:H0c_6]0=;]ZP2[
`H00c^>R0=3WX`36hI`0a=jE0>;[ZP2:UE<0bN>J0;_PTP3ElJ@0HUhQ0;ReP03honH0mooa0?ono`06
0?ooo`0:0?knoP3oool0o_kn0?Gem@3fm_H0o?[m0?gkoP3moOl0LG5c08J6R080o_oo103lool02`3o
ood0o_gk0?onn`3oo_X0oogj0;R`[@3oo_X0ookm0?Kel`3loOl0nooo0080oooo00d0moWf0?con`3f
onX0g>c80<_UYP37iId0bNRJ0<_/V`38ji/0a^^M0<G/W@36jid0b>ZM00<0bNVM0P38jYd00`36jid0
aNbM0<WYW@0:0<WYW@0L0<WZV@37iYP0d^2R0>S/^P3oomd0ooo]0?oom01?E500mogm0?Kjo@3mo_l0
n_on0?coo@3ooOl0cLO90?oin@3oonl0nOoV0<CAX`3Fcj<0MdX]0=g:Z@3`omT0m?oQ0?Gog`3gomX0
i?W10:VmP0/0oooo000:0?ooo`0K0>WLZ03NhZD0c]fJ0<g^W`3;k9d0d^ZN0<_MT`3?fYH0j>fc0=;G
W`1cOTH0c]fR0>;RbP3oooH0m?ko0?Ooo`3dool0a_3_06bh^03gk_l0oo;o00d<000/8QT0ooWg0?cb
l@3ooOl0oOco0080o_oo00T0mOCb0?onn`3on_@0k^?M0:nPV@3oo?H0oogh0?_jn03oool00P3lool0
H`3nool0ooko0?omo`3ooOl0ooko0?ofn03om>l0m_WJ0>3hb038kJX0_=^E0=SQWP13BPL0c>>M0<_Y
X`32h:80a]fU004A003XkLD0gMng0>3[/`2ibH/0H7L_09fdK03NlJl0bN2L0<S/XP2ng9@0c>6L0765
@02BYV40dNRR0=K`Z@38gIP0cMjJ0=;HV03QijL0Lglm08jGEP3Gg9`0gN:R0<kGUP3Bij80U:mX0;oO
UP3<jZ80e>^U0=3TW`3Hij@0eNJR0<WbYP30jYh0fNZV0:BPH`17@@D0d^bU0<O`Y02DX5h0g^NT0<?T
U@3DkZD0CUTM0=?MX@3Ghj<0cn2I0<WVUP3>kih0aNFI0?;obP3homX0ooKg0?omo@3Gdm00oooh09fQ
RP2g_9h0TY=a0:>TQ@3dl]/0ookf0<Jn^`3`lNT0o?oa0?Kog03=iJ/0enfR0<CGR03IiiX0f^ZQ0<oU
Y03Nn;/0a=RK0:bZK@26Q4L0EU@G05=A501FEQP0VKA]0<SSW0020<cWX02a0=cf[`3;iIh0d>ZS0<oY
XP24WUL0Lhe60;_@S@3Jj:X0h>^_0<KDUP3Un[D0dN^Q0<_ZVP3<kYP0b^jD0=;gVP3=l980d?FF0<Wb
U030hI00dnjW0<_MZ@3Ci[P0a^>e0;oP/@1>MSX0^>6M0;?KTP3@l:@0f?:Y0<;LU@3Ak:D0N8m90=;V
X@3LiJ@0f=jN09NRH035eY80anFM0=7[Y03PjJP0a=RC0=ObZ`2C^6/0^]Z?0<;NT`3<k:00`N>F0=_g
ZP2?UU00Y:ES05=H602a]gL0j^JY06]:5`1HA@d0V9iN0;O2P02e_Wd0Nhm:0:ZVJ@3Sgj80eN^Z0<oX
Y034gIT0=4l805Ud;@3BkJH0d>ZS06=i>02U^GX0d^6V0>cia03Fh[h0enG40?Coi03Ei/80e>Zl0<_V
X`37hiP0c>NH0<cVW03>i:H0dNV]0<3GT@19E``0`^2F0;kTV`2niiP0bn^H0=CdZ@2Xh;T0NL2R0;Od
^@31l:X0b^6K0=;YX`28WeT0TZUS0=?ZY03;hY`0b=nI07B;A@2:XE/0d^VS0<gPWP3Ujjl0/kf00=c/
Z`3Fij<0dn2K0=OQW022S4<0M80f0<kOT@30gHT0fOJV0<oNW@3Fij<0eNBQ0=3LVP3@dY<0h=bO06]R
9`2PVUh0?TD204UF4@2AXU`0amRD0>Wj]P37gID0d^RP0<W[U@3;k9d0bN^N0<KZY038j:L0bNVZ0>Co
aP3;ij`0a]jP0<KLW03Jl:l0a^6N0<[PW`3?i:<0cn:P0=CYY03@jZ<0`^:F0<GUV@3:iIP0g_>X0<SA
SP2;Se@0cmZN0=CXZ@34gYd0c^j[0;kMVP2S^GP0WK5b0=S][037gI`0e>nZ0=C^Y`3RjjX0KgXh0=3Z
X`3AmZP0b>BG05=?4P2g]7l0nOoX0?Kol@3ooOl0ooko00D0oooo00<0oOgm0?ooo`3oool00P3oool3
0?koo`0407QhNP1oP880o_oo0?koo`<0o?oo01/0o_oo0?ooo`3lnoT0ookk0?onnP3ooOX0hm_H0?Od
k`3glo80ooom0??dmP3lool0n?Ki0?ono`3moOl0n_ck0?Wok`3ao^00eNfa0<gXX`3<jil0c>fN0<KX
V`36jid0aNbM0<K[W@38jYd00P39jId01P3:jId0bNVM0<SZW@36jid0aNbM0<SZW@X0bNVM01`0`nN@
0=3bW03Gj:@0h^Za0>oba@3oon<0l_GP06MbI03`n^l0n_oj0?[on@3loo/0oOol0?oko03jn?T0bLC1
0?omk`3hon80goK20<C7V037W7`0WXQS0=_b^P3GnK`0g?no0=Kg/P2ogiH0b>NK2`3oool000X0oooo
00h0_n2I0<?OU@3JlJT0bmnG0<oUW03;iid0`=^D0=?^Z`3DhJ/0TYEV0?Cgc03DikX0ooof0?_en@80
o`000>00JkBP02EjI`3]ool0oo_o0?o_n`0P6@T0B3he0?olnP3ooO/0oOgo0?Wlo`3io_l0nooo0?co
o`3jnoH0oooj0?kek03ono40UhIn0>cOe`3oooX0m_Kd0?coo`3kool0o_oo0?ooo`3ooOd0ookk0?ko
nP3onnl0ook]0=kU_037h:T0`NJP0=Kd[02//g00FE/L0=3PX@3@jJL0c>ZZ0<[RZ0003`00e=Z/0=gQ
[`1lRdX0U:YQ0=3_W`35i9H0`mjG0<[XXP34iY`0_]VB09^_JP3>gi/0iOBa0>Sl]`2kd8/0g^n[09n[
J@1eMcP0c]2A0=CSX03BgI/0fn6Q0=WOW`0?6P00cnBO0=3[Y031giL0a=nH0<WMV02?WU/0b]VF0=g^
ZP39lZH0b?:V0<kOV`2j]WT0JF<W0;kITP3<mZX0U:1N0=KQW@3<jid0cnFM07^3B02_]7X0S9EF0<cL
U@3?jY/0bNJF0=3/X@3>ijD0bMVX0?onn`3iloD0];:e0=KFeP3oooP0oooa0?;dg03oonX0inG@0;:/
WP3XiM80g^Zl0=;R/@3Bjk40a^>S0<[UWP3CjZ80_=660;oERP3Lnjd0aNJG0<CYV`38kZ<0a^ZP0;gQ
U`30i9X0doN]0=3TW`22UU40Rj1K0=G/YP31f980RZ5K0:W3O03Aj:80fO2Z0=ke[`3Bij80Oi1<03I:
1@26VeP0`MZF0=Oe[`36iYd0aNFJ0<[YW@38i9T0cNRK0<[VV@3Nok40bnZL0=?]X`31eHh0e^bT0;WK
T@37kjH0[M^B0;?QV@28]G00`NJS0<_ZY02ifI00dO6X0;?=QP2CYf80f=jN0=CIV@15B`/0Phm=0=7/
Y@31hIP0b^ZQ092LFP2TZFT0h>FS08^HDP3<gIH0e^>M0;>dL02AUe40`mjA0<[VV@3;f9<0h_6/0=KK
V@2PRU40/ZY/0<oPVP3Ejj<0am^D0<GUVP3Cg9T0^l200<oRXP3Un[L0`mZB0>3j/037hIL0_mV@0=K]
Z@3BhJH0d=fX0<S?X`3fn]T0ooof0?kok`3_om80eNR`0=3VY@3Ln:d0`MfB0=?ZY03FjjP0fNb/0?Oo
c@3Fl:l0jnnb0<C=U03@jJP0^NZA0;oVR`39jId0anWA07NWV@2]jK<0/nRR0=K]Y`3;hY`0ZL1j07>:
A080b^6K04`0d^VS0;kES`2P]g40iObf0<;IT`34fY80d>NO09VcJP3;hY`0cMbI0<[CTP3TjJT0FV0P
0=?OW@33fY80cNVN0<;UU@2ffh/0bNZK0=_g[03<g9D0iNj[09FGEP3Jgid0b]VF0<GJU@3Um[80MgDh
06AT9P3Sj:H0h>NT0<[WU@3<j9/0b^RN0<SUX`38iJD0bnFX0?CocP3=gj<0e=jO0=oXY`1mQT<0CUXH
055J6`2?UET0gn2W0=cOZ03Oi:`0fnJ^0>?^]P3UiK40iMn]04U2302Z]G<0dnZR0<?OU@3?kJ<0`MbE
0>3g/@2LZfP0joNe0<[MV`3Hkj/0^mVC0;oJU`1LIRT0h^b_0=[c[`37k9h0cNVL08n9C@2OVFL0joSL
0?WomP3km_d0ooko1`3oool02@3lo?`0oooo0?ooo`3iool0nooo0?coo`1mPH80MWYk0?coo`020?ko
o`<0oooo01X0ooko0?kmn`3mo?P0oocg0;bg/`3oo_X0n?G`0?ooo@3knoT0o?oo0?Chn`3ooOl0ooWo
0?olo`3ooOl0noke0?cok@3Fj;@0b^2R0<WTW@39jId0anVL0<K[V`35k9/0b>^K0<WZV`<0c>RK00D0
b^VK0<WZV`36ji/0aNbK0<K[W@030<SZW@L0bNVM01`0a^jH0<cdWP3Pmk40_<Z=09jWLP3_m/`0n?oK
07N9H`2caIl0hO?;0>Whd@3oonl0ooof0?_nm@3ioo/0hn;N0?obj`3oonX0/m>T0=?V^@3oh<H0VGIP
0<WHW@3@l:L0`^:I0<OWW03?kj<0`^>D2`3oool000X0oooo00d0_o2Q0;oQU@3Fl:L0fNZS0=C/XP3=
mZX0]^:G0;oZX`3HjK<0UYM[0?oge03/o]P0o_ok00@0o`000300Pn_@0>g^o`3jmol0o?Om01@8001G
BT80ooGc0?omo@3ko?h0nooo0??koP3iool0o?oo0?koo@3Yj^@0ookd0?o`iP1EA3X0^ZfT0?olm`3i
nOL0o?oo0?_oo`3nool0oooo0?omo@3oooX0o?of0?olk03onn<0eMja0<cUZ`35jJ40do6Y0:ndLP1>
CQ00c]bN0=K/[035i:40c>BX004B003=dj<0g>>_0<gNVP3Hl:@0cNnK0<kaW`3InJh20<g_Y@1>0=3[
Y02;W5P0i?>`0=3LVP39fYH0eNVT09ZYIP1QK2X0eMFG0=[LW@3Dhj00hNbZ09bRHP1kQ4<0dmjL0=CY
Y03<ij00dNnW0=OaZP2lcHT0X:m/0<kJV03Hij@0bO:V0<C^XP3AhYh0em>F06MQ9@39i9d0ao6U09FQ
G`3Ii:00`=nA0=CZXP2f_X<0W9mV055J6`2FXed0bn>E0<?NS`3Fl:H0b^>Q0<cLZ`3bl^X0o?_g0?Og
n@3nool0nOce0?Okk03oonX0lOCI0?Wih@3]j]L0n?SL0=_YZ`3;gIl0b>FU0<_YZ@3El[00eo2^0=;Y
X@3<i9P0bnfG0;oSR`39kiP0a>RN0<W[X@38jZ00a^RN0<CVW03Ci:00bmbH0<_OVP2@YF00UZ]V0=7X
XP3GkZP0e>^U0P35g9H0Z`3@ij40f>jV0=of[P33gIH0Q:9L05Id;P3>jjP0c^^Y0=O`[`2oeID0b=fL
0<OMW02kf9H0f_F`0=G/Y038gHh0ennK0<[^UP2ii8/0_o2O0;o_Y@26/g00anj_0<OXX`3EmJ`0`n>J
0=oi/P2cah80emfM0=gOX01MHb<0MX900=?]YP35hi/0b^RN0:W0N02Q/6/0inNW09VADP3cjJ/0`k]l
0=[QV`3EiI`0fOJV0=GdYP3?kJ<0`>2E0=_aZ@1DC0h0WZER0<[/X03:l:<0`>:F0;_/V`3HlZT0e>FQ
096TI02Z_G/0c^FM0<kXWP3:i9X0f>nW0<CKU@3DhjX0dmf[0>3U_@2@T7H0oo_j0?ool@3Nk;L0dnRU
0=7YW@2cch80TJeR0<WOWP3Gk:/0^LV:0=3VY@21Ve`0GUdT0?Ge`@3@hZH0c?fT0<keVP3Hmj/0g??Q
08jcZ`30n/L0^o2/0=C[Y@3BjJ<0a]fG08VPFP3:hI/0c^FO0<oVX03CjZ@0bN2J0<cSW@3>j9l0fORX
0<[[VP24Y5P0jOnk0=OXY03Ylk@0dmBJ08Z=E01MIBX0e>NW0=cg/P39mJ00aO:M0;GOR`30iID0fO6U
0<WITP2OYV<0fnBQ0=7UX035giP0d^JQ0=oEVP36_H80LVh_096AD@3<iiH0bnJI0<_WW@3<iZD0cNFW
0<kSZ03`olH0h>^_0=SMW@3@dHl0TY=?0>W^[P2e]W`0ZZM`09R@G`2KUFD0X9i]0<32T`3If:X0hMF[
0=G3V`1QDb@0g>NS0<GRTP37iYH0d_6Q0<KQU03:h9L0T9eH0=3KU`3<h9/0f>nY0:k=Q`2A[6T0_LN;
0=[VZ031fYH0]mb>0=ObY@2XXVH0b/BB0?Cnh`3iooH0ooSo0?ono`050?ooo`0<0?Win@3oool0oooo
0?Cdm03`l?00lOOg0?Woo`3kool0OH:506mcMP3lool0o_oo103oo_l06`3hn?P0ooom0?gln03dlN`0
al:n0?onnP3im_40no[h0?ooo@3kool0o?oo0?omo`3on?l0oo[o0?olo`3mo_P0noo/0=[Z^@3>i:H0
cnRT0<OWW035ii/0a^^K0<G/V`38ji/0bNZK0<cXV`020<gXV`040<[YV`39jY/0a^^K0<G/V`80a^^M
1038jYd40<WYW@0M0<[YW@3;lZ40a^fN0=G/Z024TUL0V:9]0=?L[@3<fJ/0MH]J092WL`3AiK00cN2Y
0?oojP3mnnh0loW]0?Oon`3oooX0onOS0?okj03>lLL0gOK>0?o^g03ogM00WZ1a0=GTZ@3GiZ/0bmfO
0=CXZ@3?iJ@02`3oool000X0oooo00d0fM>Q08ZPH01mVUL0[/9k0<SIT`2oiIX0b?2Y0<[VZ@2h[XX0
EdP[0?oojP3noN/0k?oo00@0o`0001L0jOoo0?ogoP3ol?H0oo[j008:0017ACP0ooO`0?omnP3gmOP0
nOco0>[hn`3dool0mooo0?Ooo@3hn_D0ooch0?oim01[FU<0a[ff0?cnn@3`mO40o_oo0?ooo`020?on
o`2Q0?ooo`3nool0mogk0?komP3cn>@0cMNd0<_J/@3Zn/d0nooL0:>ZP02FVg80f^>d0=?Q[03AiZ/0
dN6`000800011@00L7I@0<oUY`3<j9h0b>^G0<S[V`3:ij@0c>NT0=C/XP3EjJ80^<F00=cWX`3MjZD0
bMjI0=gg/020VU<0PIIC0=GQX@3<gid0`N^O0<gfZP3?mJX0a^ZP0;_MT`30fi@0d^bU0=CSX023S4/0
h=jQ0>GWZ038h9H0d^VQ0;kJT03AkJ<0d^JO0<kJV01EH1h0e^NS0=CWY@2c_Gh0e>>P0;_PT`38j9l0
cN2N0=?OW`3Rj:X0K78b06E`;P3Pkj`0d^:Q0=CXZ@3=hZT0i_KB0?Wok03go?H0o_oo0?cko`3noOl0
m?Wb0?Cok03honX0b^6e0<cSZ`3Bi9P0enZZ0=KW/028UEd0GelQ069I801fGcH0Abl;0:2>GP2YWF40
WiiK0<KQVP3=jj<0a>BK0<OWWP34j9h0bn^Z0<_XY@3BjjL0bmbH0>Se/03Hhil0en:P0=SSX@3:fY`0
enV]0<[RY03<jZ80bnZN0<gYWP2mdh/0Y[Ma096PF`2FYF80T:5M0:RlM`3=hYd0cMfL0<35R`2b_Wh0
d>BM0;oQS@3?li`0b>VB0<o/V03:j9h0cNjY0;_PW@2lkJ`0]^nZ0<[TY@3Ag:00Z:e[0<SITP3;k9/0
a^FE0;RoN`27Pd@0`kf30=oOX`3PjjT0Sj1L09f/J@3Ii:80[kQg09>NG02FYF00an6H0<_YW`3<kZ80
b>RO0;gDT03CkJ<0c]^C08mmC`2QVgL0d^Ri0<WUZP39kY40`oNC0<[XWP3?i:<00P3<ij80L@3:j9h0
bNVM0<WYW@3>k:H0b^FR0=GW/`3AhK80g^S30?_oh03Kg;`0al^X07J3CP29Vel0]/^60<[WU@3<jID0
d>fM0>3j/@3Tn[`0c>VW0<C`U`38jYH0dNVO0<gWW@38jIX0bnbK0<SZWP3;ml@0[^:k06BXP@2em<T0
fOO30<SOZ@3LiJ`0RY=D0=OTW03KkJ40ennQ0=K/X@39f9<0EePL0=GKW@3:jZ40a=jG0;W8Q@17Da40
hO2]0=7UX034fI@0f^jY05=O7@3<c8h0h^^X0;[WTP33mYT0mooH0?koj03VjmL0fmnl0=77X`3oomd0
f>[20<kOZ03EiJ@0gNZU0>3YZP3EdJ40eLVQ06E==@3fhkP0mnFg0:BBK02bXG<0F4PE09J9G`2dYhD0
Ee0J05]G6P3Oh:L0eMnP0=OSY@3Bfj80k?G00?KocP3do/`0SiUW09jVL`1/JcD0JV<]0=kHW03JiYh0
d>FH0<gRU`3>hiP0DV8K0:RhL@3Xmk80a]FB0<WNV`35gYX0a^BL0<c/X03LmZ`0enjV0<_RWP3;gJ<0
e^:`0?_jf`3oon`0ooom0?cko`3hm?l0nOSm0080oooo01T0l_;b0?ooo`3moOd0oooo0?Cdm01cLg<0
PX:20<_;b`3Ee<l0b<S009^KT`082000=3D_0?[km@3ooo/0nOWg0?[jnP3oool0moKk0?omm03on^/0
dlfo0=SDb@3oooP0oooj0080o_oo0`3oo_l20?coo`80oogo01T0oooh0?_ml03Ch/<0aMZ_0<STZP3:
jIT0b>V@0=G[X03AkjD0_O>O0;cQT@36iiH0b^fK0<G[V037kYd0^nRE0;g^W@3@iYh0bnVO0<CZW@31
iYT0_^>F0<W[W`3CmJT0`n>H0080bNNM01h0d>bR0<cXWP2W`Wd0R:5M09:VH@3Gj:@0e>>R0=;OY`3A
gZT0HW<o09RYL`3Om;<0c^>N0=7QX`3EjJ`0aNFR0<k/[03_ol/0e<fa0=c?_`3_mn`0oooh0?oSi03o
mn/0M6i>0=gI]P3Ge;D0oooZ0?kok@3ioo<;0?ooo`002P3oool03P3ok/D0cn>V0=gl^@3DjZ80dnBM
0<c`YP37jjD0b]bR0:2=K@2?Nf80moWT0?oik`3Wool0Ol?40P3o00000`3Yool0mooo0?omn`020?oj
nP150003001?CD40oogd0?gdk`3ooOl0o?go0?Goo`3dool0kO_k0?Woo`3noo/0oo_h0?ohmP1WEE40
jN3K0?con`3ho?/0o_oo0?ooo`3ooOl0ooko0?koo`3lool0nOgo0?con03foN/0h>[80=GO^P3Vl</0
mooL0:F_RP2PZ840g>Ff0=GS[P3IkK80`<fO00XB00062`00J6m=0<oTZ@3:j:00a^bG0<S[V`3<iZD0
cNJU0=?[X@38fI80U9mK0<cGT`3Kj:<0fo:/0<OQVP19I1d0U:]W0=o_[P37g9T0`>VM08:[G`2bfhl0
boBX0=7eZ`3Dm:/0g?J_0=7PW@2FXEl0f=ZK0=?JU`38i9T0`=Z@0080d>NO06l0dNNO0=W]Z033e900
cm^I0=WUY@2nb8T0e>BS0<gcZ03<kZ@0c^FO0<SIU@3=eYL0SI=E065Y;@1>FQ`0i?:d0<CHV@3GkJl0
amR/0>cje`3nooH0ooom0?_eo`3oo?l0o_ok0?_om03aon@0_=NT0=G_/03[nk00a=BF08^HH`1EG2H0
eM2@0>OFWP3M_9d0]99i06Q;:@1^F2H0GE<F061d;`3GjjH0`mZD0=C^Y`3Ak:D0a>NW0<[YY@3?j:@0
g^fX0<?>R@1]LS00DEHD05YP8P1]N3h0dn2X0<[OY03:jZ40bNVM0=3/X@3JkZH0e>FN0=CQV`3Gi9h0
aMVA0<[PU`3IlJL0dnNP0=OHWP2AVe`0eN^S0<;YUP3:lY`0bNVF0=7/W@3Aj:00c^^X0=Sk^@2EbXH0
[^bY0<KRY`3Uk[D0]KEe0>Cf[031jiD0bO6K0<kJTP2UXF80n>Rd0=gDV`3CfI/0^LF30<gIU`39f9D0
enRT0=3UX037hIX0d_2X0<WYX031iI/0`N2J0>[m_@3;hIP0hnfV0;bSN`2eYh`0gN_70=7X/03:k8d0
`OB;0<cXWP3@i:D00P39jJ00LP38jYd0a^^K0<SZW@34iY`0b>NS0<gV[@3EjKH0l?oG0?[og02<Tf00
EEd/0=WW/P3CiJ/0`mVH0=7^WP3>jiL0c^^I0>7m/`3UoL<0c>VY0;o/T@36kYP0cnjP0<kZW`39hiT0
f?BY0<KXWP2]gIl0]nfi05bNNP2Xi<80/M:W0=[aa@2IXVd0Ff4U0=gZXP3;h940a^6@0=G]W`3Hj:40
JVP]09VJGP3>k:H0c>6N0<oHV@1kQ4<0cn2L0<gTWP3DlZP0dN^R0<OGT03/j:P0d=>@0;kYU`32mIT0
o?oQ0?chk@3dl_<0fm[60>7?^@3ooNX0iOGJ0>3^_@3?gj40b>:S0<KKXP3Wk<@0oooR0>K<_@1MB1d0
JeHY05Q3901QD2@0]ZIe0>oS_@3oon@0j^^b0=3FUP33dI@0cNJR0<gSXP3>h:80l?W40?;jb@3Xl/00
cmfX0=3OZ03JiZP0fN:Q0>K`Z`3;gI<0d>FJ0<cQUP3EjJ40c]nI0>_j]@34eHl0d^JQ0=O/Z@3Ek:P0
cn^Q0<WZV@31h900_MN=0<OLV@3>fZP0f=nf0>k`f`3ooo@0ooko0?KcoP3ooOl0ooko0>SXj080oooo
00D0no_k0?ooo`3Bd]80Jf][0?;blP020?ooo`0B0?onm`3elNP0o__b02XW7P0=3@D0ooog0?Kel03o
ood0oooo0??cm@3oo_l0oogc0?ohj`3oo_<0o?G[0?oonP3mooX0o?oo0P3nool0?`3oo_l0oogo0?Ol
o`3kool0ooom0?onnP3oooH0o_od0=?Sb@36g[X0bNFd0<KUU`35iX/0cMnE0<7KU031n:@0a>VK0<GT
U03=kYd0anfJ0<7XU`2jjYH0`oBS0=3OW03CkJ@0`>FH0=;gZP3Fn:`0_MfB0<;RU`3EljT0c^ZP0=7]
X`32g9<0d^bS08FNG03>ij<0a=ZB0=?WX03?hi`0cMbQ0>?b^`0W>0@0f>Vb0<3GT`3<iY`0b^6I0<kZ
X03:lJ00anZJ0=?]YP3SiKh0c;n^0?oon`3omOL0ongf0?ojkP2SW880img20>_Uc@3in^`0mo[_0?Wo
o`0;0?ooo`002P3oool0E02YWF/0b=jM051a:P3Fl:H0b]jF0<KVW@38iJ80fNJ`04Db4P2SSgH0jnkK
0?oonP2Cal<0@HJ30=Goo`2Lb=D0`]_R0>Clo03WooX0j?on0?;oo`0D00L02P000?omm03oo?P0oocm
0?gho03fo_l0mooo0?Woo`3moo`0o__f0?oim@3on?@0Lf5M0?omn03kooX0nOgl0?koo`3oool0oogo
0?ono`3nool0o?oo0?koo`3moo80o_o/0?gog03Zm/P0j?C40?7ocP2W^8@0^/^D0=?UY`3<hJ00c>BX
0=SZ^P001`0000@006ieE03?i:T0b^RP0<K/U@38jiL0b^RP0<cWX03<j9d0c^JL08^HD`3EhYd0d^6L
0<oVX03@jZ<0T:YS09:WI03EhJ40cMJG0=OPW`3OjZP0c]nK0=K[YP3?jJ80bNVP0<KXWP<0cNnU07@0
bNVN059^8`1BK280d^VQ0<ONUP3Aiil0a]^F05=W8P3Hk:L0e^JU0=?SXP29WEP0a^:H0=kh[`3=i9h0
g?6/0=o_[P3MkJ`0c]jO04aL7@0;6`00bm^L0=SXZP37dId0eMbb0??^f`3oo?H0ooGj0?ojo`3gk>P0
ooo_0?ooiP3Zl/<0aLjE0>C[Y@2PZVh0TIiX0=kY[`3Jgi`0clf@0>oTa03on=d0e=Ja0<oIY03SkJh0
I5hR04a82`081P00e=:E0=[LW@3IkZd0cn:P0=KZY@38eI00;cX0096FE03IgY`0cm6B09bMI01bLS`0
h^Z_0=;YX`3;jil0cNbP0<KUV@35i9P0`N2D0<?RUP39jId0anNK0<CTV03@k:80d=nN09jcL02lfY00
_nZH0<?_VP3CmZ80b>NG0=G`Z@39jZD0]MZE09;3P@1ITTh0`>RY0<7NWP2?X5X0`]Z@0<S_W02mii<0
an>H0<kMV01?APd0kNN]0=?IV@2IYF<0DF0M0=3QW@3?hih0cNBN0<OQVP3?jZ<0a>:J0<OYW`35i9h0
c^2R0<7FT@3TkJ`0FClJ0?onh@3PklH0e>bb0<SYSP2okXh0c>FQ0=?UY`80bNVM06l0a^bG0<G]U`35
kID0`nZG0<ccXP2mgYL0`n:O0=C`]P35gJ40enbQ0=S/Y`3AijL0dnb[0<kYYP39iid0dO2T0<_YW`37
hYl0c>>[0<gT[032fiT0cNJU0=;VY`3Ej:P0cn>N0=?[X@3Bk:80@F4N07fPIP33jL00QZ^908BRQP2I
/Y80b=^^0;W@VP3Dljl0a>fQ0;oZVP31j9T0b^RN0>;]Z@3:ei80bnfQ0<CPUP3GiZ40fNRS0=CZXP32
g9<0cNVO0>?j/P3BhI`0EeHE09nQH02lh9H0`>fL0?coi03ooO@0ooko0?oomP3ji]l0oo_d0?Gol@3k
on<0fNZn0;gM]P3<j/H0m?o_0?Gol`3Yo/D0a]jD0=GZY@3<gK40cMn_0<kR[`39gkP0l_oZ0<3TW035
kIL0dOj[0;c`W@35jj00e_6/0?ood@3oolh0lO?10<GDW@3:i:D0`nVP0<7/W@2eh8h0e?V[0=7aYP3@
l:D0LY160<KPU`3FkJD0cnBO0>Gj]@29WEP0BEdH0<gSVP3Cki/0iOj]0<WOUP3YnKX0FV4e08fAKP3o
onl0o_c`0?oon`3noO/00P3jn_X03P3oool0n?Sh0?ooo`3lo?`0oooo0=[JfP3inOT0no_k0?clo03o
ool0l_7_0?Ofm03[j^P0QhJ40P3o0000303oo_l0lo7b0?ono`3mnoh0ooko0?ojoP1HC4h0ooco0?om
o`3gm_`0o_oo0?coo`80o_oo03l0oooo0?ono`3looH0m_k_0?Kmj`3oond0noo`0?Wol@3hoo40lOo/
0>cohP3<jZX0aNNM0=G_Z032fI<0`=bB0<[PU`3IkZ<0goJX0<[RU039i9L0c>RM0<[TV`3>gIX0enfT
0=C^Y03IljT0e>^S0<gSV`3GkJD0f>bW0=;VX@2fbXD0Z[]g0=3PW`37iId0_MfB0<[YV`30g8l0dNfR
0<;KV@3UoL40UJec0<SRY@3@l:D0bnbK0=C]Z@35hYl0_>FI0<[_X@37hY/0hNNi0?G[d03goO40oogk
0?W3d03onoH0bl2/04`m9P2AQW80ooc`0?oon03ho_`02`3oool000X0oooo02X0cLR@07F?B02ff8`0
dnnR0<WQU@3AkjL0bnBR0<oIY01NCBl0^:J>0?kol03iool0JJBN08K7``3Yool0kOgo05Y_L02[b/@0
g?oo0=7onP3Pooh0GSe>01420033^K00ooG_0?oemP3mmo/0o?oo0?Gno@3lood0o_gi0?omnP3on?@0
oNCP0=K4`03ooOP0o?ok0?[no@3nool0oooo0?omo`3oo_l20?koo`2O0?clo03knnl0o?oY0>7Z_`3J
i[@0dN2Y0=GT[@2BYV/0_=2A0=;YX@3?jJ00eo6d0<7EY000200000@006I]CP3?i:/0b^RP0<K/U@38
k9D0b^VM0<[XWP3=k:00d^bR092OFP3Ij:<0eNBO0=K]Y`3;iIh0W;=]0723@@3OjJX0e=ZL0<[?S`3K
hJ40Gfh[0=CXX`3CjZ@0c^bT0<GWW@2ohiT0_>2F0;WMT`37jId0`M^A0=;/XP11Fa80VkE/0<oVWP3M
m:h0_]>>0<_PV`3Om;40dnRU0=;WXP1^Q3`0Ykee0<kUW@3BjJ40_mJ@0<ONVP3Qm[<0Q9UF01d]003=
gIh0hNna0<_BW02PXgH0MfmJ09F7O00b7R00J5=H0;BRWP3oo>l0oooV0>;O]P3ln/L0blj;059G7@3B
gJD0dMnR0<cFT@3Fg9h0l?7A0?oojP3Jj/D0iOk70<WOW`3akK00m_:e09fIG01EDaH0XZ9T09FTH`2;
VUL0VJQS04aK5P1_O3H0h^^X0=[QWP3PhZ<0fMNN0<2kQ02JVF00cn>L0<_WW03=k:00a^RK0<SZW@39
l:40a>^L0<[_X@3;l:80b>fO0=;`YP3;h9d0`=VE07fOD`2mj9H0b?BO0<_^W03:jI/0c^bT0=Wh/P2e
f9@0]^>R09W=R`2kjJP0c?>`09VcK03Aj:00b^fM0<?ZV@30iIL0goJ^05YD6P3>aH`0emfM0=WXY@2P
[f`0d^>O0=__ZP3BjJ<0cNNP0=C_Z03;jJ40bn^R0<?QV`3KkK40fo2]0=?LW@3^e:l0oooO0=KW^P3>
iZ`0c>ZD0<;_U03=hj80dn:W0080bNVM06d0a^bG0<G]U@35kI@0`>^B0<K^V034jI/0a^ZP0<k]ZP3:
j:80`MZ60<WQT`3Ak:L0_]^I0<?RW`38ij40c>bS0<WYX037i:40cnN]0=;W[P3Ei:d0e^F^0=7PY`3B
hJH0cn>N0=[^YP31eh`0_=>?08:JGP3Cj;d0e>c:08nXT`17GdL0cnO30=7^`02egil0]nJP0<3cY031
kIh0`^NJ0=_/YP2odh/0aNZL0<GTV03=hiX0f^jV0=3XWP3Hm:T0c^ZO0;kFS036ei40F5PH09NLG035
hYl0`>ZN0?[oi03oooD0o_oo0?onn`3YdM40ooKf0??olP3ionH0jOSA0?CoiP3eonP0m?oZ0?;njP3B
jjL0c>RC0;gEQ`3gom`0en^h0>;f``38gKH0m?oZ0<;TVP3DnZ<0`nJD0<cXV`37iI/0anVO0<ob[P3=
kJh0b>BW0<GIWP3>hZ<0_]jE0;gVV035mZ@0_>:E0=7cZ@39jJ00SJeT0<OUW@35h9T0fO2Z09>XH`3=
hI`0cMjJ0=OXX@39hHd0a=V:0<gNV014DQL0i^c60?Kig03ooo<0m?CZ0080oooh00/0o_oi0?clnP3o
ool0oooo0>WYj@3oool00P820?knoP3emOD0oooo0?Cdm0040?ooo`@0o`0000X0oocm0?ono`3oo_l0
iN7R09nFV`3on_l0h=WQ0?Wco@3kn_l0o_ko0`3nool0?`3oood0oook0?Ool@3Nl]L0fnS>0?Gcg03m
on/0ooo_0?ool@3eond0l?oX0<S[/@2hij40^=VB0=G/YP3Ii:00d^:K0<[JT@39fI00eNNM0<gNU`3K
k:D0g>NS0<WJUP33fI00cnFJ0<kTV@3BiYh0f^jW0<kRV`36ei<0UZIU07:2@@38eiH0dMnQ0=Sh[@2a
eXP0`nBE0<WZV`3FmJT0HG/j000>0031gJ<0c^b^0<_]X@33jIH0cnZW0<OTXP2miid0bNjP0<cZX03D
g:T0aKnM0?_ol@3YiM`0o/cH0?oem03ooN`0FDPd0:6DP`3oo_@0oooh0?coo@0;0?ooo`002P3oool0
:P3=f9@0an>H0=;eY@3@lJ00dNfP0<WPVP3GijP0g^Fa06IL>@2dZHd0nooc0>GooP0LD4h0`^[Z0?GY
m`3gk?@0mOom08VYVP0[J5H0Kk6S0:7?c@3jjoh0?S@c04m5?03bin40ooCd0?ohn@3oool0nO_h0?oo
n`3ooOT0ooSd061;B02FOGT0oo[f0?ojm@3loo/0nOgl0?koo`3oool0oogo0?ono`80o_oo0180oogo
0?onn03oond0fN2g0=gW]@3NkK@0d^BZ08RQG`39i9d0a^FE0<SYV034hZ@0f>jm000=00000`00PXQ^
0<oS/03<iZD20<S/U@2;0<[YV@39jY/0b>ZM0;cKS`2;WeP0`mN@0=;VW`3Aj:80e>jW0=;YX`2M[F`0
Z[1b0=OQXP3?jJ80bN>L0<[TW@1oVE80TZaU0=ke[`3;h9/0f^jY0<SLU`3;fYL0e^NQ0<?KT@36gY@0
b^BK0=cf[@2;YE`0QImH05]f;`2<Yf00b>>N0<COVP3CjZ@0jOB_08JFC`3OmZh0f_J/0<?SVP34iY`0
eO>]0=?/Z025VUL05B@005eY:`1lQ4/0e=NX0?ooi03oo^`0ooWh0?ogn@3_emL0Yi:=099oL@3oo><0
ookK04mC5P2W[WP0ho6f0=CUX@31cXH0b=:E0?OkhP3gonl0l_o/0<_[^@3Ool00lOo20=3WX@3Wo[P0
`=NA0=gb[@3BgIP0d>2I0>Ce[P2oeHd0fo6Y0<gQW03ZnKP0am6B0>OUZP3Qfj40ViEI0=KMVP3=gYL0
e>ZQ0<SXW034jI/0`nbM0<?^WP32ji`0aNbM0<W^X039iid0d^bU0<oZX`1CLBL0a>NG0<_^WP3=jI`0
f?>V0<cVW`35gYX0b>:Q0=?a/`34iZX0Q[Me0;W[Y02eeXl0Rj1K0<kRVP3Ckj@0_^VJ0<CVW03^iJ`0
HEHN0::WI`3KjZL0jORe07jBC@3>hih0eNnX0<_VW`37hY/0aN2I0<;MUP2`bHL0UJA]0=CU[P25S5T0
ckNE0=cD[`3@hZh0bn>U0=3ZX035kZ00cn2Z0=OQ[@020=3UXP1^0<cXV`3:jIT0bN^G0<[^U`38k9D0
b>^K0<SXW032hI/0`n6G0<3SR@32hi80bNVX0<;TY`3Dm[X0eoZh0=7b[@3<k:40c^bR0;kHT@2fbhP0
ZJid0:nhO`3Kjjd0e>NW0<oUVP3Aj9P0[/Ab0>7^Z03=eIX0Xj5j0?7ae`3AgM/0WJbU05QaG00lGD00
[]f_0;S[/`2ml:d0`>jV0;gSVP33fi40TJUM0<7WU03Am:80b>NG0<[YV@2:YUT0cNbP0<7MTP3EkJ<0
`M:<09NNF`1FG1`0e^VY0<[[YP3FhkP0kO?I0?_on`3ooo/0kM;G0?oemP3aonT0jo_G0=CT]`3BhJH0
cmfR0<gGX`3AfjT0anFO0=3]T`3Glih0enf_0<oTX@3EjZL0c^2^0?Soh`39hYh0bNFH0<7LU@3>jI`0
d>JM0=7WW`3AjZH0d>fZ0=3`[@30j:80_]nJ0>3_[03EfYP0Y9iP0:f^LP2a^Gd0c]RI0<SGUP35fYL0
g?>_0<KMU`2=Y5`0dnVQ0<GKT`31eX/0c]n?04aI502T[gD0eMf^0?ook@3ooo@0ookl0?ooo@3oooX2
0?kom@080?_lm`3oool0oooo0?clo00H61P0f=SH0?ooo`3Ti>@30?ooo`030?koo`3emoH0inOW00@0
o`0000T02PL20?onm@3=bKh0e];70?gml@3kno40oooj0?oon`3em_P00P3nool20?ooo`0o0?ooo@3o
oo/0nOo_0>3]d@3Aek/0aMnj0>oWdP3oon`0k_oZ0?KhhP3[k/l0`nnb0<C]Z@2fgYD0b^>O0:BNH03J
iJ00[Kme09JXGP2?WeH0NXM109jSH02TXVD0JXQ208BPE@28WU<0OiE:09>YH02X_7D0TZIQ09JYI`3N
kZl0cmnP0=;RY03=gIl0_=ZD0=Og[P35hi/0f_F`0=oj]`004@00Fg520>7gb@2cbi/0g?Zj0;KFS@37
hYl0b^VU0<OaY@31j9L0a>FD0=SWY03Ph:X0j_SD0?oojP3ogn@0oocj0?oai01RCd40_J^O0?olmP3o
o_X0o_kl00/0oooo000:0?ooo`0Z0=3TW032hI<0`nJF0;WLRP3=kYl0e^ZU0=[VZ03JgJP0L6Y60=_F
]P3hoo40e?_h09>j_`3Zool0ooCk0?ojo@3_no40kOok0=?on@1m/:/0;EAI0>[]o02GUiD09b0H0<g2
_P3ono/0oocm0?glnP3knoT0ooki0?oil`3oo?P0OfMU0=:i]@3ok^X0ooSc0?Smm`3bm_D0o_oo0?oo
o`3ooOl0ooko0P3nool0;`3on?l0oo_g0?ool@3Xk/P0j_?60=[[]@3=hJH0QZ1O0<g[Y@36iiH0bNbJ
0=7a/02kdj4000d000H9001lOfX0d>:b0<gUY`38jiL0bN^E0<[YV@39jY/0cO:T0<g/X02^a7`0e>RQ
0=[^Y`3=i9h0b>:K0<oVX02[^gX0PHM90=CPX036j9h0a^JM0<cZXP3CkZL0d^bU08VMF021TTh0dmnM
0=?NW03Fgih0eN2L0=kf[03Cjj40cNNN0080dnfT0>L0f_F^0;cGT03JmJh0bNNQ0=?aZ`3=i9h0c=JA
0>Od[P2CZV80aN6G0=7cZ@39kJ<0b^VS0<COVP3FjjP0i?>b0=;NX03<eil0oooF0?ooi03hlMh0oo[g
0?ohnP3onO/0ong/0;BQVP3omnL0ooWM08V>EP3EgZT0b]ZL0=3QV`3Vm:T0d]ZO0>c^f@3emn`0moo_
0=oic02ngJ80]MV?0<W[X@2_dHL0e_R^0<?UV`3LjJ40enVO0=;XW`3?jZ<0dnjW0=3YY`39gih0f>RW
0=GJVP3Vi:L0Y:1Q09fPG@2/^G<0aMJ?0<cXW@37ii/0`>NH0<S_X036jid0a^RK0<W[WP38i9T0an6H
0=G_YP1jU4/0`]jC0<ORU@3BjYh0b>2F0<GJU@2AYV<0TjQW0<WOX@3?j:h0DWln0;W[Y03Bljh0V:QW
0=KSWP3>i9`0aNjP0<SXW`3NeI`0Wi9K05=H603Dhj00bmbH09>XH`3CjZ@0cnZS0<WTW@3>jJ80d>^T
0<KQVP2`aXD0dMn/0=KV]@3OiKT0I4//0<:jU@3CiZh0c^JX0=;XY`36jjP0d]na0=_Q]@3DhZL0e>:U
0=3VWP3?iid0cNRK0<_XUP3;jYX0bNFJ0<cXWP3@jJL0b>>L0<g^W@3;jj80c>^`0=kob03^omX0anV/
0<_[Z02ogY80ZlMj08^VE`2=XeP0/;Uf08fHEP2AY680SjIN0:k9NP39hXl0X;MU0=GPW03Rijl0ShUW
0?C]fP3Ef=d0l_[l0>Wol`2mgLP0EH5M08JeQ`2hiJX0bo>d0<?SX039hIL0Rj=G0<;UT`3@lj40a^VG
0<k_WP1eU4H0X/5e0=[dZP3@j9h0d>6K0=KQW@2BVeP0e^6O0<o]Y`3@h:l0jO?>0?Wol`3oooP0jLoB
0?_Vh`3_on80i_K?0=3R[P3=iIT0c^BK0=KYY`3@hj<0b>^[0;gOR03<kiD0cnZS0<_VU`3Ak9/0`MVK
0=oea`3;iZ<0anFM0=3][@3?jj40c>BH0<gUV`3@iJ00c^>P0<kSXP2]_Gh0am6D06=M8`1A@PT0j]>M
0?;LZP3^hJd0i=fV0>?QZ03Rk:d0b=NF092WH@2CZV80c^RO0=;/XP3GkJ80fn^P0>7[[P3IhZd0fn6k
0?ool`3in_D0m_Gj0?cko`3loOP0oooh0?gom03oood0o?cl0?ooo`1dM7@0a<C40?ooo`3alO400P3o
ool0103inOT0m?Cd0?Cfl`3nood20?ooo@80o`0000`0oooh07=`I`2e/Z<0i>7@0?onj`3oonP0o_oX
0??kiP3loo<0m?Ka0?koo@3nool30?ooo`0n0?ooo@3ooo40nOST0=kQaP2hfk<0gMg30?koj03UonD0
k^kB0>;O_P33ijL0bnJQ0<CXX03LmK40ZJ1U0=WVX@32fY00e^bQ0=7SV@3:ei40jNj/0>;PX`2efi80
b>RL0=S`Y03FkZ@0eNfS0=S_Z@3?iZ00cnBQ0=;WYP3AiZD0d^RX0=CXZ`3CkJ`0a^>P0<cUY037gId0
c^>X0762E@3Chkh0gNg90?Ooh@3bom80g?Jg0=C]Z`36iIl0^nJG0<K]VP38jYH0fNVP06IW:`3Jk;`0
g^;10?cBd`3oo_P0ooca069>@`2XUX`0oocf0?ogm03oood;0?ooo`002P3oool0:P39jY/0c>VI0<[Y
V@35k9T0a^^K0>3/ZP35bHh0jn^e09^SM03Kh[P0kOoX08c5_`3Wm?l0noOo0?;ck@3oooH0mOgb0>ki
l@3hool0o?ko0>?ao00kK6T0goC]0001000o>cP0m>_/0?omo@3oood0m_Se0?oonP3oo_X0no3/09V4
P@1[DTh0oo;^0?ofl@3loo/0o?oo0?koo`3oool0oogo0?ono`80o_oo04T0ooco0?ojoP3Nfm80n_oO
0?kog`3Xn<T0eNVd0;KBU@34hj00`>FG0<?XVP3KnkP0dNVe0008000:2000NGMZ0=oYaP2T]H40V;AY
0<cXV`3Dl:<0`n:F0<7XV@3<k:00T:IN0=c`Z@36fY<0d^VS0<KQVP39hi`0e^^X0:F_L02GXF80[LAn
0>;g/P2gbhH0g_:]0<[KU`3;fYL0enJS0=_/Z02od8`0T:5M08bPF@2=YE/0QIeC0=kh[`3@jZ40aMnF
0<cVW`3>jJ80`mjG0=gh/`3BkJP0d^VS0>Gb[03YnK80d^bR03]J3P36j9`0aNNK0<o]Y@39i9d0bn:N
0>7a/03Chj80c^>X0<oQ[@3gon00mocU0?oon03im?40ooCj0080oo_o02D0a;Jf0;J^X`3Vkl@0g^^o
0=_^[P3NkjP0][ie09fLI03ci=d0k=gP0<k:_`2OXX<0cn2/0<W_Y036k:40_N>H0<7WW03;lJH0`]V9
0<[UV02mfHh0`>6L0<c_Z`3?l[80bn^Z0=7^[03Ml:h0k?^h0=ONV`3Ef9D0Q8M4059I5@3VmZl0f^^T
0<_SV@38hYP0cNVN0080e?2U0:H0a^2F0<OQV03AiIh0`M:<0=7LU`3Mj:<0g^^U0=7PV`3Tlk00NhY9
0=cXZ02HXVH0YkAn0<GUYP2G_Wd0QZ=Q0>7_/@3;dI<0k_Vg0<_UWP3EjZD0FU0E0;:VK03GfIX0cMbI
0>?d/02dbhD0WkUb0;oMU@3Ln[80`MbE0<gWX01;HQ`0c>2Q0>3[``3`nm/0l_;H0=k4[@2UWGH0Kh=6
0:S0PP3MlL00b^Vm0>cad@3oon<0h^Be0?ooe03`n[h0hnna0>Ke/P3Fij<0d>6M0=7QX03Bh:<0g>Va
0>Sg`03Llk/0g?;10=K_b03Nn=40e_780<[W[`3Dl[80aN6D096/F`3Fki`0goJT0=7TT`3AiYL0dnnR
0<[YV`2/cG`0[Lal0<o[WP3JjJh0eM^]0;beXP3Tf]40oo[o0?omo`3gool0l_oo0>konP2I/Y`0iO_E
0>Cjc03Wo<@0eNRV0;K<Q03VokH0_=R=0<3RU@34jI/0YlMk072?@`38gYD0dnVP0=CZXP37gID0g>VS
0;6`K@35fi<0cN:O0=KZZ`3aom/0o_o_0>G9aP3Ze<L0fo:n0;cDVP3AkZ/0]^N>0<;_VP2oj9X0_^BK
0<K``P33kj00^NN=0;oYT`3<m940aNj60<CZU`32i:P0_>2P0<G/[@3All40`=fJ0<kcX`30iiP0aMnF
0=kTYP2eY6h0N3XE07lf5@1_<@`0NDHK0?OAY02_LU<0NchO05h/1`1J=@/0XYIR09>BF@2H[6L0`mfD
0=3aXP34iiL0c>^O0;C5P@3;eJ40eN2e0?SohP3looX0o?oo0??fo`3inOl0ooko0?ooo`3ooo/0m_Kf
0?Win@2DU9@0Lg=c0?Win@3oool0n_[j0`3oool04`3moOd0n?S^0?oom03moO<0ooof0?_kl`3oooH0
];FW0?_ljP2=SGD0NGaO0<S;[03@hZ@0c^FO0<kOZ@3=gK00o?o/0?col`3nood00P3oool20?ono`0m
0?okn03olNT0emg30<gW`P3Ck<@0kOoI0?Sog`3cm<`0i^Bd0=gXX`3@fhd0aM^C0<oMW`2/ZVl0amjH
0<gdY@3=kj80bNRL0<[PV03Ah9d0f^JV0<7aY`3<lZL0^=J>0=CbZP2ng9@0e?:/0;_JU03ClJ/0anJR
0=Ke/@2M_WT0JXU6049G701MKSL0Tj5/0>3/_03>eZd0h>K<0>S[f03ho>/0o?o]0?Wog`3Bh[40f>jV
0=;_W`39lil0`NJF0<;QT`2EXUX0a<F30<SLX@3Xk/80omoG0?onm03oo?@0S7Mb07i[I@3onoP0ooKd
0?omo@0;0?ooo`002P3oool0:P36ji/0cNRK0<cXV`35k9/0aNbM0=cWY@3ViZX0iNJ]0<;@V`3Okkh0
hocN06j]Y@3UlOl0oo_o0?_onP3kooH0nooi0?koo@3jl_d0oo;o0?cno`15PGL0Y/Bl038h=00H6QL0
ooko0?oko03nood0moch0?oon`3oo_/0n_3^0;NSXP1YCdh0oo[f0?omn03loo/0o?oo0?koo`3oool0
oogo0?ono`80o_oo02`0ooco0?omo`3Nfm80nOoO0?Wog03homX0mooF0;??U03>k:`0aNZM0<_`XP3<
kJP0c^Fa0007000?2`80NGE/09FJO03Eh;D0JH0l0=kh[`2ofI00dnnU0;kSU@3BlJD0Zl5i0=;VW`3H
kZH0dN^T0<cWX037hY/0e^fY0=?OW`3IhZ<0DEHF02<Y003PiZH0cMJE0<oJV03LjjP0hoNb0<SRV`3<
jZ80d_BZ0<k`Y080e_2V04@0P9YA0<[TV`3;iI`0c^RQ0<KPV@3Ajj@0aMjJ0<SQW@3<hid0b=Z@0<3E
RP3CkJ<0eo>X0=KfZP3@l:D0cNRQ0=;/Y@3;hY`0`]JA0<oRX02le9H0b>2V0=OW`03Cg/00nooa0?oo
nP3mnOX0noGi0?olo`3nmOX0noKb0?Cnf`3bomX0fnf_0<oQU`2[/fP0gmbW0>CAc@3on?l0knCN0?gi
g03AfJP0b^FN0<KQVP3GlZ/0d>^T0<WTW@3NmjH0c>NJ0=KbZ03=kJX0bnj^0<GWZP30gj<0c^b^0<3I
U`3Ek:H0i?B]0>;YY@3Sj:D0R8m;08RBC@32cHP0f>VR0=;VWP3=iI/0an6G0<kZW`80b^JK04l0_m>;
0>CaZ`3Cf9D0gnJS0=WVX@3Ei:40fnbX0:2_KP3NjZX0UIeQ061[<`31gJ00JXY;07RBD@3EiJL0gnN[
0<3:R`3;fiX0S9QF0:NNH`3BbHh0eMZJ0=;QWP3Hk:L0`]bE05]f;`3ClJT0]]B<0>Ko^@3Il:X0aMZE
0=;TYP3Hh/00noo]0?ook`3Uc;P0S8MQ0=oe]`3:hZH0c]jg0;kI]P3oon`0ookV0:FVNP1CERL0PhaC
04eH701=G1/0h_6`0=CSXP3Bh:80e=nU0>_c`03nomH0m?oI0>Cdc`3`on<0mOoX0=S^b037gj/0d^b_
0=3WW`2?Ye/0enfR0<7GS03BjI/0cnNK0<g[X@3>kZ<0c>bQ0<CRV03GlZd0f>Jc0=OO^P3dl>@0oocj
0?ojo`3ooOl0nOoo0080mOoo0540mooj0?[oj`3jon80l_oA0<kPXP3;gY`0`mNB0=3WX@3<kZ@0`>JK
0<CVVP2`c880b=jF0=7WW`3DjZ40_mV?0=WYX03Ke900dnBP0=geZ`3RnK40i?c80?goj`3ef=80ongJ
0=3XZP3HlJl0`MnI0<?XXP37jZH0`^2T0;gHX@3Glld0do:/0=SiZ037i9@0d>^<0=?_R`3OmjT0dNJ^
0=?[/@37h:T0lOoO0=;e/@2hf8`0fOFZ0>C]ZP3:a8X0?BP0081<9034QF80]Ve=07@Y2P3oaj/0Qc0L
0?faVP37QVX0OddZ0<FcP@3WhZX0dNFP0=;^Y032iiL0`>JC0=;cY02;X5d0b]NR0=gZ_P3konH0noof
0?[oo03kool0noko0?ono`3lnol0nOOh0?_kn`3oool000000?ooo`3moOd01@3oool04`3moOd0moGY
0?ool@3dl^H0ooof0?7ai`2^[Z@0j>WK0?ook`3oonP0J6e=0=3F]039hIL0d^nM0<GKVP3Ai:d0m_oQ
0?cok`3ooo/00P3oool20?ono`0m0?con03bnnP0f^O90<OI/`3kn=D0oo_I0?o`cP3jh;/0j]RX0=;U
UP3=ji40hNjY0>7RZ03Lh:<0bnJO0<[gYP2liiL0c>jQ0<[TV`3:giX0cnJR0;KVW036k:<0b>JP0<CS
W@35i9h0b^VU0<g^Y`30giT0^=VB0<KWX0029P00d_>^0<WMXP3Fi:l0cmVW0=GN/@3EfkD0em[50?Oh
jP3ooo@0o_oa0?[oh@3Bgk<0bmnG0<GPS`35k9/0anVO0<cWX02_^gT0j>R/0<kQZ@3Ujkl0o=C<0?_d
jP3oo?H0nnWU0;>QW@3onoP0oocj0?omn`0;0?ooo`002P3oool06`33k9h0d>JM0=3VW@35k9d0`nbM
0>CYY`1GDaH0GEdQ0<[TX`31gil0f?O>000o=`3Rool0mooo0?_onP3eoo@0o?cl0?oho`3om_l0oo3o
0>gZl@3Nool0IHIo07J9Q`0010@0WZ:S0?[no`020?Woo`0=0?Gkm`3oood0ookm0;^[Z`1WCdd0ono[
0?omn03loo/0noon0?koo`3oool0oogo0?ono`020?koo`0m0?_ho`3gm_40[[6N0=KQ^@3Bgk40b=^T
0=O_]@24XF40a>>O0<GVU`3;kY`0cNfT0>?g`P002@002P0008MkN`3JelH0m?OJ0>Gd_@33eIT0b=ZN
0=7WYP3@l:@0b^JK0=oc[01OLb`0Vk5Y0<SSW03@kZH0c>bS0=;[Y`3=gI`0eMnP0=OGV@3FeYP0VYYL
04a>3`2QYVH0e^6O0<oPW036hIX0aNFL0<K_X`3Jok<0d>bQ0<cVW03Mm:`0ZL1h0:c2NP3AiZ40en^V
0=;VX@2GYfH0IWHe0=?XX`3FmjP0_]f?0=7]X031g8l0U:aR08^QF00208nUG@230;O<Q`3@ij40_]F=
07fEB`27WUP0WK1i0;[;WP3OjLh0noo`0?konP3mo_T0ooom0?Ocm03oo_/0nOkZ0?_ojP39fil0N8Y0
0>;]X@3EeIl0lN?R0?ojo`3jmnh0kO;B0=WU/`3Dhj00h>n/0<[IUP2M[6T0UJAQ08^RDP1^Q3/0:Sl0
0=KY/@3UnLH0mOoJ0>kod@3domH0`N2M0<7RV`33hiL0ennU0<OHT@3BgiT0UIaH05UP703EgiX0c=NB
0=G]X`3?kZ80a^RK0<?/W@39kYh0a=bB0=7QVP1>Da40VZ1P0=ga[03>j:40RjUS0:BmN@3AiZ<0fNVZ
0=?X[@1;HbL0BF4U0<KSX`30gYh0bN:Q0=_^[P19Ca40XZMW0=oXY@3Qk:P0dMbJ09>RG`1ZOST0a=nH
0<o]Y@3@l:L0_=bC0=7[Y017GQP0cMjJ0<WGW03lond0mood0?Cck`3M`[L0i^:l0<GKV`3eom<0nOo]
0>[ol03bjnD0oog/0<oLYP39eYh0e>NW0<oTW`3HkZH0e>ZR0=[`Z02hb8L0X[1c0:RbO@2^]XL0n_gN
0>GXb`3konT0nooX0=3N^`3Fj;P0b]bX092QJ`2a`Xh0f^Jn0>CcbP3SnLX0e>Zl0<kS^03@i[P0c>2_
0=W[^`36eZL0o?oT0?kok@3emO<0oogo0?onn`3oool00P3iool0DP3no_l0o?On0?omm03oo>P0jo7?
0<WPZP34fJ00H6D_0=KSZ`39ijL0`N6N0<o^ZP35gYX0f^jW0<gQVP39hIL0a>NG0=7VV`1LB@l0/[^2
0=;ZWP39iY@0kOo=0?[ojP3^dL/0j]Bm0=C_XP2I]FX0SjET0;o3XP2i_I`0b<VY0>[YbP3EeZh0alV8
096BD01aKS/0dm6F0>kZ[@37`iH0gMJi0;2`OP2RXV`0]kJ60>_Y/03=hIX0co6W0;gYW032hi`0f>NV
0?oH[P31P600PR`E07hV403=M680TS8V0<9/F`3:Q6/0Pdh^0?OU]@3/j[40a]bD0<_WW@37k9`0aN^H
0<[[VP31fi80d^RZ0<OLY03@i[D0mOoV0?Gok@3hooP0nook0?[ln`3moOl0ooko0?ooo`0d=3@0m?Cd
0>k^kP3jn_X20?ooo`0F0?clo03oool0oooo0?ooo`3HdLL0[ZJK0;F^Z015?CX03`/:0?ckm`3oooX0
o_of0>kfh@2laZd000H00=;`Z033iY80c>JU0<[QZ`3gonH0mOcZ0?ooo@80ooko0P3oool0?@3Pon`0
aOO40=7M[`36k[80T3hY08@P4@35UgH0T2lN08@d6@3=ojX0]^f?09n<E01[Ba`0a]FD0<WYX02ij9P0
`O2P0<7WVP3:iIh0b>>L0;gUWP2li9h0d^b]0<kTYP3Lm;H0`]ZL0<[TX`1ZQD80T[1Z03eK4`2ZbX40
cNfR0;cLT@3HkZd0d^BX0=[Y/P3Vl/80nOoJ0?kok03noo40n?o_0?_ok`3ioml0dN6`0=SWXP39giH0
cnjZ0=_f``3Hjkh0^KfH08b4H03bo]H0j^_;0>Vm_P3oo?/0o_Kc0?oknP3ol_40P7Ec0?olnP3onoX0
2`3oool000X0oooo02X0`^fN0=7UWP3Ci9d0aNbM0<?/W@3Oi:80A3h009fMG`39j:@0_n:N0>7oe`0S
I5`0gooo0>_oo`3nooX0o?oj0?ooo`3onOl0ooCo0?ojo`3oool0jook0;GDc`1aQXL03alO0869R`3i
ool0n?oo0?Ooo`3iool0o?oo0?WhmP3di^H0Z92>0?ojmP3ooOP0n_oi0?Kjn@3nool0oooo0?omo`3o
o_l20?koo`3o0?[jnP3hn^d0XZN@0=?O/@3Bh:/0bmnR0=S^/02:YF80c^bT0<c^VP3>l9`0`>2G0<3B
WP001P00200005E4BP3oo_<0oooZ0=o[^@3?gZL0Z[V20=CXZ`38ii/0d>ZP0=CUW`2AXU`0OY9;0<[U
WP3=kJ@0anNN0=?^Z@3Ai:80e>BS0=?LV`3PjJP0c]BD08fCD`1FG1`0i^n^0<[FU03GjjH0bN2J0;[H
T033hIL0g_Z_0<SRV03?iYh0`mZB08BJDP3;giX0f>VU0=7PW@24Te80cMVI0<WMV02dfhX0doJV0<7M
T03QnJd0dnNO08fNE`2;W5H0TjMP09jcKP27XEX0Y/1f0:6hIP3CjY`0[/:308fNJ03eomd0n?oV0?ko
m03`lNT0n_Wd0?chm`3oo_/0oooc0?;jhP3GjJl0Oi570=_WV`3[l;P0knOU0?olo`3looH0i?;>0<WL
Y@3:fiL0d^>O0=KWX`39fYH0d^>O0<_PT@2jbhD0S9aM08^GI@3lomX0nooM0?Gof03com@0b>JV0<S/
Y03:lJ80b^bO0=[dZP3BiYh0^/Ao06Ya;@3Yl:`0gnZU0<WQU`3BlZH0bO:S0;o^W@32kI/0d>bQ0=GY
X@2HWe`0h>VX0<?JU03AlJP0bNfU0<3OV@2ofYD0e^b[0<?QX`29XFD0>4dB0<SVZ038kJX0c>b[0<CM
W01HFAd0Z:Q/0=SYX`39gIH0en>Q0:NfL`2/`7/0dNbU0<7OU`33hiX0aNFL0;K@R@1mU4h0dn:O0>3]
]@3hond0noom0?omo`3Vbl@0c/ZU0=O][@3Il;P0l_g/0?3on`3ooO/0jn;C0=3TY@3Cj:L0aMnF0<ST
V@3@jih0c>NJ0=;/XP3Cj:<0f^Z[0:VfOP1mQE80k^_<0?ooi03PhlP0j>o@0=cV``3DhKD0_lbN09VV
N`3Wlll0hn_F0>[ch03^onH0h_CJ0>Kdf`3Zmmd0hnk<0?7kf03Tk//0oOoY0?cok`3loOl0oOko0?oo
n03loo/0n?oo0?Woo`3oo?l0oo[o0?okn03oonl0mo[M0<WT/@3Cj[@0NWQ80<_CX03>jZd0e_Je0<GR
X03HkZd0cn2L0=?WW`3CkJ<0`>NF0=?YWP1lIS@0g^Fb0<oWV`3HmJ40h?k00?cok@3B/k00onWC09Rc
I01IMBP0cN>R0??af03Iekh0YjJ80;flW@3:bYP0d=6=08f=C@0o>Q@0XIY`0=O@YP2ESW40eLfj0?oo
cP3hoKd0e]NM0=kLW`3FkJL0`>JK0<?hZ02miI`0eNRX0?WBZ@20?b40NBTB08`n:02[H4/0ObDJ0:YI
B02BD3P0MdHV000D0=W;VP3DeI/0f_6[0=KeZ@30hi40_^6=0=?cX03FlZL0d^^Y0<SRX`36gjD0kooH
0>cof`3don`0nOod0?gonP3oo_l0noKj07]iNP2g]kL50?ooo`0F0?knoP3oool0l?3`0??cl`35_;L0
`KJ`0:2FU@1[HF8010020?omo`3Xj^T0loSb0<WA`P3MjMD0>TH^0;gLV@3:kj80cNV_0=7W^@3kond0
nOoa0?ooo@80ooko03X0oooo0?ooo@3Ron80^nR]0=[U[@3;m[40SSdR0;UD@03of[X0WSHY088W4P3<
lZD0_>JB0;N>H01iBB40d>>Q0<_YX`2jjIT0a?>S0<kdY`3;iIh0c^bT0<KdZ`3AlJh0d^J[0=KW/036
fYl0X[Ik06=i>@003`00Hg`j0:>nM`3ElJL0`=bA0<g/X037hIX0a]fI0=7UZ03ZnlD0m?oE0>kif`3k
ond0looY0?Wok03homd0dNJ^0=7PW@31eI00bnV[0>OmeP3ZnMX0j>S@0=gA^`3`nMX0oooX0?oWkP3o
nol0oo[j0P3oo?X00`1REeD0ooOe0?oln`0;0?ooo`002P3oool0o`32k:00dnBP0=CSWP35jih0`nbN
0;ZlN`2<QTP0hN6S0<W]Y@3=mJh0foc?0091>03>ool0h?oo0?cgm03ooo/0l_7f0?oko`3okOd0ooko
0?_oo@3hooP0kOoo02m9BP0D:2T0CUQI08>=SP3^n_P0looo0?Soo`3kool0n?Sh0?oko@2fXJ00ooKb
0?W`j`3io_P0o?oo0?koo`3oool0oogo0?ono`3nool0o?om0?gonP3nonl0[[FF0=_X/`3Kj[40d>FT
0=7WYP28Xe`0b>NK0<OWTP32i8d0c^bR0<WJYP0B5`002P00079NI`3oo?H0noWT0=oX^`3>fZP0WZ]f
06n1A`35hIH0eNfS0=3QV`3AhY`0X[I_0<WWW`37iih0`N>I0=Kd[P3Jkj`0e^fY0=ki/P39hi`0dN:N
0=GTX@3>fIL0<CL004=92@3PiZH0fnBS0=oZZ03Hij80`]jC0=[dZP3;hYX0d>NO08jTG03=hI`0c]nK
0=_WY@2EXF40^/B50<?GTP2ojiH0b_6P0=KbY@2neXX0dN6J0=WVX03@giX0f^^U0<WOU`2<Z5h0cNRK
0<[QR@3>i940dNFP0:>bM`2@Vg40^L>Q0?gok@3OhM<0jn_Q0?omn@3nnOH0ooof0?Smj@3Ok[D0RIiC
0=7RU037d9T0k>_W0?KfoP3eooH0i?oF0>coc`3JlJ/0bN2J0=3ZX`3Ilj`0b>>L0>?eZ@3<f9H0jO>f
0:^^P@3dm/h0k?3;0>[bb@3Sll@0b^NW0<?WX@2jiIH0^>>C0<7SUP3Bk:80_/^50:B[I`33bXH0iO2[
0;gISP38kIl0aO:Q0<7gX`3<oZT0_]jB0=3XWP3:eI40aM6?0<;PVP3KokP0`>bQ0=3i[@30i9X0a>:L
0<CYYP2fciD0hOJm0<GXZ02jij@0`>VU0<GRX01CDaL0V9QL0=C^Y@35hIL0i?Fa0:RgM03<h9/0dNbU
0<[XX034iY`0fOV`08FOF03JkjX0f>NT0=;MY@3dn>T0nooo0?olo`3nh]h0f=B_0=7WY`3Ek;@0nOof
0?;oo`3onol0jnCD0<OUW@36i9X0e?FT0<[]V@30hX`0b>RE0<[YV@36h9L0cN:M0=?UY`3?fJ@0^[BB
0=kI^@2RXH<0[;2?0=_Q_@3@fJh0io;70?coi03lond0m_Se0?_oo`3doo`0l_oh0?Won@3looP0o?o/
0?[ni@3oonP0m_WT0?Okk@3lool0n_ko0?_om03hooX0mooo0?Soo`3onol0ooWo0?ogn03ooO<0n_kU
0<CR/03=iK40c/NM0>KY_034gJ@0a^BX0<gZZ02mdi80c=fI0=S/Y000@03CkJ<0`N^G0=3XWP1I?Q40
emf_0=gg[P3:jYL0l?oA0?Knj@3fe]L0_JB@0:_6M`3:jI/0eo2_0?ooj03nonH0o?oQ0?_og@3Fij<0
c=f?0=OVX@39d;40/[NI0:>WS03noo40o?of0<?EV@39h980f>jS0<[PV038k:@0`N^Q0<S`Y`3?iJ@0
];Qm0>2iT02jPV40XfI:07Q09@3JXXT0PC8S08@k:01]<AL0T6E30?O__P3Gg:80bN>L0<SXW03>lIl0
cNnK0<?ST03=jYX0bnVO0=Sf[P37i:40eO6g0=?^^`3<h;d0m_o[0?oon03ooo/0cLW:06e[K030`<02
0?ooo`0I0?Cdm03oool0n_[j0?Win@3no_h0^k^k0=KFeP3oo?X0mnWX0?oko`3Qe]`03`LB0?olo`3n
ool0o?oo0?WonP3`o>h0_/^i072?EP3>lk00bnNf0>_of`3ioo<0o?oh0?ooo`020?ono`0o0?oon`3o
ooX0lOoD0=;VZ@3Lj:P0cnnV0<nYNP3obJ80llFT0:YIA025>b80fMZP0=WRX@2RHSh0McPE0<oTX@3:
j:80b_JW0<?bXP39kj80eNbV0=Kd[02dii`0eNn^0<WFX01WM3l082d0061_=P2N/780_]6A0<[OWP3?
iZ00dnZR0>;j[P3<iiX0dNfR0<GQU`3>ij<0hONi0=_`^03Xn=@0i_GH0>;be`3Um]H0j?o;0<WSYP3O
kZd0eNFW0>Cob03bonX0k?WW0?Kdj03on^l0o?o]0?ool@3ohNl0n>_e0?omo`3gkN`0oo[i0:6GUP2^
Y:<0oock00/0oooo000:0?ooo`1W0<3/U`3;jil0_]Z@0=W`[032ei@0UZ1K0<;<Q`3=f9<0bNBO0=7`
[@3Rom<0WKjc072_Y`3>ool0o?oo0?Wmo`3oood0oogk0?onn`3bool0lOoo0?omo`3`ood0ooko0<o3
a`0600@0<S]005EhO022Z:/0m?oo0?OkoP3mmoL0o_7Y0<:]Z03ok^`0ooch0?Goo@3ln?T0nOoo0?Kj
o@3onOl0o_oo0?Soo`3gool0m_oo0?ognP2dX9D0_MVX0=?//P3Gg9X0gnJR086SEP3AkJ<0dNJS0=7X
Y03>k;00m?oS000900061P@0H5eH0?onl@3oonl0hncA0<oN]`3BjJ<0d^ZL0=c`Z03AiIh0c]jM0=;U
Y@3Lkjd0c>6N0<kSXP3ChJ`0m?oD0?3df@28SFl0XJ]i0=;PY@3Tnj/0bnB@0=OcWP3?jIl0d>ZS0=CW
Y`3>gI`0GVPQ09FLF01fOT80hnn_0<[NV@3GkJD0UZaQ0<[OU03Cj9d0e^bS0<cVW@36ij00anNN0=7U
W@3@iYd0c>RM0<[YW@030<WYW@040<[YW@3<j9d0cnNM0<gWW@80c>VI06/0c>RK0<cXW@3=iZ@0enba
0<oN]`3^mmX0nOkZ0<?2_@3?c/X0o?S_0?oml@34bZ@0ZkV80=_T[`3^iK`0kMc:0?ohk`3jo?L0ookk
0?Gci03Tk[X0gNFf0>C/a`3ZlM00jo3I0=KVY`3Ej:P0d^JW0=CVZ029VE/0eN6S0<WEU`3EhjD0a=nJ
0<GYX@39mJP0a_6Q0<G/V`36ji/0g_JZ0<kKU@1SGb00g]RJ0>3YYP2oeXh0bNnR0;_`WP33k9d0c>RK
0<gXV`3@iY/0cnNI0<_WW038j9`0anVO0<GYW`36jZ80bnRU0=K]Y`2igYP0b_R`0:gOVP2fgi/0c^NS
0<oTW`2d`h00KWPi0<o=VP3PiJd0bn:N0;37P@1]OSX0d]fK0=KUXP3=ij00b>JN08RXG`3Ajj@0fNBR
0=GQX`3JlLL0moo_0?oomP3S_;D0a/RQ0=;U[P3Sl<D0o?oj0?[ooP3Wk=H0gn[00=C_XP3@jj@0cnn^
0;WLV036jZ00b_:I0<?[TP33iIT0b>F[0<kQb`3BhLh0g^760>KXdP3ooo@0o?cb0?oomP020?oom004
0?oomP3oooX0ooko0?omo`<0o_oo0340o_om0?con`3looX0o?oj0?_onP3lood0nooo0?[ooP3iooH0
lo[b0?cko`3oo?l0ooSo0?o`o`3oloX0oock0?oomP3Kj<h0RYJ00?kon`3in_80ooo/0?oohP1ZLc`0
TYiL0<_PT@3Aj9P0dNVO0=C]Z`3HhjT0FD/L0=kU/@3?jj00c^fM0<CNX@30fJl0PFm709b=E035ii00
bnBS0=CU^`3`oN/0moo/0=kfa02lf9d0`Mj:0<CLX038f[@0mooo0080nooo02T0i?3H0=7Q_03>j:L0
cnfU0<W]Y@2nhid0a^ZT0<3QW037hJ00gN^^06=G8`2:=QX0YC4R08hS4@20;a@0omBb09E2=02RC3l0
aWiX09IO@03]g:H0emNG0=C`X`3:kil0_NfI0;c^V@32kId0bnNL08BJDP3@iJ00dnRU0=CZ[03<hJP0
d>Bc0<cO/P3gon@0_Lj/0:jlY@3nool0o?_o0?Sgo`020?omo`0<0?_fo@3oo?l0ooco0=gCf`3Oe]/0
ooKn0?oko`3ml_X0ooOm0?odo0070080ooco0P3oo_l0AP3lood0noom0?Woo@1SKeT0iO7I0?_omP3l
oo/0no_m0?Win`3onoX0oogj0?onn`3oo_l0oogo0?Ooi039gJ`0e_Bd0<CXX03ajJ/0gk^;08Tc702A
5Pl0VblU0=gFZ02f[Wl0YV]306D_0@3>i9/0`NZK0<G[WP3=jjD0h_Jg0=S_^`35h[8001T0000:0023
VFP0g?Bf0<cXWP3;jY`0^=V80<g/WP39iid0c>JM0<cTV03BjI40eNZ?0<;ZTP35lI`0a^^K0<g_XP3=
kJ80a>FP0<;UX@33j:D0c_>`0<c[Y`33hI/0d^VK0<gTUP3Ro;D0g?S70>[nf@3oo?00n?S^0>ggk03j
mNl0omkU0?oimP3em_020?oonP030=oHd026NgD0oo_f00/0oooo000:0?ooo`1/0;oZT@3FnJT0e?:X
0<kQX@3]o;/0QI1;0=?PV03Lk:<0c^FQ0<oYZ03Kmlh0l?ok07>_Y`3Hool0jO?l0?_oo`3oo_/0ookh
0?oon03`ood0l?oo0?oko`3hool0oo_i0?ogn@0@0@P00@H<01i3B@1@NGl0j_ko0?Clo`3oo_`0ooK]
0?oim03omoH0ooWe0?Gon`3oo?l0nOoo0?Olo`3on?l0n?co0?Ooo`3doo`0m?oo0?ofmP2nXiX0`^F_
0=?a/`3Ngid0hnJO082WE03=k:00dNJS0=;XY`35h:T0iogI000700000P00HVAI0?ool03ooo40kOKS
0=[Yb03=iid0bnNC04MG403=gYP0e>NW0=S[Z`2ndI4000l00>3`/P3>ejP0kO7>0:6OTP2b/:40b]2T
0=OPY`2id7h0^MEn0=;cVP34i9P0aNBN0=?[[@3EjZT0aMF<0=kXX@1JFB40eMZP0=CXX`3Rn[00S:AH
0=_bY03:hI<0e^jT0<WWW@3Bnjl0a>RN0=CTW@3Ci9d0c>RM0<WYW@35k9d0`nbM0<G/W@38jYd0bNVM
0P3=iid20<WYW@80bNZI02<0b^RN0<_VX`3>gk80hNc:0?cok@3Qh=/0][Fa0?oomP3nl>D0eMRk0=;N
^03Gg[@0f/ZX0?[Qc@3oo>`0oooj0?_/l`3onoX0oOoP0?SkgP3oond0nO[/0?oonP3AhjL0b^2P0=3Y
Y`3DkZL0U:UT0=SXX@3OkjP0gnjY0<kYXP3KoK<0/]b@0<S_X0020<O^W@090=C`X`3BhY/0H5XL09B<
CP3EeiH0h?6]0<?UV`33m:<0a^^M0080c>RK03T0c>VI0<gXU`3>jYd0c>^M0<_[X03;jZ@0bNZS0<WV
X`3Cij00bOFZ07fcJ02djJ<0bo2]0=CUX@3BhI`0dnNP0<kMW01OE2H0h=fZ0=Sa[`3?jJ80bmbH09RN
GP3Hhj40d>NQ0<cZXP3AlJP0?5H?0=;KVP3FhZ80cNZd0??oiP3kn>L0ooC/0=cQ^@3Di;D0iNo<0?ko
n`3jo?T0fnC70=;O/@3>iJ40b>2R0=_f`@38ijh0d_Fa0<C/U02oj8`0bNfS0=Sf`03[oo@0l_oj0?co
k03lonl0o_of0?[mmP3lo_T0103oood30?ono`070?ooo`3nood0o_om0?_oo@3koo`0n_ol0?_oo`02
0?coo`1G0?_oo@3donl0o?oh0?[fm@3oo?l0ooSo0?oio`3onol0oogk0??`j@3UjMX0o?of0?_oo`3o
o_l0oogc0?oliP2WZWD0en:N0<gTTP3Fki`0cnFL0=SW[03?eZ00FE8N0<oHX@39iIX0_]f?0=W^/`3;
j;P0HUDP0:nUH03=lIT0`MJM0=WWaP3coo<0jOKR0=kfa03Kmk`0`mnD0>Omc`3gonl0l_Ko0?coo`3a
mOH0j?KE0=;T/P39hj80anJS0<CWY@3>kJX0b>6P0=Wb/@0Q=`00DElR0>KLY`20;a80UB@B080J101l
<a<0l=FZ0=:@N01b:aD0N3`P07E9903^hj/0emVH0<gWW@35iIX0aNfT0<SbZP34jJ<0`MRB04eN6P3;
fiX0dNBT0=3TY`3BiJd0`mNR0=[^^`3/om@0b^6c0>7bdP3go?H0o_go0?ono`3ooOl0ooko00<0oogo
01D0Vi:G0?olo`3onol0oo_o0?ofo`3oo?l0no3f01@:2`3nmOH0ookk0?ono@3nool0o?oo0?_oo`1i
O7<01@P00?_mo03gm_/0oogo0?ono`3oo_/00P3oooX0;P3oo_l0ooco0?Wok03Qm/d0c>R]0<OVX`3R
f9/0oMNV0:E2;@2a9b@0Qa080??/_P1=?a80`XMM07m;6`3Eiid0aNjO0<CVVP38hId0a=>H0<kZ^@1B
MTX03cHG092]U`33gjD0dnnU0<o^WP3:k9P0eoZV0<7TU036iYX0c>ZP0<cXW@3:iY40c^R?0;gUS`33
kiX0`^RE0<GVU`32hi@0bnjN0<;YVP32jid0`nVL0<c/X`3BkJH20=C]W00?0=3ZX02ee9T0gOC60?ok
j03loo40n?of0?oomP3om?<0ooW^0?kon03gn_<0oooj0?ojl`2AQ7`0oo[c00/0oooo000:0?ooo`0<
0<;TT03Ln:d0d^VS0=OWZ03KjJ/0Hg0Z0=CTV`3<gY80cNNN0<GRW`3Nnld0lOoj0P3o0000FP3dool0
lo[o0?ono@3ooOX0oooh0?7oo@3aool0oo[o0?omo`3inOL0oooj020F50070000k_Wm07B=T@3Nool0
i?oo0?7oo`3on?L0ooSe04dh=@2UV980o?oh0?okn`3kool0nOgo0?oio`3ko?h0nOok0?Som03don`0
nnc?0:ZMNP2ohZ80`^6K0=SRV@3Gi9D0SkYN0<O^U@39jY<0cnbJ0<gOZ`3ionP00@T000T91`1gMfl0
oood0?_mlP3kooH0nOo]0=;[ZP3@jih0e^RN0<CES`2caX@0g_6_0<OLV@3>hYd0/L600:J`OP2DVW@0
kN_L0>k`f`3AhjL0/LJ30;oGR@3BjY`0g?J/0=Wb/@36gZ@0d^N_0=7UZ03@i9`0d]nI06QS;00_<`00
fnnZ0=3ZX@2J]VT0cnZM0<ORU@34gY@0a>2F0;[LTP38jYh0c>RM0<[YW@39jId0b>ZM0<K[W@@0aNbM
0P36jid20<WYW@80bNZI01@0b^RN0<cWY03UmlD0jo[C0?SoiP3ooo@0oooh0>GRf@3:_KD0Wj2>0?Gm
i@3ko^40ooGO0:ZCP`3eiMD0][VX0:bTV@2`Yj00d];D0>7Ri080o_oo05<0o?oo0?Ooc`3=ijH0dNj[
0<g[X`2ofY<0TZIN09^/I@3=gYP0`M^D0<g]Y02mhiP0c>bP0<W/W03=l:00a^FG0=G[XP3Jgid0R8M7
09nQH03Ag9X0d^NR0<;VW038jYh0bNVM0<WZV`39jYT0b^VI0<SWV@36iiP0a^JK0<OVX039j:80cN^U
0<cVW`2nk:@0Y]jE0;g^[036i:H0jO:a0<7;QP1nTTX0SIiH051?5`2`/GP0enZX0=W]Z035e940dMfK
06am>@32gIH0a^JM0<;MUP3Ll:/0KFl`0=KOWP3>kZl0cnJj0=gKa02XO7T0m_WL0?Woj03nonl0oooo
0?knoP3non`0o?oT0?Soh@3ionP0looT0<oT^`3Il[/0c^fM0<KWT03=jIl0g?>m0?;ok`3fooL0n?o/
0>?`e03Gi<P0fnO?0?;mk0020?_oo`80o?oo00@0o_om0?kon`3oool0ooom0`3nood30?ooo`1G0?kn
o`3moOl0o_ok0>;[d03<d[P0l_KM0=3D^`3oonX0no[U0?ook`3ooo<0knoS0?oon03ooo/0n?_o0?km
o`3ooo@0ooo/0=WS[P3Ll:/0i?fZ0=S_W`3EiYl0NWm704I9503Beid0b=bO0=7`XP3:iYT0g>^d0=S]
a01oJS/0a;Ah0<[]W@3Jl;l0noo]0?ono`3oooH0koWF0<cL[@3eon80n?oc0?Won`3nool0o_ok0>oc
i03Zn<L0go6e0?;oc@3aom<0i?o:0=WW[03Jfj40U9QK0=[YZ03Ml[40enNV0>CGX03kg:d0imJR0<kG
V038l:T0g>JZ0>;SZP3KhJD0fnNY0=7WYP3DkJ`0d^N_0=g__@3jomh0oooV0>_/c03Ok;H0dNBT0<?F
UP1ZO3h0dnNZ09JZK`003000C5hZ0=OY]`3?hJl0k_gF0?cok`3mooD0o_of00<0o_od0180oooc0=KH
bP3joN`0oooa0?CgiP3mo?L0ookm0?okn`3oo_/020000?omo@3oo_d0ooom0?koo`3lool0nooo0?[l
n`0000020?ono`140?[io`3nool0o?od0?col@3moo80o_of0?konP3jonP0k_SC0=WMZP3NiZX0HDhC
064n202GBBD0S1h7084Q203RdiX0MeXR08=05P1m@QH0iNZW0=GaYP33hiP0cNRQ0=7XY0007`00IYQM
07fgQ@0ZGc<0`^bR0<gcWP31h9@0dnnU0=G/Z036g9/0bMnN0<o/ZP39k:P0]n:K0;cZXP32hYH0bnJG
0<_RU03IkZ<0bn2E0<SNT`37hIL0dnfS0<kXWP3@iYd0d^JO0<oUVP3JlZP0e>^S0<?SXP3=iZd0d=:[
0=ST_P3Bj<@0k_GF0>W<^P3Abk40loK]0?koo@3ooo/0ooW`0?okl@2;M6H;0?ooo`002P3oool02`3G
lZ<0b^6I0<GHUP39eiX0dmnQ09VXH`3TmZ`0a]^>0=?_Y@34hY`0g?S800@0o`0005@0mooo0?ono@3o
oOX0oooj0?;on`3dool0oo[o0?olo`3nood0o?oh040g<00=0000lo?e0<WKf`37n_D0h?oo0>Koo`3o
nol0oo_k0;NTX01cI5d0l_;V0?okn03no_h0o?go0?ojo`3lo_d0o?of0??li`3^omd0lnW60:6ILP35
i:P0a^>S0=KQW`3@h9T0VlE_0<S^U`35jHl0bn^H0=?Q[P3konL000<000D10P23P7/0ooof0?_kl`3l
oo/0nOoc0=3X[P3=ij00dNJK0=CXX@2=XE`0ambG0=K[YP3Dj:40dnBP086;E`36c:H0mO?T0=CH_`3J
mK00^]B;09feJ`2fcHD0dNJU0<KGX@3;fjX0amVU0=CX[@3:hYP0dn>L07E^>00W:000^/j90<STVP1o
We<0e?>W0;cHS@3BjZ00a^2G0<k/Y03;jj020<SZW@<0bNVM00@0b>ZM0<K[W@35k9d0aNbM0P33k9d2
0<WYW@80bNZI02l0b^VM0=?^Z@3:g:P0i??:0?coiP3cm^D0m_S[0?oon02MT8X0[jnS0?col`3oonh0
oo[]0<>/WP3ooNX0l_SN0?Sfg@3ekml0mOKk0?;cn03Pi>L0jno`0>kdm03To;h0anJS0<g^Z@3>l:H0
e_J]0<?IT02>WeP0UZMQ0=of/034hYX0e?R^0<k]X@37j9T0c>nO0<KWV03>j9h0g>NS0;g2P01@DQ40
`/R80<kJV03DkZL0bNVN0<SZW@020<S[V`0h0<WZV@3<kIh0b^^L0<SXW@3;jZ@0dO2Z0=gj]`3El:/0
`O>/0:[SW030kZh0cnV/0;FjNP2KX5d0=4T0049H3`2Z/7@0hNN[0<_JV@3Dhj00d]jL0=WXY@1eRTD0
d>jV0<CTV`3LmZl0b=VE04E31P3LhIl0cNjY0<CLZP3Ee;P0XgMd0?gojP3koo40o_of0?cko`3knod0
o_o]0?kojP3ho>h0o?od0?SokP3JjLP0hOC60=?[W`3;i9<0dNRR0>;d`03ioo<0nOof0?Ook@3Ql=40
b=Rc0=3P_03aonH20?Woo`80nooo00<0o?oj0?con03nood00`3oood0H@3oool0ooko0?ono`3oo_l0
oogo0?ono`3oooX0e]fl0=_R`03Mj;h0S9M/0?;mdP3nomd0mocN0?Wli`3ooo<0ookk0?3^k`3hnol0
o_ko0?oom03oon`0e>:]0<oTX@3>iiH0^m:20=3MU`1/Jc<0NWU30=CRY@3:hj80^mb=0<SSU033cIT0
c=Zf09QoEP3Ia8d0`>:F0>Cjc03eo^/0oogo0>k[iP23R6X0UZ5g0?Cok`3_mO40n?cm0?ooo`3oooP0
o?oZ0>Wf`@3Kjjd0koo:0?7oeP3OnLT0_ljC0>_//01@EAD0cMjJ0;3;QP3;jj80eNVT0=KOX03BiJ<0
c?2V0;?^W036j9h0a=nH0<[XX03InK00^]fI0<g][P3AjKL0j_[C0?ook@3oo_<0lN[H0=o[^`3:gYl0
g_:c0<CHV@1OLCD0<D<902Hg002X^H80b=VS0=;S[@3^nll0m_oP0?Ooj03gonL0o?o/0?Woi`3honH0
fnC90;o:[03fon<00P3konP0D`3ooo<0lO7Y0?oon03NfmH010000?onn`3oo_d0ooko0?koo`3lool0
nooo0?gmo`1aKg@0i>?[0?3`nP3cm?P0l_Oc0?col@3honX0mooX0?Wok`3hoo00l_oQ0=7P]`3EfZ@0
fn6S09jEE02COSl0IBl00:IH<P3;RV00e<n=0:F<C021Bad0Q5DW0<kGU03=jIh0bn^O0=?aY`2ofI80
5C`00=Co`P2ll[P0Y]RS0:k]]02OhJ<0e_o10:kFS`3Cj:L0f>J[0>?[^03<f:H0c^6Y0<caX@33kY@0
dnbK0=[/XP39fI00e^>K0<OGSP3Rm:X0g>jT09>XG@2gc840c=jD0<cMUP3BiYl0b^6I0<SOV@3BlZl0
a>6Q0=kU/P35eZ80^MFT0>Odb03A^Id0iNO20?_om03jooP0m_O_0?cbiP3onNX0ITdi00/0oooo000:
0?ooo`0;0=KSW@35dI40f>>W059L9`17DQX0cmnN0=CXX`36gY@0a^:H0<_ZY03Nn<P0103o0000F03b
ool0ooko0?omn`3nooX0mook0?Ooo`3oo?l0n?Gn0?Cfl`3oooP02`0001D0003onoH0loci000W900n
L6l0dOoo0>coo`3kool0mn[T0;V[XP3ch]P0ooWd0?ono@3moOl0o_ko0?[on@3en>D0f]k30<gH/03c
l<d0WIYi0>3`c03SlLh0j_;=0=[W_02cdYL0bNRU0<CVVP3?jj40hnJi0?7af@0400001P0008MoO@3o
ooX0ookl0?coo`3hooP0e>Jl0<[RYP3Ejj00f_2W0<oVWP2CZV80bn>I0<oTV@3NlZ/0cMNR0>[ab03_
k=d0mogQ0<3UU@36iYX0_=:B0<oPZP3QkKl0n?oM0?koh`3Rl/D0]lbD0=;`Z03<h9T0VXmI0>CSZP3@
iJ00`n6I0=Wk[`1;Jb00`^2F0<SNU@3PmZd0c>:J0<kZX035k9d0a^^M0<cXW@3?iid20=3VW@070<gW
W@3:jId0b>ZM0<;]W@33k9d0b^RN0<WYW@020<WZV`0a0<WYW@3<jZ80aMZQ0<SJZP3DhkX0fN;50>;Z
d`3noo<0oocf0?gln03lood0f]GB0>S?dP3li=X0ookX0<kN[`36d9h0fmnl0?cjo`3oood0lO;P0;:f
V`3Lj;X0b>:S0<_[Z035jJ<0a>fQ0<7WW035hIH0eNfS0=CXX@3LlJ`0a=jG0<OUW@3=iid0bnNJ0<[Y
V`39k9`0aNFI0=C[X`3?h9X0hNRU04A61`2LWUl0c=FD0<cWX036jZ00a^^N0<G/V`020<K[V`0n0<GZ
VP35iIX0anNN0<[XXP3?k:T0a>>M0;gb[01BRdH0]mnS0<oRZ`1JF1d0emJF0;oDQ`3KljL0iOB_0=oZ
Z03/mK@0dmjL0=[VY03Sn[@0A5lH0;kPUP3:jZ40b]nJ0=3LVP1JEQT0e]VF0<g`X03@jZ/0f]^c0?oN
g@3oooH0n_oo0?ono`3ooOl0ooko0?gok`3jo>h0oo[o0?omo`3in_80n_gZ0?koh`3HhjT0cm^M0=OQ
[@3Xl<T0nOca0?Oml`3ion`0i?;>0=CR/@3LjK/0l_kJ0?coo`3lo_l0o?go0?kno`3nooH0o_oc0?ko
n`3ooo/20?ooo@80oogo06L0oo[l0?olo03ooOd0ooci0?[gkP3SilH0e]je0=7SZ@2aahL0cNRU0<?K
W@3Ij;l0o?oZ0>g_hP3ll_d0oOGo0?kon`3ko?H0nO_]0?SoiP2mdI`0aN2M0<[UUP3AiYT0iO6Y09fD
G@3NfJ80aN2K0<oc[@2jgH/0e^jP04mA803TjLT0ZXMW0>gCXP3BlZl0g?;<0?Wom01kMGD0=38V0>kd
dP3nomd0QhV40?koo`3oo_l0oogo0?ono@3blnD0j_;90=WW/P3>iZP0b^JY0<OZZP3:l:L0go^a04=K
4@31gI80d?FX0;kYV@31lZ00ao>T0<_aY036kIh0a>VK0=?_XP3@k9l0bNZK0;_MT030j:40cOBa0<[Z
^03VomT0k?_V0?Col@3XlN00_<jN0<OMW@34fYX0fNn_0=3TY@23UeP0_]2B0<_KW@3>g9l0fNNZ0>Kc
^`3EhJl0enBf0=CT/`39fJP0c^2/0=?U/@32eil0d^Va0;kGWP3Nmkh0]<fD0=g[b03lonX0oOo^0>oa
h`041000ookk0080ooko04/0oooo0?koo`3lool0moGh0?ono`071P/0gn3T0?con03bnnP0ho?<0=KY
^`3=hk80c^Jf0<kU]`35l[L0_NZY0=G[X`3;hiD0d^nK0<kWUP3_nK@0cm6B0=_TX`3BjZ00XJ1M0>gY
[03Jhj@0]]b?0<7`X034lJ00aNZL0<3LT@31eY40Cf@S0=7SY`2odIL0`=^V000?00004P00EHa/0<?o
g02aml40ZNbY0<olZ`2og8`0HUdM05e:4P1SHbD0BU<@069_:@2ib8<0cMjG0=?SW03Lk:<0eN:J0=k^
Y@2HZUh0HGHY08bQGP33fIP0hOZh0;_OU@3Knk00FfLO0=cdZP32iY`0_mJB0;FYM`3BgJD0ambe0<cO
_`3IilH0hN;00?oog`2]WgX02`3oool000X0oooo00`0fnBQ0>og^`3<did0UIm]0=GQ[`3@hZH0d>FT
0=?ZY02mf9<0c^^X0=gdaP3hooD20?l0001R0;;JfP3XoOl0oogo0?omn`3nooX0nOok0?Woo`3oo_l0
o_ko0?ooo@3dl>L09aH60140003on_<0noom0=ooo`0KA4H0Pk2c0>Ooo`3_o_l0ookh0?7SfP2lYY/0
ooG_0?omo`3jnol0nOoo0?Won`3innD0f]fn0<gDZP3oom/0YZN50?;hg03cnMl0m_cP0>;]b`2ldZ40
b^>Y0<GUW03BjjL0/[>90=CB_@0;1P002P4607eeL`3ooOX0oogn0?coo`3kool0go7;0=KZ]@35gI<0
c^FM0;G<Q01aRCl0SJEI0=CZW`2kchL0gNNb0>K]a03ooo<0o_oZ0<K]W03EmJX0g?6i0<kK[`3[llh0
oooV0??hf03kom`0/LJ>0=;`Z03?iId0WYEL0=WIW@37g9L0cN^S0;gOT`2Wag`0CFTO0=ocZ`2odh/0
enfT0<_UV`36jid0b>ZM0<oWW@3AiId0e>BM0=KSW@3AiId0cnNM0<[YW@35k9d0a^^M0<[XWP39jId2
0<WZV`0`0<WYW@39iil0cnN[0>;f`@3XnL`0cMRf0>3[c@3lonl0oogd0?ooo@3nool0knW[095fN`3?
^J`0ookT0<KKX`3Ljk00eMf^0?omo@3nnO<0oooX0>GYa03Gh:T0d^Z/0<k]ZP2ohid0a_2T0;gVVP38
ii/0an6G0=3VWP2P]G00b^6K0<cWX03<i9X0c^VL0<WXVP3:kId0aNNJ0<WUV`3IkjL0f^>P08>5AP1O
GB00hnFV0<oVXP38jJ80a^ZP0P35k9d0<039kYh0bNjP0<W[W`3:j:00b>JN0<KTWP3?l:T0^o2Z09O@
S03:lKP0cMjX09fHH03Mg9`0d^NJ0<SSUP3>hYX0bmRC0<S>SP2maXD0TZ5N09niLP3<jZ80cNfT0<OU
W@3IjZH0en:P06iZ;@3DfIH0bnjJ0<?NV@3Ifj`0[X:10?;ak03kool0oogo0?oio`3ooOh0oooc0?oo
m03oo?l0ooSo0:n/Y@2MWXh0[:nB0<oEY`38ci`0e]fd0>cad`80oooj07P0h^_@0=?M^03SkK/0m?g>
0?koh@3oood0oogo0?olo`3ooOl0oood0?ool`3nooX0oook0?ooo@3oo_d0oogo0?olo`3oo?d0oogk
0?onnP3gm>d0jnWL0:>WQP2HX7L0e>R]0=O`[`3?kJL0eNn`0>;cb@3konX0ooof0?kco`3onol0o_of
0?3bi@3nonl0o?oX09bcO@2Za8<0cnZM0<oTU`3KiIh0b[n90>?NYP3>k:@0anfT0<GXUP2AZE/0YZEe
0=SK_P2FLU80`JEf0;kNW@3TnMP0n?od07emM@1XJeP0fnJn0<cJZ@3gnnd0oOgk0?ono`23OHL0KfY`
0;nk^03Gg[l0eN:f0<gUY`35hYl0b>bT0;kZV`38kIl0OYeA0=3/X@3:jYh0aNbM0;_/VP2ljiX0anbN
0<SWV`3CiI/0cMnE0=G[X03CkZ40a^FG0<ocZ@2kh9X0_n:X0=OgaP3Il=<0iOSR0=_]d`3Aj;@0d>VX
0=7ZZ@37gId0d>BU0=CYZ015F1P0X;1a0<cKVP3OkZd0d=jP0<KEVP3Xn/00c>2U06Um@P1OMCL0R:5P
0>Oo`02meiH0eO:_0<CSW`3Dljl0fNZn0>[he03`nMh0o_o_0?oon03lnoL20?ono`1;0?ooo`3nool0
o_oo0?klo@3oo?d0<C4a07alNP3eo>`0kocP0=c`_@3=iJ/0aMnR0<STZ@3:iZ`0^?2W0<3fZ038hi@0
c>bG0<C_U@30jY@0b>JN0<k]Z@38jjL0b^^V09>IF@38f9L0cNZW0;o[WP33mZL0_njM0<G^W`3Al:@0
f^VT0=;MV`1[LCD0g>:V0=oV/03@g:X0?5hk000Q100mQ5`0<Gi:05n[J`2MdhL0aN^R0=[JYP3Qe:X0
g=fT0=7KW031eI00h?F`0<ONUP3>hYX0dnBM0=[ZX@3=gI@0c>>E0=3[W03;hJ00UZa/082IE`2:/F80
[Lio0=;PT@2ofhL0b>nL0<gWW@2XWf@0`LnA0<k[/`3AkKX0`m^Y0=7M[@3oomH0Y9i^00/0oooo000:
0?ooo`3905UG702>SUX0X:5e0?Wog03iomh0lOoC0>;f`@3Fjk<0bn:/0<WP[03UmM40n__c0>koo`1n
Z:H0d_oo0>_oo`3oo?l0oocm0?conP3noo/0o_om0?_oo`3eool0ooKg0?ogm00]4`H02`000?oom03d
nO80nOoo0?3oo`1BLgX0bOoo0>;oo`3gooT0oogc0<6SV03om^d0oogo0?;io`3[ool0l_ok0?koi03F
g;00injh0<OKX02;WFT0h]nl0>WXb@3]mm@0k_[B0<;<U`3GjZX0`Mb;0<gSV03ShK/0Z::B00H00005
00D0RXB40?onn`3oo_l0o_ko0?coo`3ionX0g^o20<SRV`3<iYl0cNNP0<WSV@2Ya7L0g_FW0;_?Q`3D
gZX0c]:_0;jj[`22QG00_mbI0<gUZ`3<f;@0eMk10?[ni`3oonP0oooT0=7O[P33ei`0eo:]0<WNV@1B
D1<0O8130;_@S@3IlZh0e_2Y0<gRW@3Cij80S9eG07jBBP1mUDT0]=2309FaIP25WE<0ZKUb09RSGP2>
UE40U9]G0:J`J`2BWeT0bmbE0<CNU03FlZL0bnVO0<_ZWP3:ji`0bNZK0<W[WP3>kZ<0b^NT0=kh^@3`
old0d>:b0=;S]`3JiLD0jnWD0?oon03dm_40elk?0?ofnP3hhm80n?CA0<_XY@36h9H0d>2R0?onm03o
o_40ookU0?[ff@20P5X0h>nd0=C^[@3Em[40^nFI0<[dZ03=kJ40bnNL0>7g[`2X_7L0`MF@0=7XXP3=
iid0cNRK0<cXV`39jY/0b>ZM0<[/X03;jIl0bmbF09BJFP1FE1L0jNBZ0;S8R@3=jZL0]]F?0<7VV@36
jih0a^fN0<W`X@39jil0aN>K0<?QV@3?jZD0do>Z09c@QP3AolD0NZ=Y0=GY]02NWFD0hnFV0<[RU02e
e8@0bMnF05e/9`1OJ2L0f>BR0=3TW`36i9`0`>2G0=;]YP3Om[00dMfK0>;]Z`1bN3P0hNjX0;[PR`31
gI80h>>Z0>Nl]@3oood0loGo0?olo`3ooOl0noKc0080ookh07P0eLc=0<Fm^`3oo_H0oooc0?gjj@3o
onX0kngD0:^ZUP3/kMl0oook0?3bi`3loMd0k>k70>[]`P3oom`0oooQ0?olmP3kmOL0oO?n0?ofo03o
m^l0oood0?konP3ooo/0ookm0?omo@3ooO/0oO?b0?G^j02m^Jd0ook/0:>YS`3nonX0o_oW0>;/bP3C
i;P0b=j]0<OR[@3<i;@0h_7@0?Goi`3hno00oogo0?oln`3lonH0i>_<0;BiV`2V[H/0T:=/0:c2PP33
fhl0c^>H0>C_ZP2j]Gd0fMRO0=_i[`30iYd0LiU40<SSTP3emlH0mocL09A`D033Y7H0`=jN0>7de03c
onh0l_oU0<kL^@3=iJ/0e>n/0<gKZP3lonP0o_oc0?cio`3oo?l0l>cj07YkMP001@00dNNY0=[fZ`3:
kI<0dOBP0=KeY`3CkZ40NXY10::_I`3<g9<0bNZK0<?ZV@39j9X0fN^Q0=WJV03GhYh0dnBN0=7UW@3?
ii/0b^VK0<WYW@38ij40c^fZ0<cU[03Aj;@052P002U31P3PnkP0d>^V0<OPWP3Jljl0a=^E0=CYY03@
iJ00VZiW08fQFP2X_7D0bN2H0=_e[032g9<0fO>Z0<3LTP38ii/20<WZV`090<S[V`38jiT0a^^K0<_U
Y035g:@0f^_10?_oiP3noo@0oooj0080ooko0P3oool0B@3nool0no[f0?olm`3hnO40M7IY0>K_dP3?
g[D0a=ZI0>;l/`39iIX0h?ng0<_ZYP2olj00/n2;0=[YV034g8H0dOnY0<_hY`38ij/0^NV]0<_n``2n
eZ@0XJMi0=?`[P2oiI`0_n2I0<KXWP3<mJT0a>ZO0<?UV`3KjZL0e]nP0;6gN`2@VUd0KFh/06YY:@3I
gZH0[KN509bbR`37iL40bNc;07NVQP0[GSl0Fi=`07ZbS@33gZT0c>2U0<W/ZP2khid0_nVQ0<WZX`3>
jJ80e>RP0<gSV035iYD0a>jJ0<_VW`3=i:00b^FN0<G/V`38jiT0eN>D0=7]V@32jY80dnbK0<_1P`3I
jJ80a>jJ0<SdW@2niI80bNRL0<[QV@2>WEX02`3oool000X0oooo00@0in:Z0>WW]`3Yj/80jo;C0P3h
on<02P3bomX0i_W<0<gP/`3Bi;X0l_cQ0?oon03aool0U;bk0=3oo`3Oo_l20?olo`230?conP3ooo/0
ooom0?Soo`3eool0oo?e0?ogmP0f7Q805@T00?kom03inoH0n_Oo0?Soo`3@jNh0A7ai08Bb/P3bool0
n_[^0<VYWP3ono40noWn0?Ooo`3Mool0k_ok0>C^b`3;dj80f>:S0<g_Y@25Y640f]NZ0=cJ/@3@h:l0
fNbe0:RbL`3CiI/0f?FK0=7XV03Fe[80inCC00h91P0300@0P7ak0?ckm`3bl_80o_ko0?OkoP3konX0
j_[=0=;]Z03=j:<0dNbU0=?_Y@36h9H0dNNL0<_OU`3Vl;`0Yj^:0>[Ug`3ooo40d^F^0=k^`@3SjLl0
f=g70?kol03lonD0o?oN0<_IY02DYVX0c>FQ0=;WXP2Y[V`0@DX90>;e/`2ndi00bmjL0=SWYP3AgI/0
enJQ0>[n]P3MnJ`0_]f?0<_SV@38gYD0e>BM0=WVX03PjZD0c=JA0<C?RP2@WEL0>4P10<WMU@3=hiX0
bnVO0<g/X038jIX0anRI0<[/W`3=kJ80b^RR0=kh]`3`olX0dnJ_0=7U/P31dJX0h=o30?7bhP1/Kf@0
nO;/0?ogm03Ye;l0fMN`0<SYXP3>kIl0eNVZ0?omn@3il^X0oO[W0?ooiP2/[8H0cmRO0>Gi^P3bol`0
_NNK0<SbYP35iIT0`MfB0=;XX02FYf<0QIUD0<?JU03<j9d00P3=j9/0OP3<j9/0bNVM0;OLS`3@lZH0
eN^S0;g8QP1hNS/0i^6W0?;m`@3Nm;<0a=nJ0<c/X@2oi9L0_^FF0;oVU`38jYh0c>ZR0<[XX035h9T0
`]jD0<Ki[P32n[<0Tkn40=Sa^P23QTd0h^RZ0=?^X@3Al:80KH4i0=SWXP3<eiD0d^>O0<ONV03<k:<0
a>BK0;[AR`3KkjX0RIEC09FPGP3NjZP0e>ZR0=3fX`3Ckj80gn>V054W6`3mnOH0o_go0?olo`3il?40
oo[d0?omnP35`;d0g]WE0?[ek`3oo_H0o?G[0?oik`3fl^H0oooa08Z8N`3ooo80i>KK08F8M@2^/8T0
X:1j0<30W03em=D0oooX0?ool`3oo_P0oo_l0?cbl@35_;L0[JVP09BGT03ooo/0mo?b0?SblP3ll_40
jN;L0:bUW@3>d;/0V9b30=;N^P3NjLL0n_oX0>gff@3Wm]D0g^o;0>3ecP3Rlll0kO[N0?_ok@3gnn`0
e]K>0<S;^P2GY7P0WjZ20=gQ_03Rikl0e^>^0<[LWP3Jl:L0e^^P069_:@3PhJL0cm>H0=WcZP2nhYX0
U[aW0=3[VP3Xkk`0koWG07aJ=`3?/h<0d^n]0>Kge@3ionl0j?WG0>cne038iJ<0_=bA0<cQX03Tm<L0
io;B0?ooo`80oogo01@0g=gO08ZAP@22Ueh0g?J/0<KSQ`3@iIH0f^^T0<gNU`1hOc/0VIYH0>;UXP3@
iYd0d_BW0<odYP32gY<0f^FQ0=3UX03<ij00b^RN0<[YW@80b^VI01H0d>^N0<kTW03Fi:L0joJl030m
1@2:X5l0dNnY0<_YX@3=j:<0dNbU0<WSVP3>iId0d^VQ0<oWW@3=iI/0dNVO0<[VV`3@k:40`mnD0<o[
X038ii/0b^^L0P39jYT02`38jiT0b>^G0<S[V@3=jj<0cNNV0<oU]03/o=L0lo[Z0>c_j03oool0ooko
00<0oooo04P0oooj0?Odk@3oooH0];JX0:RaTP3NkL80d>JU0<?MU03Hm:T0f_Vc0?7oc@2igI<0h_bb
0=GES@3Tl:@0c?6S0;3?R@3BgZh0`nRd0<G]^`1UK4<0fMF_0<;FU`3<iJ40g^f/0<cLV`39j:80`NFM
0<oc[@3Ll;40gNf_0=W][P2heID0hnVO0<?0N`0`<0h0WZ6>0>gnkP14G4@0Vk^D0<_h`@2fijl0[Mni
07Z[SP20Vfh0/LfC0<3ZZP36n;<0`OF]0;gWW`33hY`0d^RP0<CJT@35jiP0boRS0<[XWP3=ij00c>RN
0<C[W037jYX0eN>H0<cWV036k9T0a=b@0::GF@3<fI<0a>nC0<OdU@2mj8`0b>^G0<KUU@2DZV8;0?oo
o`002P3oool0401RFRT0l^g70??`d@3io^X0lok]0?Ool@3gond0m_o[0>cfgP3gonX0oood0?oln`3S
k_80OJ6Q09KKeP3Vool20?olo`1e0?_onP3oo_/0ookm0?Soo`3io_l0oogk0?okn00Z714020000?_c
l03oo?d0ooco0?_no`3]oO`0TKjg03YdMP3Io_L0nOoh0;RFS03oo?40o?oo0>_oo`1?RX@0;UA506Ad
C@0Q<P00:d<70:o^Y`2km[80f=jb0=WR]`36jK<0_=fT0:RcM`3?iZ00`>>A0=_i[`2UZ8T0m?GW0000
000920d0MGIa0?Ghl@3nood0n?So0?cmo`3ho^80nOoJ0<KUXP2ogY/0cNZW0<?QV`3CkjD0UjmU0;75
P02GX740ko;E0?Wak`3ooOX0YZ260>7Lb@3oo?D0no_c0?Sjk`3Ihl00d]na0<3CT`2BXel0cMfL0>3`
[`3Kk:H0fNZV06in?@19F1L0VIeR0>;QZ03Ti:P0k?Fb0<gQV@2ggHX0cO>P0<[RV032fY00eNnU0<[T
VP3Bk:80dnfS0<CJT@3RmZh0c^:J09FVG`38g9@0dNfS0<cZX036iYX0bn^O0<OZVP34iYT0bn^P0=_i
/@3[ol40cnFT0<WRX@3DjK40fmja0=oS`P3nonH0oogZ0?oij02MRVX0h>:c0;WRUP35jiP0a^BL0<oM
^P3:eK<0m?gP0080o?oZ05P0UI9M0>Ka]@3BijH0aNVO0<3YW@38j9`0bnNL0<3FSP2@XEd0J7Ld0<kS
WP39jId0b^VK0<gXV`3?ii/0cNNM0<7VV@36k9l0fOV^0<gTWP2Y]G<0FEXN03i12P3<eid0dn>U0<GP
V@3;jj00aNZL0<W^X035ii/0_MfD0;gKT`3GkZH0b=f@0;WUV03?okX0R;Yk0<CU[P1IIRh0`]2B0<OU
V`38iY`0dn:M0=7LVP3:fiL0cNRQ0=Ge[031iI/0bnVQ0=?RW`1EH1h0hnj/0=?TX03=kJ@0bNfS0;gQ
U`34hiD0d]VE0>g4[P3dlNP0o_ko0?olo`3onO007aL:0?kdm@3onol0o_oi0?Kel03oo_/0oogm0?ok
o@3ooOl0mo?b09nRT@2k`JL0Xk240=?Q[P3Jik40hNW00>odh03Nh]@0hnGH09^OR02Y[Y00iNS=0?oo
k03ooo/0oO_l0P3ooo/0D03Ie=40l>SV0>?Jd`3@b[h0no[V0?3je`3Wn<`0`MZP0<7JX`3eonD0nOo/
0?col`3ho_80noke0?komP3lond0m?[N0:^bT02CWg40f^Vb0<kUX@3UmKL0i>>c0=WGY`3BeIh0e=bP
0=WZX`1FJb00FVhW0=[XZP3Lj:X0enJQ0<gXX`30iXl0c^jI0<oNY`35ejl0Q6Q10<beO`3<ij00hno9
0>S`f02daJ40h??60<[WY03BlZH0b>ZF0=3[YP3>iZ`0i_3E0?Kmk@3nooX0m?O`0?col`26UfX0Jh53
0<SMT03BfID0e>FO0<gTW03UlZd0alJ60:FMG`3Gg9X0ionh0;cXV@37lZ<0_=bA0<G[XP33k:00`nbN
0<G/W@38jiT0bN^G0<_SU@3<h9P0^L>606aa=`3Ki:/0bN2J0P36iIT01@3<jil0cNbP0<OVVP3>kJ40
cNfQ0080o`0000L0b>RL0=KfZ`3;kJ40d?:V0<SXW@3;jj00`n>G0080bNZK00X0b^VK0<WZV@3:jI/0
c>nK0<[]V`3@k:l0bMn`075jI@3Lh]P0o_oo0`3oo_l0B@3oool0ooom0?GdlP3fmO40oooh01/T2@3O
jlL0eNRa0<;FV`3LlKH0]<^G0=kda@3fom`0d]N_0;^^Q01VJSP0HGi4000;000n:`d0OhmX0:_2V03[
hk`0alJH0=od/@32f900HehT00X5001:GR40GW`n06V;CP2kciX0a]JU0<CLZ033j;80^>Jh0=cohP3b
oo/0S92A0:nPX`3ono@0hM:m0<gBVP3DiJ40_>FG0;SYVP2<[GH0Fg]:0526BP2:aXP0W]^H0<Od/@35
iJ@0cmnN0<oPW02ohI@0_>VH0<WZV@3=jYX0c>^M0<7ZWP36ij80f^BX0<kTYP34hj00eNFV0<2_M`3Q
j:D0a>J?0<[^U038k9@0anRG0<OVV033hIL02`3oool000X0oooo0100VY9T0?oog`3imMX0n?k`0?Wo
mP3^onl0mood0?Sol`3ioo40o_of0?ojmP3onOT0nOoo0>Ooo`28dLX0i?oo0P3onol0o`3kooX0ookk
0?onn`3hool0oogo0?gimP3ooOH0Bd@j01D;0P3on_d0oo[o0?omo`3kool0ko_g0<KYhP1f/[<0h_oo
0>ollP2;JEl0ooga0?_oo`3Xool0Ql[30<oij`3<hKH0fNfl0;[FYP1OZVl0Y^fe0?_oi03doml0iooT
0>Woh@24TF<0//^B0<[a[P2jg9l0RI1_0?oom0000@00004408:4O`3nooP0o_om03Lh?@3hn_T0m_[O
0=gX_@35hj<0aN>U0=3]Z`39ij40eo>Y0<3HSP19GAP0SYMZ0>kaeP3oo?l0ooOh0?_[gP1oLVX0oocl
0?oon`3nooH0_l^U0>?d`03JkZT0b=VC0=SWYP38eiH0c^BL0<CIU03;fYT0d]bM055?5P0:1@00hMbR
0<W@S@3EjJ40_^RD0<_eX@3;iI/0b>BI0<SXW035iiX0b^bO0;[LS`33hYH0^mF;0=kdZ`3NkjP0TZIN
0<o[X@3?kJ<0bNVM0<c/X034iiL0a^RK0<GUVP3:jYl0e_:X0<[TW@3?j:@0`m^M0>O^^P2m`YT0oooO
0?ooi03on^<0cK^G0=7CXP31jil0`^VH0<k`X`39hZT0dNRb0?Oog@3hon<0m_oV03</003:dYL0a]JG
0=;dZP2lhYL0cNfQ0<gYWP3Mlj/0cMbI08bKF03JkjX0a^^M0<WZV`3=j9/0dNJK0<oWW@3;kJ40`^RK
0<[_XP37hY/0gO6/0=_OXP1TI2h0dMVP0<OBUP3Aj:@0`^2H0<7SU`2oi9H0bnfQ0=?cZP3Elj/0c>>K
0=c_X032kIh0YmfA086eM@2oiJ`0B5`Q0=S/[@3;jIl0eoF[0<KAS`3PjjT0j?fh0;oQU`31iI/0`nNM
0<[XX03>fYP0Yje]0=GPWP36fYD0_^BI0<?]X`35jJ<0f_V[0=KMV@3fc[@0kngP0?clo`3ooOl03PH0
0?ook`3onol0ooco0?cnn@3nood0oogo0??^m03kloh0n??j0?ono`3nond0n_oQ0=CVZ03AiJ00cMnQ
0=k]`P3kooH0nook0?_onP3@fK`0en:j0=oW`03fo>00mOOf0?Kgn`3ooo/0n_Kc0;ng]@3Rf]L0^kBZ
0?ool@3oon`0b]V^0<SLZ@3BlJh0dNna0??oh03honX0o_of0?_lm`3nnOd0noOf0?ook`3dnMT0/kb?
0:fmO03CjJ00g?NZ0<SIT`3Thjd0g]RV0>SU[P3EfI`0CelH04UM5@3LlZX0b]nN0<oOX03MiZ<0_MB@
0;cRR`3:k9H0d^J[0=O^a02]UV`0g/V@0;[DR`3]n=00aL^a07j=K03RllT0^]>A0;oNTP00:036k9L0
d?2U0<OTX@3Ei[T0mOoP0?cok03joo40noo_0=g/a@1EIcD0h_Nd0=_VY035hiT0aN^N0=C^Y@3SiJ@0
elnA07]j>P2_`g`0`nnP0;[VU`3?ljT0a^ZP0<G[WP35k9d0a^^K0<S[V@39jYT0f_J[0?Oob03BhJH0
g>Va0=;QZ031fi80do:T0<[YV`35iYL0c>bP0<?SU`35iiX40?l000070<7UV`2mgiD0bnfS0<OYW`3<
k:<0b^ZO0<WYW@020<[YW@090<[YV`3<j9d0`nN?0<K/U@3?k:X0d>Je04eI@`3bn^l0o_oo00<0ooko
04T0ooom0?ono`3oo_l0l>k_0?oon`3DfLD08R/<0?WofP3iomP0k?k<0<_M]@3`omd0bmRn071bG00;
000000P00<O/^@34ejX0oo7G0=WX`@3FkL40`;j>0:ZcNP2ohIL0i?nh0=[HV`1TGbL0838002=11@00
70001aL00>K]``3=g;40cNZl0<_ge03=mM/0ioOd0?coo`1^GF<0flS20?oliP2m_8@0f>>N0<c`V036
lYT0a>:/0<g^_`1:PDP03DX>05^IFP33kk00b^RZ0=OSY@3Lj:P0bNVN0<;]WP37ji@0bn^F0<_/V`31
jJ00anJS0=gU/P3Ml;T0cNV^0=GRZP2bW6X0fn2P0<cWUP3@kIT0d>fK0<[VV@39iIX0c^bR00/0oooo
000:0?ooo`3o0=KDY03>c:D0oooQ0>?[d`3Ghld0d>;:0=k`f03`onX0nOoa0?Sok`3oooP0ookk0?;j
o@3]ool0MK>`03mmNP3hool0oogo0?ooo@3ono/0oogj0?Son`3glo@0o_ok0?_on00V9Q`02`000?of
o`3olOX0o?oo0?7ln03hoo/0l_oo0=_oo`1DOGT0XK6W06I:?`3on^h0i?7g05MhO`3?ool0e_oi0?Co
iP34f[@0`n3404fPS00`Pg40i_k`0?7omP1BPfh0]N;;096NPP1/OE/0Q:b:0;gU``0<6`00Mh9b0002
000830l0?d=20827P02@UY80j>oX0<cDa@3?f:/0go2l0>_ofP3Wom@0a^VY0=Cd/@2ogIL0b^6I0=W/
ZP3@g:h0k?7C0?oonP3ooO/0oo_d0?okn039`Kl0bl_30?3hh`30eZD0/L^>0=_cZ@3=hIT0UZ1Q0::/
K@3?hih0e>VT0=S[Z`3:f9X0gMbS0<>lQ@2NUE`0VYaK0:jnM`2khXl0b?:N0<WSV@33gi@0cNnR0<W^
X@36kj40`>VK0<K[WP31hiH0anJJ0<kXWP3BjZ00[<Il0<_UV`39iI/0b^FN0<gXY@36hj00c>VW0<[W
Y03<jZ80a>>G0<g]X@3Bk:<0`ln?05UR:@3FgjX0hMjc0>7=Z02AQUT0fMjX0<7ZW03;mJ40`>^B0<[a
V037jYH0`n>H0<g[Y@38hZ40GU8N0=WJX03Pk:`0b^RP0<g_X`39jId0e?2U0<kUW@3Ij:<0c=^H0=?Y
X@36ji/0b>^I0<[YV@3?iiT0cnNM0<GUW03=lJL0bNnT0<oaY`37hiT0e>>P0>W//`1GF1l0jnje0<C@
T03[nkX0d>FP0=G/YP2F/6T0JH0j06Qo>@3AiIh0f^BK0<WSVP34j:80`nV/0:W8S`22VV00f_Be0<KU
W`3Fl:T0V9aO0=SNX03@ij40`NJI0;oTU`3:k:00b^JL09NSH@3Jhj80bmNE0=C[Y@2ojih0a_BY0<O[
Y@3BkZ40d]bE0:V;I`3KfL80oOWh0?olo@3ooO40l^[M0?olo`3lnOl0nOoo0?coo`3ooOl0ooco0?oj
o`3jmol0o_oo0?_ok03YnL`0c>>E0=K]V`3;i:00enjh0>CfiP3dood0k?cb0?Oog@3gom<0a=JR0?Wo
iP3_mOD0o?oo0>SWh`3ooo/0oogm0?onn`3ooo@0ooo_0?ooj03:g:`0dnf`0<;WVP39kJD0l_oJ0?Go
h@3nonl0oocc0?oimP3<b;l0`LJX0=kZ_03GiJX0dn6B0=W[U`2[`Fl0GV`Q07Yk?`2JVF00T95G0;Bm
O03Dj:00bN2H000j0=KaZP3=j:D0d>FT0>7ZY`27W5L0c_6M0<CVTP35gIl0aN6`07iR>P2oYG80EFlX
028b0`2U/Hd0mooQ0=W_`03=ijH0anFM0<K[W@3DmjL0c>fN0<WPW03Pl[H0b]^U0>;^aP3fomh0kooH
0>?dbP3Dj;<0UJi]0;g]X@2klJ<0d?R_0<[JV@3MgZ80in>V0<C?S@2M^g<0a>JL0<CPUP3?iYh0cnNM
0<gWW@3<j9d0bNVM0<WYWP33i9l08dH40;OHW`3Blkh0hoo90<ORW`3@jZ00c^ZO0<OSV03;jYh0b>RL
0<SZW@@0o`0000P0aNjR0<O]XP34jYl0b>jS0<3TVP3=kjD0b>ZN0<WYW@<0b^VM00H0b>bD0;[NQP3A
kZ`0cN>b0007003an^T20?kon`030?ooo@3oool0oooo00<0ooko04D0moOg0?komP3monh0fnC70=[S
a03Cg/00f>C>0>7^g03eood0n?om0?7gj`3aoo80gOoV0?3ok03hk=@0f>o50<SV/P3Dhj80R:UJ0<;g
W`2eiI40cmjI0=oYZP3EkJl0b>JZ0<_X/03Oi[`0o__H0?[ee`3iomd0];RG0:f]T@2^Zj@0PWf106AT
HP042000Yk2C09^]L`2[`7d0c^NS0<SQX03Cj[h0`Mfd0<[l_`2VgI`0DXI404e[=@1LK3/0RI1M096H
HP35eiT0bn>U0<GVU`38jYH0d>RJ0<?WW@37j:<0gn^k0>Ojc@3boml0o_oM0;>HK@3PgZD0d>BO0<cR
VP3;hY`0e>jW0=?^Y`39iil02`3oool000X0oooo0>40eN2V0;JoR03[m;l0h^bh0=CR[@3@jK80dNjf
0=Sf`03Ln<L0g?C40>kog@3hooH0n?oo0?7ho`2lgNH09Y220=Gno`3lo_l0ooSo0?oin`3ooOH0l_of
0?Kon`3loo/0nocd03/^9@0W5Pl0oo[k0?oko`3fo?`0nOoo0>_fkP3^ooT0j?oo024e=P1SJ6@0>bdR
0>WWfP3`ool04SDg0=_oo`3Mool0mOof0=k/e@3Pklh0CYJE03:2P`3Ron/0l?oX059oJ`2fh//0YJen
02/W002kgl<0_>cB03MA=P1kSWX072LI00H41`0h=Ch0Q8^A00lM7@3Gk]80cnBi0:VjM030fIL0gooZ
0=koh02ihZP0b>n^0<KWXP39h9P0h_Ja0<cJY@3co]@0lOWQ0?cok`3lo^T0o?_W0<o?]`2DVG/0LgmI
0<KSZ@3<k:/0cNfT0<;LT`3EgY/0Nh0n0>_//P30cY00`^6M0<WZY@3DijD0f=jP0>7OY01QFal0LGHd
0=kh[P36hYL0c^2F0=CUWP39gIH0eNVT0<cSW@3FkJL0c>ZR0<SXW@3>kZ80doRX0;gNS`28We40d>JK
0=?VYP3@gjH0e>6e0=[Y`03<h[@0cNRc0<?SY03@nZP0a>bF0<SPUP3Ll:P0Y[Ma09VXI@3BeIh0in6a
09:>GP3KhjX0a>NG0<S`V034k9@0_mj>0<k[V`3@jZ00bN>J0;oITP1HE1L0fn2N0=gZY@3:i9/0cNbP
0=3`Y030gi<0cnVO0=[ZX`3Jij80e>BM0<[YV@39kiP0`^RA0<_^VP3:kId0anBQ0<cYY`35i:00b^ZQ
0<SZW@3>kId0f>BR07am@@2TY6P0i>:W0=cGW@3Fe9T0hN6U05AH6`0oA@L0:C800;o8R@3PhJD0j^^a
0=;EWP3JhJh0e^2/05E]<`3AkK00_=ND0=?VY01aL300h^:R0<oUW03>kJ40b^VM0<o[X03<iY`0U:YR
0<cPV@3?iYh0b>BJ0<G[WP37kJ00`nBE0=[bY03BgiL0GE<R0;fgU@3on_<0ooOg0?CXj03ooOX0oooj
0?[on`3gool0m__o0?olo`3ooOl0ooco0?koo`3jool0moo`0>Cbc`3GiZd0cmnP0=7XY03?iZ00gO?=
0?;ok@3doo40h_Nn0>7f/`3?fZl0o_oa0?gln03ooo/00P3oood0D03oo_l0ookm0?oon03monl0o_oZ
0<WKZ`3DjJh0anFK0<SXW@3Hmk/0g?2k0?Ceb`3/j/<0YZ^308bLK`3El;T0d>V_0=KX[03DeIT0i^FU
08N8@P1OHQd0am:>0=WXY@3AjZH0cnfW0<;RV@3:jZ40dNnY0<cUX@3?iZ80f>nW08>OE03:jIT0a>6A
0=7WY`34fjD0OE@f0=6YQP1VP4<0Pj9W0=_na03Kol40b_6^0<S`Z@2jhYT0`mnB0<_XV038hiH0d^VQ
0<OLU`3EjZT0f>ba0>Wla03gom<0h?Fl0<kRY`0oCQ<0bN6S0<7KW032fiX0dNBT0=[VZ03Qjj`0cMbK
08NKEP2DZ6<0b]^E0<oUW@3Fk:@0dnZR0<[QV@3;iYl0bNBO0<WVY00P?P00^]VN0<k]/P3CkkD0dnJ^
0P3Bi:P01@3CiJL0dNNV0<kWX`3:j:00bNVN0080o`0000<0aNbK0<?]V`33kI/02@33kI/0D`3=kIX0
cNRK0<_PZ03@hKL00@h00=_Xc03lonX0nOoY0?komP3jo?T0noco0?coo`3lood0o_ok0?gon@3ooo@0
o_oa0=oWdP3AfL@0dmc90=KQd@3Rk^00nOoj0?Won@3hoOT0n?om0?Con`3gooP0o?oY0<gO^@3Jl;l0
a]ZC0;cGQP38jiL0bNZI0<oWV`3?iid0c>NP0<[WY036hj<0fnfi0?Cod`3momh0nooP0?Sok03hond0
n_oY0?ook`3ZimP0QGmc07]hJ@2h^Z@0cmVg0<_OZP39hj@0bn2g0<cS^@2afI00c_>U0=CbZ0031P00
10@006abC01EH3D0NGmC0>CN^P31gj40do:/0=[TW`3Cl9h0b^fK0=?//P3El<<0l?oZ0?_oj02RQV40
knZb0=7[XP2kfhl0e_J[0;[JS`3BlZL0`n>H00/0oooo000:0?ooo`3Q0<cLWP2IYFL0f>BT0=GQW`3B
hil0a^BN0<KWX037k:H0b>^Y0<[XZP3Pm/P0mooa0?Goo`3kool0h?Ko056o/P3Hool0mOoo0?obo@3o
no/0ooke0?Gom03doo`0l_Ca0?onn01eI5X06@P00?cbl03mnOP0l_Sh0?;kn03iood0n?om0?;oo`3W
k>l0S8^701hJ4@2^]:X0hOon01Y4@`3Lool0i_oo0?OonP3konl0nooS05FGX`0_OHT0f?oN0=7^`P0I
AS40/^360<7;S`1NDad0doKH072UR`0<;a40cnO?01<P3`030080MG9m0?Soo`2K[Jd0QJ:30<3LZ@2j
dH<0U[A/0:oP`02Yek00/]fW07BLG@2beI40c>NP0;gFU03Hjk@0a]N[0>[ifP3honL0h^W70=[R_@3G
i;P0d^:c0=KZ]@3DlK40_mjK09B_JP3>hih0hNjY0=CKV02KVV40KgTm0<g/Z03:jj@0a=fI0<cKVP3R
j:X0VYQK071b<@2R/F`0eNJP0>7^YP3DhI/0f^FQ0<cGU@3KjZT0bMRG0<kUW`3:iY`0`^:F0<S_WP34
jYL0[lIf07R=@P37eIP0hnfi0?Sog@3bnmh0mooT0>?jc034hjL0[m^60<?^U@3<i9P0amnC0<[QT`2D
YU`0jNnc0<k=U`2GUf<0gNFZ0<?RU039lIT0b?2G0<OSUP3CkZ40c^JL0=3XWP3Bj:00>Sd00<cFT@3L
jJ<0c>JL0<o[X038j9`0`N2D0=OaY`3IjJ80b]F@09NSF`3;hiD0an^D0<;ZTP35k9T0a^^N0<oWZ`3R
mkl0c^>Z0<WSY038jJ80a^VI0<gQVP2k`800Y:IW05iH701NEA`0Q7U106=J8@2l^X40h^>Y0>7WZ`0h
?P80MgPn034W001_Hc40EdlP06QZ>01CJc40T[1b0<_UY03Qm;80XYiO0>7RX03=hYL0b^JI0<STU`3<
iiX0d^ZP08VSF@3GlJL0d_2V0<;PUP39jil0`nFH0<ORT@2neHD0h?2W05AD7P2m]Hh0ooW]0?KThP3o
n_h0mo7c0?konP3bnO80j_Gg0?_oo`3ak?00oo[n0?omo`3kool0mOkk0?3nk@3KjLl0eN2e0=?O[`3A
iJX0dnRS0>;gc03don`0m?o_0=?YZ`3EjZD0en6l0?oomP3oo_/0ookj00@0ooko05L0oooj0?_ol03l
on`0bmb_0=3U[036hYP0b>RM0<c/Z`3Ikk40[:mh0<S8TP3ChJH0e^b^0<g][03Akjl0b]jQ0:6NJ@1Q
FR<0Sha90=?FT`3;g9H0_]F=0<GYX@30iYd0f?bd0<SYXP2ng9H0cN:O0<kUW`2<ZV00f_Z^0=3/W`3D
kZ@0a]ZK0=[_]`2FI4d0gJ^D0<KOZ031iJL0_^VR0<G^X03Iok@0coFX0=Gk[P3<i9P0e^jR0=?^X@3<
iYd0enjV0<WSW03Km;00`mVH0?Ooc@3Xol00gO6d0;C2Q`1QKSH0>4L<0>[l_P3IkJh0`=BE0>?h]`3;
gY`0g^n[0:jmNP2N[FP0eNVQ0<[PV03LlZX0bn:L0=Sa[@31fYH0ZlF405af=`3?jk00^mVM0?Cod`3f
om40d^2[0<SIXP3=gjD0d^RZ0<kTX`3<ij00b^RP0<SZW@36ji/01035k9T05`35k9/0a^^K0<K/V@36
k9T0a^^K0<S[V`38jiT0a^^K0<oZV`3?iid0c>2[0=7R^0003P00enO20<kM]03Hi;h0n?o/0?_onP3j
ool0n_on0?_oo03noo/0o_oj0080ooof03l0oOoe0?Oml@3ioo@0m?ob0?Kom03hoo<0o?of0?coo@3i
ood0mO_i0?Onm`3/n>00i?C?0;C6U03=hiX0Z<1/0<gXU`3=j9T0c>VI0<[YV`3:jId0b^RP0<[WY03A
j[00goJn0>;caP3RlLH0fNk?0>?gf`3gon00oOoQ0?ooj029P740O79Y0=cGd@3bm>H0k?oB0=oh_`0a
@A`0Ffe50<o`W`3ImJ00dNBE05I>:@0_:0h0IW5?0:foU`1oPeh0A3HL0:k9U02og9`0gmjN0<[PS@35
ii40b^RZ0<7N[P3/on/0m_oY0?kV`P3=c9<0c>^O0;oTUP39kZ000P37jI`00`3BlZH0oooo0?ooo`09
0?ooo`002P3oool0hP3KhjL0T9YK0>3/ZP3>i9`0cnVP0<c^XP38k:80b>bT0<_UY03=hjD0h^k00?oo
k03good0lOoo0>?oo`2di>H0OK:f0<S]l`3moOl0kooj0?;on03mm_00nO[l0?WhmP3ooOX0^:ZQ01L:
0P3on?H0lNo`0?coo`3gn?`0oooo0?oonP3lmNd0Uhj50:fVWP0A6QL0BUmR0=Soo`3<ool0[nKS0=[o
m`3lonX0bm:`0<SO]@1_/[X08FM_0<G/`02mejP0Nk2B0;Oab`34hYX0g^FR000T002gj[l0^>Ba0<?R
``003P0000<306U_K`3[noP0_=3>059`IP32h<P0Yl>80>Oob`0060H0S:bD0620E`004000@V<Z0<SX
Z@3=jjd0d^fh0<3GZ@3@i<40BEDa0>WW]`3=eJ80l?o@0>goc`31i:80d^FS0=KRX03<dHl0Uj1M0=O]
Y034fi<0enRT0=7MV`31bXT0UJ1N0=[[Y`3;hY`0an6J0<?JU03Bhil0WjAT08J=BP2;X5D0FFXS04]J
5@18Ea80GF`[09:RH@3Mlj/0`mZB0<_UV`3NoJl0]mJ60<COT03<i9X0/L2708bHIP2CVgH0Qi5^0=KW
^`3DjkD0`n2N0;WORP37kIH0c>RM0=GaY036hI00goJX07n8A`36bXl0VYeV0=CLX@3?jIl0c>nK0<7Y
T@37k9`0dO>V0<cVW03DjZ40_m2:09JPF`3Gij00eNVQ0<WXW03:k9l0co6T0<SXW03=jIh0d>6J0=k[
Y@2^^G@0e^ZR0<_ZWP3<k:00a>6N0<kV[03Xl/l0o?oU0>W]e03Uk/l0i?C?0=kf`P3Gkk40eNZY0=CT
X`3MijP0gnRY0>7WZ@3IhZ<0b]VF0<GFTP3EjZD0[<5l079n?03Xk:l0i^N]0=SMY@3Ch:P0RjU[05n2
@P2ohZ00a^2O0=7KW02V/Fl0dnVP0<gYWP3CkJ<0c^JL0<cTVP2kdhT0eo6W0=CbZ03AkjD0`N>G0<k/
XP3Fhid0hNbW0<WCSP29S5<0dLjQ0=_E_`2DS840oogo0?oko`3oo_l0o_om0?Won`2_]:d0ookh0?O`
jP3oo_X0nooi0>cfk@3eoo@0loo_0?GoiP3gonP0mooZ0>Kdd@3Bglh0g^_Q0>ollP3<h:l0dnJ^0?[o
i@3noo/0ooko0?cjo`3oo_l20?omo`1J0?ono`3noo/0o?of0?7kh`3@hkD0dNZ`0<WYWP3=kJ80fNn^
082DE@3Rl[@0a=:D0>Ge]P36f9X0f>b]0<oRXP29UeX0V:9V0=_UYP3:gYH0bn6H0=3ZX@35hIL0dNnU
0<k/XP3Uo;@0a]bD08ZNE`1`OCP0Z;Uc0<KTVP3Dm:T0bnVS0=C][03Fj;P0Df@j0<nIS@3[/jH0go6o
0;_GW03>kJX0e>RP0=gaZP3TmJl0dN:K0=[d/`3?jJP0`M^J0<cVY@3Bk:d0bnFV0<gWZ02nf9/0aMnR
0;kHV`3Pn;X0fo6a0<cRX@3>ijD0I7ll04ER7`2P_GX0e?6^0=G`Z`3>ij<0a]fI0=CYYP1dRT80SJ=K
0<oUW@3GkZP0eNbX0<kUX@2bb8P0AU`N0=CY[P32ei`0f?2f0=;Y/@3/ol/0koo<0>Goa03=jZP0anJR
0<WYX038jZ00a^^M0<K[V`38ji/0c>RM0`3?iid20=3VW@80dNFM0`3Ci9d03P3=jYH0b^bH0<WWY`3=
j;<000d00<[U/03>ijd0bN:X0=W^``3TmmL0kOoY0?coo@3oool0oogo0P3oo_l0@`3ln_l0o_om0?ko
n`3jooL0n?oc0?Ool@3Ulm80en;20=7K`P3XlM`0nOoa0?CojP3/o=P0e^Nk0=OZ/P1?Ia/0/LYg0<gX
V@3=j9/0c>RK0<[YV`39jId0b>ZM0<_[XP35i:40bNFX0<OPY`39h:X0b^>/0<7JX@3bolX0hnfh0>KT
_P2ETG@0>S<Q0?Wfk@3loo805RL70:k5V`0l@RH0Ri9`0;cHR`39iY80f^nR0<[;X`1VJD`0QZEk039J
9P2Zci/0]/^R0;WDW@1mSe<0J60R0;6iK03TmjH0_]:C0<3FY@3Pm]80k?OE0?_ea@3>hIl0anbO0<gb
Y@2ohID0dNfS0<WSVP2aaGh02`3oool000X0oooo0>40eMJJ09FNG@3IiZ40b^BJ0<c/X035k9d0a>ZM
0<SZX03?iJ@0d>2R0=cT/`3?eKT0koG[0?KonP3aool0l?oo03UnN`1f/[00oogo0>gmo03`ooT0ooci
0?ono`3oo_d0oogj0:JIT@080000oo_k0?ono`3nool0ooko0?7/l03on_L0SGe`05Q8>@18?S@0F6=U
02E2B03Dool0c_oo09C?b@3LooH0n_oR0>;]``3:ikT003Ph00a<CP3@kl<0d>Bc04^1G@21`9D0^^>E
0=g^Y`1OPDl0/=j]09G2Q`2mgkh000P00009201_NG00m?oh0;K=``1MNWP0UK6U0<WU/P3Nom<001<<
0<Som@2fg/@09TDS06=jD019F240WjY^0=CRY03MkJl0VJic0;O:T`2SZH<0dm^b0?Sof03`oll0a=jQ
0=7XXP38gY<0h_FS0;k=N03TlYX0dn:=0=g^Z03@gIP0U9eJ049;2028VE<0e^fU0=7[XP3:i9d0cN:M
0=?LV`3/mK80eNbN0<?HS@3;g9H0e>FO04=D401:FaL0bMfF0>Kl]02neX`0eO2S0=?`X038i9L0an6H
0<KGX02T/X40e=ng0;K0V`3AhK80amZR0=_d/P3:k9P0dO>M0<GTV03BlJ<0`=f;0<oXU`39e900KW8e
09jQJP3RjZl0a]jD0<KXU03;lid0`>VJ0<[aXP3?jj40cnFM09RWHP3@h9T0f>jU0<cVW039jih0bNjP
0<K[W@36j9/0c^fQ0=WZX`3RkjT0X:]V0=GYXP38hYT0b^FN0<WSYP3Jk;`0ooo/0?ool`3on_@0oood
0?golP3gon@0go_10<gZZ03;iZ<0aMRH0=KVY@3=gYX0g>fY0<_RVP3@k:80c^bR0<cZX03@i9d0e^6O
0=CMWP3IijX0e^Z]0<OZZP2/di80anj[0<SXY`3<gZ00RIaL0<cVW`36h9L0bnFL0=7XX03@iYh0]/f5
0=?]Y03Bl:H0d>jT0<;TV03Ak:D0h^RZ0=[OW`3^lk40FUhS05MI9`2b/ID0dM2n0?gin03dl_D0ooko
0?[jnP3`n>/0MWU^0?ojl03oo?80ookc0?Omk`3PkM`0m?oc0?Col@3honl0nOoa0?Won03joo80locg
0?Goo03hood0d>6e0=OY]@3konP0o?oj0?koo`3lnol00`3ooOl0D03oo_l0o_oj0?[olP3Ji/h0aM^/
0<cX[@33j9/0aNFI09JYI`3AiZD0`MNF0=S_Z`38fiT0ho6c0=WUY`0^>P00B5@F0=7QXP3;h9d0cnnT
0=?aY`3Al:@0fOFZ0<3JT03BjZ00@eL?05MX8@3Slj`0`/n90>[j/`33hIL0_=bA0<WVY03>ijd0fNW2
000;003UZjL0kkB/0;g:W03IlKL0bNFX0=[a_@3EjKP0c=j^0=[/^P30fJ00c>F[0=C]/`30fIl0b>6X
0=7Z/0003P00e^ne0=ce^`3Bjk40]]2A0<gVY03;iZ40d_2Z0<GTWP32hi`0cNjW0=?d[`2ngIT0b>FR
0<3KV03DkJT0h?N_08bSF`1eS4@0_]F?0<SMVP3<hIh0bn2O01lc003@i:L0g_:e0<_PY@36hZL0k_o@
0P3aom40103ClZl0bNZU0<SZX038jZ020<SZW@0I0<[YV`3Ci9d0e^>N0=?TWP3AiIh0cNNN0<[XWP38
jYh0aN^N0<;]WP31kIh0_njN0<K^U@38k9@0bNVV0<_Z[`003`00anBZ0<WXY034hIh0b>>/0=Wca03^
on00o_oj0?ono`020?ojo`140?olo`3mn_l0o_oo0?koo@3jooL0l_oY0?Coj@3Xml`0f^Ni0=;Q^P3Y
mm@0nOoX0?Koi03homl0gNnm0<_PY@36gY80eNjK0<gXV`3=iid0c>RM0<[YV`38ji/0a^^M0<SZW@37
j:40bnZW0<[VZ@3;i:X0eo:_0<_UWP36fYD0bmZI09NIJP1JFSH0MG5H0>_/gP3foNd0QYIi0=CXa@1W
JE<06ah00=OcZ03ImZ80fO2R08b>IP1PIdH0a^bm000L0037nKh0^=j[0;oLY03JjJh0THQ=06EW7P36
dHD0fNNY0=?Q[P3Ch[/0jO7<0>CW/P3;iYl0a^^N0<g]Y037iId0bn:L0=[^Z@2>VUP;0?ooo`002P3o
ool0103RfY`0f=fK0=?SW037k9`20<;/VP0=0<CYV`3:j9h0enJU0=OPX@3Kgj`0d=Zg0?ook`3ooO80
noWn0?oho`2`oOD0>8^10?_oo`020?Goo`3o0?gno`3mo?l0nO?e0?oln`2_YI`04`X107akM`1lO7`0
OG^00;nf^`3onol0J5=@09AmK`3om>H0oocd0?;lo@3^ool0I9VM07:`[`1VX940JYb307:>IP1iUVH0
Eh=607^bW@2D`jl0F6D_0;g4SP1NSF40OK^80<3`Y03Fkjh0F6i00;cJY033jjD0b>?40007003co_X0
XJjD02Xl4P0C9PH0go?b0?7oo`31gjT0[M>P02AOF`20_;80ZnO;01A>:022^XT0`>b_0;gTX@1HKRH0
NXE009fLF@3Wk:T0a>BK0<cUX@2AWf40d>2R0;gAU02mhYl0_NJR0<od/@3Vol40bljG09RFG@3>e8h0
bmR@0:c=OP3CmZH0aMnE0:nnN@2V[f`0`lZ70=WUX`3Bl:P0co6U0<COTP3CkJ<0d>JN0=CXX`3Di:<0
dN6P07F4@@2DXeh0`m><0<oOUP3LlJH0f_R`0<CNW@3YnlT0ho;70>Ocb`3Cg[@0i_>m0;30PP2[_gX0
h_Z^0<WTU`3BlJ/0aNNK0=GgX`3ElZ00bm^B0=[QWP1kO4<0];Yn0=S/Y@3;iYT0aNJE0;gVV035jYd0
b^JL0<oVWP2FYF00b>BI0<GTV035iiX0ao2Q0<C]WP3=m:D0aNZL0<OWV`3>i9/0c]nH09FRG03BiYh0
cNVO0<_YX`3Uo/L0m_oM0?oomP3oo?l0ooGo0?ojo`3onOl0mooc0=klbP34jJH0b>^W0<7PW03>jJ@0
dNbU0<KTVP3FnJT0_nBD0;_RS`2mhi00cnbL0=C/X037hIL0a^6J0<[YY@2ggY/0aO2[0:;?S033kJd0
an^]08FUIP30gYP0e_2Y0<cVW`3Bij80dnVQ08BJDP3CjZ80e?2V0<?RUP39jih0bN2J07A/>`2TWfP0
kNfa0<W?T`2NYFl0e^2m0>?[d`3cmO80oooo0;Vd^`3oo_l0o_oh0?oon01=A3l0oo_b0?ojkP3gonL0
d^720=?[a`3CjlT0go;D0?7njP3nool0o?kk0?Oko03ho_`0nooh0<oL/@3Ci:h0f>Nl0?WojP3jooX0
o_om0?onn`3oo_d0ooom0?oon`3loo@0noo_0<cK^P38i:X0c^nZ0<K`VP3:k9P0YK1/0=KZY@2jg980
`^BH0<WOU`3BfiX0GedP0=gMW@3PjJP0f_R`0;CHSP34jYl0^mfA0=GaYP27WeD0bMjA0=?UV@3Jk:00
hoFY0<GJS@3Yok@0`]Z>0=_i[`2feHl0d>ba06n7E@3RlM@0nOoa0<22Q`2fM7H0i>W009n`N@002`00
7AP0089mE@2JTFX0VhmY01PY003NklD0`mBX000V000:001HJSX0hO?30:foR`002`00`=>L0=W/]@3B
iZT0cNBN0=C^Y@3@k:80`>2G0<KVW@36ij00`N2L0<?RW`1ZQ4<0@U/J0<kWY@3CkJH0c^FM0=C[X`3=
hYd0Nhi<06Ym>`3?gih0hO6b069`<`3Jj:/0g>jb0<gY[033hJ<0cN^[0=cj^P3Rokd0g?Vf0<[XX03<
j9h20<gWW@050<[YW@36jih0aN^P0<G[X036jZ000P38jZ020<WYX080b^RP05@0c>NP0<W[U@37ji@0
anNT0<[W[`003`00bNN[0<WWW@3;jY`0cNRS0=G_/P3Jl[h0j^oK0?gjl@3ooOl0ooWo0?olo`3nnol0
o_oo0?con03ioo40d>:j0<OM[03?i:40eN^S0=O/Z`3@i:L0c=nX0<kSZ`2gc9<0L8I80:k7Q@3>jI`0
dNbK0<gWW@3=iih0b^VM0<WZV`36k9T0aNbI0<O^V`37kYl0anbN0<SZX038jJ80a^>C0=;^VP3@iIH0
d^BJ07R3A`0X<@00K7=703Do702e`9h0mOoR0<WM^00d<B00K6aB0=?aY`30h8d0foJY0=kS^P3JgKh0
[<bK0;[W[01aZ6D0CW]20<GY[037hJ@0d]RL0=GFTP2`]W00Hf`]09JKI@3VhKL0S8=H0;VoP`3KnJl0
b>>L0<oTX@3AiZ<0eNBS0;W5Q@2=TeD;0?ooo`002P3oool04031]GT0g^6N0<_KU039l9l0_NZE0<C^
W036jIT0c>JM0=WSY03Igj40gmn]0=kR_@3oon`0oooa0?olo`3omOl20?l0003@0?7oo`3Umo/0mooo
0?koo`3lnol0noGg0?omnP2QV8l03PL0004000071`D00`0003hd=@3Xf=T0LUYF0=W5^P3on?00oocf
0?[no@3/o?/0KiZC04AhK02djm@0_oCF07>KMP1]UfL0BW/i08k0W@34jLP0VImQ0;fnQ01eW6l0P;J4
0;OTW`36gJD0RiYa0:o3T03>kJT0bMg102Dd;`3Tk^H0gn[806Ac?01:FRd0m?oj0?;onP2lfj00/m^M
03mdFP1:PF80OkR?019<701o^8<0]nV/0<[f]`2/c8d0Uk5d0:RjP03EjJ`0a^NR0<k[Z@25WF40e^ne
0<WV[02?]GX0GHE90<g`]P32gZ@0gnbg0;6fOP37b8@0g>bS0<ggY@30jiT0e?2U0=?PV`3LgYd0hN6Q
0=kYY`3<lZL0_^NI0<_WW035giD0b^6K0=CYYP3@hj40dN6R0:^gM`1aOC/0io:^0=ORW@3=gIH0c>ZT
0<cVZ@3aomL0mooP0>?_b@3:eJX0aM:J0=KTY`2R/W40`mN@0=G/Z02ng9`0bnZT0<3QT032ghd0f^ZQ
0>3YYP1TIB/0Wj=X0=WZY03@j9`0cNbN0<CVVP39jIh0a^2G0=C[X`2]_WP0anNK0<[/W`39kZ00a>fN
0<7/W039l:40`^NI0<[ZWP3DjZ40c=fF08^KE03<hYL0b^VM0<KVW@3Rnl80k_oF0?[jlP3oo?l0oo?o
0?ogo`3oo?l0n?oh0=;^_P35j:H0c_6]0=?b[P3<jZ@0bnVO0=3_X`2ohY80anfJ0<[aWP36k9L0bNZI
0<c[W@2ngHl0`>:F0<__Y`32jjD0`njY09C1OP2jiZL0`Nf^08:YJP2C/6d0dNZV0<oVX03DjJ@0e^^V
09:XH039h9P0cn^Q0<_WW037ii/0cNBN0:fRM03BbiD0jnV`0;_1Q@2OZ740e^2m0>3Zd@3`l^l0m_Kh
09fHW`3oo_l0n_gf0?okn01YGeh0oogh0?;[h@3lonP0enO20<gW^038h[D0hOK?0?OojP3ko_L0oOoj
0?coo@3looP0noo`0=;O/@3GiZl0b]^U0?Wog`3eo^d0o?of0?oomP<0oooh0500o?oa0?_ojP3:f[D0
b^JY0<_]X`33kY@0b^bE0=;KV03FjZ<0bNjQ0<7VV@3CjJ40^;ml07Uc=@3WiZH0cmRE0<g_X`3;m:H0
`nBM0=7aZ02AZEl0R9eB0=GWV`3FjIX0bMjA0<;IR`3El:40^MR:0=3_X`2nfI80eO:_0=3//P0`B1P0
j_SO0?Wol`30PHX0m;:f0=cN]`2]^XD0Kga4024N001oNdh0bL:F0?3W_0002000dmni0=KR^P044@00
IgA80=7N/039ejH0:3H306ekAP36eIh0b=NL0=;VX@3>i9/0a=bB0=GaY`35h9T0cN^S0=Gb[`3=ijH0
c^BT08jTI01TN3T0V:mY0<gTW03Aj:00cnBO0<7DTP16FAL0W:a[0=GSY@3FhZ@0fnNY0<cLWP3;iJH0
c>VY0<k[Z@80o`0000<0aN2K0<gWX03?iYh00`3@iYd0103?iYh0cNNP0<gWX03=ij020<oVX0@0d>FP
05@0dNFP0<cYU`38jYH0an>V0<_V/@003P00cNJ]0<gYW`3=j9T0c>JM0=;[ZP3@ijl0gNC50?Keh@3o
ooH0oo_k0?omo`3no?l0o?oh0?_olP3gonP0c>>_0<_SZ@3@j9`0c^FE0<cRV@3@iJ00dnVY0=;XZ01K
M3<0Y;ek0<KPV@35hI@0anBB0<gWW@3<j9h0bNVM0<WZV`36k9T0aNbI0<O^V`35k9/0`nZI0<O/W`3:
k:80e_>S0<_TT`3@iiT0]LYo0;2oOP2DXVL000`0028_0@3Tm<L0n?oO0=k`aP1aL5h0KViF0;oOUP3B
lj80GWT/0=gN]03Mg;d0X[V;0<7W[02^gIT03cL00<C^[`36jZX0f>Z/0=GLV@3LiZ40Ef0Q05QK903V
eJT0YI9W0>GVZP32g980bn2K0=?SXP3BhJ00g>RX09JPH@2HWV0;0?ooo`002P3oool03`2SSUD0fm^K
0=KVW`35kid0a?6N0=3cX`3CkJ<0b=VC03i41P1GFah0knfj05E89@31b:T0nOo/0?O`jP040?l0000:
0>[oo`3eool0n_go0?_oo`3oood0oooh0:RPT`070000cl^o0?oom080oogc06X0EDDh01H6001eL6d0
ooko0?[dm03oooH0m?;U0?SojP2keK8002d6000c3@2flm80`?_?0;kbZ037kK80b^J/0=gPT@2EU540
l_oI0>kog`3PoLD0n?oP0=GH^@2IX7@0h>^a0?cok@000P00l_KX0<W@Y02R[F40R9=>0>Wed@3eon@0
aNVS0<KbW@32liX0^^JA0;gNU`3Bl;00]mBL0;_L/@1WSFH0AWiK04R9J@18UgP0:fa<05UZBP1ROEX0
BGUA000J001AQ5T0SK:60=3]_`2R^HD0T:aa0;7IT`3IoKD0g>VT0=?YX@25ZUd0d?FX0<cVW@3KjZD0
f^>P04iG502@XEd0_=jD0=Kj/03@jj@0dnjY0<kTX`30eYH0en^^0=WX[@3BgJ40VJ5U055G6@3?e9@0
dM^L0<_UZ03Fk[X0mooX0??oi@3VlLl0cmZ`0=KSZ`3ChJH0fnR`0;6mR`2Z]hT0hOO80<kW/039i9d0
_=J<0=k[X`3Eg9P0VIUM0>OX[03@gIP0en^S0<kTV`3Cij80enbW0<WNV@1nUDl0a^2I0P36jid06@35
k9d0`nbM0<?/W@39l:40b>fO0<7QU@39hIL0c>:I096WG03?jYT0a^VE0;kST`3:j:X0eN^l0?kom03o
o_`0oo_o0?omo`3nool0l?k]0>Goc`36iJ80e?6^0>koaP3El:T00P3<j9d0Q`3:jI/0b^VI0<W[U`39
jiL0c_2L0<_^W032j9D0`nZK0<_aY03Ho;@0b^nY0<7ZZ02:]gH0^>n^0;_/Z`3AlK00d>JU0<cRX@3:
gi`0eNRV0<kSWP2F[6@0dN^R0=SdZ@3:jId0d^NR08QnC@3IdYh0fmRQ0;NlQ02^]8@0o_oX0?[ok`3b
m?4000020?ooo`3gmoD0l_G/0?_jn03onol0oo[o0?omn`3hon80f^^n0=7^[03<jJH0iOfo0?Soe03N
i/40j^oH0?cok@3goN<0ino:0=3JYP3eolP0e>>P0<kLWP2[]i40nooX0>oaf`2][iX0loGP0?ook@3j
on@0n_oQ0=o/`@2meY@0_mjB0;gRQ@3AkiL0gnZU0=KZXP3AlJD0anNK0<[KU02GWUX0in>S0=cMV`3E
hY`0cO:T0<3UV03^o[d0SYmK0=k^Y`3EiI`0`mJ70=?ZVP37iYH0aNRH0<O]X02kjIh0a>jT0<7JV03C
kJ`0c>R^0?3of03gonP0kokW0:a_MP3;RH/0j^c70;G1T@3Mkk/0a]j^06UoD@1YO4l0e^Vk06ibC`3X
k<L0_lBL00dB00011`00H6Hh05UP;@13BQL00@P0079j@@39diH0IG0/0=o/YP3Xn;40^Lf60=S/Y`3H
kJP0b]fK0<;ET`3[nK/0d^2R0<_IV`3=hYd0cnJN0<WPV03AiZ40en^V0=3TW`020?l00005065`;`11
D0l0B5PG04QM703Gl:l0103o0000<@3>gi/0/L1k0=CQV`1CH1X0DE8@06IC6@1[D1/0J54K06IC6`1P
EQ/0GELK05MG6@1AEQH0gNVW0<kMVP36eI80aM^@0<cSV`3KkKT0b=V]00@C003Di;D0f>^Y0<kOV03K
k:H0cmnP0=SU[@3OjkT0`LZM0=WO^`3Qi/P0ooo]0>c_g03TkM00g^[60<CDY`2jdi80b^BM0<gYU03D
kYL0`]^80=ohY`39i9L0`MfB0<WUV`3?jj40cNbP0<GTUP36iIL00P3:j9h0<039jId0b>^K0<K/V@35
kIL0coNQ0<G[V039k9`0_=b@0=cj/038hY/0UZeW0;gBS`3BijH0`MJC0>3e/03Aiil0c^>N0=CYYP3G
jk00m?oA014?001RIE80eobf06J=?P2ddhL0KFDn0?GTb01IEbh0en6/0<gVY03AijT09ELH0;S`[`2_
h9h0b>:Q0<GKVP3<hIh0dMVM07QH:@1cCal0j^BV0=KSW@1AGA/0DedN06af=`39eID0fNFU0=7PW`/0
oooo000:0?ooo`0?06mH8P3YjJT0cmnH0<[cY037l:40`^6E0<gQV@35d8`0F5hP0::XK038ciT0al>M
09:AL`35`j`0oocf00@0o`0007P0a]?L0?_oo`001@T000D70:F[Y`3Yj^80XIZ80108002l]J<0o_SX
0?ook@3onnH0HUHn01`A00010000moKk0?cgn`3ooOH0o_SX0?ooh@38ejh0@VLk000^1026aJH0[>Vo
0;oaZP38jj/0b>:Q0=gWT@2m`7/0`<fO0>Kib`3Jk;X0o?oT0<[>Z`2Z/880gN6^0?Oih`0>3`T0k?3O
0=oW^02Z]FH0_lYl0>;`_`3SnL/0c?F_0;kYVP32hI40eOJW0<7YX`2fh:40`^nh021D9P0JCRL0A7UK
04ElG`1]XHX0F8=U0=?Z]P2jeZ<0JYAT04ajC01eXWT04CHD01m18027YH<0QZB009RhT@32hk@0d>fZ
0<3KUP2Y`7`0O95>09BYI037fiH0bn2K0<OLU`2=Xe/0dNRP0<;IT`3BjjL0f_>a0?;ob03MlkD0e>R]
0=;QZ03NjJl0_lN<04152`3^kkD0j?2d0<cSZ`3Vo<h0m_o/0?7njP3ZmmT0kOWC0=[W/P3DhJ/0f>:`
0>[bc@3[mM<05bL30<_N/@35gYd0e^fW0<_HTP3Xkj`0YJEY0>o`]02<VE@0WZmX0=S/Y03[mkL0eNBS
0=__ZP27WUP0eO2Y0<SZW@36jid30<G/W@0J0<O^W`39kZ00`n>G0<KPUP3=iI/0SJ=H0=;]WP3@lJ00
dOBT0<KTY037gJ`0m_[Y0?oonP3ooOl0no_m0?Kjn@3gonl0iOg90<GRW`3DkjX0lOo50=K`Z@3=iid0
c>RM0<cXV`3<jIT20<[YV@220<CST`35j9P0dOJV0<O^W@32iiT0]]J=0=;aZ`3DnKH0R[Ad08>kNP3:
oK/0bn^Z0;75QP3AiZD0d>>Q0=CWY@3EjJ@0Q9UD0<KPU`3ElJH0aNBF0=CZXP1hLCd0lnjg0>3MYP33
aI<0hnJk0?KhhP3fn>/0ADM60:BVY@3nood0o?oh0?col@3oooP0oo_o0?ojo`3on?/0o?oX0?Sog03>
jJ80cNVO0<gTWP3DjJH0WZ]e09ZTP@3ammd0ZK2?08F;I@37cZ80PXaH0=cXYP2jbH@0i?760<kH]P3e
nMh0mOOO0>KXdP3^l=X0nooT0?Sog@3Ag;80eN^[0=C^Y@3Gn:40a^>?0=g/Y`3EjJ80foF/0<SRV@2G
YV40FF0M0=kPW`3Qj:D0e^FP0=?eZ@36iY/0YK5a0:bhMP3BhY/0c=jD0=S_X@3Ak9d0`nFH0<G[WP37
lJL0`NnW0<Sa[@33g9/0bN>R0<GQY03BkKH0bn2i0<kQ``2XKFl0bXf<0?oog`2`_Hl0Pi=T09jUQ01f
OEh0JG1A06U^CP0/<`T0dmZ`0>O^`P0H800000P00=WQ[P1hPDX0:c@000@>001RK300f>:S086<B03;
f9<0bmZE0>Ce[`3Bhil0dnNR0>Oh]03AhYh0a]FD0=?OW`3GiZD0eNZU0>3g/@2AZ6805bh00<3ET0@0
o`0000@0cn2L0<gPWP3Cj:D0QYaK103o00001P1cPSd0X:eX06]h<P3EhY`0fnFP0=_RW`<0g>6O0P3N
h9l08@3MgId0emNG0:b/K01QH200IfHV096QF02N]6`0O8aK09RWOP002000EV<g08ZJF@36eXl0dN2K
0=cZ[03=f:00b=NL0=k`]03Fi;40cMR]0?Ckf@2OZHL0TYif09FRMP1_P4`0R:5O0:K0N@3>jYH0X;aW
065m:@2G/V40`n2@0>3l[`020<g/X0030<[YW@35iIT0anNK0080bNVN00<0b>ZM0<S[V`36k9T00P36
k9T0:`33iYH0e?FV0<[VW03WokX0@EPD0:o4P`3Rn;X0d>FZ0=C]Z`2je8d0cNRK0<_VU`3?ii/0cN>S
0?;ob`0U8a@0CE0o05f5?`1ZTd@0e_BZ05Q<9P2dW880GE4W0<G5S`3DijD0d^:T04Um?`0;B@X0Q/>0
0<OY[039ijL0anJR0=OVY@3R_X`0Q5`[05]E5`18D@h0TimM0:fhMP35d8h0e^FR0=g^ZP3;h9/02`3o
ool000X0oooo0100LEXX0>g[/03Hi:80`>:F0<?UV@3=gYP0e]nN0=_LX03FgZ<0fNN/05Ea=`1[QED0
PV5>0;>7OP0f;B@0k_oj0P3o0000N00200d04@0?00<02`0oNg40Qk:[0007001bOFd0X9R1038T2P2d
YX/0f]6d05QE<P2;RF00cLbN0>o]aP37aKP00@0408n<T`3oo_l0n_[b0?ooi03;eZ`0cnNc0<?U/P21
/8@0>f/k0:gIW032j:/0^n2K0<S[S`37hIL0V:1]0;^oS@3Yl;`0mOgH0=7SY`3;fYT0QXAD0?ooh`00
1000jOSK0;71U02/_7<0dnFI0<KPX`2aeZ80a?g@0<Sof`2Sfk@0VLfY04idF`0eED00GGIS0>kmjP3h
oo40Wjb>06QhE023UVP0b]f_08NKMP3>g;/0MWYS06AYD`1GIDh0a^W;0;ST`@2XeJ`0]]^_02<b2@1<
Gc40VL>30:k@T`3Jk[<0i?>j0=W[[@1XOC`0TZ]W0<GPV@3<hi/0Q9A=08ZIEP3FjZd0X[Ik0::gOP3T
nL40`]FN0=KW/`3Mik<0e=^W0?GiaP3HeZ<0j^fh0<oP/`3honH0n?og0?Won`3ioo40nOoV0>_hbP3^
nll0i_3=0?com03ko_D0oOga0?goj`2c`I00[;^00=WRW`3Oi:80ZJM/0>_[[`3GhYh0QiM@055Q6P3H
gZ80fN:S0=SWYP13EQ@0]Ln80<[YW@80bNVM01P0a^^M0<SZW@33iIP0b>ZM0<_[W`3:jId0d>bQ09Za
J@3Smk80c^:M0=S]ZP38fj<0e^>g0?kmj`3oo_@0oogj0?oon03dn>X0lOoN0=[d]`3@kZ@0aN>I0<KU
V@33hYH40<[YW@240<[YV`3<j9d0fO6W0=;^X`2feXX0_=n?0=GdYP32f900cn>N0<oXY`3BmKD0C8=0
0<Gh]P3Jn[/0Vjmb09b`L@3@hj<0e>BU0=KZY@1lTD`0b^BK0<kXWP37iYP0d>RN09FKG@3Hg9l0gn2W
0??^aP3lmMP0oogf07ifM03]jnh0nogj0?Wom03Pkm80dnB`0=cVa03eko40oo_o0<6j`@3cnnH0m?oL
0=7ZYP38hYT0eNVT09faJ@3Ikj@0ho?60?cok03non`0n?cQ0?ool@3oond0]K^=0;[3RP3=e;<0g^?<
0>cbf03dmn80ZJZJ0;fn[P3blMl0VYb60:b_U034cj@0e>:]0<gPX02BYf80bN>L0=KZY@3JiJ<0g>:R
04U?3`2AW5X0c>2K0<CIU03Ajj@0a^2I0=7XXP2[]gL0enJS0<WQU`3El:<0`NBB0<[_W`39kJD0bnjZ
0<7PY03:ik40bn>_07:6B`0`B0X0`MjK0=Ke/@36hj/0bN>c0=:QT`3:U8P0o?oQ0=S[_P1^QU80N95@
09bfM@32g9/0dN^Z0<[LXP3GjJd0e>R[0<_OX03Fj:X0bMjM0=?XY@3Smk80gO6Z0=_aZ@3EjJ80cn2L
0=WZYP3=hI`0iOZe0<WPVP3>iIl0Z;mg06Ek<`2/`7T0`mB>0=?TWP3MlJ`0d^NR0=K[YP30ei40kOnl
103o00001@3;hYX0fO>Z0;cGT03<ij00c^VR0080o`0000P0c>JM0<WPV03CjZ80bMnG0=[`Z03FkZ@0
bN>I0<STV@80a^FI02P0aNFI0<CVV@2nhiD0]Mb=0<gfY`37l:40b?>S0;gJR03OmjT0fo2g0>?fb000
4000[l6?0<OLU`3MlZD0a=V<0=KZXP37eiP0^mN=0<[XWP3BjjL0fo6a0?7oc03Mk[P0g_2l0>Wka`3h
omH0f^nf0<kV[030fi@0dNfR0<GQUP3KmjX0a>>E0<o^X036iiP0a^JJ0<OWV`3;kJ40b^bP0P38jYh0
<036jid0a^^K0<S[V`38ji/0cNjO0=GaYP32fI40dNBR0;[:R`3DijD0gO:a0<kSZ036gZ@0_mbI0<KV
V`3:jIT0anBB0=C_XP3?i:/0f>Vl00H0000e=BT0M9]H0;cWV03FmZ/0Jeli0:25JP2HREh0XJ1W0<_S
V@3Ek:H0^^Z`0<coc019Rdh0T;V10:kGV`2mljP0anRQ0>oBVP1`CAL0aLb90=OXY039gYT0`]VA0<SO
U`3EkjH0b^JL0=?aY`/0oooo000:0?ooo`0T06195`3Bd9L0`/j>0<g]Y037iId0iO6_0=oSYP1THbX0
hNV`0;oAU@1MOd<0E7900;^@P02EGUL01@L0000<003hool05a@K04TkBP0?00/02`LE04B6NP0/GUD0
<T`o0=3Mb`2OUGX04`@009F6I`3[g[`0FUL/0;^mS03Mh:T0jnfl0?ook00400800@050P3kool0H`3k
on`0h_7:0<cQZ@3<ik00/M>P0:C;UP0TC1L0c?Bo0;WVX`33lYH0`nRK0=GNZ@2`/7`0_l:90<cHZP3C
kj@0f>nQ0;bjRP2PY7l000H001lb4P0V?0h0f>fZ0=;XX03<k[40a?2m09CE]`1f]il08eQ60192=027
YZ00c^;P0=_Wi`1kO7L0>3D/00<300011@0000P0008<00001`000@@002HT3`0U9a8000D000LT201T
RFL0R:n30<3O/`1ULTH0dnFe00@/00006000^MJL0<KOY@3:gZ40c=jP0=GXZ03?hi`0en^T0<7ES@3N
lZd0nOoC0=_/]@2AY6d0e>Rc0=S/]`3UmL@0i_2n0=gT/@3@e:80EE<R0=OIY`3Ah;L0nooZ0?Won`3i
ool0m_oa0?Ooj03iom/0nooO0?coj03loo/0n__m0?onnP3no>d0hNZo0;_8TP2CVET0fM^L07il@@38
b8`0bmBA0=c/Y@3FiYl0]K]o0=gSY@3?gYd0PIAB0>?m]P020<cXW@0I0<[YW@38jYd0b>ZM0<[/W`38
jYd0bNVM0<WXW03Al:@0_mJ>08RDEP2mb8h0c=ZO0>3^^`3Dg;D0ZZBD0;:XW`3XgMT0oood0?[kj`3I
jL80e>j_0<[ZWP35iIT0co6T0<?UV0030<SZW@80bNVM08@0c>RM0<[PV037hIP0a^FI0<o`X@39i9L0
e>BM0=OTW`38gI`0c^j]0;S_Z`1m/6d0_MfN08fQI01^PTD0cMnQ0=GUYP3@hj40FVhY0<_RVP3CkJ<0
`n:D0=7/W`3>fID0_lR70=3CVP3ZiKl0`[RO0?c^k@1]H6L0oogo0?kon`3Ym^80k?kF0<cQW03KjKP0
ookj0?olo`3Uh>L0PhYj0?Woi03Jl;00cNBP0=_[[00oD`/0e^nL0>Wjc@3cn^P0noo^0?ool@3oo_d0
nOGb0?ooh03Zl<80k?3I0>3Te@3mon`0mOSU0?ool`2c/jL0/JnS0=OEb03fmN40/kVG0<SAYP1PKCL0
UZY]0<k/Y03FjZD0fM^L0>KTY`1BEaL0V:AR0=K`Z@33hIT0anFM0<CKU@3GjjH0i?>`0<[NV@2geXX0
co:R0<_bX@39l:40b^jX0<_YZ`34gJ@0kooC0>Shb`003000d^Z/0<KVW@34i9/0c^b/0<WV[P32Tgl0
fJJE0??of`3[omH0cNRc0=;]YP2ng9@0bnVQ0<GUW03>jJH0bNBO0;SCSP36hI`0cnZS0<ORV`39iI/0
b>BI0<cXW@36hYD0bN>I0<CIU037g9T0dNRR0;C>Q`3El:T0d>^T0<o[X@3Nn:l0/<Im06Uo=P3Dj:00
a=ZB0=?XX`3Nljh0dNRR0<?JTP3<iYd20?l0000:0=WeZ`3Dl:H0bnVO0=[j/@2ogiH0b>RO0=GcZ`35
hiT0cN^Q0<SVW080bNNM02h0c>ZP0<[YW@3=kJ40cNjO0<c_W`3:kj40bO2Q0<OaW`33l9d0bOJU0<Gf
Y02lkYT0__:O0<W]T`3Flil0/lf>0<SP[P003000amjV0=K`YP31fXT0gOJU0<oWV@3JkjX0b^ZN0=[m
[@32h9H0b>>N0=;XZ03?hjH0bMbT0<cNZP3homP0en^j0<KLZ`3Fl;40bNBO0<7LU@3EljT0^mZ>0=?b
YP37j9T0b>RL0<WYW@39jil0a^RL0P38jYh0<036jid0a^^K0<S[V`39jY/0bNRJ0=O^YP3>hih0]L>6
0:njOP3>gi/0f>fX0=K^/03>j:/0a^FQ0<W[W`38jIP0b^ZG0=7]XP3AiK80lOoK0>?Ie`32_[<0_>6N
0<WdY@36j9`0K60j07eSB01KD2<0^[j30=3_X@2be8P0]n:Z0:oQ[P2al;T0FhIA0;[U[@2/jYl0`^bR
0>OAU@2RQD/0go2Z0<SQW@3HmZ`0c^bR0<KTVP3:jYl0c>bQ0<o_Y0/0oooo000:0?ooo`1`0>7HX@3H
gJ<0CeXP0=?WZ03IjJ/0IV`^05=E5P2MWf00aMFG0=;/[@2lhZT000/00?oci`2kUXd0jo[W05=ZF03o
oOl0oo;l04Q2C00400P000850;GOd`0R@c`000/002m4<`33^:@0A38J0:BEM03/h;X0E4hL0>CUZ`3C
gY`0moo30?oie@3onoT0/Jje038kBP3/n_l0mOok0?Ool@3Ah[P0jo_:0;_@R`3<iZL0e__@03UW@P1Y
Wfd0Y>BF0<3i]02ofIX0h_6^09FQF@2GYfP0cnfE0=?[T`3GfZD0eMf/000:003Mm/`0_=NZ0=G^]@39
iJX0]=NQ06bFL02Kd/d0dooo0>kjn03_noT0BU=B00030P0C6AL0WJ2G0>?Ue`2@T7@0S8e[0<k?Y@3_
k;l0/JMf09JDH`3QkKl0d^>g0<WI/P1XLE80@dX[02L/300>5@002AT008VKL`3Ik/<0`^2/02eL9@1:
ND80c^fb0=c^/P3<e9P0KFhb0;2iN035h9<0e?2U0<cQYP3?hJl0[KnG0<_T_@31hK`0f_SD0?CohP3n
on@0gmnk06EN<02j]XT0nOcO0?ool`80nOoo01L0eN;80<[I/03;hk<0gO?<0?Sok`3ooOl0oo[o0?[g
l03ooo40d]fb0=WX/@3Ghj<0VYiQ0:^RJ`3Tfj@0g^BT0<gNV03Dj:40RI=D075k?02IZVH0`]JA0=;X
X0020<WYWP0J0<WYW@38jYd0b>ZM0<g_XP35iiX0c>bP0<_[W`36iiP0d^VS0>Oa_02NYW<0Ph]H0?Ck
d@3oon@0oocc0?oknP3onoL0f]C80:2PR03Tl[l0cNNP0=7`Y039iid0cNfT0<OWWP39jIh20<WYW@2G
0<WYWP39jJ00c>NR0=GVXP3KkjP0Hg/a07JAA032f8d0e=nJ05aU8P3AhJ00eo2^0;3MV037lZd0`N2M
09F/MP11EQh0g_>`0<SJX03LkJT0Oi=;0=oe[@2ofI00c>bQ0<[XWP3Olj/0RI]A07n>B@3RgKD0YXmo
0?obn`27NHH0m_7g0?Wkn03ZmN@0i_KA0=_bX029UeT0[:^I0?cgm03oo?l000400<K>]`32di`0h?2a
0:ZhNP2H[6@0a>:<0=3W/`3Gh<l0j>kT0?oon`3onol0o_Go0?oon03in>@0oook0?Ogm`3oonl0mOSU
0>W/f@3]l=d0inSH0?7_h03oonl0kNgC0>7Ua03DgJh0gO6f0<_aYP37gYP0h>2R0=cFW01KG200eN6Q
0=7_Z@2mgYL0c^bV0=GUY029V5D0fO2X0<CNU`37jj40`NZL0<G`X@34kJ40cnf]0<oV[P3=gK00loKI
0<;7Y`3Ej[80c^:U0<CRV03?l:40e?B[0<_[Z02mVWX0Tf]A0>Gdb@3UoLd0b>2^0>Wf`@3Nk;T0c]j_
0=k^_`3RolD0d?2]0<g^Y`3Amj@0^n:?0<W`W@34jiX0dORY0<?ZV`3BnJP0a^^K0<?QV@35hid0c^bV
0;kNU@38jZ00bnfQ0<KXV`32hYH0b^VK0<GQU03<iiX0U:YR08NKEP2kchX0dnNR0;W=QP3Hk:D0e^bT
0=;YX@3?jJ00dnnT0<_YW`3BlZL0dO>W0;CFRP39jil0doR[0<7VV@37kJ00aN^N0;oUV03=ljH0`>NH
0<K[V`020<K/V@1F0<K[V`39jY/0bNZI0<WXV03FmJL0cNRK0<kYVP3?jYd0bNZ?0<SYT03Fm:h0`MjN
004I0033g:D0bnNJ0<7NRP3<kI80c>fF0<g/X02mhY@0coJU0<W^X02kfhl0b>>L0<kWX`3Fk:h0c>6Y
0<gQ[03_omH0k?oB0>Gmb@3:iZ`0a>2S0<[WY@38j9l0a>BH0<WZV`38jYd0anVL0<KXW039jj40b>ZN
0<K[WP36jid0a^^K0<S[V@39jY/0bnZN0<KKVP3Ij:d0[;B30>K/`03kold0mOo90=3U[@37gZX0_m^N
0<k_ZP37jId0a^JJ0<kYYP3AhK`0logU0?ogm03ooo@0]m>H0>7o^P3:i9d0Hf0c01P>002ma900g?6`
0;kZU@39mZ40b^V]0;WLYP32mK`0XL^I02mK9P2^k:T0]>NR0>_OY@1RDaP0`n>G0<c^XP37l:820;gX
V@030<O`X@30iiP0dO>V00/0oooo000:0?ooo`0l0=3WX@3KkK<0bMJQ0=?FZ@3OhK00GV@V0<WDS`3E
ii/0a^BJ0<CXX01KODX000L00?SZg`3onnl01P<0004200000080o?oo0?Smo`0;30h000400=3Ba@0T
81d000X007:@Q03]gm`04P0009nLO@3Ke[00G4XJ0>;MX`3GhZ00goRf0?_oe03ooOP0oogo0000401R
HV`0o?oo0>gcl@3hooX0kooT0<o[X030hYP0`NJj01E39`17NUT0[O2m0:SY/@33nJh0a?6N0<cXT`1H
Ja`0d]R@0>KYY03AeIP0g>B[000:003Tn<D0dnZf0P3<hjd0g`3CiKd0>TX`0?Ooo`3ano`0nood075j
J@001P00NhAU0<7;YP3Gh;<0g>Jd09jWL02:TeX0f^BX0=OOX`3LijD0dMfM05=Q903=g:40dn:[0=CL
Z@3Jh;00f=^^02ha100a=`T00@D00=_Qa`3Bi;@0bNW205j2GP0XCQ/0anZZ0=3]ZP2HYfh0LWi00=_U
WP3EiIX0b>RU0=cb``1LLEh000/0045kK@2UgM00l?oo0?Gjm03ooO40E48L06aJ<P3onN`0oogo0>7[
m03good0b]VR0<_QV034lZX0eoo:0?;ok`3omOl0ooKo0?Ooj03fomh0g_Jj0<SUXP3Ak:D0f^JX0:VD
I@3egJl0dM2H0=cb/@3;jZ@0f>bT0=7UW@3CjJ00e>ZQ0<oWW@30k9l0_nVM0<ScY032kIh0_>FF0<[a
XP37k9h0a>NG0<o`X@36iiH0d>jT0<kXZ`3Jl[H0jOk30?_ofP3an=T0ooom0?ghoP3oood0lOCS0?ko
h`3Ah9l0enVO0<WJUP3;fid0b]VR0=7PZ@3Fij<0b]jF0=S]XP3CjJ40bn2O08fQI02@We`0FFTR08JG
D03Ci9d0RiaE096QFP3JjZ<0RY]E0=CZXP35h9T0c^bT0=7]X`2G/8H0Q9ia0<cXWP3Ai;H0cn2L0=GV
V03IkJH0`]^I0=3c[`31hYd0f_2X0<_XU035hhd0f]VQ0>k9]P3onOl0JFIa0>cYl03lool0o?cn0>W[
h03Jik40TYYY0?ooj03jlnT0oo_o00L00@2YYiP0gnV]09NTG01;GA40enjL0=7dVP35h9/0dMnn0=SQ
c03ko_<0ooco0?omo`3mnOX0ooom0?_jo`3oo_l0o_cW0?ooi03:ejT0fnbh0<_HZP3EgKH0oooQ0=GL
/P3WlKl0d>BO0=3/X@2eh900e_J[0=7LV03XkJd0C54A0=[UX`3=hYd0enjX0<[QV`3Ci:00SYeH0<cR
U`3>iIl0dnf^0<WWY`39jZD0`nBM0<SUX`3;i:/0cn6g0>C_gP1PKeP0dNjh0=KW/03El:/0anFK0=3W
X`3Dl[80b[>:0<j`S03;dj00enZb0=3UZP3Yml@0koc>0<KB[P3Oj/X0n?od0<WK/`3Ck;<0b^fI0<S_
UP2miHd0a>fQ0<C/YP36kZL0a>fQ0<3UU@38jYd00P39jJ030<SZWP80bNVM01@0bNZK0<[YV`3=iid0
d^JO0=CPWP2?VUP0CeXH0<oEU@3TjZX0dmbK0=oZZ038e980e>>N0<[NU`3>hY/0c>BJ0=7[X@3AkJ80
cnnS0<OYW080b>fO01/0`NJH0<S]W`35jY`0a>JI0<g`X03:kId0b^bO0<KVVP3Cm:D0`nBE0<k^XP35
i9P0c^fO0<c[W`3=iIL0c^>F0=[^Z@3>hY/000T00<WG]03@iJ00cnJN0<c[SP3:ji80b^RP0<SZW@38
jiT00P39jY/03P3:jId0c>RN0<oXY03>ijD0bN:Q0=7[[03Wol<0l_oJ0>gof03=j[00a>:T0<SXW`3<
k:00bNZI0P39jY/0=039jIh0bNVP0<SYXP38jZ00b>ZM0<S[V@38jiL0bNZI0<CSU`38gJ80f^Zi0?Wo
h@3oonX0nooT0?KohP3Kj<h0dMk40<gO]@36gZX0b>JV0<OWWP37i:40g>_20?;hgP3hoo<0jo[S0=KT
/@3?fYh0f^>T09>HH02IXfl0_]NM0<k^Z`38jiL0_^670=7VU`3Aj:00^N6J0<Kc^023[gX0Q[630;o[
^P3Id:D0UXYH0;WJR@3ToJX0_NBE0=3l[`2lj9/0`NZL0<cbY@35jY`;0?ooo`002P3oool0VP37i:@0
l_oA0?oog`3oo^@0oogP09jMI`3PjJP0bMjC0<c[W`30hIX0_]ZZ0<oLbP3ooo@0ooka0;RZW@3`i]`0
oOko0?Gmo`3hool0o?oo0>gZh`3oo?<0ooWi02aABP3<lNX0k^7Z05U9BP2DT7L0hMVe06=;7@3UgZL0
dmnO0<KYY`3Ahk<0n?c^0?kon`3blnd0<SDT0005001GGTh0mook0?Gom030gZ00_n:>0=KmT`2fhXT0
b_bc04^4F`05@20001D005:9HP3BnLX0a>6a0=g]`02MZGT0f^R]0<_JX`014`00//bL0=Oc`P1VPU40
KHMH00TH000W<1d0ooko0?[im`001P00CePi0<7<X@3;f:<0e>6Y04aK6021T4/0fn^T0=k]Z03<fiX0
dn:O0=c`Z@3JkZL0eNJR0=OXY03?gYd0d]jP0>7[[`3=eI`0k_>k0=7DW`2JW6X03Q800004003;iKH0
a^Va07RRM01PREl0^>2^0=Cc[@34fYX0RiIB0=k`YP3Iol<0PZ>409>`[P0`CdL0`^c40=7ke@0O>CP0
m?oo0?kno`3Uf;H0TgmJ0=6e]03ik_80ookm0?_ijP3BgZ00dnFI0<_YX@3Bm;P0a>g10?7ol@3hoo00
e]fc0=?T/035iI`0aNJG0=;RV@3Qi:40M6Lb08b3C034e9<0fo^`0<7ZV`30jYP0]Mb;0=GlZ`33kI/0
a_2N0<c/X@3Hn:d0a^JK0;WIS@36iYX0c^jR0<[ZWP3;jil0`^BG0<[]W@36j9`0b>bV0<g]Y037iId0
b]fV0=7P^@3jo?T20?koo`220>W`gP3CgKP0f>NV0;[6QP2mai80e^2^0?Ood`1MIcD0dmnM05m_:03B
i9X0enNV0<WKW`3:fjD0b]ZI0=_/Y@3:fi@0go>[0<kRVP33ehl0hON^0<gSVP3:h9L0FFlV0<_QV034
gY@0HWi;000?003:k:80b>F_0<_QV@3;h940T:9H0<SOV@2feI40a^>Q0<WPVP39kID0cOBG0<[<S@20
ESh0oo_o0=kSi`1`LVl0mokf0?ooo`3kn_D0f>6f0:B/N`3Oh;h0ooo[0?onn`3oo?l0oooc04aE703@
gID0b=Z@0=K^Y03<kIh0a>6O0>Cdc`3bo><0o?od0?Sil@3oooH0nogb0?komP3ho_@0nood0>Kgd`34
g:`0c?B]0<SdZ@2nij<0bNbb0>Ood@3;jKD0a^R[0<7/W031kYT0cOBU0<?QU`3@gIP0f>6N04Q>3P3D
gid0eNVT0=CYY036fiH0d>JN09:VGP3PmJX0h?>c0?Cog03don<0kooO0?Cog`3CjKP0eN^j0<OI[`1^
OF00N8]]0?7oh@3nom`0g_Bd0;WBSP3GjjH0bnRU048d0`1:=@H0SiUM0>;g]03>ij<0eNNY0=GW[@3N
k/40l_oJ0?WmoP3bo^X0l_oN0<cWY03:jYl0bN^N0<G[WP36jZ00`nRH0<CZU@3;kiD0b>^I0<S[V`80
b>ZM1P39jId0;P38jYd0b>fP0<3UV039jil0d_:W0<_WW@32gY@0`=bB0<KTVP3>l:@0bo2S08VYGP16
FQ80DEhH09^/I@3Hk:@0fo>Y0<SRV030g940a^:G0=;^X`3;iI/0f?:X0<SWV`3DljL0bNRL0<CSU`37
iYX0eoJZ0=7`Y03ClZH0c>^O0<[YW@39j9`0bMnF0=CXX03?hi`0eNNM0007001SL5@0cnFT0<gVXP39
k8h0b>f@0<KZXP38jYh20<WZV@040<WZV`39jId0bNVM0<_YW`<0bnVQ00P0c^bV0=7^^03@k;T0bnV]
0<SVYP37ii`0anRI0<W[U`80bNZI03@0bNVM0<WYX038jJ80b>ZP0<SZW@38jiT0bNZI0<WZV`3Hlj`0
c=j/0?Kog03hn^`0oooh0?Kkm03hooP0oOko0?koo`3kooX0m_o`0=cbcP35h;<0c>Fm0?;mk@3hn_T0
j_cT0?Coh`3Nik00gMjR0=oPWP3QjZT0f>Z^0<OVZP30hj<0cNZJ0=SbV`3Ij9D0dNNE0<GXV02dhJ00
a>fe02U87P1CN4d0JElk05mC:@2khIH0b^FH0<GMT`3=iih0e_2W0=C^Y@3<iYd0`mfD2`3oool000X0
oooo0?l0bN6W0?gog03in=X0imK40?o_f@2MVFT0h^R/0=;RV`3Dl:H0`N2L0=S_`@3aoNT0oO__0?om
l02SUHP0oogc0?_ko@3kool0l_[m0?Oin03oooX0oOC[0?ooo@0KASl0^N;N0?ogo`1MCU40YIf60?W/
c01VBah0i=nW0=CSXP3>lJl0amjZ0?_ok@3/mN@0o?o]09FONP0;5`001A00000600086P@0V;>00<SV
WP35iH80dOFK0<ceZ@2]g:h0b_cF08NmV@0mM4d0LIig0=;hd`3;iLX0`MVg0:_0R015G2P07SH6086N
LP12HCL0WkjB09B_QP21U7P0ZkJU0;Vj_00c=2l0Dehl0?Oog03EhK40e^F^0=KTY`2IZ6D0e^NQ0;c=
QP3<fiP0a]FD0=g^ZP38g9D0`MF>0=;SW`3>gi/0fNRW0=_ZZ@36dY@0QY9D09JPI02HX6D0/;Ql0;^o
S@1_M5h093`:09JhN`36l<00014009BmU@3<l:P0`^2J0;75P02]a800LYeU04mgG02`dLP0jood0<cU
[P3Lm<00X[f^09N]Z`3eool0dlj`0>oTaP0_9280]:bY0?oml`3oo>D0PhYD08FCE@3=jZP0[m>E0;GP
Z`3Ton@0l_oX0=SK/037fZ<0bo6T0<OZV03EgI80gMFD08=m?`3<cXl0RZ1G0=3/W`2hfhT0b?FR0<gh
YP2hhi40_nbI0;gZU`3AiIh0cN>K0<OMU@3@j9h0e_2V0<kZW`3:iY/0cNbP0;kNTP30hYD0c_2T0<GY
W`3AlJD0cNbP0<kRY`3DhkP0n?gf0?koo`3moo`0i^gK0=3J^03Gi:`0dn2[0>ohb`3Eh;D0o?oJ0:nl
Q`29VU@0Wk5W0=3TW03DijL0eNR`0=SZ]P3Bij@0e^bS0=?[X@37giD0dNVO0=cdZP33fi40hOV_0<SP
UP30f8h0SjMM09B[H`1NO3h001400<?XX`2jg9l0dN^R0=;YV`2V^6`0W[9Z0=C]Z@3AjZP0f?6]0<CZ
T`2ihX@0koBd07eE?03cjNP0f^?P0;[0]03`nn/0o?ki0?cnl`3<eJP0^<:>0=SM]03oonP0ooof0?ch
m@3hnN/0h^fe0<_JU@3RmK<0a=^G0<[XXP38hJL0i?C@0?Coi`3loo40o_oa0?Smj@3Yk]L0o?o/0?So
jP3^o>80gOK<0<[X]02ljYl0[n:C0<7`ZP33jjl0b^nk0<OY]P32jZh0`>nO0;o_V`2ceHT0g?J]0=GP
W03JhIh0io2_0=?OW@3BjJ<0c^RQ0<KPV@3<hi/0SjEL0<WJT`3Hij`0n?oV0?Ook`3eoo40ioWO0=CV
`03=gkD001h0d^>i0>Ccc03hon@0m?oZ0>gacP36fYl0g?Fc07>7@020WUH0VhmK0;:NK03=fI/0a]fG
0<cXWP3?iId0c>6N0=_^]P3Tm/@0n?gg0?_ol`3gonT0enjj0<cX[@36iJ80bnfQ0<c_W`37ji<0a^Z@
0<_^TP38jiL30<S[V`H0bNVM02h0b>ZM0;cUUP38lJ<0[MJ80;gRU@3Emj/0b^bP0<CVVP35ii/0]n2B
0<;]WP3<kZ80hoN_09NTGP26UTl0Q9E>0;_AR03Hl:H0d>RN0<kVW03Bj9l0c^BK0<_QV032g980a>>G
0<GTV03ElJH0b^JK0<?RUP37iYX0_MV>0<kZW`3<jil0d>bQ0<cTVP3Dk:80c>:J0<SNT`024@00HG5D
0<gVY03:j:80b>f>0<K]T035jj80b>ZN0P39jYT03`39jY/0bNVM0<WYW@39jIh0b^RP0<[ZX@39jJ00
b>JP0<CQY`35hZX0b>JV0<SWX`36iYX0a^NF0<W[U`020<WZV@040<WYW@39jJ00b>ZP0<SZX080b>^K
02h0bNZK0<[YW@3;i:00c]ja0?coi03inNl0ookm0?koo@3lool0oogo0?olo`3gno`0l?c`0?Gok`3^
onD0kooY0?Woo@3lool0e^K;0<KI[03?ei/0YjaY02`_003Sk:/0bMRM09JcN`3Bl;@0b^BJ0=_bX03D
iY@0e^fM0;gRU037lZd0]mfR07F?HP15ISL0XiIc05Q?9P21[6L0U[Ea0=_ZY@3HiIl0h>fW0=CSWP3@
hI/0cN6L2`3oool000X0oooo04l0dN>_0?cog`3oonP0[IV>0?o]g02JTfT0hNB]0=gYY`3CkJH0an:O
0=kdaP3_n><0oooc0?onl@21LfP0oo_b0?Sfn@3nool0o?oo0?CdmP3ln?D0ookh0?Soo`0DAd80T;jk
0?olo`0o<cL0YiZ70?odeP1XCB80hn2Y0=?VYP3:kj`0an:[0?Ooi03Um]@0dN:f0<kOZ02lcY@0amVW
07N7K00]?bD000`007^CH`1WNDT0d^Fg0<[T]03:l;L0]>2Q0;7VWP2djjL0Kj5^04AbCP0OA3d0SJnQ
0<cV]P3=j;/0@Uhe0<CS`@3Cl]00Li5]045L>`1jSWD0n?of02T]<0021`40d=nd0=gZ_P34di`0f^b`
09VYJP39fY@0bMfE0=O[X`3AhYh0eNFT0<kRW@3?hi`0go>^0080cN6L0<`0c=fI0=?TX02^_G`0UZET
0<cKVP3LjjX0WZUW0>;W[@3Ni;h000`0008P0039m;l0LYaf021:903<m;H0c?6T0=7/Y`3Dl[H0I8iV
000_3@32ilH0`=Zc09>HH03EgJ@0foOA08>TR@3So^/0ooo]0?cok00981H0QhEi0;V]T`2RUGD0OGQ@
065Z>`23[g00cOjl0<_^]02mi:l0`Mj^0=WQ/P33hZH0_NjL0<O_V@3Mgi@0l>>O09VHE@3Nj:<0`mZ<
09>XF@3AjYT0]=n?0<C]WP2ki9D0`njN0;WTU03Fh9/0g^VT0>;_Z@3AhY/0c^:J0<cSV`32g9<0an>I
0<k^X`37ii`0b>ZN0<KXV`3<kI`0cNZJ0=7UYP3Di;D0o?of0?Sln`3koOX0l?CV0>_ae`3UlL<0l?[E
0>;/b@3MjL<0m?oC0=3OZ03KkjL0b=f@0=_aZ03>hj80f>fe0>Cha@35h9d0an>H0=WeZP38i9T0dnnT
0<GOU@39hiT0_]R>0=oi[`3CkJ<0d>NO0<_PV`15Ha/0BFdW0<og^`33k:H0]]J;0=C^Y03Ej9T0d>>D
0=S/Y`39gYd0dNbW0;cTS034ki<0dmVI06e8;P3[i=`0HFeS0>ggg`3hon`0mOg^0?kol@3<f:P0dMjV
0=SQ/P3oon<0nok]0?oon03nonl0c]fV0=GUYP3?hJL0eNZa0<cYZ@3>ik00h?7?0??oi`3gon/0nooZ
0>ojf03IiKd0mooK0?;ofP3Vm/l0e>^m0<GTZ`36lZD0]nRG0;[WXP2oiJ`0bN^i0;kN[@2ohZX0ao>X
0;gXV@3Qo;D0aMZE0=CMW02b^7P0d]^H0=7RW03:iIh0b^RP0<WWW`35h9T0SZQO0<oPV@3DhjX0nOo/
0?ColP3goo/0mooh0=3Na03:f;D0dN2i0=gX_@3Ij<40loo_0?oojP3Ol;X0PIMG0=WZX`3>kZ<0c<69
0:ZIH`3Pkj`0aN6G0=7bX`3>iiH0bn>E0=;YY@3Bj:P0nOoa0?_om03hoo40j_gM0=S_``3:iK00b^ZO
0<_]V@3:kHl0bNf=0<[[T039jiD30<WZV@@0bNZK0`39jId0;@31hiH0b^bO0<[ZWP3BlJD0^]J;0<gY
WP3>jYl0eO6V0<OWV`35iiX0aNBH0<GESP3TlJ/0iO:/0<gMUP2@Y5`0MH]2096WGP2<X5P0TZ=L0::b
J`2AXU/0U:aR0;C@Q@3?jj00c^RN0<KPUP3=jIh0foN/0<OQU`3@jZ00aN6F0<oYW`3CkJ<0d>ZP0=S_
Y`3Omj/000X005m_DP3<ij@0b^RR0<S]SP36kI00aN^R0<SZWP020<S[V`<0b>ZM00`0bN^O0<SXW@38
jYh0bN^Q0<SXW`39ijL0bNNY0<_ZYP3<k:<0c>fL0<c^VP39jiL20<WZV@040<WYW@39jJ00bNVP0<WY
WP80bNZK00L0b^VM0<cWX037gId0am>[0=[Pa03oooX0o?Kj0080ooom02D0oogo0?olo`3nool0nooj
0>Cfh03Km=@0g_GI0?7lmP3io_l0cmjo0<SJYP2KY6<0RHm704a?2033c8/0e^F/0:>kR@3FlK`0cnRT
0<_QUP3>hI80ennQ0<GZW03?n;80c>n_082DH@1AKC`05PP005588@2nk:h0Nj5T0;c7Q@2>TD`0SI1=
0:N^J`2IXUl0e^:R00/0oooo000:0?ooo`3o0<cNZP3non40oocV06EBB`1GACT0`;bF0=[QZ`3Gj:@0
eo6X0=kl]P3eomH0o_oZ0?_hj@3oo_40[::I0?oln03on_`0ooco0?GdnP3oool0ooko0??im`3]ool0
?GQd0:KHe`3ooOl0Z9nR09EoL@3on>00RVY40?ood03/olH0b^nZ0=7eZ`35i:40b>JX0<7NWP37hYl0
c^NS0=O`[`3Rn<T0b]nf0=[_b02faJ@0;34M008300041P<0PX^80<gIe@3So>L0kOo/0;_V/@32l;80
a?Va0<;c/P2[bJ<0@5dn06>0I00E<1d001410;C9]P3doo@0[;RZ0<?=a0082@h0@TM00>Sm`P31eIP0
c^>R03580P2J/6P0c^BK0<;JT039h9P0gO:]02m40@0R=`00V:aW08>GDP1aQCh0RYiG06Yn=`3Ll:T0
c>:I0=O]Y03DjZ40g?:Y0<kOV02LXEh0j_JT00HG00057@00b>g10;cW/P26/Wl0/]f`0;g[[@2kjJ40
eOk208jcU00D?a40eoVl0=C/[P3FfJ@0XZYa0:6oO`3=lK<0_N2Z0<cD_`3EiM/04Ti20<Sof`2heYX0
dnnd04M_C02;Zi<0WiQl02DL002MYVd0_]jE0<gb[@2chjl0Z>JU0:kbW@32n:80eMnF0>?OW`2`[fl0
dmFD0=CNU`3LhYP0UimD0<cTVP3EkJ<0amnE0<oWW@3Hl:H0dn2H0>?`ZP3;f980RiaE09JWH@2icXT0
g_>^0=C[Y@3?j:@0dNZV0=3^Y03@lJ80c>bI0<SUU@3>i:H0eNNg0?Sol@3cnOD0nOgn0?Wkn03nooH0
o_oa0?con03`nnX0nOo/0>Cha@3SnK/0b^FF0=ghY`3:i9d0h?Rj0<oV/P3Zom80`N:M0<[_X@35jY`0
d?FW0<W[WP3<k:00aNFI0=3`Y038ii/0bNRL0<?NU`3Bi:X0a>BA0<gcZ033kLD0aoN]0<7VX@2jeiL0
hO>W0=;PT`1MIRD0[;Ij0<[XXP35kiT0_^^@0=_TY@1cDCD0ZZVE03e@=03Xnlh0k?oD0=;Q`03ionH0
e^:`0=CTYP3@gj@0e>:a0=GS`P3gonh0V:N:0<7DW@3CiZh0dnFk0=?V^@33fid0bn:Z0>;hbP3eon40
lOoI0<cP[`3Bi[40cN2X0=7T[@3>gZd0f>Bd0>CR/P3Wk;@062T001@X000`?`H0T9M[0=_O^P3oon<0
oooL0=GPY03LjjX0aMFF079n@02:Sdl0TIIF0=[WXP3@iYh0`^BH0<S]X03;kjD0bNRR0;_GS@2=WEH0
c]bO0=OS_`3<fKl0mOob0??mlP3ioo40`LVd000M00@:003_m=@0o_o]0?koo`3nlnl0o?oM0;2oR03C
i9h0_=b@0?;/[P2RUUX0gO>Z0;[MS@3Do:H0b^^B0<g[T`3;j9H0b^VK0=OS_@3gond0lO_`0?OooP3Y
m^`0i_GN0=?[[`3:i9/0c>NF0=3[W03<iYd00P3<j9/01P3:jI/0b^VI0<[ZU`3:jYL0bNZI0<WZV`80
bNVM02h0b^VM0=3ZX03EkJ40d>RL0<[RUP32f8d0b^2E0=W_Y03Qmj`0c^JJ0<?KS`3DjYl0b]jF0=SY
XP3Hk:@0d^RO0=K/X`3AjIl0d>JM0<gQV@3>gYL0fn^T0=?SW03DjZ40cNFK08nWG@2:XUP0SJEK08nW
G@2P^6h0TJUO0=WaY`3;hiT0d^ZP0=K^Y03AjIl0fo6Y0=G[X00A7P00JGQK0<oUY03?iZ80b^b>0<W/
T038jJ80bNVP0P39jId40<SZW@0A0<O/W`36jih0a^^N0<O/W`39jIh0b>RM0<OXV@37j9L0anVE0<OY
T`39jiD0bNZI0<WZV`39jIh0bNVP0<[XWP3:jId00P3:jI/0;P3<j9h0cNJT0=S[/`2j`J00Y:NB0?om
o`3onol0ooof0?ool`3oo?d0ooco0?onm@3nond0j_[E0<_V[`3:iJh0hOK=0>Gde`3Rk/00TiiV0:2Z
I@3bn[40j_6[0=?LY@33cj40joWH0<gL^`3SmLD0g^nh0=O^YP36hYL0`nZK0;oUV034hYX0fnJZ0=S/
/@33/H/0<2H209O;VP38mlT0cMbQ0=7GU`3Rj:P0fNBR0>3/ZP3@gi`;0?ooo`002P3oool0;`3=hZL0
m_kG0?ooj02fZYh0FTi00=_M]@3Ji:l0c^>P0<_YW`3;jj80cnB/0=CI^`3ooo40l^cN0:ROV03on_P0
ooco0?ojoP3oo_l0n_Wn0?koo`3gool0iooo04V4P032l_80j^[b0=3:c024JUd0onKC07eL>@3hn/P0
hoc20<;WXP2lhXl0b^bO0<CUWP3@k[00`]jQ0?7oc03Ekk80b^6Y0<oV/P34eZ`0nOoV0?gol@1KFUP0
8AlR0080000701H0MH1j0?GomP36iK/0`^Na0<?aZ@2kiJ<0bnK504mYCP00300000h306=dK03booD0
n?oh0:V_Y@1/KVT0OW^20?Ghk`2kdI40e^b[0=C[Y@22VE40ennU0P3@j9h0eP3Il:P0OiI@08ZQG@3D
jjL0f>bW0=GYY03KkjP0a]ZC0=_aZ@3@iYd0b=jE0<kVW03@j9`0`]Z>0=O[X`2CVE<0g^^C06Ae@@00
2P00`>2i0<7X/`34kkL0`o730;c/^P2olj/0]N>R0<[Z``004000^mNJ0=7YZ`3AhjT0eNV^08FUHP31
hJ00c^^a0<oI]P3=hlh004Hg0:caa03?n[<0^^NT011<:P20[id0fmS503T_301kNdD0f^nT0<;SWP19
Qe@0AHU<0;3`XP2il9l0dNNO0=WRX@2AT5L0dmBJ0<_FTP3DgiX0f^NO02a0001JKRH0e>RP0<?GS`39
gID0en^S04QL501EJb80hON^0<cRVP1JKbX0_mB?0=od[`3Cj:D0d^NT0=;/Y@37iYP0cnjN0<gYWP3=
iJT0dnJh0?Wol`3koo/0o?oo0?koo`3nood0o_oj0?;fm`3ano00lOoV0<gT[P33g9X0anBB0<3MR`3=
j:40l_o>0?Gof03EkK/0cNjY0<O^W`32jIX0`nZK0;[OT@34iYT0d?:U0;oOT`3AlJD0_mnC0=?^Z@3B
hjd0a>>C0<K[Y@1dWh40a_R_0<O^[`3=j[00a=F>0=_WW@3Df9d0V:1W0;kLU03=mj<0a?2G0=WSYP1X
ARX0IfUA0<KL^03BjK40_=RM0>3ec03Ehl00f>Bd0=3PXP3Hjj/0c^6Z0<oQ^@3eonX0mOoT010T0000
3000mooV0>[leP3?j:H0dNV[0=of`P3aomL0eNfi0<OPYP3?ij/0d>FZ0=OZ/P3;fj`0eM^_0>SJ[@3M
eYl010T004I@2`0/;`004Ph00=G<[@3on^00ooWF0?ooc`3Df9d0938005EO8`3Kgj80g^BT0=KWX@3=
iih0`>FH0<W_XP39kj@0c^nX0=;]YP1FHad0gNb[0=7O[P3Kikl0k?WM0?_ok`3[l^80QXYk0?cokP3o
oo40oooh0?Kdo`3on_d0YZb:0=CP/03@gih0cN^S09B>DP2<PTD0cnNM0<[_W`30jY@0bnbC0<[[U03:
jYL0c^fM0<[KY`3ionX0mOoc0?Soo`3coO`0n?oh0>;ea`3CijX0cnBQ0=;XZ03=hZL0cNJR0<cXW@3<
j9/20<[YV@030<[ZU`39jYT0bNZK0080bNVM00T0bNVN0<OVVP3BkZ40d^jQ0<3LS`31gI00eO6T0<cX
V`33gi800P3?jih0103=jI`0dNVO0<CJT@3?iid30<oYW`090<kXWP3AjIl0cn>K0=3QVP3Ci9d0amfD
0=G]X`3:hYP0c^JL0080d>RN0140c>BJ08JNE03:hYP0b^:H0=?[X@39giH0c>:I0=;VW`3:g9807RT;
06MaEP3Chj@0dNBR0<gZSP3<jY00c>NR0<[XX0030<WYW@<0b>ZM0P38kJ003@35jYd0a^^N0<SZW@3:
ji`0bnbK0<[/V038jY@0anVC0<W[U`39jYT0bNZK0<WYWP39jJ000P3:jId20<cXV`0^0<gWX03?iJ@0
bMbT05=J>@3non`0oogo0?ojo`3oooH0o?g_0?omn`3onol0o_c`0?kojP3iomd0honm0=;aZ`36gZ@0
c^2^0=?KZ02JXF/0gnRU0<oIU03MiZ<0kOG40:jfT@3]mml0nOo]0>gmf03iomX0`mZF0=km/@2khY<0
bNjP0=7]XP3Ji:D0b=ZL0=g:XP1DBRH0BX9C0;;U^P3Hm;X0c=jP0=OYZ`3:gId0a=VF0<WPVP/0oooo
000:0?ooo`160<7VV03JlKT0gNc30?cmj`3oonl0dmng0=3T[`3:ijD0anVO0<_]X`3DjK40cm2^0>KO
c@1LETP0ookj0?khn03onoh0oogo0?koo`3iool0g^c_0>goo`2M`L40a?;`0>Koo`3oo_l0/k:`03PH
2`3FZ9P0L4d]0=kT]P37hZd0a>2S0<OXS`37jI80b>RM0=khb`3bonP0m?oV0<WN/`3JkZl0e^^Z0<_J
X`3lon40oOkf0?oonP3mnnh0lo;F0?Sgf00b<QH00`<000H700082PL00045004:1@3Lkm40_<^d0005
00000@80GUeR0?ono`3ooOd0OgMd00H0003onol0iNGI0<WSVP3?jJ00bnFK09:/HP80e>jT06L0eNnU
0<WSVP2;YEh0e^n[0<oVXP3>hYd0d^JQ0=K/Y03Mlj/0^m690=O^YP1QNBl0c^JL0=;ZX034g980gO:W
03m60P3bn[h0en>S0=OV[@004P00cnW20<CT/`1NRE406TLP0<Cj_02gjj40_mfM05a]>@3Jik`0cnNg
0:cSW`2dkJP0cO2f08VMJ01PJSD0cMRC06b;C`0NIU00U/6F0;OUW032n[<0KkFA0:G_f01KV7T0Mj9g
09:OJP1=D`d07C<00<Kof`2oklD0GH1:09:fN@2ihj<0_n:X06=eA@3Di;D0/]>J0:cOW@3=okT0cn^Q
0<;NU035hIL0bNFK0=WeZ`38k:80`>BJ0=Kj/03Hn:l0a>:J0=;YX`29X5X0E6PS0<kOV`3AhYh0dnNR
0=SbZ@37hY/0dNbY0<kU[`3?h[D0lOoX0?WomP3lool0noco0?ono`3ooOl0o?ko0?_onP3hond0b^BW
0<CRVP2mgh/0e?FT0<SSWP3:hZ@0ambS0<cTZP38ij40c_>U0<;WV@3:kj40a>VK00<0a^^M0P38jYd0
FP3:ij@0go710=?`[@2hfj40TKVQ0<Kc^P3>l;d0c>Jg0=7QX`3=fIL0d=RO09ZSK037hY/0d?ZV0;o[
U03MiZd0I48V06Y`C03Lm<80dNfS0<GUVP3@j;@0gNg60=3H/@3=fZ@0g?6/0;cEU039i:l0c^Vl0>So
dP3Km;X0bMfZ02Pd703ionH0cnNK0=?]Y03=jZL0`=nL0;kMV@3>kJL0^mJA0;kBU`3komP0oooT0;6a
S`1dJ3@0c<J:0>W_Z@3CfYH0k>bj0:jXQ00;0000]ZJ?05E7:P1CCAT0FEXQ0;BnR@3@ej40fn>W0=KP
X@3BjZ00bn^O0;kWV@34kIl0a^bQ0=Kd[P3GkZX0Z[Yc0=7QV03;gXl0eNNK0=OWZ@3Agj`000@008N8
P03ooOl0oo[o0?oko`3on_l0o^Sd0=SG``3non<0bMFS0<KRZ03=aY80SX9>0<oYX03<lj80^^JA0<WZ
V@<0bNZK01<0b^BJ0<kT/`3PlM40n?oo0?Woo`3hooh0nOo_0?Woj03honD0kocP0<gL_`37fjP0c>FS
0<_TX03=jIh0an>F0<_XV03:jYL0bNZI0080bNVM00H0a^^N0<?/WP36lJ80a>nO0;_WV02oji`20<Ke
Y00<0=7m[P2mj9T0^NBD0<G^W`34i9P0`^:F0<_]X03:k9l0`nRJ0<gbY038jYd0bNVM0P3<j9d00`3=
iid0cnNM0<oWW@040<oWW@0F0<KNU038h9H0dn^Q0=cdZP2dc880Cf0I04aL5@1BGaX0Qi=;030c601V
J500en6T0=gWZ01SMQd0f>bE0<3@S`36gi/0fOF[0<gYW`2jeX`0e_FY0<OWV`80b>ZM0P36jid00`35
k9d0b>^I0<WZV@040<W[U`0g0<OXU`37j9T0b>VJ0<WYW@39jIh0dN^Q0=?[X@36hI@0g?J/0=OaZP3<
iJ<0AU/P0=CP^03]m]T0l_CW0?oonP3nooX0o_ok0?olo`3onOl0ookk0?kok`3Um</0bNNM0<[[VP39
j9X0d>ZQ0=OLYP2IVFD0fN>T0=OSX@3@gZ00i?760:ffV`3looP0nooe0>3]d`3EiL40cNJU0<WYW@33
k9d0a^bI0<gXV@3GhYd0_m2<075O<@2ZWWH0]>Zh02mS=@1k[WH0_O2e0;k`/`2ehj80`>fX0=So^00;
0?ooo`002P3oool0Q031kIH0bNNY0<gS]03lonl0o_o_0=?S_P3Bj;L0bnV]0<7QWP34i:40c^2^0=_H
]@2VWX/0ZZBH0?ono@3oo_l0ooWk0?3/k@3lool0l_go0?7oo`1dTiP0?5iO0=coo`3Xool0ooko0>g/
j0107Q80a9F506E2903JhKD0_mVY0=gb^P3BkIh0b^JI0<[TX`3Kl=40io[W0?Gol@3HjLD0aMRF0=3Q
W@3eol`0lOWB0?ook`3lon`0nokS0>7S_03]klP0gMc0079_G01;AT808AdN00<01003100000d007Eo
IP1cNVX04@`@038X<02m/;L0ZinQ0515@`1KD4h0oocm0>WWf03EkJ<0d>RN0=;ZX023Ve40b^6I0=7X
X03;hYX0/lZ408>JE03FkJT0`mZF0<SNUP3Sn;<0FFhY0=K[YP3Cj:<0N8e80;S>QP1CJB40aM^C0=W_
Y`39gIH0a/n>08^AH@22Re@0BUDK00hO00002P00c>Fn0;GJYP2MaI40?flk0;WX/@3Ookh0dN>W065_
?03Bk;`0^OFo0;Wh_`27Zfh0g?2a07^4@`3ZmZX0]LN;0=Weg`006`00/mjG0:gUWP0kSeh0HK2@0;WT
b@1EME00]=FP0;3?P`1fVED001L000h/2P3Hik`0Mh]H0<oh_P33k[P0;dXO092[P038nl<0Ml:10:Wb
Z`80anfP02T0a>ZM0<[`X`36k9l0`>JM0=Sl]02mhIT0a>>M0<GSW@3@ij40bn:L0<cPV@2mcXP0b]VD
0=;SW@3<hid0dnjY0<OQX03>ik00dnVk0?SojP3ioo40o?ok0?[ko@3oo_l0nOKo0?kno`3goo80looT
0<oYZP3HmZ`0/=6007ZKC01kUU40SZIX0=CY[P3:h:80fON_0;[JSP3;jil0a>BH0<KVVP030<SZW@80
a^^M05T0bNRT0<CHY@3;ij`0hOo?05MnH`3Som/0e_?3092XN02?Wf40U:=R09fXK03EhjP0cNNN0;kU
TP2ihhl0bm:L06a8;P1QId40gOJo0<o[WP3:ji`0b^>/0>GecP3HgKd0e^:`0=3WX@3GlZl0d>jb0<KT
[P3`omH0an6T0=S/]`002000kOSJ0<gUU`3>j9h0_]bD0<[YX`3MokD0b>RM0<o]Y@3?hJL0lO[=0<k<
/`0m>A`0_L270>?^[03Cj9d0fNnV0<_IY034c:D05QT00=C@]@3MgKT0d=RO0=ORYP3Zml80hnfh0=KP
Y03BhJ00b^JK0<_]X031jY/0b>jQ0<?UV`3KlZh0`]NF07J7@`2nd8H0dnNB0>7gXP3@i9d0d^6Z01/P
2P2n_kT0o?Wo0?ogo`3mmOl0ooco0?ofo`3bkn00n?cS0>S`b@3Aj;X0gmJ]0:nRM@3Ajj@0`NRG0<C`
V`040<WYW@0C0=3_W`32fj40cN>e0?KolP3iooX0n?oi0??kk03eo^/0nooa0?_ol`3SkmT0cMjb0=7V
Z`3:h:80d^bU0<[VV`36hYD0b^VI0<WZV@020<SZW@0D0<SZWP36i9X0bn^R0<KVV`3:k:80an^Q0<W^
X@2nhiH0_MnE0<KVW@38j9d0bnVO0=CcY`3?kj<0`nFH0<KXV`3;lZ<0_NBE0<G/W@36jid20<WYW@04
0<cXW@3=iid0cNNM0<gWW@80o`0001L0cNNM0<cVW03CkJ<0`]bB0<gWW@3DkZ@0dnNO0=GUWP3DhI`0
h>bT0454:@0e=al0f>:U0>7[[02dafh0PiM008bLF`39h9`0bN>L0=OaZP3Ro;<0`]jD0=KdZP030<SZ
W@80a^^K00<0b>^I0<WZV@39jYT00`39jYT0=`37j9T0b^^L0<[[W038j9`0anNK0=3XWP3<hYT0ennU
0=kf[01oVE80TJYV0<WQX`2hbI`0nOoQ0>kfg`3noo40nook0?_oo`3oo?l0ooKo0?omo`3nooH0h_3?
0<WVY03:jZ40d>jT0=oh]03HgJL0Vi]W0=[VYP3Gj:@0d>FT0>CcbP3Pj]40oOog0?comP3WmM/0aMNa
0<cWY039jId0`nbM0<G/V@3<jIT0e^>M0>3d[@1ZF2P0MFXm0<gobP2RdZ00<6Tb0:KSZ02[ij/0b?no
0<3e/@2_giD02`3oool000X0oooo00l0__2A0<KYY@3;hk<0o?od0?kon03eond0n?o/0>oogP3?hKL0
cmnh0=CG^02ISW00j=g;0?ool`3oool00P3oo_l0o@3em?80n?oo0>koo`3Wool074E;0>Sno03hool0
l?Ce0?onn`3nooH0CbhM0:IeI01M>Qh0gnNn0>Koe@3dnMT0c=B_0=SS^@3Vl/h0n?og0?Ooo`3goo80
d=jj0>Ge[P3AgYT0fMfj0?;dg`3ooo@0m?SQ0=CK^@2?WFP0U:E_0<WIZP3Rkl@0][jI09:IL02//7h0
WjIb07b9F`2a^9H00P@001@:2@0g:2d0BSXm03d];P2ISXP0`kbf0?SekP3dn>40dNNO0=3VWP3>hih0
?e@?07jCCP3?i9l0b]nJ0<WNV@26VeH0cN:M0=C[Y@3Llj/0cnJN0=3UX03;h9/0h?>a0=CWY@3Di:D0
FFTZ0:NgN@3:f9/0f^N_0=WR]`3JhKL0alRV08B7G03GgId0@DLG0007003>h[d0`^2P0;KH]@0UC340
aoK00;WOUP2bcX<0Ggdo06:9KP1FOf40RJeS0;WKO@3=j8L0`=FD08:CG@1_NDD0i^nh0<SMW034gi`0
b>b^0:7>U`2:b9L0:FDb09g>U`3;jIl0bNRT0<gde@28XWl03AP005=O<@3Dj[T0^M>V03iJ=02feZl0
E8=G09OAW`2/hjT0a^BL0=7_Y`3Elj/0b>JN0<_YX@3DhJT0ho:g0<OFV`3<gZ00fNVZ0=[^Z@3<h9/0
d>BM0<cPV02W_740/LMl0<KPUP31fi@0c>FQ0<WSYP36gjD0e^Zg0>WjcP3lonP0jnkM0>_[h@3oo?d0
ooko0?3hh@3`o=H0d^bU0<;NT@2P`G80a>BI0<KOW@3PmK80cn>N0<SITP3RmZh0`mN?0<kTV`3:hYP0
e>jT0<[YW@39jId0b>ZM0<K[W@35k9d0b>ZP0<_UY03Jm/H0k_oQ06:3E033h[T0TjYf0=;VZ@3>gi/0
d>BO0=G_YP3DkZD0`=J=0<3ST@3BmjL0l?;106U3;00F6000aMfQ0<o[UP35ii<0b^6[0>[he@3ooNh0
mO_G0=gd/02fdHX0cnn/0;_NW03`old0a^6L0<WMXP0O9100o?o/0=3VY@37h9l0g_fj0<;SW030i9X0
cNjO0=KbY`3?fYh0f=V]07IZE01HDCD0Z<600;kNU@30jYP0d?^/0<W//P39i;L0l_oS0=3O_P3Ah[H0
an2O0=G_[P3dom@0i_O10=GWZ@3Cj:D0anNK0<K]W033jY/0co6U0<cWX03>fY`0SIQL0<SLW`3DijD0
amfB0<[RUP3Ol[X0d=nf0?Gkl@3nool0ooko0?ceo@3ooOl0ooco0=>na@3oooP0o_od0?kol`3doo40
mnSC0:RGN`3<hZ80b^nR0<;/VP39jJ000`39jIh09`32iiL0bnfQ0<SWX`3Aj;@0i_O=0?Koh`3koo<0
nood0?Wol@3eo^T0n?oW0?3nfP3bomD0f>Zh0<oUY`3=iZ80c^ZP0<[YV`39jYT0b>^K0<SZW@3=ij00
g>:T0=CCVP3DeIT0fmbR0=kTZ03TjZ`0f=jP0=OKX029R4l0NWXn0=OHW03Wm[40`]bB0<OSV03>kJ40
bn^O0<c^X@020<K[W@030<SZW@39jId0bNVM0080b^VM103o00006@38ii/0bNFJ0=;^X`3>kJ40bNFJ
0=[dZP3;hiT0e>ZR0<7FR`0nBB/0>D<X0<_KW03EiJ@0d>N=0<GMQ@34fiL0QYUI0<CGU@3@iJ00d^NR
0<3GS`3CkJ@0b^VM0<[YV`39jY/00P38jiT30<WZV`<0bNVM03L0bn^O0<[ZWP38j9`0b>VJ0<[[W035
fI80a]NA07jBBP2@YUd0dnfS0<o[X@2bcHH0e>ja0=oh_`3QmlP0go770>;jeP3Rm]/0nook0?ono`3o
ood0n_ob0>7`d@37iJT0anNT0<k[Z@3Pn[d0gN2Y09nNI@3?h9T0bNBG0<OUV`3Gk[X0ho7=0>W^fP3n
ond0jO_A0<SS[03=ij00b^VM0<?/W@32kId0b>ZM0=3VW@3<j9h0hM:K08ImAP2mk:H0coJe0;cc^P1;
RU<0<Vhh0;[d^P2^iZT0/nNW00/0oooo000:0?ooo`2a0;g/S03;jjP0c^Bf0?gom`3lo?X0o?oh0?_o
l`3iond0n_oY0?cojP3mn>@0Kf130?O/f03Zi=P0n?Ol0?_jo`3oo_l0ooom0?Goo`3Rood0OZJX0=Wo
o`3dool0ooko0?_gn03el>`0o_oc048Q4038UhH0SF]@0<O?Z03CjL80oooZ0?ool@3oond0o_o_0?_o
n`3kool0noo_0=OT^@3@gY<0fNBP0<S7/P2o_;<0i^7K0:V]U02LYgl0cnFU0<SQW@3<iZL0a^2S0=7T
[03MkJl0bMJ>0=?PVP2e`hh0WZIm02DX3@070000H59B0>7AdP3olo<0^;6W0>[Vg@3oooH0f^;:0<gS
V`3>hih0bn2K05]`:`23V5<0a=VD0=O/Y`3@iJ00MX]60<gRW@3<hYX0_mV@0:6hL03AiZ40c^>N0<cO
W@3>gYl0e^BW04E@5P3KiZ`0g>F^0>_e``3Vl<h0i>c5096AK`1<BR<0gmnS0>7QZ`2KWW4000P007B;
E@2nfk`0bNcD049hA`2biYh0b^nO0<3NWP2fbZl0`mZm0<?XVP3Ioj00b_2=0=G_/033f:00dn>L08VC
E022TU<0e^FT0=[SX03?i:<0]Nne0;Ka^`2njk@0bMnF0=?/Z028]Y40/MZ`07ZBHP1OKch0IVe10:ng
SP003`00@ETg05]kE03:j/<0cNVi0<cKV03Ei:40f^VV0<_JU`3Ei:40fmVY0<_;V@3LgjX0e=bS0>7[
[`3Ij:L0c]nI0=;VWP3>iYX0bn>E0:o:N`2I]6D0f?:X0=3ZX`37hYl0c^RW0=;Z[03Hjk<0kOS@0>3U
a`3>ckd0g]WC0=cIe02?UGT0V:Ei09NaJ02O_6`0cnnS0=[h[P3AjZH0cN:M0<gNU`2HZE/0[;ac0<kN
U`3Fij00a]bC0=G]X`3<j9d0b^VM0080b>ZM05X0aNbM0<K[W@3>k:80lOoQ0>cog@2kfYl0K8IQ08RK
H`36fYD0gNjW0=[bZ038jIP0anJF0<oUVP3@lJ00_n:B04a>7@1gDCX0?ClG0=3X[03:iY40aNNA0=7X
/P3Qklh0ooof0:^`T03gol/0`]fF0=Oh/`35j:@0bNZS0>7m/`3Dj:/0albf0?kok@3DjK40b=nW0<SV
Z035iJ80`nNO0<?TT`3Dkj00jO6e0:2NKP2o[IL0FE0c0<kXY`37iih0`>^K0<3/W@33iZ`0`]fb0?Co
iP3`omh0mOoJ0=7/Z@30fiP0l_oE0>Ch``3>i:H0c>FQ0<SZW@37kYd0_^FF0<_[X03DjjD0f>2U0:B/
L`3>hJX0dnNZ0=cb/@3?iJL0eNNo0?Koj`3ioo/0o_oo0?Ogn@3gm>d0o?Wb0?ono`34[k@0oooj0?;e
kP3nooX0m?oi0?GUf02bX8X0cN:W0<?WW@35k9d30<WYWP0D0<WYW@38kZ40a>VK0<CWU`3>ij<0eNZa
0=WZ_@3SkMD0moo_0?_ok@3_o=h0i_G>0>OedP3ion40jo_>0=?X[@38hIl0b^BM0<[YV`3:jIT20<S[
V`0B0<gWX03MhJ@0J6<[06=Q:01OGRD0>c`202HZ001OH2H0G5dS051>5@1ED1P0MW@i0;:mN@3JkZH0
dnVP0<gUV`3AkJ80b>NK0`39jId40<[YW@@0o`0001T0c^fQ0<c[W`30gi<0_mjB0<WXW031h9@0cNbP
0<_WW@3El:<07Rl?05ASAP3Cj:L0b]nL0<o/T03?kI<0h_fh0:o2PP1TM3<0e^ZU0=S/Y`3Unk<0`mZB
0<cXW@3<j9/0b^VK0080bNZI0`39jId30<WYWP030<OWV`35iIT0a^JJ0080c>fN0380fNfV0<7@S@2V
^W80eN^R0<7MT030gi40jOnm0;oLV@3=jZX0^]JL0=K_^03:jK00bNFb0>Sfg03foNd0n?c]0?WojP3L
k/H0b^VV0<c]YP38iJ80c^RY0=oSZ02TY6@0dNJG0<[ZU`37jYX0cNV_0<cM/`29Sg<0m_gN0>Wmb03>
jjT0cNNN0<[YW@33k9d0`NjM0<G/W@3?iYh0c^jS0?7UZ@1=@`P0]N6D0;oSV@2bhj/0`O[50:3FXP1>
Pdd0R[f50<[ma0/0oooo000:0?ooo`0Q0<OXU`39gZD0b]V`0?oom03jn_80ooof0?ool`3oond0ooo/
0>WRd01FAc@0`k>A0=SC]@3oond0mo7a0?ono`3moOd0o_oo0>coo`39lo4034A50=coo`3hool0oocj
0?ogm`3oo?X0moGX03hK202BI4d0NeTm0<kB[`3Pklh0ooof00<0oogo0P3oo_l08P3lonX0fNFg0=3M
U`3@fYh0/JfR0?onn`3noo80joK<0=GTZ`3@k9P0aNJ;0<3WSP36k9L0d?:U0<[YW@3MmJL0a=^=0=ob
/P39ej80IVi700X6001jLfd0oock0?;Zi`3Ti=P0oood0?WomP3QkmD0c^BS0=7WYP3@iJ80eNRV0:Fh
MP3Fij<20<CET@3309f^JP3<gIT0dnNP0=K`YP3;ii`0dN:K0=o`Z@3:gYL0e>VV0=3SX`2?VV80U:5/
09bOLP3;bjL0o?g[0?[li03XjL40hN:h09>@I@1]K3<0XjET08fDH@0`=Ah000/0096`Q`1h^H<0@XA7
0<Sh_035iZd0W:=`09NNJ02ohI@0cobY0<?bX@3:jZ/0cnZU0<o]S@3@mYl0cn^P0=KXW02WYU<0ViY8
09n]K`24VF00K8Q=0=[TW@3GiZ<0]>jk09?CU`2>_7`0`]jS0=G@YP2LUW804Q4000hD000=6`00Ee@e
065G<`1HDQH0H5XN05QB5P1KEaX0FUHI05a?8`1KDb@0Pgm?05EJ8P1MIBT0D5/I05=N6P32chT0hoFY
0<3GQ`3=iY<0a^6@08ZREP38h9H0b^6I0<oVWP37hIX0d>VU0<[KY@2JXWT0KG5@0?ook`3dl^D0k_K?
0<oNY`3Lm:X0a^:H0<SUXP3Im[@0_=J?0=cbY`3>hi@0dnBF0:niM01EGQ/0RYEA0=OTW`3@gi`0d>FR
0<oVXP3<iZD0b^JY0<WWZ`3:ijD0b>BG0=Wa`@30fZX0_mfC0;;9V`3Ai:@0aMZ=0=3WV@3<iiP0^mn7
0=3aVP3RlZT0amfB0<ONUP3Uj;T0MELk07b6E03CkJ`0gOBR0<_WVP3AhK@0jo7E09NCQ`2[/Hl0e>f[
0<CTV@3?lJD0`N>F0=3_X@3Dk:80amVK0=gVb@3lon`0=3lG0009001^Q5H0VKAo0<CPY@36h9T0f>bT
0=OMW@2IUV40Ed<R0>OJ]`3BiZL0aMnF0<WZV@30h9@0amf/0=CS`P3lond0e=O209:IN03@h:80d^BV
0?3og@3Pn<P0c^R[0<_XY@32iiT0_nJE0<CYV`3:j9h0dnRS0<G;S`2c^h80mooJ0?;of@3gon@0looV
0?Gol`3hooX0jN_V0?oon03ooo<0oooV0?ooi02YZ9H0k^;D0?Ggj@3noo@0o_oj0?Soo@3onOL0ck^b
0?7ndP3MmK/0b^VV0080bNVP02X0bNVM0<WZV`2nhid0b^nO0<[`V`39jY<0cNVL0=;[Z@3<g[@0d>:l
0=_^`@3IkKP0c^:W0=KQ^@3`n]D0nOoK0>Wja03Gjjh0f>f/0<oVWP3=iih0c>RN0<[XWP3?iZ80R99F
07f5C03Ji:P0gnf`0=;UY@3AiZ<0d^NT0=CWY@3Agj40fNFW0=7KWP2KXF40@dX70:2WI03Yl:d0c]^F
0=_/YP3=iih20<cXWP80cNNN00<0bNVN0<SZW@3<j9d00P3o00006P3AiId0fnnW0=KZXP3@iYd0d>JN
0<gSV`3;iid0anFK0=G`Z@36hYL0LH=K0009003Ejj/0a]fI0=WeX030g8P0f_F`0<kYYP3>ij<0`MBB
03e<2@3Dh9h0e>>N0=3VWP3=iid0c>RM0P3:jI/00`39jIh0bNVP0<SZX0030<SZX00g0<OYW@35iIX0
bNVM0<[YW@2ngHl0UJUR0:^lN038gYD0dn^Q0<;QT`3:ji`0d?6R0<SZW@3:k:00b>VR0<SYY03:liL0
ao2B0<_YX@38h:@0goJn0?Cod@3Qo[/0a>NE0<KYU@3>jYd0e>jU0;VoO`25RTL0cNF?0<k_U03=lIT0
aN>S0<kU[`2Q[gh0e>:]0<gSXP38iYh0cNNN0<cXW@35k9d0_?2M0;o^W@3<j9h0bnfS0=kEVP1HDQ@0
a^fN0<_/W@3<lk@0^N:X0;CKY030ik80J91L04ilC@0;0?ooo`002P3oool0o`3Egj/0jo?40>ofbP3j
omT0i>c30?3gc@3_mLT0h^Fh0>kY_`3gk/D0He@Y0=kDW`3KikD0oOoP0?ojm03onOT0o_ko0?Cio03Z
ool0]_Ca04:>S03Iool0mOoj0?CajP3oo_d0ooCh0?okn0148@d0WGEK06M::03kl]<0j^kC0?Gom03l
ooP0ooko0?omo`3onol0ooco0?WnjP3]mm@0amJO0=OT[`3Xjl`0o_oV0?Gog@32fZ00en^/0=GYX@36
fi00b^:H0=?]X`3:iIh0c>JO0<oRX03Bhid0fNZS0>3^/`1@G2h00@@007emL`3oo_/0n?Oc0?oon03j
oOH0nook0>;ag03>kZl0b>JX0=7ZYP3AiZ40e^NP0>3]Y@3Hi9`0hnjY0;K1O`3Dh:80eNFT0<cYV@39
j9P0dm^>0>?ZW@35eXH0aNBF0<cZX03;g:D0d>Je0?ooh`3hk=@0oogZ0?olj@3oonP0i>_:0=KO/03@
fYh0k?>`03Xm102ATVP0AdX]03927@2^ij<0O[Ig05>1D026[Gh0anFa0;cJW02=/V80anfH0<W/W03F
kjh0c>>O0<gZT02nh8T0`NF=0<[^U03@ki40c^^?0<cWUP3@j9`0Zkmg09bRG01aMcL0b>Ba0<O]/P3:
jZ/0d>R/0=WR/`3@i[P0CE0a0;:mW@1UVVH0YLfI0<k[/`3Fhih0f>NR0<GFT03MlJX0a]ZE0=k]]036
g9h0bnRX0<SWX`37iIl0g>^X09FLF@2OX5h0_kmi0=7CRP3:e8/0dn^Q0;O<Q`26UE80gn^Y0=3OW03@
jZT0dNj^0<gU/`3ZnM80jo;A0?ook`3ooo@0kO[>0=O[[P3Ilj`0`M^N0<WV/039iZ`0b^VK0<cYU@3=
j9L0d>FT0=GQX`3?ei/0[kUl08RBE@2h`hL0c=VS0=o]^P3ion40nOoX0?Coj@3Iil@0fNR_0;G7R`2a
ahT0R:=L08:NH@2/bHH0b>>L0<CNU`3Ek:H0b^2H0;S<Q02IXe`0TiQF09NOH`3HhZh02P<00;kKV@3P
okX0aMJ@0=;VY`3gn=P0o?KL0=3E[@3MjKL0anVM0<gdX@32j9<0dNfI0<GJR`3Ei:40c=^R0>Wne@3h
on<0k^_80>c/bP21QVP0Hfe;05QT?P2Y]H<0c=JQ0=SKXP0a<000hMJY0>;N[`3>ijD0bnJI0=7ZUP3;
i9<0i_?70>O/f03lnoH0o_[i07mmL03[lL40dM^Y0?;oi`3IkLP0c>F[0;gJU`36j9/0`>FG0<W[X@37
iih0c^VT0<gRW@33f9L0gO?20>cnf03conl0lO_b0:R`X@3am^80m?SE0>_]aP00903no]X0^;>F0:j[
S036c9h0h>>f0>_fc03QkLT0o?o/0?cll03onoP0bKZe0?oojP3RjLL0d>6e0<SXZ@3:jZT0`nNM0<?X
VP36hI`0bn^P0=3bY@32iiT0a>ZM0<kdZ`36jJL0a^VY0<[WY`3<iZD0d>BU0=;JY`3Igk40oOoC0?oo
d`3nom40en:Z0=3NX`80dn:W02@0f>Z^0=?PZ02RXW00iNFa0=cQZ@3=fI/0c^BL0=C^Y039iIP0cnVO
0<gRW@3>hIl0f>BV0=7JV`2IUeX0FeDI06aR9`2/Z6/0iNNX0=;VX@3CkJH0e>jW0<_RW03DjjD0bNnT
0<C]W`3>i9`0dMbH0>[VYP2LU5D0GUTI05A@4@26QDD0h=jQ0=?AU03@fIX20=gWZ00S0=;LW@1bNDH0
0@L009VQIP3JhZL0fNBP0=7LV03Tk[40]N>J0<Ol[P37hYd0gNVY07mo@`1nP440cn2L0=S_Z@3:iIh0
c^bT0;gGT03:j:00b>RO0;[NU039kJ<0cO>X0<?YWP36jZ00a>JL0<[XWP3EkjH0Y;ie0;;9P@33gI@0
dNfR0=;^X`33hYH00P39jId0:`3;kJ00b^bO0<CYW037k9l0`>JC0<W`W@2jhiD0`NZN0;oYW`2mii/0
`NbM0<?XV039jY/0fNnV0<[NUP13BQ@0P8Q=0=3VT@3CkI@0anB@0<STZ@37h:T0e^fY0<gTW038gI`0
e>Jb0<[PX03@jj@0a>BH0<7iWP2om9X0c>NJ0;SJT03Yj[40CDhE0;kTV`3;lJH0`>RO0;kVW`35j:@0
e_Bh0<?TZ`27/gh02`3oool000X0oooo02@0bN6_0?;of03`omH0d?Bf0<GYZ@3=l:h0cnn^0<SUY@3;
gJ<0g^^c0>C[^03Iejh0/KRI04M9<`1oJVT0ooWk0?ggn@3oool0j_oo0;cckP0iP7`0dooo0?Coo`3o
ood0m?Cd0?olo@3on_H0?aX709agG01H>aT0gln]0?See03TlmH0h_7D0?Ojk`3no_`20?olo`3o0?[o
j`3Tm<d0d^N^0<cOY`3Gh;<0e>Bc0<GUYP3:jJD0aMjJ0=OXXP2jbh@0OiE:0<7LS`3;jYh0dnnU09^`
J`20U4l0h?6]0<kKYP1KHc`01PP004e<BP3oo_l0n_[l0?kon`3koOP0noom0?KolP39ik40cNbc0<gZ
ZP38hih0bn:J055V6`38fY00h?2Y0=STXP2c_h40dN6R0<;RUP3=lZ@0e]bD0=[MUP3HjYh0a^bQ0<;U
X@3Hjkh0j_oP0?ool`3ZfM40ooKY0?onl`3nooH0/[^Z0;K1W`2QZ7`0e]fZ0=_KZ@3?d:@0VIao00L=
002Y_Y<0c^Be0=3Y/P25WVL0IGe;0=CZ_02daIP0VZYi0<WHW`3@giX0d^>M0<oYZ03Cl:d0_^2F0;[O
TP3Bn:/0coBW0=Kd[P36hIh0enf]0=[W[`3Eh:P0TZ9T03aC3`3Il:P0d^JQ0=cZ[`35hZX08Ad009RJ
L`2bkJd0/^2P0<W`[@3?lZ80a>NG0=7hY`32k9X0`NbJ0;W/Z@35lZl0`NZX0<7TY03<k:/0_]bL0=Ca
[`3<iJ@0LWXn05EF703Kfil0eNbV0=3WW`2lcHH0TYmG0=[/XP3=kJ@0eOVc0<CVZP38gj/0iO;70?_n
g`3kond0kOo>0<ORW@3;jj80l?oC0<KW/P36j:/0b>bE0<S/U038jiL0bNRU0<GSW@3AkJ<0b^BK0=S_
Z@3?i:40Lh9708jKIP3non40oooX0?ook`28Sg00EF8Z0=ca[03:i9d0`^:I0<7SV@37jj40`^>L0;WG
T@3BjjL0D60O0;o@S03=fYD0gMjT0=_NZ@0S<@00HV@b0;oQU`39kj80a]JE0<KKX`3Kg;d0^;NI0=CW
/03@i:T0dNRP0=CaX@33ii00_NZ?0<?aV@33i9l0cnB[0?Gec`3oom`0dMFS0;NjS`2XZh`0`lN/0?[o
h@3jomP0k?C50=kVZ`2GWf<0g>:T0=_WZ@39jZ<0anRG0<o[U03;i9<0i_;:0?;ij@3nool0ooko0?oo
nP0a>0l0Eelf07>0K03`on00enjf0=;/Z`35iIX0`>2G0<[XXP3DlJh0aN2M0<GOV02H/V/0hoNj0=7R
]@34d;`000D00:>`U021T6D0S9mO092SH@2faXP0g>bm0<KFY@3BiJ<0d>NQ0<SUXP34h:<0g_380>C]
d03almh0_/2[0>7Xb@3Rk/P0i??80>Cb`@3KjK@0d>:T0=3TW`3Jij40dN:K0<gQV@3Bk:80d>ZP0<_W
W03<j9d0cNNM0=3VW@3AiId0cnJN0<c`Z02oij00b?2Y0<K[Y@3@mJl0`^JP0<CUX03<jjL0d^n/001f
0<3KV02?YFD0FF@/0<cGW@3BhZ<0f>nY0<OXV@38kId0bo:Q0<GZW@3BlJd0cnbZ0=7UZ039diH0f^ZY
0<kSX03Lmk80dNRT0>;b/@2<T5<0J6T]0>Sd]03DjjL0b^jV0>?o_@2mfiD0Ef4R05MH702`ZVh0f]BF
0=SMW@3EgYd0_l^90:nkN@2U/6h0UX]C0:FDGP1<?`X0Og<o07ae@@1SH2/0i^Vb0>K[/@1>FQ`0KG/m
0;G4P`3Ej:H0e^^X0=?/Z03IlZh0_]6?0=_WY`2j^gl0Gf0T06UZ;P3@g9`0go:`0<[KU`3HjJD0cnBO
0=W^Z@3KlZ`0a]fG0=gd[P2kd8/0cMjJ09^WI@2_^WP0cnJN0<;QU@37iYX0aNBH0<g/X036iIT0b>NK
0=3_X`3:jYh0cNnR0<o_X`3@iYh0c^:K0<WSVP3>jZ00`]jD0=7]X`36h9L0cMjH0=SSW`3ShZ80YImQ
0;2gP`33dIH0cnF@0=3XTP3;hiD0Zl>?04]Q<03JlJd0fNnW0>Sg`03do]T0nooE0=SVZ`3AhJ00a?6L
0<C`V`3DhI/0dNJQ0:JOJ@1=AQ80c^VV0<cZY02hhY00`N^G0<?VUP3:hYP0dNVO0<GSV@/0oooo000:
0?ooo`0n0<GV[@3Zom<0j_oD0<7^Z`2ok:L0^NJQ0;gVY02ohj<0`]jT0<WPZ03Ul/H0m_WN0?cjk@2c
[:@0Ac@f0;>PXP3onOT0ookk0>kooP3:m?00Agml0=coo`3Ynod0o_oo0?knoP3oo?P0ooC[03lJ202A
Je@0M5Lg07i^BP3:aZ00cMbe0=KT`03koo80oooj0?omo`3ooo/0lOkP0=7T]`3<i:H0amfO0=GQ[`3=
gZX0cN^]0<[WY037gYX0fnbU08ZLDP3>iYP0c>VI0<?TT`2kfX`0bN6G07Z@B02O[G00PhaM04iE=001
0000Lg5d0?oko`3ln_d20?oon`3H0?con`3ioo@0fO?30>7lb@3:iZT0b>FS0<SSWP18HQT0Y;ab0=S/
Y@35eI@0RiIJ0<CDU@3:jZ40b_2S09RRG@3Sj:D0cnFM0<GZY@33iJT0iOGA0?7ok@3oo_X0k]oL0?ol
l`3^in40e]SC0;Vn]`32ak40[Zn@0=kN^03/jkl0oOkF09^RP`0a>Qd0<SdM0=cX`03Dik00gO:i000<
001lTFX0]l^X07f?J@2J[Wd0eNZU0=7XX03<j:d0`=jP0<o^Z`3>kjX0`nBM0;kOV03BlJh0anBR0<cY
Z@34g:80d^J[0=[ZZ@26X5L0[LEi06]m<`3FhZ@0b^BW0599802b[HD0`O:a0=Kj^P36iZD0`NJP0;cQ
W02ojJ40cOR`0;WWWP2PgiP0H95?09>kO01TP4D0NYIK0=ooa`2bg9d0`>Z[0:o4R`23S5L0alNC0<gT
X031fi40jOjc06f0<@2P]fL0`^>D0<;WVP36jJD0an2V0=?T[P2d_9<0nOoV0>Koa@3GmJd0anVM0?3o
d@35j:h0aNZW0<K]U038k980b>^G0<SYY03:kj40c?6Q0<CWU`3=k:00goV`0:RkN`23TUT0m?_A0?_o
fP3knml0S99/09BSJ03=iih0^mN=0=?eZ`3:kZ@0bnnU0<;TVP3>k:H0c>>O07n?CP3FiZD0KWhm06aa
=`1cN480UZ=^09JFHP3Bl:P0aNNK0=OWZ03Pn;h0Z[2>0;[0WP3Aj;80c^:W0=?WX03Ak9l0`^FA0<7f
VP2jlYT0^nFM0<7IW`3oomd0n>c609FPI01`NTH0GfE305EJ?03RilT0k?790?cod`3AgIl0JGDc0>Gb
[035fI@0an^U0<KYV@3>k9H0bNBE0>CcbP3koo<0o?oo0?Kio`3bmo00FF@l00HA00002`00j_OI0=kc
^`3Fkjh0KXa409FcJ`39iZ<0eo:_0=?^Z`3Ck:P0IG`f0=3PW`3KjK@0>dP/0007001@HSX0C60[0=Oa
Y`3<j9/0f?BZ0<[VZ`3>jZl0bN>J0<_YW`3=lJL0a>VT0<OR[`3Eikl0k_OH0<G>[`3JjKh0jOg:0?Oo
eP3eom@0jOG30=?RY`3?hZ00bn2E0=CZW`3=iIL0c>NH0=3[WP3?jY/0cNRI0P3=j9/0>@3=j9T0b^VK
0;o[W02mkYl0`O2R0;oYW@34kJ40`^RM0<_[XP3<jZ80]]2908fTGP1CIR@0L8120<cQX03Ck:P0cN^Q
0<7XV@39lj40cOJX0<7ZWP3Pokl0gO^o0<cTZP3Hk:d0`^2J0;SLU035kJ@0_n2I0<CMV@3Fg9h0UYMK
08fGF02ndi00`N2J0<7GUP3?gj40E5PM09RGGP3Bd9D0h>BW0<OGUP3;hY`0e_6Z0<oZX`31fi@0gn>V
0>3NX`2YZ6l0GehV061S;027S5@0g^N^0<3;T@2EXfD0DF4R06f0?P020=GEV@160<kQW`33gYT0g_Vd
0<kSX03Fei/0WIQN0::LHP2JWV40/[am0>Wb/@3;dI40_lZ80=_WY@3Dhj00f^VV0>Cc/03NjZP0WZUW
0>?YZ@3Igil0cNNN0<7SUP3>l:<0bn^O0=7aY@37ii/0`N6E0<SXW034i9P0b>ZM0<W[WP3:h9P0h?6[
0<gSV`3Aj:00e^fU0=3WW`3Aiil0h>^W0=WPW@2j]7H0I5XM0=kY[`3EjZT0an2<0=;^VP3?jj00OIES
00`S003?i:T0d>JV0?;od@3ao=X0oooL0=7HY03@f9l0a^^M0<[]W@3?e940dMfK05I64`1VERD0eNRX
0;cAS02oj9T0b_FU0<W^X03>iYX0e^jR0<gXV@/0oooo000:0?ooo`3o0<S/[03Iokl0f?no0;k]Y`31
l:X0`Nj[0<C^[038k[40e?6k0=3[^03Lk<P0o_od0?oho03om_d0ooCi0;FRY02jZ:@0ooK]0?Gon`3D
kNT0Q:b[07VZ[`30dmX0m_[k0?oon`3_i]L0ooGV0280001@:QL0h<:V069@;03Yh[P0b]JT0=3M/P3n
onl0ooof0?chm`3moOD0nOoT0<kR/@3;i:<0bMnO0=OQ[@3DhZd0dnnb0=G`[@3Gk:T0g^jW08:DBP2l
ehP0d?2M0<W[U`3FmJD0^=220=CZX@21ReH0fN6h00L;00010000MW5h0?ojo`3oo?l0oook0?kom`3f
nNh0nooa0>goe@3eomd0d>V`0<cXZ`33h9h0`=jH08:MEP38gIX0enZX08jIG@3Zn;/0cnjX0;oWWP1F
HAl0i^n`0<GJV@37jJd0cNVh0?Soj@3doo@0oogo0?ocn029P7T0GeYG0?ooo`3lo?`0ooof0?onk029
PVP0oooN0??cc`2Z]I<0JgQJ00<=001DI400d>Nc0;_FW`1KNd`07clJ0;?E]03;kLP0`NFg07nVH`1e
VU@0bn^Z0<c/Z`2if9@0f_Vc0<o_YP39jJ00bnbU0<gaZ@3:kZP0_nBO0<c/Z@37fiH0e_:W0<cWUP2Y
^fl0/;]i096WI`1aHST0f<^Q0;SOX036h:40bn>Y0;cP]032iK/0N9mb04A^@00;=`H06fDJ0:GIU`38
k[40^LfH07bEGP0eIBT0/^Z]0;7[[P39jkP0amZ/055C9039gYd0eo6W0<?ISP2aagD0Jh@a0=?gX02d
fXD0cO:U0<SSWP3CijP0/[j<0=CU^@2ofIX0eO>[0<CVVP3AlJh0aNVY0<G[XP36kI80b>bB0<S[U`36
jZ00co^V0<?_V038lY`0/]F30<7PTP3DjJ@0cN2P0=gU/P3oomP0LG9:0>3V]P3GjZX0bnNL0>7o]02e
eh/0doR[0<;TVP35iid0f_F^0<SMVP3YnKP0NXY907^=C`3DfjD0Vim/0=7KYP23ODT0d^bU0;kLTP34
dY@06S800<;<Y`3do]T0cn>^0<oRZP3@iJ80bnNL0<3VT`2hki@0]>bE0<;WXP3Ol[X0VXIU06MH<@2<
XE`0V:Y^0<C<Y@2KX800WJ230=CF/@3oomP0cmjM06en=`36gHd0f?>V0<K[Y@34jI/0c>bG0<STU`3S
ll`0n?ob0?7gm@3kool0n_oj0?_oh`3Rk/P0noo]0?3ng@3PmKd0_=FD086LE@1hTdh0IX0o0;SBT@3B
jjX0c^FQ0:[0N02BXUT0FfT/00XI002N[XT0d^Rg0=Oa/P33iY80aN^D000m0<7XU@2niYl0`>FO0<OW
V`32iiL0`NbL0<7[W`3<jk00cNFc0=o^a@2;VVl0_mJN0=ol_03Bk[40l_oJ0>oodP3CkK00anBQ0<CZ
U`39ki`0aN^F0<KYU@35j9H0`nJB0<S[U`36k9T0`nfI0<?]U`32kYT0`^bJ0<O^W`34jI/0anJJ0<KP
UP3>iY`0a=B=0>;]Z01XKBX0Oh8o096HE@37f9@0b>>L0=3^Y03:k:00_nRI0;[UU@37lJD0^n>L0>_o
c`3^om<0bnZa0;cUW`34l:D0a_2V0<K/X`37iIl0d^^W0=[]Z`3AhJ00OHe<0;_;RP020?l0001M0?3`
^P2?RED0QGm;0>;U[03Ii:P0cnbY0=Ok/`2cg900bO:V0<kdZ@2mhIT0an^S0<KWXP2ddi00d^b_0=3X
[03<h:<0go6e0<OGV03@gZ00ZKQg08Mh@@2jZG<0gnVZ0<gTX02ddX`0fO:^0=;HVP3OfZ00kNB[0;nj
P02CTeL0VYYL09^IG02^/740WjAT08N=C@2JX600[;9b07Ek>`39cXh0fmfN0=OIVP3@kZ@0`nbM0;kW
V02lhi@0`nZK0<;YVP35k9d0bO2Q0<S_X03<lJ<0bo2R0;gIS`3GlJX0b>>L0<[XX03>k:@0a^6J0=K`
Z@3RlJh0d=^I04Y:301mNC`0cN:Q0<CRW02nh8`0c^nN0<k`YP1VPe<001400<cT/030fJ80iOO=0?7o
h`3oom/0e=6V0>WW]P39i9d0an6H0>CPX@3Zjjl0n^:b06I>7P3NjZX0enJQ0<;/XP30kZD0^N6H0;kL
U03?jj40e?2U00/0oooo000:0?ooo`3o0=KVY@3EiJ@0c^6O0=?YZ03<hZ40dnV[0=ob^P3Yml@0jo?:
0?Wof@3nonT0o?ok0?ofo`3ojO40m?CX0?okj`3UdKT0OfmF0?Wgj03oo_/0mooo04AeN@2=YZX0moob
0?cojP3Mdk00n>?601d0001I<Rd0Dc8Y0>_E`03onMH0inVg0>S]a@3oonl0ooof0?omn`3oooH0n_oO
0<kLZ`3@hj<0f>JY0=KHZ@3oomP0nooF0=CQZ`3AfZ<0W:9V09ZSHP39gID0h?R/0;oLS034gi00b]nD
0=7RW03KiK<0gN>o05UMAP0=2@X0IEiU0?olo`3oo_/0o_o]0?koj`3Eg;d0gnC40?ooh`3momh0f>Ri
0<SLY`3Aj[00/m2>09>^J`3FjJT0a=:E09BIG`1DG200dnZT0<SZX02GXF80WjEY0=GWZ@3;hZh0cmje
0?omk03jooD0ooOn0?oio`3ooOH0oogj0?olo`3onol0ooWk0?ohm@1UCd@0oogR0?oog`3?g:h0S9a_
0<77Y@0_=AT0QYEn0=W]e03<k/d0a>g307:RKP1HRUD0EX]G07V^PP1UW780LjZ305B8HP1DPEX0GhUS
09S1V@21Zh<0Qkb>08>nSP26bIH0[?W50:[[]@2ieiT0b^nY0<k`Y03DkZD0`<^?03aA602>MeL0VX=T
08nUM02;U6D0TiY^00XS00047@00_mb`0;GBY034i;<0YnZK0<;_ZP34ijD0dnR_0<cU[P30l;H0U<^B
08G0R02egk40bNFl09RSN`2^_8L0`M6@0>ck^03;gI40j_n`08fYE@3=jYH0dNbM0=7WW03FjZ80b]VH
07N7B@3Rmk@0b=nI0=cf[`3<ij80c>RN0<cXV`3=jI@0cNVE0<oWV`3=iZ80`nBE0=CgY`39jY/0^MF;
0<OPW03CiJL0`]:D0;o9S@2W[g@0jo2f0=;LW`3:gYL0fo:Z0<[TV`3Bk:<0e>jW0<?JUP3DjJH0e^BV
0=SRY@3Rijd0=d090;o?X03oomX0n_O<0=KDX`2[UfD0dmbK09BSGP2]/gL0b=ZP0=?O/@3[l/P0d=bZ
0<oRZ`32hYl0aN^R0<O/W`32fY00e>>N0=[KXP37`i<0WIQ`0=_O[030gHd0cnFT0>CZa03AdKD0oooZ
07E`D`1=BbD0ADlB0=KWX@35hXh0cNjM0<WZY@38ii/0cnZK0<_RVP3Vl/X0noo_0?_onP3[lNl0o?oh
0>G`cP3ion40o?oZ0>Occ`3Ai:`0aM^J0=gf/P3Jlk40^m>E059X:P005000LHI50=;VW`2ic7d0XkA^
0<CEWP3JkKH0b^BS0<SVWP3GnJ80/=Al000K0<7WT02ih940b^nR0<_VW`3;jil0bO2O0<O^W`34hIl0
`mRO0=WU/`2Q[WT0cnBQ0;[DR`3AkjT0f?S60>;oc03Dm[X0bnj/0<KaX@30iiP0a^^M0;gMT@35i9P0
e?>W0<SZW@36jid0`NjM0080_^nM00D0aNbM0<c/X@33hiL0e_:W0;kES@020?l0000H0:6/J02EW5T0
bLj;0=gTX03?hIL0dnjQ0<OSUP33hY@0anNK0=?eZ@3=jZP0c^R[0>SjbP3iomd0i_k<0<Od[`2ggI@0
c>NR0<cLV`3HhZ<0cmjM0=_f/@30fiH0dNBR103o0000G03oo]<0FddP0=WKZ@39eZ00a>BS0<K^Z03:
l:L0eo^c0<SVWP3@lZP0_n>I0<7NV`3;i:<0`m2H02df0@29QU<0GEHR0;2PK02OReH0[9MR07ed>`2O
VV00J6<Y05aJ7`2PYVP0WJUY08FJE`2<Wed0QYED09nMHP2XWFD0V9AG09>CE@3Ifi`0^K]l08Z@D02`
^GP0Pha;04mJ601RKB/0Mh9008J?CP2BTU80ZJQW0:^WI`39aHD0YZ9R0:nZJP30^g/0/j]/0<:jN`2e
[Fh0/ZQZ0:FWJ02`]WP0[;9d0:ncMP2^[g<0]KEi09jIG`2OU5`0[9eV08ag@P3<]H40^k5d0;VcM@2[
XfD0[:9]0:fPM018=1`0:1410:jDP`2lXY40dkNY0<FWW`3Wf<40[ZF40;:ZP`2P]7D0XkId08Ii@P2G
TUX0X85C08ea@@1hOc`0XjmW096DD@2>SDd0W9QI09jFF029PdL0Og/n2`3oool000X0oooo05H0f^2P
0=cUY03EgYd0fnNW0<gIV@3?fZ00j_>l0?ooe@3moML0oooO0?ooj03cnnh0nN?U0?oYi@3nonX0oooR
0>cJ]P2WUgD0dLRg0>KDe03jnOl0445509nl]`3Eh/P0_/FS0;FYO`2cW7X08@0001/0001WBDT0m=kA
0>OI_`3^jl00k>_<0?3Xg@3[h=h0l>CV0>;Ie03koml0eN6a0=;PX`3DgJ@0`;fB0?oog03oomX0loK9
0=cN[@1HF280UIUN0=KUXP39gIH0eNfS0=K/X`3Jij40fNFS0=_U/`3GgKL0cm>j00<0001XHVH0oo_h
0?oomP3oonP0oooS0=CL/`3PiKd0oooS0?ooh@3nom`0e>Bc0=?V[`3Jl[@0`=VH0<cLW@3SkK40blbC
05eQ9P3>giT0c^ZP0=GKV`1VJRd0f>JX0=CU/@3Bf[40oo_Y0?ool`80ooWj0<80ooS/0?omm03oo?P0
oo[j0?ohn03om_<0GT<j0?okg`3oom`0dMjX09^UL@3oo]`0ZZB:004100000`00`mZn0<kZ`P3?m[l0
_NRb0;KR/@27/i80HXea09:iW01gW7d00140000:000jCS<0H7MK08jaT01]VGD0H9A]08;3V01k]XH0
anZb0;cVY`2oij40a>>P0<WJY03AjKL0PF]C0:nFP02[_IL0OH5L03<e3P2=WG00E6Dh0=S/^`3Llkl0
enjf0;obY@34jJ<0c^fY0<[PXP38hJL0^=nV0<gj`@2]g:H09ddN09RdR`2X]i00DEX[0>3W/@3>f9`0
f>NR0<GGS@3Cj9T0RIi?0<cQU03DiY`0g>bU0>Kb/03Dh9h0`]6@0=c/Z`39gYd0dNJS0=3VW@3@iiT0
dNJG0=?UV`3Ci:00dn>U0=?XX`3;h9/0c>6N0=OY[@3Ah:L0dn2Z0>Se_`3>fIl0en6U0=GOX03EhIl0
d>6M0=GYY03>hYd0e>NU0<[MV`3Jj:X0dmjR0=WQZ03Qi:l0emFR05=E9P3Nj<<0noOD0?oog03CbiX0
ooG606IX:@2ka8<0fmZQ0>7_]03Jh[40j_320=7MZ`3>hJT0`N6N0<c[Y`3Ajj@0jN^/08N1A@1AA100
AC/:0=WO[`3>gJ@0c>VI0=7VY@3=dJh0h=c30?onk@3OeK`0][2>0=KNY@2mcXX0e?6O0<?RTP3=j:<0
bnFL0=;XW@3=hI`0io;80?_oj@3loo@0o_oj0?SlkP3Pj/P0m_oM0?coiP3Xll/0d>:V0=7VY@39h9X0
a]nM0=[`/P35fYl0cn>V0<WLW03?hi`0bMjA0=_aZ@3;gj80f>fb0=7ZZ03Ajj80bnRD0=GbWP35hY00
e?>W0<KPU`3?i:40cnJP0<OVVP39iid0dNJU0=OT[03Nh[00UYYW0=g/Z`3;g9D0dnRS0<gS]03<h[40
a]fU0<OOX`3;iYl0dnZT0<oSWP2JZFH0[Kai0=CSX03Ci:00d>FP0<[XX080b>ZP00@0c^VR0=G/YP3;
h9/0b]nJ103o0000203NijH0h>VX0=CMVP3ChiX0e^^N0<GLSP3MljP0cNBL0P3o00001`3Ei:d0f=nc
0>_`b03Wl/L0aMnP0=;YY@3Tm;<00P3o0000103Oj:T0cMbK0=k^[@3>fYX40?l0001L0;BKL`1B?aD0
h=j^0>3X]@3;iJP0a>:R0<7JV03?i:40b=ND0=7UX03<hI`0dnJV0<[JW01OJ3<00`L00>7O[P3PgJX0
h]^T0>cSZP3Fc940f>6R0=KRXP3Ac980ZIiV06eX;P3Gfih0iOZg0<3IU@3NmK40gnFW0>3KX@3Ri:D0
eM^K0=;KVP3LiJ@0eN6O0=WUX`3Ij:D0fNZV0<OHU03>hYd0e>RS09JFEP2/YfL0TXY;0;^cM02JT580
Zj5S0;:XJP2NTeD0/ZMY0:2EE`2MSe80UIYJ0:niNP2EWUl0VImQ0;6bMP2WYf/0ViUN0:VPI`1cJ300
VhaE0:JEG`30^7T0/ji^0:JJIP2m[h80d/2L06Q>?@2QPgT0o=_D0?oWh03oiM/0o]gF0?oniP3RgKd0
i>2j0;S>T02dbHP0VXmG0=[EW@2fVV/0GD<B0<;=R@2jagl0_Kih0;ZeL@3>bHD0fmJD0=7<S03[jZX;
0?ooo`002P3oool08`3>eI40dmfH0<?=R03?fYH0`lj:0;g7RP3?ei`0dMRR0<W<W`3NgkD0d=N^0=CZ
_03Qek<0hmN_0=?WZP3ChZ40fMBJ0?k`_`2ANfH0ooKh0?olo`0oMg@0Q:f?0=7U/P35cYT0RGe=0?gW
`P0U1P40F3Tn0?ofo`3ol?@0oo[d0?onk@3ooO40ooWm0080ooSo0?/0oo[m0?Ogf`3NiK/0c]FO0=CD
XP2m[h`0oooO0?ooh@3jm=80gmNb06iU>P2>RU/0dm^R0>Ka]@3<fYd0iNnc0<o@U`3OhjP0en:X0=_T
]@35bjT020P006ERG@3ooo<0h^C>0<gDZ03LiK00dMfM0<cDV@1ZH3`0THUT08B5F@2=U640k_O20=7O
Y03CgZ80JW8f0=WMXP3Ee9/0`l640=gNV02gbGd0[[5/05IG4`34ch/0TieQ0:VWM01^Fc/0MG9C07Y]
FP2<NfT0T89X0;R/TP2o/iT0d<:X0;ZTS@2CMV@0QFUC08]gDP2dZWT0N88m05UK702_Rg40f;RQ08]a
H02`VhP0?C<H00L2001bMdl0CeD_00P?001MHT/0EeLo03@S1`1ZECX0TgEM07EB?02nV8D0X7]X07=I
@01kJTh0ShIU0>KZa@2FY800EGmG07n`P@1o[WL0U;^606n8GP1AKdT080h200l0000J;1H0[JjL0>3J
`P2l^H`0/k610;k0SP3=dIh0[[=k0<gIT@35eXl0amfD0;SAS@2ldY40a=>J0:6^N02PZWH0K7a;04EK
:P1QM4L0De0_09B>JP2JV6l0TYUS09FOH`2MYVD0Mghk0:FZJP2CV5P0UYaN09VOG`30`g`0N7U009bN
K@2Y[gl0X:Q_09BNE`2g`GP0DUHI0:2PK02OWW00T8QQ0;6XO`3FbJH0g]>c0<S1Y@3@b[80_knS0?oo
h`3?fjd0_/fF09b_K@35eI@0M7e40:FZM02>Ted0TYIT05AF9`1^Jd00TXmV0;ngTP1kKT`0QGIE03dd
5`35a;00b[^V0=C3Y@2=O4h0PF4b06m[;P1lOSl0ThaE092EF`2i^H<0h>>/0=K[/P2M/GH0aLZ@0:f[
LP3OdY/0I4PF081R<03_gZX0f]FN0>?e^@3@jJP0eN^S0=o^/`3`lM40oooZ0?ofiP3oo^H0ooOF0=KJ
Y`3BgJ40f>fX0=[aZ`3:giX0c>2I0=GUWP3Lj:H0j>k00?oog`3no^@0ooo/0?;efP3@ejd0fnBg0?Wo
f@3[nLH0cnBQ0=;YX@3?jJ00c>FQ0=3XZP3AijT0cnFU0=7VX@3BjJ40d^fV0<cWXP3<iJ@0eN^[0<CG
U`3=gI`0RIIA0=_VX@3=eY<0eM^K0;RlP@2k_XT0`LJ>0:RgMP2ocX/0[[=i0:NUM02eZWd0RWmA09VG
GP2XZ6P0c<j?0:jZN`2MUVP0ZJ=a0:^UL@2XTV<0X8QJ06]C9@1TC1h0HDTK06iF:01_FR/0hLnO0?3T
/P2[Y700b;j;0<6aP033/h00i=BQ05M;5`040?l0000709ZIH@2KW6<0c<fA0<?9P`2HWU@0[[A/0;Vo
N@040?l0000509bCJ02NUF`0dL:K0=:lS@2ZWFH0103o0000102gZ740]JA^0;bjO`2QZf`20?l0000b
0:F?H02MQU`0YY1W0;>ZO`2IUVT0^l:?08bCG`24OdP0ThIA07AP:`1EA`X0P7Pj0::PI`27Qe40>d<@
000:0038hJP0^]RL0<_e[@2ojih0eOnd0;oYW@32iYh0c=^J0>WZ[P3BbI00D4L>0>oc]P3Cgil0`=FB
0<oZY@38iZ00bnJO0>Go^032g9D0cNNP0<3KU03El:T0a^BL0<SXW`3=kjD0c_:X0<ocZ@3:iY`0d>RN
0<_UV`3<i9X0dNVO0<oWW@3>iY`20<oWW@80cNFK02L0bNfS0<O]Y037j:40a>>M0<cUX@3CjZH0d>FR
05ia;`1lSdd0b]nL0=3UXP3;k9d0c^jS0=O]_03Lk<L0g^W;07f0K@3mo_00oooj0?cmm`3dnnT0i_3E
0>Oac03WklH0h^bj0<[^Z03@kjT0RhU<09^OI03?^X/0X91O0=?ZYP3Hm:X0cO6W0:kFS@3Eo[80Y/en
0=go/037i9802`3oool000X0oooo02<0b^2H0=S^Y@3Aiih0enfT0=K/X`3?i9l0e>VV0=3TY@34eil0
dN:/0<kSZ`37iJL0g]nV0=oMY03;hYX0b^FH0=SOV`3Of:40SG5L0?o^k@3oo_l0DHj608>`Q@3<hJH0
h>V`08EfB`3oo=`08`H2054f>`3on?l0ooWo0?oho03onOD0oo[g0?oho`020?ogo`3l0?oko`3oonD0
d=V^0=WPZP3UiK<0ZYai0?olg03mn=P0mo?@0>[R_@1QFRh0Lg510=SOZ@3>fIl0gNR^0<_CVP3OgZP0
i^N^0=[XZP3=fJL0LWYE0002001]KFD0ooo_0=GH_@3Ggj`0`ljB0>3`Y`3IiZ40XIia0>gZ_@2VZ7H0
LWI309^RK03DgJ@0j_Bh06A/<03Vk;00eMVL0>SXZP3MfYD0e^BI0<kARP1oPSd0f^NO0=gXYP3OgZD0
/J1e0:>QN032_9X0hMBd09N:JP3>a:00c/VO0=_DZP3?`I`0Leln0=o;ZP2XVFh0_;Eo0;>mM02IWU`0
ZY1g0<>/S@1iJSl0SH9E0;>`Q`0A3P002PX000P;000110000`D000d>000M7@D0:B@>02@G1P0d91D0
MV9G079NE@1YGDl0UHmo0:>TTP2AWHD0XKFJ04miE@0PDB@095DN01a43`0jEBX06SXC03d/8P0k:280
T:6?0=7Ba02f[i`0YIid09fFK02;R5/0XJ1b08:4D`27QTD0XJQT08bID`1cQd80Xk=b09nTJP1UIBl0
GE/X079kAP2N[gT0:c/<04]49`1?A2P0DThY09bRLP1`Md40W:1U0;NhO01bLSH0UiQN0<G9SP2EVed0
/;=/06MU<P2QWgP0XZAm09bPK@2LXel0Zk1]0;RfP`2d[hL0@cdK0<^mX03HaJL0jM>l0?oZe`3Zf/d0
jMcC0>k[fP3oon`0b]F[0=CR[`2U^WT0a=BE08fAG`2;RUh0IfHj09B@JP2WXGd0]:^:0>3G^03/g/@0
h]>l06IF?`18>bX0g=G;0>[Ib@3B_Z<0XYAS06mA7`2FU5L0Y:UY09J?F01TJRh0QhE<0:N[L023X600
Tj9W0;f`O01bFbT0WGm=06Q>6`1`G2L0XJ5U09^QI@2Q[g40V:QW07jBC@2LZg80YJV60<K5Z@2`ZY80
]Jn?0:^WP@2EW6H0TYeQ08ZMG@26VeP0VjmZ09^/IP2Q/FX0YK9]0:J]N@3;cZ<0][RC0<;6Y@2Y[HP0
UIe/09NQK@2g`i40/;n808jTG02G[fD0TJeR096/I@2J]7<0VK9a09F[JP2G[VH0V[A[09NeK`2?[6T0
U:e[09fcLP2;Ve`0RiUK059K702_]GL0TIEH0:6RIP27QTd0RHUG08jAG01bO3d0SiYH07Yk@P2FT5h0
OFi307maA01NFB40K6X]0<K8R@2m`8/0^;R40;BeO02d]G/0]Y]`0:ZBIP1SBal0]j9e09b7FP2VU6H0
DdDF0:VMK@26O4/0RH5@0:bNK@1cERX0YhIK09akD01UB1`0OVHh0P3o0000201ND1l0EddJ05]A7P21
O4@0VY]G06IY8P22QCh0SI1;103o00001@1UGBh0Mf`o0:>EJ03=]HD0GDPC00@0o`000400LfP`07]b
>@23QdX0L7`l09^ZJ@1UHbX0RGi809^=G02GRE`0OWE:05mK;P3Pgjl0/[1o09Z<F`2bW6X0OF4_0;RO
IP2jYV/0Lf8^09>5E01?AaT020@00=CKZ02W/G`0aMRH0<ONV038hYP0bN^Q0<O[X`3:iJ00enbY0=OH
W01FDAL0THI>0>_V[03Rj:X0d_>/0<;`Y@2aeh`0^=R?0<g]Y02ng9@0`^2H0<OUW@3;jj80`>:H0;kR
V02mhiP0]]nC0=3ZX@3=hiX0d^ZP0=G[XP3?iid0e>bR0<_UV`3<iY`0cNNM0<kXWP3;iI/0an6J0<oV
X03@i9l0fnZW0P3Cg9/08@3Rj:P0FV<R0<_DT`3MjJL0cMbI0=7`XP3:k:80b=fd0?WojP3lonl0VY^=
0?knm03oood0o?kk0>KbgP3Bh[h0c]nb0=;T/P3Ci:d0_nRL0<gbY@2X[Fd0EV0S0>CFY@2ZWV`0cNZW
0<OYW`2mikD0^>Jh0;GS]02cfZ40_=jQ0=W^[@0;0?ooo`002P3oool0o`39kJD0aNVO0<GZW@31iYP0
`NJF0<;WU`31iYH0a>VK0<W^X@37jj40aN^P0<C]WP3Aii`0eNFL0<oZW@31lI/0d>nS0=?GVP2`RgP0
ln;J0?Goo`0kPFT0UL^A0>7i_@2maIH0^:B<0?oijP0[5`h0>BXS0?oonP3oo_l0nOCh0?ojo`3ooOl0
oo_o0?ojo`3oo?l0oook0?3oe`3Ik[H0f>jV0=7MV`2RWf`0fMNW0=SP[`3Yll40noo@04aD6`35ci<0
e>NW0<gSXP25VUT0EV@W0<;5S019Ca<0cn:R0=[Z^@3Bg[X000<007IiLP3am><0mO_O0<;?VP3JjZ/0
SjAE0=keY`3@ij<0d^NT0<OFU@3Afi`0SYMH0=kWZ03DgYl0WJaY0<gNVP3JlJ/0c]fJ0>7OXP3Kk:H0
c]^E09>PFP3@j9h0a]ZC0=OPW`3OfIl0f^RZ0<_JW`3Wk[X0U8mW0>7S/@3GiZ40fNZS0=GTW`3Nj:/0
D5DM0=3EW@3JhZH0c^2D0=;VW`2mcid0bMnQ0;cGQP3:iY80B68K0=od^`1GISl0VjN3049=9@002@00
TIaT05mb>P3Fik40f>Bf0=7J[`3^l/l0c]:a05mR@`0]<a40NX5O0008001OKdX0c>^o0;oW/P2/eY@0
^]nL0<GNY034iK00h]:i0?olj03con@0X:26065O>03KiYP0cmZ<0=OUUP3FiiL0enZI0>;QZ@39aXl0
hn2Y0=kKY03_j[<0j>F^0=GBV`3ShZX0gnBZ0<WAV03BeZ@0l>;500X4000N8000g>fg0>?b^@3HhZD0
f^2R055E603Jhj@0iO6c0<gMW03GhIP0dM>[0>WYd@3jo>L0e=Va0=[SY03IhJD01@D00?ook03klND0
VXao0=G5]@3ono40ooK_0?ogo03onOl0ooci0?Gej`3GhKh0aM>R0=GYY02ibH/0C4hW0>STb@3EdKH0
1`4000L00025O6d0?cDY00X0002g[:H0ooch0?ogm03ooOd0oocc0?okh@3_l;L0aK^00>7b[P3<hil0
h^J[0=?OX@3MgId0h^:R0=KTYP3Df9d0jmbU079Q:`2OTU/0e]bL0<oPW034hYP0d>ZP0<kNU@3<g9<0
dnVQ0<cQX03Bhjd0dnB`0=;S[`3DiZX0d^FU0=;VW`3DjJ@0dnRW0=3VY@3Bk:80ennU0=CYWP3AiId0
enNV0>Og^@3Ei:T0dnFY0<cNX03TnK@0_mBA0<oQX`3=h9h0cnRG0<[VTP39j9P0b>NK0<OTX@39i:40
b^FN0<_VV@3:i9X0b^FP0<[UWP3;iI`0c^RN0=3UX03Jkj`0go:b0<SHV@00;@3IjJX0c]fJ0=OVY@3B
gJD0dn>T0=?YX03<hYL0eNBO0=7IW@3ViJl0VYUS0=kTYP3SkZX0_m290<?UV@31hIH0c>bS0<OWWP3[
hZ/0YZA[05mS:03JjZ/0c>6P0<[SX@3<ij@0c^VV0=[_[P3<g9d0f>BV0>Oa/P39di@0fN>T0=?OW`34
di80fNRW0=7TXP3@iJ80cnJR0<kUX@3BjJ<0am^C0=g]Y03AhIX0c]jG0=k[YP020?l000070>;]Z`3R
jjX0h>VZ0=KPX@3Jhj@0jN>Y0:>DG@020?l0001=0?3Z/03;fiX0_mRD0=[c[`3CiZ@0cm^I0=3TW03D
jYl0en6R0=_PYP3SiK<0gN2a0?ooeP3_m/<0hn6^0>;KY@3gj[D0cMjG0=SgZ@36hIh0fo>e05QZ=P00
2P00c=RV0=WS[`3HhZD0am2=05YQ6`2FYf<0b^6M0=Gd[P3Hmk40bMbJ0=GNW`2TVf80EdhE09jLH@33
f9D0c_:Z0;[LTP3>k:@0a^6J0<kXX@31eY40g_>^0<KJU@3@iJ00eNbV0<7KU03GlZ/0b^ZO0<?UV02o
i9H0`>FG0;kWV032kId0a?6P0;k]W02lkI/0_O6N0;kbW`2igi80`n>H0<;NU03<hi/0e>FO0=?TWP1P
LB/0bN2H0;kJT02kh9<0aN^N0<SlZ@2lkZD0^]fo0>kon02]`kL00P3gooH05@3bool0l?oo0=Oke`31
kK80c>b[0<[UXP3@jj@0`oBK0<_gX03>f9<0BEPG0=oGYP1@BQX0^=^K0<3YY@2Xjl`0=7eZ03AnI`1D
Ug@0]^k707:FJ00;0?ooo`002P3oool0_`35iZ40`nBM0<KXWP3;kYh0cO2N0<_^VP38jiL0a^VG0<GZ
VP34jiX0bO2O0<G_W@37iYX0c^JL0<o[X02klYh0`>VK0>7[[P1nED40o?3R0>OolP0aO5h0F91C0=K]
]`39cjT0^jFJ0?ogl`0]6a409A`=0?ool`3nooX0l_;b0?omo`3oo_l0noSo0?gjo`3mo_l0m_kc0<oW
]`35hj<0c>VI0<OLT@2JWV<0e=bS0=3RZ03AiJX0fnfa055Q803GjZP0`]fF0=;`Z02:Y5d0e^VW0<;8
S02SZfl0`]JI0=3R/P3KjLH00PP0079gL@3noo@0j_;J0=?Q[P2eahT0amj@0<cWV02mhY@0e?BX0=3V
WP3HjJ<0a]>>0=3KV@3EhIl0RYiI0<[TW@36iYd0dNRR0>?RZ@3EjZT0enZX09ncKP3Bl:P0eNnV0=SW
XP3SiJH0fO2Z0=C_ZP3DiZX0QhQN0=SQZP3=j9T0c>bG0<[ZU`2ldh/0I7Lg0<SFV`3Lk:h0e>ZO0=?]
X`3=kJX0bN^Q0<_^VP3;kIT0an>H041I5`2`_XT0fnFc0=SN[P3HfZP0e=^U0;kGU@37gId0d^>/0=_/
^03Mj;d0o_oM0?Cje03`m]00d]Rb01TP000nBAl0b^F`0<?WZ@3LokL0hOne0<kUX@34i:<0k=Vh0?oh
f`2FYgd0i>C00=3?W`3@iY40e>ZE0<WSS039iHh0bNN?0=?JYP2UXG40XiUX0:RGJ@3SdZ@0UI9M09^N
I`0/=000Lg]00:Z_M@2n^XX0k^710;>`S@0B6@00/lR?0;O=S`3HijH0e=fL0>_a/@1bOS`0dNBR0=G/
YP3EiYP0j>k80<75]03noo@0iNc:0=7LX03Mj:h0Ng]Q0?ool`3oo_P0jN3G0<W2/P3mmNX0ookh0?oe
o@3oo?l0ooko0?oon03DfkX0eN6a0<KGT@1kRD`0UYYi069PB`1kN6D0inCE0?onlP3oo_H0ookh0?ok
n03lm_H0ookm0080oogo01h0ooO^0?ooiP2mb8`0h>2R0;SFSP31hY/0f>BV0<_NW03Ef9D0hMjK0?Cb
]`2OVV00F5HK0:VZKP3]mkP0d>ZS0<_[XP39jih0c>^M0=S]X03Jkj80f_BZ0<[TW@3>j:L0b>:S0<cY
Y`3;jIl0bNRJ0<SUU@3:iIP20<cUX@0n0<GVU`3;jY`0b>>F0<OOT`3@iil0b=fH0<oVXP3DkZL0b>:I
0=OcYP2ofHl0b]nL0<WOU`3BkYX0bnVC0<c^VP3:jYh0anFO0<SVX03=jIl0cNRI0<_VV@3?j:@0dN^R
0<gXV@3<iiP0d>ZP0=3ZX@37h9h0b^FR0<gXX`3;iid0bN>L0<cRX@3>j:40`nBC0<SZUP38hiH0fnnZ
0<WCU`2b_7l0c]nI0<SMTP3BkIh0_NBC0<7VUP35jY`0`>FG0>WSY`1QHb@0Xji/0<COV03<kZ@0_>FI
0<G^XP32j9d0dnjW0;W@RP3>hih0^mN=0=3`Y@2ifHh20?l0001j0<_[X03:jYl0b>RM0<GUVP37ii`0
c^jS0<kZW`38hYP0bN6G0<cTVP3=i9`0c>:J0=?YX@35fi80enfT0<GKTP3:hYP0cN:M04iG603UiJT0
h=ZP0<O2R01aMCP0h_Ve0<k/YP2ogIL0a=fI0<oUW@39jYT0a^VE0<kTW03Chj80eMnZ0<kKYP3komH0
m?oA0>[e_@3?eih0l?6h0=OgZ`2jiI<0c?B[0;SLW01hUEd000l00<OIY@3DiJl0cm^M0<[ET@3RkZH0
Tj9O045A403?j:@0ZlB00=3UXP38eiH0dMFH051A5@1JFal0gNNX0=3PW`38giT0fO>/08ZOFP1NLRd0
<cl001l[0030bhT0am:@0=OSX@3Nkj/0g>fY0<cSV`32g980d>bQ0<g/X02nh9<0b>fO0<S_X035l:00
`NjM0;[[V@2lkI/0doR[0<OWW03Jm:/0g?:Z086BC00fA`40R9UC0<?MU032h9H0_^NI0<chZ@2hiiH0
_>VT0>;nj02U^K0021LB0?WomP3kooH0looo0?;oo`3FnM40`N^Y0<KXWP3;jJ40an>F0;SYS@2mjXl0
TieF096PG@3RfZ/0Ge//0<oc]P3Lol<0GYmm00mI?P1?VW/0RlnV08K1T`2A]h@;0?ooo`002P3oool0
8@34gI/0dNZV0<gWX03?ii/0dn^M0<WTT`3=jID0cNZF0<[WT`3;jiH0aNJE0<W[WP36kj<0b>bR0<WW
X@2jl:D0_nfR0=;PXP2bSG80dmS405f7L`2Mi[/0]>BV0=;R]@2CUWT0h/k=0?oin00d9Q/030@00?oo
k03noo<0o_ok0?_lo`030?_oo`3j0?Son`3doo00`nFX0=Gj[032iX`0e?2L0<_IV`3FiJX0b>2R0<[W
Y034hY`0a>>G0<WZV`2oi9@0d?FU0<3PU02nfXl0eNVQ07J:A@3:gZT0dn>o0=OSb`001000IFUX0?Sn
lP3[m=T0S9mW0:ZoQP3<jZ80b>^K0<gkX@2njY<0anfJ0<c[W@3FkZ@0gNbW0<gLU`2AYel0`MnE0<?`
W`31hiT0g]jZ0<GQY03?k:X0RZAS0<WZY@2igI<0iObf09fOGP3AkJ<0]n2B0=?b[02BVVL0e^R/0<?]
V`33lIT0`o2K0<SaXP31hiT0/<V80<OPW`3;iZ<0c^ZP0<OPS03Ckj80cNNX0=ga]03DgI`0h^ZQ0=SO
T@2TZV00T91B09nAK02VWWL0/lF709VZM03<g:d0GVi103M45P0K:000:C0>02T`4@3Oi<H0GV52020U
003Hj:L0c>JM0=?_V`3FkYP0d^2A0<7LS@3Td9d0ZiIW0=?X[@3@ej40fN6X0<o_[035iJ80co2[0<[Y
Y@3;j:D0eN6_0:NON00^6`00oMg40:F;L02n_iD0eN6_0<gRZ@3@hZ@0dmfQ09^HH`1NFRd0[kN601@U
0027Y680a>>M0<?MU03Jl:P0bMfF09F/I020VU40b^VM0<cWV03Ij;l0bMFo0?_omP3kon/0koc@0>;_
a03Uk=`0^[^f0?ono@3oo_P0oood0?konP3_lNh0nO[o0?Kgo03nool0o_oh0=;G]`3Dfjl0A4h?0=KM
Z@010`00jn_Q0?oomP3nooH0nokc0?comP3Qim/0o?oh0?Wlm@3nood0nogj0?_kl@3em>00DELc0;gF
U@3Ci:00bNfS0;kRVP3AhJ80cN:O04]E3P1KFQL0_JY_0;:^KP32h9H0d?^/0;7RT@35mZL0_^ZM0<g_
XP2oh940d_JO0<g_V@39hID0h?J]0<gTW03ImJX0^=^90<;_U032ki00an^A0<SZU03;jIl0b^ZO0<;W
U`31ii@0a^VI0<S[V`37jYX0co2Q0<3QTP2ohY00a^VG0;WORP3@lj40bnNM0=7^WP30hHX0anR?0<WY
UP36iIT0c^bT0<cZXP37iI/0bNVF0=3]V`3=i9`0b^:F0=3/V03?k9P0anRG0<[]W@38kZ<0_NJJ0<?/
WP30jiT0`N^I0<;YVP34kYX0_>^?0<3_T`34jYD0b^ZN0<[QV`2P]g40`]bC0<KUU`3DlJ40d>>D0=7S
U`3?i9L0h?FZ08Mo?P2EUU80i_2W0=?^W`32iID0`NRE0<C^VP38kId0c^VL0<_RU035g8h0coFR0;o/
U`@0o`0007T0bnZJ0<k[V`3<i9H0c^FG0<oZW@2ohI@0b>jQ0<K/W`36jih0b>fP0<W[W`3:k9l0cO:R
0;kTS`3Amj80PjID05mk<@3?kJD0]]R>0=7eZ`2nh9H0e>nX04YK5`2gaX<0c^>N0=G`Z@2niiT0`NjI
0;k/U038jYd0b^FN0<_QX`3AiZ/0e>fc0;oKX03;j:P0bnRV0<GOWP3Ajj40a^6D0=?/Z037gId0MHYB
000=0039gZH0d>FZ0<WRWP3<iYd0c>NJ0=7VX@3AhJ00?DL80:nhN@3RlK00b=fJ0<WWX@3>jJ@0c^>P
05EC601LCAH0/K5c0<kDU03Nhj<0f]ZL0:j/K`3GdiH0_[Ym05mK7P1LFQd0m_Jh0:Z/K@1OEAP0FdlC
0>7GVP3Le9H0HUhO07Ad=035ahH0f>6N0=_VXP3@giX0dn:M0>7aZ02]^W80P8Y506]d<@3KhYl0cmRE
0=[TW`3Jk:80bn6F0;kOT033j9X0ioJm0>[ab03on?H0HeIP071NJP3onO/0ooOh0?oioP3oo?d0jo;A
0=?RZ`3Fl:T0a^:G0<CQS`3:mI/0anfF09NQG03HjJD0al6A07IcB02lik80:ePO01U72@36mkH0]^NU
0;k/Y02E^W@0_M:=00/0oooo000:0?ooo`<0b^RN00<0b^VM0<[YV`3:jI/00`3:jI/06@39jY/0b^VK
0=?]Y032jid0_nZJ0<OYW@35ij/0`nNM0=KSV`3O`Id0fo3Q04AhJ`2jl/40an2V0=OJZ`2OWg/0ooOX
0?oll`11<2H0=bHL0?oll`3onoH0oogm0?ono`3oool00P3nool0_@3iooX0moo/0<[SXP3@jih0_]F3
0=WZY03Af:l0lOOE0>ggdP3Hj[H0bN6U0<OYW@2lhI<0aNNJ0<k^XP2P_780e?2S0=?`WP3>jYd0dNBg
0=_Ve@3cno00008007EbK@3oonl0h^S208ZPE`3=iZ`0a>ZQ0<CYV`3AkYX0bnjJ0;CQT03JokH0_N6G
0=WXY@3Gh9l0WZUU0<SNUP35lYl0a^JJ0>GPZ02lfiL0d>nY09J]J@3>hIl0`nNM0=G/YP2UU5`0i?>`
0<3TVP3@k:80SiAD0>Ge]P2igId0b?:`0;cVWP3?lJL0b>:I06Mh<P2DY6<0e^^`0:JjO@2nbX80c>>O
0<WRZ`3Ci;00dLjI0860@02bbG/0b^VK0<[ZX@3Bfj`0emZ]038b000Q7P004Q8005aP>`3Tl;00e>>P
0>;_``1`NeT0KGML0:2/R00`?0h0cmnP0<gWX02ldXT0f>RM0=_UW035fi00RgY20:BGHP2lgid0g?6f
0<cOY`38i[00a^>]0=7T[@3Gi:h0UIQS0:2EG@2GQEl0Ie8g0?oil@3ono40fMbo0=GP^03@hZh0bnBS
0<gVY03Bi:H0cmfR096OHP0fAPP0IGhl0<o]Y`38jZ00_N6G0<CTV@2/b7h0J7lg0=G[X`3CljL0e^^c
0<gH/03Cd/00ooo_0?kol`3fo>h0loSa0?onn@3[hn00oo_h0?omn`3Mf=`0jNCX0?ono`3hn?P0o_og
0?kolP3Ig;l0VIeh0>7W]`0b=0l0UY240?onn`3hnO@0nOod0?Sok`3Nkl/0f>S10?_oh022R6H0alF^
09ZHO`2c]XT0YJel0=;QZ02mf9D0X[Md0=[YZ03=eiP0]KIj02H/002KYfD0/l9m0=CVVP3=hY<0c>RD
0<_[V036k9T0_^RL0;_WW039ljL0^nBE0<kdW@39jiD0en>Q0<C2Q`2WWF80d<jA0<GDS`2niI@0`nZG
0<[UUP3:hY@0d_6U0<KVVP020<WZV`80b>^K0180a^^M0=?eZ02nh9<0anVL0<SXW036iIT0a^JJ0<O^
W`39kYh0_^2:0>Ko[`3AjId0cNBN0<kWY@3;iZ40anNL0<KZT`35jI820<[YW@80b^VK00P0bNZK0<WY
W@38jYh0b>ZN0<SZW@36jid0a^^K0<K/V@<0aNbI01P0bNVM0<kZX03LlJh0Z[em0<WGV@3Rl;80dmjL
0=gLV@2/[FT0VZ1J03<j002QZ6@0c]^E0=SZX039iIP0a^RK0<O^W@35k9/0aNbM0<SZW@3:jI/0bNZK
0<?]V@2okiT50?l0000@0<KUU@3Ak9d0dNVK0<kYW03Al:@0`n>G0<[ZWP3BlJD0`^6E0<WUVP3;ii`0
cNNM0<?NT@3Mn:/0S:MJ0<WYW@<0b>ZN06D0bNVN0<cXWP3HkZH0Y;Qa0;gARP3:h9P0bN>J0<KUV@3:
jId0eNbT0=KZY@3ChZ40d^2R0=[ZZ`3<gil0dnRU0=G/Z029X5`0bnNL0<o^XP30fi@0f?:[06f3@P00
3P00bn6P0<KOV`3Im:d0^mV?0=_j[P33gIH0gO:]0<cMV@2<WET0dNFP0<kRW@3>hih0f^nZ0=CXX`3A
g9X0_L>3069M8`1BBA00YYeT0=W@U`2SWF<0OgTo0=SCV@2o^X00QhE:0>SX[03LgJ40j]jT0>KEW@2W
V5l0h=BJ0=_BU`3VhZD0EeDH0>OYZP3QiZH0hNZY0;6jN@1;E@`0DehB0=KQW@3Hi:@0f^ZY0=;WXP3C
jJ00cNRG0<WYU036jIL0a>NG0?[oi03no_@0_;Nm0518D`3omol0ooco0?omo`3oood0oOkh0>_df@3J
i/80e>Fa0<_QX@3Ckj80d_6U08:LE@3Ii:P0dnnU0>3P[00a>0h0Ah9F06jTLP2>`840/n6P0<oi^@32
hJD0U:a`07b9D@0;0?ooo`002P3oool:0<WYW@0G0<[YW@3=i9`0`_6P0<GbW`3Aiih0bnJa0;kCTP21
Rd@0b<NI0=Whj@09>c00]^:a0<cFXP2a[880A44N0<Bo[01aJE`05@@001L4003on_H0oo_j0?oko03m
o?l00P3oo_l0_P3nool0nooj0?Sok03GjJd0c>2I0;G4O`1bO4L0m_SR0?gkk03ooo40n_oR0>3aa03>
kJT0a>JJ0<OVVP3BkZ<0PI]B0<OSUP36jID0c>^O0>W`cP3oooP0ooom00/<001RGeH0l?CI0=[T/P3;
i940f_Be0<?WW`2ogY00g>ZM0=G]W`2miYL0_^NI0<;SW03Gh:40jn^_09nOG`3Ii:00`^NG0<STU`3J
eYT0c^bT0;kPUP3>iIl0HVd[0<W[X@3CjZ@0GdPB0::[JP3;jj80b^6I09nKF`3Aei/0Igm;05Id@03K
n;h0d^RX0=c]Z@3;eY40WZYX0:k1R@3Hijh0dmfH0:c2P@2<YFh0ZKV80>7NZ`21OdH0@5`A05=i;01B
O3@0c>2]0=3I[03QgkT0kNSD0>KUd@3Lgl00VjQS082@A@2V]Gh0eN:f08JBK01CI2h0XK1e0>3^/01m
U500^]2809>TGP1mR4<0aMfC0=[;TP3Dai00^]fI0<oTZ@3Li[40nO_:0=gL[01NFRX0Ad@A0>_U/@3Q
hIL0gM^X0=GA[03ooo@0n_O`0?kol03hoNH0mooO0?CofP3RlLP0d>:b0=c_[@36fIL0j_k307F;G@1A
K4<0ank20;WS/`2mijP0c_:/0<_ZWP3Gkj40c^jU0=kc^`3do=<0^K:R0?cckP3oo_l0nOco0?[no`3c
lO80oogk0:^LV@3oo?X0oogk0?_cl@3oo_/0ookj0?kkm03oo_D0UYB509FDP00m?2L0lO3K0?ool03d
m>P0o?ka0?Wol@3Ymmd0_]6S0=GY]02V]G`0d=fW0=CJ[P3SjKT0h>n^0=O/Z@35gYX0d>VU0;g@SP2g
^7`0gmZP07Ud>P3PhJD0f>^Y0<o]Y@33kYh0a>^H0<SXT`39iY80a^>C0;_KTP3Fmk80`^>N0<GSV`3>
hi@0f^ZO06Q^<P2MWV80^KUm075b=P1DFQX0S9]F0=;XX03EkjD0fOFZ0;kMS`3DljD20<[YV`0B0<WZ
V`38ji/0b>ZM0<SZWP30h9D0c^ZP0=SbZ`35g9H0dnfV0>?o_`2_dHD0cnnL0<?PSP33gY40cnVR0<[T
X`39iZ<0bNVP0P37kIX:0<WYW@0E0<S[V`36k9T0a^bI0<S[V`39jY/0c>RN0<KMU`3Tm;D0/Keo0>S]
/`3:ciD0UYYO07al?02KWEh0h^RX0=SSW`3FjZ80cNFK0<[TVP3;jYh0bN^N00<0a^^M00<0b>ZM0<WY
W@38jYd00P35k9d00`35k9/0o`000?l000050?l0000=0<WSV@32gY<0cNVN0<GQUP3DkZ@0an6G0=[d
ZP1aRCl0Tj]Q04MO5@2J/6L0a^2F0<SZW@020<K[W@160<SZW@3:jId0c>RM0<KNU03>iY`0h_R_0=__
Y`1XO3@0Mhi809J]I`3Dj:<0e^NS0<oNV`3BhIh0`<n<08^JE`1=HA`0[L9m0;oFT03<k:40c_2S0<3N
U036hIX0f_6]0=?ZYP3;hY`0c^RQ0=3/XP3Imjd0/<n30<cVW`3?iZ00_mJ@0=kc[P2gc8L0Jh0k0;gA
S03@hId0b=VE0<OHU03Um[80e]bN0>KWZ`3BdYH0alN;0=3@U02e/gP0^[Ek0=[EV`3lmkd0S8M=0=C>
U027NT<0Wi9K09nDG03kl[T0c/V?0>?QYP27Qd/0f=bO05UO8@2S[6d0/[]l0=WUV`3<fXd0gNjZ0<gP
X03BjjT0bNBM0<_ZW080b>ZD01h0b>VH0<WYW@3ho>/0oOWj071[L@2n^l@0oO[o0?glo`3ko?l0o_om
0?con03lonl0mOgV0=KS^03Wnl00_m^>04aV7`39fid0dN2W0;kNTP3Phj`0:S<80:GV^`2jm<40Vn_>
021hHP1DXHd0K::;00hf7028WGh;0?ooo`002P3oool:0<WYW@270<[YW@3=jIl0`oBR0<GbW`3FhI`0
c>F^0=[Z[01IHR40d>2_0<?Ue0004@@0`^Ri0=OM/@1FD2`0QH1S075[G@070000<1lH02dJ4`3onoH0
oocj0?okn`3nool0oooo0?ono`3nool0o?ok0?[okP3Fik40b]ZK08nMG`1hP4l0ooo_0?gjl@3oo_P0
o_oZ0>;abP3<jJL0aNFL0<kZW`3GlJL0QIeC0<cVW036jIL0d^jT0?ooh@3dlNX0o?Se0042001PHUL0
c=Ff08JDG`30fHH0dnj[0>Go_03=j9/0f^BK0<?HS@3:k:00doFY0<SSW03=diD0i^BW09BCD`3Fh9/0
a>FF0=K^XP3<bXd0b^RP0<[/XP3@ij40?4D40<;TVP3GlJX0IU4J09>LF`35iI`0dnVQ09bBE@3Xijl0
21X0000<001AJ300e>R[0=CSXP3Eh9`0f>BR0<WLY031diL0gnZU0;oHU03ImK/0dN>_00d;000S9000
h_bc0;WMT`3<lJ`0d>Bc0=[U^P3Ri/<0m_[S0?ook@3non@0c]fJ0=o_Z02O[WD0gN^j0<CAX`3EiJL0
cMbI0=k][013FQ@0d>ZQ0<OKU036eXl0dNfR08ioAP2SUUl0`=nL0?Cob03oom40He`X05iG8`3Ac9D0
g=NP0>3OY`3HiID0dmjR0=SQ]03noo40ooof0?ool`3oonl0ooo/0080oooZ04h0j_7?0<oQY@3@i:L0
bM^W0<OM^@1ZPfH0E7]L0;gYa@2mj[40a^n]0=7eZ`3?jih0anJR0>;d`P3noml0fM760?olnP3ooOl0
n_[o0?coo`3]k?40oogo0:>HUP2l/ZT0ookd0?cek@3Cc/P0mNgZ0?cgl`3oooP0/k2W0:j[XP0=2`00
oooa0??eg`3go>H0o_o_0?_ok`3Ul]H0h?74041B7P3Jk;00i_Fj0=GR[036eI`0`]ND0<cUX@3=j:<0
cnJR0<OGUP3<c900MFle096?E03OiJL0b^6M0;oPV@2okJ80`NbM0<_ZVP3@kId0e>nR0>Co^P2ddHh0
eo2^0<[NV@3Rk:<0g>:J0:N]L@3KijL0_]6?0=c[ZP3Ujj/0[Jm^0<[CT02keH/0b>RL0<_/W@3=k9h2
0<[YV`0D0<WZV`38ji/0bNVM0<SXW@3Po[@0b^BK0=7XXP3Cij80a]^H0;cIU`3DlZX0cnbJ0=?`WP3G
ljH0c>RN0<KSX038ij<0bNRR0<KXV`38ji/:0<WYW@0F0<S[V`36k9T0a^bI0<WZV`3:jId0cnJN0=;W
XP3EhJ40d]bO0=3CVP2WZW40Ce<H0<G>S@3ao;X0e^FR0=[^Z@3;hiT0an6G0<[VV`3<k:00b>ZM0<GW
VP80b>ZM00<0bNVM0<[YW@3:jId00P38jYd20<WYW@L0o`0000`0bnFK0=C^Y032g980a^2F0;[DRP0m
E`d0aMfC0=?[X@33fi40hOV_0=KbY`38jYd20<K[W@160<SZW@39jId0b^VM0<WSV@3GlJL0_]J<0<CJ
T@36g9<0c^RO0<_UWP2=XUd0G70[04aM6@1LKBT0Sj1L0=c]Z@37g9L0g_F_0=SbZ`2ngY80aNNJ0=Ge
ZP3?kJD0a=^G0<GLV03Pmk<0b^6M0<[TV`38i9X0j_nk0<3JT`3KlZ`0fO2Z0<cQW038gIP0c^>N069f
<@2nch/0iOJb0;o@S03=gYX0dN2O0=CSXP3@fY/0en6R06me=`38c8l0[Zib04a:3`2<Qdd0H5XP09bC
FP1OE1`0fM2G0>cV[03?bY00UiEJ0>?TZ02HVEd0k?:d0=3IVP3Ihj@0cm^K0=?SV03=h940d^NR0<_Q
X03CkZT0a^BL0<SYVP80b^bH00D0b>NK0<OUW@3jon/0ookm081kO`020?omo`0G0?ono`3mo?l0oOol
0?con03loo<0mooZ0<_H[@3Dj:d0cn^N09NaJP34eYP0g>^`0=;bYP3JgJ@0OHIG0:GT]@2dj[H0Z_oP
01ilI00nTW/03DT_08nmX029Xh002`3oool000X0oooo2P39jId06038jYd0a^ZP0;[^W035k9/0imnQ
0=GT[@0J8P00P8mH0<7c_P1BOV<0^=o<0>gog`2YYHP0lNKB0?K_g`080@00L6MR02HG4P0O3PL0oocd
0?olmP3oo_X0n_ko0?ooo@80oooo0500o?ok0?_olP3FhKT0dmn_0;_4U`3enmT0n?S^0?ono`3omol0
ooof0=[PaP3?i:T0d^VS0<oVV03>hiH0[L=j0<cVW@33iIT0cN>R0>gM``3oo?<0oocf00P;00073P00
R9Y`0<7IV`39iI00amjF0>Cj/P3;g9D0V9mK0>gj]03BjJ40amjF0<gQW02IVe`0eM>F0:VXJ03JhId0
c>NJ0<cRV@3Zk:d0c^RQ0<_]X`2oeY00GF<S0<_[XP37hY/0IEHM09RMG@39i9d0en^V08alB03Jd9l0
BdhS09BMLP1<FRT0VJMb0>kl`@3;fI/0JG`l09ZbM037h9l0Ykaa07ZECP1JMcL0GG8g0<oFX03Li:/0
amfM0<cVY`3;ijd0nOoL0?_og@3Mm<X0l_oV0=WZb03Fj<00d^BX0<oOX@80U:5[06`0dn2X0=GSV03D
h9@0Df8Q0=SbZ`3>kZ<0d^jT0=[`Z03>l:@0f/fF0=S9TP33eiP0N7]40=SFW@3Sj:D0dMJD0=_QX`3G
gj<0gnZ`0;kTS@36ij00b>JZ0?Goi03hon`0mok/0?kol@3ooo40ooS^0?ommP3^j]l0fNC60?Soi03i
onP0l_oW0>koj@3?m=80=Eli03]Y>021[GP0/MRO07NDFP1_R4l0b=FY0>?Ya`3ooo<0Z:2N0?gjo`3o
oOl0o?oo0?koo`3`k_<0ookk0?ogjP3/iMD0ooka0=C;a03bj>H0ooSi0?olo`3Fd=@0aKo30=;>c`3o
oo@0n?oO0=3Q]@3Iil<0o?oZ0>kdf02;TfX0cm^Y0?;oa03DkZD0Xl=g0<odY`36k:<0b>bT0<GTWP38
fiT0b=6B0>ORZ01HDQP0g=fQ0=OSX`3>kJL0anbW0;kZ[@32jJP0e_2Y0=W_Y`3BiYl0go:`0=7SY@2G
XFD0VIeR06aT9@2PV5T0hnf^0=3aZP32mJH0`>VM0<;ASP3:^Wl0LF8W0<3AR`36iYX0`^VJ0=;gZ@3:
jI/30<WZV`0B0<[YW@39iI/0foF/0=GYXP2[_7P0_l^90<_GV@2`_XT0d^BX0>[o^02nfhT0co:N0<KX
V`3DmK00g?bk0=Oe]@38iJ80cN^U2P39jId05P38jYd0a^bI0<S[V`3<j9d0cnNM0=?TWP3BgY`0CE<E
05UM8037b8h0iNB/0<kDV03CjZ@0g_Ra0<OUW@3MoK@0bnZN0<c[W`38j9`0aNFI0<SZW@3=kJ420<[Y
W@040<gWW@3?iid0cnNM0<oVWP@0d>JN1`3o00020=_cZ@080<[RV03CkJ<0[lUo0=7]XP38i9T0dnnT
0=CcY`3;jil30<K[W@0<0<SZW@39jId0bNVM0=_j[P3<jil0bnNL0<GQUP3@k:40c>ZP0<[XWP3=jIl0
dN^R0P3FkJD0F03>iId0eo6X0<OSV@3?kJ<0f?J/0<_]X038kIl0bNVP0<SVX03<hZ40cnFT07R=C03L
lK00e>VT07^BBP2W_gD0amjF0=C[Y@3Aj:80a]fG0<OLU`2icXT0dNFP0;kBS@2db8<0YkQd0<?DT03<
ij00c>bS0=7_Y`3@jZ<0d>BO0=?TX03Ii:80g>:R0=[OW`2DU5H0b<J90;^kO@1NH240GV<S0=kSX`1_
N3L0CeXH05EQ7`3KjZL0dnBP0<oSWP3HkJP0d^fN0=7^W037iId0b>NQ0<[[Y039jj40aNNJ0<_/W@3;
jYh0an2O0<WQY@3oonl0NWMb0?ono@3oo_l0o?[m0?gko`3noOl0o_kn0?cnn`3nooP0o_of0?cog@2=
XF@0TZiQ0<gWX03;gIl0bmZO0<_/W@3Vij/0KgI308W4SP1[WF00<6PO0:oWW02WgI80^^FN0<S]ZP31
gil;0?ooo`002P3oool:0<WYW@0H0<SZW@36kj<0_NjM0<[/W`3Ygj80e]^U065Y>P2DZWT0_OW601E6
9P2lh/T0m?oQ0;F]V03ooO40ooO^00H0003`i^D0:a`G01h?203oo?@0ookh0?oonP3enoT0o_om0P3o
ool0_@3noo/0oOoc0=?J^@3Ni/40_<BO0?koj@3oooX0oo[n0?oio`3oo_X0e=O20<oSZ03EjZD0f>ZN
0<cNTP3:gYH0cnJN0<SZX03@iZH0i]:i0?oik@3oo?@01`X0004=002Y_i00_]RG0<[VT@3LlZL0a=F?
0=OTW`1GH1d0b=NB0=3WX@3Il:X0a=RC05UO7`2MWf00UY]I0<WDS`3GljP0c^JL0=kSX`34fiD0eoV_
0<?MUP1PIBD0c>bS0<CRVP1MDaP0V9eM0=;YX`3AhJ00F4/G0:2HI`0S9000EE``096NL00X=PD0c]nY
09V]L01DK2h0h?fm0<cYYP3EkJ<0`MfC0=3ZZ@39hJ<0fNN/0<gHX03>hZL0ambT0<gQ[03_o=00mOoI
0=3`_P3WomH0a^2c0<GK[03BiJh0cMjX0<gIY`2?VFD0h>^c0:jjL02IYET0SiiK0<cVW`35iid0aNFL
0<_UWP3:kZ@0g]6J0<bkQ@32dY<0Ph9:0=SGWP3Ak9l0bN>I0=?XY`3?hJD0bmbV0;cSTP36jZ@0b^V]
0>gof03gon@0n_oY0?Woj@3mon/0oooa0?ool`3ak^D0emgA0?Gnk@3eoNP0nOoV0?Ooh`3>l;h0PJUe
06bHI@12K3`0=5T]09ZeRP2gbiP0cMV[0=cR_P3ooo00gm[F0?omo`3jnOl0o_oo0>o`m@3oo_l0kNWV
0?ggj`2o]j`0j^7H0?oflP38_;`0oo_m0?[_l`3iloD0LVa^0>gYj03cmnH0mOoH0=G/]P3;g;00o_oX
0=SL`@2EVG@0fN>a0?Coa@3;jY`0b_:J0<;^V@39mj`0a^jU0<g^Y`3Lk:/0bm6C0=KAU`1YI2X0f^2R
0=?SXP3=kZL0a>VV0<KX]@34hJT0bmjN0=7PW@3ChYl0Hg4c086?DP1FH2@0I6P]07ad=P3VhJ40`mB@
0<7ZWP2_j9L0b?NY0=C[Y@3`hJH0[9UO0=SOW03OmZh0^NFF0;o/V`040<WZV`0B0<[YW@3Dl:H0aMbD
0=KWX@2^^WP0cmRG0=[RY`1eOD`0enB/0<kVW03LnJL0b>^I0<;WVP3Ko[X0ioo80=kl_P39hj@0d>^X
2P39jId07038jYd0a^^K0<SZW@3=iid0d>JM0=KSWP3HhJ00O81309FFFP3Kg:00h^>Y0=GNW`34h9H0
bNNM0;gMTP2deXX0aNNJ0<CVV@33iIP0a^RK0<_[W`3>kZ80c>RM0<gWW@3?iid0d>JM0=7UW@3AiIh2
0=?TX0<0dNFP00<0cnBO09:WHP3o0000103o00002@37gI@0cNFK0<gWW@3OnJl0g_Z_0<gYWP3=k:00
e?BX0<CVV@040<SZW@80bNVM06<0`n>G0<GUV@3DljL0d>nS0<OVVP32h9H0anNL0<_YW`37hiT0b>BJ
0<gYW`35hIL0c>RN0=CbZ02ogI<0b>JL0;kPT`38kIl0bn^R0<WWX@3Bj:P0c>:R0:>eM`3?hZ80dnRS
09bcJ`2E[F<0eNnV0<KPV@3Nn;40`]VC0<gTWP3DjjD0enbW0=O[YP3<h9/0U:QS09:VH@34hYX0c>jT
0=?aZ@31giL0d^VS0<kSWP36ei<0cmjK0>7]Z`3NijH0am2?0=3FUP2]]WD0RY=B0=[SXP33chd0RiYG
092QG@3GjjH0`mRC0<?JU03@ij40bnZJ0<_/V`34iY`0a^ZR0<GYX@3=lZD0b^bO0<[[W037iI/0bMjS
0=7S/@2VZIH0@D4i0?oon`3fmO<0moGf0?Sfn`3ooOl0oogn0?kno03ooo/0oooj0=WT_01bQT/0[<Qm
0;WDS`3FjZd0g^fb0=7bX`3ZjZ`0O85;0:kU[00HAPD0>5T80=CaW@3GlZ<0bN:N0<GOX02^bI@02`3o
ool000X0oooo2P39jId06036jih0`NfP0;gXV@39j9`0gmJK0<g6TP1bNe00kOoM07BcQP0mLdl0b>o@
0?oojP1jKUh0ooK`08n5P`1fL700oocm02dP6P0M3PL0ooW_0?olm03oooX0nooo0?koo@80oooo07X0
o_ok0?kom@3?dk`0g^G60?ooj03hnnH0n?Wd0?omo`3onOl0ookk0<kA_03>h:H0e^ZU0=[ZW`38f8d0
fNfV0<[QV`39jZ<0dNFX0?OOa@3ol=l0ooS/0003000b?bD0c>F^0=Kc/039iI40bN2B0;K2P01cOCh0
e>2N07>3@P36gIL0amjH0>Kj]@3Ag9X0YZm/09VTH03Jjj@0`N2D0=7[X@3NijH0bn:L0;oSV@3=ij00
D58C0<SVWP3<jZ80HU`P09^MGP3FjjH0b=^I08IoB`1GE240Zjb0075gB`2/]h`0JWY=02Tk2`0hDAP0
SJU^0;gMW039j:@0cnVO0<oZX`3BjjT0f_2`0=?UZ@3Kj[40gN^f0=[[]`31dJ80o?oL0?SofP33jJ`0
aNV/0<[W[@3FlKX0d^Bd0=7Q]03lom`0YZn009>MJ02KZ680TIiF0=;SW`3@jj@0bNfS0<OWWP33gIH0
`^JL08n0B@2aX6X0`<j@0:nZL`3IfId0`N^I0<S^X@34hJ40b>6X0?Sog032iJ40`N6R0;gKW`36gZ`0
dnVk0=SW`03>f[H0e^2n0?Slh@3Vj=00f=_:0=CId`3oooX0mOOY0?Wog@3gomT0`=fW0=7d_02hh:`0
_N:f0<_^aP8000`000L0KgQ90=ON]@3em>00oood0?ginP3hm_T0oooo0080o_oo03P0oook0?okm@3n
mO00f]7<0?ocl`3hk>h0oo_o0598B@22NWP0KVUU0?oonP3lond0m?oD0<KOY@3Dj;L0oOoU0=cOa03b
m]40bmFS0<_UW038jYH0boRK0;c_T`39o:l0]=jD0<GVW`3KijL0al^>0>SSZ@1?CA80d=ZK0=_^[039
kJD0b^j^0>?idP3Nkl80MGi505aU9P1dOC`0SIUK09VWJP2Z]GT0d]ZN0=cKV`3Ph:00f?:[0;gVVP32
njX0[^6B0<SXW`3YhJ<0_JY`0:6KG@3EhYd0c_n^0;?WU@@0bNZK0180b^VM0<SRV@3Djj<0d=nJ09:N
G03Rj:P0embR0>7W^`22S5L0bn6I0<_WVP3:kId0_^:H0=oo`P3/oll0h?k20<KNXP3>j:L:0<WYW@0H
0<SZW@36ji/0b>ZM0<oWW@3Ci9d0f>6N05YO7`3XjJd0W9eQ0>KZ[@3>dYL0hN^/0=WhZP36iIL0fOZ[
0=;eY@38kIl0b^bO0<_]X03;jil0b>RL0<KUV@3=iid0cnNM0P3@iYd0103Ci9d0e>>P0=CSX03Dhj03
0=?TX00308nTG`3;h9/0_mJ@00@0o`0000T0d>RN0<_SV@3<iY`0a^:G0;_JSP36iIT0anNK0;kNTP34
iYT00P39jId0D038jYd0bNVM0<WYW@39jId0`^:F0=;bYP36iIT0`^6E0<SXW03?kj@0bNVN0<WWW@3@
kZ@0bnVO0<?SV038j9d0a^BJ0=OeZ`34hYP0c>bQ0<g`X03;kYh0`^:I0=;]Z02R^7X0Jgm20=OY[@15
EaT0eNZU0=;XW`38h9@0SJMN08NQFP3:i9d0c^FO0=C[Y@3>iIl0a]^F0<gQW03Hk:L0bmnJ0;K:Q@2:
YEh0aN>K0<3NUP3<ij00`mfF0=OaZP3Ek:H0c>6L0<WNV@3@i9l0dNFP0=CSX03MjJL0g^fZ0=KUXP3A
iJ00e>RS0<oTW`33fY@0g?J_0=3[Y03BkJH0anZH0<S^V`37kJ00bo6V0;oSV@3:kj80anVL0<WXW03:
iJ00g>jj0>gld@0g>RT0AdLo0?kmn03ooo/0ooom0`3oo_l0503no?d0ooom0?_jmP2R[8L0eNR`0<gY
WP3El:/0en^`0=3OYP37iYX0eMBD04a?602gjZl0`^fX0=O_X@32ehP0d^NL0=7WZ@3=iZd0Hh1B2`3o
ool000X0oooo00D0b^ZN0<SXW039jId0bNVM0<SXW0050<WYW@3G0<K[WP32lJ<0^mV?0<cSV`39dY<0
KE<R0?ooh`2>[90034DU05ZBI@2jgk@0FDTj0:6BR`2f[:d01P000?[en@3hl_@0<bHP01lA203oo?<0
oo_a0?oon03kool0o_om0?ooo`3oood0oook0?oonP3ooo@0m_OY0?ool`3oooH0oook0?Kel`3omOd0
m?GW0=?J^`3BhJH0d>6K0=gZXP2@W5@0d^6N0=?VY030giT0bmnP0:NDL`3_h/80iMk400<;00002000
e?6_0<7OU@3bok`0`mV70:NaM03HhjT0c>:R07^AD@3:hil0c>FQ0>?j]03LlZX0_mF=0=SbZ03>kJ40
_N:D0<GUVP2AX5d0dnNR0=;f[031fi@0in>V0<7LU@3FmZd0ATP907mm@03=gYX0`=FB0<gFW@2IXFP0
`<BB0>OZ^`0Z=@d0dn:k0?7og`3@kKl0^mbW0<CVZ@3@l:l0`mbJ0=3SX@18FAD0AeXH08^SI@17G2@0
=SlB08bAJ03oom`0e]fa0<WLY02nkYX0ao>L0<g`X03>k:H0ioOC0?_ok@3lon`0koWG0;k:W02d`XD0
dn>R0<cRV@3>kZ<0d?:X0=GcZ`3<hIh0`n:N0<VhQ03:]X<0S9aM08f;DP3Pi:L0`>ZN0<GZY03=j;D0
cnBk0?_ok@3honD0nOoO0>kod03AiJX0cN>U0<WOX@3Nm;H0bN6U0=O_/`31fi`0cN6^08bAN`3?b;h0
ooS[0>KKa`3OfKl0W:J1092QM`2P^XX0XK^;08fWM`1YODX0e^BY08F@F02?VfT0gNC20?oojP3QgM80
mo;/0?Cak03noOP0o_og0?conP3oo_l0n?7i0?kdo@3dio00ooWo0=C8b03ooOP0N7EV02l^6P3amM`0
hno90=C^/@35gZD0bmb`0?OkhP38b[80kO7<0=SR/03Ajj40b>bE0<7cT02klI<0`NnT0;oUW03Lmk80
g^BV0=7AU@2:RTh0OX950=GXYP3:iJ00aNVQ0=kj`03oond0oooV06UR=03=b940i>FY0=CSX03@iJ80
c>NT0<gVY03AiJ00cnJN0<G[WP36jih0`^fN0<7]WP32kIh0d=nL0>7MX01nIc40fmFI0;SWV@33n:H0
1039jY/04P3:jId0a^:H0<cSV`3LkJL0en>Q0=7JV@3RjZl0jo;60=_U/@37fYX0bn2M0;kHU`3=iZ`0
h_g80?;of03So/L0bnFX0<GPW@D0bNVM1038j9`09P39jId0b>ZM0=Kk[@34i9T0d>BM0=_XX`1kOC`0
JVX/0=[JW02GVEX0cmZH0=_WY`3Rljd0bnRF0<SWU`3@lJ00e_RT0<G/W@35jY`0anVL0<_ZWP3<j9d0
bnFK0=S^Y@2odh/0Cf<K0=[^YP2Y^W<0WZeX08RGE02KZVL0TJ9N09f^JP3<h9/0gOB^0=C[Y@3?jJ80
d>^T0P3o00000`3?iid0cNNM0<gWW@020<cXW@0;0<WXW039jId0bNVM0<KXV`39jId0`mnD0=C`Y@3;
ii`0cNVN0<o[X036iIT00P36iYX00`32hYH0b^ZN0=?eZ0030<WYW@<0b>ZM00D0a^RK0=;dY`2ogi<0
b>RL0<7QU@020<c]WP0P0;oJT`37h9h0S:1U004E001kSE<0d^BX0=GZY@3=iI/0c>BH0;kHS`3WokX0
Q9iG08bVG`2=Y5h0c^FO0=gd[P39gYT0cnBO0<WNV@3QmK00//=m09Z[I@3@i9d0e>ZR0<[TV`3AkjD0
b>ZN0<K[WP35jih0`nbN0<;]WP3<j9h30<oVWP030<gWWP3<j9h0c>RN0080b^RN0P39jIh04P36ji/0
aNbK0<?/WP33k:00aNbM0<K[W@33iYH0dNbU0=K^/03[mm40o?oZ0;Vk/03`l>P0no[e0?kmn@3ooo/0
ooko0?7]kP80oogo01<0eM7B09jJV@3non@0d>6]0<WTW`38hZ<0d>>/0<oNY`34hiL0hM^M08F2B`31
kjl0aNVQ0<ke]039l;L0_>>/05QnC@0C>@X0UKb@00/0oooo000:0?ooo`030<OWV`39jId0bNVM00L0
bNVM01P0a^^N0;KPUP37hIP0foF/07J9A`1M?`/0n_[N05mhI@2ei]00cooC0<GU]P1ZET/0YIJA08Z1
Q01cKW80ooko0?ojnP0`8a/08aD:0?oml@3mm>/0oooh0?Kjn@3nool20?ooo@2^0?onn`3oooX0nOC^
0;Vf[`3oooP0m?G]0?konP3nooT0oooh0?koj@3?f[80d>>S0=WZY03OjZD0c=NC0=o^[@3>hIl0cnnV
0=7WYP2h[8@0g]N]0<o<Z@001@0000T00<COVP3GljP0_]J:09F[F@3OjZh0cmbV0>coaP1kTeD0_]BC
0<kUX@3JlJ/0c^RO0<_UV`3<jil0`N>F0<CZW@3AljL0RYiI0<cMV@2cehd0dNbU0?Sb]P3@jZ<0aNNM
05iT901RGR40cMbI0>3e/P3Mkk40dMbP08^>F@3Nh:l02Q000>?^c03VmmL0`=Zc0;oL[P2mfZ00bnNZ
0=ga/P3ChJ<0EV4O0>Cc/038h:80bN2X096FK@1SHC/0mo?=0>G]_P3:gZ<0_^bD0<GaTP3:k9D0c>NP
0>?ae`3hoo<0o?oa0>kgfP3Gi;T0dN>Y0<[MW@3=iid0b^bP0;gMU02ofY<0eNFV0=3ZZ@2GPe00FTHC
05]^;02JWV40i>R[0<gWX03EkZd0e^Fj0=;M_@3noo<0oOob0?Woh@3loml0f>Z/0=GZY@3:hIT0c>JM
0<KQVP38j9l0eON[08fXI@32cZH0noKS0?ofi`3on_H0ooSb0?gnl03ion`0mooO0>_ocP3AjJd0am^F
05UX9`3Agj@0NXQC0;O3W@3monL0g][>0<o6_@3oo_P0oooh0?oomP3an?00moKl0?olo`3onol0gM7K
0?ojo`3ono/0ooWb07imJ@1^L5P0m_oM0<SG[036gJD0cn:d0=7P^@3Tj=40mOOQ0>cbc03Fh[00d>bQ
0<S[U`33lY@0_^nD0;?KTP39j:80c>6N0=_LX03;bhl0HFDX0;g7R03DkJT0anFO0<KWX03Wo/H0oocc
0?odh@1PE2X0h]^U0=gMX@3Ci9h0cNNP0P38jJ803P3:j:00bNVN0<?/W@39jId0b>ZN0<G[WP31kIh0
f_B]0=3FUP1H@``0hMJN0<CZX@2nkIl0b^VK0`39jY/04P3:jId0a^:H0<oYX03EjJ80cMjJ08B@CP3B
gZ00h>bj0<KCWP1oSU<0/lF90=c_^03<gZh0h?K80>goe03ToLH0bN>R0<[XXPD0bNVM02d0b>RL0<WY
W@39jId0bNVM0<SXW036j9/0doFY0<;PUP3Ei9l0g>FR05]K6`3=cHl0gn6R08nEE@36eI80dnNR0<GK
T`3MnZX0b>NI0;gNS`3=l9h0a^fN0<?XVP35iiX0b^VM0<SRV03?iid0dnNO0=gaZ@39gID0am^C0=KZ
XP3:fiD0enRR0;kBR`36g9@0eN^S0=W`Z03EkjH0a^2G0=GaY`3@kZ@0c>RN0<cXW@3=iid00`3<j9d2
0<[YW@0C0<_ZWP37ii/0a^JJ0<OVVP3Fl:H0dn^Q0<7IS`3Jm:X0b^BJ0<o[X03:jId0b>RL0<[ZWP38
j9`0`N>F0<WYW@3:jId0bNVM0<SZW@020<K[W@0X0<S]W`3@lZD0`n>G0<g]X@37iYX0c^fO0<?OTP3;
hY`0hoVi08^NIP003@00=TL@0<cPX`3Aj:80b^BJ0=3[WP3:iY`0`]fF0>?n]`3EkjP0P9YC065k=038
giT0bN2J0=cc[@3Cj:<0dNJQ0<OFT@2T/F`0cn2J0=;VW`2je8/0c^bR0<K[WP35jih0`^fN0<7]WP2o
kYh0bNVN0<gWWP<0c>RN0P3:j9h20<WYWP80b>ZN00h0a^^K0<G/V`35jih0aN^N0<K[W@36ji/0c>nO
0<CMV@3@iJ`0m_oQ0?cok`3dmNd0oooj0?[im@80oook0P3oo_d05@3on_`0n_Cf075[K@3ooOl0o_oX
0<gM[P36h9l0bnFX0=KX]03OkKP0cnfS0>?KW@21O4@0ao6a0<_[X02egYP0^>JV0<;`/P2fhjP0XljF
0<ki``0;0?ooo`002P3oool01@30h9@0bn^O0<SXW03:jYh0bn^O00D0bNVM0<P0bNVN0<g[Y@3Hm:X0
_nBG0=Gd/02KR4d0`:RL0?7_m01COW@0`=nc0=3LZP2`VXl0n_7/01@D503GfMP0o_oo0?oon`1CASd0
6`d00?oik03ono80ookh0?ooo`3nool0oooo0?ooo@3oooX0ookk0<c3a02c[Jd0oook0?oon03gnn`0
f=g60<kH]@3LkKL0TJEX0=K]Y@3:gYH0e=nM09nWJ`39eIL0f^ZY0;oNTP3=iih0SiAN0=oW[03UkKX0
00P006IgBP3JlZP0a=b@092UH02W_FX0d]nY0>gjc03=hZT0e^R^0<SFV@3?gYd0d^6N0<?IT03DkZ@0
c^jR0<SXW@35iIX0`^:G0;S?R@1lRdP0e_Z`0<SSW03NeIX0c^RQ0;KLT@3_nkT0GELK0=3IV03DjJH0
b^FR0=SXY`1OGB@0KfLf048l703ooNP0l??R07Z6LP14CS<0SIAX03Y44P1SL3/0ADD?04M5201_MCD0
MiAD0729DP0f=Q80bl2P06mR?`3Zlk`0bMfN0<S]W`39kY40c>RA0=GZY`3jooL0o?oo0?_on03Wm=H0
bmn/0<oZY@3@k:80d_>T0<?ZV`3Ak:D0d>>Q07Ej@01:FQ`0IDdM0:ZDHP36i9h0f>VU0>7^Z@3FiJ00
h_2b0>ogd03Wjm80nocd0?ono`3ooo40o_oT0<WIV03EjYl0/<Ql08jXGP2D/6H0b>RM0;WKSP3FmZd0
d^Jc0?ooj`3il^P0oo;o0?ogo`3onol0o_oo0?SoiP3/old0e>f[0<_RTP3GiZ<0dN:[0<[NZ`37fK<0
lOkR0?okk`3ol^`0oo3`0?olnP3oooX0noom0?[no`3gm_`0o?Wo0?_bm`2l/KD0oocg0?oml`0n@R/0
LGMK0<7AZP3Jj/<0cmfi0?Cli03jond0YZZK0?kok`3Xm<`0dnB`0=3[Y039jY/0anjK0<GZVP3=iZ80
bm^J0<_DU@0]:`00QhM;0<gLV`3FkJT0`^>L0<SYXP34hY`0hoG10?okn@3on^`0G5<Z0;nlQ`3Jgil0
d>JM0<[YW@80`nbP00d0b>ZN0<SZW@38ji/0b^VM0<cXW@3:jId0a^^N0<3NUP3JkjX0VY]O06e]<@3P
jZd0b]ZI0080b^VK01@0bNZK0<S[V`39jId0aNFJ0<_YW`3<iYd0f_6[07B8@`3LlJh0dnf^0=_c]`3I
ik80b]>T08jBL@3ZkM80mokO0=WX`@3;gj`0bNVP0<c]WPH0bNVM0`3:jYh08039jId0b>RL0<KVW@3B
k:D0cm^I07Ek>`3ShJ@0eMBD0>3WY02mbXD0`=ZA0=GeZP38jZ00b>VT0<KZY03Bn[<0`^ZS0<?XVP3:
k9l0b>RL0<oYW`3BjZ00f>jU0::fKP2O/f/0_=:90=_aZ03<i9X0d>ZP0;cHS@3=jIh0cn^P0P3o0000
2038ii/0cNbP0;kNTP31hID0cnnS0<WYW@3:jId0bNVM0`3:jId0403;jYh0b^JK0<_WW03>kJ40bN>I
0:ZnMP26Ue00UjQQ09^/I@1eRd80X[Y`0=SdZ@3<j9d0b>RL0<WYW@3BlZH20<cXV`0[0<WZV`38ji/0
a^^K0<K[V`38kId0`NBD0<c]WP37iYP0an>F0=3XVP2N]6T0TJEP0:k0PP1ZN4<000d00>Gh`@3Gk;<0
dnjW0<_ZWP34iIH0b>JL0<KQVP35h9T0f_F^0=cf[`2idh`0NiE>0<_RW03>iIl0eNbV0=kc[P3EjJ80
cN6I0:^oM`3CjJ00fO>Y0<gYWP39jId0b>ZM0<K[W@35k9d0`nbM0<SZW@060<WYW@H0b>ZM0P38jYh0
2@38jYd0bNZK0<OVV03Ejj/0go6m03Dm:01CETd0ooom0?_kn@020?ooo@0H0?ono03oo_/0o_Wf0:BL
VP35_;d0oocm0?3Vi`3non/0jOS?0>Cm``3?ik<0mooM0>[gb@3NnkP0gmFJ06]T;P34j:P0bnFK0=7X
Y03@jJP0an6T0;_IX`27YgD0W/BC2`3oool000X0oooo00D0_=b@0<c/X038j9`0bn^O0<c/X0050<WY
W@0F0<[XWP35g9P0e?BY0<[dZ036jZ@0c/B60:V3P03nk?X0028J0=C[_`3/k[d0jM?80;be[`1IFeP0
o?oo0?gooP3ooo/0Fe5501`<003onnh0oocc0?ommP80ooko0;D0oooo0?oon`3oo_X0oogk0:VPX`3M
e=L0o?Se0?_kl`3monh0eMjo0=?Q/02ldY40S:IO0=_fZ@3>i9/0e^2Q09FMHP3?fId0g^f/0<_WVP3B
kZ<0X[1e0<OFU@37e9`0GFY>096QL034fHh0h?J[0:>fM03?iI<0fnVd0>3]`@30dI/0e>6[0=cTZ@3V
kk00e]nN0=S/Y03Dk:80bNFJ0;oMT`3>jZ00dnnU0=gg/02IYF<0]mfB0=?^Y`3XgZ<0e_2Y0=;h[@2g
aX<0K6<X0>K_[P36fiH0bnJQ0=[[Y`1?B@l0@38107QXCP3on^X0oooc01LI3025Qg80mO7;0:JUN@0R
:`00=S<00:BNHP3Nh:40anBT0<oW/`1ACR/0o>o?05Q:9@3?f9l0f>b]0<WZY@38j9<0bn:@0=GWZ@3l
ood0o?ko0?Cnl`3Wm]D0d>N_0<c[W@37j9L0b>^K0;oVU`37hY/0M8=207Yi@@2DWV80PVLh0;6KJ@30
hIX0c>>M0<OKU03;hIH0cN2N0?CoeP3eo^40m?O/0?Cdo`3noo@0nOoQ0>?c/P3<hIH0TZQM0<?JTP37
h9`0hoji0<CRVP3>jjT0amjb0?_olP3oooX0ooGo0?oho`3onol0oOko0?OojP3SnLX0b^:T0<[PU`3B
h:<0d>:^0=3V]@37fkP0n?o/0?oilP3om?40h/oA0?ohnP3oo?`0koGa0?_oo`3nool0oooo0?omo@3?
a/L0ooWc0?oll@0`<ah0a<fb0=OXa03@gkh0f^;:0?[nk`3noo@0[;2R0?WokP3VmL`0d^B`0=3[Y03:
j9h0b^bO0<SXW@2ndHl0hnf^0?Gf^P2GTUP0V9QL0=c_[@2lei80anfT0<SYXP37h9`0jOW80?_fl`3o
o>l0J6<i09bMI03Eg9T0cnNK0<WZV`33k9h0aN^N0<SZW@39jId0b^VK00<0b^VM00L0b^RN0=[e[P37
hY/0a=BC059L7@3lmkl0d]>G0080b^VK01@0bNZK0<S[V`38jYd0b>ZN0<[ZW`3;iid0f?:[09ZaJ`36
gi/0e?Ba0=ci^@3lomP0l_W@0;JaV`3RgLX0inWA0=SR_`3;gJ/0b>RL0<CWU@H0bNVM0P38j9`08039
jId0bn^O0<c/X@3FmZd0aMnH0=3KV@1LHR80k^b_0=[IV@3Oj:D0Xk9]0<SXW@2lhI@0_>FI0;oVY`2i
hJ80a_2`0;cYZ034jI/0c^jR0<c[W`3EkJ<0eN^R0<7GSP2CYel0^ln70>3f[@30f8h0c^RN0<;NT`3;
jil0a^NH103o00001@3;jil0`n>G0<[]W@36j9/0b>ZM00<0bNVM0P3:jId0503;jYh0bNFJ0<gYWP3A
kJ80^=2607J6?`2AWUP0_/j70=GUWP1iSDD0Bf4H0=OaY`3EkjD0bNRL0<OWV`3:jId0c>RK0<gXV`3:
jI/0bNZK0P36ji/08@34jIT0aNRH0<GTUP35hI@0f?>V0:BiK029Ve40SYmK0<kLX@2KZG@000X00;kA
VP3Gk;<0c>ZT0<CTV03;kYh0a^BJ0=?^Y`3<ij00bnJO0<SRV`3HlZ/0TZaU07fDCP2M]6h0e>^U0=3U
X03<hi/0an6G09bfK02U_gD0cn^P0<;NT`020<[YW@T0bNVM1@38jYd20<WYW@80bNVN02<0bNZK0<[Y
V`35hI@0]/b<0<kN[@001000gn3K0?ooo`3kno/0ooko0?klo@3oood0oo_h0?onn`2KTi40oogk0?[a
lP3oo?d0ooo]0?KogP3aom40b>2^0?Oog`3Ag[80cnbZ0>3FV`1_IC00b^f]0<kVW037ehh0cn2J0=KY
Y`3CkK00SJYb0<3U/@0;0?ooo`002P3oool01@2]cH40cNfQ0<WYW@3=kJ40bn^O00H0bNVM09D0bNbL
0<[`W@36jIT0g?Fa0<3?V01OFSd0>2/J02<B2`1^HEP0ooW/0005001DGC80nooV0?Wol@3fn_/0noWn
089dL`0K30D0ooga0?W`j@3ooo/0o?oo0?cmo`3mnoh0noWj0?onn@3el^d0_Kfc0?oom03bn>X0n_od
0?Won03hoo40o?o/0:>_R@3:g:`0f>j`0<kTY03@hj<0T:1Q0=KXZP3?hZ80eo2/0<OPW028Ue`0fNNY
0=7KYP3SiLd0dmR_0=ORWP29VE00`mN@0=;WV03>gjP0k__?0=?O[@3Jjk@0RjIO0<cZX02lf8d0c>6N
0;c?S`3Lk:d0b=fL0<CTV031iYH0f_R^0<g?SP3FjZD0dNnW0<ORV`1AAPh0SH9:0=OMX@1P>Pd0b=JH
0<__Y@3<j9@0b>NG0=CbZ02[^G/0JeD^0=7F[@3lomX0O6A204Tl4P3BhZ<0cNJR0=;^Y034iiL0coVU
0;gVU`39i:d0g>c508:1K@3ak=P0FeDm0=;@Z@3Rhl<0n_gf0=WT`P3>hZ<0a=ZL0>;]c@3gonX0nooQ
0>Kca@3Ll;<0`nFK0<W_XP38jIX0a>>G0=_QX`1PGRD0f]ZL0<oUW@2`[fl0[;1c0<W_/P3FikX0kOW;
0<cVY@34h9<0e>nP0<kWY@3gonT0o_oo0?;lf@3OlKL0d>^J08:ND@35iI`0cNfR0<SYV03CkjD0b>:Q
0>?eb`3homd0i?_30>?oa03SolD0hOS:0?_om03jo?T0n?Ol0?Gem@3/l^P0j_KP0?konP050?ooo@1B
0?glnP3oo_d0d/k=0:^WYP3lmo@0noSa0?ooo@3loOl0o_oo0?ono`3QeMD0o>k[08n1OP3Ygmd0o_ko
0?Woo`3doOX0n_[j0?kjn@3ooOP0J61C0>C]`P3BiZ/0`nBE0=GfY@37j9L0bn^O0<oOX02bZVT0FE8>
0=7OXP3Udjl0d=Ne0<KN[P37iI/0cnVO0<SVZ03Nn/T0nOo_0?coiP2d^hP0TieP0=3LVP3>iY`0c^fQ
0<K[W@38jYd0bnRF0<;OS@39jId0b^VM0<gWW@3<j9d0b^VM0<?XVP3:lJ80anNK0=7[X@2FXE`0EEXH
0>GNY`3:b8d0aM^C0=?cY`30jiT0a>jJ0<CWU@3@j9`0b=jE0<7OU@27XeT0e^FR0=c[/03Chkl0c]c5
0?coo`3ooOl0a/320<[8_03Xk]80d^N/0<o]Y`@0bNZK0140bNVM0<WYWP3:jYl0bNVN0<GUW03?kjH0
fofc0=Oi[@38giL0b>RM0;oIT01HF1P0eNBQ0?Og^@2OY6@0c^jU0<gXX@020?l0000`09ZcR`22VGd0
MHab05MAD`0d>2L0Pi9a03iM8P2ZdHh0`>VS0;_UX`2mijP0aNjb0;[SY`38kk00bN:X0<kVZ038iJ80
c>bQ0<OYW@3:k9l0dOBT0<;QU@3:i9d0bn:L0=;YY@3;iYl0d^bU0<kSWP3EjJ@0SiYH0=cUY03TjZX0
_lR70=cWY@32cX`0a]ZC0<gWWP38jYd0a^^M0<G/W@39jId0c>RM04=D3@3NkZL0d>BL0=[bZ03<j9d0
c^BL0P3@hI/0;@1KK2H0W:eW08jOF@2Y^W@0cn2J08NHDP1cQ3h0VJYT0<kWX`3;jJ40cNZF0<WTU`1i
SE`000X00<cP[`3<iJ<0bnRD0<gZV03:j:00c>FQ0=ca[03<fiH0NHI00<?DS@3LlZT0cnjR0<OWWP3=
jj<0Oi9B0=GPY03>jI`0b^bH0=CcY@30g940foF/0;gGSP32hID0cNbP0<[]V`31ii00a>bD0=7gXP30
iY<0co2Q0=C`YP020<kWX`0/0<gVXP32gIH0cnjR0=3cX`2nhHl0`>JM0<WaZ02jii@0`>fJ0<O/WP33
hiX0c^BV0::`N`0nCaT0a>6Q0=?d[@3Qlkl0lOkB0?coiP3nonl0P8Af0?oon`3jnoH0o_oa0?kok@3l
onl0n?oc0=;U[P38hih0do6c0<CN[P3bomP0e^:b0=3Y/03Vfj<0MW0d0<ObX`3:j:80cN^Q0<gWWP3I
j:D0TI]O08FIGP2ojJX;0?ooo`002P3oool01@3>kZ80b^ZN0<OWV`38j9`0b^ZN00D0bNVM09H0a^^N
0;SRVP38lj`0a>nX0=?e^@34fZ/0@D<]059<?P3Qelh01`0000<2003BfKL0i_;40>G`d03fonh0o?oo
0?ono`2YViX06@X30?3Tf03on?40oook0?Sko`3nool0o_co0?ooo@3fln`0o?[^0>OXeP3oond0o?o/
0?_ok03;fKl0cMbm0=gY``3bom<0m?oA0<gNY`3Bi:X0aMNI08nSI038g9d0d>JV0=7WZ@3DjJh0T:9X
0>kl`@3GgJd0oOST0?oog@37di40TJ9K0;oDS`3=hY<0f>F`0=cW_034d9h0_LjG0<gXX@38iY`0e_:W
0<WNV`3>hJ40TZ9S0=W^[@33hiL0_^>C0=cl/@38bXT0f>bW0;OES@39i9d0EDPA0:ZMIP3Vk;00]i9U
0=CTY@32iY`0d^^J0=7bX`34iJ00g>jb0<NiTP1kQeL0F6He0?g^``3omlH0f^f[0<?MUP3:h9P0aN6D
0=?jZ@3=mZP0`=jR0<gQ/027RfX0lo;C0>3P_P1=CR80fmfh0?oomP3homl0dnFW0<KHW03Wk/l0hnG@
0?ooh@3bn/T0eN>X0=?][03ElZl0g_f_0=OaY`3Gfih0fMBL09>AE03LlZX0T8a=096AE@36jZd0eN:f
0?oog033ei`0goN]08NPC`2/`gd0hoG=0?ono`2FX7/0Z[b00<OSS`34hi<0`^:I0<GWW@3?kj<0cnZU
0=Sa^03XnMD0n?oQ0<ONYP3?k:`0do2]0=7Z/03Rk=40j^kO0?clo03moO/0n_of0?Wom03nooX40?oo
o@080?_jn03lnoT0n?Cc0?ono@3ooO`0l>_X0?oon03oood20?koo`0Z0?_ioP3ono/0]jVV08EgM01@
AT@0oooo0?Woo`3foo`0oooo0?G`m03onoX0dl[10>WabP37fJD0c>bQ0;WJR`33i9D0`n>G0=OZZ02H
T4l0J64K0=SSY`2cX7l0oooT0>Gkc@38hi`0cnVO0<[ZZ@3MnLH0j_WL0?_oh`3=e9h0R95B0=KQW@3B
jJ40c^ZP0<S]X037jI`0bnZJ0=7`X038jYd0b^VM0P3=iid07@3<j9d0bNjP0<S_X032i9L0b^JK0=[Z
X`3Fgi`0L6he0<S6R`3Mk:L0b^JK0;c/V032kiX0`NND0=K[X038g9@0bnfQ0;SHS`31ci@0ho6l0>Ke
e03honl0o?ok0?_jn03oooH0g=_90>;YbP3Bi[D0bnNZ00@0bNZK0100bNVM0<_[X037ii`0cNfR0<o_
YP35iI`0a>BK0=7aY@3;iI/0`nVL0=GcZ@1OHB00e^:P0>OSYP2TXVD0bnVS103o00002P3Lk]@0bM_5
06m[DP1WLDh000`005Z1DP25/880K9Y/0;?P]`2oj[d20?l000200;GSV037hJ80dNJ]0>;j`02D/gP0
b^b_0<3TYP3;kZh0a^VW0=Od/@35h9/0_mVB0<oYXP3Qn;80aMZE0<oSWP1<FaP0hNf[0:fiM`2;VUL0
`M:>0<OKUP3@iil0c>RN0<WYW@36jid0aNbM0<SZW@3:jId0en^S0<7ARP3<h9P0ennU0<kZW`2=Y5`0
Rj5I0=O]Y@36g9@0h_R`0<?IT@3Bj:00cN>K0=O]Y@3Jl:P0eN^S0=3YY@3>jJ80bNJB0<KRU@1oUfD0
00`00<cT/P3Ak:T0c>VE0<cYU`39i9d0dNRT0<KJU@2KZVD0fNJQ0:^lM@3Ejj80b>JL0<_[XP3:j:80
`=BE07f;D03:hil0c>NP0=;[Y`32fiT0KhE50<oUY036h9T0aN6G0<KUU`3:kYL0bnnE0=;eX@31i9@0
dNfS0=O^ZP38fY`0dN>U0<SJW03FjjX0cnJR0<?RUP3KoZh0bNZS0;gQV@3Gok40b?:P0<g_Y@36hIh0
bn6S00@E002CYVl0d?6/0;[SU`3Gkk<0^<VC09JTL`2ha9`0joKH0?_omP3fonh0io??0>CaaP3comh0
mOoY0>Oj``3;i:80c^b^0>Ooc`3homd0dmb_0=G/]03PeIl0ZjEY0=Cm/@3;jJ<0dNfS0=K`Y`3<f9H0
Z[Ag0<_OX02ScH/;0?ooo`002P3oool01@3:jYh0a^JJ0<_[W`3:jYh0b>RL00D0bNVM02/0aN^R0=7n
_@2Vf9T0/n>U09_2S@2D/8L0M7aW0;VgZ`1;A3X01P<000H8003?fkD0b]JX0>Scd`3ioo40loOh0?on
o`2^X9l0=2DN0?oml@3ooOH0ookj0?coo`3nool0ooko0?ooo@3ooo@0fmW:0>__eP3`m]X0nOoR0?Ko
h@35ek40d>:h0=;R]@3WmL@0jOO40>[h``3[n/<0Y[Ym09F[J`39gj40dNNY0080g_>k06T0fNbd08F@
EP3FfJ`0oocZ0?oog`2V/W00ZKYc0<GLUP3Llj<0/[b808ZCJ035dIl0fNZc0;gHT@34hYP0d^jS0<kS
X03KkZh0TZ9S0;K;RP36iYX0anjM0<GWV`3Kh9h0S:1K0=?aZ@3KmZl0GE0I0:VLI@39ci<0OeX]0<WL
W039kj@0bN:A0<_[W`2lhI`0fNje0?okdP3Vn<H0^lnJ0?K/^`3gm;d0c^>N0<GOUP3KkjL0eo6W0<;W
V@3;lJH0g_bn0>WobP1YL4L0o_oI0=3BZP1NHS00@4DM0?ool@3komX0b]ZK0=CTYP2]/i40RHM^0;Rf
S`3Ph[00fnFY0=;VZ@2gd8l0^MF80=G]X`3Fei/0mNjg09nKGP34f940[:IX08J4B@3:k;00dmjc0=[O
]P3GiZl0a]ZB0=G/VP3Ek:@0R9]^0<G5a@2IY7`0a=JH0=3/U`3;jiP0cNnU0<SZX03=kJ40`]bK0=[a
_@3conD0nOoS0<WPZ032gid0aN>I0<SSX03Fh[`0h>G>0?gnn@3ooo/0nooi0?WomP3noo/01P3oood2
0?ono@040?gin03/in@0o__d0?kno080o_oo02X0o_co0?ocl`3onOH0oo_h0<2f]02[Zjd0nooo0?Wo
o`3mo?l0oogo0?oinP3djn@0/[VG0<kP[P3EmJ`0aNFI0<[[W035iIX0dNBR0:VRGP1=AP00e=nS0>cG
^03dmmP0gO330<ORV`3?jIl0b>RW0=[h`P3;f[T0fnNo0=GMY01hPD80VZEQ0=?YX@3<ij00c?2V0<k`
Y037iYH0bnZJ0<SZW@3:jId20<gWW@0M0<cXW@38kIl0a^fN0<GZW037iYX0d>6J0=SSW`2KVV40IF<X
0<CAS03?jIl0^^bG0<;bW02oiY<0fNVP0=3PV@3:kj80b>ZP079oA`3Qkk`0k_kJ0?Ooj`3ioo40oood
0?SehP3Fe[h0b<n^0<WL[P36hZP01039jY/04039jId0b^ZO0<OWW03<k:40cnnV0<WYX03:jYl0d_:V
0=7[X@30jI/0d_BX07an?@1OJbT0j>:V0:VUJ03DkjX40?l000090?Sok@3o0000o`000?l0002bb9X0
FhIA07f]N@1IReX0;5T^00@0o`0002T0eNnb0=?V[`1<Hbl0Z<JD04YZ>@23YG<0cO:l06jAE`2YbHP0
bnZV0>Wo_@39h9X0_mB?0=GYY03:gYT0gNjZ0<SIU@3Dj:<0`=F@0<7HTP3LmZl0d>bR0<cXWP39jId0
a^^M0<G/W@36jid0bNVM0=?WW`3@hIX0VjmW03=;0@1NNRl0d^bS0<oYX03Fl:L0^]B;0<OQV03>j9l0
bnFL0<gWWP020<WSVP1D0<[TV`3;i:00b^FN0<cYU@3BkZ40W[J4000F003<i;80cnZW0<WVTP3>jiT0
cNRQ0<[OW03Lkjd0`<b:0=?NVP33e8d0D6HM0<WWW@3@l:L0_=ZD0>3d]@2@WV<0dnV[0<[RY03:gj@0
e>V`09BWL03BiJd0h?Jf0=?/Z03>jZ00b>ZD0<_]UP2oh8l0eOFY0<KPV@3AiZD0_LbA09BQJ@0hA@d0
_LnA0=GZZ@39iI/0_mnC0=?aZ`3;jZ@0_MnC0<3RU@39i9d0cN>R0=KX[P0>7000fnbe0;kOV02egY00
T:UX09jbM@3QmKH0dNB]0<gN]03honl0mOoZ0=7S/`3:gJH0ioS;0?KoiP3doll0bN:P0<SVZP3dom`0
m?oI0=kW^P3BjK<0i]^U05M>5@2bfhl0cnfW0<WUV`3?iid0SiYF0=SRX`2oe9<0c_Vb2`3oool000X0
oooo00D0c^jR0<[ZWP37ii/0b>RL0<[ZWP050<WYW@2F0<?[Y@2klKd0>WQ9066LK032l/X0a^_:0009
00001000`/:f0?kok`3konP0h?750=[X]`3fon40n?o`0?coo`3oo_l0Kf5P00/0003<`;@0nO3Y0?oo
n`3fnOh0oOco0?ono`3oooX0oO_/0<S:]03KhKd0dm^b0?Wof03homH0a=^S0<KNY031eY/0bMRQ0=?P
Z`3Zm<80koc70;S<T@3EkJl0c^R[0<CKX`3iom`0n?oL0>oob`1TKST0hN:h01`@0P0W8@40^<B20=7W
W`3=ij00a]f=0;2hQ@3komL0RYIT0<OHX@2X`g`0U;9X07jJC`3Nlk00bmjN0=7QXP2>Xf80c^jR0;GL
R`3;l:<0iNZX0=7UX03:j:00d>ZS0<VlQ@3Eb940^/2407IA903FjjX0_>FI0=?^X@3:kZ@0_NNX0>;o
b@3Yj;`0`mjW0;GCU@3LfYl0[K9`096[HP2:YU/0gnZU0<WMU@3>kZ<0a^ZP0<c/Z@39hj@0OHYD05YT
;`3Uk[L0h>^a0:J^N`0d>1D0>D8;06]k<02?WeP0RHYN09:>J03QfjL0M70c05EH5@3FhZ@0bMVJ0=ge
Z@38g9@0gM^P0?3U[`1WGB80eNBO0;fcMP3:a8X0b>F[0>gdbP3oomd0cMFR0>3[Y`3Ik9X0fo:T0;cC
V`3lnoL0hnbo0=CUX@35hhT0`N>=0<[^Y037jj<0b^bR0<cUZ`3Kl<D0kocX0?WojP3Djk<0`MnI0<OX
T@3Gm:00g>^d0>7Y`P3innh0oooj0?con`3ioo/0o_om1P3oood0<P3imO@0ookm0?omo03Uh=d0f]O@
0?gmn`3in_`0oOko0?ono`3ono/0m^SU0>[Lf@3gkN/000020=gRi@3XlO00ooko0?Obn@3onol0l^SW
08fDM@3Nkl80`n:N0<KVW@39jId0b>RM0=CYY03VhId0b/=m0>ce_03F`J80oooV0>Wkd@3:iIh0bnNJ
0<W/Z03QolL0eNNm0=_Y^03AfId0Vj9O04mI503Hk:L0d^^W0<?TW`34iIh0bn^O0<SYVP38jYd0bNVM
0`3=iid07037k9h0`^VJ0<W^X03<k:00cnFL0=SWXP3Sij`0EU4G0>W`[@3>i9/0^^jI0<;dW@33jYL0
f>BL0=cWXP32j9/0aN^P0=;PY@2BXFX0go340?Soh@3OjL@0gn>n0>k_a@36bIh0en2c0=7T]P39i:d4
0<WZV`0A0<WYW@3;jj00b^ZO0<_[X037iih0a^JM0<c/X@36iIL0bnNL0<3]W037kYl0f]nM0=kZZ03N
di/0[JA[0=Ka[032hId00P3o00000`3Um/`0o?o_0?l000030?l000040;KUU@32mZ<0b_j/0=;k]@@0
o`000P003@00O@1=H3<0<4//03aJ?P1dUW/0]Mfj0;_R]P2oiJP0`>FP0<o_X`2O]Vh0DfLR09FYI02M
/F`0gO:]0=;YX`34giP0e?:Z0=7cZ@35jIl0`>:F0<cXWP39jId0a^^M0<G/W@36jid0bNVM0>?g[`3M
kZL0e>FN0=7WWP3:iY/0b>NK0<KVVP2adHD0eoJZ0<KUV@3<k:00b>RL0<OVVP39j9`0b>RL0<SWV`3A
k:L0cnVR0<?PS036hYD0X;R6000<003=iK<0c^VV0<cYU@3Cl9h0c>JO0=_`[@1lS4/0d]jL0=WTX03J
jjD0bn6I0;;BQ`37iZ00bNRR0<oSY03Rl;D0]<FI0>Ggd@3^o]X0d=jm0?_oiP3eomd0b=R[0<CFXP39
gZ<0b^JL0=?_XP3DljL0d>^T0>Kk^P3ChZT0oooD0=OO[03Vk;`0`LjH09n^L`2D[FT0OiYC092PG`3G
iZD0`M:<0<kOV03?fi/0e=bQ0?Gga@0V:000VjA_0<[UX03GnJ`0cnfS0<?MT`3Cl9`0an6G0=gg^03I
l//0jooJ0=;]Z03=jI`0cnRW0=CZ_03eolh0dNNV0<kZ[`3^omL0fN[00?CmdP3`om40j=^V0;nfO@3F
ok<0b^FR0<oYW`3Bj9d0[[Ud0=COV`3=hYd0c?R[00/0oooo000:0?ooo`050<;RUP3=kJ40a^JJ0<WY
W@3<k:001@39jId0:`32jjL0^O?103f0E@22`iP0_o??0;gUbP001`00XJ^R0?colP3do>D0nOoV0<WJ
[@3:f:L0nooV0?Wol@3kool0o?[o034S8P0C1000oo?W0?ommP3ooo/0o?oo0?ono`3hmoD0oooj0;6`
WP2b]IX0emje0=7J[@3fom40loo<0=?[[@3@jJP0`]RG0=7PY`3Jik40dmf[0=CQ[02jci@0dn^]0<SQ
Y`36gJL00P3iomd0J@3com80V:9^0=cM]@2[WI00H5Xj0<kJVP3?iId0d^fX0<WPT02oaY<0jN_30<WE
X`3Znl@0a^6J0<GSV@3BkZ<0n?o:0=KYZ@3Hj:T0SZ=R0<k^XP34jiX0a>VL0<G<R@31eI00dNnW04EO
603biJh0gm:K05UO8`1]Bad0d^NV0<?/X03FlJ@0an^S0;[VZ@3Fm<00loK;0<[Y[P36iZL0HF4S09RO
F`2lf8d0V;AY0<cFT@3ZnkD0aNFL0<KXWP31hYd0`M^J0=SW[0002P00dMbR0=3KW`3EgjX0d]R/0=[T
Y@3CiI<0fnVL0>SZ^03`k;l0o_Fl0>GPWP1CD`/0a/n>0>7][@3?iIX0eNJO0=oJX03ZgJP0VHmD008?
002[XF@0TH]A0=Se^`3NiK/0oooK0?Ojb`3=eY<0dnFA0<WNS`3MmKT0oooj0<gFZ@35eY80d_6D0=3b
W037jj40an^S0<?TW@3HlKP0iO[A0?Som03ion`0dNR`0<_YX@2nh880d_2F0<WIVP3Ih[D0o_ob0?oo
nP3joo/0nOom0?koo@040?ooo@030?7`kP3oo_`0noOf0080ookm02l0ookk0?CajP3oood0o?go0?ko
o`3oo_l0oo_k0?odl@2dYZ<0/jVW0>3PhP1WK6l0nOoo0?ono`3oo?l0oo[o0?olo@3KhLD0fnc00=?b
[`3?kZP0cnnT0<o_YP31eY40j^FQ0?Wb[03Cg:<0m=o20?ooh`3TmL/0an:K0<gYW037jZH0f_c00<kQ
]03:f:D0gnRY08jEDP1OJB@0am^F0=7ZYP37j:<0`NFM0<c/X@35iIT0b>ZM0<WYW@030<gWW@0L0<W^
X036kIh0a>^L0<KVVP3=hiX0e>FO0>7UZP1KEQ`0d]VF0<KLT`2aiI00_o6J0<O^V`3GhIX0fnFP0<3Y
V`35kZ80g^b_0<oNY@3Xn/P0n?oJ0<gIZ@3GgJd0bL^I0;6ePP3KiK40d>Bc0<GPZ@@0bNZK00l0bNVM
0<[ZW`3<k:40do>X0=CdZ`39jJ00anNL0<_ZW03@k9l0_nbK0<C[W03MhZ00e^6O075T;@21MSh00P3o
00001@39j:D0b=ZX0>CcbP3nonl0ooof00<0o`0000D0_NVN0;k^Y02ei9h0^]fS0=Kg`P020?l00020
0<O`[03IkK808Rl10>CfcP1:I4/001X501i1;@0VCS<0PZZ50<G^/P38lJ/0_=jA0<gTW03JjjL0e^NS
0<gQW03AiZ40b^6K0=3^YP39jJ00^MnD0<7ZWP38kZ40c>RN0<WYW@36jid0aNbM0<K[W@39jId0d>JM
0<GFS`3IjZ<0enfT0=WeZP31hID0e_R[0=GgZP39jId0`^:F0<oaY03=kj80dO6U0<WYW@35iiX0b^ZN
0<[UX03:i9d0b>B@0=C`X`2nfJH001@00<KQ[P3=j:D0cn^G0<gXU`2echP0BUdK0=WYZ03AgI/0e=nK
0=3QV`39giL0S:aQ0<OVX03ClZ`0b^2P0=k]/P3Agk`0iO?I0?KojP3kond0o?o]0?Koi`3hon80gno2
0=KX]039hZ00c^ZP0<STVP2ofY<0fnf_04]H8P3kom40oooF0?3caP3DgZX0dn2X0=7WYP3@jZ<0EV0Q
09RNH03Lij<0fnJR0:6UJ01XJC00G5PX044o3`3KgJ/0eNbX0<KVVP32hID0cnbL0<oaT`3Bki/0anFM
0=3[_P3=ikP0b>NI0<_/U@3:iIh0bn>a0=KZ[`3;hJ00an>X0<kU]`3;g;80fnBi0=7X/P3ool`0eljE
0<G^XP36hIh0bN>I09ZaH`28U4`0kONb0<cPV@2lj9T;0?ooo`002P3oool0W`2abh40cNfR0<WYWP3>
kIl0b>fP0<[ZU`39jiL0a^^K0<K[WP35jj80_^^`04QmC`1ZXW/0Nk6=06VDN@1:JeH0OXj30>[dj@3i
on`0nooX0?3nfP3CikH0enNf0?3kf`3eo^/0oOko0?[hn`0o=380=2LQ0?oml`3oo_H0oOcg0?cmo`3e
lO00o_Wf0?onn@3>d;/0o_oT0=SU[`3Ah:D0joo40>Wla@3UnL@0h_K10?3ocP3Mj[@0f>F_0<kHX`3I
i[40/LN90<?LV`39hj80e>bb0?OohP3hon<0joo90<3;T`3Hej/0e<Vc0:6ON03?i9l0dnfS0<ONUP2b
agP0fnR`0=ST/P3?hJD0bMnO0=G`Z@33hIT0c^ZP0>Ci]P39g9X0d>2O08nTH@36hYP0do>W0=KbZ030
ah@0hO:^0<oVX013FQ@0hM^Q0>3JX01=EQL0YXmM0=GUYP35iYl0cNVO0;KJU03NolT0gO[40=cT]@3;
ijd0cN^[0:fdL@3Ok:H0eOBV0<;QT`2EYEh0QYYC07jLE01]SD@0c^jU0=?/Z039g9X0GFd/00@D003J
jJh0d=nV0=;LY`3OkZT0b=j;0=S[W03Fh:@0embT0=KFUP3LgiP0gnFK069]:@2@W5X0RIUB09BUG`1<
BPl0LFP_03di001@GAP0VHeC0:fTK@3:hJ/0/K>;0>3L]P17D1/0E60N0<cRT03?iiT0aMnN0?coj@3J
ik40d^JO0;oMQ@3BlYl0aNBN0=3_Z`3<jjP0X[J505QX@`001@007RL<096OJP3=hYl0UjmK0:JlJ@0c
?`40Ifdo0>o^g03oooP0ooom0?ooo`020?ooo@<0oook0`3oo_/0D03ooOX0ookk0?onn`3oo_P0ooom
0?gmo@3oo_l0oO_o0?cbl`3ono/0j=gI0=oEd`3oo_d0@TA300010P3dm?`0noSo0?oko`3kmOD0loKQ
0:VcT03=iJ/0a=jO0<GSW@35iI`0gOB/0=OMU@3Ce900GF0Y0=O0X03oomh0iOW80<gYW`3Hl:H0`=nK
0<WWZ`3ioml0nooL0=_V[P3GhjD0bmJB09f/I`2md8h0c>JY0<KRY@3?kj@0aNRH0<SZW@39jIh0cNNN
0<gWW@3<j9/0a>NG0<K[V`38kJ00b>RM0=7YW`3FjZ<0e=fN0=oMX03Lhj00fnbU0<oiY`33jYT0co2Q
0=COVP3Gi9h0`NZL0<[cY`3AhjD0am^L08NOH`2H[G80TJ=W09:MH@2NZ6`0_LJ=0>Gb_03[ol`0m?oC
0P36k9T20<S[V`030<WYW@37ii`0c^bT0080o`0000D0dNnY0<SVWP39j9P0d>bR0<;[W`020?l00003
0=KMVP2k[G`0o`0000<0o`0000@0cM^g0?;mg@3lon/0o_oa0P3o0000R02GYFP0bnbW0<3UXP3=l;00
dNbe0;KAVP32hJD0`^NR0<7YXP3>hjP0V:Al086?KP28VHT0eN[K08jUU@1[RV/0:TdU059n@@2UdY40
coZe0=7`]039hjH0`]nM0=Wd/@39iI/0d^jS0=3/X@3<j9h0cNnU0<[^YP37jIl0cNNM0<cXV`3:jId0
bNVM0<[XX03<ij00cn>N0=g/Z@3Ci9h0en^T0<STVP3=kj80`>FG0<GWVP32i9P0dNnU0;gLT03;jYh0
a^JJ0<c/X03<kil0b>^K0<WXXP38iYh0aN:>0=7]X030f:P000`00<;HZ@3;i:<0d>VF0<OPS`2Q^780
Z[ml0=W]Z03Ol:X0dN2K0=KZXP3>i9/0RZEN0<g[Y@32g9/0e>N_0>Wg`P3/o=D0j_[F0>3]c`3do^D0
kOGP0?kok`3lonP0e>2j0<GEYP38hIl0eo>Y0<gRW@3Okk00UJ9]0=KO/P3noml0oooS0?ooh@3Gg[80
b=BR0<kTX`31g9L0dmfN08F;B`2nbH@0]L1k09RNGP2?TeH0a/J@08V;F@3Mi:h0dNNW0<KQW039jIh0
bnbM0<;UR@3;kIH0_]n@0<7NYP39iZh0bNRJ0<c/U`35i9P0bN:X0<[OWP3Ek:P0cnf]0<?NY`3Bi[<0
cm^Y0<cTZP3ool`0Og@l0<CZX@3@jJD0e^bS06Ej;`2LZ600aM:<0<cRV@31k9d;0?ooo`002P3oool0
Y@2JX5X0bNJT0<3MVP3LlZT0dofe0;[NOP31hh80cORV0<3h/@2im;X0=fe=09RiSP22UGD0FFQA02lf
;`1`MG40nOg_0?cok@3hom`0f^Zk0=;T/03AiK00cn2c0?[oi`3nonl0oogl0?omo`0R6AX030@10?on
m@3oooH0oooh0?oomP3ooN`0oo[k0:BIW`3/mN80iOW80<GXSP3>lIL0an2W0>Kge@3jooT0o?ok0?oo
nP3Bf[40e^>[0<gPWP2X^X00aM^J0>3h[P2oeh<0g_:]0>cgiP3goo40`n6I0<WCUP1JFB<0`/:<0<GJ
V@39kZ00_^6?0<oRT`27Ud`0cnfW0;oTU`37jY00`^:?0<3NV02ofYL0b^BS0=7XX03MmJ/0h_N/08bP
F03BhZ40h>n^096FEP1jOcl0e]nN0=GPWP1ZMS@0dMfK0=WUX`1=FAL0XZ]Z0=kTY03IiJD0dO2]0<KS
X`3NlkX0g_6i0=c[/P3Fi:T0EVHX0<cSW@3IljT0_Mb<0=CeY036iYX0a^BJ0=Sa[@2hdHd0cnNM0=3W
V@36gHl0bn6F08NNFP34fjD0d^^b0<kXX@34gYD0cnfS0<WYWP39jil0c>jR0=7aY@31h9@0fOFZ0<3J
T02kc8H0W9eQ0:k3P03BgI/0fnJR0;kES`3<g9/0WY5M0:VKK03Hh:l0[:Un09nNKP2lei00hojg0=7a
Z03=kjD0a^^N0<gQV@3Aiil0h?N_0=?]Y03VokX0dNNW06n4B@1SM400QY5Y0<K<ZP3oon@0oooL0<S4
U`30_8`0MWLn07Mg@@0[:P00[Z^20>;G``2ZW9<0^jVY091oQ`3mlo@0oogk0?omnP3oo_P0lNcX0?gh
lP020?onn00@0?oonP3lnO@0oogi0?ogm02:PH80l^c/0?omo`3oo_l0n_Sm0?ono`3ooO/0o_Cb0=31
_03oo?P0lN_[0?koo`80o?oo01h0moSj0?omnP3aj=l0oooV0=cR_P3=hJ`0dN^/0=7^WP2lfY00^Lb:
0>gK[@3TcJ40c]bN0=3^Z037hiT0g>^X0=CZZ@3;h:L0oooX0?_ok`3_onD0dnZl0<[OWP1RJ280[jmc
0?ooh@3WklP0c^jR0<3VS`3:j9h20<[XX00N0<[YW@3:jYL0b^ZE0<[ZU`3:j:00b^RR0<[XWP3<j9d0
dn>J0<CAR`1GGQX0Kg@b0=gOWP3PiJD0e]nN0<kRW@3AkJ<0_^>F0=;h[`3;kZ`0aNNM0<__V036j940
co6M0<g/X03<iZD0bnFX0<cTZ03?ijT0c^^X0P32kYL01033kIT0aNbK0<SZW@37jId40?l000030<cV
W@3:jIT0c>VY00@0o`0000<0ooCF0?l0003o00000P3o0000=@3iood0nooh0?Soh`3aomD0nooS0>_h
c@3jomP0XZee0:^eN@3;eIH0e>>P0>7a/03On;H0e?6_0<OUZ@3Wolh0g>_>0?col`3`i^D0n^gW0<Ji
Z03Hfj`0h_6f0;gVZP2TfJ<0:F<m01=58P2Wg:h0_?>l0;O_/02kjil0c?FV0=O^X03Tm:/0f>BV0=_V
[01]OCl0UZIO06Ui;P2da7d0a=>@0<3>T@2d`XL0moo;0<7CU`3=hZ40`]VE0<[XX035jih0`^fN0<K[
WP39jJ00cnJP0080cnJN05L0cNNM0<[YV`39jYT0a^bI0<7[W`32kIh0b>^G0<SWV`2b`iT000/00=OR
^P3OkK80_]>409:YF@3Aiil0c>NP0<[YW@3:jI/0c>VI0<gXV@3?ii/0bmnJ07Z:C02IZ740j??90>?[
aP2M]700cn^P0<KJW@3;fJH0oooX0?ook`3ooo@0noo/0?_oj03OmKL0a^:H0>o^]P1hK480nOGL0?oo
m03jnod0o_ko0?onnP3monL0gnO20=kc^03?jJP0d^VS0;O=Q@3<hYT0b=jC0=_cY@3?ii/0Y;ab0=?Y
Z03?ijT0mOoH0;_AXP35j:P0a>ZQ0<C[V035ji@0b>bD0<[/V03:jId0c>NR0<cWX03:jI/0b^ZG0<gX
V`3:jId0a^^M0<SZWP3:j9h0dNFN0=;`Z03[gjD0DTP=0<CUWP3Plk40/[ei0;O4OP39f9<0f?:Y0<_Y
W`2oi9L02`3oool000X0oooo0=X0Vj=J0<c[Y`3>k:`0^lV>0;kMU`35l9L0c_BO0=Sc[02=b8h0FIeZ
09O4Y@30fkP0=D<Z02Pc8P3Pin00o?ok0?col@3lonP0iOG80=7S/@3;h:P0b^6[0=3S]@3konP0o?o_
0?oln`3ooOl081HE00L0003oo_D0oogf0?oon03hn?00n^kP0:2AUP3[hNX0nood0=g```39jiL0c_2L
0<_Q/03XmmX0o?ok0?gonP3koO80hNZo0=SVZ`3>hIl0M8I:0<kTX`34g980h?RT0<SLU`3[m><0m?o]
0<_XYP3Ul[X0`/JC0=_PZP33diD0c^jR0;gNS@2I/600Z[mb0=7ZYP3CkZL0c>VE0<cXV`3@jjP0c>FT
0=G][`2X_gT0cN>J0<;GS02gbh<0a]VG0=;QX02GW5`0WjAT0=?LV`3BgI/0V:AR0=CSX03Ei:40EV8P
06mh=`3LhZ80cm^K0<k[Z@2keIH0e^^`0>;f^`3Yn;l0cmjS0;_;S@3CjZ@0b>:I0<;QT@3?l9l0eOFY
0<7OU`3<iJ@0e^b/0<_PW@3BiYl0a=Z?0>3f[@3>iJ40GgLm09R`MP38hY/0bN>L0<_VW`35hi/0dO6X
0<?SVP3<jZ80d>^T0<ORV`3=i9h0cMjJ0=?JU`3Bk:<0b]^D0<oOV03@k:40fNnW08^5B`2NUf00d]nW
0>_]^`2^/gd0bn:N0;oFTP3BkJP0anFM0<CVW03Bi:H0cN:Q0;gCTP3;i:00a=fI03eC4P2^a8@0cMnU
0=[V]P3JhkH0bm6U08N:G@2LX6d0UiaV0;S0Q03Ji:P0g>>_06=Y>`3;bZh0ooo_0?ogl03omoP0clK7
0>gWi`3dkn`0ookj0?onn`3oo_X0kn[V0:NTW`3ckn`0ookk0?okn03ooO/0mnk_0>kXj03onol0o_co
0?Oen03oo_l0ooOe0?olnP2fYj80ooch0?omo@1kNgd0k?3a0>kbm@3nool0oogk0?okm03imn00loSH
0<SLZ`3:hZP0_MV?0=Kd[P0cAPH0glfM0=o7V@2jb8X0bnRU0=Ka[P3WmKP0enbc0<WM[03monX0nooc
0?3oj03<hKP0bMfP0=3GU01ZJc40jn_70=KO]03GmZP0an^D0<WZV`39jId0bNVN0<WYW@80bNZI01/0
bNZK0<WYX039jJ00bNVN0<[YW@3FjZ80`mB>0<cGT`23S4/0P8E50=CJVP3RjjX0dNFP0=G/YP2ogiH0
a^NP0<_`ZP3;l:<0`>J?0<O[T`37jYH0b>ZM0<[YY@3:jJH0bNRU0<GTWP33hiP00P36ji/40<S[V`@0
o`0000<0bNZI0<KYV@3;jJ/0103o0000=@3oo^<0hmG80?l0003o0000nOoj0?Wom03bo^H0iOC90=oa
_@3ioml0enNj0<cJY`39ei`0[[an0:>bK`2HZF<0eNVT0<SMW03colT0m?oC0?3oe03^omd0noo_0?ok
lP3oo_40oo[R0<oFXP2DYVP0fOo20<;a^`2^g[H0Nj9f00hj2@1bYFd0V]BG0;oh]02ej:D0d_:a0?Oo
c`3GhZX0f^6[0:niO@3Ci:00c>:I0;O=Q@2J[fX0OIA>06R1?@2kfI<0b>RO0<OYW@3BmjT0`>NH0080
`nbM00<0a^^M0<SZWP3:j9h00`3:jId0EP38ji/0a^^K0<K[V`39lZH0^^>E0<SZUP3?jj00UJIl000;
003NjL40_LbA092UEP2^aGD0cnJN0<[XX039jId0b^VK0<[YV@3=j9T0cnNK0=3TW`3@h:80W:]d0=[U
^P3Pj<40NY590<[WU`3Dj:T0gnfl0>c`f@3ooo@0oook0?Wjm03joo40lOoH0<OKZ03Uh;P0d<>S0?oo
k`3dlnh0ooko0?Who@2<RX/0Q8Ec07AkG02fbYT0bN:[0<gQY03Rm;H0c^>R0>Gj]`36g9@0PIM?05eb
;@3@iZH0dNJ[0=___03gomX0b^Z[0<O[Y@34jIT0a^VE0<O[U03;kIT0bNVM0<[XXP3:j:00bNVM0<WZ
V@3:jI/0bNVM0<G/W@35jih0bNVN0<oVWP3<kZ@0f]6F05eG6`34jZ40e^fY07F2?@3EhY`0f>RQ0>7k
/@34hiL0bNjQ2`3oool000X0oooo01/0Xk1N0<3SW`3Jn<H0j>O;0>Wd/P3Aok`0]mjW0=cN]P0PGTD0
CIUo02m=<@001P00^[ni0?coo@3looX0j>kP0>[fdP3Rl/<0b>2T0<oYZP3=jj/0foRn0<GL[P3fonL0
l__X0?_gm03oo?d00P080000Q`3ooOH0o?G_0?ObkP3oooX0oogd0?oko`3fl_l0nOok0=[[a`3:iJ00
c>NT0=OW`P3Uk]/0ooom0?oonP3Gg<P0bmNW0<;AUP3Ll:/0NHi;0=CZXP31f8X0^m2307>3A03lonl0
gNKC0=CW^@3PllH0dN2e0=KR]03?fJD0`]JA0=geZ@2_cg`0dNbM0=[UX`38di40cn2J0<WIVP3iom<0
enRb0<CEWP2W^WX0`MF@0=kcZ024VU40enbW0<cMV@2EWUd0SiQG0=_VY03;eiD0Si]I0<gLV@3GiZ<0
d=bJ0::]J`2a]gL0jO>d0=cb/P2ld940koo50>?e^@3DhjP0enV]04=F5P3BjJ<0c>JM0=3/W`37iYP0
cN^Q0=3[Z03Nl[d0d>:`0=;P[@3RlKP0c]jM0>[n^@3Gk:T0cn>T07nDD`087@0042D0059[9`1XPd00
FgPe06Z4@`1HLS<0_]JH0<KLWP38g:40amNI0<gNU`33iIP0cnNK0=7YV`30iY<0bnZJ09fNFP2IW5T0
`mfF0=OVX`3DgYl0b]RJ0<gMW`3IkZd0T:IU065o>@1UMdL0cn6]0<cOZ00<8P00<T/90=_b[03BjJ40
c>:J0=?TWP2a`7/0`M2=0<_NWP3?iJ@0_]FA0<cXWP3;iYl0`mjK0<oWZ`1nSf<0M89O08VCN03noo<0
o_gi0?chn@3Pg=d0oogl0:n[[0020?ono@070?Gal03MfMP0fMGD0?onn`3ooOd0j^CV0?;^k`020?on
o`0W0?oko`3oo_l0oocj0?oln`3djND0fLo=0?omo@0k>cd0ZZj_0>gam03mo_l0oogm0?omnP2MUhT0
oOoZ0>omg03domh0]LbD0>;j`03DhJT0jM>T0?GJZ`2ia8P0`=ZK0>Kmb@3lomd0i?GC0>Kff@3noo@0
nook0?;ol@3Xn=d0ho;70=SOZ@3Ig:L0[k:70>3Y^P3<iY`0cnnJ0080bN^D00<0bNZI0<WZV`39jJ00
0P39j:820<WYW@0?0<WZV`39jId0^MB?0=_d/038fiT0joZi0<G?T01LIRL0BE<D0=3OWP3Chj80cN>R
0<KQWP2lh9P0`>FH0080b>nL00L0aNbM0<CZW`35jj80a^bQ0<O^W`37lYP0b_6H0080cnJP00D0cNNM
0<cXW@39jYT0bNbH0<S^U`020?l000050<C`T@34kiD0_nFL0<KY/`3aonH00P3o0000>`3ThZl0oogZ
0?7Tg03mnoh0n_ok0?Wom03RmLL0dnNd0<_QX`3=iZ80d>>/0<kSZ03@j:X0c>NP0=7]X`3GljP0]]27
0=3UX03Agj40_LR<0<gJXP3BjZ`0m?oL0??og`3konX0mOoM0=[U^`3Vm[L0fNnW08FTH@2C/WL0^=BS
0<CFW03?kK40`nnb09oFW@09CAX0L;:40=3ne`2oh[X0o?oM0?oofP2CTV@0a<^Q0=?Q/03;g:H0a]ZM
0<gYWP30ghl0NIe30<ofV@33khh0[]aj0<3[S`36k9L0b>^I0<K/V@36ji/0aNbK00<0`nfK0P35k9d0
3P36jid0an^Q0<SZWP3@l9d0b^:H0=3O]P001`00YK690;oAU@33gXd0e_>Q0<;PUP36jZ00a^^N0P38
ji/0A03<j9/0cNRK0=7VX@3=h:00ZKQo0?Soe03[m//0SJIE0<OUS@3SmkP0joS:0?ool`2VYJ<0ooco
0?kjo`3ooOl0o?oo0?7hl@3onO40akJ_0?[elP3eloH0oOco08V6S@1cKW@0m>o[0?oom02lbJl0P95a
02Hg3@0gAaX0IgM606Ef@013EA/0Ffdc0<oQY`3DiJl0b]bZ0=?T^03homh0bnB]0<[WY`3<k:00bnbK
0<[/V037j9L0bNVM0<WXXP38jZ00b>ZM0<S[V`39jY/0a^^M0<7^W@32kIh0a^^N0<gWWP33jIh0g]ZM
05ME603EoK@0//^70=KSWP3EiIh0d^>L0<KPUP3=k:00a>JI2`3oool000X0oooo0:40b]f40<[ZZ`3a
on<0ooo]0?ooc02cgj@0`nRm0=gKa01<QGh09fmQ000?00001000lo;g0?koo`3gn_40fn?>0<oO/P3F
jK40cNRS0<k]Z@37ij@0l?oD0<ON/03ionX0m?gZ0?gjm@3ooO/02P0000P0003ooO@0oogh0?omnP3h
lo00YIjF0?olo`3ooOl0n?ok0=[[b@3=ijH0d^Z/0>klf`3foNd0ookk0?Wik`1;DCD0d=jY0=c^/036
g9@0T:EP0=?YWP3NmJL0Cf4G0<oMXP3nonl0kO7R0=7Q_03^omd0^<jX0=CP^03Dg:d0gn^[08ZOE03<
ki/0b>NG0>GZZP3Ngj<0o_o:0?koc`3@g:X0b=BT0>C`_P1AHB<0b]jI0=odZ@3DjZ40e>ZR0=;VX@2>
VEL0VJAR0=?OW@3GiZ<0JGPe0=3OW03GiZ<0en>Q0=;MV`1AFQT0a<j?0=3RY01HJ2X0e^JX0=g][`38
fY`0dN>U045F5@3?iZ00c^RO0<OSV03BkZ40bnNM0=gf]@3Ynl/0looH0=_X_03Agjh0d^:T0<[JV@3G
jZP0goBa0<GJU`2K[fX0VZe[0<kTX`3:hj40c>JW0;oIVP04700000d006Ii@@3:fjD0gnje0=;VW`39
kZ00bnJI0<_SU`39ki`0e?>S09jOF@2CUU40dNfR0<_LUP3RkZ`0gNR/0=GSYP3CiJL001400;?>R`1>
H30000h0000<003Jl;80a=fK0<;IT@3=iIT0a]bA01T^002DYeP0_mB90;kES@37hiT0cnfS0<oaY02n
h9<0co2Y0=;a[P2idId0TZMl04eO>@3kond0oOkf0?WemP020?omoP030>gYjP3ooOh0oocm00<0ookm
09@0m_;_0?omo@3]jNX0ooko0?omoP3oo_l0l^k_0?ono@3hlo00oogj0<Fj]P3oo?X0mNo_065QH`3?
dm@0nooo0?_lo`3onod0oocm0:jWW`3ooo<0n_o[0?Soj03Kk/40`]JU0>C^^P3_fJP0ilfL0=KQY@3?
jJ`0hOK;0?koi03gonh0l_o^0?konP3kool0mooj0?Sol`3hon40h^Zi0=cP[P1GGBd0h^Zg0=?YX@2l
ehH0bNbB0<W/T039jiD0bNVM0<WXY039ijT0bNRU0<WYW@39jYT0bNZK0<WYWP3:jJH0cnVX0<gSXP3?
hZ00c=^J0=3LW017Da<0:3@006Id=P3EiJH0d>BU0<SXY@33i9d0bnfQ0<?XVP3:kZH0anbW0<CYX`33
jIh0`nZI0<C`S`38ki@0d>FR0=3UX03=iih0c>RM0<[YV`37j9L0anfH0<S^U`37kiL0a>bC0<7/T`30
iJ80a>Jd0?7ok03[om`0f^2`0=_HZ`3oo>`0m^OT0?omo`3nooX0n_o`0=O//@3>iZP0d>VW0<oYXP3L
l;<0_MJD0=_f/@3=kj<0anVL0<GWVP3Al:@0e^fU0=STYP2>TeT0fN6X0<?IV@34gjP0b=na0<oQ^`37
fZd0am^X0;cCS@3?iid0VK9^06f7B03BiJh0hnn_0<ORW`2ihJ80_oFi03=gAP1=T6@0V/VU0<c_cP3C
g[`0dMFb0:BUO@2Z[hL0h^k00=o]^037fId0cNFI0=WdX`16I`h0^]^20<7USP3Dmj<0bnbK0P3:jIT0
1039jYT0a^bI0<?]V@32kYT20<;]V`0P0<G/W@36jid0b>ZM0<GUW03>kZ<0eO2O0<cTVP3EhKT000L0
0;K5W03IkK00e_>Q0<g]VP30h9D0a^ZP0<G[WP36jid0b>^K0<[YV`3<j9d0enjX0=7VY@2hbXh0loo=
0?3lcP3;i9<0e?2I0<oSY03Njkl0[:jQ0=_IfP3onol20?olo`0d0?kno`3lool0ooGh0;j^[`3ooOl0
ooko0?KenP3no?l0IV5W0?omo@3nnoH0nooa0?Sok`3=gKP0U:=h020`0@0V=PD0h?6k0<[KY@3Kk;P0
eNFh0<gL/@39ek@0kOSH0<WM[038hZD0c>RN0<_ZW03;jiP0bNZI0<WYW@38jZ00b>VR0<SZW@38ji/0
bNVM0<SZW@32kId0`nbN0<SZWP3=iih0a^ZP0=cFVP1SGb80bO6X0=kg/`2?WUT0dn>L0=_/Y@3=iid0
eoJZ0<W[WP/0oooo000:0?ooo`2/0=OfV03;hK<0h^kH00<1000=4`007CL700DN0@1SLG80:DaO06fF
W03aoo<0o?oo0?omo`3oool0o?o_0=SS`@3Bj:P0c>JM0;oRT03AljH0_n>I0<7SY`3?i;T0noo/0?_o
kP3mn?@0ooSg028C401IBT<0oocd0?ogl`3omoD0/J^[0?Wik`3mo_l0o?oo0?SomP3Ql/h0b>2R0<[O
Y03konH0o_o_0=3?_@2DUg`0dMf_0<kPYP37fi`0fo:Z05ee:@3=i980gO:S0;2nP03?fJL0nO_V0?oo
l`3loo<0j_gY0=Oaf0002000GV0k09jQJ037eY40b>jI0<_/W@33_H40O6lj08V>F02AUF<0jng50=SM
]03Gg[80UjEZ0<KFU@3Gk:40cnFJ0:o6OP0I;`00R9MD06Ac<03EiZ80cn>N0=S/Y`3EiZ80cMjJ0=WX
Y@3OjjT0h^^Z0<kGUP1bNSh0VZAW0=kZ[03;fI/0d^NT0=CYYP2jdH/0enjX0<WSVP3=iih0b>:H0=7]
X`3?ijT0looJ0?Koh@32cZX0j??90=c[/P3:fY/0b=bG0<OMU@3?iId0d>6M0=OZZ036fiX0f>j]09>[
K@1YPDD0FVlg0=?X/02daI40=T@C09bYM03EiJH0`^>N0=S[Z@3IjJP0bNBM0=CYY02FTUD0PX510:c3
N`3>gIP0e^6O0:jfO@3EgJ@01aD00<KHVP3>ijH0e^Z]0=3VYP35fi/0a]fI0=gd[P38h9H0e>bP08fT
EP35g8`0goJV0=O`W`39iYH0c^nN0=7dXP31ii@0a^^K0=;gZP2ifY<0b>JV0<kZ/03DkKH0SIef0<_B
`02:SHH0l_C_0?ooo@1fMWH0]K>f0>GSiP3ln_/0ookm0?oknP3hm?<0ooko0?Wgn080ooko04T0o?Si
0?ono@3oo_d0blK30:2HU@3ooOX0oocj0?omo@0k>c/000400?_oo`3]lO@0oogo0?oko`2o]KH0n_Ga
0?oomP3joo@0l?WT0?WoiP3nom`0jm>S0>C6U02MYVl0f_6m0?Goj03gnnX0n?oj0?Con03jooh0m_cl
0?Wno`3dnOD0o?of0?_oh03HgkD0_LJ?05aU;03Egj00c=fI0<W[U@39k8h0bN^D0<WYW@39ij/0bNFd
0<WV[P39jY/0bN^G0<WYX039j:D0_=bM0<k^[`2og9X0a=nL0<gRW`3;gY`0cMfL0=7MW@3QkJl0HF/_
08VDG037fJT0dnFc0=K[/P3Ej[40cnJ`0<_S[`3;ijd0bnVY0<c/X`3;kY80b^fC0080b^RN0P3:j:00
0`3<ij80c^VV0<gWYP020<gVY@2:0<oWZ@3>j:T0b^F`0<OO_@3eoo@0m?o/0=_H]`3Rf;D0oo[_0>gE
e@3on_/0ooO`0?ooj03DkZD0bn:N0<cUY03;iJ@0cnNM0<GQUP2ohY80b?BO0;o/U`33l9/0b^bO0=K`
Y`3Gh:40h>6W05UJ803@i9l0dO2/0<KTYP3:k:l0b>^[0<;RW`3@lJ80c>VI0<KJTP2Y^7D0cMVK0=OV
X@2edhT0b_:Y0<?bZP2nl[80^nbd07nSM`089000A5@i09RXSP2T/YP0T9af0?_of03Mk[L0g_2b0=GY
X@3DjIh0cMjH0<gKW@2X/7l0XjQo0=KL/03FhZ80dnFK0<oWV@3<jIT0a^bG0<G]U`35k9T0a^^K0<[X
WP3=ij00cnJP0<kWX`3@jZ40c>>C0=KZXP1@Fc<000H00=[Y`03:h:80anND0=?fXP37k9l0aN^P0<K[
WP36jid0b>ZM0<[YW@3<j9d0an6J0=gb[`2;Wf00f>N`0<WGXP3?iiT0c^NF0<KGX@3]nM<0oood0?ck
mP3oood0oogn0?[hn@3moOd0n?Sh0?oko`3mlO<0^KVa0?gol`3noo@0i^SM0??`j`2WWYl0oogm0?7d
j@3koo<0mooN0=CV]03AhZh0bMZV0=CT/`3/o<d0k?W>0?Ooi03KiLd0jNoS0>gbj`3Tl/h0go6m0=3V
Y@3;iI/0b>NG0<c_W@38ji/0a^ZP0<KZXP38jZ00b>ZM0P3=iid03`38jYd0bNVN0<gWWP3Ci9h0RZEN
0?7RZ@1cIbd0d>nY0=?SXP25U540hO:/0<3DS`3@iil0a>2F0<?SU`0;0?ooo`002P3oool0Y`3?m9D0
bmNc0=GIbP011P004Qd005AQ<`26VWh0/=7H06f1VP2Y^lL0i?gX0?coo`3ooOl0moOe0?[ojP3BhKP0
cNNP0<[WU`2lh8T0b^fK0<7VV@37iZ/0c^2f0?cok03monl0oogg08MlNP0;0000NV]T0?oek@3oo?P0
oock0>oYj@3oooH0o_oo0?_oo`3donl0h_C<0=G[[@38g:40o?oV0?ook02UYH/0^KfH0=CS[03=hJ@0
c^BT07jEC`2cbgd0bn:@0=O/W@3GiJX0f^6g0?ook@3knN`0o_oh0?;om@2ldkl000P006i_C@1gNT40
e>>N0<_aW03:jI/0Og@l08alB02j_8X0LG=40=OI/P3Rikl0bm:X0=[X[@2V]WD0dNJK0<WOU036gID0
CfDM08^LF02CY600c^:M0<[OVP3JkjX0d>BO0<;FT@3Hij@0fNFS09NPG`3Fg9`0Gf0V0=SLW`3Ihj@0
d^6P0<oTW`3@ij40bN>L0<?MU03Ek:H0fo:/0<cSV`3AkJ<0c>FT0>GfbP3hon<0^<BP0>3]`P3GiZd0
cmnP0<KJU@3Qmjh0a]bD0=KWX`3@i9l0e>VX0=CZZ@1fSU00OiMK069g?`2;X6P0f^^g008@000^>PP0
dMnT0<SUY@39ei`0g^V_0<kTY03AhJ<0O78m07Ub>`2caXH0TYiN08fEF@2LY6/0e=bS000;003HjZ`0
gOJe0<[QV@3NmJd0cnJN0=CZXP3:h9P0c^BL0:o5O01dS480dn^Q0<oWV`3?jY/0bnRF0<SXU@37jID0
anZH0<S[V`38jYh0_=bC0<cVY@38h:80f>fd0=CU^03Rk=<0O89d06]aI@3>d</0004006m_K`1/K6`0
ooko0080ooom04l0ookl0?klo@3no_h0o?cl0?[hn@3ooO`0ooWi0?onn`34_k`0bLC10?okn03oo?T0
oogm03<c<`000@00OhF508>7RP3oo?l0ooOm0=G9c@3oo?d0no[e0?oonP3bn>`0noo]0?ooh@2SR5/0
jl^L09JMJ@3Gj[`0h_;G0>3Te@3WlnT0c=W@079hM02KXIl0k?3c0?cmo`3nood0o_oZ0<cD[@3LiJ`0
EV0T0>?X/03Eh:H0eoJX0;kOQP3Jnj@0`n6G0<[U/03<iK/0b^Fb0<?RU03;jiP0anBQ0<KTZ034hjL0
aNFV0<SWY03DlJh0cNNP0=?ZY036fiH0gNb[0<cHVP2QZfl0Ig0k05mVA03IhKX0gn^m0<_GZ@3Bgk<0
eNFh0>;da03<hJP0bn6P0<KRSP3DlId0a^^M0080o`0001/0cnjX0<WSY03=iJT0d>:^09JVM@1bP4l0
f>Fi0=CQ/`3Ij[h0dn770?WonP3dmn`0l^_?0::CMP3on>l0jlo<0?ohm03om>L0k^k<0=G/Y03BijH0
f>fe0=S_]`3=j9/0b^VK0<S[V@32kYT00P31kYT0CP3:kj40cn^Q0=?MWP3@dIL0KVle0<OKU036iYd0
c^nZ0;[OVP31iZ00b_2U0<c_W`32hI40fNjS0<;?R@2nbXP0dNNO0;oQU@33jY/0c?NW0;oXW03>lZ`0
goK003M97`004@00V;2J0=_fi`3`ooX0lOoa0=C_cP3=j[h0bNN[0<?PWP3Ek:H0dnNR0=?MX@2AV680
_/>=0=;LW@3AgYT0dNJK0=O_X`3<k9T0cNnK0<3OS`3Dl:<0e>^S0<[OVP3NlJl0d^VU0<;LT`2]a7@0
SZ9J08>>IP001P00e^Nm0=7WZ@3?lId0`nVD0<W_XP35jIl0dO>W0<o_Y036iY/0e_BZ0<OSV@3CkJH0
e>VV08ZOGP3Mkk<0^L^A0<[RV03>iY`0g^jo0=gXaP3noo<0ko7T0?gok`80ooo_03@0o?o^0?Sjk03o
nO<0ookf0;JiY03lonX0o?o/0?Olj03_kn<0K6AR0?oln@3koo40noo_0?Sof035fYl0gO2h0<SKX`3M
k[X0nOoJ0?Woh@3kond0nOoa0?Wmo03kool0nOoV0?WofP3>i:@0cNNN0<CST`36jIL0c>nO0=3bZ038
jJ80bn^R0<k^X`2odh/0kOni0<7MTP3<iYd0fNfV09JQG@1AIR40[IYR06EB6P3AjZH0d=ZK08nKF`3F
ij<0e^VW0<oVX039i9d0b>JL2`3oool000X0oooo0;<0^=n@03De6`060000enc10>[of`3UlKl0bnG2
04R:R@3ioOl0m>Oh0>Kkk03iooP0nooc0??oj@3aom/0cNB/0<?OTP38j9<0`^><0<7PT02ng980hOJn
0=ST_P3jo>L0oooa079WH`0L3@X0iMC=0?c[h`2;OWH0bl2l0<>i^03ooO`0oood0?[on@3joo`0moo/
0>GfbP3Tm[X0d>6[0?[oi03nonP0`LJM0=GPZ03IkjL0eo2^0<WSYP26XE`0b^FF0=C/V03=hYD0gnJl
0=cL`03^j=P0ookd0?ooo`3kood0cMO>0005000?4`00g>N[0<;FS`3;j9P0c^BI065J8`2/X6`0j>^f
08nAH03`l/X0oooL0?Ckc`3@gZ<0RIUH0=7VV`3CjIh0e^fU0=gd[02icXT0d>FP0=3WX@3Ajj@0b^6K
08^PF`2X_7L0fnZW08ZFE03BfiX0^;em0;:YL03Uh:H0g>:R0<WFT@36gY@0cnVP0<WUV`1WPCP0d>NQ
0=CYYP3>iIl0bnZN0<[WY03Llkl0jok@0=7S/`2jbiD0TJAR09jcKP3HkZH0enjV0<kUW@3=hIX0dnNP
0:BkM@2;Y600hojk0<GPW@3Gkk40d>JX05ib=`2@XVP0RYMO03E0200?:000KGI10<oFX`2Q[gX0R91O
07UX?@0?0000iOBk0=CMYP39dIP0];n30>;`/`2K[Fl0dNJU0<?NV`3Gli`0foBQ0<WRT@3KlJH0`=J=
0;G:Q@1lTDh0i_fi0<_TX03>jJ@0c^bR0<cWV03=j9L0c>VI0<WXW039iid0aN>K0=;]Z03/ol40iobk
0=CWY`3Eijd0dN6d0=cZb@3]n]`0`<Vf0?;hk03noo/0n?[e00D60@3Qh=`0nOSd0?konP3nool0oOko
0?ooo`3oood0o?Sg0?onn`3mn?@0]k:^0?onn`020?ono@120?Oal`37alT0?D5200030P2b^;P0oogo
0?[amP3on_l0Bcm30?omo`3km_X0ooko0??fj`3oonP0GShG0=nlTP3CeZT0`M>Y09ZZS`1eNVH000L0
01`/4P1jQGL0I6YN00400P0k>3l0KVag0?Knl@3Ul=80l?k10=GMX@3BcJL0moOE0<;JYP3GlJP0d^fN
05A_;0002`000aH003iE:`3;iiX0dNbM09R^O@002`00014004iW;@3ClZl0`=nI0<g]X@3<jil0bnNL
0<gSV`3=hI`0e>:T09nWM0030P000`<001HH000[;@D0<CH=01LL00083`00F60_0=7JY@3=f9H0g_:Z
103o00006P2of9h0JWi90009000a?1@0LGQF05=F>@0M8040MGYJ0:6UU`3fmo/0n_Wg0?ofh02o[Y@0
M5Q:05e2=`3[fLD0jmjn0>?Q/@3KijL0X:Ye000800002@00c>VI0<[YV@38jiT0`nfI0P33kI/0Q03;
kJ00a^BJ0=KWX`3>fYX0HF`Z0<CJT@38ii/0a^JJ0<K]WP39l:40`^VJ0=7dY038jIX0eN^P0<kSV038
g9D0RZUS0<odY`34jIT0bN^E0=?[U@3>h8h0l?Vj0?kod`2;WhH0b>?D01Y2@@0aGV<0S/:n0<?ik02b
k=@0/^bl0:[TZP30ljh0^NVO0<kcYP3>kZ<0f?:[0<[NW`2W^Gd0L8=309faK03>hiP0h?FX0=c^XP38
fI80UZMS09f/J@2DXV@0e>^W0=?]Y03?iYH0g_:Z09fXP0001P00enJm0=?YZ`37jID0aN^F0<O]X02k
eXl0iojh0;K=Q`3Lljd0b=nG0<[QV@3?iYh0d^VS09bcK@3Aj:@0d>FR09^^K03GjJ/0_l^U0>[df@2I
Xh/0`LZ]0=ST]03Jijl0enFZ0=GT[@3GiK80o_oR0>3Va02S/h80c=nX0<[K[P3FhKl0m_WT07A_J`1c
L6/0jNkJ0<oJ_03:hZH0c>NT0;gFU03DkJ`0a]^S0=c^_03Yn/h0mooZ0?Wol`3kool0nOko0?Ooj03i
oml0d^Z^0<gXX`39jId0a>ZG0=Ol[036ij00e_Fa0<_VX@3?jJ80d>2I0=CTW@3@j9h0Q9YB06im>03M
i:40enRT0?OPZP1_F280S:5N0:neM`3Lij/0jog10>Gi^P3>i:@0b>6O0<[UX0/0oooo000:0?ooo`2n
0<S[Z@060P00<B/C0<oZ]@3?k;`0c>2]0>[oj00iPWT0m?Oo0?oho`3gooP0nOo_0?SojP3eon@0l_oG
0=Sb]@3=k9`0bnbE0<o]U`3Dkj80dNRR0<?DWP36cZT0m_?P0?oij`0V61D0?bd[0?okm03ch]X0l>?K
0?omn03onoT0ooko0?oon03koOX0nool0?Sok03TllP0`]>L0<cLZ`3lonX0j_3F0:ZaQ@3;fI`0dn^O
0<oZY`34gJ<0bnJS0<SSU037ghT0e^RN0>K/b03oon`0h=S;0?onm03bl?<0oooo0<;3_P0520005Q`0
0=?UY`2oeHd0fO6S0=7QV02g/WX0d/fF0<gBVP2UZGH0oooL0?cof@3LiKH0eNFW09NWIP3HkJ80c>:G
0=O^YP34fi<0c^FO0=O^Z037hIX0d>ZS0<gWX02Z`G/0L8E00<oPW03ChYl0A4d<05IH6@36^H80JV4V
05mT8P2mb8<0hOV_0<_UV`3Ckj@0NIE;09B^I`37fYP0e>VT0<[[W039jJ00d>V_0=?Z/P3@iJ`0bMfN
0=G[X`2bbX00:d80092YI@2[aGh0/<Im08nUG@2Y`gX0b>BJ0<3NUP3Mn;<0_mZG0=7ZZ03>i:<0//J7
09ZZK02>W640NYAE05mY=01TJcL0f>Jc0>kfa@1`GSH0P7=7010R000c?0D0MGi50>Gc]@2?Wf40PiQG
0;oEU03MnkD0bnN@0<gVT`3=iYD0dNNL0=7WW`2;X5d0/<N30<KMV@39i9l0bNNQ0=3`Y@3<iiP0c^VJ
0<gYW03:j9h0bNNO0<GRW`3So[/0iOjj0>7f/`3=h9h0d^BV0=GX/@3Ol<@0kokG0?Wok03fon`0o?of
0?konP3oooX0F5MC0=OFd@3em_40o_oo0?cmo`3nool0ooom0?ojm`3ooOT0ooch0<[5`@3ooOX0mOCb
0?ono`3onOd0/[:d03/o@00<5QD0m?[j0?omo`3il?<0ooOl06mPI@80ooco03L0oogo0?OhlP3oo^X0
HClJ0=J`R`2l_YH0ioWA01l_4P001000T:1k0>Wmf03ioo40l_WW0:>OWP0B3A@00@0<0?_on`3_o>00
noo=0?Cl`02l/i@0k^SB0=k_b`3@iZP0f_:X0<CJVP0G:@<0Jg]P0=oab@33fhl0dNVM0<OI/`004000
;D090=3U[03=jZP0d_:Y0<OZVP38ji/0`^>D0=?]X`3<hi/0dn>R0<_HX`030@00Hf9=07AfC`1IG340
VYe^0864E@0^=0H0LWQ80>O^^P3Ggj<0eNBQ00@0o`000:00<TX>000<002BXW<0a]>W0<oJ/P3Ni/40
Y:Z60044000l?CD0o_ko0?ono`3oonP0ooCG0?o/e`2bVhT0KV1308N0E02HV680f>2T0=_Q/@0M8@H0
00P00<cYV@3:jIT0bNZI0<K[V`35k9/0a^^M0<SZWP3<jZ00d^VS0=KZY@2ebH@0V[9X0<o[WP3<jid0
`nJF0<[_W`36ji/0d?:U0<KVVP3<iY`0e^jR0=[bZ025Xed0dO>W0<CUUP35iI80e^bI0=GSUP2l`XH0
i^bn0<oNa`3aooX0fooi08fl/P0ABSL0@7aS04F4I@21`940RLZD0;;^/02ilK00`_2_0;_UX`2kgj40
a^FZ0=?_]@3EkJl0]/b;061a:`1lS4<0gnnV0<oOV02?X5`0a=BC0<oRXP33g9P0f?BZ0<OPS`3:h9L0
N8AL00@=003TllX0fo6c0<3RSP37jYH0d?FX0<oVX035fI@0dNFP0<[NV@2Z`7P0C68J0=?ZXP37gYP0
QIaF0<gTW03?iYh0VZe]0>?b^@3kon@0noo/0<3:[`2>W7P0NH]=06=g<01bQc`0YKYe07Z>D@1]NDT0
]<2@0=oe]@39hZ00b]jY0??of`3nond0mo?`0?kkmP37c;H0g^W70<[TY`2ogY/0bnRV0<7KVP2oeid0
cn>^0=___P3`omh0nOo]0?_on03jooX0noo/0?SohP3>iZ`0`]fJ0<GUV@38kY/0]mb<0<g/YP2og9T0
b>6O0;;9Q@2@WeX0QYM@09RbJ03NmJd0e^NQ0=oXY@3AiJ00l]^U07EP:@3;hYh0iNj_0>;_]`3Tm[`0
j?c10=G[[@3?iJD0c>JU2`3oool000X0oooo0?P0EVi<0<O4X@3Yj[h0aNZU0<S[Y`2mm;d0Ol2F00aC
=@3`ool0oo_o0?oom03Wn<`0cNV_0<cY[`3=kJh0bNRT0<SWU`3;j9@0dnZJ0<gNU`3BhJ00fMn_0?oo
h`3cj]T0710402PF503NblL0oo[c0;^ZX03ooO@0oogj0?omo03oo_l0oOgm0?ono`3nool0n?oa0>Sc
d@38ej`0dn6m0?Gnk@3Oi]@0e>2b0=o_/03Dkih0cNZX0<cW/038hZ<0eO2Q0=;ZUP36ei40jngE0?ol
l`2FS8<0jnCL0?ono`3mlOD060D700L0001bO5L0a>>O0<KUV@3=fHl0DELA0<kAV03HgJ<0cMVK0=?N
Y026Sf00fnNg0=GR[@3Di:D0g>fY0=3UVP3?iIX0e^bT0<_RW03>j:40b^BM0=C_Z038hi`0a^6J0=3W
X@3;hY`0eNJR0=3OW03HhJ00XZ9T0;RTK`3ahZT0DUDB09^WG`3:iIP0b^JI0<c[W@31gI<0O9I?0<cL
W@3DjJ@0a^bI0<O/W037iih0a^BL0=3ZX037hY<0a>2<0<o/VP30g940d^n]0=7^[03BkJ00e_6T0<_W
VP33hY@0`^>D0=KgZ02kfX`0e_:U0;WER03Dk:00bMnD0=_cZ@2mhiH0b=^I0=SVZ@1oUe/0X:mh09bD
I@2TX700dN^/0<kRY@39fid0FW4]02<j0037hYd0`n6I0<_]X`3DkZ@0gOB/0=;YX@2ldHh0Y;Me0=GZ
Y`37gYX0f>nY0;oNT03@lj40_N2<0<WZV@39j9`0b>RM0<WZY@3:jZL0aNFT0>7o_`34gYd0d>VW0=?]
YP3BjJ40cnJN0=cb/P3Ej[40kOgF0=CR`@3ionh0nOoa0?Sil@3/k>@0kNgU04m@B`29SHh0loOj0?ko
o`3ooo/0ookj0?onn03on_@0g]_F0?ono@3hn?P0ooko0?oko`1jN7/000420004003kood0oogl0?ol
nP3on_/0EDE80?kbm03onol0ooSo0?cjn`3oonl0Me8e0?S?[`3WilD0bMVe0008000j@1X0d^JW0<_S
Y`3fonD0o?oV0?kil`3>all0>C56004:2@3aonP0enNX0?7i_P2<Nf/0ooOh0?Koo03Ymm<0cn:R0=GV
[`0F8`D0HFeG0=7O^`3HkJ80fnnX05IRCP043000]l6=0<oLYP3LmK40_MfB0<[bW035kiT0b_BN0;gS
T034iIH0dnfT0<WNY@001000L7UL0<SBWP3KijT0c]^E0;6lN02DWV80E5`S06Yb>@2OY6X0bm>H0=CP
XP80o`0001L0f>RY06j3@P1XOSd0a=fK0;_FT@33h9d0`^2J0<gUZ@000`0000400?_oo`3hoOl0oooX
0?oog`3omm<0hM^g0>7V/03FhId0RYI<081kA02_ZX80<R`L00<100030<[YW@80c>RN08D0c>NP0<k/
Y037iih0`N>G0;oTU`2mgi<0/<b20<gWW@3:iIH0c^^I0=;_W`35i9H0c^jU0<c[Y@34iY`0b^bO0<?R
U02?X5T0d>BO0=3YY@3@kJX0bNFZ0=3W/`3Vl</0l_KK0<O<^03Xkml0n?o_0?;og@3ZomH0g_o?0<;Z
^02kkK`0/nNg0<7ic00kLdH0<F<m03][A@1/Vg40[N6`0;ka^@3=m;/0bnZ^0=KYY`3<fiP0f^NQ0=3P
V@39h9X0aN2K0<;SWP37j:40_=bA0<gXU`3KljT04Qh000hI003Ij;l0bmnR0=ciY`30h8d0b^bP0=KR
X03DfYX0d=VH03Q30@3?gY/0U:EQ0<kRW@3Jl:P0`]Z@0<OSUP3:iYT0QIED0:^hPP3konH0noo]0>Cc
e03SmL/0cNVN0<KTSP34iH`0eOBV0=;`ZP3:h9l0aMbF0=KeY@3MoZd0c^Z`0>[of03ioo<0ooko0?kn
o`0W;aP0>TTR0;oKZ01HND@0HH170=Gd^@36i:H0dNf`0<WRZ03Jk[T0hOG40>Gfc03Ulll0i_?E0>Of
e@3XolX0b^NU0<_]X@32j9D0doRZ0<;QV`3?jZL0Q9MG0=KUY03Bj:00b>BI0<SZW@37ii`0c>JM0=[[
Y@2ofY<0g=2F065E6`32hI/0b]fK0<[KY@3=gj/0hO>o0>Kk``3Qm[d0c>BX00/0oooo000:0?ooo`3g
000?003CdJP0gnB^0<caZ`3Bm:L0]?[402ekD@00?aH0h__g0>obn@3olnX0iOK20<OXX`39jJH0a^VU
0<KWX03Gn:L0c^^I0=_`X`3Kjj@0dmfN08B6E`22OEl0@SHX01@6002kZ:@0ooWf0?oekP3Ga[`0ooW`
0?onnP3oood0k>_a0?kmo`3ooOl0o_ko0?WomP3bo>40mOoO0>Wff03^n>d0iNgN0>Odb@3AhjD0f?FQ
0<7OW`39i[00bnFX0=G`X@3BjYH0TZ=M0>_Ze@3oo_P0e/_50<[3^`3ln_d0h/oE03hU:00:0000L7aF
0<;VX03;jil0];ac071a;`3BfYl0eN2T0=3OWP3Mjjh0HFdk0;2nR`3Ehjh0c^6Q0=;VW`3BiiX0`]R=
0<kTW02AZ680dnjW0<SSW03@jj@0a>:J0=?^Y`3=i9h0e^fW04iO6`3Xmk@0bmBC05]K7@3^ej<0e/N>
05]N6`2KYel0dnjO0<[YV@36iiP0`MfC0;_BS03BhZ<0d^NT0<C/UP36k9T0bNVM0<_ZWP3=jYP0cN^E
0<o]U`32hXd0f_V]0;kLWP2lfYX0an:E0<SSU03?kYh0b>VH0<obX033iY@0fO^W0<_[V03AkY`0dNbK
0=ohY`2ieX80b?BO0<OQV035fYD0aN:P0=GY[02[Z7D0_kn90;gLV03NmkD0bn:N0=?^Y`2bcHH0_]jE
0=?eZ`2mhYD0aMjJ0<_QX037gI`0TjEW0<GGV@3LlK00^M2:0=ccZ`36j9@0dOFN0<C[TP39k9X0a^RK
0<?WW@36jjH0b^n/0<;UY@39k:`0`N2M0=Kc/03DkjP0a^2F0=C_XP3HlZ/0mOo=0<OHZ`3Dh[l0o?o_
0?col`3en>d0ooof0?Wkl01ZJfD0;C<c0?Gio03nool0oOch0?onnP3oo_P0ooSb0>[WhP3oo_d0oooo
0?ono`3onol0:RP[03m0@P001@40emgI0?onn`3hl>d0oo?c06=CE03omOD0oo_o0?ojo`3on_h0ooga
071;;P3`ajT0aL:S069`C`002@00Q8]O0<WOU`3;iIh0mooS0>khd`3oo?@0oo_o07mgS0000P@0iOCO
0=[ZZ`34c940RgM/0?oho`3^l_/0nooX0>_j_`3Ehjh09S4C05mXD`3Wlll0eNNM0<gNV0022P0000@0
09nVL`3CgZH0f_>_0<GTV02ojI<0`NfD0<SdV`2miHl0b>^K0<cZX038h:H000L006UgEP3=gj<0e>FO
0=KWU`3Agi80e^>N0=?MWP2obHd0SYIK03Dj00020?l0000L0=;JW`3Fh:<0cN6L0<?JTP3Blj@0fObZ
0<;XT`3?nZ40a>JJ000400011`<0n?oo0=gWj@3Df[h0bm2X0=gN]P2i^Y00bmVK0=kcY03MkYh0N6hi
0:jUOP090P0010000<WYWP3:j9h0c>RN0<gWX080cnJP08@0b^FN0<GUW03;lJ@0b_>U0<G^X02heXh0
cNFK0<gUU`3>jIP0dNbM0<[UV03;jJ<0anJR0<3TVP37kJ00dO2P09BNE@3Ii:80d^JW0<o[/03Cm<L0
g?[D0=k^e03loo40oooa0?[giP3?bKT0c/Ng0?gkk03bmn<0j?KO0=_hf@3CmM00^>Ba0;_[/@2Vf9<0
`?2V066EB`09A0X0=G4m0;o^]`30hjT0enb[0=OVX`38eHl0e^NQ0<COV030hIX0bo>/0<7UW@3Dm:T0
`Mj<0<OOU@0I9@00>TDU0=OV_@3:gZ40dNbK0<[ZU`2mgI80f^FS09VKG02PYFD0gN>U0=3LVP13DPl0
cn>N0=_aZ@3<i9X0a^:E0<OSUP37eiH0/;^30>WddP3jon`0`=6a0=;X^P38iiT0cNjG0<kaU`32hYH0
`^:O0=?]YP3?jYd0d?:L0<7TT037hjT0k?oK0?;mk`3noOl0moKl0>3Ye03Xn=40`]nc0=Ohb`0?;`00
Rjae0<k/[P2nfi/0cNNX0=7YZ`3@j:`0cN:Z0<kQZP3Ch/40fN[80>god@3:jJH0c>jR0<;YUP31iYP0
d>jX0:o8QP3Xn;T0dmnO0<_UW036j9/0bO:S0<W_XP34i9T0a=^C0<W[X@3cjZl0SHM;0<K/X`3;hYh0
c^6Z0<gQ[P3EjKH0j_k90?3oc@3Gk;<;0?ooo`002P3oool0mP002P00g>6[0=?MX02mh:00`n2M0:Oc
a@1?Wg`001`00?7oo`3lool0ooG_0>Wfb`3<j:d0cnf_0<WZY@37jIl0_Mf:0=?^W@3<gIH0V:AT08nG
GP33_iT0XiEj01<0000?0000d[fl09^7R02jZ:H0b[fg0?oomP3mn_D0ooom0?koo`3noo/0o_oo0?cm
o`3looP0noo^0?Ooi`3eoNP0moce0=oUf@3Ylm40dMn/0;cFS@34h:<0b^F^0<cVY@2ofX/0dNNE08fN
FP3_kmL0ooW_0?omm02o^;00mo?d0;bW[01TBTd0200006EcC`39kZ/0dNnW07j1?02ETE40hO2_0<kS
X03BiZ40dn>T079lA`2f_hX0joBo0=cVZ@3?fYP0^<Eo0=k_Z02DZF@0S:5L0=7VX@3=hYd0dNbU0<KT
W03Elj/0dNnW0<COV01nTTd0aMBA0=_TX`1GEa/0jMBO0;BSK@2KUEL0^;Yi0=KZXP39iIX0d?2T0<OU
V`3NmJl0bmNG0=SYY@35jYX0a^^M0<SZWP3<k:00`nBC0<_[UP3<kIH0do>N0;[KS03Hmk40cnfW0<gY
W038i9L0bNZK0<_/V`34iiD0cO2N0<?UT@32hXl0eoBR0;gHQ`3>jIP0eOFP0;SRS03=jIh0g_B/0<[S
X@3?hJ<0ZjYb08f@E`3?kJL0_MRC0=G_Z03@k:80dnjW0<SXW`3<kZ80co6U0=3SX`36fiX0T:ET0<SN
W@3Fk:`0cNBP0=K]Y@3:i9X0eoNT0<g_V@3>m9d0bN^N0<KUW`35i:00bnVY0<o][`3Knk`0c>b[0<CS
W`3AkjL0]M>9092/G`37i980foJY0=gg/03Fj;H0f>Bn0?kok`3]lN<0n__c0?oon03lo_<0Q8Mn0003
003iood0o?oo0??bkP3oooP0ookh0?okm@3ln?D0ooom0?koo`3lo?h0mo7e06EPI01XJF/00``90>7W
i@3kn_P0ookk0;nd/P0h;B/0o_?_0?oko`3on_l0ooom0?cfiP1ZAbL0ejb<0;F^T@0/=AH000T00>;[
_P3QmJd0a]fG0?Woi03fomh0oooh0?G`mP32_/d01@T808fFP@3Lijd0e]^S0:^LQ`3kl>X0mooj0?So
i03Kk;D0fNNf02`f6`0e?2X0WZN:0=OUZP1oS5H00PX004E;?`27Seh0gnVd08VPG039iI/0_^B?0<3X
T031jI40c?:O0<o`X@2ng9@0eo2f0008001WN5@0d>FZ0<kUX@3@iiT0dnZL0=CXX03Dj:<0cMfL0=k^
[@@0o`0001P0c]>I0=7MW`3JjZT0c>NP0;cLT@3@lZD0^^6@09VhM0031P0000800?Cno`3hoo/0a]6_
0=GL/P3@ej@0[[N20=;VW`34h8/0enfJ09^AGP22N5@01`0000d:003:jId20<cXW@<0cNNP01T0b>JN
0<WYX033j9/0_NBE0<G[WP2V`GX0cnJN0=?[W`35h940cNRI0<o[WP32h9P0bNNQ0<_[XP38jYh0aMnE
09^RG`3Pj:l0cmfZ0<_Q/`3YonH0l?oc0?3nl@3kooH0mOKX0080ooo_06T0nNoU0=gDc@3hm>/0k^kR
0?Sok`3Ol]H0foS:0:o@V@3<lZT0^N:C0<OfZ02:aXX0=gM308NkRP2lj;L0eoBn0<7IW`3Ml:h0b=fH
0<gXX@3HnK80`NJP0<WYX03?jj40dn^Q0>7d/P0U;@H0JG1?0=;M/P3Ij:l0b>2D0=ghZ`2S`GT0T9eH
09:LE`39e900fnJR0>;_ZP1bOcX0d^:K0<oTV@2fc840e?>U0=?dY@3CiZ@0Wjeb0>gjc`3Oj/P0amJ_
0=GW]@39hiT0aN6=0<_XU037ii`0bNRU0<[TW@3EkJ<0c>^K0<3QT03?j:h0cnBi0>Oeg03io_P0o?oj
0?Wok03WnM40e>G30=WYc01ON500=U8R0<KTZ03Fm;@0b^NU0<gVY03>i:<0c^:S0=;TZ03;fjh0d>6e
0>cob`35gih0bNNQ0<[ZW`35iIX0YL1i08^RGP33eYH0d>2O0<WSVP3<kZ40`njN0<G^X039jil0e^fU
0<S]X03Qfil0TXa@0<G[X03BjJ<0eNR`0=3T/@3;gj`0k?k>0?SofP3Sm<L02`3oool000X0oooo06h0
_mf70=3TW@3?hJL0mOoV0?Sol`3Bool0;FmS0;oHg03klol0ooco0?3hnP3nool0mo_Z0<G@/03@iZP0
a^2G09bgIP2Q^F/0f>JY0>;Z^@3Ri;l0<2@>034D101@;BL0l]?A0?oho`3di>h0ooco0?[io`3cn?@0
o?of0?[ol@3honL0l?oJ0=OY``3]o=/0o?oa0?_mlP3oo_/0o_Wf0:BOW03dkn/0oO[a0?[mj03Nj<<0
`=>L07b@D`38gYD0e^bQ0<[KU01dPT@0iNc30?ooj03mm^h0^[Fa09JBT@3nk>`0kmcH00<2001RLe40
^=>N0>Gg_@1SGAl0inBQ0<3PS@36kIX0a^BL0>Gl^03]l[P0ShiF05aE8@3`i;80gmFR07=d>P26T5<0
b=nI0<GIU01[K300]K]k0<cSV`3AkjD0aNZL0<WbX`34ji`0g?R^06j2?@3AfY/0X:5W0:VKJP2]UVX0
W7aC09f2E`2LVfD0bmfQ0;kMV@3?mJX0iOng0823?P3Lgi`0h_no0<_XZ03^oll0k_oA0<[]Z@3;kjT0
bNVM0<c[V`3=kIP0c^^A0<k/U080anNK08H0anVL0<SZW@37jI`0bn^O0<WXW03Al:@0cNVN0<[TVP36
h9H0b>BI0=GaYP38hYT0fNnW0<oHU`3TiZL0Y:9U0863A03HjJ<0c^FM0;WCRP34gY@0bnFK0<cXW@38
ii/0a^FI0>ka[P2R[fT0bn6H0<gbY02oi9H0c_2S0<[YW@38hYP0`=R>0=oi[`3Elj/0anFU0=?X/03F
i:l0fnB_0<K?V03>hJ40U:]U0<c[W@3<ji/0cnbL0<_VU@3:ji@0cNVE0=_cY`2nbiD0Z:j80?oom03h
m?40n?Sh0?3aj`3noo@0m_o/06MeI03Hi]L0iO;Q0?;fj03ooo@0ooke0?_hl@3cl^h0nOWg0?_mo03o
ool0n?;d0:FOX@1WHVH0000501HG700l@4<05AHH004000030000oooa0?olmP3om?h0m?c]0?_oiP1H
@1@0k/:M0:B?LP060P0000T00<;@[035eid0iO>n0?[mk03nooH0nooo0?coo`3emo@0104006]UB`3]
j[l0QHEC0:^dN`3CiZH0anjM0<W]X`3=i:h0fNZn03<m6`010P0020T00044000010000``00=SS`@3U
nLP0bmn/0<kTYP39gih0LXY00:_3M`38h9@0d^VQ0<oVX039gil0d>F]00080011DS00SjIl0:BnS`0O
@0L001L00<CXX03=lZD0doRZ0;SKR@@0o`0003D0FehW040o4`1JF380HfA403Tl7@0:4@0062<50006
000A4000b<jZ0=GT^`3hom`0_lfJ0=;LZ03FgJL0XJYa0=W[[@3Dk:h0cMnU0<RlUP21Me@010<000@7
002kdX80bN6C0=OcYP3?lJ@0a>JI0<W^X033iIP0anNL0<;LTP34fY40d>BL08RMF039hi`0b^JL0<;T
U`3;l:00`NJF0<7RT`3@jZ00c=fI0>C`/02KY6/0bM:U0>khe@3`nMX0o_o/0?kol`3nooH0nOof0?So
l`020?Gok`1Z0?CojP3^omd0n?oT0>G`d03Efl40inWD0?ook@3koNL0oooX0?[ogP3Jjkh0a>2]0;kX
]P2ikKd0X=Ra07^dT`17N5X0BGEB0:30S`3FlKX0aMnN0<KQWP34hil0bn>I0<WMU@3=ej80emf_04E3
7@0K5`00QhUG071h?`2P[W00YkYj0<SNWP3BlJ<0c>fL0<CSU@38i9T0/L9l0;[7PP39cX`0^/200;S4
PP3<jjL0bO6[0<3QVP2lfY@0^M2<0<KFU@3Fh:40cmRI0<cEUP3MijP0e>>R0=kc/02gcXX0e^VY0<[J
V`2V^GL0UjYX0<_PW`3FjjX0^Ln?0=[a^@3Uo<H0h?O90>3gb`0^9A@0Pg9X0=?E_@24TVl07SX908BS
JP1mVel0eN^[0=o_/034c900gN>W0=cXWP3EhiP0X:Y]0:J_N02FWfX0VJA/0:NeM`3>hYX0eN^P0<ST
VP3=jj<0c>RN0<[YW@35k9d0a^^M0<[YW@3@iYd0d?2T0>;HVP1ICa40a^JJ0=KWX03BjJD0c>JU0<WR
Z03Ij[h0jOOD0?cok@/0oooo000:0?ooo`0I0<cUX@34eIl0bMJZ0??oj`3iooP0]OGU03QgK03^ool0
ooWo0?gho03bnoH0oook0?OkjP3lonP0l?o<06Ek>P2^aGd0gO>[0=7KYP3CfJd0HfA203<V4`19<BD0
iLW50?ohmP020?oko`1C0?koo`3cn?@0h^gL0>OdfP3Tlm80i?O:0=kfa03<h[@0go7;0?_ok@3moo80
o__f0?onn`3dkn`0l^gY0?kklP3oonl0hng:08RIH`2>X6@0e>VT0;oES@3FiZD0X[1e0>gcc`3oon`0
oogk0?;/k03kn_D0oo[j0=G2_P070P00<T0O0=[^^@3:f9d0a/:20=OHU03Am:00aO6L0<;XW@3DmJh0
f^b^0;O5R01PJ2l0g=nX0<kCV`2`_X00V:e/0=?cZP3DkZL0NX1207F0?P3CjZ80bNFK0<;TU`31iYP0
c>jQ0=G_YP19GAP0fN:S0=KJW`3?`i40FdHG0?3?YP3oj;h0XYaX0=[X[@3NnKH0^]jD0;gIS`3Mi9h0
Mghj0=Wf]02heI<0g_bl0>7o`03:jZT0bNVV0<?SVP3:j9h0c^ZM0<cWUP3@jiX00P39jId0@@36iYX0
anNK0<c/X03;jYh0c^fQ0=3_X`38i9T0dnfS0=G_Y@3Ro[<0/ln507VEB`2=Y5`0VJAP0=;GU@2PX600
/;Ec0=CUWP2kdhT0h_jc0<;NT`3>jYl0`^6E0;oNTP3=kJ40f=fJ09VYHP35gI<0bo2R0<K[W@2ngY80
fOFZ0<OQU`3]ok/0bnFK0<o]X`2S`W`0QYaL0=;TYP2Y/gL0Yk5d0=c`Z`2mehh0bn^O0<c[W@3:iY/0
d^bR0<;QT`3>j9h0cN:M0>;[_030aZ80ookb0?Sel03hnO@0ooof0?cok`3ionP0k?cO0<gK`@38e;`0
mocX0?ool@3ooo@0ooof0080oooj04@0nOSd0?glnP3ooOd0em7C07mjOP000080l_?e0??em03gnOH0
fMSC089oMP3onNl0o_Cb0?oho`3iooH0l?gO06UB:03fbZL0eL2S01<A00003@00enC60<cL[@3Njkl0
ko7T0?con03lool0blo>0=cNf@0:2000MG9C07QjB@23R580lOc00<7FT@36ki40c?2I0<WRX03Ej;00
41`006eaD03Ig;d0Q8UY06edDP0020000A000;O;V03Bi[40e^b^0<kUX@35gI<0a=b@09ZbIP2CZV80
]Lb60=CZZP38gJD000P002`k6P1LLdT0F79305Ed>`004000anRS0<SZX037jId0bnbK0=;aX@80o`00
09<0d]jP0=WRZ@2NWg<0GU`e00L600040`000`@006IYC01[LdX0aN2C0>7o]03Emjd0b>NQ0=kb]`3K
iK<0oooR0?cfgP3oo>d0k^kT0?Sgi@3;_iT0Ge@d00@200010`00fNnW0;gDS03:iY`0co6T0=KhZ`2j
ghl0aNRH0<g]X@3Ajj40hON^0<WMU@2M/fP0aN2A0<WXV032iI40bNnL0<G[V034i9P0c^ZP0;c?S`2f
a8L0a]6I0>chb03Wm<P0nooM0>G`b02U[8X0g>?20>[ed`3ZmMD0h_?A0=gacP3GkLH0iocA0>cmd`3K
j/<0e^2n0<34Z`3IgL@0oooV0?koi03TllP0gNno0=gha@3In/d0f_oD0;3QZP3;o/D0MZIb000U0000
7@000A/00;?AW@27ZF`0OJEO0<CSU`2]a7`0QYEL0:>]N`0`<`P0?3l@09VQIP28TU<0aMJB0=?XY@3Q
mkH0a^2S0<WUZ03Rokl0f?:c09BSJP3AfJH0^;V?0;bnUP3Qj[l0hOc90<ob^P3Bm[00b>RO06Eo>01^
PSd0YK5_09^VI02=V5H0f^JT0<KGT`39h9X0eo6Z0=;WY02ic8X0PiQE08NLF@24VEH0RYmN0=K/[03A
iZd0_]FM0=?Y^P2ldZ@0c=Ne04QC<`3Bhl40PIMc03mK<`0T@AD0[LVI08>FG`2GXVP0jNRX0<g5Q02C
WE@0X[9[0:fhO03Ji:l0eMn[0<oJXP3?gIl0d^RO0=?[W`3<jZ00b^ZQ0<cXWP39jId00P35k9d03@39
jId0d>JM0<_[W`3[hJ<0J60Q0<g]X@3Dj:00bnVO0<W[X@39j:D0bn:/0=OZ_@3hon@02`3oool000X0
oooo0<`0l_oT0?kok`3moo<0lock0?_oo`2>b/80Sl_10>Olo@3ooO/0ookh0?_om03no_H0oood0?oo
k`2[]I80f^Jn0<gJ[03Zm/P0al^V0;blVP0b;Q40PWYW0=K<``3klO00oo_k0?kno`3enOX0n?oh0?;o
kP3?i[X0c>F^0<WSY037iI/0anJP0<OUY`3;i:d0iOG@0?GohP3ooo<0o?cb0?oonP3oo_/0oooj0?[l
kP3/m]40SIiX0=;TZP3<hIh0dnRU0:6cM`38eZ<0gnG;0?ool`3onOl0lo7d0?kol`3nm^/0EdU000/0
000c<aT0e]j]04YB5`3Qi:40fNFM0<;YV03<mjL0`^BJ0<3OV@3Ck:X0b=jM0<?GV03<gZ00enV[0<kS
XP3Qn;@0eo:[0<KPV@3FiZD0e^ZU08NNEP3:i9/0cnVO0=G_Y@3:hYP0e>RQ06Qi=@3=g9/0fN>V06AM
9`3Zf:H0/8mT08m^@`3;^hX0f=VP0=cZ[035iI`0eoF[0=_`Y@3HkJ80b^6I0=of/035h9d0c>VW0<g[
[@3Po<40foNl0=Sa]`3@j:h0c>2U0<gVY@39jih0bn^O0<[ZWP39jId0b^VM0=3/X@39iIX0c^ZO0<[V
V`2`bX00Uk5W0=_i[`3BlZL0cNfR0=gi[`39fY<0e^6L07b3?`2BW5D0SjEJ0:o;OP3<jil0e_BZ0<SV
W03EljT0f?J/0<;PUP2b^GD0f>VR0=?]X`33j9X0b^nQ0<GTV03Dl:D0f?2V0:FmL`1oVDl0b^VK0=Gg
X`33gY40b=jF0=WXY`3RlK00`m^A0=KeY`3;kJ00bNVP0<CRW03Fk[80c^N^0=O[]P3?gjh0mOcJ0?oo
j029Qg/0/JjU0?ool@2[]9T0I71:0=;S[`3HjK<000T00=_T^@3gn]d0oooZ0?ool@3ooO<0gMK>0?Sa
j@3ooo@0ookh0?olo@0o=ST0;BLW0040003]k>L0oooh0?KfkP3`kNH0m_7[0?onn03ooO/0moGf0?Co
l`3eon@0He4S09aeC03B_ih0Lg9D00DD001TKEX0lOWQ0?[oj`3/k^/20?koo`0[04M8@`000P003a<0
02T`102?WF00`M6B0<7GU`3FlJX0aNf=0<W]U@35giH0e>RY000;001MI3X0cMB[0>S_aP3Fgk@0h>jm
000;000oDah0c>6Y0<oUY@3<hil0b>2F0<_SU`3EkJ40bn:J0>Wo^P1QMcH0[l::0007001[MU@0e^S0
0=?Y^`35h:T0cn^a0;[GU@30giT0eoF]0<_ZWP30hI80c_BQ0<GXV0020?l0000?018L000D6P00GEXg
0<c7Y`1RGCd0QGiQ0;RmU02ggXl0bO:S0:kIQ`39l:40cnFT0=KPZ`3oo^80a;RZ0080oo[o08l0mn__
09Z@K@1GCC8030H000X8003KkK/0a]^S0<WSYP31hiL0^mj>0<oeX036jY<0cnnL0<gUV`3@iYh0Oi1:
0=G/WP3<j9@0bn^F0<?WT037kIP0c?:O0<g_XP3?kJD0d>JX07nCF02DXf`0XkMl08NKG03Ol[00c=fI
0;W:P`1aPcT0f^^T0=KZX`36g9`0bN6U0=7]/P2og9`0dNV]0=;W[P3?h:`0bMBY0;K1UP3`nm00i?73
0=W]^03QnKl0g_Jl0>;e_P3LkkL0cnnS0<geW`39lZ<0bO6Z09bkS`3Glld03c@909O3TP2jk;40_>NP
0<[_Z@3ClK<0d>V_02Dg000X>000e>FN0=SYXP3FjjP0amfM0<KNXP3QmM80io[J0>[ob`3OmkT0SiaW
0=OL]02b[j00k^[Q0?cll03_on40i_oB0<?XXP33jI`0b^RN0=SdZP3KlJT0c^:K0<7ESP3;giP0e^fU
0<SVW03ClJL0a^2G0=3WW`3HkjL0`]VA0;gDS03Il:X0TZMT0:g1Q030e9T0g>nh0<;DXP3DiJh0G6Tc
0?7ed03NhL@0eN;>0<;Ja013I4L0_n^h0<Oa/P3BjiX0gnjI0<gMU03Hj:L0d^6Z0?coeP3dom40c=jT
0<WNW@3Dkj80c^fM0;kUUP34jYd0bNVN0<SZW@33k9d0aNbM0<WYW@3?iid0c>jQ0>KNW`1QG1`0`NRI
0<oWW@31jI<0_nfC0<?]V@35jIl0aNJQ0<GQYP0;0?ooo`002P3oool05`3ioo@0oooj0?ooo@3fnol0
o?ko08S3_`1a[JD0lOoo0?cdlP3oo_P0n_ob0?oon03XiM`0fmc>0?kok03bnmh0i^g<0>3WaP3Wj<T0
8al400`6003oo^d0ookh0080ooko0=l0o?oo0?Woo`3gooH0l_o/0<cV]P39iJP0bNNO0<_/V`34jIT0
bNZS0<WWY`3FjK`0i_CA0?kok`3ooo<0oooj0?C`k@3hm?<0ooob0=GP^029VV<0fN^_0<_PW@3Bij80
RYaP0<gNZP3Vkm@0oood0?omo`3lo?`0f^C<0<O4/`18?3005@D006aTC@1OHC80]kZ10<G<QP3OkjH0
^=n@0<;[W@3<hid0bn2M0=CWY`39g9`0fnf_0=CTYP36e9L0g^b^0=GTX`3HjJD0c=fI0<KKV03Bij80
PIM?096WG`3:h9L0d^JN0=GYX@3EiZ00K7di0=GUY03EhJ40KFPa09Z:E`1kFRl0Le8W06IB801iM3d0
UYiR0<SSW03ClJL0d>^N0<SPTP2S^G00eN^R0<OPW03Bk:/0`]jS0>goc@3bomH0hOO60=;V]@3?hK40
c^>[0<KXV`36iYX0bNVM0<c[W`3<j9d0bnNL0=;^X`3AkJ80[<Qm0:S2N037hiP0]MF:0<CVVP32i9P0
a>>G0<SLU03Jij40cmVB0<cHT03?ii/0d_6S07nOD`2mfHl0dNfS0=C`YP3?jJ00g?J]08>:AP3BiYh0
aMnE0<3UU`3<lJ<0cnjR0;[DRP3DjZ40[/Ak0=O_Y@3>kIl0b^bH0=;/XP3IkZT0dN6S0<gMWP3?jJ00
eoJX0<CYV`34iY`0bnRV0=3W/`3Bik`0gno80?Woh`3oonP0oOoZ0<S6^P2n_[80o_o/08RBK`3GikP0
IGTj0:jnP01GHRX0;CD40=SI^@3Ng<<0ooc_0?O^i@37_[D0cLBk0?kek03km>`0ooOh03`c=P0;0P<0
1@800?oon03cl>L0oood0?onm@3bjn<0ooci0?omn`3nooX0eNkA0>kog@2KSUX0M58T0<JdSP3KfkT0
00L00004003nonl0l_WY0?coo`3nool0o?cl004000010P00TYQb0>Ga_`3FjjP0eNbX0=;]ZP2kfi80
`nVB0<S[V`3<iJ<0enZb01DS001bNUD0gnG10=gU`03BgKD0e>Bg000?000Q=P00fNje0<gSX`39h9`0
dn^Q0<KNU03@j9`0bN2H0<gTWP33fYH0`MFJ0007000h@Ql0`mBZ0<_N/@39hZ/0bN:Y0>?o_P31gY/0
c>ZT0<CPUP3=k:00_^RD00@0o`0002<000P00>[Za03@cZP0g]Zg09RBL01eMDl0Fg@k0;gKW`3Pok`0
b>NQ0<SKV@3NjJl0oooO0=3:/P3onOH0n_Gi0?onnP3;`Z40W99i00H000030000n?oQ0<?IZ03Rnl80
c^jU0<[]V`2oiHh0_Mn80<o/V03KlJP0dNFP0=7QX03@iYd0c^VL0<o^X0020<S[V`1j0<GZVP31hiT0
dO2Z0<_SY@3?i:T0bmnT0<GKV`3Cj:<0_mF=0=?WW`3Fj9`0]LQi0<CIS03FkIl0cnJN0<WSW030gYP0
cN^S0<GPV`3AjZP0d>BW0>3^^@3Sl;/0cM^X0=CU[`3;hjL0a^2Q0<WRX@3IjJX0gNbY0;_FQ@2jg8H0
c_BQ0<GZW@2N^h<0PZ1^0;;GZ`1VTF<064XI0<Si^02dhIh0/MRI0<_Z[`1bRT`0Jh500<[PU`3HkZD0
hONf0=K[/03:hJ/0moo/0?3oh`3Cj:d0b=nI0::]L@3Bf:X0`[^a0?onnP3lo?@0jOkG0>CobP2miYX0
dOZ/0=7cY`36i9X0d^VQ0<WPV03Bj:00d^VQ0>?m]02hf8d0bNVN0=ok/02_bGl0a^2F0=?[X@3Sn[80
^M280=3UX02P]7D0Qi]N0>oob@3Yn/<0cM^P08nHH@3Xh/00m>gC09fTU03DjMH0`>C8097;V02RgYh0
boNR0<?TR`3IkJH0bmfO0;k?V`3gom@0nOoH0=?W[03=hj80c>^M0<[]V`32ji`0`^fN0<SZWP38jYd0
`nbM0<G/W@39jId0cnNM0<W[WP3VhJ40IV8R0<3YVP3;iI/0annG0<3_T`2njY40aNbM0<S]X039j:@;
0?ooo`002P3oool06@3loo/0oogo0?olo`3lo_l0moKo01=;BP2MeM80i_Wo0?oko`3llo@0o?oh0?om
m`3;a;h0iN3J0?olm@3oooP0o__b0?oom00>20005Pd009:6MP3ooO40oogh0?ooo`3nool00P3kool0
503iooX0m_oa0=;T_03<hjd0cNFW0<c[W@39kiP0a>ZG0<g_X`37gZH0b]^^0>G^d`3monh0oooj0?kj
m`3nnOd0oood0=GQ/`2?XV00W;1Y0P3<hYL0S02]`Wl0cN6V0>Gac@3non`0n__e0?[olP3Umll0d]Vj
00H1000A0000C3LV06=K;@3?cYD0cn6E0=3[WP31iId0cNRS08N6AP2<RTd0f]ZN0>KW[@3Ce9/0:RT0
08>2B@1MFb00LF/_05mG6@2CTe<0aMjJ0=_b[036fY<0^lb60=7QVP3MjZ@0c=VC0=KUX02R/fl0d^FS
0=?SXP3MhJ@0i=jT095gAP3=[X00kMFU07Y]>01HEah0bN2J0<OUV`2jghl0dO:Q08bMC`3Lk:40e>RS
0<oTX`3Bj[00a]fY0?Gog@3OlL/0eNG10?Woj03goml0fof`0<c/X03;ii`0d>ZP0<gUV`3AjIl0_]J<
09^eJ`2S_G<0foN/0;C@QP34i9/0anVM0<O/WP36j9/0c>NJ0<[OTP2iaWh0eN:L0=7XX039iil0anFM
08VOE`28W5D0cn2J0=_ZY@2HYF00U9mJ0<[PU`30g940`^NI0;gRU03;ii`0b^:H0<WMU@3=hiX0dNVO
0<_WW@3@kJX0d^Ve0>gndP3koml0jo_>0<o/Z@38jYh0bo2S0;;CSP3?jk00mooS0?Ool@3koo@0kOCT
0?_kk`3ooo@0g]_B0<72]01iPf00f>Rg0=;VY`3>iYP0dn>L09^SJ02PYg<0>S`G09:BMP3<a[P0h=W?
0;je/025NWH0oocf0?omn03oo?d0MFa]03H^;0060P00>3@Y071]GP1kN6T05A450P0600005P3no>l0
g>_:0;kP[P39kK00g=NE06Q;3`2h[GL0e]ZX08:CK`001P00;c@P0:N]W`3doO`0oOko00@000080@00
10400=CP/03Gjjh0gOfb0<W[W`38jJ820?l0000Q0<SW[03>i;H0amN`02dh600k@2T0Hf]D0>3Zd@3@
gL<0=TLW000:001ZOd@0fNna0<_RWP3=i9h0d>NO0<gUV`3Cjj40e>^S0=C[Y@3Ek:P0//B800D;000e
?A@0O8UM03Q:6P3Cj;00UJea000?003>jJH0e>fY0<oVX03>j9l0b^^J00@0o`0009l0Hg@n07b8F034
cIh0f^>d0=?K[01cMDh02`0005E@<`1bN4P0f>6X0=gVY@3GgId0o?k=0=SJ/P3kond0CEY900PA002U
Vh00OG9P00H000050@00mOoZ05ebB`003P00cNbV0;_NS03AmId0anR?0=KcW`3BiYl0f>NV096NJ03C
hk@0dNNf0<[R[P3;jJd0cN^]0<[ZZ@39jZD0e_Fa0>Oo`@3:iJ80an:M0<kYW03@iil0cNBP0<7EV03O
l;`0amRT0:NhPP3<gZ80c>>K0<[UV03>jiL0_^2:0=WkY`33h900cNRK0;?7PP2?Weh0g_6a0<KKV03@
jjH0bn^R0<?RU03@iiD0enfJ0<[VW035hid0cN^Q0<k[V`39hh`0eNjJ0;7?T@35ikD0^Mnj07j`N`1;
PDD0Z=NP0;?LY037jJd0`n6Q0<?LV03AijH0c^2^0>[kd@3honH0noo]0=KQ_`3Djid0N94f0=;TTP3o
olX0d<^h0?omm03ooo<0f^bj0;kMT@3>n:H0_^NH0<3UU`38jYd0a>>G0<[VV`3FlZL0c^fQ0<SWV`37
ii/0a>JI0<WZV@3>kId0bNJF0=ghZ`3IlJL0aMfC0=O]Y@3FjZD0cn:P0720@@2Q/G80cMjX0?cof01[
HT40mnW?09ZLQ03gonX0e?[C06N[LP0mPd@0^oF[0<;bZ03:ijL0bn>Y0>ood03gomX0m?oG0<_SY`3;
iZ40bnjN0<K]VP2ojYX0`^jO0<SZWP38jYd0`nbM0<G/W@3:jId0d>JM0<o_X`3Uh:00I60P0;_VUP39
j9`0aN^D0<K^UP38l9X0b^fM0<WYW@36iIT02`3oool000X0oooo00h0n?_d0?omo`3km_`0o?ko0>k]
o@0nMWL0DXf;0?7oo`3ll_d0ooco0?Cim@3oo_X0ZJ6N0?onn`80oogm00T0ookk0?ojm`0B2@808aT?
0<Bh[03oo?00ookh0?ono`3oool00P3nool0Q`3lool0nooh0?Woj03homl0bmf[0<oZY@35j9H0a^bI
0<CTV03@iJ`0dN>c0>gff@3lond0oooj0?ooo@3oo_l0oOob0<kJZP2;WeP083D00=?ZVP35gXd0dNNN
0;G:R@3FhkD0g^S50?kok`3/m]d0h?K50=WU`@3Bd[X04@0008abH`0g;000hn>W0=C[V`37i9@0g?Vf
0;oDT`3Mg9`0YJ=V0>CTZ03Jfil0fMZP05EF701WIRd0Ti5F0>_UZ@2HT580IVHV0<ONVP3BjJ<0dNFN
09:SG@3:fY<0dn2J0=gZY03Ei9l0d>6M0=3SX@3BhZ40d]RH0>WWZP3Sci`0onRf0>kHYP1_HRd0DDlF
0=kc[P35hiT0cONU0<?VU03Nk9l0R9Q=0=KZX`3Bij@0e^^`0<_R[03goml0mooS0?Koi03honX0l?oL
0=CfZ@3;jil0cNVN0=3ZX03Bj9l0bn6H0=[bZ025WE<0f?:X0<CPU@3>k:80bNVP0<SZWP35k9d0a^^M
0<gXV`3DjYl0^/N10=c[YP3BjJD0anBQ0<KQW03KjZL0c]ZH0=WTXP3Mj:H0UYaL09VVH03IkjH0a>2E
0<_`XP34iYT0bN>I0=S`YP36fY80e>ZQ0=S`YP3<ij80cNRa0=o`cP3`o^@0noo/0>_ieP38i:L0`nBM
0<?XV`35i:40an2W0?;ohP3hooH0nook0?conP020?oon00`0=SHcP3Nh=80nooS0<cOZ03BjJD0cNJE
0<gLU`3@fJ00GVHc01dQ00031P00JFMH00`8003Of=80jMoM0?olnP3oo?/0oogm08AoO01GDTh01000
059>@`1@CCh04@h005IC@P1BCch0fMK50?ook038gZd0b?2b0<3XX@3ThIX0GdP50:RPHP31bHd0eN^l
0<gI]@001@000P`006IaJ`000P001`0005U?AP3Ug/`0e^:b0<_QX`3:k:00`^NI103o00000`3Hk[l0
00/0000800020006000L00HA00001`0000T0000E0033fIT0enf]0=;YY@36gIL0cNBL0<oVWP3Aj:00
e^fU0=;YX`3Hkj/0Gg4c000700063`000a40000;00003@0000h0069k>P34gI/0dnZV0=K]Y`3?iYh0
c^JH0<gUV`80o`000:00dnR]0<OLX`00300000/0008D000030000@/005]>903[iKD0JFh^059I5@3F
fiP0f=RJ0?Scc@3IdkT0n__f065UJ0072@H0718000/0000600000`00061`E@003@0000h00=Cc[@3<
kid0_^::0<;SRP3<j9@0eNJP0=;PXP2GX740g>O70?OojP3aon80k_oI0?;ofP37i:`0bNRU0<WXY039
jJ00b^RP0<[YW@3?k9`0dNRT0<oTZ`3Nkl80nOoZ0?_ok@3Gi<H0dN2i0<WMWP3HkjL0dNnI0<?USP3:
k9D0`N6<0>Go[`1FJR80BelH0<_OVP3=hYd0d>jT0<k^X`36jIT0cNZJ0=7^WP3;k:D0b>RU0<cZX03?
jY/0d>F:0=S[TP2hchT0cNV_0<SU]`2fi[80FXmG01m?6`32k;X0c>ng0<_Z[`3Nm[X0c>6X0?Woh@3f
onD0nOo_0<oH``3Hhl40cnJH08jWC03Jk9X0dM^L0=cIaP3oooH0o?g_0=3R/036hYL0`^VH0<G^W`35
jY`0a^RK0<WYW@37iYX0bnZN0<o^XP3:jId0a>BH0<c/X035i9@0do>P0<KST`3:iIP0b^:H0<SPUP3D
jZ80bmnJ0<OKUP2R/W40PI5@0<?Q[`3]on00LG]H0>3Q_`2]]I00l_oL0=Ohb@2djk80CHA:0<?/]03@
k[X0a]nU0=C]/`3eomP0mOoJ0>_ocP37hJ80cNRQ0<OZV030j980aO2P0<[fY`32i9P0d?:U0;kWV03F
njd0c>RM0=7UW@3>kJ40j^:S061L7035lZ40c>bP0<_ZVP33i9<0anRI0<WXW039iI/0c>JM2`3oool0
00X0oooo0;D0o?od0?ommP3oo_/0n?_o0?gmo`1f/J/0T/o80>goo`3onol0oogo0?SooP3kmo@0f=3>
0<[1`P3oo?l0ooSk0?ojn`3onOX05``:08b1O@3hkNL0oogd0?oomP3oo_/0ooko0?omo`3oo?l0oO_o
0?ooo`3loo40nooX0=GT_@3=hZX0a^BL0;_IS`39i9l0n?oD0?;od`1@ESX0ZJbI0?oon03oood0o_go
0?_ol@3Ji[H0g^nY0<kSV03Mm:80e>fI0<_TT@37gi40@eDG04eL9@34cjD0cmn`0=3ZZ`3DikT0EUm0
00h0000T2P00Kf@f0=[PX03;jiH0d>nO0<cEWP2EWVL0cNNM0<KPU`2G[VX0dnRU0<WNW@3Ik:`0bMbL
0<WLVP3GjjH0h_J^0=SYX`2<V5P0jOFc0<?BS@38fI<0d^>L0<cMUP2JZf@0enRR0;g>RP3QlK00GFhZ
0=cYX`3Oj:D0FE@J061G7P2UW6D0j^>/0>g//`3Yn[H0c>JO0<K_X039jih0eN:J05UV7P3Bhid0c^>N
0<_QX@3BjZ`0eNjg0>kod`3domh0f^c60=[``@38kIl0bn^O0<gWW@3@j9h0d^JN0=?WW`1LLRT0bn>I
0<WSV@3:iY/0c>ZP0<cWX039jIh0aNbM0<K[V`3<j9/0dNNN0<?BT@3KjJ`0c^6Y0<WPZP3?i:/0kORf
0;k9Q`18DA00io2_0:6VIP2IZV<0f_BZ0<g/X039kZ00`^BG0=WaY`32eXh0amRA0<cPV03<i9X0bN>R
0>;gcP3iooH0nook0?_oo03[m^D0c>Nb0<CTX@33iI/0eo6d0=c_`@3koo<0noom0?koo`3oool0ookk
0?omo@3oooX0oOob0?Woh`3@i:l0aN2K0<o[WP3DiZX0d]j^0?3lc03kom`0nooO0?koiP3dn^00oooc
0;2]Y00=1@<0mO3]00<0oooj01L0K6UT0>3Ke`3elNP0oooc0?ooj03oonH0dmVe0=WR]@3:iIh0a_:S
0;cYV03Nh9L0VXE40:ZWI03Gi9h0`]nM0<oQY`3KjKH0eNJi0?Cok@3lonl0ooO^08imL`020?l00003
0=?Z/P37kJ@0anfP00@0o`000<<0`M^B0=W^Z`3Ol[80eN>X08nMHP3Bi:P0bn6S0<;LV`3NnKH0f_6]
0<_RWP3RnK<0T:MQ0<oVWP12FA40FG0X0<_RW03<hid0dnZT0=3SX`3HhJ`0f^B_0=KU[036fYl0dnVY
0<oXY`36hI`0aN2I0<gWX02fcHD0Fg4X0;g;P03>gYL0f^jY0=;WY03>iZP0an6R0=C^/@3=jJ`0foFf
0<_UYP38hIl0e^VJ0<?IQ`3CjiD0aM^60=oWWP13?`80WXU/0::8N@3een<0ooGo0?ofo`3ml^00Rgma
0::KU@3mn_D0c^>h0<SP[P38i:X0d?2W0;SKR`3:kIT0e?6O0=kfZP3Ql:l0VJ=W0<W>YP3=dL80nooh
0?SolP3honH0mooQ0<?IZ03:ijL0b^RR0<WZV`39jYT0bNZK0<kYXP3Ll;d0m?oO0?Wol@3jool0o?ko
0?coo`3looX0XZj:0??odP3Pmk40doBU0<c^VP3Cl:00b^FF09FZG`3<gY@0h?B/0=W_YP38i9T0eOFY
0;OKT`37jjh0`nV^0<;/XP35kid0bn^F0=7XV03TkZT0d=ND09>NF@3;gI<0foBS0;[WY03=ol80^nJa
09:iRP2:ZW/0b^Jf0<7DY`3Ei;/0mocU0?ool`3oooP0o_od0?_ojP3EjJh0c>>M0=OYZ`3lomP0PX9f
0?7^j@3oooP0dN6l0<CMYP3=kJ@0c>jR0<[ZW`36iY/0`MnE0<KRV03:iY`0c>RN0<[VW03BkZ@0e?2V
0=;_W`39i9<0a^6B0=?[W`36gID0d^VQ0=;WXP34fI@0dNJQ0<gQVP3?hi`0c^:m0?Gok@26U7<0KWQC
08RDIP3<g:d0fo700<;S]03;l/D0MZ9n0=3lf`2ni:T0a>NU0<_X[P39iZ`0an>X0<GSW@3AkJ80`N>=
0;oSS035jY`0`nVN0;cJT03Gmj/0`nRJ0=CcY`3Vo;<0gnbV0<oYW`3aijT0WIQH0;KSTP38jYd0_]>>
0=KZY@2mdH`0Ef`W0:c1O03Cj:<02`3oool000X0oooo00h0o?od0?ommP3ooo/0mO[m0?[mo`2Acl80
=gMY0>koo`3hloL0noWj0?Son`3ooo/0n_7b0=G<c@80oocm06/0oock0?3Vi@080000h=GC0?oln03o
m^l0ooof0?onn`3ooOd0ooco0?oko`3oo_l0ooom0?7ii03boml0e>Fk0<gT[03:iJ80`=VG0=W_/@3Y
mlH0/[fC0=CH_`3mond0oooh0?Wim`3nool0o_of0<WDZ@3Okjh0aMVB09jeI`2<YE80d>VF0<gUU`3E
jZD0eNNY09>OK@2b`h`0_mZE0=O^^P36e;4050H003LO4`2DS5d0fnBQ0<CXT03;jYX0`/2?09:DHP36
kIh0b^nR08j^I@3=j:<0bnBR0<;HU`3Qn;@0f?>/0<kZX03<k:00`]bC04=72P1cNCT0hNjY0=SYX`3S
mjl0bn6H0<SNU@2DZV80AUXE0=;RX@1[NSL0e>BM0=SUX01DFAT0P8550=cKXP3FeI`0gN6V0<_JU`3@
ij40`NRI0<[/W`3IiZ40AU<>0=7UWP3Bj:00an2L0<oZY`3:i:L0goRo0>Gmb@3>i;D0cnRa0<kcY@33
iIP0e>jT0=?YX03AhY/0cn2I0<gQV@3=hiX0eNfS0<3LT@3ElJH0c>NP0<[XWP020<K[V`1A0<[YW@3F
k:@0amFH0=[U[@3Bi;80cN2b0<kR[`35e940j?Bb0:FaK`1kQT@0]Kim0724?02ofi00a>BH0<c^X@37
ii/0enfT0<?DS@2]_GH0a]ZB0=cdZP3<iZD0g_740?_om03io_P0o?oo0?_om03?ik<0b>NT0<WXY03X
olX0k_kI0?konP3nool0oooo0?ono`3oo_d0oogm0?kmn@3koO80kooK0<oV/P38iJ80b^VM0=?X/03b
omD0enNh0<7CX@2hbYP0amJ[0<gI/`3ZkmT0nO_]08F0O01=BTD0OGmd0?7dj`3oooX0QH600?chm`3l
mo<0o?[^0?coi03`m]80j?;00<kLX@3;iiX0a?BP0;k[VP3JfiT0/YaR0;NfM@3?gYT0eOF/0<cRX@3A
hjL0ho_10=Sab@3Cg[h0ooc_00H0o`000<L0c>NP0?l0003o0000b^bE0<oZV@3Mm:H0a=V>08bKEP1g
R480d>JN0<[RV03Em:H0_=R=0=K]Y`3;hY`0fO2Z09J]I`3Qn;00/<Mo086HD02<Xed0MXe70<_RW038
gIX0h^fc0<gKX03?hJ<0en^/0=G^[034gi`0dNbU0<o[X@3=iih0d^VQ0:>iL02IYe`0TZ9K08bPF`2;
X5d0VK=b0;oIV038hZ<0`]bK0;;<R`3:hj40cNNP0=_kZ033iHl0b^bE0;WGP@3Kiid0jnV/06QA;`1Q
ABl0_j2M0?oVj`3ok>d0oog]09^?P`3LeLd0ooof0<oV/035gZ@0b>FU0<CTV`2nh9<0c^nP0;kJS@3H
l:H0d=bN08fEG03all/0g=o<0?com03]m^40nOoT0?Sog@3?hk00c>NT0<cWX039jY/0bNZI0<WYW@3=
ijP0iOG>0?Ooj03koo@0n?_o0?gmo`3dm?`0j>[Y0>C/e@2JYH<0b=^T0;oMU`3;jY`0bNFH0<_SV@36
ei00eNJO0<CHT030eXd0e?2U0;kMT@3=lJ/0b^fe0<;Y/P31jil0aNnI0<k[U`3CjY`0emfQ0;ZmQP2d
_g/0dnJG0=SbU`36l:@0^^NT0<S_^02XbIX0A5ld03eD:P3Hil00fN?00?_mj03ooo<0lnkX0?[nk@3k
onP0]/ZE0=3XZP3Gj[<0looE0<[=_03oooH0o_od0=?T`P3:h[80a>6N0;cJT030gY@0f_J/0=KbZ03B
k:<0e_2W0=O^YP3<hi/0b=nG0<kUW@35gHl0fO:Q0<GMT@2L]6X0Mhi609>ZI01JKbX0dnRS0;[?RP34
fY40eN^R0=OM^`3oon/0o_oV00`F003fomT0d=^a0=_W_`3So=D0^=Ze03U_B`2Sh;h0a?:d0<[_ZP36
iZL0anNX0<cZZP3<jZ80bNFH0<SYTP3>kYT0d?2T0<CVW03>jZ00anJJ0=;dY`2lf8d0eNVQ0=CNV@37
gI@0gM:D08R3@`31kYd0f?R/0=g^ZP3HijH0]<B30<?FU03AiZ40cnJP00/0oooo000:0?ooo`030?Wo
l`3oooX0oook0080nooo01@0ZN[F00iB>`3UooD0oooh0>SZg`3]nnX0oook0?omo@3Ugml0ookk0?ok
n03iknd0XiVG04Dk>@3_iN<0ooOe0?omnP3oooP0oook0?ono`80oogo0600ooom0?comP3HiLL0f^c2
0<[Q[@3<iZL0b>2R0<cPY@3iom@0VjIk0=kV`@3monP0ooo^0?Kgl@3nood0o_oo0?Cjl03Rk<L0]LB;
0>Kh^P39giL0Tj]O0<oZV`3=j9T0bn6I0=3SX@3Kj[40YKMi0>Oo^@2hdIP0c]ji00/1000A0000Ui=S
0=;OVP33jXl0bNVF0;:UN02NV6P0boRW0<7/W@1kVe80S:MP0=7XY038gIX0g?6^0;SCS03=kJ80`>NH
0=?_Y018AP/0];Af0;O4O`3MkZP0bn6H0=7[X@3MnJh0b=nG0=[_ZP1gQTD0fNRU0<[LTP3@hIX0d]jL
0=;MV`2CW5d0YJ]]0=?LW@3;fYL0c>>M0<CVV@38j9d0en>S04QD4P3AiIh0eN^S0<[TV`3:iIh0b^NT
0<o/[03AkK00cNJ]0<WUZ03=lZ@0_^2C0=3ZX039giH0eNFN0;G5OP39gID0dNNN0<cTVP3>jYl0c>RM
0<gWX03<j9h20<K[V`1A0<[YW@3?i9l0aM2H0=GOZ`3Yn<d0i_K?0>CgbP3PmK80b]fK0<oRX03JjZT0
QIAC08FKDP2ngI40aNFI0<[/W`39jId0cN>J0=CUWP3:fY<0e>FN0=7WWP3BkJP0gNnk0?Cih`3nooD0
n_cg0?_olP3<i;00bNRU0<gZZP3eom`0nOoZ0?ooo`3oo_l0oooo0?ono`3ooOd0oogo0?ono03nooP0
h>o@0<_Q/P38iZH0`n:L0;oEY03fom`0l?oC0=_c^@3Bk:d0dNJ]0=OY]@3kon@0o?o/0?;bj02UYYh0
J6mO0?comP3fnO80MgEh0?ono`3oo_d0oooh0?ooiP3Fgk@0d=jQ0<WJU03<jIT0`o:Q0<?_X03Gf9h0
]9i/0:ZZKP3Ci:00co6U0<OQV03BjJ<0an:O0<cY/@3Ag[<0ooc/00L0o`0004l0cNRK0<W]T`3o0000
o`000<GLRP3>hi@0SImE0=k`YP3<i9P0d>^L0;gMRP3=k9`0b^6I0=_bZP18GaL0e^fU0;kES`3@ij40
b^6K0<3GT@3;hY`0OIA<09FZI@39eIL0cM^M0<gPWP3Jkj`0bnJO0=?^Y`2lfY00c^fQ0<gYWP3=iid0
eNfQ0=CVVP3Dj:00enjX0<SQW@2`bhP0M8m<0<cRXP3DjZT0d>FT0=7QX03>hj00`NNN0;GNTP3BnJX0
c_6Q0<?ER`3LhIl0f<ZI0=O4V@2MRFP0NVM906YI?`30/j<0ZIfA0?oom03gn>X0cnRV0<oZY@3@kZP0
c>bQ0<o_Y03:jYh0b^BK0<cQW02<UUX0i>bc0>[[`@3oonD0o_oY0=[Q`P34cjD0enFb0=c^]03?iZ00
c>RM0080bNZI00H0bNVP0=cb`@3honP0nOo]0?_ol`3nood20?ooo`1]0?oon`3ooo@0o?o]0>;`c03=
ijX0_mfE0<;MUP3JlJT0_/n908ZIE03NkjT0d>BM0=C^Y@3<jZ00`^>N0<SZ[P31i:X0`^RM0<?ZU`39
iIP0d^JO07V0C02g^hP0ho:_0<3GQ`3Poj40_nNA0<G[WP3;kK00f_S402Ln500<7P00G6I309RNO02S
XH`0Y9j@0;^bZ`3@ekP0fNRo0:g4SP3Ek[@0am^V0=3P/`3Sj//0Be0i0??lh@3gon<0h_W;0=Ob[`3?
jJ80b>:K0=?]YP3<iYl0`MRB0<gTWP3Bij80e>VT0=[_ZP39gIP0LHPj07fDA02L/VL0`mV@0=GZY@3=
hYl0f_6]0727@@2>YEl0ennU0=?[X@2f[8T0aK>M0;BcU`1GG3h0j>kB0?SnhP3monP0moo/0=?`dP14
Q5l0=hQM0;K]Z@2ojIl0_>6L0<CTX`3=k:T0b>NK0<OTTP3@kYP0c^bF0<7MTP31giT0f_B[0<7MTP35
iIT0d^bR0<oPV@1nQD40EFTQ0>7CUP1KDa@0`^nN0<?SU`3AhYh0`]6>08bMF@3Kl:/0c>>K0<WSVP0;
0?ooo`002P3oool04@3kool0oooo0?kno`3gooh0loci09gR``00?aX0aNS:0=CJ_P3Fh;h0m?oV0?co
n03oo_d0d/k;0?oomP3oo_@0ookc0080o`0000H0e<c90?S`kP3ooOd0ooom0?koo`3oool20?koo`1P
0?_om03iond0b>2/0<SXY`3:kj80c>nO0<SKX`3homH0eMbb0>?Wa03Qi<D0iNOB0?cmk@3oooX0o_om
0?coo`3eo?D0o?o/0;g9X@3Hj;T0RZ1R0:g3PP33gI@0iOne0=W`Z03DjJ@0]lZ:0;K:Q@2nfHP0h?bo
0<WP]00;1`00>b/L09NGH`3GjIl0boNH0<?PT01dES80WhIN0;oTU03?kZ80h>bZ0:6WI`1_Kc<0UY5G
0=SFV`2AW5X0bmbF0;gIS03<h9P0VX]D05A;403Eh9`0a]ZC0<oYW`3CmJP0_n6D0<[VW03@iJ00d=bL
0;:nO03RmjX0c>BH0<_UW03DkZL0^Lb:03i=303JiZH0^lZ70=GYXP2ogY80bnJO0=7LXP2N[6l0d>FP
0<[QV@38i9L0bNRH0<_/W@36iYX0a^JK0<cZXP37iih0b^nQ0<SZW@3<i9X0d>BL09FUGP1oS4H0i_N`
0=?WW`3JlZP0aNBH0=7]XP3@iYh0cNNM0P38ji/0DP3<ij00dNJU0=7KZ@3Gg[@0n_oT0?Soj`3don<0
c>fV0=Sg/@2ogYP0gofg0;gKU@3<iY`0bNRL0<KXV`37jI`0c^jR0=CXX03=gYL0f^NQ0:FfK`34fY40
c>JL0<oPV@3Khk@0kO3A0?ook`3non`0b^:X0<kYYP3:hZP0n?oT0?comP3onol0oogo0?ono@3oo_/0
oogm0?omo`3ln_/0n?[e0=g]dP3Om/`0anJ[0<_[ZP3;iKP0l_oM0<3MY@3;kJ40c>nM0<7SS`3NoK40
ioc40>ckdP3Zl]/0j?3K0?7mi@2c_Zh0nooj07IeO@3oo?l0n?Gl0?oon`3non<0^LNB0<gRT`39gh`0
bnNJ0;kZW@38lJd0g=Za09=lG02UY7H0d^BZ0<?YW03GmZP0anJF0<g`WP2kh9<0c^2V0?oliP1OA3T6
0?l000030=?WX03o0000o`000080o`000<40UJQX0=g][`3o0000o`000<gVY@3Hmk<0_]jE0=cdZ030
f8h0f>nW0<WPV033fY@0e>^U0<kUW`38giT0a]fG0>co^`37gID0TJ1K0:NhLP2fc8@0_MF;0<OSV03C
lZH0/]>40;gNS`3>kIl0c^ZM0<[WU`3=kYd0bn^O0=;bZ@3<k:<0aN2K0<OPW02DXf80Phe>08jDE03=
cHd0i>VW0<_TXP39iZ<0b^jT0<S/XP3:iY`0f>jU0=[ZX`2AXEX0_]B;0=?[X@3Ljk00a[JY0<2bY`3o
oN`0ooo/0=?_VP3Bki/0anND0<WYW@3Gmjh0eOB^0;_DT`3Pm;L0PHYC03]02P1UIC<0IFLe0:6ULP2I
XFP0fN>T0=OSX@3FiYl0d>JK0<oWV@3:jI/0bNZK0<[VZ@3Rl]L0nooc0?Cmj03Vk]H0gN310>3Q`@3l
o>80ooo]0?kjm`3gmOP0U9VB0;;7W03GlK80d>RZ0;_?T036e9H0fnNW08ZIEP1HJBD0iojh0<ORV`36
iIT0c^^I0<o_W03Uokl0g_Zo0<kR[`3Ei[80Qi9F07b8AP38hYP0`n>G0<?/WP3=lI40a^J50<_WW03>
i:H0:3L<01<M000B5P0010<00>7F`03ol^40_jnP0=gWZP3CjY`0c^ZM0:G4N035hIL0enjV0<[KU@3D
hj00/lB00=3YY`3Gm;80`=FB0=_^[02X_GX0MHQ608JIE`2>XEl0bmjL0:JfM@1dPd80Pi9A0;W5Q@33
eH/0dnFI0=;VWP3Dj:40d>FR0=[_[P3Xo[d0cnRT0<CNU`37hiP0c>RK0>WX/P3He:L0mOoT09:_T@3M
k>D0o_oo0??Rk03omod0o?7]0<;/b02^l[l0ZN:E0;o^W@30jYh0_>:I0<KXWP3HmJD0cn^G0=cdWP3H
l9`0c^BK0=kc/P3;hIT0ennU0;OCR024VU40T9eG0>_^Z`3Chi`0ckb107]`<P35l:00d_:V0=[^YP2=
WUL0T:IM0=K`YP37iYP0anZJ00/0oooo000:0?ooo`0@0?coo`3oool0o_oo0?Woo`3iood0gOoa00e:
8@1AO5h0fn_40<cL[@3>i;H0i^oJ0?oon02ZYIl0ookh0?omm`@0o`0000<0oocm0?Who@3nool0103n
ool0GP3hoo40mooZ0<SP[039j:D0c?6S0<OXV@3<fJ<0oooL04Q?9@3Li;/0`<RQ0>C[bP3nonH0o_o]
0?WokP3koo<0n?o^0?[ojP3Hi<00RYM/0<GIWP3OmKD0d^VU0<WPW03BiZL0bM^O0=GT[@2>WUl0fo:T
0;oIW03Bi;X02@4000l0002HU6D0f>NR0<G`UP2ofhh0LE4Z0;>GK`3;kJ00e_FY0=GTX@3OiJD0RX]?
0>[UZ`3Jf9d0EUlN0=KSWP3IlJL0e>FN09F;D01ME1T0gmnO0=?LV@3LkJL0c>RN0<WSVP39gIP0g^n[
0<_KVP3MkZX0c^BI0<cWVP33hiP0bn^P0<cSW`1<FaX0DedN0=KQW`3GiZ<0bnFL0=7/Y@3AiJH0bmjN
0=CUX@37f940`mjA0<c[V`33jIH0a^^K0<_]X03<j9h0b^JL0<W^X032hYH0bn6H0=W]Y@1@H1T0TJ9K
0=;XW`3?iid0_mV?0=?bYP38i9T20=7UWP0V0<[YV`39jY/0cnJN0<gKW@3DfZX0e=^a0?GogP3gonH0
mooS0<?SXP32hYl0b^^T0<OYW`3AljH0e>bP0<kZW@3>kZ80b^bO0<c/X@3?iYh0dnNP0<kOV@16FQD0
X[Mb0=3XWP3Fj9`0eN2V0=SQ/P3kon<0nOoQ0<gWZP3@kJ/0b=nY0?WoiP3nooH0oo_o0?omo`3oo_d2
0?onn`0_0?omo@3oo_l0nO_f0?Sok`3eon@0cNRe0<[V[03AiL00mOoV0=[a``35iI`0aNRD0=3bW02n
gHl0cNB`0<SF/P3Hh<T0dMW40<oH``22RWd0k_G^08R9SP3/k?@0o_om0>[^h03HiKT0@U@H0=W`WP3A
ii@0c>NJ0;gVVP39l:d0gN2c08=cC`2CTF40f^V`0;KLS`3;kJ00aNBD0<c]W03Emj/0`]RH0=S;Z028
LUX0VhAd0?ook03fonP00P3o00000`3EiJ@0b]jI0?l000030?l0000304aP8`3o0000o`000080o`00
0;`0b^^V0<SWX@3@j9`0aMfC0<gWWP3?jJ00eo6X0<GOV03AkJ<0c>JM0=Wc[02je8/0dnfS0<KLT`3J
l:L0_]J<0:S0MP3BjZ00`]bB0=3ZX03Bk:80dn^Q0<oWW@3EkJ40cnjP0<_ZWP3:jYl0b>RO0=3^YP33
gIH0`]>?0=;NW03IhYl0VYeJ0=kSX@3GjZP0a]fI0<[ZX@31hiT0`^2F0<CKT`3;giL0RImF0=[iZ`37
jYX0b>>P0?oih@3oonT0oOcX0?ook03@k9P0bNJB0<[ZU@3>kj00a^JJ0;oOUP3Hl[40`]RH0?Goa`3b
oL40en6T0=?MWP3FhZ80c]ZH05AS7P15E@h0V:UR0=7VV`3@iY/0cnNK0<gXV`3?i:/0k?OV0?_omP3k
on`0k?SD0<oHZ`3Ih;@0oooV0?ookP3onoX0oogo0=cOf03@g[X0c]n[0<[KY`3KikD0g^Jg0=7IZP3T
k;/0c]ZZ0;G6TP2IZgL0eN^]0<cRV@3Djid0loo=0>Sob`3;gJd0d>6]0=OVY@2?X5T0bnJI0=GeZP36
k:<0aNN90<o_SP35hiT0f?2d07R1DP0P9@00TI9`07MjG`3Be/D0j_7Q0?kol`2b^Wh0c=Z=0=C_WP2<
Y5H0f>RM0=?UV@3>ji/0bNRH08j]G`3?iYh0dnRU0=gX[03Fh:@0VZ]W0;_AR@3Sn[80aMnF0=G/Z03F
jjX0b]fM0=CUX@3Gj:80eNZM0=;YV`3@iYh0eNZW0<oTZ@3Qm[/0l_o>0<_SY@36gih0c>JM0<STV@3E
gj80e]nX0>Wog01cTGD0l?ol0?kno`3on?l0oo3i0?ojnP38hL<0[mjb05F9B@28]g<0cO:_0<c[Z03;
iZ40b^6C0=;ZUP3=iHl0TZYF061f;@2jcH/0eNVR0<kTV`1@JR00[LEk0=_/Y@3FgIT0enJQ0?OX[`1[
HBH0anJP0=C]Z`3Ej:P0RiiN0=?XY@3>j9l0an>H0<WZV@/0oooo000:0?ooo`030?ool`3oood0o_oo
0080o?oo00/0oooM0<;K/`2TiLl0_nR`0<gWX03?i:<0`mRO0??ff@3MelT0noGi0?_lo`040?l00003
0?__l`3gool0n?_o0080ooko0P3ooOl0CP3ooo/0o_od0;C2WP3Nl<00e^^b0<3BU03Shk40/[R80>on
a`38iJD0a>>O0=C^Y`3=hYd0e^NS0<OHU02=XE`0enV_0?_oh`3lon40n_oG0<SKV`39g9X0e>JZ0<KG
X@3loml0k_GC0=[O_`3Pikh0TYiN0;g;UP3QjL807``002L7000g9`D0c=6K0=?i[03;jIl0MV8_0;2P
K032kZ40_^RL0=7cZ@3<k:<0`]fF0=W^Z@3;h9/0TjQS0=CYY039h9X0cNBN0=KUX02BTE40J5DM05E4
301]Ib/0gMjR0=[JWP1ECQL0WYeT0<_/Y`3:kZH0c^BK0<SWV`3=ljH0c?:U0<kUW@3Lj:H0dMJF06m_
<@3>e9H0e>VV0<CTV`2gh940f?:X0<g@S@1XIbH0g^^U0<cXW@80_njM03<0aNbM0=?TW@3Ci9d0co6T
0<gYWP3HjJ80e^JO0<_QV03=iid0b>ZM0<K[W@38jYd0b^VM0<gWWP3Jj:X0d]NG05=V5`1DKah0Cf0I
00T7003=aYP0dmJW0<_R[034dYd0i_;20?Coh`3domd0cnj[0<OYW@3AmId0dNJI0=C/X03?jYd0a>2E
0<_YW`38ij40a^BN0<KQWP3Ll[80a]ZK08nOGP3AhiT0a]bA0<[TV`32iZ00anbV0<O/Y`3<kjl0bn6c
0?_oj03noo400`3oo_l0=P3oood0oooj0?onn`3ooOh0ooko0?kon03jo^d0fnC90?Koh03moO40ooom
0?Skl03@h[80c^RQ0=7]X03>j:L0m_o]0?Som@3noo00ooo`0?oonP0610L00@840=cSg03ioo@0cMne
0<gRZP3Djj<0@eT@0=CZX@37gI@0cN>J0<c/X@32iiX0eNZU0<c@T`2NVEl0gN6T0<SZX032j9/0an>H
0<kUW`3@k:l0a>RN0=?MU02DSdl0KUh]0?goi`3goo80n_gb0?ook@3Skkd0e>RY0=c]Z@80o`0000<0
b>6M0<oZY@3o00000`3o00001036k9T0bNZI0=?YX03BjZ020?l000190<GWVP3?lJ@0_N:D0<caX`3I
njh0^]b?0<CVV@2hgHd0c>fN0;K@QP3Fk:<0bmRC08NBD01MHbD0Be4C075g>`3?ei/0joFf0=WYXP3J
jj@0bn6H0<[TVP39j9`0anNK0<GTV03FmJT0go^`0=7[X@38gYD0B5@B0<OHU037hIX0/lj70<ONV03>
gi/0en>Q0<3?S03Il:X0_mZC0<GSW@3Bk:l0ho[60?_ok03koo<0aMnN0<CRV038iiT0a^N@0<[/UP3;
kIT0b^ZQ0<OVX036iYd0a^JK0<GVU`34i9P0a^JM0<[ZX@39i9l0d>VW0<SNW@3;fi`0a]BF0>Wb/`3?
eIL0cm:W0>o^k03ioo<0m_oP0>3m_@3;iZ<0c>>]0?Ojk`020?ono`1[0?oon02Y[8l0XZ>10?oohP3l
nml0oooZ0?gjl`3oo_/0o?Si0?ono`3kn_P0oook0>o_h`2_/YL0XZJ50?kog`3Mj;h0g^nk0<gPZ03P
m[H0cnJR0>3f[P10EPd0d^NL0<gUU`36iYX0b_Bd0<CXZ`0b=@0050d008j>K03JkMT0BH5h04:4NP3?
ool0B4DT0?KY_@1JJbL0Ff4K0>KGU03WhYh0Z]nA0;cj[@32n[40SiYN03@c001QEBd0He``0;c=QP3?
jiL0`^ZA0<oiY@3:jZL0bNNY0<STY`39jIh0aNRD0<O[U036jIL0bNZU0=;`]03/omD0looP0?Goh@3g
om`0f>bg0;[?S03@iYh0a^2G0<kXY`3hon@0MX9^0?3dm@3hnOd0ooko0?oonP3oooH0o_oa0>cch@2M
_Jh0DWMV04EH?03Ghk/0hn^h0=WUW@3Ej9L0]m=l09FcG@3Hl:H0d^NR0<OKU035fi<0aMnE0<[ZWP37
ii/0d>NO0=3OWP37bY<0FETW05=F:`1mPUT0f^S50?;ogP3[nMD0d>2_0=?T[P3>h:802`3oool000X0
oooo00<0oood0?ooo`3no_l00P3lool0303oon40_MFa0;cmj@2kiZh0b^JL0<kUW@3?j:L0kO7>0=cG
``3oo_l0o_oo0?onn`80o`0000@0h/[60?ohlP3cooT0lOOc0P3nool0@@3in?h0noWn0?Wjm@3enN/0
nooT0?WofP38fj<0enNX0;:eP034cIP0h_Bj0;oNVP37iZ00b>>L0=7XX031dX`0W:eY0;O:R03Jk;80
bmF`0>ojd03bol/0gO6/0=oe[@3Dj:T0JGe205IV>@3komd0o_oO0=GQ/`2Z_G/0hoJo0<OCZ`0F2@00
500009ZAJP3TkkL0a>nO0<;TU`1[GRT0ShI?0<WbYP30iY/0c>bS0=CbZP3Fl:T0bn2K0=;WXP2I[VT0
c>6L0=C[Y@3;iIh0b=jF0;k3P@1JD1D0HEPM0:Z_K`3Nj:T0e]nP09BBF@1<D1D0`^>N0<CXX03AjIl0
c^fQ0080_NJH00d0b^JL0<WJUP3Sk:/0WZAT0=CNW`37h9`0d?2W0;[QTP3DkZ@0hnJS04U:203DhI/0
c>RM0080`NjM03<0aNbM0=?TW@3AiId0bnfP0<;NT`3`okX0]<Am0=S^Y@3=iid0b>ZM0<K[W@38jYd0
b^VM0<gWX03BhJH0gN>U0<cQU032gH`0dNJK0=[HV`1[Hc80d]BR0<gRY`3@gZ<0d]j/0?Goj`3Ol<h0
d>Rd0<gZZP3<k:00a=ZB0=3XWP3Bk:80a>2C0=3_X@3Al:@0c>^O0<_WW@3:hI/0d^NR0:joN`29VU<0
konm0<CNU`2kgiL0d?J]0<S^Y@3:kJT0bn6b0?[oi@3lonl00P3oo_l04`3oood0oook0?onn`3oo_d0
oogo0?ono`3nool0o?of0>S_g`3lond0oood0?oon`3looH0c^6c0<[SW`3>jZ00cNNZ0?Sol@3iooX0
0P3ooo@09`3mn_D04Q0A01/M6P2e_K00i?3J0=;V]@3Cj:d0Ni=908nUG03IkjL0dnVQ0<kXWP3>l:@0
_nBG0=o`[03>cY80ViEK0=kOX`3:jZ40`^RK0<CSU`3=ij00cNZW0<GZW@3Ji9/0YImQ06]J;03oonl0
nOoj0?[ln`3oo_P0hno;0<[L[039fIX0TjIV0<SOV`3On;@0c^VR0<WYWP020?l00080a^^M00<0bNVM
0<oUW03o00000`3o00001P39jih0b^bO0<SZW@36iYX0cNfQ0=Sh[080o`0000X0d>bQ0<KNU03PlJ/0
e^FR0=kZZP3?fi/0c=RH09ZXJP27UUD0c]jG0P3o0000X@3;iI/0eOBX0=3`Y02mg900fOR/0:k:O`3G
lJL0dnVP0=KUXP2K[fX0SjYS0<kYXP3Il:X0d^>O0=GQW`2;UeD0dNJQ0=G_Z03>jJ@0d^^a0>?ib03i
on`0n_oc0<STY`37iIl0bNRL0<GUT03;jiP0c>^K0<_XY@38iJD0b^JY0<cXZ`3:iZT0bNB_0<OR[@3A
j[<0an2O0=3YY`3?iZ80d^:Q0=SVZ@2nai80WjIc0?ooh@3hmo80nOo/0?7oeP3Oo;X0c>JU0<_R[P3e
n>d0oO_n0?_gmP3ooo@0Yjn:0;:kSP3Sk;l0j_;;0?goh`3go>H0o_oa0?comP3loo@0n_oa0?col@3Q
i]00cm6k0=CF_P3nonP0n_oT0>gke`36ejd0dnFc0=GX/@3:g9h0//F308VJEP3Ejj<0eo>Y0<?[XP3C
mk40<C4000d2002NWWX0c>:n082iV@0[KE40Sm2h07AaD02RTfP0^lZ907R3?P3FeXh0g>BK0=Cl/`2o
kJD0_>FQ0<3@TP2T[740XIm_0;JfQ03JkZH0d^nM0<?YUP34jI`0b>BZ0<_T[@3;i:/0anNL0<G[UP3:
kIT0b>^K0<WZY@3=jjd0gOG30>7ib@3Tn//0i_[50<oTZ`23V5<0_M>:0=;/X`31fiX0n?oT08bHQ03l
ool0oOko0?cko`3ooo/0o?ge0?kol`3jo^l0gO;Y09F_YP2L[YH0SYii0<[JZ@3>giT0d>FH0::kJP31
g8d0f_6Y0<CKU`3Kl:/0eNbT0<kZW`38jYd0a^RK0=?ZXP3Hij@0j>fc04Q;5P2i_hl0kOG60?Soj`3h
oo40lOgW0>Sbe`3ZmMD0io??00/0oooo000:0?ooo`1/0?oon03oool0o_ko0?cno`3kool0n?cQ0=?/
cP1o`k@0_nnc0<k_WP3AkiT0^mN=0=kS^P3oon<0l>cY0?koo`3oo_d0oocf03`P4P3Ob[D0oooS0?Go
i03fon80logT0?Onk03ooo/0ooko0?ooo@3oooL0oooX0>gec01^N4H0bMFG0=?MX@3>hJ40cnZU0<_`
X`3:kj80eOBX0<7KT@2R/fd0U:EQ0=W/ZP3>h:@0cm^]0=;N[03;fYl0dnVN0;;:O03Ajj80b^>O0=G]
/@3JkkH0PiML07jDE038ij40`n6U0<[Q/`0E5`001`400=[R/`3>iZP0a_JR0<SaXP2]/gL0f=jR0<o_
YP3:j:00bnJO0=3ZX`3BjJ<0e^fW0<SOV@3:i9d0]Ln80<WTW@37iId0c>ZP0=;SW@3UkZd0dn:O0<cW
X02mgYL0eO2[0<O?T`1AFAd0`]fJ0<GTWP3;hiT0`^6E0<K/W`3=ljH0b>JL0=;YX`3EiZ80J7Ld065a
<03<ij80_mnF0<caX`39hiT0fN2L04Q=2P3MkJH0c>RM0<?/W@32kId0a^^M0P3@iYd0G03=kj80bNFJ
09JWH01oSdP0aM^B0<gWW@38jYd0a^^M0<SZW@3:jId0c>NP0=S]/P1UKc80b^:H0=3_X@3Bj:00e=:G
0<o5U02i^HD0ZKen0=WSYP3Hgj`0j_7O0>_eg037eZ/0bmfY0;gCTP3GkJd0UZm[08RRF@2=ZUP0[m1i
0:[8L02?[ED0Qj=>08fTEP2[`GP0enNX0;70Q@3Dj:d0c>BV0<KXWP33j9X0cO>P0<KXV`3BjK<0nOoS
0?cok`3moOd0oooo0?oon`3oooX0ooom0?omo`3oo?l0oOWo0?kno`3mo_l0o?om0?_om03noo40hNWL
0?Wol`3PmLX0e_2a0<cYYP3>ik00moof0?Woo`3mooX0nocf0?;ak@3Mg=L0NWeb06ihG`3Kj/<0cnFU
0<ONUP23Vdd0bMnF0<oTX`3>i:<0a^JJ0<?YW036k9l0e>2N0:RRJ02/VfD0iMnU0<KTW033jI`0anVL
0P3;jYh05P34jYL0h>ZQ0?l0003o0000cm740?7knP3koOl0o?Co0?WonP3honl0f>6d0<SFX`3Gjj`0
c^RQ0;cHS@39jiL0b>^G0<S[V`38jYh0bNRR0<[XXP3BiYh40?l000050=7`Y02ngY80eoJZ0<c[W`3C
kj@0103o00002035hIL0a=^C0<oTW`3Ek:H0dNRR0=;YY@3;i:00bn:L103o0000X03Al:@0_=^?0>?o
]02mfHh0b>:H0=;/XP3>iY`0a]ZE0<oVX032h9P0`MnG055X8P2=WUX0l?^i08nJF03;g9P0c>6L0<gV
XP36hZP0bN6_0>SgfP3goo40lOoH0<cYZ@36i9h0b^VI0<k[V`39iI/0c>>]0=OZ_@3`on<0m_o[0?Co
k`3gool0lOgc0?Sol@3HjK`0enRa0=?SY@3GiJP0d=fW0=SP^`2LXXH0kO;N0?kok`3Sm<L0dn^a0<SV
X03;iJH0c^Bc0=OMc`3ooo/0oood09FIP03Mk[P0c^NU0<[WY03;j:H0b^JY0<COZP3Bk;`0b^Bd0<cV
]P36hJ`0an:]0?Oog@3ionD0oOk`0:R/WP3hno00l?S]0?WomP3fon`0nOoZ0?Oof`2kaiT0l?c:0>S`
_`3Jijl0`^B=0<_/U@1EE1h0EDPN09NFJ02mdiD0Yn2K0;[j_@1PWG<0emnj05iG;@3JgZ<0j?Nb09bm
K02A/V<0b]ZI0=SSY`3NjJl0fo6a0<?NV`3EjZT0bMjK0<o[X03@kj<0b>FU0=G/^03Pl<`0ioOC0>?e
b`35iYl0ao6K0<?XV036j9`0anRQ0<WXY03=ijP0c^RY0<cUY03=hj80enjZ08VOE`3GkJ@0c^RO0<_T
X`3hon<0OHUe0?cno@3loOl0ooko0?ckn@3oooX0oOkf0?gom`35`<@0ooko02@e8`2[aZD0^MZ]07ZM
G@27YEl0dnNP0<gQVP3?j:@0gObh0<[UWP3<j9h0bn^P0<K]WP35k9d0an>H0=O[X`33cX`0JG<d0>Sf
^`3DiZX0i??D0>?`g03`nnX0nooj0?[on`3nool;0?ooo`002P3oool00`3oooP0oooo0?kno`020?_o
o`0O0?ook02W`JH01de20<?e^030hhl0a^N>0=7]XP3RjKl0oooV0::NV`3nool0ooko0?olnP0/4P<0
a[FK0?omf03Fk[X0dNFb0=SW`03Wl]@0o_of0?gnn@3oood0oooh0?ooj02c]i80gNFd0<kJW03LjjX0
b^6K0<_YX@020<?ZV`2W0<_ZWP36h9H0Oi1:08ZKE`3Gk:T0cn6S0=KR/03=fZ@0b]ZK08FMC`1nVDP0
`MfB0;gKT`3<jJL0^mFD0>?l^P3<ij00d_>/0=;`]031fJT0728600<3003Agj`0d>f[0<?cW`2jiID0
cM^M0<oIW03>jJ80a=jG0=K`Z@3GkZP0c^FO0=G/YP35g9H0fO>/05ii<P3QokL0_mnF0;gMTP3Gjj@0
_<^80<_PV`3IoK<0_^JM0=?b[03Cfil0GF<W0>7f]@3BjjL0cnFL0=;/XP3:k:00`^BH0<OUV`3?iZ00
a=RC0;G6PP1HJ2L0c^FQ0=Wg[`36j9/0e_2V0=[TW`1OIR80f^^T0<gWW@35k9d0`nbM0<K[W@3@iYd0
cnNM0<GWVP3?jj00_m290=c/Y@3?iI`0cNNM0<SZW@36jid0b>ZM0<[YW@3<ij00`MVK09fYJ`3>j9h0
aNFI0=?XY@3^jkH0f<bR0=CAY02kc9D0c]NP0=SK[P3fnNH0oooZ0<gH[@3GiK00XKAb08BLGP2fch/0
cn^Q0<gZUP3Cm9/0do6G0<GSR`39iI40bMnG0;G8QP2T/g`0B5HS0=KX]038h:H0a>BK0<_`X03:l9T0
`^FC0=3X[P3`omP0mOkY0?_mo03nool0oook0?oonP3oood0oogo0?olo`3ln?l0o_ko0?[no`3koo/0
kOKS0?7jg`3CglT0n?oa0>gof@3Pn[d0bnRU0<gV[`3gooH0n?oo0?con`3oooX0oook0?[jlP3noo@0
IW5A0>7aa03BjJ40c^JH08JOCP39giH0dNFV0=K/[030iIL0_nRJ0<_aY03Dh9h0WiAL0;2KIP3ZgjL0
bNBM0<;XV`33iIP0b>NK0<[YV`37jYH0103o00004P3eoo`0o?ko0?ojo`3co?L0kog/0=;H]036dJH0
i_Zm0<KOV`34h9D0bN^E0<S/U@38ji/0bNVN0<WXY@3<ij@0f^jV07nEC080o`0000H0aNBH0<o^XP35
i9P0d>bQ0<?OU03DkZ@40?l000080<STVP3?jJ00d^VS0<SRV`34gYL0aMjJ0<oZY@3DkZL40?l0000P
08BPE@1]RCh0//j30<o[X03GlJL0dnfS0<oWW@3>hih0cNNP0;kNU@3Lo;<0cnJP0=[[Y`2;U5<0K7Dd
0=CSX03Cij80cnJR0<OUY`34gjP0h_?A0?Gok03aom`0cNV/0<KSX03:jI/0cn^N0<_UWP3Fj[T0i?C@
0?Wom03iooP20?Woo`1L0?Ooo`3kooX0j?C@0>;_`@3Fhjh0o?oC0>3/^P2f`9h0[kRM0?Cli`3XlM80
enbd0<oZY`3:j9h0b^NW0<cR/@3Mi=@0oooh0?ook@0i@1l0bMnQ0<WWW@34iYT0bNjQ0<_/Y@32hZ40
a>BU0<o^/P39jJX0anNV0<7QWP3Mm[`0o?oR0>KXd`3UjM/0n_of0?_oo@3eo_T0lO_`0?Wom03Vkm80
lO_H0;_3W02j_9D0_lNF0<k[U`3Glih0XIiY07e`AP2VY7<0a]^F0;ofY@2YiIl0Ql2=0<WK/`2@TfP0
f=>L0=CQW03Jok<0KiU70:F_L03Si:/0cM2G0<OPWP3QokX0c^bR0<gYWP30hI80anNL0<WPZP32dZ/0
mooX0?_ok03coml0`nNQ0<KbV`33j9X0a^NP0<SYXP3:jZ40cNRQ0<cWX03;iIh0amjF0<oVWP2>Y5/0
c^BK0=O^Z038hJ00lOoL08jGQ03nool20?ono`0P0?ono03oo_X0oook0?gonP2ORi@0o>_c0;_<^P0m
Gch0_^Vk0:[DU@36iZ<0g>fY0=GVXP3?jZD0c^nX0<c/X`3>k:80bN^O0;oXV@34ji`0b^JK0=7WWP3U
lZd0DelM0<CGU@34fYT0c^6d0=;Q`03Zmm/0o?of0?[lm`3mo?l;0?ooo`002P3oool00`3ooo@0oook
0?koo`020?Woo`1T0?kok@2U`J/055]G0;c_]`3<lj80b^bE0<[WY03`m]80oooY0?ono03Ef=l0oOco
0?oko`0V2`00WHab0?oof03=jjD0c^ZP0<cRXP3@hZh0j_?F0?Slj`3oooH0o_c`05IF?03GfK@0eMR[
0>3[[`3@i9l0a^NH0<;WU`39mJ00`N^G0=;aX@39i9D0HgL_0;G9PP3:hId0dnRW0=_X/02CXF<0bMfF
0<o[U`3Flil0`^>D0=3`Y036j9h0`n>H0<;STP3<kI`0d>jV0=O_]@3<gZh000H000@:003FjZl0`]fH
0<CWU@23YU@0amjJ0=CWY`3EiZ80dnBP0;?7PP2=XUd0QY]F0<kUW`3@ij40e>jW0:G0N@26Y5`0bnVQ
08VWG@2^`W/0cn>N0<SSW033kJ40`NnT0<?WW`1fNSl0FeTP0=cRYP3MijP0XJiX07R8@@35fI80fnnX
0<OKU03Ci:00cn2L0<oKV@3Egj00Lg`m0=7PW@39jId0bN>I0=3MU`3OjZD0enRQ0<oWW@80b>ZM0680
bNVM0<gWW@3=iid0co6T0<;NT`39fY<0gNfV0<OMU03=iid0b>ZM0<K[W@38jYd0b^VM0<[XWP39ij40
V:US0=?_Y02kgI<0bn2W0>OS_@3HbK@0f=:l0?_ojP33`jL0lNgD0?oojP3gm]P0gnFg0::[M03ChYd0
d>f[0<WWW@39j9X0c^^G0<KTSP3:iIH0enjV0<gSX`3Ah;D0eN?00?Wok03Wl]@0dn:i0=?W]P3<jZ@0
aNJE0<[_TP37jY00b^>R0<gN/@3@gL40o?om0?coo`3oood0oook0?ooo@3oo_l0oogo0?_jo`3loo/0
mOk]0?Wok03>g[40c]nX0<oO^03gonH0mOoO0>OoaP3=j:D0cNF[0?OokP3iooP0o?oh0?gom`3oooX0
NWY`05EIB01<F300g>ff0=;ZW03Km:00TJYG04YP5@3EjJh0d^Z^0<G^W`35lJ80`nbN0=cWY@2ER540
TgU60=o@V@3DjjD0`^NJ0<?UV03@kj<0a^:E0<g`WP@0o`0001/0moo_0?Som@3no_H0m?o`0?Ool@3h
mn<0oooX0>gnbP3CjJT0_=R>0<W[U@38k9@0bNZK0<[XX03<iZT0cnFW09ncJ`38gYD0dn^Q0=K`YP36
hYL0b^JK0<GQUP3Bk:80`]Z@0=__Y`2mdHT00P3o00002@2mdh/0d^RP0<_QV@3DjJ@0b^6K0<kUW`3=
ij00d>ZS0<oYX0030?l0001c0=;/XP3=iid0an6G08jXGP18HQP0TZaR0<CNU03GlJL0goJ`0<ORV`3C
ljX0_]jE0=3WX@3EiZ80h>VX0;6jN@2CWed0]<F10<kSWP3<jZ80c^^X0=G/^03Vn<h0g?O:0<cY[`37
iZ<0aN6F0=3ZX@3DkJ/0kOgF0?_ok@3lool0nOco0?cno`3ko_l0nOgl0?conP3noo40o_o/0>O^c`3d
o=L0n?oK09f/P@3Ql/H0dN>c0<kRY`3<iY`0b>NI0<GXV037iJD0bn>_0?cojP3joNP0lOWD0;;0S@3;
iI/0anZH0<cbW@39ki`0^n2@0<O/W`3:kj80dO>W0<[/X03;kYh0anZJ0=SbZ02=Vf00[KF40>C^b`3V
km@0hN_P0?Woo@3gool0mogi0?comP3_m^H0i>WE0<k7Z`2_ZhH0c>6V0=S^/03Zik80Nflm0>7NY`3D
i:<0e_nj0<Cc[`2oj:`0IIEQ0<?S]01FB1T0`;j30;ORTP39n:L0`Lf=00@8003?ei/0bnVS0<cWX035
jiH0c?BL0<O/W03AlZd0n?oS0?kok`3jm_D0oooj0?Wok`30hj40b?JN0<G[WP39jZ<0b^bP0<_[W`02
0<gZVP0=0=7/V`3FkZ00b^:D096WG03<hYT0dNNV0<gRY`3gon@0Q8ej0?ooo`3oo_l0oO_o0?ono`02
0?ooo@0M0?Shn02_RY80l/kB0?Ook`2E_iT001d00;?[ZP2ihZ00g^n[0<cKUP37iYP0a_2N0<;WV@3:
k:00bo2S0<K]WP39l:40an>F0=K/X@3BhYT0JG/a0=3[WP2ngHl0d^fP0=7YW`3VnkX0looG0?_oj@3i
n?<02`3oool000X0oooo00<0oooa0?comP3do?400P3hoo/0aP3lon`0eo;O03=iM`30l/40`>JK0=7b
X@38i:L0hnS80?ook03ooOh0n?_o0?omo`3omol0>QlH09N5K@3oomL0b^RP0<SWU`3=ij00cnFW0>;^
b03fo>80ooo_0?[kj@3LgKh0gN:j0=SN/03CgZ80c^>N0<k_X032jIP0a?2K0<WcW@3<ji/0d^ZL08bP
F03;hIT0cNJR0<oUY03AhJ<0dn:O0=S/Y037hhl0_]^70<k^XP37jId0b>ZP0<[/X039jiL0bnfI0=Sb
Z`3ChZ/0dMZ]00<700001P00bM^O0>7h/P2C[Ud0dNbM0<gTX03?i:<0d^6N0<OFT`2?X5`0PYIA0=kc
[P3HkjT0b=nI0<[TW@3<ij00bNBM0=?aZ@2@ZV40UJAO0<GFTP3GlJX0`nVN0<;/XP34hid0EU@K08^2
B`3KfZ40i>R[05=M601?FA@07RT006A_:`3HiJ00f^JT0=KRX03BfiX0em^N055?503Fg9`0`n:F0<GO
U@3AhIX0h?2Y0=c`Z03@j9h0b^VM0<SXW03>kJ40b>BI0<KRU`3DmZT0a>2E0=[[Y037ei00d^RO0<_U
V`36j9/0`NJH0<KXV`3?kZ80bNRL0<3OT`2BY5X0e_:W0<;SW03gomP0ookP0?o_i@3ooO@0mood0?_k
k`2g/JD0SHMi0?Kag@3oon40`<NK0=_Y[P35iI`0c>fN0<SYV03<jIT0b^NG0<oVXP3;gj@0aMNW0?3l
i03ioo@0n?oi0?_ok`3Qkl`0c=nb0<SUXP31hY<0a^V;0<OZSP3<iJ40d>Ba0<kM_03an?40o?oo0?ko
o@3emo@0oook0?3_k@3oool0ooom0?col@3`nm/0d^6f0=7UYP3DjZ80c^:a0<gO]`3eoml0h_[00<CM
V@3NlkP0fnS>0>Kah@3looH0o_of0040003Ph=H0cM70075mE@2nciP0e^jP0<7JQP3Jlj00@eT>0=GY
[P3;hjL0aNbM0<_gZ02ki9H0jOBb09J9DP1`ER<0YiQQ0=;YX`37jId0b^ZN0<WUVP80o`0002T0g^NT
0?l0003o0000nooJ0?Ooh`3eonH0oooZ0?;oh@3gonP0oooc0?ook@3HiKL0f^jc0<[UWP37jID0bnfG
0<SWV@3Im:d0eN^]06Mk?022UTh0dNNN0<SPUP38hYP0c>RM0<_WW03AkJ80bN6G0=K/X`3@i9`0cn2I
0<gLV@3FiJ80U:EQ04iO6`3?hih0c^:K08NME@17GAD0QYaD0=CZXP040?l000060<CNU036gY@0a]jD
0=C/XP3EkJ<0_MN=0P3:i9X0=039h9X0cNRQ0=Kf[@37iih0cnJP0=3QW@3BfiX0SiQG0>;^[02Y^WH0
fo6Y0=?_XP3<j9h0bN6U0<oV/037hk<0b^R/0<c[Y`39iIX0e_2W0>Ko_@3hon40noo]0?Kjn@3lool0
noko0?con03honl0o?oc0?_ol03io>/0o_o^0?koiP3bo=L0_<jJ0=S]/P3FkJT0cnJP0<cYV@39jiL0
b>^I0<WXY@3<iJh0o?oT0?koiP1RKT00g_2f0=KbY@39jYT0b>^I0<S[V`38jYd20<WYWP1S0<CTV@3B
l:H0_]Z=0=OcYP3<i9H0DV@J0;S7PP37eJ00d]nd0=_Wc`3hoo@0m_oi0?Won`3looX0o?of0?kom03o
o>40YZ1n0=?U_@3:gK00X9mY05mF7`3Sh:T0e>6[0>gof034j[40c>jb049oAP33ll40KUda09:9DP36
j9/0`>VJ0<SMVP3QlK80CF0P0=;`Z038gYH0a>RA0<ObV02oi9H0eoJc0?_oj03jo>l0noCk0?ono`3n
oo@0_mnP0;cXT`34jYd0b>VR0<KXW038j9`0bnRH0<SUU@3:iIH0e>bP0<gUV@2EZf80cN>K0<KLW03K
l;P0mooV0=[SdP3no_l0n_On0?olo`3oo_l0moGf0?ono`3hn?X0ZH260<>KV`3`onH0]=jf000T002h
lk40_NZW0=ca[03=gYL0c^jK0;WTR`37k9h0_^2D0<S]X03;lJ@0`NJH0<SRV03?iIX0dn>H07R8?@39
i9D0doBS0<g[T`39iI00bn>G0>WgaP3fomh0n_c_00/0oooo000:0?ooo`2R0=cTc@3konl0l?cX0?Oo
l`3hoo<0o?oX0=olj00jPH<0aoO?0<;UY@2hf8l0bnRb0>[`e03oonl0ooko0?_no`3ooOl0oO?n0207
0`25MEh0oooL0<[ZX@38jYH0c>RM0<cUX@3Jj[/0joG@0>W]dP38c;40c=2]0=OL/`3Wkl00ho6f0>Gj
]@35iIT0dOJV0;kXU033jYL0bNJF0=?[W@2aaW/0e^bS0<kYXP39hYh0e>BU0=GVX03?i9T0e>nN0<SU
U@37ii`0aNJO0<g^Y`3=kjD0a^NF0<SWU`2oe8l0h>^c0=;EZP0R8`403A<00=CVZ02gcHD0J7/Z0=[_
X039hYh0dNRT0=STXP2d`7h0RY]G0<oSWP3BiZ40a=^E0=[aZ`3?jJ80d>ZS0<kXX@3:iIh0]/f50;C1
O03EhIl0eNZU0<7UV`37kJ@0eo:]06YS;03OdYd0eM2H079c=`1mQd80YJaX05iS8@1WKR/0c=FB0<cG
U@3Qk:X0gN>S0>?SY`1UFR80iN>V0=SdZ@3CkJ<0_m>;0=g^Y`3AiId0c>BJ0=KbY`3;ii`0_]fA0<o^
XP3<k:00a>JI0<cXW@2?X5T0g>bU0=;XW`3<iY`0b^bO0<GZW036j9/0bNRL0<OVVP36iIL0X;9V0<GQ
UP3Blj`0lOoH0?onh`3bhn00oo[h0>kglP3ooo/0oo[f0;jd/`2i/ZX0/K2K0:fbTP3>fZ`0a^VI0<S[
V@37j9L0c^ZO0<WSVP3@hj/0f^bl0=GS`03Pj]l0l__h0?Woo`3joo<0ioCF0=?U_@3:i:D0a>>G0<_^
TP3:ji00b>BJ0<_RZP3=gkL0lOc^0>gck`3nood0o_ok0P3ooo/09P3oood0o_oj0?_ojP3koml0d^>]
0<[PU`3@jIP0cnB/0=KX_P3bom`0kOo:0>7f/`3?hjP0d=Zo0>;[fP2j`;80OH5c05mNF@34a;X0d]K5
03<o6@2fai<0cNFI0<kWU036gh`0D6HK0=CXZ`3>iZP0_nBF0<G`X@35kZ00d=^I09J;D`2SS5P0IEPQ
0<_PV`34i9T0c^ZO103o0000:01JE1X0J5/W0?[odP3^oll0dN2e0=WP]P39gjh0cnBk0?gfkP34`k40
i?760=KY/P38hZ40bNZK0<[[VP3<jil0d^bU09BXJ@2Z_gh0e>ZQ0=K^Y03=iid0d>bQ0<7MTP3>jYl0
b^JK0=;ZX03=hiX0XKE]0<gNV03Dh9h0e^:P0<cKV03AhYh0VZiY069f;`2icHH0cN6J0<7ESP17Fa@4
0?l0000V0<kXWP3EkJ<0f_:X0=C/XP37giD0g_J/06f7?@1_Qcd0d>NQ0<SSW03@l:L0`N6H0=?ZY03H
jJD0jO:a09ZSHP3?fiT0[;ei082FCP2mf8L0_mZ=0<[SW`3<i:H0dNfj0<OUY`38iZ00c>RK0<kXW`3@
jJL0k_oE0?WojP3kooX0nooo0?7fk`3VlM<0jOCB0?Woi`3noo420?ool`0@0>G^d@2kaj40b=bO0=?]
Y03?jYT0cNRI0<W[U`38jiL0a^bI0<WXY03<iJ/0kOS>0=kV_`2BX6/0enb[0<?PT080bNZK0P39jId0
I@3:j9h0c>RN0<STVP38hYT0eNfS0=K^Y02me8H0RZ1=0<gPSP3:gYT0d^BZ0=?S_P3Vm]T0j_OV0>ok
k@3hoo<0n?kb0?_ol@3oon<0clVY0=g]d03FjLT0f=RT07A^=03Zik80f>6d0?7oh`3Uom@0a]nX011D
6`2ckk/0VXmR07=W<`2me8`0d_:W0<SSWP37h9h0U[=`09bjLP3Jjj@0b>RC0<K]U034iYT0_=VI0?_o
k03ko?@0ooSo0?omo`3ino00dNf`0=;lZ035jY`0b>ZP0<OYW038j9`0bnNJ0<[VV@3@jih0b>2F0=O_
Y@0oE@d0TZQP0=ca]P3>h:h0nooZ08R>P03oool0oogo0?olo`3oo_l0oo_l0?ono`3mnoh0`9VJ0<JQ
V`3hon`0a^c50:3FY02bk:l0`>j^0=3ZX`3AjIl0d_BM0<WdV03BmJD0a^JK0<3RUP2nhiH0a^RL0=C/
XP3>giP0amB<0720=@2jeH@0a^RD0<WZS`39ihl0b^FH0>;b`@3bo]X0o_oc00/0oooo000:0?ooo`2S
0=7S_@3eomd0d^Ri0<cT/P3CjKX0amBY0>gol`2Efn<0e_o^0;oK/`3Fl<00f_C?0?Woj@3oond0ooof
0?_on`3nool0oo_o01D00023LV00oooM0<[YX`39k9X0b^^L0<WXW03>i:@0e>J/0=;P[@2`_8`0c=RX
0=OU/P3Vm<40jO[30=ga/P3:iIh0aNFJ0<S]W@3<kil0c^VJ0=;YV`3Jl:D0cnNM0<o_Y03<jZ00d>FP
0>7e[P3=hiX0bnFK0<cWX03KmkX0dNfc0<CPYP37hJ@0cNJR0=?]Y03Ci:00[[=m05aI;01=CbX06BH0
0<7HU03:gi@0gNJG0<oJSP3GnJl0^mZD086<BP1kQT@0gnj[0=CXX`36fYD0CfHP0;oFT032ei80dNJQ
0=GYY037gYP0f?BZ0=KUX03Ki:<0dN2M0<_VW`39ij40iORf06QM9`3`h:`0D4hE0<36R03EiIh0cMRC
0>O/ZP3LhIl0MH0l03m;2@1PKb`0j>j^0=C?U@3Ia8l0OW8h0>?k/@3>iY`0dn^Q0<oWW@2>Y5/0b=jE
0<cRV@3Cjj40dNfR0<KXV`33iIP0cNnR0=3/X@3Gj:40BUXC0<OMU03?jIl0anVL0<W^X039jih0b>NK
0<k]X@3Dl:<0YKE/0=C`YP2oh9T0aM^/0?ooi@3Pe/d0oooh0?GomP3joo80n_Wd0?oio`3on_l0oooo
0?_onP3Ji]80a>bC0<?YU034iiL0c>JU0<kV[03Mk<D0mooX0?_ol@3co?L0nOoo0?Soo`3goo00nOoZ
0?Soi03Aj;80b>:Q0<_[V03:ji@0a^FI0<_UY03Cj[@0lOoQ0?Clk@3io?<0oOog0?oon0020?oon`0I
0?kon03konX0nOoM0<_NY`3@j9X0d>ZC0<CHX`3gon<0nOo/0?Woh@3PkKL0l?c:0::WT01iNfh0G5eE
0>_[h`3oo_/0mOC_0?Wll@2]]ih0NHQQ0=G[Z`3=i9`0g?BV0;K<P`020=;WYP0:0<[YW@34jI`0^n6D
0=[[Y`2QWf@0jmjW0:BNI01`QD00an>I0<CDS@@0o`0001P0YImU05I9503DhZ@0d>VW0<cQX03KijT0
bnRX0=;Z^03@al80P7U_0?Woh`3Ol<H0d^Ve0<WXY036iYd0dnnU0<7HT02jbhL0c^:K0<?OU03<j9d0
dO2T0<GUV@3Al:@20<o^XP0?0<_UV`3<i9X0R9aD0<KJT`38f9L0cmnN0<oTW`31f980gON`0<CNU@3D
jj<0cNBL0<oUW03Olj/0bn6H0080o`0003X0//j308FOE@3Ejj80dnVP0<[PU`3IkjH0eNfS0<oYW`3E
kJ<0RYiI05M^:02ng9@0cnfU0<cSW@3@hId0c]VG08NBD03Ci:00e>VT0<oUW@3Gk9l0cN:G0=cdZP3B
k:80`=nL0=7_Y`3<jil0b>NG0<cXW@3<ij80fO2l0>?eb`3Sm=00i?GA0=_^`03>ijH0dn^]0>7d_@3Y
lm00j?7D0>cbf02a^iP0VjQj0=7YW`38iY00bN^<0<[ZU@38jiT0a^bI0<G/V@39jIh0c>NR0=KUZP3J
iJd0YkYh0<cSV`3:jiX0b^VM0P3:j9h0A03<ij00cNNP0<gWX03IkZT0f^jY0<KGT`2N[Vd0]l^30=O_
V@3@jXl0bnNC0<_VU`3@jjP0b^BW0<cR/`3Jk<80ioGD0=kYb`3Mil`0oooM0=OC/03/onD0g??F0:B[
N01BDAT0W9QY0?WngP3Ym^80nOo]0=kT`P0QGc00Mk^80>3b`03Ig:L0MgTj0=COW@3=jjD0`^NQ0;GM
U03Kmjd0[;id06Ej:`3Cjid0^=:;0<cTZ03`n^40oooh0?ogo`3ooOl0oood0<gRY`39jYT0bNbH0<OZ
V038jYd0bNVP0<gXY@3Bk:/0a=bN0<oUY`3AijL0/LJ50=ca[P3KkK/0k?gC0>ohi@1dNG80moGj0P3o
oOl20?ono@0N0?chm`3ln_/0aZnY0>OAaP3bn^<0b^C70<C/b@1bY7<0^NRb0<3TY03=lJT0`NF>0=7e
V`3<iiH0e_6T0<[TVP2kehd0d>ZQ0=SWY03QjZT0koJc08^FD@3FkZ00anJF0<g^W`3=kJ80bnRU0<SK
[P3Di<00nOoc2`3oool000X0oooo0<X0cnJh0?7od`38i:L0a^>Q0=7[[03?gJX0kOo_0:CXl`3GooH0
hOWO0=_ac@3Yon40o?oZ0?ooj03oond0nooc0?koo@3oo?l04P0007=RCP3Vi/00aNJO0<SZW@3:jYh0
b^VM0<cVW`3@iJ80gNna0;_=T@29Vf40U:E^09:SK@23UUl0W:ib0=Wb/03Hm[00anVM0<o_X`3AjI/0
c^FG0=?YWP3<iiX0b^bO0<g]XP3CjZ@0bMfF0<oUW@3<iYl0cnZW0??oe`3SnlT0c^Jd0=3W/@3?iJL0
c^FQ0>3d[`2GW6@01`@00;k5W03KkKd0hObe05ac9@3GgXh0jOJW0;KOT`3Bn:l0WZUW0<WDTP3?gY/0
c^:M0=__ZP3JlJ/0FW4[0>ko_P27VeH0fNZV0=GZY@3:jYl0c^:K0=7JV@3BhIh0d>ZS0;kIU03KkZ`0
HEPQ05iC7@3BeY/0enJU0<OOU@3Jjj@0cMJC0=CMVP3ChYd0/lN20765@012C@/0IV@Y0>?<V017>000
aMfC0<cTVP36h9H0c^RN04YP5`2;XEP0a]ZB0<OMU03Fl:H0cNnR0<3UU`32i9L0bNFJ0<CESP2>WUL0
i?Za0=7[X@35iiX0a^^M0<W[WP3:jId0c^ZO0<OQV01^NcD0foF/0<;SW03=i;00oooM0>kWe03oon`0
b=fn0=7L^P3NhL`0oo[o0?olo`3nool0nooj0>Sfg`30ji40a^bI0<CVV@38hZD0eNVf0?Cog`3kon`0
moo[0?_omP3kooX0nOoh0?_ol@3honT0k_gL0<[P[`3;iJP0cNbN0<g]VP37iYP0a^6L0<[TY`3GjL40
cMW10?col`3]lnD0o_oh0?oon`3gnOP0m?Kc0?_ol@3ionH0d>6d0<GLV03@jIP0bmb_0?Sok03do>l0
m_kV0?Gnd`3?ejh0A4Ld059BBP3mo?P0ookk0?_gmP3ooo/0l??/0=;Kb00>6`00dnR`0<GKVP3NmZX0
cnFL0=[_ZP3;h9/0e^jT0<c^XP2hgI00d^NR09:CE`3Yh:L0jNN/09BYI01CJR80d]bG0`3o0000I@3>
e9H0WIIO05=64@3>gYd0cnZU0<oUY03GiJP0`]jS0<WP/P3HcLT0bL2g0?cojP3_om/0g_C60<[X[038
ij@0c^RQ0<WOUP35eH`0b]bB0<k]X@3<jil0c^jR0<g_XP34i9P0b^ZN0<c[W`3=iid0d>RN08nSF`3B
iYl0eN^Z0<WRWP3ClJ/0eOB^0;kNU@3<k:40cNbP0=;^X`36h9H0cNFI0<[UV02ohI@0c>bP0;kJS`3D
kZ@0<dT007R<A03Vn[80^Ln60<kVW02ofHl0f?2V0<oPW03Kl:/0LHm70:2nMP3=i9h0i?Fa0>G`[P29
U580e>RS0;S?R@3Il:X0TJ1K0:VjM03AjIl0]m670<KTW03?kZ00bnZJ0<OWU037iYP0a^BL0<kW[@3?
j;40bn:^0<gT[03>j:L0b^ZO0<SVX03>ijH0dn>b0=CO]03Eh;H0UZ9b0<GDW@3;iI/0b^NC0<W/TP39
jYT0a^^M0<G/V`35k9T0bNVM0<cXW@3HjJD0SIUI0;_AR@3IljT0aNRF00<0bNVM06H0b^RN0<cXWP3=
iih0e^fW0;kCT026VEL0dNBT0=[^Z@3BjY`0aN:@0<g/W035i9@0cnjR0<cZX03<iZL0b>6W0<oQ/@3?
gk80e^Fj0=kI/`2b/8X0lOoS0>Wog01/MT@0=C@407iiD@1:CBh0m_oZ0?cok@3oon`0XLnZ000T0033
k;@0b]nV08B4B01HFQ/0`]^G0<?TW`31iId0fOFZ0=7XVP3NkZD0MXM00=_`[@3LkkL0noo/0?KikP3o
o?l0oocn0?oom03AiJX0`Mj>0<[^UP37ji@0bN^N0<WXXP3?j:h0eo2g0?GoeP3<h:/0eNZa0<SLW@3J
kjh0c=f`0?Soi03Af/T0K75[0?omo`3im?/0oo[o0?okn`3oo_/0ookm0?ono`34]K00oocc0??jjP3b
oo00k_oa06jHLP1YU6L0_NV/0;WRWP3>lj<0dO>M0=?ZVP2ldXL0fo6X0<SNUP3;giX0J78c055E603@
dY<0I6/X0<OLT@3BkZ40a^RL0<W[X@3:jJH0b^:`0=S]a03honX;0?ooo`002P3oool0b@3>kK80honk
0<O]VP37ji40anND0<gOX@3Ton<0cooo0:S;d@3TmNl0mOod0>WoiP3Tk//0lOG@0>ccbP3SlLd0o_o_
0?oll00A0000A3HK0?3aa`3;k:D0a^ZR0<SXW@38j9`0cNZH0<gXU`2nehH0ennS0=_d/038h:80an2V
0<?JY03Um;d0VJ]a0;kDUP3>jJ@0bNFK0<SNT`3Gk:40a]^@0=3[WP2mhY80b>fO0<WSW02DZF@0`mZD
0<_TX`3<i:X0kooI0?;oh03hon@0nOoQ0=_Y]P3>hZL0^mF>06=/<`26R5T0dMjb0;kLYP34jYd0XKi/
0=WRS`3PkYl0^^fN0;o_X`2<UeD0f^JT0=SYY@3Oljh0_M:=0<WNV@2ldH`0fNfX0=GTX@1cOS`0e>VT
0<C_X039iI/0e>2N0=;SW`3=ij00dNbW0<KIU`2TXVT0fmVP0<_NWP3=jjD0`NRI0<7QU@3DjZ80en^T
0<kXW`34hYX0fo^b0=?WXP3HgZ00Pfhi05a=503>i9/0e^jT0=_g[03=jIh0c>BJ09Z^IP3Bhi`0e>RP
0<_UV`36jid0aNbM0=GgZP3<j9d0eNJO0=;RV`1RN2l0[/Qn0<g_XP36jid0`nFH0<_ZWP38i9X0d^JW
09>MH035g9H0cnjX0<_SY`3Be:D0b<NK0=;LZP3?kZX0e>^S0=;OY`3ooo@0oooa0>_ff03Jj/<0d^Zf
0<3/U@36kIh0a^ZR0<GMZ@3Di[`0n_oU0?_oj03`nM`0dMbl0=WU`@3ion<0i_7C0>_hgP3honX0jO_C
0=ke`@38hi`0c>RK0<g/W03;jYh0eO>[0=K]]`3OkLT0lO[O0?cok03_l^L0ooom0?Kfo`3lo_l0nOoo
0?3jl@3dond0fNbo0=3UY038eKL0dM_B0?coo`3Zk>L0RH]c05mOA`3bkNT0oogo0?oko`3mm_d0n_Kg
0??am03nool0nook07j9N@3<g[@0eNZb0<WPV03Aiih0TJMN0=GYX@39fY<0cnfS0<oaY@3<iYl0WJMX
0>3PY03>e9H0_mB?0?3o_P040?l0001V0=SNX01QG2@0K5l[0=7QXP3;iJ@0b>2T0=o]^P3Im<L0goCC
0=[;b03ooOH0noo/0?Wok03eonH0bN>c0<cY[`3;iIh0cnFL0:bjJ`3Plj80c_2S0=CfZ@36j9/0`nRJ
0<GZW03AljH0anNK0<gYWP2ofHl0Rj5H0;kHS`36jjD0/=RA06^GC02>_740`O2R0;SWU`3=n:P0`NZK
0;gRTP39jY/0aNJG0<CVV@2ngY80bNFJ0<oWW@35fI40e>FN07^?A`3Nm:/0enfT0<[TVP3=hiX0gNVW
0>_l^037hIX0fOB]08>JE02N[f/0`<b:08jMFP36gIL0d^fV0<gTX03Af:80TIaR0<[MW@3Om[00c^^G
0<OXT@3;k9D0^m^60;oPS`3@l:@0bNRT0<c[Y@3=kYl0b^bE0<W^T@37kYd0an^Q0<[ZX@3CjZ80dnNP
0=;SW@2mcXP0e>RQ0<cVW`3=jjD0b^^T0<SYY036jZ00aN^N0<G/V`39jiL0c>VG0;kAPP2L[640enjP
0;gHR`35jYX0aNbK0P36ji/0A038ji/0bNZK0<[YW@33giD0V;9[0<WOWP35fYT0fo6c0<cUZ`3<jJl0
b^^V0<SZX037jYH0an^C0<[/U@3;jiH0c^RN0<?JTP2Q]W<0e]B[0=cN]P2mhI/0c?6[086>H00_<@`0
in;40=kP^@3Lh/00ooo/0>oPg@3HjMH0_n_707o;RP2ilZd0hn>W09Z@E@2/]WL0c^>P0<;LU@3FlJ@0
b_2M0=[UX@3VjZd0[[Um0:ZiPP3/nM/0n?o`0?OemP3oo_/0m_OY0<?BV`38gY<0cO2D0<K[SP3:k9l0
bNRU0=7Y^@3Om/X0l?oN0?Oog`3eomX0d>>[0<_OXP3:f[<0n?oZ07^3N01iNgX0noSo0P3ooOl0803o
oOX0ookj0?kjm`3jm_<0oook0?konP3nood0loOf0?Koo@3[ooP0KiMm0:GFY`2ij[80bNfW0<cXWP3?
hID0bm^@09NWGP3GiZ40f^JT0>W]/P3BciP0T8]C05AD602Z^G@0Z;mg0<[]V`37kIP0a^^K0<KVW@39
ij40d^b]2`3oool000X0oooo0400b^NW0=;bY`2nghh0b>VB0<cYU`3DiZP0l?oV0=Koo`2Zd]@0iOoo
0>gon`3Jl]00c=RZ0=[S]03?hJd0cmb^0?Cdg03ckMl0200003L/5P3oom`0a^BL0<WYYP36ij00anNL
0<[YV@3;j9H0e_6T0<GOU@3<iJ@0c>BX0??odP3CiK40c=VT0:6cN@35fid0anFO0<KTW035giD0g?BX
0;_AR038h9H0_Mb@0<o^XP3<hid0ZKii0=?ZY037h9l0d^N^0=;X^P3OlLT0n?oS0?Gof`3Gi;H0d>6Z
07R<A`1LI2T0gN6_0=c/_@2ngJ@0R[1U0<OXU`3BhI00eNJH0P33kJ<0102@We`0[Kai0=;SW`3;giX2
0=?WXP170=oc[P35fI@0enRT04YI5P3AiZ40cO>V0<[VW03JjjD0d>BM0<WUV`3:j:00enjX0=;KW03H
hJ80b>6O0<WWX@27XeP0RJ1H0<SIT`3=gYP0an6H0<7OU`3>kZD0bn:L0=gYZ@3_jJl0e]BG0<_SV@31
gI<0_=jB0;kPT`3AkJ80aM^C0:flM`3Kk:D0d^VQ0;WKS`3>mJH0b^bO0<GTV036g9<0e>RP06Z0=`2D
[V@0d?2T0<[ZWP32hYH0dNfR0<cXWP3?hj@0fnNY0=3UX03?jJ80bn6Q0=_R[03FgJT0enJ]0<KSX03N
m:`0l?o60?_mk`3hoNL0jo[?0>Gia030gIX0`nbM0<G[WP39jZ<0an2V0=3T/@3Qkl/00P3ion@0>039
fJ`0c^2/0>Wla03RllH0d^:k0>CfcP3SnL/0j?o;0=7WY`3CjZH0c>JO0<KOV`3=j:D0a]fW0<gM]P1d
OF80:S8K05]LE02ZZZP0MGAl0:VY/`3en?d0lOOe0?WonP3Sl=@0iOG60>G^f@3Vj^T0fm_W06e^L02C
U880f]W70?onnP3oo?l0mnoj0?olo`3nn_T0oooo0?_ko@3am_80Z;2S0<WJ/03=gj/0bN2J0=G]X`11
Fa40c^FM0<SLU03Ajj80b^RN0<oVX02GX5l0en2Q0=WUX`3AiZ40bN2H103o00005P3UjJ`0GUTO09B;
DP3FiZL0cNNV0=O^^03iomX0m?oX0?OokP3Zf]X0oo_d0?[oj`3fonL0mooT0<GPZ`3<j:/0d^VQ0<OL
T@3Vlj@0c=f?0<GWVP33iIP20<KXV`120<c^X@37jI`0bNVM0<STV@3?jj00bN2H0=G_YP37kJ@0bNjY
01U2001DOS`0a?:Y0;o^X030jiT0`nZG0<_^WP3;iI`0d^bS0=Oi[@38j9d0cNVO0<[TVP3Ejj80d^RO
0=W]Y@1XO3@0PYQ?0=7WWP3AiIh0c]fH0<_OVP3Lmk00a>:J0=;/Y@3=hI`0g^ZX096PG@3LlJ`0b=nI
0=3WX`3Sk[@0d=jS08fPH02;X5/0bnBA0=C`W03=jID0T:QJ09fgK@32g9<0cNNP0<gYW`38j9D0aNJ?
0<KZT036jid0anbO0<WZV`3=iIL0bN2B0<GJS@3_ok`0a=ZB0<cWX039iil0co6W0P38jJ80C`38jZ00
bNVM0<cYU`3?j9D0MX`i0<gST032fhP0eO:P0<;WU`35jih0aNbM0<K[V`36k9T0bNZK0<[YW@3BjjL0
PIMG0=_/]P3gom@0c=b]0<gO]@3@iKX0`mnU0<[ZY`36ji/0a>ZE0<[^U`35i9@0d^VS0=O/Z`2lcY80
f]be0>?Z`035i:00cO6[061_AP032000d]6b0=[P]01=DbL0[ZZ=0?okm03ChLX0/]^c04BDC`2;bHH0
h>Vb0=oLY@1kOC`0f>6N0=?OW@3?iId0`nJF0=3KV@3JgZ40OXa>05AW;`3RllL0k?OI0>o[jP3oo_/0
o?S]05YQ=@1RLbd0d>nB0<SZS03<jZ00b^NW0=7X^P3Qn<h0mOoS0>koeP3Oll80d>>[0<SLW`3Fi/40
moo[03Dm<03fnoL00P3oo_l08@3lmo/0oo_h0?onnP3oo_X0ooch0?gonP3dnO<0oOko0?koo`3fnoh0
fo3W0=Cch@0[E2X0R[9n0=Ca/@38gi/0enFH09FVEP2BYeP0amRA0=KUXP3?fI`0h>JZ0?;`]`2JVel0
dnNP0:[1N@3:jYL0b>ZF0<OYU@3<jid0c^ZO0<WUV`0;0?ooo`002P3oool02@3@h9L0e>FO0<gQW03B
hZ<0c]jO0<gLX`3gomP0k_oQ039YE0020?l0002/0<W//P3DiJ40dNnY0;o]Y@3Ji:P0c[RS0?okm000
1`L0;R/R0?C_dP3Kjj80cNJU0<SWX`38jZ00b^bO0<WYWP3Bkjd0`MZP0=SZ]P3GiK00ZkR20=;MX`3>
fJ40n?o>0=O`[`3?l:T0coFZ0<;XV`3<lJ@0`mfD0;kBS@28TE00d]^J0=SWXP30e8d0SJ9M0<KKV03L
lK00enf_0<gRY`3Sn/80mOoF0<gT/03Ci:d0O7/k09nPIP3GgjH0bmjW0<[SZP2YbXD0E7H/0=7]XP39
giL0f^JV0=?OW`3AiZ40b]jI07j=BP3?gY/0gNVW0<[IUP3HjJD0a]fG0<CNU`38iYh0b^FN0=?WX03?
iI`0d>^N0<gYW03;jYX0c>nM0<KYU`39jId0anNN0<WWX@3EiJ@0g]:H0>_RY`1;B`d0C58B07n@C02L
/F`0dnZT0<gWX03<iYl0foJ_0<[UWP39i9d0e?R^0;_/W@2ol:40aNVO0<CKU@1XLc40XZe[0=3QW@2o
gID0a>VL0<7XV@31iYP0cNbP0<o[X036gY@0^]270=G[XP3?iI`0b^:H0<gWW@38i9T0bN>L0=KZX`2j
ah80e^6M0=KUXP3FjjX0Rj=Y0<[SZP3Hjkd0nOoM0?_ojP3lool0n?oa0=CY/@3:iIh0bN^G0<OVZ`37
iZ00b^VK0<[WU`3:i9/0b^6[0>Cjb@3OmlL0b>FR0<WZV@3<l900bNVD0=KfZ`2kgI<0e?:b0>kocP3[
m//0h^S20?3fdP0M9`80@e</06=iDP1/O5P0lo_V0?com03/k>X0ooko0>kZj@3oo_/0JfMT018@4@1/
JVl0[jjd07ijN@0j>CL0>SPk0<72aP3RhnD0lO;Z0>_]h03noo40oocc0?olo`3ono/0o_oe0?Sil`80
ooom0140moW^06adB`3NkKH0bnFK0;SGR`2eeXl0Q:QP0;SHS03IkJD0dn>L0=CUWP2>STh0bnFL0<WY
WP3<hI`0c>jT0;gHT@020?l0000F0>7GYP3GdI<0EeHC09VOE`3@i9d0c>:Q0=7S^@3honT0o?Wb0?ol
o@3onO`0oo[c0?koiP3Xml`0e^^c0=7]X`3:iIP0c^>F0=CQV@3BfID0fnRR0<S[V`<0bNZK0;H0b^VM
0<[XWP37iI/0b>BJ0<cWX031fi@0dNfS0<KTW03Pn[d0HgQA00HL002ogJL0_nBO0<gaVP2jeh<0d>:F
0=CCV`3Xj;80e>n/0<?NV`35iI`0d?2U0<7QU@37j9T0c^RN0=3VW@34f940Y;1^09n/I`3Yn[<0dNVO
0<c^XP3Fnjh0bnVO0=_b[026TU00K7Le0=;NWP2lbhX0hOF`0<WUVP36h9H0f>jU0=CXX02ibW`0lOji
0<OATP3QjK00hnR`0<oEV@1eOS/0UJ1K05Y[9@1gRTP0enf/0=7]XP3;j9@0a^:=0=WbX@2jdXP0RJ1L
0<oTZ@3;hjL0anJJ0<SZT`3:ki00bNbH0<_UWP31eY40h_6^0<ODS01^PC00/m1d0=7dUP3=kiP0c>^K
0<gZY`32hJH0a^JU0<WYX03<jid0c^VJ0<oUW03lomH0QHeX0?ool@3hm^X0oood0?ool@3oon`0nOoQ
0?GofP3Gn[P0a>VS0<_^[034h:H0i?3:0?koiP3lnnL0Uj230>cke03hom`0m_oN06=eG@0c@Rl0gN_7
0<7>V03MhjL0DU8N0>CN^P3Ah[h0bnbm09O>S@0TGbL0_nZm0;gKZ@36b7d0IehI05]@4P3Xj;@0bmNE
0>3[Y`3BgiX0`mnE0<;PX02lfHD0en^T0?omn03on_/0onob0?7[f`3Qj[<0]/]`0=3URP33fI40bmnR
0<kT/`3Vo</0m?oH0=og_@37gj40bn6S0<cPY@3Mk<d0Phmi0?Wom03gooH0o?om0?gooP3hn?P0mO7`
0?ojm`3_i]l0gM?:0?kol03loo<0o?oo0?[mo`3io?l0o?oo0=7IcP0X=QD0RIQ]0:ZmQP2BYfh0^lUl
0;kDO`2niH`0cnZK0<oYW`38kZ<0c^nX0<oEU`1QJRT0b>ZM0=C/X03>giP0i?B]0;C4O@3BiYh0`]R?
0<[RV0/0oooo000:0?ooo`080<kPUP3Jl:P0h?F`0<cOW@3IjJP0e>>X0=ca^@3ElL440?l0002W0<oT
Z`3;ijd0`nf]0=;LY`2]V8<0n^WQ0004100W7QL0lnc?0=CYW03?jIl0b>VH0<[/V03<kYP0bNRH0=;]
Z03>ijH0dNFX0=?SY@29V5L0fnNU0=cZ[@3holl0d>VX0=?b[03Cmjd0_N:E0=?eZ039hiX0eNZU08JB
DP2W/g40cMbG0<3AS@3@i9l0VJaZ0<7FU@3:h:00dNNY0?7oc`3eom<0dnbc0=7SZ@1KFQX0UYMM0=oT
[03Ol;X0c>>[0<k[Z01[RD40d^jS0>3g[`3@h9l0dN6P0=K[YP3MlJ`0UjIS0:>bK`3Dhj00kObi0<GF
TP3JlJ/0`mfF0=Sf[P38hi`0dNNO0<cRV@3;iYT0cn^N0<k]W@3AlZ40a^NF0<c/X039iil0bnJQ0<kQ
W`3WijT0embL08jIE`2O[V/0MX]608:GDP25W5H0goB_0<[OVP2ndXd0d^JQ0;oITP3CljX0]>2C0<Kb
Y@3>kZD0bn:L09FPGP1hPd40eNJR0<CRVP3>ljH0`nZK0<;WV@39jId0cn^P0=;ZX03CjJ00d^RO0<OM
U03BjZ00cnVO0=cf[03DjjD0f^nZ086>B@3NjjH0gnj[0=7TXP2<Y6P0b>2V0=oc`03_om00n_oU0?co
o`3honh0dnR_0<_VW`39jiL0b>JV0<WWX@39iid0d>^T0=3YZ03=i;00e>Zi0<gU/@3:j:80b^^J0<g`
TP3<jIL0dO6V0<OVX03;ijd0g_C50?_oi@3oonX0ooo]018J0`1OKE<0cn;40<GD]@3lonl0nooc0?oo
o@3imOH0ookm0?onn`3=bLH0FEQF00H41`0o?T@00`000:JTY@3ShN@0o_oo0?koo@3Vj]`0g>3?0?oo
lP3oooH00P3ooOl0;@3ooo/0oO_n0?omo`3mnol0oook02L^303<f:H0e^jT0=WeZ03=kj<0dOJY09bj
L03Gj:80d]nJ0>Of/@2HUeL0d>ZQ0<[ZW`3:giX0a>RN0=7_Y`3Ej:H0FEHS09^FG`3@chh0FUdH092G
D@3>hj00c>BZ0=g^cP3ioo<0oOSo0?oko`3on_<0oog_0?OogP3OlL40amnS0=3/XP3:iYT0dnRK0=SX
W`3JhIh0f>FO0<S[V`030<WZV`2f0<[YW@3:j9h0bNNM0=;^Y03Ak:D0d>ZS0<[VW039iil0`=ZK09^b
Q00oFB`0Sk1i08^bL@2ni9L0d?2T0>_o^@2OYFL0W:9V0<7DTP3MlZl0c^RO0<3LT@36iiP0c>fN0<WU
VP3Dl:D0f_B[0:o4O`2I[FH0//=l0=cdZP30hYH0aNZM0<g[X@3?iZ00eN6O09BOG@3Ojj/0dn:Q0<oS
WP3:jId0eoJZ0<KPUP3AjIl0VZeN0=7PV`3?fi/0Xjac0<gEW03OjJd0QY=>08jNE`1UNC80JWll0<WR
WP3GljH0gORY0<kYVP3>i9`0h?Fb07Z?CP3@iZP0c^BV0<[UWP38iiT0b^bH0<_^W03Fl:L0b=fH0=CS
X02Q[VT0K7hd0<o/V03>l9X0a^JK0=;_[03Aj[<0bnRb0<_YZ`3:jJ<0b^VK0<gXU`3Aiih0o?oD0;2h
S`3Be;h0l?7O0>o]gP3jo>L0mogQ0?7oeP3bomH0fojj0<S^Y@30h9d0cNNZ0>7^``3jomh0oooZ0;g6
Y`3ion40mooK0?Ooh@1eQ740E69C0=7L_P3Bfj`0`lJA05eJ;`3aj/h0g=c40<[H]033lkT0>G=00;cg
b@2nlKT0eNbL09fSF@1lN3T0T8YH0:6QH`3DfiP0h>^W0=OaZ03Cl;00V[ET0<_OVP3onOL0ooGh0?OX
k@3oo>d0e^2[08fQBP3EjI80cN>K0=W]/03<hjd0g_Fo0>kocP37gj40bn>U0=GY[P3:fj@0nOo]07V1
M03kooX0mO_g0?GinP3nool0ooko0?Sdl`3oo_/0b<6i0>kWg@3monT0n_oY0?Wom@3jo?/0noco0?_o
o`3iooH0MXUY055Z@03=k[L0`>>[0=CXX03BjIT0a^jH0<gXV`3?ii/0anbO0<g[X@3Ff9T0Mg`j0=7]
XP3?hi/0f^^T0<gNU`3Kk:D0_]::0<cRV@3EkJ<;0?ooo`002P3oool0202lf8d0eO>Y0<WWW`3ToKT0
eNZU049B4@3;gJ40d^Ja103o0000L@3OnnD0iooY0?3oiP3loml0ooOP0?ojk`0j9bT0=QlG0;baT`3M
nZX0cNZF0<k/UP3<kIH0a>6A0<[UWP3<hj/0io_80=SV/@3?fZ80G6HW0=[WX@3@iJ@0an6P0=?^Z`3:
iIh0b>BJ0<3JT031fi40hOR`0<oVX03Kl:d0amZH0<SGU03KjZL0`mB@0;kAS`3IkZ/0AehJ0<GKVP3?
jZL0d^fZ0<_XY@3<hil0UIYH0:2VJP3JhZT0JWA0000:003DjJP0fo:/0=C^Y03GlJP0Af8M08>NF@3>
hih0e>RS0<?DT02DYF40JGXf0=7RWP3@hId0PYMB0=?ZY03DkjP0c>NP0<_UWP3;iI`0e?2U0<c[W@35
iYL0a^FG0<_ZW03<j9d0bnFL0<gRW`26WET0bnVQ0;SFSP3Bl:P0b>JN0<GPV@3@jZ<0bN2J024b000E
8@00C5DD08bEE03QmK00b^BM0=?eZ`30hYP0cNRQ0<oSWP3QkJ/0en>Q04UJ5P36hIX0b>RM0<O^W`39
kZ00anNK0<WUVP3<iY`0d^ZP0=_aZ01eRd80g_J/0<SPUP3Uo;@0goJb0=O/Y`2O/6X0a=>>0080d=nJ
06<0]LR60=KZZ`3BiZ/0bmnT0=[[_P3hoo<0mOoW0<oW[@3<ij00bNZI0<_[V03<ij80b>:S0>god`3g
oml0looH0=KZ]`39gZ<0dnnU0<WXV03<jIL0`m^A0<[UXP35hZ80d^Vm0=g]d03lo_T0ooko06aWKP3l
nol0noom0?Oom036e;/0o?oa0?comP3oool0oogo0?_gmP3mnOH0ookk0?glnP3_kO00ooko0?Can03o
oOl0ooko0?_on@3loo@0i>oA0=OP`@3non`0oooc0?gko`3oo?l0oogo0?olo`3on?l0oo_o0?_ho`1c
MV40N89M0<?HU`37giD0bnRH0=?bY02leXl0UZ9P0=cWY@3Cgid0UI=F0<[TW@34i9/0dnZT0<[^Y038
j9l0d^VS0>Wd/02laX40CUP?0<cHSP3QlJX0cNFY0<kX^03coo80nOoo0?oio`3on_l0jo3@0=_S_P3F
jk<0cNNV0;cJU036iiH0c>^K0=S_X@2ncXL0en2O0=?OW@38ji/00`39jY/0]P3:jId0`MnE0=7_Y@30
g980V;=/0<_UWP3Mn;40d_:W0=Sf[P2F/740`]jS059g@@36k[X0_NR`0<[b]P38jjT0eNfQ0<kNU@1W
L2d0am:>0=GVW`38gY<0eO:R0<KUU@39jih0anVL0<;WVP36jZ80c^bT055R6`2;XeT0cNfR0;SJSP39
iI/0fo2[0=7LVP2<UE@0Xjm_0<SGUP3JkjX0cO:T0;oTUP3:k9l0b>ZM0=;YV@3Fk:@0b=fL0<[LXP3<
fj80g>^`0<oTW`3Bj:00c^RO0=?^Y`2?[FD0c>VI0<_RW037fi`0GFdl06YkA`3Bhjd0c^6Q0<_NWP3G
j[80eNVf0=3X]P3<jZ80cNFK0=7UX03LjjX0bmZI0=_[ZP3Bl:X0a^FR0<3LZ`3>ikl0hoKH0?;oh`3<
j:d0bNBQ0<cXW@3BjiX0dnZL0=GUY`39eZ40o_oM055G<`3non40nooQ0?Oog@3>iJl0`]jQ0<GYW`36
jih0bNNO0>?l^P3Nj[P0fn6e0;noV`3BhKX0c=jd0?OofP3fon00QI650004003^l^40m_[I051<9`3o
n]h0oocc0?oajP3oon`0`>Bf0;;W_@0mQ5P0]__40<OgX`34hi<0enJQ0>7QZ`3IfYP0D5DB09NQG03C
ij00bn6S0=C[W@3BhZ<0l^c/0?ccn03oo?l0oood0=CR[`2bagX0Zl1c0=od[`3Ikjh0dnb[0<WTX@3A
k:L0e^n[0<kTY03:g:X0dn:i00<80@3Fem/0o_oo0?kno`3cl_X0ooko0?Ccn@3hn?H0Z:RP0?ool@3o
onl0e>Bc0<gPZ@3Mj<P0l_[U0?kom03looP0jOCT08^XR@2igkP0?7A30;[ha@34iZX0anJS0;k/X`3>
k:80d>ZP0<OXU`35h8l0gMZE05aI5P3:h9P0fnJT0=c]Y`3CjJ00dNFM0<[PU`29WeH0cN>J2`3oool0
00X0oooo00T0c>bP0<_[XP36iYd0`]fH0;kES`2gaX<0L7i00=GV[`3;jL<00P3o0000e`22`Jh0jOoo
0?3oo`3]onX0o?oV0?k_f03on>/0;0lA02P;0`2`XXD0bnZL0<[WU`3<jIT0d>bO0<WTX@3Aj[40l_oL
0?Goh@3EgkX0eMb`075hA03RkZh0d^^Z0<[WY03;iZ40cnVP0=7XX03Aiih0f_2W0;kES@2neHl0d>VU
0<kSX03Ei:40JGPe030o003?hZ00fNbZ0;W@RP3Fl:T0an:K0<?QV@2ifI00c^RO0:6ZI`1EGB400@T0
0>Wa_P3:e:00c]bN0<?GTP3=iI/0a>2F09flMP1IMc40fo2[0>7e/03DiJ40d^>O09FVHP3?h9`0fNfX
07J;AP3DjjD0^]B=0=G_Z037hYd0c^VR0=7_Y@3>kJ40a^NH0<OVV03Dl:<0c^RN0<[QV@3;giX0JX4m
0<G[X039kj@0`NFK0;oQU`3BlZT0cnZS0<gTWP2kc8P0RYID0>3YZ01kQ4<0aMJB0=W^Z@3DkjP0aN2I
0<kUW`3Cij80cmjK0=3OW00lD0/0eNnX0<[ZW`34jI/0bN^N0<[YW@39j9`0bnFK0<WQU`2jd8L0X;I]
08fUF`3@j9h0a]fE0<7JUP3@ij40aMVB07V:A03>gIP0gnbW0:FfLP39fIP0eNZY0<oUY@3?hjh0lOoW
0?GohP3=iZ`0bNNQ0<WZV`39ihl0b^FP0<GLY03con40n?oX0?Wog`3Fj;H0bmnR0=3ZX@38i9T0bnNM
0=CYYP3=iJL0c>F[0=G[a03EiL/0h=oT02`V=036_ll0oOco0?Chn@3`oN/0lOgU0?Kmk@3kooL0m_Kf
0?omo`3oo_l0ookk0?kjm`3in?H0ooko0?Gdo03ooOl0ooko0?Wjo03kooH0noo_0>Sdd03Kil40nooW
0?kol@3oool0oOco0?kko`3oo?l0oo[o0?olo`3ooOl0k?3O03]49@3Pl[P0gO:_0;_FR@3BkZ40f_B]
0<WET`2PZFP0fNFS09jJG@3>j:40aNNM0=3WX@38kZ<0b^ZQ0<oYX03=giD0j?R]0>7_XP3MkJ80bMfE
0<_UZ03:i;@0mOod0?Woo`3onOl0ooSo0>[ebP3Bh:l0e>f/0=;`Z03:jYh0bN^G0<g]VP3<hYL0VjaU
0=CMWP3FiJ80b>^K00<0bNZK09@0b^VM0=[h[P31giD0//j40<GPV@3Fl:T0^mJ?0<3RUP3:jYh0fOB]
0<SUXP1SR580L9Y/0<KdaP2^fZL0^nFV0<;STP3=iYD0a]2;09bWHP2BY5X0c>6F0<o/W03<ji/0bnfP
0<OYW034j9h0aNVQ0<KVW@3=gYL0X;Q^0:k>P`3;jj00aMnF0<oSWP3Mj:H0V:5P0:bhN02]_7/0amjH
0<?XVP37k9h0^=Z=0;oQU03@jIP0`=NA0=3VYP3gom<0e>N_0<OKWP34fiD0c>JM0<STVP3?kJ<0_M^A
0;3=N`3@iJ80amZS079nF033cjL0mOoD0=_[[03?gj00ho?20>cle`3donD0g?Vg0<cSV`3BiZ40b=JH
0=SVZ03Ai:80d^n/0<OUY@37h[D0d>S60??oj`3con<0bnB[0<oXY`3EkjD0b=n?0<7HR03Un;H0b]VN
0;2lRP2]]XL0d]j`0<WKZ`3=hJh0b>BW0<GTX038kIl0b^fM0<7PU03>iIl0e^6Y0>;Y]P1>Cb<0cn2c
0<?IZ02odj00dnFk07J1L`032@D0oooc0?ooh`1HDc<0oo_Q0?ohl03on_H0ooo_0<g/``2hil<0@h=N
07:bP035m:<0anZJ0=?ZXP3CgZ80i?6Y05iX8@1HI1`0cMjH0=OY[@3Bii`0enFX0?olo@3ooOl0nOOl
0?Wol`3Bh[40cN>J09^aJ03<hid0cNBP0=Wd[@31gI<0d>bQ0=?ZY03Fk:`0]LJJ0=3N^`000@00J6M]
0?Who`3ooOl0m?7j0P3oo_l0803Ce<h0^[b_0?kok03MhlT0b^>R0<_VX@3ChkH0fnC50>W^f03ooo@0
o?oc08BNP@2efkH0FiIZ072bQ036kKP0a^b_0;_`[036ij00b>NK0<S/U@3=iY<0i>2I05eJ5@3<h9T0
hnf^0<_OV03=iI/0hON^0>ko^`1/PST0gO>Z2`3oool000X0oooo0:P0an^Q0<3VW@36jjD0b>NS0<WR
WP3?g9L0g^VW09VQIP3;fZl0en_80>Con`1<Thl0Ym7W0>goo`3kool0mok^0;FYT`3onN`0BahQ01T0
002?PF@0bNZS0=7/Z@3?ij/0i?_50?Goh`3don`0lOcd0?Ooo@3nooP0o_o`0:jaUP3EgZl0cNNX0<WX
XP3?kJD0cnFL0<kRVP3?giP0DF8K0=CZXP34fiD0X[eh06j7@`19FAP0T9aL09NVI@39gIP0eNVR0=G]
X`0oF@l0e_:U0<[YV`3=kYl0`^6C0=CSWP3Dh:80Uj1W07^2C`2a]H<0dmfP0<WET`38h9H0bNFK0;WM
U@3=kZL0TJIQ0<SLU`3Dj:<0bmnJ0=7UX02<X5/0M8Q309:WHP3Kl:/0bn2K0<gTX03Dkj`0`mjK08RV
GP2bdXL0anNK0<_WVP3?jih0fNnV0<_OV03KjZL0QY]F0;oXW035kZ80bNfS0<S/XP3>kZD0e_B/0;kI
TP3Ilj`0cnBO0=ga[035fI@0G6/X0=OVX`3GjjH0d>BO0<oSWP3@i9l0eNVT09JZI@0@9@00`MRB0=Sb
Z@39jih0a^RK0<SXW03:jId0b^JK0=7[X@3=iI/0b>2F06n5?03?iI`0bMnF0=K`Z@35giP0cnVP0;W@
R03=g9L0c]RC09>MF03<ei80bn6H0<o[X037i:40hoS?0??of`3<iJh0b>:U0<[WY039iXT0d^RX0<[K
[`3co^d0nood0>kie`3@gJl0c=jR0<kSXP3?iJD0g_:m0:ViRP2U]hD0GgE4086GL01[Nf40bL[?0?ol
o`3on?l0o_Wm0?cnl`3Sl=80jOKL0?_ol`3`mNh0ooko0?C_m@3oo_l0ookk0?Ocl03oo_`20?ono`0h
0?kko`3nool0n_ok0?Sok03]nmP0f>Zf0=7T[@3TllP0k?WK0?_on`3inoX0ooko0?omoP3oo_l0mOGe
0?ooo@3noo@0i>cE06]gC`34e:<0hoNl0<OMW@3:hId0dm^O0>CZ[01LIRL0DT`B0<SRV`3;jj80c^FO
0<GZW@3=kJ80b^RN0<CSU@3>ji/0aMj;0<oXU`3Flj<0cNjY0<OVZP3eonP0nOoc0?omo`3oo_D0f>j]
0<GPV`38jIX0a^VG0<S^V@36jY<0b>ZD0=;ZWP2=XET0dmnO0=7QX038ji/30<WZV`0Y0<[YW@3AkjD0
cnfS0<7MT`31g9D0_]RA0<kYXP39jil0cNjM08VVDP1_ST00bo2j04aeB`2Sd[80^^c60;CW[`36mZ00
`njE0=;ZX02le8X0eNfQ0<[RU01ZQCH0/lio0=7[X@3@jZ40b^BM0<_VX`3<iJ40cn>K0=3XWP2XaW`0
Dg4W0=3VWP3FiJ80YJ][071f=P3>fYX0Wjm^041E403NoK400P3:jId0R`3Al:@0do2P0<gXX`34gYl0
c^N`0>goc`3Nn[l0c^fW0<SXW@3<kZ40bN^O0<g]X@2^bWD0Yk]n0<[K[`3_n><0o_o/0?Kmg03Mj;00
bMBJ0>[dd@3doN`0mOoh0=cb`@37gI`0_M2@06]i?03Hj:L0c>>M0<[ZW`34iIh0lOoH0>gofP3^oN00
n?oX0=CV]P3>hZL0`]ND092WE`25W4`0Uj]T092TG`2Q]7@0c^6O0=;WY03>j:L0b^VV0<;TVP36j9`0
bnjL0<OYU@3;iYL0dnVN0=3LVP2h`XD0YZ]a0<[SXP37iZ80e>f[0<_PZ01]MF0000800=gJa`3Bd[00
GUXd0?;]c@3om^D0oood0?Wok`3`onH0i?o[08R`UP0gGcX0dONZ0<g_XP2lg940d_Fa0;gTT@3Gk9d0
U:9G07F2?@2nbI40e^6L0=cU[03jnod0o?oo0??ho03hooH0b=bW0<GLV03Uo;P0[<Io09:/H`31gXh0
dNjJ0<WUT03:hYH0d>FT0<[H]03ann80oooo03Ld>`3kn?l0n_Gl0?omo`3ln?T0`Kfj0?cok03jonP0
nOoO0<oO/P31jI<0_nZ>0<oWZ@3PkL40lOKH0?ool@3onnl0loo[0=;Uc`2oil`0Kj230:SG[@2^h[40
/?:e0<7^Z@35jj00b?2H0<k/UP3MgI<0RXa30<[TW@3Ai:80e>^S0<GOU@38hYP0eNfS0<WQU`1FK2<0
2`3oool000X0oooo06h0`N:K0<CYX`3:kjX0e?>`0<CMV@39eY40gNJU0>7WZ`3Uk/<0f^G30>?om03;
ool0S[cD0>[oo`3lo_l0mO_a0>7F`P3oiMP0MDM903@C2P1EC2l0bNZU0=?][03>iZX0fO2j0=cabP3R
m=X0lokf0?Woo`3`lnX0oooa0<G8[@3Gh;40cnVZ0<o^Z03=jj<0c^BK0=7UW@2__gH0dnBM0<[PV036
gIL0a^6L0=7ZZ03<gil0eNBS0<KEU03Tn;<0]l^40=[bZ02L]V`0h?f]0;_JRP3<kI`0anJF0=o`ZP3L
jZ`0c=NM06Yb?`1JHBh0VJ=V0=CPWP3HkZD0d>ZQ0<7RV`3?kZP0UJUT08BIE03:giX0fNjY0<kSWP3F
jjH0a=VD09^_JP3AiJ00am^F0=?XY@33gI`0foJc0<KTW02=Zf40`=nC0<STU`3AkJ00a]bC0<gQVP25
U540^Lf80<KXWP3;kJ<0c>bS0<k^Y@37iId0d>jV0<SVWP34hYX0anFM0<WWW`3;iIh0enJS07:1?P3K
jZL0bmZG0=3QW@38g9L0e>VT082ED016FaH0c^:M0<_RVP@0bNVM02P0b^VM0<o[X03<i9X0cnNM0;[@
Q`3?hi/0d^RO0<_UWP3CkZL0_=ZB0=ObZ`2V]G00h>NT0;_0O@3=ei80h_R]0;_JS03=kJ@0fo?30?Go
g02oeZ80d^Vc0<;LW`3=ih`0bMfP0=?R^@1jPW<0noof0=SQ`P3@gK40d^6Z0=?UZ`36fJ80looH06Ue
C`3@hK@0dnVh0<WP]03VmmL0o?km0P3ooOl02@3oo_L0ooo/0=CP^03=f[h0o?of0?con`3oo_l0oogo
0?ono`020?onn`0@0?ooo@3oo_l0ooko0?ono`3gn?X0n?gg0?Koi`3Rl//0e>V^0<kTYP3Di[@0i?C?
0?Wom03looP0oooh0?_kl`80ooof02T0o_od0?col@3Pj]80=T4Q06IeCP3@h;40dnJ_0<cRX@3IhjL0
i^b`0=_UZ02PVV00dNRT0=;aZ`3Aj:80cO:U0=OeZ`37iI/0b>ZN0<WYW@3<jIL0c>VE0<[ZU`35jYd0
^=bF0=;Z^P3hon<0ooW[0?oojP35h9T0d^jT0<;STP36jID0b>jG0<7USP3=kiT0d^fP08ZPE`3Dhj80
d^JQ0<S[V`030<WZV`2f0<[YW@3;jIl0a^BJ0<STVP3?jZ<0cNNP0<gXX@39kZ40d?6P0=;_V`2R_fl0
^MbT0;oX_01HRFT0WM6Z0;3U/@33n:H0_nnI0<SZWP37jId0cNbP0<WUV03=j9/0c>BH0=;XW`2[_gP0
eNJR0=3PX@3Di:<0b]jF0=G]X`3?kJ<0aN6G06=g<03GiZ<0UYaL05iT903>fYX0eNFT0<cQW02/a7X0
d^ZP0=C^Y035giD0d>fM0=7/Y`2leYL0a^6/0?;of03PoL<0anRS0<oaY`34iYT0b^bO0=3aXP38i8l0
e>R[0=3Q]`3koo<0oOo`0?kojP3Ni[L0dm^X0>[`e03looH0nOoo0>;hbP3=hJ@0dN>W092NH@3:gYL0
dn^O0<W[U`37jYX0gofm0=cd`03Zn=D0nOoX0>7`a@3Mk[P0]lV;0<?HS@3?i9L0a]bC09neK@3?iId0
dNNO0<[TVP2ogiH0anRQ0<SZWP38jYd0cNjM0<WYUP33fhd0e^bQ0>Ke/01OJbT0d=ZK0<oZX`37jI`0
cn^P0=7WY`1VKe@000<00>7OaP3Kg;80T91N0>OU_03`km<0loST0?OojP3Gl/T0i_oV07RLPP1aUg00
`^^M0<C[W033iid0bNjY0<G_V`3Dji/0cmnD0::]J01/Lcd0g^RS0=KNY@3lool0moco0?Koo`3goo@0
bn:Z0<gTX03@iZD0c^RQ0<KPU`2>ZeT0bnVC0=7]UP3AjId0cN6R0:6/RP3lonl0o_kl0?Kdm`2i];P0
ooWm0?omo@2^ZjH0k>WP0?oojP3jon80nOoJ0=?U/@31kI@0]nJ80=;_[`3kom`0oooV0?ofjP3on_40
oog`096HR03Sn^P0]]G305:0F`1d[Wh0Y>^a0;KWY@32k:80/mf70=7cW03OhiL0EU`B0<GUW03Ck:P0
cn^Q0<_WW038i9T0dN^Q0<gWW@2gchD;0?ooo`002P3oool0KP38ij<0_n:N0<S[Z@1BL300JX=20=WU
X`3MhjD0f]fT06=X?`1NI480NIJ40<Coo`1fZ;l0f?Go0?cmo`3lood0ooSV0<2VV@1V>3X09P/005YG
>03;jZH0c^NS0<OPWP3?ijT0d>Jg0=CX``3goo<0n?of0?Onk03oonP0^knL0>3Z]@3BkJX0cNfT0<[X
WP3?ii/0d^RM09naI`3>h9H0eN^S0<gTWP35h9d0d>VW0=OZZP3FiZD0dn>R0=CXX`3:h9P0a=bB0=_c
Z@2edX80f_NW0<;RS`3JmjL0dNFN0<kNW`3Fi:T0^<:>08VAGP1KIbT0W:]X0;W?QP3Aj:00^mVC0=Ka
[02ndXd0U:UT0<cQW03>hih0g_>^0<CIU03Nljh0d>BO0<[NV@3PlJd0d>>Q0<_SY@3;i:<0eO2[0<o]
Y@3=jj40Uk=X0<o[WP3Ejj80Yk]d0<WHU@3Cij80c>NP0<oZX`3=j:40e>nX0=Wd[@30fi@0c^bT0=?c
ZP36j9h0eOV_0<o_YP36fYD0YKIb0;_7Q@33chd0dN:N0=O[YP33fY@0V[5[051U803Bhil0gO6Z1039
jId0=P3:jId0c^ZO0=G_Y@3Dk:80XkU`0<[NUP3JkZH0bN>L0<k/Y038j9l0d_2X08BCCP3?e980Ph=3
0<G:Q`38gi40bNZI0<OYW@3Klkl0g_C30>?ibP3BiKL0f^jk0<gTTP2@XVP0_<VN00@;003ZlN40iNc=
0=7L]03Ghk<0e^Bc0=;R]@3]o=/09C0B0=CU^@3;hK00b>>`0>Wne@3goO40ooom0?onn`3ooo40oooT
0=OT]P3>fK/0n_of0?coo@3oo_l0oogo0?ono`3oo_d0ookk0?ooo@80ooko02l0o?_o0?[on@3kooH0
m?oT0>7da`3=iJL0bnBR0<kV[03Ik;h0lOoV0?_ol`3noo@0oooa0?ook`3non`0nooY0?_ok03^nn40
M85S00LE0038ejh0f>Zj0=O][@3Ji:P0c=BI0=?KW`2CS5D0]<^70;KDSP39gYT0aNNK0<KRV03;iid0
a^ZP0<SZWP3:jYL0b^ZE0<W[U@3Amj@0a^^N0<WRZ03Xn<T0oooT0?Sje@3:iIh0cNVO0<_/V`020<[]
V@070<S[U`3<kYX0b^FH09V_IP3Ci:00dNJQ0<S[V`030<WZV`2c0<[YW@3<jZ00b>JL0<kZX03CkZL0
d>ZS0<o]Y@39kJ<0a>FF0=?_V`38hiH0goo50<G[_02:^ID0Fi1V09gCW`2Zh9@0^^fN0<G_Y@2li9/0
a^RL0<?SV03:hYP0cnFL0<oPVP2N[FX0UZ9R0<K@T`3Pk:`0cn>K0=?[X@36hYP0b^JL07V:A03AgI/0
TiQH055G5`3NjZX0e>BS0=ga[02^a7/0Zkmg0;77OP33fi40a^6B0=kg]@36h:<0a^6/0?3of03Gm;`0
b^ZW0<k`YP3:k9l0dO6U0<c[W@39iI00d^RZ0<oP]P3koo@0nooc0?kok`3OiKl0fN2g0>[_f03looH0
n_ol0>Cfc03Ll;D0bmfQ09>QI03MlJT0bnJE0<S/TP31ii00d>nY0<oY[03[mm40nooZ0?coh@2oc9h0
e^F/0<[NUP3Cj9d0e>ZR0;_AR@3@j9h0dNbO0<_XV03<kZ40bNjQ0<7VV034iiL0b>NG0<SUT`3Pn:X0
bMnD0::cK02O[VT0h_6/0<SYVP33jI@0c>VG0<cSW`1TJdX00@<00=_K^@2;Se`0`LN;0>3W/@3Cf;00
o_oX0<cG]@37hK80c>_907NNP@27/XL0aOBT0<GbX@36kj<0_N2L0<OZV03;i9<0fnfQ0<?>R@2e^X@0
dMJC0>7Y/03kool0m?ko0?Koo`3eoo40bn>W0=3WX@3?iZ80d>ZS0<[VW02;Z5@0anF?0<gYTP3>i9T0
fnf_0:B_S`3foN/0oOki0?_jn01iMG@0oogm0?C_j`26PG/0oooc0?;ff`3[mM80h_C20<OJX`3<n:40
`?6F0<;NX@3Kj/40in[?0?oll`3om>d0oocb08R4N03`nnd0f^SK06:@K01FU6<0GZM_0<Si^02hhI/0
f?n`0=3bWP3MhiT0IVhU0<cbY`3:jJ<0b^RN0<KUV@37hiP00P3@jZ000`36gY@0oooo0?ooo`090?oo
o`002P3oool0AP1XOT00b>6W0<_W[@31gJ<0bn:Z00LB002DVF40clnK08F3G@27R6T000L00<?_h00j
M7P0eooo0?Kio`3jo_l0oo[^0<2ZW`2DLW401`0003m99`3@iJ@0dnjO0<cZU03=kYL0bnRH0<cWX03;
hZX0d^Jc0<cJY@3NjK40g>JW08bID@2ne8/0cNVN0<[VV@3;iiX0d>fM08VTE`3CkZ40e^fU0<oVXP3E
jZT0a]^J0=S][038gIX0e^fY0=S]Z03DjJ@0dNRP0=WaY`2oehd0B60F0>So]03Gkj<0cn>L0=OZZP3?
hJD0cn2Z0<OHXP3BiJD0g?2[05=T7@0O;P00ho:a0<cKVP3Cij80bn2K08VPFP3JlJ/20<WPVP0W0<_R
W037fiH0dnBP02di003lolX0go>h0<;FV`3Fk:/0cnRT0<WSW03:iY/0`=bA0<KNU02I[fL0^ln80>3d
[@39gYT0dNJQ0>;f/@3WnkH0eNZU0=3WX@3Nn;40cN^S0<GWW@3Tokl0Zln50<gXX@3JkjX0bmNE04aG
5@3Bhil0dnRS0<WTW@3:iIh0eNbV0=[VY03Wm[40b^VM00@0bNVM06l0d>nS0<kZW`3Lm:X0Y;Ya0=WZ
X`3>hYX0bN>I0<SXW@2igi@0a>FN0=gYZ@1GEa/0SXQ<0;nnOP3PmZ/0c>nO0<O^W`3Omkd0kooB0?So
iP3ionX0h>[?0=GTZ@3:f:D0fNFg0?Kmf`3@eKD0j^oA0?koi`3cmm`0o?o/0?7kh`3Yl]l0MWiY0=3Q
]037hJ@0`n>H0<CQW`3ionH0o?oa0?oomP3nonh0n?oN0<kK[`3]n^00o?oj0?_ooP3oo_l0ooco0?om
o`3oo_d0oooj0?ooo@3oo_l0oooo0?kon03koo40nOo]0?Ooh`3Pm/D0b^NT0<g[X`3:j:00aN:R0<oW
]@3Ij/H0o?oc0?kok@3jon80c]nY0<SKX`3Nl[d0_M2R0=SX`@3hon40nooM08:DI01[QdX0LWm70<oH
W`3>f9`0YIiX0<OLV@29Y5l0cMbI0<o[X@3Aiih0`mVA0<KZY039j:80b^VI0<[ZU`39jiD0`nVB0<W_
W031g9D0d^BX0=WK[01<D1h0d>VW0=7ZZ039iil0anNL0<SXW038jIX0bnZL0=3/X@39hiT0c>>K0<WS
VP38ji/00`39jY/0X`3:jId0b^RN0<WWW@3<j9h0cNRQ0<oYXP3DlZX0c_:Z0<SVWP3?hih0dNFP0;[D
U@39j:d0fooA0;?T[@1o/G`0Bgi60;GW[02_g9/0]^2P0<ka[`33hYh0e^fW0=GYY03KijD0hNbZ0<WC
U01CFal0Uj5R0=3VW@37giD0e_:X0<7KTP3VmK00dmbK09ZLG@2OY6@0dMfM0=g`[P33f9<0cn>K0<GI
T@3Unk80Igdd0>3eZP3;h9l0f>fd0>goe@3dom`0an:_0<GRXP3Bl:X0b^JI0<_WVP3BkIh0bnRD0<_T
X`3<h:l0nOoa0?Wom@3nooX0nO_^0?ool@3moo00o_oc0?_ok@3Vn/T0dNFX08>EE`1;FaX0e^fO0<cZ
U038l900b>nD0<_YX@39hJD0j_CA0?Cgi03Pi</0Ph]V0=3IZP3Okk40a=NE0=3WX`3;i:00bNFJ0<KU
U@3:k9P0anbL0<;YVP3>l:<0cnnS0<gWW@3BjZ00PiU@08nUG03<i9X0dNVO0<gUV`36k9L0a^jE0=3a
VP3Aj:00LWYE018G000b>0X0WJMX0=?YU`3<hYL0dnVY0=KN[@3JhJd0dn^]0<;R/@2;_YD0N;5l0<;o
ZP31n:@0^^JI0=KZZ`3LjJ40dNbK0<cWUP3Mj:@0WZ1^0>OZY`3AeYh0nOom0?Goo@3doo/0mOoX0=;Y
X`3BkJ00bnFL0=?_Y@3=jIl0RZMG0<gZUP3@k9P0h_R`0<CFVP3MilD0o_o_0?komP3nooP0oooj08J3
OP3nm_<0oocf08b5N`3koNL0m_gN0<cL[`3;gJd0a>RR0;cQV`3Ai[/0m?kS0?cmk`3omoH0oo[j0?ok
m03hjn800P3ooo<02`3>l/h0Ymf/07fnQP3:lKX0bnR^0=Sg]03DjjL0kNf]08R?C035l:40^n6D0080
bn^O00@0bnZN0<[VV`3;ii`0cn^P2`3oool000X0oooo05H0FfXa0<oS[P1FKSX0Ih9=06MnBP1XLSd0
Zjml0=;AX@1kN5D0LW5E0006003:k=@0:fMO0:kOh`3iool0o?oo0?oll`3]fM00WHF10004000W>1H0
k?Zm0<kYW038jI80bNbB0<WZT`39j9P0d>VW0=?YZ`35ei/0eN>U0=kZZ01cPCH0Y;Q`0=7YW`3>jI`0
aNBD0<c]W027Z5T0fORZ0<oYX03>hj00cMfN0:BdM@22VED0N95=08^TH03?iZ00[/Eo0=GZY@3?iId0
e>ZR09>YH@1QMbh0Yk]c0<[NU`3BiJD0dNFX09^bNP1LLc/0_]BC0=?XX`2``7T0M7lk0;VoP@3Ki:D0
d^JQ0<SMV02@Yf40`]bE0=3ZX`3<iYl0f>nY0>;f/@29VUH0aM6?05iZ;03FiJh0j?[00<oUY@3@jJD0
d>ZS0<o[X03Ckj@0TZYP0;oGS@80d^RP01H0cnJP0=7XXP3?hih0_=2;07F9A01TN3<0LXM20=3ZX`30
fi@0`MnG0=gm]036j9h0a=jG0=[VY01GHR00fNZV0=_b[03Mnk<0cnZS0<gTWP3Vkjh0^lR30P3:jId0
LP39jId0b>ZM0<SZW@3AlJD0bNFJ0<gUV`2T^W40g^nX0=3QVP37hiP0bnfQ0<7ZWP30i9`0fNFW0=oN
Y@2FRe<0i^:U0=3VWP39kZ00^=jA0>Ol`@3comD0jOKL0?7ji`3Wk]h0AE0U0=ST]02CW6d0o_oG0?oo
g02;SW40If]D0?kol03Yk>40o?of0?_ol`3=eL00d^Ja0<7OV@3>lYX0d?>S0?7of@3^n>00oook0?oo
m03io^P0fNG10?Wok`3loo/0o?oo0?omo`3onol0oogo0?ono@3oooX0ooom0?ono`3oood0o_oc0?Cn
i@3^nml0mooQ0>3haP3:j:80b^ZO0<[ZWP38j9l0b>BW0<_P]@3ioo@0nooa0?Woi03Bj:P0cnVR0<OP
W03?ijT0j_k90?Sof03@hJd0d^N_0<7OX@085`0000/00<_FVP2PVf@0fo2]0<CMV@2>VUP0cnVP0=;S
W03Tn;40a^ZR0<WYX03<j9/0b^ZG0<W[U`30iY<0d?FU0<7NV`3>hJT0l?7705]N<@3Vo;h0l?o80<cU
X`3=j:<0d>jV0<SWV`3<jil0cNVN0<7MTP39hiT0c^ZO0<S[V`<0bNZK0;H0b^VM0<KTVP35hiT0bnNM
0=7/Y@3Pn[<0jOno0<?WX@37i:40c]jP0=;PX`3Kl:l0dNj/0;[TXP34l[@0`o:k05R7F`2@_Y00aNbc
0=;h_@36iJT0d^n_0=3UY03<gid0hO2]0<oNV`3>gI`0Y[Ed06n0?03MljX0f?2V0<WSVP3=i9`0d^6L
0=[SXP22Q4D0XjEV0;[6QP3JkJ/0goB_0=7YW`3MmJ/0a=bB0=3XWP2Y^G00e>BU0=KW/03fom`0mOoM
0=C/_036h:40c>NR0<[UV03>iYP0bn>E0<cYU@39i9l0bn:/0?Wok@3hoo<0o?ok0?_mnP3noo/0o?oa
0?_okP3[mm<0fNbd0<oTX`2HZfT0V:UU0<;KRP3KnJ<0bO2E0<O]UP3<jJT0d>Nc0?Omh`3ooo<0Fee8
0?3ee@3Cg;40h_6h0>ooa@3@iZH0b>6O0<o]X`37j9T0co:N0<K[V`35k9d0bnfQ0<SVW039h9P0cnFM
08fSF`3@iil0fO>Z0<WSVP3Hm:T0`^VH0<7[U@3<k9T0bn:L06]bD00;4000L7Q90=_ZY@3<iXl0do2L
0<c/X`3:gYl0f>RW0<GPV@3Al;L0OJQk07^^MP2lm9d0aoVT0<G^XP3>h:@0fNBO0<cYV@35i9@0f^NR
09BDHP3IfYP0g=nV0?Oon@3eooX0l_oh0>[of03Aii`0d>VH0<cWVP3AkJ<0b>BJ08bXF`3Cl:00cNRI
0=GZY@3Bi:P0g>K40>caf`3looH0k?;X0?Gfl@3mnOH0=bl]0?_cl@3fknT0o_c]0?ook03Ulll0c=be
0=7/]@3;iZl0g>_<0?Wol03ko?H0oo[k0?oln`3ooO@0g]K90?kmj`3oonh0b>Bl0<;^_@2RfJ80Mi=P
0<WKZ@2odYX0d=jS0>;LXP22Q4D0bOBU0;cSU039jId0bn^O0<c/X038ii/0anJJ0<WXW0/0oooo000:
0?ooo`1a06Q_?03JikT0_/nR0<gS]@3Sm/T0<CX;0;^nT@3Edj`0gMVn0:VWTP001000VZb6000b5P2?
bK/0mooo0??dn03om>l0jMK@0=cCc0077`L00ah00?3d`@3>hjX0b^VU0<W[X@3:k9l0bn^P0<?PWP3@
jJl0jO_70>Gc_P3;f:80WJU[096NF@3@iIX0c>NJ0<7TTP3:lY`0Rk9Q0<3UU@3=iih0d^FS0;JnPP2G
XfD0b^>O0<k/YP3>jJ@0aMjJ09F/J02Z_g`0goBa0<oOWP32dY40SYeL08ZIEP3Bhid0dnRW0=C/[P1E
LSP001000<GTX03;iYl0d]nI0>;WY@1iLcT0U99G0=O[YP35fYD0dnfV09>]IP2X`g`0c^RQ0=K]Y`36
ei<0Z;Md0=3KV@3SkK00fnF`0;k;U@2<WV00^m2?0=;YY@3=jIl0d>bQ0<3LT@3Jm:X0c^FM0=C^Y@36
j9h0b^ZQ0=7XXP36fiH0U:=P0=OSX@3JiJ<0M7lm08fIE`3Ei:40f_6[0;SQU@3AlJP0fnZW0=[VY02M
/F`0Z/En0=CdZ`2kfI40eNbV09fSH`2h`Gh0c>RM0<[YW@39jId00P38jYd0K`3;jil0c^ZO09ZbJ02E
Zf80d^:K0=c]YP3@jih0`nFH0<C^XP3;l:X0f^F[0=cIY01WEb@0S8=<0=K[YP2khIH0`nbP0=7VZ`36
ejX0n?k`0>c^j@3no_h0l_[S0=oX_@3KiK00g^NV0=KLX03If[/0g]o?07akN@2EUY/0MgQl0?con03S
kM@0bnBR0=KhXP31k840coNF0<cR/@3;fL00noko0?coo`3kool0nOof0?Wom03jooT0nooo0?klo`3o
o?l0oogo0?ono@3oooX0ooom0?ono`3nooX0o?oV0=CP_03:f;D0l?oL0>?kb@3=k:P0bN^N0<OZUP39
k9P0b^^L0<cT/03iool0nOok0?Soj03<j9d0a^N>0<SYSP31hX/0dN^Q0<GLUP3Ll:T0fO>/0=3b]@3>
hJT0f^V`051N8`1iM3d0f^f]0=?ZYP3Yl[40MH]30=GRW03BhY/0b>ZN0<[XWP3=j9/0c>RK0<[YV`3@
m:X0_>6K0;_FX@3homd0o?cR05MH>@3WmlH0loo@0<kSZP3;hjD0cNJU0<cWX03?jj40`^6E08b[G@39
j9X0c^fO0<S[V`030<WZV`2a0<[YW@3@kZ@0b^RN0<OSV@3;iYl0b^BM0<_YX@37ij@0kOo<0=_T]@3H
h:l0U:=P0<oVUP30ii@0aNnS0:kJW`38k]D0GWmZ035;7P1GKT80Rim/08^NI`2odID0dNBT0;kCT03F
kj/0_]VB0=Gd[P33hIT0YK]b09VaI`3GlJP0cNBL0=cYY038cXh0^;Qj05aN7`2]^GT0fNbZ0=_b[03H
nZd0f?R/0<SXW03;jil0c=J?08F@E031cYT0f>Vo0=SZ`03eom`0d>R/0=?YZ037g940bmfA0=G/WP3<
ji/0b>JL0=7[[03honH0mOo`0?_oo`3jo?l0o?ko0?col`3lonH0d^BZ0=K[YP2ebH40YKI_0=KWX03J
lZ@0b^NE0<W^WP31iih0f_?90>[mh@3nooX0ookk0?gkkP3Jg<@0b]2/0=o[^@3Um/00amnU0=3Y[`3=
k:P0aNNK0<S^V`32iiT0bNjQ0<CTV`3;iZ40e>VX0<OJVP2Y_Wd0cnJR0<g[X`3=kJ80bN^O0<O`Y034
kJ40c>bQ0<oUY`1WKTl000@00<cHZ03:gYL0doJH0;KMPP3<mjL0_?BK0;;ZR@34ji00an:O06QeBP1f
Q5<0d^ZL0=3/W`36iYd0bNNY0<g]XP33kIT0d?NT0=SWXP3KgJ/0W9]J0=WJX03bo_80m?of0?3ol@3B
iKL0cN6<0<gWSP3?k9P0b^JI0<GSV@2<Z5h0_=R=0<SRV039gYd0b=NN0?Kmf`3lonL0nooh0?Oon`3`
l_40ooko0?oko`2/XJT09Q/S0?cgm03oooP0moo]0?Wok`3@fk/0gnS90?komP3nool0n?Wn0?gno`3l
ool0hN[I09NQR@3_o>00nOoZ0?Oog@3<ik@0^=fY028Y00061000RX]Q0=gJ[`3fi;@0M6df0<;WV@35
j9H0anRI0080anNK0P39jId00`38j9`0oooo0?ooo`090?ooo`002P3oool0KP0?7@00OXmI0<[NZ@1:
HRh0DVXf04II8P3?gJP0gNNe034c3P0A4P00X:F50=OY^@12OEd0Tlfo0?Coo`3io_X0oo[_0<2]YP2j
]K400100024h6`3IgJX0bn2X0<OWZ036iZ<0b>NS0<SWY03:hjX0j_o>0?SofP3bom40f>Ja08NEE`2C
X5/0c>:I0<WTU`33iY@0cO>P0;OJRP3AlJD0d^NR0<gMW02NZ6`0U:9U0=G`[@37i:40a>:L0<SQW@3P
m[D0NXm>0<cQWP3Hj:L0d^2R08fIF`2f`X80dNJU0<OOX@3;i:/0HgM6000?003AhjT0g^b^0>GWZ03H
dYP0dlbF08V8D02neHl0f_6[0<WSW02U_gP0I7hg0<[TW@3GkZP0f>bW0=o`[01fPT00d=nN0<GIW03I
kJh0dnNX0:2eM024VeL0dN^T0<gWWP39j9`0aNBH0<c/X03:jYh0a^RL0<[ZW`3@k:80dN^R0<;FS`3@
hI/0g>^V0=OVX@3Tljh0LX4l06j4?037k9l0`^2F0<KJU@3Hj:L0`mRG0<GPW@2U`Wl0eNj/0=3SX@3W
jjh0CEHE1039jId0:@3:jId0bNRL0<[TVP2;YE/0WkM]0<cRV@3Aii`0dNjN0<kaX@34jYd0aNNM0=SS
Y`2MVVD0TXAC0=7:U03;h9/0`NJI0<oeZ03:gj@0enVi07EnJ@1fO700o_ok0?;mg`3Dh[40cmfP0=OT
W03Dh9h0eM^g08R;MP3PhM/0no[o0?koo`3ennl0VJB4086KE03<kIH0]n1j0<S]T03<h[<0bm_10080
nooo00X0lo[o0?Woo@3kooH0o_oj0?ooo`3nnol0ooco0?omo`3oo_l0ookm0P3oo_l0>P3oooX0o?oV
0=_Z``3@h;T0mOoQ0?Gog@3ElKH0d^n]0<WXW036iIT0b^JL0<oS/P3gn_l0n?ck0?Ooj03<iYd0b>J@
0<OZS03<kI80a^>C0=G`X`3?iYP0a^6D0<;SWP3EjJX0b=ZN00XI000T8`00dn>T0<GJU@3;eY80g?:Y
05ma9`1GJ240b^RP0<cXWP3<j9d0b^VM0<WYWP36jZ@0`>>Q0<?NZ`3homl0oOoU0823I03Kk;P0hOBm
0=CY[P3?ijT0cnRW0<cSW`3Aj:80dNRP08jVG03>j9h0aNBH0<K[V`38ji/20<WZV`1o0<cXW@3<j9h0
an>I0<WUV`3AkJ<0c>NP0<_YX@37iZ00j?o30<[GXP3Li[40PY5>0>co]039jY/0cO6Y0=goaP3Bl=H0
e>_A03Pm50003P00:T/L086XL`1@Kc@0BF4U0:2^L@3ChJ<0fNfX0<o^XP3<jid0`mB=09fcJP3:i9/0
f>nW0=CSWP3LjjH0]kEh0;NgN@2IZVH0RIUH05ib;@2ngI40bnVO0<[XWP36iIT0f^^T09b_K`2O/GL0
c]nc0=o_b03hon40cN2Y0=K[ZP2AYUT0PYM:0:c2N@3<ji/0anNL0=?][03hon@0mOo_0?_oo`3fn?l0
o?ko0?con03lon`0c]bY0<cNXP1JJBP0c=^H0=?RW`2odh/0fo>Y0<_ZY039jJX0k?oP0?Gok`3kooX0
mOOZ0?ooj03oon<0l?O>08jJJ02iai80aMZQ0=cd^P3<jjP0b^^T0<_`X`33j9/0c?6T0<KTW03<ij00
^m:>09V^K@2U_7P0foB`0<WWW`3:k:00bnfQ0<;[W`31iiX0c>ZP0=3XZP1YLU<00PL00=OS]@3FjZD0
dNnE0<ocV`2kh980^oBF0;_eT@31hhd0e^NS07UoC`064000N95?0=C]Z`3Ck:X0cnVX0=;dZ034kid0
`NRG0=?WX03KhjX0dM:F0>?V/@020?Oom00e0?Col03?h;<0c>6B0<cXT`3Ak9/0bn>I0<gTW02>Y5`0
/LMo0=K/Y03Lkjl0d^6V0827G@32aZ<0o?o]0?com03jnOD0oogo0?CXlP3on_l0UXV@0:ZRX03oo_P0
oood0>W_h@3oon`0o?kX0?Cgl03lool0mo[o0?coo`3lood0/KZU0<7>/P3DjL80eN_40<SJYP3Bhj`0
dnJ_02//0P0B4000LGMC04aA:@3Ydj80Pg@k0<KTW035jj80b^jT0<W[W`36j9`0anVM0<SZWP36j9`0
2`3oool000X0oooo01/0`Mf@0>3k[P31gI00c^fQ0<c^XP3;m:H0^nBH0<O[X@3<g9/0hNNY0;ZnP@3=
jj<0TL:/06:BTP3[ool0koOX0?oae@2YUh<0oo_o024O90030@00gN2Y0<_QX`38iJ<0e_>a0=3X[P3E
jKH00P3hon40o`36ejX0e^Va0<_PW`2`aW/0XKE`0=7XXP39hi`0bNFK0=3XWP3@gIP0DU/H0=OOX`3R
k;00TjEY0=S^/03ClZl0cNbY0<OTXP39hZ40e^b/0=GYZP2gbh`0eNFW05QS9`3NhjT0emnV0<gQ[P34
h[00a^6f03`e6@0E0000W8QW0:FBJP1gEbh0YhEO02TU0015Ca/0aN>M0<GPV`39h9`0cNBP0=?XY@3E
jZL0cnBQ0=GZY`3@iJ80VJi[0<oZX`30jiT0d?NX0<KQW03TnKP0m_o:0;71P`3Bi:H0bNNO0<K[W@2o
l9L0b?BM0=cgZP34gi80cnjP09JgJ02igXh0b>fM0<GZVP39k9`0bNZK0<KUU`3;j9P0R9mA0<[PU@3B
j:L0`MNI0<kR[@3aom40^<BB0:ZdP03Ih:`0VYYT0:ZdM`39kj80dO>W0<7MT`3>iId0g?2Y0=k_Z@35
fi<0SJMN0=WeZ`33iIT0b^nR0;WLS02ohY00e?6Q0=WaY@3Dg:00I6@`0;JdP`3CeYl0d^RO0;KFP`3G
n:L0a]jR0<KNY01_QE@0i_c>0=cabP3Jk[40b^6K0=7YW`3Dkj80cnVR0<OIZ@3ion<0noo/0>WYh@3X
hml0l_3Q0?3nc@3<hYX0W[A[0=7WW`3DjJP0e^Nm0<gK`@3hood0k?Kg0?Ooo`3iool0o?oh0?oomP3o
ooP0oOki0?ono03ln_d0ooko0?cko`3jn?d0moKk0?Ghl@3fon<0c=^b0<KF[`3Iil@0i_CA0?Woi03_
oMT0eN:g0<oL[P3_oLX0oooS0?ognP3onoL0nO_V0=?W[03BkJH0e_VU0<G[UP31i980bNZI0<cYV@36
hhl0]]=i0<cST`3Smk00g>Va07^5D02OZVh0k_fj0<_RU03Im:<0cNjM0<k]W`2>XF40Vk1_0>Co^P3?
kJL0`=nK0=7`[@31gYh0f^bh0>Oea031aYh0DETZ0<gVXP3<jZ@0b>bT0<O[X`39j:80b]nL0=KUY01A
Fa`0V:AT0=7TXP33gYL0aO2Q0<?/WP3@l:D0d>bR0=ccZ`3>i9`0SjEM0<CNU@3Kmjd0`^:G0=KfZP3<
jIT0dNjN0<SRV03=iih0enf/0<oSY03<gJH0f>Vc0>?d`03Xm/D0j>Ng09MhB@25QUX0RL^K001B8@2I
gj/0]^:_09VII`1`Ic00He/M0=?NS`3BhI00eNFL0<kXWP2mg900T:YP0=cbZ@36j9/0c/J80:RRI02i
gY40d>JN0<;AS02/_GT0Sj1L06]o>P3?hih0coFZ0<GVU`31gI<0d^:c0<SA]03non`0aLbR0>[f^03A
iYL0f_:V092ZJ@00E03InJd0a^6L0=3X[P3fon<0o?oa0?SklP3lnol0ooko0?cko`3jnol0o_ok0>cZ
f`3oonH0f]Vj08^;I`3Lgk@0fMna0=_S^P3kon40moo]0?Gol`3>h<P0fnc00=GS[P3=fZD0dM^Y0<W@
W@2?UV<0_/JE0>Kb`02hbYH0mOoF0;cJWP3<jjD0cNfQ0<gYWP3ElJH0V;9X0;kHSP3Ajj40a=jD0<cX
W@3BlJD0b^ZN0<obX02nhHd0do2N0<ONVP1^N5H000D00<[AY`3@fY/0i?:S0=WYWP3BhZ<0gOBR0<_R
T036cYD0dlZA09^LH03AhZ`09U8_0;[H/P20T6<0Og/k0<kGUP3=j:40b>JL0<gUV`3EiZ80d]FV0>CT
`P3ooo40ooo`0?kmj03Mi[L0e^6U0=S]Z038gIP0en>Q0=GKV`38cHd0Vj5Q0=7LVP80h^j/00d0fnBS
0>7WY`1GEb40^KJ;0?onk@3onoP0ooWo0?ocm`3A_kd0l^CG028E1@3iknD0ooch0080oo_d01X0oood
0?[jl03oooH0jmkE0:NER@3om]h0lNC40>Oa_03BjjX0dnBP0=?DTP3agIh0Cd<A0:6SO02[c:l0a=nn
07UR;01eEAX0eMRS0=3ic`30hjd0c>R]0<CPY@2F[gD0`mbR0:[2R0/0oooo000:0?ooo`1O0=_TX`3?
eID0fMnO0=7LVP3:fIH0cN:M0<KKV03Rl[40fMVM0>GLX`2MU5/0a]^H08:]V@2;];H0iOco0??fj`3o
nn<0TGYZ0?gan`0600@04@X20?ood@3Ch:P0bMfN0=kb/`3NkkP0dN:^0>7/a03ao=@0d]j`0=WV/03@
gZ00d>2G0;c8QP3Fij<0ambG0<_RVP3Ciil0fnBQ04]@3P3[k;80e]VP0:2[L`2nd9H0b^:T0=7^[03@
kJ/0a^>Q0=7[ZP32eYL0cmnQ0=ORYP1:EAT0d=^O0=[SZP3Hh:l0_=:Q0>;gc00Q7@003P000=;:X`3Z
hkD0[9IW07aK<P1WG2l0TIER0=K]Z@3=hYl0d^FS0<oRX03IjJP0@E4@0=[ZZ@3=gI`0aMFD09^[JP3<
hIh0a>:J0<gXX@37fYX0f>JY0>Ob^02CW6<0S9MK0<?HU@3>j:40_=jA0<WYW@38g9D0e^ZS0<[TV`21
WE<0d>jT0<[ZW`37ii`00P3=jj40?P3>jZ00d^bR09FWF`38fY00aMRH0<_OXP3AhZ`0n_oE0<WCX@2]
]840dmFS05mN:03Sjjl0`N:K0;kLUP3Qm[<0`MBB08VHE`3BgYh0fNVX09FZI`2ldhl0f?J`0;kOV03>
ljH0anbN0<[ZWP38i9X0eN2V06EW=P2AT680aLVF0=K]Y`3>kj00bn^O0<SMXP3Ik[D0eNVf0=c_`@3T
m/h0e>JZ0=;VX@3Ejj80a]bC0=S]ZP3Eh[H0m_oN0?ook@3mm_00oock0?onl`3Oi;`0g^Z/096MF`3G
hj40d]fQ0=SS^`37d;<0o?oh0?coo@3kool0mogk0P3iood03P3hood0moon0?Woo`3iool0mOol0?So
o@3iood0n?om0?WomP3lon`0gNC50>3YbP3Af;T0h>O60P3non<05`3@fk40d]fb0>3/_P3kon<0loSa
0?Wom03eonP0aNRV0;gVVP2kjiL0/nF@0<;aX03:mZL0bO:S0;cRS`3ElId0eN^R0=GXZ03>fjH0^lFC
020[003<fY`0f>jS0080o`0005P0`]bC0>gf]`3Afi`0QiMF0<[MV`36fiP0dNFV0<kPY03UkKX0fMb]
0:BOM`19C1d0b>bT0<;ZX@2fhYL0^NFJ0<C/X`3Bl:X0f?6]03Y=2`25W5P0a>:L0=3aZP3Dn[40`NFM
0=G`Z`39h9`0e^VW0<oOWP1CHb80dNJS0<ONVP3?jZD0bNNO0<GWV`32i9P0cNfT0<KUW`35hZ00b>:S
0<3HW03EkK<0bn>Y0<cQZ@3CgJT0YYM/0:^YN02mfJP0_^>h01=08@28]900^mVK0>Sl]@3FgYD0WYEN
0>;QZ@3PokP0]n:C0<7QUP39giL0d]fI0=?ZXP3DbXl0a/:50;S]W@3@nZh0dO6X0=CUX@3MkZX0c]nK
08jOF`3>jJ@0enfT0=3TW@1BFBd0oooX0?Ofh@3^l<P0`l^?0=;SU@3>hiP0dnV[03UC2P3Mlk<0c=nX
0?Woh`3ooo40oooh0P3oo?l0M`3ooOl0ooko0?chn@3jmO40oogd0?[bi`3oonl0AD0/0?[eg`3dlmh0
ooo_0>[bi@3bo?<0n?oh0?Goi`3nonP0oooX0?ooiP3Ee;H0PX5R0?oog`3lom/0o?oM0<oN/`3Ek;H0
dNZV0;G?Q@3Lm:X0_mF<0<CHT03Hk:@0e^ZR0=7UW@3AjIl0cnVO0<cVW02lfhd0f?NW0<COTP3IkJh0
Jg9C00D9001]LTX0C5HI051N3`17E``0B5PG07V1=P1PIQh0A4TC08f4C@2]WFT0ShaO05MdF01TO5X0
fNJk0>oSY`3;`XT0dmjJ0=KSV`3Ih9X0f=RH0;N/O`3Te;<0oo3R0?okk03ooNH0g]RX0>KRY@3JjjD0
]<R30=KQW`3Sk:/0hNNW0=?LV`2]^GL0hO2]0=CSX03Hi:80cMRF0=cOZ02VYGL0m^kK0?okm@3ei>X0
oo[m0>[HeP3oo>l0CD0`0?omm02]XYh0nmKM0?obmP3R`[L0oN;?0?o/e`3;XI<0a9:;0=JOV03c`[<0
SW=80:nPI`1QGRL0G5DO08]e?01dDBL0H4d/01`j7P1GHDT0GDPK030B000N2`0000X0000700041@00
4Q0000T7000E4`001`<000/0oooo000:0?ooo`3707maA02RTFD0OVdo09fCHP2SWFT0ZZed09NLHP2j
_H@0`;Eo0;>OK025LCl0SIAN0;_Ic@0^C5@0gNkh0<k:a`3^d/@0S71U0>oMj@0a8B`02`000?GU`@3/
jL00DEDS0:JZN03_ll40`<>F0?Chd`3Cek80Yjb30:J/O02SZg80R8i>07Ae>`2RYV/0UIiO08nLE`2H
Xeh0XjAR055=3P2UWVP0YZ1^01lQ001[Ld00IWPn05E_;P1JMcD0GWdj05Aa;`1ZO3h0Df4T08VDF02C
XfD0Qi]L0:2[K`10<P<0N7]<08jIKP1TIT40Hf4k08ZMIP2AYFX0XiiV0;RRL01gJCP0UHED07=;6P1Y
@A00KDDD07Q@7`22F2P0NDlO06]14@1>8P00Sf<d081A8`2`Q5L0M4PS08EH<@1mD2L0L4<J07=67@1l
C2@0JSdD09MZ@@1[?QL0OE4Z099V?`2<G3@0RE`c07A:801fCb@0PF0c08e^@028JC/0Pf@f07iO<@1d
DbH0MU@T06U22@1fCaP0d:Yk0;><H@3O]i<0cJ:00?W;ZP3odk80hJn<0;R2G031T6P0ekR<0;BCJ03A
ZX40LDDN0<6AJ`3P/8X0XGE>09QaB03E/8H0^IY^0:jHJ@2m_8@0XZ5X0<O2R030]h00Zi9Z0>2mW`0X
0`00Hd8S07m_?P2XWfH0Wi=I09MeB01[BA`0/XmW0=>_R`2eTFl0/HaR0;:>GP30W6P0jLB@0;bFJ@3E
YHl0om?80?o>d03AS9l0jZ:h0>:JYP35QWd0/gYM08E=;02XLd/0k[RB0=2JP03oi=80`Xf50<NBS030
RhD0omSI0?oDh@3me>H0omOW0?cDg`3ne]l0X7Ul0<6KVP2QO7H0TVeT0=fi[@3Vb;h0flc50=cFbP3X
h]80b<N[0<31X@2JW7D0QX]R0=KM/@3Fg;00dmZ`0=OD]@3/fL/0m^3;0?oee@39`8T0ZJEX0<K4R@2m
^h80/JUh0=c?XP2TTfL0^Zak08AmAP2h[Wd0Y9M]09f8J@1kI4D0I54Y02PG00040?l0002V0;nMK@2j
VVL0_:=]08af?@1JA@h0N64[0=2fP`3@/HD0ekB<0:9gE@2UOeX0^:M_0:2DFP2XWf@0]Jaa0;V_M03<
]Gl0h<F@06Y<602fVfH0ckb40>7=V02[UFH0eKf?0=RgS03fdJL0gkF=0>RnUP1aAal0i/6G0<RUN`3E
]XX0[IMX0=kMY@36aHd0ZZUa0=_HX`1QFbT0gMNU0=kFY@3Dc9/0fm>R0>CIZ`3GeJ@0[kR308V0E@3S
`jX0i/Zd0;[4XP2>]8D06UHH09K:S03@k;T0VX9X06QA<@2ec8P0j?nm0;VoP@3Meid0ZI9N0:ZMIP31
UV/0Y89B0=C_ZP3DjJP0e^JU0=3TW`3JjjL0e^:P0=_VY03Qh:L0i>>S0>o[[P3omM40_;2J0?3Sd`3@
bZH0h>6W0>[fZP3Hj9l0e>J/0=[XZP1]N3h0dMVX0<c;[@3VhLh0ookc0?okn`3onol0oo_m0?ohn@3o
o?d0oo[o0?oco@3onOl0onoi0?oio`3on?l0ooKh0=_Ad03oo_P0oO[a0?oom03nooP0n_[`0?oom03m
mn/0i=S80:BIQ@3JdK@0iMno0=SI/@3[k/<0cmVT0=GTX`37f940hO6Z0=3KUP2GXE`0joF`0=7KUP3?
fYD0eN:L0=KVW`3HjJ80c>>M0<oVX03FiZD0ho2j020O2`030@00gn2n0=cTZ`35eXH0c=jB0<gPWP3G
gYP0bMVB0;kTY`3KlkD0em6M09^IL012ITX0OZb70;gY]P2[]7<0gmbU0=WHU`3Ifi80fMB@0=G;S@2H
QUH0bkF<06aA=02OQVP0/I]f05i?501bJ2<0/[Ue0=STXP39eI<0g^ZX0<oNV`3>gi/0dNFP0=O/Y`80
e^^V02P0`=B?0=oY[@3CejD0fmZn0>OPd03oo?X0oNo^0?okn03/gmH0XiV?03`c:P3ooOP0loci0?Go
n02fdIh0f_Nd0=oi/03DhZL0a<JN0?oki@3ooN@0d>6[0=[d[@3=fZl0fmRg0?_R^P2LNdh0h]6U055Z
C01CK5H0gMG001`4001K@al0^;B>0<[SXP3=kJ@0c^bV0<g[Y@3?kJD0e>nX2`3oool000X0oooo05h0
a;J?0=o@Z@2AQ5X0i=b^0=KDX`3eo<H0e]nV0>C]]03LfJ80l^Na0;NYN03NhK80hogd09Fb^03Jj?D0
ookm0?obi`3^dL/0ooCo044a>`0=0000oocQ0?ooh@2l^Y<0][B;0<o@Y02_/8H0l_?A0?7ee033aj80
g=nd0=;FY03Xjk80YjAa0>7QZ`3Igj<0c]^F0=OQW03FeiD0J6@U0>;KY@3LeZH0?3XA09jVM`3<h:D0
d^^Z0<GNW@39gil0bn6Q0=KZZ`3Jk:h0a=JH0<cPX@3Hk:d0f^:W07ES<`2=S5`0dm^/0<g;Y@2QWGL0
bN6W0<cVY@3IgYh0h=>L0;BZM@2cZ780_IUW08eY=`2FLT00UG4o0<BNK@1fD1l0YX1?0;B<F`2^Q5@0
S68b0:j3EP2cQf80]XYU0;bBJ02dSV40]8iO0:f7F02gTF80aYab08=G<02QLe40]8IT0;f@I`2cQf00
Yh1G0;jLK`3<[Gl0/iIZ0P2^Tf@0I`2/TF@0YXUM0:Z;G02_SeH0SF`f07mM;@1^C1h0fKJ>081J=@2a
RFD0j/2J0>>gT01cA1X0JChC08=V>P1UAQX0WGQ>079;8P1lD2T0WG5:08YS>P2;J3h0UgI;08Q[?`1g
HC80PWe6061K8`27OTL0KV4]07EG<`2PNeh08`0002@0001YDb@0DT<<07ET;019:P00>AX007=D:02F
Md/0LU8Y08m`A02CMD<0Tg=009YiAP2?JSh0c9f90?2n]@3/];L0`X:B0=nL[P2`K7L0ZFeU0;=mH@1d
?ad0U6<h0=BSNP2YNeT0n<V]09Y/E@2/OfP0ZGaU0?76]P3oemh0o]CR0?oJh`3hdMH0n=3A0<6JT`2o
VY40Ug=S0:1kJ@3jel<0onKF0>oNe`3_i]l0mo7S0>CSa@3Lg;P0][V:09BKJ03Ni[<0dm^Z0=kW^P3J
g;L0f/Zc0=G2Y03[g;D0WIAM06iX;02KU600SX=E0:2@K035/I00Meho0:6;IP1CB1/0U8IQ08UiF01c
Fd<0I4Xc0;2HM015<PP0103o0000d01VB1H0F3d807mY<01fHBP0MF8X03`W002@Nd@0UWY;0;VHK@25
GcX0ME8X09B1B@1]GRD0KfDZ08Il@@2ERDl0SWDo0:j@G01ZBQL0V7Y609N2B`2TT5/0IU4R09^5EP2D
Md/0^IQ]09agC@2ONU00H3/A095`A@2oX7@0R71208YeAP2HTE/0R85;075Z=026Od/0E4XI0;Z^OP2c
YWT0ThII09^<H@2WV6l0TH]K07V4B012>@h0XG]V09UeG`2ZZgl0OIaS00e83P11Md<0CFe608EfG`1M
BR`0WJ5V09JNH`1^JC80[9aX0=BeQP2UU600cIQ`0<^LLP39dID0hn6X0=cLX03Fij<0dn:O0>3[Z@31
bXT0i=^T0=;8R`3MdYX0g]2]0>oNc03;^j`0in6m0>7RZ031cH40amV?0=W[[`36dY@0Q8aC09nVL`3T
i<80m>kF0?ook@3omNl0n>gY0?oln03ooOH0imcH0=?7a`3kk?40kn3W0=o>f03bh>`0hm;L0>[KgP3N
dll0i=g=0=C?^@3De;X0b/nk0>GXe@3jnND0f=Jo0;BZS`29P640Zj=n0;>/PP32`Y00a<NB0=OOX`2?
W5L0]lN00::_J@3<ei80KgHb0;[1O@2`^WD0/[ag09JSG@2:VU<0SIeF0=;WYP2N/g80_lf@08fEI00;
20006AD:0<[9ZP3Oi:h0eNJH0>;gZ03FjjP0e>BK0=K`YP2cijD0anj[0=CLX`2CW6d0BWUG0;old02Z
i:X0cnFM0=GKW`3KhY`0g>BK0?7d[`3Yj:L0Jf4^069E:@2NSVX0h=6Z0>SK[P2XXf40WI]@08F:A`2]
]WD0cMVG0=;QWP3>hYd0f^nZ0=?XX`3;hY`0eNbV0<ONV03DjjD0en:V0<oHX`3Rhl<0mo;N0?ommP3o
o?P0no3/0?K/h`2CRX40?cP`0?;[i@3bool0hoob0<cc^P2jhiL0aNbI0=C_Z02cai80nOoV0>cmg@3N
o<H0aNbY0=Wec`3Bfl00/j=o09n>F03Mf:40WkfI05=oI03Lh=402P0009^?I`1iMDH0bNNO0<S_X032
iiX0a^^N0;_PTP2oi9H;0?ooo`002P3oool0b03EeJl0YZAm06YX?`3Ig:l0e^2^08bQJ03Cjjl0cnNY
0<SFV@3KhjP0ViUV06Y`A0004`/000lF04UIIP3Zj>T0j]7:07QOF`0C0`h02P06020@4@3om^40oogZ
0;NbU@3Fdk80oooJ0>SZa@3MhL00l?GE07UnGP3Lh;/0d=F/0?oodP2/Z7/0gn6_0=SPY`3Dh9h0f>FO
0>GXY@1iNCT0f]FN0>o[^`19BR80OHUI0<WSYP3Il[00gO2`0=OQY03Pk:h0bn6P0<?NV`3HmK80f_>a
0<_IV`3JgZ<0Nfhj0>CT/03/kl00QWiG08f4F`3Jl;80anBQ0>3[Y`3EdI@0i^N[0=OPX@3NijH0UYmN
0;O2P02<UeD0Uj9P09bWI@3Fgih0lONg0=;GU`2f^7T0j^^_0=cOZP3Ae9d0g>JW0=_WY@3Ch9/0bm^D
0=OTW`3FgZ80[K1i0::PK`2CTF00e=>J0>[[/P3AfIh0`L^>0=?SY03AhjD0c^6Q0=?XY`3Dj:T0eNNY
0=[ZZ@35eH`0gNfV0=KUXP3>g9h0b]FK0=OPY`3KhjX0f=fS0?;g_@3/l;D0dmVM0=o]/03Agj80TYaP
0=3HW@3Wk;80f=fS07Z2A`1@Fal0d=jQ0<[LWP3Rl[@0gnV/0<[FUP3NijP0e]ZO0=kAY@1gHd00QFY<
085ZB03^i;40hn>U0=CKV03Ai:80f>^Y0<_NWP3<gil0`MBD0<gOX@3JkJ/0a=FA07=o?@39diL0aLFQ
0?ooj03ooO40ong]0>SDe@2gXi`0i][00>[V^@2VY740emVJ0=cNW@3ZkkD0ooo?0=7HY03LiJh0f^>Z
0=_Q/@3oon`0oood0?ool@3gm^40m?;K0?ooi03XjLL0bL^T0=SI/@3all/0oooP0?ojkP3mm^`0ooo]
0>g_bP3VjK`0f>6X0<[EV@3Iij`0c]fT0=;P[@3=gJ`0nOoM0=SX]`3Pm;T0c^FQ0<[QW@3Kk[L0d^:c
0=OO^P3Pi<<0e]Ff0>;R`035bZ80[k2@07=bEP1UGDP0VY1g0:NONP31_I00PXE@0P3o00003P3Uk[T0
knnc0=7CU03Lhj00fnBQ0=?NV@3EgiX0/kai0:N[KP2f]G`0^kR30>;QZ@3BgY`0c=fI0P3Ek:H0`@3?
i9l0fnBS0<O<S01]Kc00h>FU0>;^[03?hZ00^mFD0=;[ZP3@hZ@0gnf`0=;LX02g`HD0Y:ib0<_KW@3N
l;80cnRW0<GJV@3Gg9`0eMVL0=CHW@3:cI@0g=nZ0=SJZ03OhK80alRL0<G3VP3AcjP0];J50?koa03o
om@0/IEm0>oD]P3Wj:h0d>NS07RSKP14Kd@000d00;FnX`2m^YT0XHmM07ae@@3Vgj/0_[9n0;6MJ`2Z
Xfd0PDdV06Lc301/H2`0R6hm08Ud?`1QKB/0Ae8@0;>lN`2NY6@0HE4N05Q94021LS/0DD4P0<:aW`2B
PW<0^KF@0=7EVP1BHa<0TJII096UJ01[NST0U9aP03Lo1P0i>Q00Ng]I0<O3YP3>ak@0blBb0?oij@3o
ond0iMo?0?ool`3onO@0jn7O0?S/kP3PdMH0kn3S0=kAb`3/hm@0Qh=P0:BSM`2>UF80VZIh0:bgS02h
_i<0YjYm0:RVM@2JUf@0QXA;0::PI@2XZfP0];Yd0<C@R02IZF80Y[M`09ZWH@2PZfH0OhU405eW8P33
cHP0f>:M0:jkM@2FYUl0Tj=L08:DEP2CYFL0aM2F0<[@Y0090`001P000=OC^03Sj;80`]F60=GZV`3B
jJD0eNfO0<7TU02fkjX0^nJN0:o2PP2^ai00KZ^209kR[`2Zjj/0cn^N0=7RWP3IkjH0b^:F0<KJT`3>
gYd0eMjW0=kU/P3GfZ/0jNfk0=KNY@3=fY80d^6@08J=B@1OI2@0gn^Y0=S/Y`33fY@0b^BM08nYHP3;
iIh0a=jG0<cWX03>jJ80d>2Q0=gX[P2MY7/0fMVm0?ojkP3on?40oogh0::IU02o]Zl0M6eW0>KOf@3f
noL0nOoh0=o_`P3EiJL0c=fF0=gXY037cYP0l_SD0>G_c@3Bikh0d>bk0:kG^@35h/H0XZ9l0;o4PP3=
g9T0Y]2P07^oV033g/d000P00=KL[P2=TUP0enZZ0=O`[`37gj40c^JX0<OPW`3AjZT02`3oool000X0
oooo0640JgUE0;6mU`3Hi;`0Ff`o0=O]_0004@00coNh0;SQW`3:kJT0bnRV0:ZiPP001P00l?oo0>Wo
o`003QD0008500d0000h:RL0n_Sk02`Z;@060000oo_c0?GZj00;2@00KFiL06I]CP013000WJZ>0=?P
aP001P00hngD0??mhP3non@0[jj?0?oog03hom<0c^FQ0<kVW03@hYP0gnbV0=CLX@3Jhjh0:SL<06=k
B@2mk:H0fO2/0=3DU`1NBQD0b;^40<;KU`3=mJ`0]nNK0<gaZ@3BdYH0Z:9X0<kHV@3Mjjh0fn:/0:nE
L026IT00h^J[05MX8P2mdXL0bmR@0<o_YP3:k:80h_R`07J<A03<iYd0e_2W0<7MT`3Ajj80d>ZQ0<kT
W03EjJ80aMB?05IW8`3Ajj@0cn^Q0<c]WP3=lj00aN^F0<[`V`3@lj40a=nH0<oVXP37eY/0f>JY0>Kf
[`33e8d0fo6X0<gWW@38ii/0`n>G0=3bY@3<kZ40a^RK0080d?2T00@0bNRL0<WWW@2ogID0B6<N0P3A
jZP03P37h9h0eo2/0<?LV03@jZ<0cNNP0<kZW`38hYP0SjMM0<gUV`3AjIl0cnNM0<gWW@3:jId0bNVM
0P38jYd0G`3<lJ<0`NRG0<_`X034i9P000`00<oHX`2GUVH0d=:P0=GTX@3Bj9d0b^FF0<SZX039jJ00
bNVN0<SZWP38jYd0c_:/0<[/XP35ii/0cNRQ065g=`3Ii[X0gNO50>oef`3^kml0jNOH0?ooj03QlL@0
c^BT0<kXX@3@jiX0bnRF0<c[W@3;jj00bN^O0<W/W039k9P0c>^K0>Gi_P3YmlH0joW60=WX/@3DhjX0
iOBi0=_Z[`3BhJP0c]fV0<oNY`3gomP0n?oV0>O]d@3Zm<l0enV]0<kRW@3?j9L0cNVE0<[YV@3:jId0
bNRR0<[WY03AjZT0cNBP0<gRW@3AiZ<0dN>W0<cD[@3en]`0ooo_0?onl@3on^d0W8mo0>oSe@1DAS/0
ooC/0?oaj@1TC400JE@g0:NEL@3NdJD0iMf_04=05`1nQUL0c^nX0<7UW@36k9l0`^^M0=3iZP33kI/0
`nbM0<?/WP35jih0a^ZR0<[XX03Ci9h0d>JN0080b^RN07T0cNNN0=;SW@3Ch9/0dMbH0=CSWP3@iYh0
c>RN0<G^W`3?m:H0bnZN0=GaYP3Ajj40O9A:0=K`YP33hiL0aNNJ0<kgZ033j9P0b^2>0=O/W@2:WUH0
TJIQ0<kRY`3Ci:h0nOoM0?Woh@3ion@0mOoT0>gid`3?f9D0fnFN08:9A@1<DQ80f^6[0=[SZP3CjZH0
c>^X0;GHWP0mJDP0J8YY0<cCW@3@hj/0Hge007>8C@3@hZH0cNZZ0;ZVM02DO4`0fn>W0<NnQ`2PTe`0
UIYJ0:FZJP3Efi/0g>FT07=U=P3JciT0im^W081eE@3oon`0b/Bd0=SP^@3GijP0cNVE0<;QT@34hIl0
c^BK0<OIS`3Jjj@0d=nN0;_9S02:Uel0[[^60:bfQ03NikP0b]>T0=SP]`3monD0o_oa0?cnl@3mo?L0
ookm0?_gm03akn00dM6e0;>lQ@3RkZ`0e>ZH0<k/UP3Bl9X0cNJB0<GKR03Gi9@0e=nA09bWF@2DWe40
dnBF0<_NS`3<hi<0e^jR0<3JT03LlZT0amfD0=g^Y`36ei00b]^D0=KZXP3Fk:<0c^JL0=K^Y03:gYl0
h_Bh0<oIY03oomd0QGag00P0001`JU@0UYQW0=GWV`3>iIL0bN:N0080d^VG04H0dNFV0>7ZZ@2BWeX0
cNV/08S0T@2ij;@0_MbP0=oTU03GhYH0`nFI0<G^XP3<lJh0a>JY0>ooeP3aomX0i_o;0=3^/033hYl0
anVM0<_`XP2a/g80MW8e0=KUXP3:i9d0_n6G0<c^Y01cTDT0dnfV0=;/Y@3ClJT0aNNM0<_TX03BijH0
^/RC0<O@Y@3Ri<h0d]330<>n^03oo?d0oogm08j;QP1jMg00ooof0?Wik`3mo>X0knoE0?7edP2@WFL0
H7@g0<CVZP3@m/<0X<ba08VhZ00A@C40DG]S00d/0`1JIB40e^bQ0;Cf[`2_kKh06e8k000E003Pj[D0
kob]04U31`2APe80[Z1a0>oQ/P30/X40HEDS2`3oool000X0oooo018000T00=?O^@39e:`0cMf`0<_O
[P004P00c?>d0;;IUP3>kZ/0`=^H09JTK`021`00l?oo0;kNg@0041@000<500d50P1ZHed20001001J
00<0003olo00KfI[065PF`1HG4h0JGIH0008001HJdd0e^W=000:003QkmP0nOo]0?7jg`3Ff<00o?oQ
0?7oe@3;j:D0bNNM0<SPU03Dj:00e>:T0=3OZ00I:P00GWa80<;f[P3=i:00Z:Q/06mC8@1YE1l0goJb
0;;LTP3OolD0]MJ?014;001SFQl0enjX0=G[Z`2h`HX0ZXQS06Dj5`2DSeD0iO:]049I2`3Rmj`0^^>E
0;oXW038fI<0VJeV0<oVWP3?jJ00an6H0<_UW035g9@0dNFN0<kMV03SkZX0@e8=0<_VV@39iIP0b^^J
0;OJQP3Moj`0a^NF0;SGR@3;iI`0b=fH0=WYZP3?gYd05R@00>3`Y`30eX/0dNVK0<GPT@3BkZ40`^6A
0<KST`3ElJ@0b>>F0;oJS@3>jYl0bNFK0=K`Z@3<hid0d^VU0=;WY03DjjL0a=^E0>Gl]P3=i9h0cnJN
0P3?iYP0AP2CZU`0c>>E0<oVV03@iiT0cNRI0<cYV@3:jIT0bNZI0<S[V@3<lj00`nfI0<K]VP3<lJ40
11T00=cZ[`2h^XP0dmRP09VYHP3:hI40e_6P0<[XX03:j9h0b^VM0<[YV`3:jIT0`^>N0<g]XP3=k:00
f>nW08ZMG@3EhK<0f>2i0=OL_P3]kmL0jngE0?ooh@3OlKd0b^FN0<_WW03>jiL0cNZF0<CSU@37iYX0
cNfQ0<c_W@39kIH0a>B?0<gTWP3=hZ40dnRU0<oTW`3>i9`0enfU0=7VX@3AiZD0c^:U0<gQYP3]old0
kooH0=CU^`3Di[@0bnBP0<_VV@3:ji@0bNbB0<S/U@36k9L0aNbM0<SZWP3>jJ820<oUW@0P0=GUY03F
hj/0oooT0?oojP3ooO@0oo_e0>_Hd@3Sd/X0PWMa08]mNP3om_<0ooWd0;>MT024LeD0Whm[0>kV^03P
g:l0ZZ^300XC002if9@0e_Fa0<CVW030iIP0cO:U0<K[W@35k9/0aNbM0<K[WP38jZ00b^RP0=7UWP3?
iYh20<WYWP310<cXWP3Cij00d^6L0=3OVP3HjJ<0dN^R0<_ZWP33jIH0b^^J0<kYVP3AjI/0enjP05ac
9@2neXP0d>nO0<o`W`3:lIh0`nJB0>3dW`34ehD0V:eR0<[NU`3Fj:`0b]^U0?Cof03hon40n?oV0?3o
hP3Ulll0gNbW0<gNT03AhY80Hg0X0=[S[03DgJ@0dnRM0<CPT`3>ljd03CdE02IC;03Bk[<0_N6S0=7e
]@19IbT0d^JY0<SVYP2GQe@0VhYF0=G[ZP3DfYh0gMfQ09fRHP1UJRX0en2O0=_VY02[X780k^N`0>_V
[`30_I`0VYN40<W:^03EhKT0dNNV0<c^V032iI<0b>NS0<_SU`3:hI<0aMb>0<GKTP36g9@0h_Nb0=od
/@2>XF40dn:W0=k]/P3Ehk00n?oS0?Gnk@3looP0o_ok0?Kfn03oool0[k>T0=GK_`3>gJH0cN2N0<o[
U`33j8/0b>^=0<g^T`3AkY@0go:P0=CUU@3Kjj00T:1E0<_QV03NmZ`0b>BI0<CSU`3?kZ80c>RM0<gW
W@33fI00g?:Y0>;h[`38h9H0d^jS0<3LT@3;jYh0aMjM0<_OXP3Ihjh0nooH08=iM`080000YIj;06MY
>P36eX/0goJX0<cUX@3>i980dnBD05EH7`3Qfil0UZ5M0;oMW@1`Z7L0annk0=kc^03BdH40g^VK0<OY
W038kZD0b>b^0<3QZ03/omP0lOoL0>[oc@3<jZ`0b>RU0<W[X@39kJ<0Xj5T08j5BP3Hij@0bNBM0<?Y
WP36k:40Li=:0<SOV@35g9H0a^6J0<_]X`3?jZ<0e^fY0=3RZ03Rk[h0oooX0?ook`3oooP0ooko0?C`
l@1OFeP0YZ>L0?oom03innh0oooh0?kil`3mnn`0TZ9e08VUJP37m[80/nJ]05>:M@0kLVl0h_oo0<oe
h01]SFP00@T009JWH02flZX0_>bl03a]F0006080e]fY0<kJR02@R4L0ETTB06]N9`3ZgJH0HE@M0>KK
X`0;0?ooo`002P3oool0M@1/LdT0f=^`0>7R^01^Kd<0f=j^000<002Y_h40_mRG0<kQX@3MjJT0TYAS
030[5@0M;RP000T401/g>03eool0100000<000063080;38X00<0003DaLX00`070?con`1kQWD000/0
0<oV^P0Y@QP000/00008002/^Z00j_CK0>O/f03QhMD0n_o/0>3dd@33iZH0`nVN0<KWUP3Bkil0cnJR
0<WNX`0F;P00Cg0k0;SUX03Cj:D0Zja`0?GNZP1aGBP0g>JW0<_RWP3;jZ@0g?6^06EL8`3DdYD0_>:E
0=gn^@1UM3T0EC4=07i@;P3OfZ00c]fH0=G`W`27WU00_^NH0<O]X02hbH<0eNVR0=3ZX@38i9X0dNfS
0<OUV`39iI/0XkUa0::cK@3>fID0e>BK0=7cW035ii<0c>RK0>Go]`1ZQ3d0R9eL0;76Q@3:gih0cn:P
0=S/Y`3>hY/0gO:U0<[QT`2neXP0goZ[0<gZVP3HmJD0b^NG0<GPT@3MmJL0e>^M0<GMT@3BkZ@0`=ZA
0=?ZXP3:h9P0b]jG08JJD`3Fk:@0d^VQ0;oIT034h9H0e>jT0<kSU03AiYL0RZ5A0<[STP36hI00cNRG
0<cYU`020<[ZU`0h0<W[U`38jiL0_^FB0<7YT`2oii40a>ZG0<SMVP3Sk[@0LgI10:Z]M02S[fL0f^^K
0=3UUP3<ij00c>RN0<cXV`3<jIT0c>VG0<k]Y`37iYX0c^^K0<7IR`3Vn[80g^fd0;G1S`1JISP0ZKF7
0<_IZ03@i:T0dNbY0<OXV@39jYT0anVE0<OXU`3=jZL0cNZZ0<cX[@3<j:/0c>VW0<c/X`3>m:T0aNjP
0<?^W034l9T0a>nF0<;/UP31kIH0a_6Q0<?/X02liY`0a^jX0<g][036iJ40bNZS0<OZVP34jYD20<G]
U080`njE0P33kIT07032k9P0anjK0<K[V`35hj<0bN6]0?Wok03koo@0m_Ob0?[glP3ooo@0m?CZ07J1
O@3iool0kO?_0>oci@2k_ZT0b]6X05AN;00U=`00B5dU08NOK`3:h:l0UIiW034j0@2f`X@0j_Jf0<cK
V03Di9d30=?TW@370=7UWP3@iYh0b>ZN0<?/WP2okYh0_^nN0<7]WP32iiX0a^RL0<SZWP39kZ40_n^L
0<3[V`3<kYX0a^>A0<cUU03:hI40//Ef0<gRT`3NmJD0aN:@0<_]V@3:lY`0bN^E0=3QT@26UdT0c]nH
0=GVX03CiJL0b=VR0=7Q/03<gK00b]^_0<kN]`39gjh0_N:B0=;`Z02lbi00k_Vo055L6P1hQCl0^]27
0=C_Z031h9`0`NFW0<?[[00UEQ@0Ok1^0<OSYP3Agj@0XIMR05]L8`2AK3l0DcL50<c/X`3Kl:/0cMbI
0>K_[P3HhJ00]l>10=3QW@2DUVD0g>6Y0>kf_@3`n=<0k_SP0?Wol@3:gk@0a^6N0<c^V031i980a^FQ
0<OQU`3JlZ@0dNbM0>7nZP35iI00bn^F0;cLR@3JmjD0Xkia08fWG@3UnKh0a=>d0?Oom03iooT0m_cj
0?coo`3fo?`0k_W[0?Sok`30eZP0dNfc0<GWW@36kI`0anfJ0<KYU`39j9X0e>^S0=S_Z`2DZVX0Ykn1
0=?`]P3=k;<0b^b_0<?WW`36j9/0a^JJ0=SgZ`3aol80`MfB0<?OU03<j9d0d?2T0<OYW038jYd0d?:X
0<OUW`3Xn[h0i^o404<k>0080000G5E3051A9`3Xn;40aM^@0=;]ZP3DjYl0^lb509RLJP2TWVX0a=VH
0;gYZP19TF40b?k<0=3c^@2haGH0`Mb?0<gXV`3Bj9l0d^N^0<kP[P3domP0mooI0=;VZ@3=hj80dnZV
0<SNW@3DjZX0YIYR0:VJH@3DiJ40dO6X0;gYW034kZ80e?B[0<3DS`3MkZX0d^VS0;SFSP3=kJ80b^RN
0<kWX`3AiJP0iNo:0?Oli@3io?<0m_?j0?Wfo@000000oooh0?com03ho_@0oo_o0?oho`3oo?l0fnS>
0:S5U@3AolL0RLF?09cFbP3=ool0k_oo0>ollP3Ul>00d=bd01XX003:gZ<0_=:T0?Kom@0R:Ql0d]^/
0=cWV@3Mkid0a]^<0<_NS`3EjY/0bn2A0<[QT@0;0?ooo`002P3oool0AP1dODh0KG1107AfA`1eMdH0
k_:o00/J0010E1D0KH=20=;RX@3=f9H0YJ=c01dB001[N740BV=M00081`22SI403PP803<^:P000`00
9RPM00h90`1kIg00@3]20>gcj@2HY8`07C<40<gV[`1EKCT001D00009002>VGT0fn;30<O9]03Cc/X0
o?od0?7oi036j:/0a^bS0<[/V038iI<0goB_0<KLWP067P00GWU40=[j]`3JkZT0SIIE0=cFVP3Id9D0
f=RJ0=;HV03BgI/0dMZI09VGFP3Mhj<0a^^N09JgLP0b@@P0S6a607A>:@3SjJ/0b=nG0<?RTP0lD@H0
_]fA0=3^Y03Dj:00dNNN0<o[X03;jYh20<g]X@0]0<_[W`2E[F<0g_:Z0<oLUP3HjZ00doNO0<SZUP39
h9`0c^:S05m^=@1nR5H0JgE10>Gb^P2kbhd0c=nM0=_aZ@3CkJ<0fO>Y0=KbY`2lfhl0dO2T0<GTV032
gY<0eo6W0;gER`2Q]Fd0cN>J0=OeZ`3@k:80^m>90=S`YP3GkJ@0UJ]R0=C/XP36h9H0d>bQ0=KeZ@39
iIX0e>^M0=3WV@26WU00cNRI0<OVUP3:jIT0bNZI00<0b>^I03L0aNbK0;CXU@2ikIP0^>jH0;_/VP3<
kj/0`=VO07f;EP39f9l0W[A/0<7LS@3Bkil0b^RP0<[XWP3:jI/0b^VI0<[ZU`38jZ00do:T0<cYV@2o
f8L0c>:G0<_MW`36f9h0TZ=/0<gQYP3CjJ/0a=fI0<WYX037jI`0b^fM0<KWV037iId0_mRO0<_S/@3Y
o]<0jogC0=oba@2mf:40_n>U0;gVX02mjIh0`^nN0<?_VP33kiP0`_2H0<CaWP31k9`0_>RI0<?]X`36
jZ00bN^O0<_`XP38kIl0a>VI00@0aNbI00d0aNbK0<?]V@30k9L0a_2L0<C]WP38j:T0dN^k0?OokP3i
ooH0o_om0?oon`3oo_80ooof0080o`0000h0oogm0?omm03?a;80[ZIo0:JRL`1lOdP0HVTe07f9F`3=
fZ`0_MBL03593`3=iZD0bN:P0=7/Y@80b^VM0P39jId20<SZWP350<SZW@35k9d0_njM0;k_W@31kYd0
aNbM0<oaY03@lZD0b_6R0;o^W@35lZ40d?6P0<SUU@3=iIL0dnZL09>XF`3DjI`0eNbN0<SWU`3AlZ40
anjK0<3WUP3PokD0PjEK0=;c[036ij00cO2/0<[]Z`39kJl0`nZ[0<7WZP36k;40a^fZ0<S_X035hjL0
cmje0<kJ[024STT0BED;0>Gd/`33eIT0dnN/0=C^Y@3DlZP0Qk5a02==3@3?hjP0g>6Y0>7?W@2NUEh0
Z7a?07QB8@2DZV80bmJB0=SQWP3=g9T0g^fZ0;75P03<hI`0V9i^0<oHW`3;eYh0nooS0?Wok`3hoo40
c^>h0<[UXP3@l9/0b>NG0<7KVP2G[6T0bn6H0=K^XP2XaG<0c^jI0<c/U`3?kiX0bnRF0=;]X02kdhL0
^Lf@0>?_b`3/ln40o?od0?comP3nooX0o?oh0?Wok`3honP0g?C20=;^/`3=kZL0dOF[0<W[X@3Knk80
_]VB0=?YZ02Z_gh0e^b^0<_SY`30gj<0dO>g0<__[`3;kjD0`nFH0<c[W`3?kZ80^mF;09F_I@3<j9d0
eo>X0<?RUP38j9`0c>jQ0<CYW03;l:<0eN^Z0=3L[P090@001`0004a5<`2DUF/0c]jG0=_aZ035h9d0
d>BO0=o_/02oc:00a/jK0>Ooa@2lik40JKJ<0;_mc`2ej:l0SjYM0=?eZ`3=iYD0d^NH0=GY[03AhZh0
jO_90>Gh`@3@iJ80d^RP0=G[XP3Bij@0e>RY08=d?@2OSUH0e>FQ0<W[X@2nkIl0`^bP0<_[XP2__W/0
cMVG0=W]Z03?jJ80cNfR0<WYW@3BkZ@0dnVX0>Ocb`3lonX0o_oh0?cko`3oo_l0HV9P0?kom`3fooL0
m_oj0?cko`3lm_l0oogo0?Ook@3Qnm@0ZmfX07N_PP3@ooX0gOoo0?7oo`3co_P0noom0=cff@0Q>Q80
fMn_0>;cb@3oo?H01P400<kT]P3Ejj<0d>BO0<SMW03Plk<0dNJU0<3EU03GkJ`02`3oool000X0oooo
07@0d_2b0<cTZ03Fk:h0f>Z/0=S^[P3Dljl0aNJO0;cPV03;jJ40cnVP09BHI@0]6P`0oooj0>Sek000
1@@000050?oko`3jknd0oooa0=[Db00;0000ooKo0?olo@3nond0io7>0=7UYP2hchT0^M2:0>Kk^P0;
5@00I6Ll0<o@Z02j/Y/0el_=0?oon`3ionl0cnbd0<OXX`38iI<0e_:N0<CHT03Ai:@0IgU706Id@@3O
i:X0]/N309J]I`3@jZ<0dn:O05912@1M@Pd0AR/006YK8P3@gi`0hoZd0<ORV`2D[Vd0bmfS09F4F@1V
EBX0a>6N0<kjZ`3HnjT0`/n70=_PWP3;e940enfT0<kXWP36iYX0c?6S0<7XV@3;lZ<0]]^=0=KbY`35
gI<0NXY30=CYWP35j9@0b^VM0=CQ[024RF00lNk?0?onj03hlML0/[:<08J>G`3>gZ00fo6`0<WZY@3F
mk80bNfW0<[^Z02jfiH0`>6L0=3_Z`2;Y680PYQG0=W/[03AiZ<0@V8I0;cJT03HlZP0cNFK0>3fZ`3H
l:@0U:mP0;oLS033i9D0_^6A0<_[W`3FkJL0d>NQ09fhL@37iId0bN^Q0<KZX0@0aN^P00h0a^ZP0<_T
XP3AkjT0c^bV0<cWY01ePTd0cLjT09^AK@33]hl0UiAM09NGF@3KiJ00bNVP0<WYWP80bNZK01h0bNZI
0<c^X@3;kIT0_=b70=KbW@3DkIX0c^FM0=C[Y@3@jJD0a>>G0<_/V`3@lil0bN^O0<SXW`39jJ00cnVX
0=gd_03fon@0moo[0?[om`3kooL0o?od0?[ok`3`on<0k?oI0=cda03;iJH0c>NR0<WUV03;j9H20<cY
U`070<k[V`3=k9`0bNbH0<OZUP34iiD0a^RN0<WZY@020<SXY@0>0<SYY039j:80bNVP0<WYW@38jIP0
cNbL0<cXW@3Kk;H0l_kF0?Gej@3oo_/0]Jb_0;F[ZP3om^`40?l000040?oml`3Md[h0fmNZ0>c[]@80
o`000=8000/005i^?`3>hZd0bMjV02i21`3:h:00]lf<0<gWWP3<j9h0b^VM0<WYW@38jYh0b^RN0=CT
W@3AiId0c>RM0<[YW@3<j9d0cn>K0=?TW@3AhY/0cnFL0<SWV`39jId0b^ZQ0<kYXP3BjJ<0d>FP08ZN
F@3EjZD0d>NQ0<[ZX@2nhYP0aNjR0<c_Z`3Bh[<0Q9AS0;oBV`3Sn;l0bnBS0<WRX03;iid0cNbN0<k]
W`38j9D0a^FI0<GPZ@35hZ`0k?oK0<[S^`3@e[00g=N]06=D6`1YGQh0EU4=0=SSWP3MlZl0c_Ff0<Kc
/01BOCP0_^6O0=3YY`3Gn;40VX]B07IV:`22UTh0Zji[0<c?S03:iIh0a^6J08JPF@39hi`0b]BR08F@
F03Jik40n_oR0?Wok`3ioo40f>Vo0=O/Z`3?iY@0c^FG09naM@3Fhj/0Tj5T04QH6@3:h9L0_]V<0<cY
V@39i9<0f?>T0;cBR@3>hY/0d=jP07=jA03Ohk40j^fn0?;eb03OiKT0SiEW0=CQ[03CiJT0_MN>0<WX
V035iYD0^mV?0<_TX031f980goB_0:FfL038fI80d>FH0<WQT`31hhl0bo6L0;kTS`2mgXl0dNfR0<oY
W`3Hl:H0TJMN0<kTV`3;hIP0c^BK0=K^Y03?jIl0an>H0;cXT`31kYT0b^RP0<_MZ@0400005Pd@07Qc
H03oom`0hO2[0=?YX@3DkZd0h<fR0;fUP`3kon@0hn;30?oog`3inMl0L9n=049iG02_h[L0RYaP08nF
HP3>j940bNf=0<g_X`37ij@0bnj^0;kSW@34k9H0`NR?0<O^U@36jid0`nNO075R:`1aG2D0d>BO0;kT
V@2mkYl0`^jQ0<SVWP3]n;H0dmVI0=;NW03Kl:/0bnfP0<S]W@3=kYl0c>RN0>Gfb@3konP0o?oh0?Cd
o`2ATId0o_oo0?3cj03gool0nOoo0?oko@3onOX0ooSc0?olkP3oond0U:>>02m1<@3boOT0mO[m0?7o
o`3=i^<0d_Gi08Ze[0005000dN[20=WP_`3Pin002AXD09_5W`2_j:@0b_6R0=3_X@3;jY`0a>FF0<SY
VP3=l:0;0?ooo`002P3oool0M032iJ40c>VW0<GOWP3=hj80`]^I0<WXXP3<kZ@0`nFI0<_[W`38i9L0
f^F]07AQDP0Z:BD0;c`e000:2P0a@dD0ooco0?oko@3ooO00Ti6401@:0@3om_T0ookf0>O`d`3Gi;T0
f_6]0=C^Y03SoK<0`MR@038o1`2GWV/0hnBh08F0H`3Kdm40ooci0?Chj@3Lm/H0e?:d0=3XW039gXl0
f>bT0<_PW`17FBD0MX=>0=;EW03/nkP0QYeG0=Kd[03<hI`0[JM[07m^=P1GA0`0WYQL0<cQW035h9T0
d^VS08NPGP3Mk;40WXeR071O<`3?jZD0]N2A0<SWU`3NjZ80g=jO0=kWYP2mfHl0e?:X0<?UV@3<kZ80
`>:F0<WYWP3<jZ00amjF0=__Z01[N3<0d^>L0=;cXP3BkJH0bMFU0867H@3>cK40n_?P0?oojP3momh0
mOkA06n3AP36g9`0honn0=Kc/@3@kJ/0`MjL0=;/Z`3Fl:l0`MZI0;W?SP39gY/0fNj[0<KKUP3?jJ80
ZL=j0<GLU03?iid0dNNN0=3XW02[agX0SjiP0<;UU@35jYX0cnnS0=7TXP3?i9l0Z/Am0;kLU035iid0
a^ZP0`35jj809@35jZ@0bNRT0<_NW03DkJT0dnNX0<GDV`2GV7002P40089XD@3OaJX0gMFT0:2KH@3D
fiP0bNVP0<WYWP39jId0bNZK0<S[V`39jih0bNZI0=KhY032gh/0d>^J0<cVW03:iY`0e?:X0<g^W`3I
o:X0bNnH0<g]X@39iid0b>JL0=C]Z`3Yo/H0nOoX0?_ol@3oool00P3oo_l02@3ooo/0noof0?Ooj`3S
lll0c=jZ0<oSZ03>hih0dNNN0=?XW@020=;WW0080<cTUP36iY40b^bH0<[ZWP3:jJD0bnZW0<WXY@39
j:@20<WXXP0<0<SYY038jZ00c>fL0<o[X03<hil0f^Fj0??hf03oooH0ooWh0;2TYP3omoL0m^cS103o
00000`3mmn/0lnSB0=7IYP040?l0000>010Q001]NDL0d=bZ0:nmR00L;@00NhmB0<gVXP3<ij00b^VM
0<WYW@38jYd0b^VM0=KSW@3Ci9d20<gWW@310<oWW@3FiYl0e>6K0=7NV03Fij00dN^Q0<cZX038jJ80
d>jX0=CYZ034eiL0TZ1S0=GUY`39gIh0cNZX0<_[ZP38kJX0`MnS0<_F[03:dZT0o_oL0>kgbP3kom<0
f>Z^0<gWWP3;iiX0bnRF0<[XTP3;iiX0j?o:0>oodP3[om80a^2`0>3Za@3PhKT0g]FJ069K5`1OF100
h^6Q0=GMX@32jJH0^nRU07BXIP2FbHL0_^RX0;3OV`2k]7d0T8M<0<cTVP20O3`0hMbL0=7[Y035giP0
/L^40<WSW03IiZh0YK=h0=?PZ03/nLh0io;B0?OoiP3VllL0iOFg0=W[X@3Jjj@0WZeb0<kPY03=gj40
d^FU0:2dK@3FjZ<0dNNN0<cRU`3;hIH0ione0<gUV`3Cij80NhE80=SMY`3gnLL0oooC0??fa`2h_h`0
enFZ0<kNW`3Hlj@0bNNA0<_/U@3BkZ@0enjX0<_PV`2@XE/0amN>0=GXV@3;i940b^RB0<[^UP35k9<0
b^fI0<SWV@3Bk:<0b^6I0=3VWP3<hYX0eN^R0=3VW@3EkJ<0b>:H0<_WW039iIX0a>jJ0;_UT@3DkjX0
dN:/00L8000D4PH0alZ]0>O``@36fIL0c^FQ0=O_/`37[H`0on3:0:^UU@2LUH<0ooc_0?oom02;[ZL0
DX9Z07^YQ03@iJX0LGY30<_XSP37k8`0c_6Q0<O[X`3?m:l0`nRR0;kUU033kIL0coZQ0;oYU`3AnZ`0
YIUO05U63P3:giX0b?6U0:gRTP35mZL0b^bR0<SDTP3RjjX0K7Pf09:WI035iIX0anNK0<SWV`38hi`0
iOO70?Soi@3anNX0o?oo0=cOj03en_H0o_oh0?Woo`3kool0ooOg0?oin03on?@0oo_a0?ojl@2CV940
92dX0?Soo`3hoOl0mooo04eWI01OThl0C7Id02e>A@1mUGD0e=Ro0?WomP00200002`80:k]]02njIL0
cNnH0;kRRP35jI80d?BM0<G[UP0;0?ooo`002P3oool0W@3<jid0c>NP0<kWY@3BiJd0g>fg0?Woe03C
i:d0c^:S0=ObX`3ClI/0a]ZE0:NKQ@3kood0MHF40009300kN7<0co;d0>Sgo03_jn`0/KN]0003003S
fl@0oooS0=3T/@3;hjT0anNL0<KYV@39k9X0aNJG0=C]Z`3Ej;00h_2o0:nhV@3hoo@0ooWf0?omm@3g
onP0h_c?0=KPX`3DfiP0fO6W0<7UV`38fj@0e>6[0<kQX@3Dhj00XJe[0=KRX03Dj:<0c>bS0<GYW`2o
j9`0b>bR0=7/Y@3CkJ@0UjeT0<cQWP3KiJT0WX9J079B:@36c8h0]lf506eo<`2QYV<0iO2^0=GZY`3B
mZh0anRQ0<OPW01`QD80TJ5P0=7MW@3Nj:T0bmFF09fWJ02?Ve/0d>BO0<g/WP3<ij00b]nW09N[NP3E
i;/0j_SE0>knfP3aomT0mOoH0=?_/P36gZ00=d450?cob@3AeYh0fn2V09ZPI037ci<0ZkEf0=g^Y`35
fi00anBB0<[UU03@giX0cmjI07>4@037fiH0cNBN0<3JT`2jeX`0PZ1F0=3`Y03<kZ40_]Z?0;2kN@32
chX0c^>H0<gUV@2ee8@0`nBE0=7cY`34hid0_]fI0<[WY`3GlZl0`Mb=0<kiZ@39g:@0i>g00?cnj@0;
0000]HV:0?3>a036dZ00]L>60>7e/038iY`0bnVO0=;bY`3;kJ40a>VL0<c/X03@l:@0anNK0<3PU03<
k:00anNK0<?SU`34i9P0bn^O0<WYW@3;jYh0c>RK0<gXU`3<jID0cNRK0<oUY03ion<0lOWR0?ojoP3m
mOl00P3on_l08@3fm_l0nOom0?Wom03SlLd0e^Fj0<KFY`3:ejT0en>c0=?MZ@3=ej80FFPU0;O>O03F
l:H0foBb0=;W[`37g:<0f?:X0<KST@2gfH<0`NJF0<O^[@2hh9X0bO>Q0<[[YP3BkKH0lOWR0?cllP3n
m_@0/jVX0?K_j@3oo_P0oogj0?omo@020?l000040?Sgl`3oo>`0onWD0=;f]P@0o`000580SIeN0=CA
WP3<bid0O8AM09bXP01gRUd0b>F[0<KYY@2niIH0^nFC0<?]V`37kYl0b^VM0<WYW@36jid0b>ZM0<WY
W@3BiYh0`mB=0=GVW`3?iid0b^bO0<G/W@2ojY/0b^ZQ0=_VZP3Kh:P0XZAc0=WO/@3Ih[D0bmj`0=7T
]P3Rn<T0looJ0>gndP2_^I@0oooZ0?ook03lon@0e^Vl0<KYY`35kJ@0aNjR0<;[W@34kIl0a^jU0=C_
ZP3IiJD0eN6Q0<gVXP31iId0bNnV0<_VX@2CW5d0XH=A0?7NYP3:l:<0b^fY0;;W/@1_ZGT0PkR<0;SS
]P2bYWh0RX1?09B[I@2k[740flJ=0<7BSP3?hih0cN:M04QO6@3Hl:@0`]R@04mT7`3AhJ<0hNnd0>Ca
^@3Sl;X0n?o=0>C_]@3>g9l0^Lj;0P31i9@09@3:iYT0SIaI07Z5@`3Oj:T0dmjL0=c[YP2dd8<0doJT
0;GHR03Hk:d0Zk>40>;Y_`3Vj/D0oOoQ0=[N_@3Hh;L0e>:_0<_RWP39iIP0bn^H0<k/YP3;h9d0IgPb
0=?PVP3=gY00b=j<0<[/V036k9T0`nbN0<G[XP38iJ80e>^W0<WNV`30eI80LHQ20<;LU@3GlJX00P3:
j9h30<SZW@1C0<GRTP3FkZ80b]RJ06=^=P002`00IGTn0<_ZY`3:jjH0b>BW0=;Z/03Jk;X0nnc;06eG
@03oo?H0oogo0>[fo`3`ool0jOoo05AkJ@1oZhP0_o2^0<?fY`3:jYD0OYM30=;YV`39giL0]<R90=G[
[@3?jJX0c>VW0<[[Y032ji`0`^bJ0>7MW@1?A@P0an6H0;[VV@2^jIL0_?>R0<_g[03AijH0cMfN0=CW
Y`2L/W40dnNX0<kPXP31diD0lOo50>Cda@3gon40mooZ0?7klP21Qh<0noom0?Ckl`3co_P0l?Wf0?;a
k`3ilo<0oock0?okn`3oo?l0nooo04MIF`2mhn@0h?oo0>Skm@3^ood0[NOI0<cUk03kool0ZjZX04Q<
?P3oon@0f=nm07b/Q00QE3<0b_Zl0<cj/@2fhIT0_nVQ0;?MU@2miI`02`3oool000X0oooo0480bnbK
0<SWX`37hjP0h?C?0>ooi03fon/0dn?60<oT^`2mfYL0c>fN0=kbZ`2JRg@0KFmZ00050P2VbL/0`_[i
03Z5OP2`i>00_JR_0;V[Z0080000]k:E0?[of03@iZP0b^FR0<KWV036jID0e?NU0=3`Y03;h:L0dN6b
0?_og`2EWHH0n?ok0?olo`3onoX0m?oX0>3gc@3DgZ40i^fY0=3WV@37jI`0eNNY0:ZhO@3Ai:80e^NS
0;k=RP3GiZ<0e>FQ0<WWW`3;kjD0bNnT0<[/XP3<iYl0aMbD0:NmM03?iZ80gNR/0;JMM022IC/0WZMX
0<;HT03PmJP0Z[5]07N3@@2U^7H20<gMW0100;2oOP2=VET0b=BD0>3_[P38f9L0j_nm0;;;Q`3=k:H0
c^jS0=7`X034h9D0bn6S0:c1R03HjKD0e^Ji0=o```3eomH0m?oB0<o/ZP3DkZd0cmnQ0:jlO`1iQ4P0
QY5E0:NcM@3KjZT0e^NS0=K^Y038i9L0d?:N0<WXV02mdXd0iOZe06b1?038gIP0b^6K0=;YX`3JlJT0
U:]S0<cTVP3Cjj40cnFL0<?BS`3IjZ@0b^2E0<WTU`3:jI/0f?VZ0;gMTP3:j:80do2]0=Wc]03dolT0
c^JH0<;/VP3Rm[/0PhaO0?[ii01>@3L0iKRk0?oek`3lomX0Z[Mo0<oOX080an>I0440bn^P0<?UV@3:
k:00_]fA0<7PU03FmJT0f?N[0<?RUP3>kJ40a^FI0<GTV03@kj<0bNRL0<SWV`3:jId0c>VG0<[ZU`3<
j9/0c>NR0?Oog`3eonP0ooom0?_ioP3onol0ooco0?kno`3fo?X0n?oc0?_oj03jonD0nooS0?Cnf`3l
oml0_<FJ09jXMP2`_gh0TJIG0;c@R@36f9X0nooF0>Gc_P3Plk40a]bC0=G`W`3=k9h0fORe0<;SWP32
j9D0cnjZ0=7Z/`3lond0ooof0;>[Z@3Xh=h0oo[g0?kim@3akNX0[j^Z0<Fl_`3ooO`0oook0?olk@3m
h/l0^MNI0;[VV@020?l0001j0=7[Y03HjjT081l0051B8@2X/8L0Hfm703935`34h:H0aNFR0<caX`39
kYh0aNZL0<_]X03:jId0bNVM0<K[W@38jYd0bNVM0<oSV`2W^740dnBM0<gUV`3>l:<0`nZI0<;/VP36
iYX0dmnO0=gRZ03CeJ<0gN>c0?3ibP3MlL00h?C30>Kjb@3gomX0nOoM0=[T`@39b;<0l>oJ0>gge@3R
llL0a^VW0<?[XP36kj<0a>ZM0<;[W@30j9l0`^6K0<kNW@3BhZ40c>ZT0<G[XP3AnK00]M>=0>C^[`1Z
D1d0RGQ00<caX`39kZP0dOo<0:7GY@1BPED0_nfn0;:YOP2;PE00a=VD07U_<P1UFAd0fOV`0;gMU03A
kjL0_M^C0<[RUP3Bj:00a=VD06j1@@3:fIh0c]fR0=GTZ`3DhJT0QiEJ07Z:C033f9<0co:R0<c_W@3>
kIl0dnNP0=7PW@2BWU`0]<>00:JgL@3Ak9l0^MZ90=SiZP38gIX0`m2J09jXMP29T6H0oOoQ0;6fUP3A
fkP0eN6i0<cQZ@3=ijP0b>JP0<OQX03GjZP0KWdj0>cg/`3Kj:00g>jR0<KWUP34jIT0a>^L0<K[WP3=
jj<0c^FQ0<_PW@2hcHX0ZL1j0<GOV03=ij020<[XWP<0b>ZM03L0c>NF0=O^X02c`X40JWDk0<WFWP3L
l;<0dO2Z0<GWW@3<jjL0d>ZY0<kSZP3Pejh0N6U80?olk03ooOH0mooo0>[ko`3Ln_P0[];404YeFP2j
k;L0]n^[0<c[W`1ZPC40d>FJ0=kbZ`36fIL0bmjN0<oUY039hYh0b^FN0<oaY035j9P0hN:P05iH6P3W
oKD0aNVO0<ko/02mk9h0_nVO0<SSX03=hj80enf/0<_TXP1<HB00]LR80<GHV038f9X0ho700?_oh@3Y
lmX0nook0=KJf@3kooh0nOkj0080nooo01X0ooom0?omo@3oo?d0ooGd0?ojo03hoOl0iOGe02Y9B`29
[k00/]G>0>Woo`3Uool0n?oo0?3co`2FZJL00A820?ooi03Xk<T0`^Nk0:oL/@07?b@0?WYQ02iXC`2M
djl0^>_00;g]/`/0oooo000:0?ooo`2O0<W[W`39jJ00aNBN0>3j_@3VolD0jOo80<;KX@3;i:X0anJS
0;kMU`3Unkd0Mg9B0042002CWYH0eOko0<koo`18`[<0<Hb307eKJ`3oloX0IdQ30;NcSP3Hj:X0b^NG
0<[ZU`38k9@0a^ZB0;gNS`3Fm:h0`mBW0=oZb03lon`0_/6j0?3hn`3on_l0ooWo0=_Xe03@i/00eMfQ
05mU7`3Fk9T0anNB0<[JT@2Q[VT0eNbV0=7XXP3JkZT0e>>P0=;SW`3?jZ<0a^JM0<7SV@37iId0enbW
0=oe[@38i9T0`]fH0>Kf^02fXGH0MEda0<gIV@3MnJl0/l]m0=_VX@3EjJ@0c^6O05UO7`2UZf/0T9UH
0829B03VlJl0aMVD0=C[Y@2jfY40d?BZ0<G^XP3Enjh0a^>A0<gXV@3EkJ40T:QL0=;XW`3>hih0dNJQ
0=3WX`39hYh0bnJQ0<kYYP37hJ00a=nL0=Sa[`3Nmk<0eNnV0<[VW03>kJ40a>NG0<caX@2nj9H0a>^L
0<SWX@2Q`7X0d>^V0<3IU@3DjJ@0aMJ@06Uf<@3Ym;00eMjK0>C[Y`26TD`0bnFN0=C^Y@3:iY/0aN6F
0<7PU03BlJD0bnFL0<_RW03Bij@0enV[0=GUY03<g940^mj>0;70Q@3HgZh0n?SP0?g_iP3G[;<0om_K
0?coi02T[8<0VjQc0<kUW`3BjJ40an>I0<[XWP30h9D0b>:H0>Cn]02ofi00^mN<0=[dZP35giD0c^ZO
0=3ZX035giD0cNVN0<o[X03<j9h0b^VK0<[ZU`3:jIT0b^RN0=7Y^@3Bi/<0n?oe0?Onm`3lood0oooo
0080ooko07D0ooom0?;cj`3hnO40d]G>0;Nj/@3lond0o?oV0=GQ^@3@gZ40g>ZO09NRH02b^h80a<VQ
0=;D[@3Ni;@0IFhe0=;QW03?h9T0e^ZR0<gUV@3AkYh0bN6S0<oQ/@3go>P0e]K>0?omo@3gl^l0ookk
0?ooo@1LG5h0/k>e0?ono`3lnoT0oogj0?okk`3P^j/0Y[Qn0<7QV03KjI`0e^RN0=Kd[036h9T0`<J6
0>;Z/@2EWW40gNZn08VIK03[olL0f_:d0<GOV035giH0bnBP0<oYXP3:jId0bNVM0<K[W@38jYd0bNVM
0=;VWP26Ue00d^>L0<oWW@3=kj80_nJE0<;ZU03<jid0en>Q0=GKW`2h_8T0hn^j0=o[^`3Sm<L0g>o1
0>GfbP3_om@0iO7;0=_R`@3FeL00g=_60>gge@3hom`0bn^X0<?WW@35jYd0bNVN0<SZWP33jj80bnbU
0=CYYP3AiZ<0`n:L0<WaZ03AnK00eoJ`0<KEU01VEb00IE/P0<KRU@32kZ40ZmbK0<Wb^P1VQeP001D0
09BAI023NDP0e>RS0<W>R`3HfIL0PX]:0;JlO03DeYL0hn>U0=W`XP3CjJ00bMnG07fBC@29WU/00P2l
dI009P3Kl:l0XkQe0<OLU`3EkJ<0b>NG0<7PT033hY80a>2E0;G?QP3Sn[80bn:J08nVGP32f8d0aM^@
0=W`XP3Km:<0a]bD0=7VY@3Fik00RYI^061[B@3`oN40nOo/0?Coi`3aon@0e>^o0=GY]03=fZ80fnJ^
03a12`3=eI`0h>^_0=;]Z03?kjH0anZJ0<KWUP3;j9P0d^VS0P2G[6T00`36gIL0`mfF0=C^Y`020<[X
WP<0b>ZM03T0`=N50=c_X01=F1H0fN6V0<OBUP3Ik:`0bNZK0<S^V`3=l9h0aNJG0<KRV032bXh0kNfg
07=hC`3PiLD0nOoc0?Gon03]ood0g?k^0;OQb`1gZXT0^_7:0<g//@3DjZT0TZIQ0762?01BHQ/0IGD/
0<KFS@2``7L0X[AZ0=G[X03;hIH0b=F@0=SQWP2h`gl0e>2N0=O/Y`39i9d0cNbV0<7VX03XolL0`nBO
0<KSX03Hk:L0d^>M08ZKE@3Wn;@0a=6L0>G`b03Sk=40o_ok0?koo`0;3140JVU^0?KenP3oool00P3o
o_l0603oo_d0l^k]0?ooo@3cmoH0mOkm0=WWj03[n_d0k?Wo0?3fo`3omol0aNSk082ia02Db<@0mOoo
061;>03`gl40bn:Z0<C/[@2ejkL0Z>2_0<[od@1l]8<0654N0<KmaP/0oooo000:0?ooo`0_0<c[Y@39
iid0anJJ0=3]W@3?k9X0b>>D0<gYW03ElJH0`n2M0<k[Z@33f:000@D007=fH`3iooP0h_oo0<Coo`0>
Q7P0CZ>N0;2AX@3lg>40GChi0:fUP03?gih0bNVF0<[/UP38k980an^C0<o_X`3Ln[@0aMJY0>3[b`3c
n>80d=?<0?_oo`3omol0ooSl0??oj@3Nl/d0_/>905=F4`3Ai980`n>>0=[WW`2=VUD0d^bU0<kYXP3E
jZD00P3Bhil0o`3@jZ<0anFM0<CTV`3Hlj`0cn>N0;kDS03@kj<0b^RR0<oQX`2UTVL0KUL[0=?RX@38
iY`0g?VY0=WVX02hcHP0goJb0=7PW@2HYf@0<Sh008fLF@3LjjP0h_Ja0=CYY03;iYl0dNnW0<g]Y02o
gi@0aN:B0=3[W03BjiX0P9U80<[QT@3?iYP0cnNI0<_RVP34gYL0b^FP0<_VX`3?k:X0`]nL0<GPV`2l
ei00d>nS0<_[W`38jIX0_^>C0<?ZV@2liIH0ao2R0<;QW@2>ZfP0_]VD0<gVXP3AiIh0j?Vc05iY9@11
BPL0HfXW0=OLV@1HHal0`n6I0<KTVP2if8`0_Mb@0<_WW03FlZL0hORb0=GZY@3HjjT0g>b]0<_GU`3J
j9d0eOBV04YH6`3DfjP0jNWA0?oll@3@YJh0mm?G0>O_e`31b:L0Ae8W0=GZY@3DjJ@0aMnF0<_WW@3=
jj40eNnU0;cFS03:i9X0e_2V0<SRV03@jZ00eo6W0=K`YP39hiT0c^RN0<cVW@3=ij00c>RK0<cYV@3<
jIL0c>RM0<ONZP3<hKX0n?oc0?WomP3looX0ooom0?ono`3hl_80oocl0?ono@3oo?d0P8220=SJf@3l
oo<0lO_P0=_W_`3Hj:X0b]R=0=_VY01NIBl0Si5/0>c]c@3Xj/80c<nP0>;/[@3LjJ@0b=R=0=kcYP3C
jid0e>R]0>3]`@34akH0a<Bl0?ggm`3ooOd0n?Cc0?ooo@1EEUX0o_oo0>g]k@3oood0ookk0?ojk`3@
Y9L0aM2H0:6lM@3FhYH0eNNM0;?CRP3GmJd0k?Nc0=7KWP2MZGT0f^Ni06YgB@3hom<0kOo40=?XX`3D
jJ@0eNRX0<cQWP3:jId0bNVM0<K[W@38jYd0bNVM0=GYX@2;W5D0e>FN0=G]X`3<kZ40`nZI0<G/V@34
hiD0en>S0>K^/`3>dZ0031@0000;003:fjl0e^Rn0<gN]03<fk80dmni0>W`d@3Og/T0d]6l0?Kog@3f
omX0bnbW0<?WW@35jYd0b^RN0<WYWP34jZ40b^VS0<kSX03=hYl0c>ZT0<S/Y02jgYH0c>NR0>Cc/P1M
D1T0ET`A0=7/W`2fiID0_>VT0;cPX`29YG80Gi1H06UX>P1NDbD0dNFP0=_VX@3WkZX0SXi@05MG6@3S
hJ@0i>:U0=CYW03Aii`0d^RO0=C[X`25W5H0XKQb0>3i]@33fYH0_=>=0<oVWP31fHl0dnjO0=7^WP37
iYH0e?>U0=gl/02edhT0bNFK0<SRV03=hYL0k_nf0<oQU@37h8d0gORY0<OQV03Bj:P0fNZm0=SX``3h
onX0n?o/0?Ook@004`3eon`0kooP0?Gof@3lomP0g^Fi0>OX_P3GfZd0fN6`0<OOX`38iJ<0aNFI0<KU
U@3=j9T0`=N?05eb;`3Om;40g_F_0<[TW@3;iIh00P3:j9h30<SZW@1C0=?ZVP39fX`0FV<T0=KKX`3`
nL00bm^L0<o`X@34jYD0bNnJ0<[]V`38iiT0j_Vf0<OATP3Ylkh0l__>0?7ogP3gon`0goSR0>SolP3V
oo@0C89R0:oXa`36ik80[/J:0=[`[`3?i9l0dnFI0=o`XP3DhY<0c=Z=0:6aIP3HjZ00f^jV0=__Z03?
h9X0CeHC0=cNW`3Jhj80e^NS0<gXX`2kiId0j?o:0=3d[P3?k:T0f>bU0=KWX02AXeT0OHi80=cY/`36
dJL0n?kR0?kon`3nool0f]WQ0=?Bf00:20d0Qh:80?ono`3fm?D0m?;c0?Gel`1QHEl0G5iK00/?3P3f
n_/0fmoR0?olo`3on_l0ooOo06RQ[00jRHd0/NOY0?Woo`1UCd80D44T0<oNY`33iZ80`o6Y0:kMU`3;
n[H0/NBR08_1P`1f/7D02`3oool000X0oooo08l0cnZW0<[VW03<jIT0bNJ:0<OUQ@3=j8T0eO:F0=3/
U`3RoKP0bnFX00lU00002@00R99i0?_omP3Jool0D:nW0<3oo`2Dbm80;B0Z0?STi@0I0P00aKRE0=3P
W`3;jiP0bN^E0<O[T`39jiD0c>^O0;WDS`3Zn/d0`/bY092FO03noo@0nook0?ohn@3onoT0nOo/0>Gj
d`2d^Gl0MgXg0=W/W@3AkYh0dMfK08B@D03>jJ80cnfU0<gTWP3Ci:00d^>O0=3WX@3<iYl0]m:;0=of
/039fYH0SZ9K0;;BQP3DmJh0f>j^0:RGJ`1oJSd0g^j]0<c/X@35i9@0fn^T0=3WX@36i9h0a^JM0<;P
V025WeP0Ykih0=GZY@3<h9/0cMjJ0=GVXP39fYH0bMRE0<cPV`3<iY`0c>NJ0<cWUP2>ZUH0c>FA0<kW
T`3=iY<0eo6W0<WSW034gI`0dN^Z0<7KVP3Mn;D0aN>K0>7o]@30gi40anRI0<GVU`30iID0`>FG0<K/
W`39kJ<0W[Qg0;oHU`3Ek:P0bn2M0<[KU@2lbhH0dmjI0=KPV`3Ki:40TYUF09NTG`37jIl0^]b@0=Cd
Z@3=jj40a>2F0;[DR`3AiZ40HGD`045B3P3IiJD0f^>R0=kZX037hiH0[KUk0=WMZP1CDcL0ooga0=V^
]`3ke]d0o_oa0?ook02W[hX0bmjL0=3SX@3BjJ<0aMnH0<kZX026WU@0C6@J08JNE039hIL0`]Z@0<cT
VP020<;JT00d0=C/XP3>iY`0cNBL0=3UXP3@iYd0cnNI0<gXU`3=j9/0d>F]0=KW_@3ionl0nooc0?ko
n03oooX0noKb0:>KV02JTXl0eLc?0>_Tj`3ooOl0ooko0?[om03konX0e>>h0=7VX`3QljL0cm^K0<cE
WP3oon40oooV0?Sif@3DeZl0P8U@0;k:R03=gI80cn:C0<kSV03Xml00gNRn0:nbX@3Kfm<0ookm0?[f
m@3lnoT0PX:20?cmo`3lool0mOOf0?ooo@3jm_<0ooW_0=>UV080o`0007`0Z;=W0<kNU@3;kJ<0anNN
0=o_YP3@gih0Xk5l0<[HY`1NK3/0j?O00>Of^`3:fIP0bmZI0=_VZP3>gYl0b^VM0<WYW@36jid0b>ZM
0<WYW@3BiYh0TZ=L0=;SW03Hl:H0b>ZM0<S]W`35jY`0cn^Q0=cWZ`3Eg:H0Jfi307ElD`002000a]Ja
0<cL^03MjlP0looK0>ObbP3Jgkl0];BL0<?3Z`3gomX0i_S60<SWX@37jId0b^bO0<_WW@3:iY`0bNRR
0<cUX@3AhJ00dn>R0=?/Z03BlJ/0gO^e0;;9Q@37dI80GU<K0:BJG`3Bj9d0^>VG0<?]Y@34hJ40TjMb
0;KXZ`0g>@X0HUX[0=ka[`39gID0fNVR0;g3P`27SDd0OXU70=3KV@1gRCl0g?6V0<kTV@3EkJ<0fo:Z
07ZDB`20W580VK=Z0=C^Y@3Mmjd0g?BZ0<CLSP3GlZ<0e_:U0;cOS`34iYT0f?Z]0>3o/`2nfXl0KH4i
03E5003Di9T0e>fJ0<KST@37hiP0d^^W0=?W]03_omD0mooT0?;oh`3conH0mooZ0?Ooj03hon<0nOoL
0=3D/`3JekP0e=Fe0=GK]@3Bi[<0e>fd0<k/YP3<j9d0dNVM0<kSWP1cR4D0b=fJ0=C[Y@3CkJH0cNNP
0P3:j9h30<SZW@1C0=[_Y02<VE40Zk1f0=WKZ@3DfjL0b]RM0=3_X`36k9T0a^jH0<_aW038jIP0`mV@
0=S/Y@3@h:80bmRP0>[gb@33e:P0a=ji0<KX``2Wcj`0K:9n05jHLP38k[/0fORo0<cYZ@3>ij<0g?>U
0<[PSP3Mkid0go2P0;c=O`3>h9H0cMjG0<STVP3<iYd0EEXH09RDE`3OgJ00cmFE0=7VX`30jj<0bON^
0;OLUP2ogYX0dNNO0<?HS@3=gi<0TZAJ0=3MY@3Lj;X0iNc=0>c]j03jn_`0oogo0?olo`22Nh80CTQ<
02l]<00Q7b00K6a/03i0?@1hNWL0SHn<075aK`1jMWL0ooko0?ofo`3oj_d0ooSo09cVi`1C[j`0h?oo
0?[io`3hlNL0d]2g0<S@W@2gbhh0d_>T0<CWU@2jghl0^>BI0;KUW`14O3/02`3oool000X0oooo00H0
c=nM0=;UY@3Eij/0bmfY0<kP[P3Ch[L20=;S]`2105]Z?`0/?0l0IgY<0<gZ^P21Xh80h__V05I_M00o
QH<0fooo0?Coo`0oA4P0m?_c02d/6P1YFS/0b=FO0<[YY@3?kjH0doBU0;_JS03;ii`0`M^D0<kPYP1n
S5T0o?oJ0?coh@3hon@0oOWN0?ooiP3]oMH0iO_<09VNI01EEaP0e>FQ0<gVY00D7000I6hi0<c[Y`3?
kjH0c>JO0=OVX`3BhIh0g?2[0<CIU01dRdD0Q9UD0=;QWP2/_GL0^mf@0<gaZ@38hJ00YYU/06AC9@3:
gi`0c>jR0<_/V`3Dj:00b^FN0=7`ZP2mhYD0`NJI0<CTV@3?kJ<0b^JL0<[PV03Pm:d0OX]609ZUH@1l
QD80VJEU092VJ02W`7h0bnJI0:_6M@3?jiL0d>bG0<WUT@3=iih0`=VG09^`M`3PmKd0dnN/0<cPX`3>
iIl0cNFK0<[UUP3?jY/0fOBU0=3ZX@3Bk:D0`mfL0=7WZ@1mQU40hNbd0<oKW@2DXf80dn:M0=?TW@3R
lj`0cn>K0<7ESP39gYT0b^BM0<3VV@3:kZ@0]mN>0=Oe[@2X`W/0RJ1J0=;VW`3EiZ00fNRS08nLE`14
C`X0i_:Z0<gYW03Hij@0am6E0=WO^`1PF4D0h;Nm0?oXl03looH0n_ca0?ook01gQTd0KWe208ZOGP1U
O3P0b^BK00D0cnNM01D0cNFK08nWG@1EKB<0UZiT09R`IP3LlZX0d=jP0=OTWP3?gI80g>fM0<3@Q@1]
NT80c]Z/0?_nj@3ooo<0ooof0=cEc@3YhM@0ookc0?omm03on_/00P3onol07`3ooOl0n?o`0?Soi03?
hk00c>RM0<cWV03=iZ80dnR]0=3O]P3Uk/l0o_o/0?7gg@3Eh;H0bmVT096RG02:VeD0c=ZL0>;[`03R
ilL0iNGK0?onn`3imO@0ookm07UiM`1aLG40o_oo0?WjoP3lool0lo?a0?onn`33Z9l0103o0000D01D
I1/0d_BZ0<3UV03BjIT0bn6I08nNI`1bP4/000/00<_EX03TkK@0LW/l07Mo@`2;T5H0g>JY0<[YW@39
jId0a^^M0<SZW@39jId0d^JN092QFP3HjJ80bN6G0<GWVP38kJ00b^VV0<?KW`3Hh;40L79:08J:J@2@
UgP0JgIH0>3^e03SkmL0lo_T0?coj03Wm<P0kOG>0>CWb034b:L0ioC60<gUZ`38jZ00b>ZM0<WYW@3?
iYh0d>FP0=7PW`2d`800]Kio0=[TY@3=g9/0b]ZI0<_JV@3KiJH0gn2T09nDG03Ug:<0c^BL0<?eX038
kih0dNNN0:2^L@33kk009RL005177P1SO3/0RJMM0<oYW`3CgY`0hNbZ06]j=`2Y_GP0d=fG08fMEP3E
iYl0eNfQ0<_VV@36hYD0bNZK0`3:jI/0:03=iid0cN>K0=;YX`3>j:40b^nR0<O]X032j9/0a^RL0<g[
X@3Wn;80eN:M0=KSW@3Cjil0anJH0<OVVP3<jZ80c>VW0>3j^`3Om[h0e>^e0=7U/03Fj[L0e>Fk0=;N
aP3in^`0oooc0?ggj`3_k=d0U9J10?3og03eoml0iOk50=?[[@3?i:40dNJS0=CYYP2K/6d0a]fG0=kh
/@37hIX20<cZX080anVL05@0b>ZM0<kSX03>g9l0KVm30=cJ/`031@007RD00=?][P36j9h0`>NH0<gb
Y03?lJD0cN^Q0<WUV`0kDPX0a]ZB0=SYXP3BiYh0c>ZT0<CWX`2miZ@0_?>b0:OQY00LCaL0Y=>L0;OQ
XP32jZ@0_n2A0<o_W03@k9L0bN:?0=C]W03AjIl0c^FM0<K/W`39jil0TYME05iE6P3omK/0emFH0<cH
V02kh9X0`nfU0<;VX039i:40eN^R0<cSU@3GkI/0bn2A0;c;RP3@gJL0jo?<0?oom03loOL0ooko0?om
o`3onoh0oocm0?ooo@3no_`0m_Se0?_oo@3lood0oook0?onn`2CQH@0>2PX0<:g/`3hlnl0ooom0>Co
o`2Zd]@0QiBU0>goo`2no>d0;F5:0183002BOel0d^^Z0<;[W`39ljL0bON/0;SXWP2kkjD;0?ooo`00
2P3oool0@P3JjZT0d^6V0=OX/P38f;40c=bh0:>bU@0K:Pd000d00008000f@QX0aMRZ0<cY^`1]VGH0
<UDo0:joaP2hhNL0kOoo0>[eo`14BD`0n?oh02@Y5@1GB2/0c]b[0;kJW@33hYl0[/b209BcI`2bc880
TjeT08VNG@1`PTH0dn:[0=7O[P3=hK00gn2h0?[hdP3@hkD0cNJ_09>IG@2LWF40eNFT0<kXZ@3=eJH0
V:9`0<g/Z@3<k:<0c^FO0<OCT@3EhIl0cMjJ08FIE03@ij40/<F009b[J02EZF80`NJH0<ocZ`3DkZd0
YIQ[07AS=@3AiZ<0a^^N0<SYV03Bj9l0c>NP0;oMU@80dnfT04D0^=B:0<WUV`38i9X0cNNN0;kES@2/
`WX0c^:K0<gQVP3DijD0S:5V08bRHP3@jZ40^=>60<;MSP2ofXT0hOb]0=Wc[03Fkjh0_M:J09BVLP38
eZ40h>nf0<OKUP3Ejj80b^:D0<[QT@3;hY@0eNZU0<GJV@3Zo/<0g^ff0<;6U03WjkP0?4@90=7KW027
UU40HG8[0<CJT@3Omjd0bnFL0<?NU`3@kZH0]]^>0<[^Y03;jj80eoF]0;?:Q03Bij80d^JO0<[KU@3@
hI/0fNVR0<WFSP35dXX0OYm@0=7RW03Pk:h0d]Za0?oih@2dRi40o]WQ0?oonP3oooP0ooo_0=gY]`3A
gjX0dnNZ0<OMW03VokL01@3?iid0:P3:hYP0c^JL0<;JT03GkjD0`m^A08nUG@23Se40>D@007V5>`1l
RS/0Tj5F0=7LXP1gOU80^KRT0=SDb033_;@0oogf0?_ciP3ooo40ookc0?ojn@3onol0oo[o0?ono`3h
on`0n?oQ0<gT[03:jI/0bNZK0<_YX@3=jZP0cn:e0>?cc`3eo^T0nOo]0=;P_@3Ei;T0aMNI0:FeMP2M
ZW@0l_SD0?oojP80o`0000X0ookm0?OclP1HEe<0ooom0?ono`3nool0nogl0?ooo@3He=40ooW_103o
0000C`2[^g80_MnE0<_`X`3>iiH0bN6G092RJ01IIc8000T00>G^^@3KhjX0XJMY0=cRYP2EV5l0X:Y]
0<[YW@39jId0a^^M0<SZW@39jId0dNFM09BUGP3Kk:D0cnNM0<OYW036jZ00]m>F0>Gj`P1QJ3h0H68k
09JINP0[<AD0N89W0?Sok@3iond0loSR0?coj03Ol;`0`<^P0?oog`2h`9T0fN^g0<cVY`36jih0a^^M
0<WYW@3?iZ00dNFP0?3i^P11BP/0NGm102Xc0026T540OHU90=OPX@3MhjD0fm^O0:ZOI`3KeI/0d>NO
0;c/V032iXl0enbM0<SBU@2oiJP0KVY401@;003Oo;`0cNbV082LDP34cH`0g^NV0:^fM01EH1h0d=VF
0<WFT@2@X5T0eN^P0<gXV`3JnJ/00P39jY/20<[YV`0Z0<gWWP3GjZX0d>BU0<[SX@37j:40an^Q0<K/
X@38jYh0do6W0<3DS@3OkZT0Df0K0<OOU@3Dl:H0bNFK0<7OU`3KnK<0/]2:0<gXY@3>ijH0dNNW0=?Y
Z@3=gjl0c=S20?;ak03jmNl0ookf0?ool`3oonl0d^700=?X_`34g:P0c>>[0?Soc`3folX0mOo70<OL
V@2AZ680dnfV0=;/Y@34hYP0anFK0P3:k9l0A`38jYd0bn2O0=GRZP17B200emBa01<C00001`00`]ZP
0=?b[`33iid0`>BJ0<SZX037iIl0bNBM0>Gm/`3OmJX0c^>D0<gTTP3<k9T0b^fM0<7ZW030m:T0]NfR
09K<T01<OdL0a_Jh0<Ca[P3<lZD0`NBD0<WYUP3AkYh0c^ZM0=3/XP32gIH0cOJX0;gRU@3Nij@0Y:1S
08f3B02m^gh0hN^/0=Wh]02igIL0ioo10=O`[P3=i9`0c>BH0=K]V`3Ek9X0YkQb096OI03Tl<80o_o]
0?oom03gm_40ookk0?oim`3lm?80oook0?ooo@3nood0n_ok0?goo03dlnl0mO3]0?oknP2;NGL0ATHj
07j4MP3am>/0kO_k0080mooo00/0h_oo03B2M@0_K5`0cK^_054l:@3DjJh0[=2:0<[`Y`2afi40`nfS
0;o]XP0;0?ooo`002P3oool0G00nDQD0BelT03973P0eCQL0>eHQ01@^001UOdl0IGa>0>3caP3RmLP0
e>Jl0:c1XP10Je00SKBQ0??fo@3omol0i?oo0:c@d028O7h0ooof040m;P1QDcT0bMBY0<CKX`3Cjjl0
`MZF0;oIT03Jm:X0fO>Y0<GOUP3DkJT0dNZX0<cUY03=k:P0en2W0>3W/@36gjD0aN>U08^FE03Hgi`0
cN6L0=7^[02W/840WJYe0<SWY03;jJ40dNRR0=cWY@3Gh9l0WZeZ0<KJU@3DjjD0f>fX0=;SW`3Ejj<0
`^BG0<W]Y@3RnkX0CT4D05Q76@3FjjP0_nBG0<k_WP3;hIP0Z/En06b3?@2QX600Rh];09jYI@2=W5L0
Q9YB0<3PU@2N`gH0c?NX0;o[W032lJ40_nRL0=?WZP33fIT0RZ=O09>^I`2ieH/0f_J[0;C@QP35gYX0
MH]:0<_OXP3HjK80WJUk086=F`2X^7T0TZIO0P2@YeL0:`2S^6d0TJ5R0=OT[03Ih[D0o_oK0?Cgc02O
YGD0b]>J0=_WZ@38fI80dNNL06Z5>03;iiX0aN>I0<OWWP3>l:H0e_J[0<7OU`30fID0dnZV0=S]ZP3B
ij@0c^>N0=7XX03>iY`0a^6B0=7YW@2gcHD0`nZK0=ObY@33fI40eNJb0>_/bP1nFeT0g;Vm0?_jmP3o
o_/0oood0>KbbP3?gk80f>fe0=?[[@3@kZH00P3=iid20<cXW@0@0<gWW@3;iI/0bnNL0<OQU`36h9H0
a^:G0=O^YP3JjZ`0f^VV0=KXWP3CiYD0e>NH0=oZ/03>eJT0k>WH0?oil@80oocj00@0ooof0?onl@3o
no00oogk0P3oo?l04P3oood0n?oY0?Oog@3<iZT0b>^I0<G/V`38kj00an^Q0<[VZ`3Rn<X0n?o_0?Wo
m03ao>`0m_o/0>Oed@3IiKd0hNW40?ook0@0o`0000X0TY6=0?kmn03oooX0ooko0>kZj`3?cLh0X9nM
0?onn`3onnl0on?C0P3o0000:`3GiIP0f^bR0=[h/036iY/0dO6N0=?_Y@2BYFd0[[b7038n303JhJ/0
f^:W0:N]K@2f_7`0UYaP0=STY03:jId0bNVM0<K[W@38jYd0bNVM0<_OU`2N[fP0cn2I0<_SV@37jI`0
a>JL0<3IX01IJcL0e]^b0=GG/03GfkX0WjJ50007003ionH0nOoT0>?XbP37cjP0TJMV06Yl@P2gaI00
Q9EO0<kXY`39jJ000P35k9T01P38ji/0cnJR0=?SXP2JWV40CeDG0=;LW@80am6B01/0WjQY065U:02V
Yf/0fMZN08F5B@3Qij/0a^>P0<K`WP3;k940d>N?0;O0O`37gjD0XiAg03LY303CnKh0a^JU0<gVXP3A
g9X0en2O0>;WY`3AdI<0eMBK0=[NX@1JHb80hoN_0<GMT@3@kId00P39jYT20<[YV`0f0<oVXP3Bhjl0
iOG40?CodP3]olX0g_^k0=Gd/03CljX0b>JL0=OaZ034fi<0f^nZ092SH`30eI@0a]fI0<CNU`3=jIh0
cnjP0<WXV03@k9l0cNNM0=7[X@3_ol`0kocZ0?ooo@3mn_D0nO;X0?oojP3oonH0amZ]0=?[^`3>jK@0
amn[0<_PZ039gIh0goBa0<[OW03Qn;80a=jG0=G_Z03QokD0dNnU0<GWVP38jYd0b^bO0<GNVP3GjJ/0
/K>;089oGP060P00DU<c0=c^^P32g9l0aNBN0P3=k:H0B037h9h0f_6]0=;/X`3IlJD0d^jJ0=WeX03;
kY@0c?2F0<C[TP31k9<0a>nF0;7UX`1/XfT0`oFh0;;PXP2khZ40c?6/0<GVX@3Al:X0`>2G0<?SVP25
Xe/0_nFH0=Wn/@32fI40f^VV0:^aL@2IWUh0MW`n0=?MX03Dh:80loo30>Kd]P3:hil0d>jT0<GRT037
hhh0eNbN0<WMV02<WV@0k?KA0>ofe`3ioNH0k_3J0?OhjP3emNT0o_kf0?oonP3ooo/0ooom0?ono@2T
Wi`0b<2n09jDTP3oo?X0_<:h0005003Gfld0ooch0?gdm@3Yool0f?oo00hoA03Yool0l?3^0=kchP13
BA/0oO_80=cOZ03Xm[T0b=fL0<g[X`/0oooo000:0?ooo`290<[TY`3Fl[D0bNNW0<O[Y@3>ljd0`>FP
0<3UXP3BmKD0c^^c0<kY]P3Cj/00DVA<06>0KP3`oo/0ooko0?olo`3Mool000l50;BRXP3onO<02`00
07=QB`2ma9P0fNjc0<kTY02?YV00enjV0;gGS@3CkJ<0cnZS0<oZY`36h9l0anBT0<OWY03@gZ<0cMRP
0=Kb]@3;jjX0TIiI0>K`Z@3?i9T0a^BL09RSJ`27UEX0b^VU0=ObZ`32ei80c]NF0<;;RP3JiZ@0_m2<
0=;YX`3:hI/0dNFP0=3VWP3:k9l0`NFM0<[SXP2LSf80OV`n0<kSX02lhI@0d_>R0=7UW@31fi@0S:5L
0=GAT@1jNCP0a<n:0=WYXP3<hYT0`^:F0;kUUP3:mJD0`o2O0<CcXP3<mJL0b]nL0=;YY@33gIH0Uk9[
0;cGT037iI/0cN^Q0=gg/026WEL0d^NT0=3RYP3lom`0nooH0<CGU`3GkJD0/<Qj0:o7N@37gI80UjU[
0<WGXP3Rj/40o_oO0?Ooe`3Hi;@0j_Vn0<CDU@3Bj9l0d>JK0;gER@2=Z5/0d>ZQ0<oZX`3<ij00`]jD
0=[d[@3Cj:D000h00<[OWP3DjJP0d>NQ0<gWWP3<j9d0cNjM0=;^X@37hIX0c?NW0<OVV03?jIl0bn2W
0=GJ/@2CL6X0]iFF0?oonP3onOH0oood0=oZb03<fk@0cn>^0<KNXP3>kJL00P3<j9d20<[YW@0Z0<cX
W@3>jYl0aNBH0<o[X03FlZL0a^FI0<KRV03?iJD0aMbF0=3XW03:hi00b^>B0=7SZ@3BgK80oooa0?oo
n03ooOd0oogo0?gnn@3jnoD0o_gh0?onn`3ooOl0oogn0?ooo@3honT0mooO0<cU[036jid0aNbM0<O^
W@36jid0c>JU0>3d`@3ionl0mOg`0?_on`3kooP0m?kV0?[oj03Xk]@0oooa103o0000=`010000o?Wb
0?olm@3ajn/0oogo07UeMP3oo_d0oook0?ociP32Xi40bn>W0<O]XP3EiYP0c=jD0<cWX038iY`0_n2?
0<?QU`23V5l0cMjZ07N3D@3=eI`0cMFI08N@C@2;U540SIIG0=_ZZ@3:jId0bNVM0<K[W@38jYd0bNVM
0=S/Y02eaWl0d^>L0<kVW03=kj80bnfS0=Oa]0003P00h>Jh09NJK`34bj80e^6i0008003ioml0hNg5
0=_P^03Ih[<0S:=K0<KKVP33eIT0cn>V0<7PVP36jid00P33kIL0G036ji/0cnJR0=?SY01FG1h0VJ9S
0<WHU`3Okjh0aMBC0=GQX@1<EAH0D5HH04M=3`2d_Gh0`m6C0<GUXP34jI/0aNN90=7ZS`3Dgi/0DF8[
0=c6[P1VF3h0T;^30<g[[@36hIh0PJ5H0<o]Y@3CkJH0e^^V05YE7P3`kkH0dmNJ0;S9PP3AjId0d^jQ
0<WZV@39jY/0b^VM0<cXW@3?iJD0amNZ0>Kec03eomT0l?o=0=[b]P38hJ00c^VR0=CbZ02ng980g?Z`
0<OQVP3GjZX0WJe^0<gPWP3RnK<0bnNL0<WUV039j9X0cNbP0<SRV`3<iYl0mooF0?Sol`3nooX0oood
0?ook@3jnmT0gNBj0<SMY@38hJL0c^^a0=3[]03Fjk<0d>BU0<WNV`3Kl:d0a=^E0=7[Y03?jJ80hOne
0=7_Y@35iiX0b>ZM0<[/W`3ElJL0cnJR0=_Q/@3CdJ/01P<000<5003>gj/0d>JX0P36i9`01`3;jJ40
eNZW0=OZZ03<hi/0a^2F0<CST`31hHh00P39k9P0@037jYH0b>ZF0<OYU@33m;80P;Af0;WY[@2njZl0
`^F[0<OY[@3:iZT0bNJV0<OTXP3;jJ<0PiiG0<GWV`3?lJD0aNFJ0<kYXP3JjjL0en:P059F6@3FeI`0
jnZa0=;FV`3Pj:`0an:O0<[YX`3?ki`0cN^E0<kYV03AjIl0EfXZ0=gX_@2nbJ40o_oS0?ooh`3nond0
o_oa0?oom03oooP0oooj0?oln@3kmOD0k>?T0?S`kP3oo_X0o?Oc0>GQh0051080inSR0?oon03mooT0
i_oo0>;oo`37f^T0mOoo0<_Vg@3Eonh0=30G0?ojh`3ooN<0lo7:0=;JZ`37g:4;0?ooo`002P3oool0
R@3An[@0_>FY0;[U/02Rd:/0Pk2C05^8L@1_WH40BgMF01e76@1PR5<0NYaZ08bQSP3nmOP0aJjf0?ca
m@3Pool0=g9L096fY@3on_H0OfMS01P0003/bkX0l?>n0=GYXP3Dj:40Ni580=7WW03DkZD0d>ZS0<OT
XP38iZP0g_g20=Wj`@3Fn[`0i_Bo0=OS/@3TolL0coBa0<_MT`3QkYl0h_bS0<GXSP3IjIh0RYYA0<k/
XP38hY/0g?2[0>7WY`3TjJT0b]JD0:2aK@3;hY`0h_be0<?JU03=iih0eONZ0<__Y`2neiH0YIMZ07mZ
?@3DijD0b^bP0<GTU03?h9T0cNNP0<COV03LlZT0c>BJ0<KRU`38ii/0cnnS0<OWV`39j9`0b>BI0<gU
V`3KlJP0e>VN0=_bY03@iY/0bnFK0=C`YP3GmJ/0bn^P0<g[X@1fTTD0c^JH0<gST@3IkJH0mooP0?Co
f@38hZ<0dnjW0;gLSP35i9H0bNRL0<OOX`2U]hD0k?OE0?Soi03`omd0cn^h0<_XZ03:iJ80c>JL0<oW
V`3DjIh0f^bR0=3QV`3BhJ00b=VE0=S^YP35fI@0enNX04aL7@3>h:80eNZY0<cWX037iYX0`nJF0<C^
V039l9d0c>^U0;S/V@3:lY`0_=f<0<_UY0084000XH5d0?oNf@39a;h0oo[h0?oomP3ion`0n?oV0=3V
]@3=jJl0a>FN00D0bNVM0140c>bP0<KVVP3@l:@0`N6E0<k^XP33iIT0a^VU0<7WW03;lZ40aN^D0<GX
U03KmKP0^m6R0?_ol`3kooX0oooo0?ono`020?_oo`0G0?koo`3mnoh0o_Wm0?olo`3oood0m_o/0?Oo
h`3:iK80b>VR0<KZX037jYP0anVE0=3XWP3DiZX0jNkG0?oon03ooOl0l^of0?kmn`3hn?00nog`0?[m
mP3nood00P3o0000101jN7T0[JbW0?_gk03aj^820?l000080?[am03oo_d0oook0?olk03Mak80`NFU
0<KgZ03@iIH20?l0001k0<_VW`3CmZH0anNN08bQJ03JjkL0VjUf0>K_]P36d9<0PHa70<gHT`3Ok:L0
eNJP0<[YW@39jId0a^^M0<SZW@39jId0[L5i0:fnM`3Bhi`0dNVO0<W[WP35ii/0Hg`h03U<303GgjH0
V9eW0<WBW@0Z=`40d>6Z0<CFW03;fZ40aLfD092LG03=jYH0d^fN0<SOV@3HlZ/0gOnb0<?]V@31kiD0
`^jG0<G/V`3=iZ@0dNBT0=?OW`3:gI/0b^FP0;G@R`36gi/0eNZW0=WXY`3=gI`0_]6?0<ONVP3>kJX0
_nRV0<k/XP3;jX`0b^N:0<kNU`3JhJh0^IZ808akI`009@00bNF[0=_[[@3HkJP0WkA_0<gTWP3Qn;80
GU8R0>COZ03_k[D0UZEP0<SNU@3BkJ00b^VI0<[YV`3<j9d0c>RN0<oTZ@3Ymm@0lokP0>7/bP3VllD0
enFb0;W;T@3CjZH0d^fV0<;TV036k9l0cnnV0>7_/P3:e9P0amJE051S8@3Mmjh0`]jD0<OUW`3@kJ/0
c^N]0<cU[P3coml0mooc0?col@3Vj]40dmF`0<_CV03AgI/0cnZM0<WXW03Hn;D0gofo0>3h_P2ichl0
f^n/0<KKV03Pmk40`=ZC0=Wc[034hYP0anFK0080b^bO05@0b>ZM0=OiY@32ghd0a<nC09nQLP070`00
5QL00=OVZ`3>hj00b^BJ0=G`X`38hiH0FVXS096NF@3Fk:@0cnVR0>So`P2nhYX0a^ZR0<OXX`3;j:D0
dNRT0=7VX`2hgih0d_nn03UO9P1cUF80bNBg0>?jcP3eom`0mooH0>ooc03Ejj/0]/f90=;/X`3Bl:H0
`^fN0<;aX`35jIl0bMjI0<[>T@2:MT<0LU`Z09nFG`2o_XD0do2`0<GXY034iiD0b>ZC0<k/UP3El9l0
cNFK0=k`]P3DhZl0dmn_0>_da@3Eh<00i?7G0=kQd02n_;00^KF/0?oln`3bj>T0n_7d0?_em@3ooo/0
o_oj0:RR/00H52D0[kBj0?oonP3hnO40looo0?7ho`38e>00Cg9d03f@LP0VHd@0inoJ04M2;`2PWXT0
o?oX0??ogP3>iKT;0?ooo`002P3oool0R@1UTE80HhmD04ah@`1IQVD0;UY3000Z6@0gHD/0EWmO096g
QP2fg:<0anBf0>GchP3om_`0^j6Z0?Sjn@3Fool06dTl0>;gl03on_X0>RLQ01@0003on^40ooo=0<[P
V03GkJD0LhU00<gUV`3:i9X0`]jD0<SUY@3DkK@0k_oD0?;og@3`omH0lOo=0=SY]@3<jZh0_N2L0:Bf
K03KjIX0a]n;0<WYU03<gIH0UZEP0=3UX03<iJ40fNfX09fKGP3Mhj<0eNVT08^OFP3Gjj@0_]bB0=[`
Z03:h9P0`>2D0;gNU`3QmkL0ZIQ/06E>8P3@h9l0b^ZO0<SWU`3Gjj<0bNBM0<[XX03=iid0an6H0<k/
XP31hID0bNVN0<c/X@33hYH0f_:X0<KJT`3MjZD0d>2I0<OLS`3=hiP0cNFK0<kXWP3;iI`0`mnE0=;^
X`1:IAP0d^fN0<WRT@3Aj:00l_oM0?3of034hj00a^RN0<k_X039jYT0b>NI0=3YY`3>hjX0//:E0>Si
c@3KnlX0b>Jb0<KTY03Jn;80b^BJ0=C/X03;giL0dnBM0=3OVP2GXf40fNFS0=CUW`3Mk:T0fnZY04YI
603Ai:@0cN:Q0<gXX@3AlJH0bo2R0;o[UP3:m:80`>BJ0<?dXP31ii80eONS0=CbZP003000/91k0?OE
b`2g/jX0oogh0?[ek`3ioo40m?oW0<kT]@35hJH0co6U0080b^VM0380bNVM0<[YW@3:jId0c^fQ0<7O
U@3AkjD0cn^Q0=7]X`3?kJ<0b^bP0<[_XP34jI/0`nVF0<W/VP2ogId0dn^k0?SomP3fo?P0o?oo0?Kg
n`3kool0n_go0?koo`3jn?/0oO_n0?omo`3oood0n?o/0?Woi03?h[@0c>JU0<[XXP38iiL0b^NC0=3X
VP3?hZ80io3E0?[mm03ooOl0n?Gn0?ono`3oooX0ooof0?[kmP3oool0moKl0?ono`1]K6X0no[e0?Kb
j@@0o`0000H0n?Kg0?l0003o0000hlnd0<WVY02njIX40?l0000<0=?dY@3;jJ40//N<0=7RZ`3:f:<0
bmVN0=SVZ02Y^G80eNNM0=GYX@38h9H0bNVM0P38jYd0`P39jId0c>RM08bPF02JZf@0cn>K0=C^Y03<
kil0a^RL06Eg>@1;Fad0e^BY09>QIP3PkKD0@E0G0=k]/P3UmKL0c]jP08VGF@2`a7l0a^RD0=?_XP3B
jJ40b^BK0;kQT@33kIT0`^jG0<G/V@3:jI/0e^:R0=[PY03Kg:80iNnb0<oXY03Jn;80d_2X0<CNU`3@
iJ00b]nJ0=C]Z@39j:80`>FO0;kYXP3<k:00cNN>0<kVSP3IiZ00en2Y0<j^V@2^W8@002h00=3a^P3:
gj@0fNRS0<oNV@2kc8P0`=B?07]Z?03IeZ40f=^R08nJF02__WT0dnVP0<[YW@3=iid0dnBP0=CSXP3C
hZ/0jOG=0>oieP3DgkL0g^Nh0<gJY@2/^h80YKYi0=_d/039kZ40b_6R0;oTU`3>hIl0enJU0<cMV@2g
b8@0bMnG0=7XX038hId0cnFU0<_PY`3:gZT0n?oQ0?Sol@3lond0o_oT0:fcQ`3Ghj40e>JL0=7^W039
jY/0b^^T0<_ZY`3:i:D0e_6^0<[TW@39gIP0cn>N0=[_ZP39h9P0c>^O0<[/W`35jY`0aNZJ0<S[V`35
hXh0eo2O0>;]/@1gNdT010D001`O003Ij:l0d^NV0<gXV`3FlJ80_]V80:ZjL@3:fY<0_]B<0=?_Y@2e
fI40b_2W0<S/YP39jZD0bNRT0<WRX03=hj80coRb0;;MV018Ib`0:4HD0>3kdP3KlLX0io_:0?;oc`3Q
nKl0an2O0<[OVP3:gYL0f>nW0;cRU@36lJ80_^2F0=O^Z03QjZT0_[=k06IK8`1QHBD0JW<d0<gLX`3A
ijT0c^jR0<KXU037i980bnJG0=C^Y@33gIh0c>JY0<kRY@3=fih0dnBj0=k]cP3lonl0oood0?omm`3o
n?T0oo_o0?ojn`3ooOd0n?Wd0?3ek`1oNhX0IfAe0>oco03gm_80oooj0?_oo@3oo_l0k_co08B/X`0M
KTD0VLfV0<SH_P1CGdT0VjZC0>Soj@3Zon`0dO?B2`3oool000X0oooo08T0`>390<W/`P2dfJH0^mfZ
0<c[_`3Mm/h0`mZ/0<GLYP3LkKL0a]JW0;BgY027OG/0BdI307f7OP2Rc[d0CG]a0>CWn00n;TP0@S8m
00<3000a=ad0d]fU0;kHT@3FlJ`0c^NU09>/JP32gY@0anVC0<[/UP3BjjT0c]^]0?goi@3hmnD0n?oH
0=3][@36h:<0dnR]0<oSY02AYF00e^ZS0<gPX03DiZ`0G6]008RAIP1EDb00^MRD0=[`[`1]ER80g>FT
0<gbY@2?ZF00k_Rc0;;RSP3SmJ/0b]6;0<GTV031giT0iOFg0:nHKP1dEbd0c=JG0<OSV@32hi80f>jU
0<7SV@39j:80JW<b0=GQW`3HkJP0`=ZC0=kl]032i9X0gOfd0<3KU034fiD0K80k0=c`Z`2DZ6<0S9eI
0<SHT@3?g9H0aM:<0<cLU@3MkZL0bn:J0<_VW`3;jZ@0`NBP0<gd/`3;kjl0b>^W0=cm^03<jZ00c>^O
0=7]X035gI40f?2R0<ONT028WEP0fNbo0>WmbP3GkJ`0b^BK0;kHSP3Jm:/0c^NU0<SOV`3JlJ/0b^2E
08nTF@3JiJ40g^VU0;o>R@2?X5X0c^BL0<gWX03:j:00bNVP0<SZX036jZ00`nbN0<CaX02liY@0d^nO
0=7/V`3;k9d0ao2R06mB:P2lUGP0/kFM0;2]WP3oooH0m__e0?_om03?h[D0dN^^0<KXU0030<cXV`0Y
0<cXW@3=iih0bN2J0=7XXP3AiZ<0dNBT0=CTY@3?h9T0gO6J0=S^YP3AijL0foBb0<_WW037iId0bN:[
0?7olP3hool0nOoo0?comP3nooX0o_gk0?oon`3hmo80oOcj0?cjn`3imO@0O7Y[0:n_U@2NX7T0cMBN
0=;QZ03PmZ/0a=f90>3lY`3;iI/0jO[H0?Som00c=Sd0<c@h02d]8@39ak/00P3o00001P2XXZ80=2h^
03di>03oood0mOCb0??cl@P0o`0000<0fmjK0<gRU@3o00000`3o00002@3BjY`0e^bQ0<kSWP28WEX0
fnn`0<cRXP3BjjT0bNNO0<OWV`020<CZU`240<gdY@3>l:<0aN6F0=WaY`35fi<0QIUA09:VGP33gi@0
_mjB0<C[W039i:40MW=B0=[R^`2ie:40e_Fl05Yf>`1bQTT0jONj0<SBU@2^_Wl0`=nL0<S/YP35jj80
bNRR0<oVWP3?iid0bNZK0<K[V`3Em:H0c^BK09>HEP2jXF/0]I1S0:V3GP2AO4d0WJ]]0<ORV`35jY`0
`^:F0=?_Y032hID0`N>G0<WeZP2gj9T0^>ZE0=OmZP3Pk:80jo6[0>O`[@17G1L0h<FJ0:bEK02^gJH0
GI9L0;?SY`3=hIT0i?F^0:2]J03VmK00fL^J096IGP3`o/40eMjO0:V_L@2b_Wh0TZ]W03M7202TVVL0
OW9203dm2@1_Mc`0UYiS0>Wa^03QjK00d]^T09nXK`2N/780c>>O0;oRTP37kIX0`>RB0<W/VP3>kId0
cnZK0=CZW`1mSDH0WZ]U0=COV`3Jhj80c=JG0=STY03@gJP0f=k20?koiP1XLdP0cMnU0=[eZ037iYH0
c>fN0<OYW035iI`0anNN0<CVVP3>ljH0c_2S0<_KU01nQD80aLn:0=CUWP36ji/0`NjK0<7^V@33kIL0
a^bG0=OWWP3=eYD0PhaE07f5E000200000T00<gQ/03@j:h0c^fQ0<GWT`3@liT0OYE50=[_Y02_bWd0
a^:E0<_/W@3>lJ40aNbK0`35k9d0<036jid0/nRH0<CeY03Bij80LHQJ0>gojP35hKT0g?2a0>3l/P3B
mZ`0^^6N0=_bXP2@W580RiIA0>7^Z03<g9D0hOF]0<OMU03AjIl0d>bQ0=?bYP2ogi<0`>2D0:nSL`2J
Qe`0ZkUk0=?ZY03DkZD0e>jW0=7_Z@2njJ40`_>T0;WOR03<i8`0cnNY0=C__03aon80nOoa0?comP3o
ooX0l^oX0?Wgj`3ooo@0oooj0:j`[@2LWIl0o_oo0?ooo`80oook00`0nO[e0?kon`3ao>`0iO?J0=7/
]`2fe9H0XkjE000<000:=AT0D8ig08[;]@2kl]l;0?ooo`002P3oool0RP3aool0l?oi0?7on03boo40
m?o_0?7oi`3<f/40h^kF06I]F`0d>b/0QXF00;nc]`1cMG80Jgab031DAP0N?cP09RXf085hR@0;0040
9Ad@08J7I`3HjZh0fNjY0=;UX`3BiJD0UJ]Z0<[TV`39jiL0b^fI0<k[Z03<h:l0n_oU0>W^f03YnlT0
bN>T0=Wa]@3DjZ`0en^/09:XH039giL0d^NV0<CHW@045@005b8009fPJ`39jZ<0b=nK06eF8P2c^GT0
`N6F0=ccZ`3Mij80`>fL0<GJS`3SkjL0fOFZ0<KTWP3?gj40XHYP06e@9P2GXF80f?BZ0<o`W`3;hIP0
c_2V0<GTWP3FhIl0WJaY0<kUW`3Qo;D0]=::0<k^Y@2de8/0bnJO09:YH`3?h9`0a]NC0;oDS`2BYV40
h_>/0=c/Y@3Di9d0dN6J0=gaZ@36h9L0d^jT0<SXW`36iJ40cN2Y0>oob`36fJ80a=NO0=W]/P38g9l0
d^RX0>3f]@2ldhl0d>NQ0<SJW03GgkX0o?oJ0=g][`3<gid0Uk5X0;kHT@39i:40`MbG0=Sc[03QoZh0
b^FF09NVH@2]_7L0VJYT0<OKU03BjJ40cNNN0<[XWP39jIh0b>ZN0<K[WP35jih0ao:R0<[aXP3;ii`0
a^2F0<cZX02oiih0_J1h0??<[@3@eKL0Y:J>0?3ah@3ho_@0nooa0=CU^`3FkKD0c^fQ0<[YV`<0b^VM
02L0c>RN0=[d[@3=ij00`mZF0<?HU@3BiJ<0en^T09R^G034fY80hoZf0;gGT03MnJ`0cnZS0=7X/03_
o^T0nOoj0?_on`3looP0n?[g0?ooo@3dlnl0oooj0?[fm@3hm?D0h=cK0>CUe@3fnMh0emje0;[5S@2f
aH`0f>jU0;kGQ02meX<0`=N?0>Gdd`3/mnL0>3]00:JWZ`3hn>h0103o00001P3onoP0ookm0?_jn02V
YJ<0ooom0?koo`80o`0000<0nooo0?l0003o00000P3o00000`3NhIh0cnBI0<C_W`020?l0001`09J?
F@3AjI/0cnFJ0<kRW@2EZ6H0b]bN0<gSX`3>ijD0a^BL0<_[X034jYL0bNnL0<cbY@3>l:<0bnFK0=kf
ZP34fY40P95:0<7ESP3Fl:T0aN2M0<_/Y`2_aXh0/:bC0?koiP2N^8/0[/ZG096ZL01eRD`0cM^N0:Nb
L026Ue<0do6Y0<c^Y035jj80bNRR0<gWWP3?iid0b^VK0<CWU`3BkZ<0enRR0;2bL@3L`Xl0l]2R0?KE
[03?_Hd0Tj9Q0=;]YP34jI/0c>bP0<OSV03:iY/0bNVN0<;[W`31l:00^N^F0<7VUP3Sl:P0e]bF0:nh
M@2;XU`0c[>609R1E`35mK/0>g0h0<cn`@3ElJL0cNBL08fLE`3;fYD0h^6X071f>03@fY/0fnbV0;oE
S@2`b7h0_MB<0<_OV037d940e=RM0>O[/03HhZD0]/:408NBEP3BgJ40SiYP0:>aM02K[Vh0hORd0<k^
XP3<lYl0b_:L0<[]V`36iID0bNJF0=?[W`2X^G80WJeV09:OFP2BWE/0^/J40<kMVP3<fJ40f^:i0;:k
T03Ij;40cN2P0;7<O@3KnjP0b^^L0<KVVP80bn^R01d0c>bQ0<[/X02fe8X0VZUT0=SQX03/nK@0bMfE
0<G/V`31kY/0`^jI0<G]U`39jiL0g^^U0>7WY`1jPdX0OHEB00hJ00002`00`=BO0=;Z[P37iYX0`nFA
0<oaVP2K/FH0e>RP0?3o_P3:i9X0e_JZ0;KHR`040<K[W@0n0<SZW@37n:T0`^jO0<gQW01GKCh0]MBd
0<SW_P3:gId0e>jU0<k`YP38l:X0b^>B0>?cZ03;fi@0Be`E0=[[Y030e8`0fo6X0<[RV03Bk:80aN6F
0=;^X`2acH80fMRP0=oHXP1XKb`0bMJ@0<_UV`31giD0a>BK0<CUWP38jYh0d^nK0=3ZT@38iYh0bNFX
0=cca@3[omX0looT0>olhP3konX0o?oZ0?cok01oQWH0:S0T0?gno`3nool0n?Sh04Q7@`1HEe<0`/6o
0?ooo@3kooH0<3`V0;gCY03LmK`02R8003QE9@20ZWX0Xn2d06>UM`2_ikX;0?ooo`002P3oool0MP3e
ood0mooo0?Ooo`3VlNT0h>_K0=CMb00S;1/0dmSB08b=T@2l^l00noOf0?oio`2c_kd0KhIl000D2@0:
7AT0nooo0?kko`0:0000=BPE0?oog@38hih0dN:N0=GQX`3FhZ@0b]nN0>?m]03:k9P0b^fI0<g/Z@3:
hZh0mooT0=SUb`32e:00bn6S0<7FV`3<hZ@0^Lf>08nUG@3?iI`0e^^Z0<3DV@002P002a/00=KOZ03?
l:T0b^6M069;5`3@eID0a^:H0<oUW@0nB0<0boRW0<7GS03Njj<0dNfR0<WTW`3Pl;80/IY`07aO=@2F
X640_]Z@0<g^W@35fi80d_:Y0<?RW03FhZ00P95=0<oVX032gIH0fON_0<KVW@3:j:00e_2Y07fBC@3C
hYl0e>FQ0<kSWP3Gjj@0g>fV0<7BR`3Ol:T0d^>L0;c@R03@jZ00c^ZO0<?SV03?j:H0oooF0?oof03E
f[40gN:j0;W1V03Oj[l0a]>U0?;od03Ik;@0_mFG0>Oe`03oon@0o_kJ0<[CW03?gIl0BV4K06j8@@3?
kJL0b>NQ0<OWWP2dehD0bNRH0=_/YP3Olj`0`MN?0=cbZP3:i9/0c>RN0<WYWP39jId20<SZWP0B0<G/
W@2liIH0e?JZ0<;HU`3Fk:/0b^NU0<;ZY02TR600fkNE0<oJ/P2Z/Hl0oooZ0?kom03lonl0c]ne0<[N
Z`35hYl0b^VK0`3:jId09`3<j9h0^mF>0=SbZ`3:hil0>U4=055X9011EQ<0CV@K0<_QV@2me8`0bnFK
0=?^X@36gi/0ambS0=OVa`3fon`0m_c`0?WkmP3go?P0o_om0?Sim03oo_X0oo_k0=cCeP1cKFd0oooa
0?Gkg`3TklD0c^2V082AFP3JkZL0eNbN0>;kZP3Gk:L0joWH0>geiP26Qh/0m_Kh05aID0040?l0000:
0?okn03oo_d0d]7?0>g/jP3oood0o_oo0?gooP3nool0mo[o0?7em080o`0000@0k]fb0=7CTP3HjZ00
`^fM0P3o0000901YI2`0cnNI0=?YWP37fiH0Cf8R09:TIP3JkZl0e^b/0<WTW@3EljT0a>NE0<gcX032
iiX0`nFH0=C_XP3;hIH0dNJK09b]IP3JjjL0bMfN0=Wa]`3BkKH000/00?ook@3non`0m?oS0<kX^@1K
LcT0OY1D0<OEU`2KYV80S9aE0<STU`33hiL0aN^P0<WYX080cNNM06T0c>RK0=GdYP39h9P0g>RV0<o=
T01^DR80MeDX06566@1DAa<0amJC0<kXW`35iiX0do:T0<KPUP3CkJ<0d>jT0;gSV038lj@0con[0<W/
W03;f900emjH051K5`3?iZ00W8AF06YC:@2ljJh09eXQ0;GWZ031ii`0]]B<0=;VX@3FiJ80f^FS08^@
D01QJ2D0_=N:0=WjZ@37j9L0d^NJ0=K/X@3DkZ@0fo6Y0<gFU@3Kk:P0e^VW04YJ6@1cPd@0KWho0=7Q
XP2AYV<0a^2I0<WYW@35j9P0anfJ0<OZV039jYT0b^VI0<WTU`3Gjj<0bmbE05=R7@1OKR/0D5lL04aM
6@0a@@<082X00>Od_038f9T0e^ZS0>Oo/`2lfHT0a^NH0<SXW03?kj@0bnVO0<g[X@3:j:00f?6]09>R
H@3FhZ80d^>O0<CNU@33k9d0`NjM0<?]V`38jiT0c>VI0=7LVP3Bf9X0EEhU0=7JX`1MJCL000h00<CL
X03Bk:/0b>RM0<;UT`39kIH0Rj5H04YK5`2ldH`0d^bU0<k/Y03@l:D00`38jYd20<WYW@0m0;WSU`38
kZ40cMjJ09Z`O`34i/D0_=Zd0=;UX`36h9T0bNZS0=7i/`32fhX0a]^>0=GYX@3Hk:@0d^RO045G3P2G
[F@0eNfS0<gUV`3;hiT0`MV?0>Ko]P3DgYl0gn>V05YK5`3;dHT0e>bP0<c/X03:k:80d>NS0<cPV@3I
kid0dN^B0<[YV@36iYd0bNN[0=;]^03Ekkl0cNBf0<gS]03Ci;X0a]Ja07V5K@22RgX0i^SW00000P03
0`<0`L2l0=OFdP010000bLO80?con0043@00i?G;096UL0003`00`]fZ0;[P[@38oll0P[j:0;[a^00;
0?ooo`002P3oool0M03oond0oooo0?ono`3moOD0nokS0>GYb03^l=X0n?Sf0?[ho`3bl_`0mOKa0>WO
j01oUI<0:dQ30=[PgP2RVI`0_;fg00H8001JD3D0el^S0>CW[P30iID0am:@0;boQP2T[740]LR60=?]
Y038jIP0c>fL0<c[Z038iJd0lOoM0<cQ^P3;gj@0c^2R09^]L@2jcXl0Y;Yi0=;YX@3Qnk40cnRV0<_S
Y`002`00dnJh0=?WZP35jj80d^^W0;VVKP3ThZD0d^>M0<;?RP3PjJH0a^nP0=GaYP29WED0V[AZ0:[3
O`3GiJP0c[N=08e`AP3Ojj/0PYiD0<g/W03MlJT0b^RP0<WXXP3?hih0b=fH086KE03On[<0bnVQ0<k/
Y031g9D0b=fH0<[KU`3^n[P0_Lb90=3WW`3<hi/0GG<[06f2?@1NLRd0UjaW06f3>`3IlJL0_]V<0<kZ
W@3HjJD0OVM70>?>/@3ii]D0ooc]0?kdj`3Wh=H0FUQ;0?7jg`3RkL/0dnBh0<cD[`2lZYh0oogX0?oo
eP17CQP0f^f[0=3YY@1lVeD0]=J<0<K[WP38kY/0bNbJ0<gYW`39iI/0eO6W0;WGS@35i9P0b^VM1039
jY/04@38ji/0dO>W0<?PW@3Lk;d0OhaQ0?3of02ohZX0RG530=FfR03Yol40d>BY0=g]_03oonT0oooX
0??of@3Ol<@0c^Fa00<0bNVM0P3:j9h09`33gYL0XKae0<GPV@2ofYD0c>NR0<WSXP32fJ<0cnVR08bU
E02H/Ed0Y[ib0=?XY`3HjZ`0c]^V0?_of`3emn80m_Gj0?[oo`3lood0oook0?olnP3onod0hMGI0?ol
o@28Sgd0>DHX0;gCY@3HlKL0RIYT0=o_/@3IjZH0e>RQ0<_MW`3Oj/P0kOCR0<O6a03nn_/0oogj0?on
n0020?l000050?[glP3oo?L0l>o[0?_jn03jnOL00P3oool02@3kn_l0ooko0?ono`3nood0oood0>GL
^`1TDRX0VYYL0=;RV`040?l0000T0=gcZ03Nm:/0d>>Q0:RkN`2_`H<0@5@G0<7GU`3:iIh0`^2F0=;e
Y@31iYH0bnfS0<k^X`3BkIh0b^6C0>[l/03RlJ`0d^2R0<cIZ`3BhKX0]<BZ0?Goj`3`kmd0ooo]0>[j
e@3=gkD0Fg0h0::dN03HijH0E64K08bLD`3MlZD0cnZK0<K[W@38jYd0c>RK0P3=j9/0T`1DK280dmnO
06IZ;`1TFRD0KTlS06A56@1REal0i^BY0=SYX`2jdHT0g?^_0<_WVP34g900bn>G0=?[X@3?jj40bN^N
0:_FQ02ce8D0en>K08nFDP3BgY`0b^>O0>S@X02nZ7T0a?2a09k>T00PEa@0`_b`0;3OU`3<hZ40fnZY
0<_UW03Kh9d0@4H00<W_VP30kY@0_nZ@0=OZV@3ElId0^^^B0=7mZ039gY<0eO6T0;;AP`3SokH0g?R^
0<gWWP2leXd0an6H07VEB`3DljL0c>^O0<c]WP3;kYh0bNbL0<g^W`3>kJ40dN^Q0<[TVP2oeXh0eN^S
0<GLUP3HkjT0c>>K0=SYXP3TmJh0fNfV0<kUW`3<ij00bNBM0<cZXP3;jIl0an>F0<cXV`3FkZ@0a]RJ
07^:D@3ChZL0h?2b0=Ka[P2mgYL0`^bP0<?/X03:j9h0cnNM0=?TWP3GgJ40^Kj4061Z;P3MijX0eNFV
0=W/ZP3Bk:D0an:K0<k^X`39jih0a>VI0=S[Z`3Bh:D0amVK0=GYZP34gI/0d^fX0<[XX03<ij00c>RN
0<cXW@3=iid0bnVO0<cVW@25TE40EVdi04a_D@27Yh80d>6M0<kUX@3BlJh0`>RO0=?`WP3;iiX0aNBH
0<WXW03Ckj@0b^BJ0>Gm/`3Ejj80f>bT0=7UW@3Sm:d0`mB=0<SWV`3OnZd0]kM_06AQ6P3@hYP0dnZR
0=[a[@3?cYH0/:Ub0>;XX03BjiP0c>ZB0<k/UP39k9X0`nZI0<3YVP020<G`X00E0<CUX03CkkD0lOoQ
0?Ook@3lo_/0n?[i0?_mnP3em?00o_gk0?_fnP1fLGL0IFAR0041003RilL0Z[680:ZjU@3Gkld0/mF`
03ea@`2DbYP0aORm00/0oooo000:0?ooo`090?koiP3fm^`0oooh0?ook`3oon<0l?KD0?oojP3fnO00
o?oo0080nooo06T0^;No02Lk?02AZZL0`L710?oko@0R6a402PD008V4GP3Xik40h>fX0<?ZU`31bh`0
ooo?0>;]/@3DjjD0e?2U0<OVUP3?jih0d>VX0<cSZ`3domX0c^Bf0<oNX`3IjJX0VZa^0<gQXP2dbXT0
dnfT0<7MTP3:iJ80`mbR00DJ0036g:d0e_2a0<oeZP3@jZ<0iMBL0=C@T`3Kj:<0io:^0>Sc[`2ni9L0
f_J/0=G[XP2R^W00S:EQ0=k/[`2/UF/0K54V0<oKV`2bd8H0`n:B0=3TW03BkJH0cN^U0<ONV03Il:X0
Q9mH0=7/Y@2lfY80f_F^0<7LU@3Bij80bMZF09jZJ03RlJ`0eo6W0<OQV01jTD/0R9mK06Yo?02;X5d0
Vk1]0=C[X`3<i9X0eO2Q0<KET02MQVH0oocO0?okk@3ol^/0oo_k0?oemP2SWY/0oooa0>gcf@3=fK<0
f]o108AcK03ooN`0oooJ05UR;@39gYd0a]nK08NUG`2YbH00cNfR0;kOSP38jIP0bn^P0<[ZW`3AlJH0
anNL0<g]X@39jId00P3:jId20<[YV`030<WZV`3EmJX0d>RZ0080o`0000<0mOoT0;oQ[`24K3h00P3o
00001`3@jjH0d>BY0?ooi03oon@0o?oQ0>Gdb`33eZT00`38jYh05@39jIh0b^RN0>?n]`2V`GX0c^bT
0=;`Z03?kjH0`MnO0<oY^P36hI`0b^JB03E?001SNbl0aMNI0=[Z[03Ki:/0oooJ0?ooi@3ooOl0n?kn
0?coo@020?l0000>0>oPh`3om?P0nO3a00D<002T]ID0c^Ri0;OEV@2]_XX0IgDj09BTH`3KjjX0enJ[
0<[D/@3Hh<T20?l0000D0>KNf`3on_@0ookh0?SekP3oooP0oooj0?kmn@3oood0ooko0?GcmP3dl_L0
ooko0>cZk`3imoP0mo[c0?Slj`2^Z8H0JEXa0:ZXJ`2nbhD40?l0002o0=O]XP2ebH40h_:a0=OWZ03>
gZ0000d009R^KP39i9l0a>:J0=?fYP36jIT0b^ZQ0<_YW`3Dk9h0e^fM0;G8N@39eY40g>N[0=GP]P2Q
ZXd0fNCD0?com03oonX0oooX0=3O]P32djH0G6lg0<CFVP3QlK80SYeJ09RWHP3;g9H0b^2G0<K[W@38
jYd0b^VK0<cXV`3?ii/0Igdd0;FnO`0o?PD0NVhl0:J6G`2jWg@0I6@V0;VnOP3?h9X0g_B[0;cFS039
hiT0Vk=Y0;cBR@3Ejj80bn>I0=7`Y03FoJ`0f?N[0<KAS02GWUX0e>>P0=Wd[`3La9@0]j5b0<K`/030
kZd0MZeY0:k`YP34nK40c^RW0<oOX03=i9h0eMbH05aS7@31hhl0aNfG0<CZT`3CjYX0bnJE0<7^V@2n
jIL0c^VL0<OVV03Cm:<0^]^<0=OfZP2ieHX0h_jc0=kj/02M^Fl0cn^P0<KRU`36iIT0co6T0<[/W`2m
gI40c>bP0=3_X`3AkJ80f?:X0<oYX03:i9/0bN>J0<?MT`3Gk:40d>BO0=S][03KlK<0j_o70;gIW03=
jjD0c^ZP0<cWV03FlJ00a]bA0=[X[@2Z]800enJ_0<SLX@3FmK80`NJP0<?/X035jj00cNNP0=7UWP3F
hZ00fMjT09>HGP2?VE`0cMNH0=3QW@3@iYh0bnFK0<STV@38j9d0bN^O0<;WVP3CiJT0g^^e0;oAU`3A
iJX0f?6`0<OPWP3<ij00cNNP0<gWWP3=iid0cnNM0=;YX@39gIH0SiUL03iG8017Jdl0`>:o09n`J@3?
i:<0e_>c0<3YW@3:iiD0e_FW0;GGRP3>kZ80f?N[0=?_Y02hdXP0c>BJ09FYH@3;g9D0cMfF0>3`Z@2g
eh/0gOb^0=cRVP1GF180h>VV0=gYZ@3>fIl0XI][089hA`2i_W`0_M:50<_RT03<iI80b>ZF0<?ZU`30
k9L0aO>K0;OUS@3BmZh0c>R^0?_ok@3nooH00P3nool03`3bm?40n_We0?ooo@3onol0gMKM07UeMP03
0000clnc08nAK035eZ`0/LbQ07FKK015NT80/n^/0:oWW00;0?ooo`002P3oool0G03cn_80en3;0<[B
^P3gonL0o?oa0?7kl03hooX0l?oh0?7oo`3`ool0bn3e014T:`3am_X0kNkb0?omo03oo_P04@0002/H
003Kh:P0amjH0<kaW`3=l:00[;Yo0>3b^03Nn;L0b>fO0<OZVP3<iiX0en^T0<[DV03AfZ<0log80=GR
[03Ghj<0dn:Q08VIF03>i:<0e>fY0=WeZP3:jId0`]fJ0=[b^0002`00cNFe0=Cd/@3;lJ@0eNnV05eE
5`1^KRh0cmZH0>Ob/03Hi:80aNFL0<7KU03JkZL0dNNN0<cSW`1HHbL0YHiT08A/@03Mk:/0a^BJ09Nd
I036ei00bnFN0<cZY02leXl0gON`09^fK`2F/FX0ZLAm0=?]YP37gYP0_m>>0=;SW`2ha880T9mJ0<oY
W`3HlZT0d^RW0<gSY@3Fjk80/<><0<kQZ@3Pkk@0enNX0=3QV`1cOcl0fMJ]0=[F/`3ooNd0ooS`0P3o
o?l0703hko80Pgad0=gGa`3oon80oooZ0?onn`3knNX0Xjj40=SY/`3Gl:`0fO:^0=G/Z02[`7/0C60I
0=gZXP3CiIT0a>VK0<?UV035ii/0c_2T0<OWW03<jZ00e_B/0<g[X@36hYP0`]jD0<GTV03<jZ840?l0
00030<?R^03o0000o`000080o`0001d0c>NT0<cAZ@3Jg[T0o?oO0?Oog@3Vn<h0`>BJ0=7cZ@38j9l0
a^BL0<[UWP3?jJ00MY980>3n]039jIh0eoV]08Z^KP2G]hh0^=RI0<k_X03<jID0bn:N0=CS[01kQTh0
TIIL0>SY_@3Fd[T0n_Cn0?koo`040?l0000<0?oioP3^iNH0o`000?l0003<i[L0bNN[0<cMY`23T5P0
KW`o02Ph002b`HP0W:Mo103o00000`3hl>h0oooj0?oonP020?oonP0?0?oon`3oood0ookl0?ono`3o
oOl0n_Gi0?ono`3mnnl0nOo/0=WRa`3QgkP0iMZ]0=oIW`2LYF80`nZK0080o`0001L0enRR0=K[X03<
gIH0e>BU0=KVZ02a`8D000`006Um@03<iJ<0eO2Y0;SIRP3?kj<0c^RQ0<SRV@39gi@0/<Eh09BVG03M
jJL0eN2V0007001VKe@0o?of0?cok`020<kKYP1:0=7NYP3Ah:L0Vjm`03=72P1JKS40NXaB09BSK02K
Xg00e^>[0<o_X`31hID0d_BW0;GER@37gI@0cmjI0<2oQP1PFB<0Og520:fFK@1hIcT0IgL`0;S8P@3:
fI@0cMjH0:RlM@1]Pc/0e>VT08RNEP2CYf00b=VC0=S^Y@36j9/0d^bR0=kYY@26Sd`0b=bG0=3_Z@2]
UfD0NF<a0<?[Y@33kZL0^NjX09ONVP2el:h0a^:U0=c^/P3HgJ<0e>BU0=?SXP1=FAL0]/5o0=?RW@3A
k:D0b^FP0=?YZ@3=iZD0c>fX0<SVW037iYP0a^FG0<[YV`33hY@0cnjP0;kJS@3AkJ80Y/1g0<SRV@3B
kZ@0c>bQ0=GgZ`30hYH0c_2T0<W[WP2ogi<20<WYW@80b^VM06X0c>NP0<kTX`3Bi[<0looM0?;oh@3M
m/l0bnFh0=Od]03CkjD0dNZG0<OOR@2BY5X0b<nL0<K;XP3aolh0g_Nn0=[o_03Jok/0`>6J0<SVWP3<
g9/0f>BT0>3VZ00h@0D0JWDi0=k][03Ah9l0d>BM0:g3NP35hIH0bnNL0<OWW036j9h0b>VR0?7ob@3`
oLP0Jga50>Kh_P3CjJ/0dNNW0=C]Z@3<hid0goJ`0<gSV`3FjZ80fn^T0=3KU`2<Ue/0J8I:04UgG@0i
HT80`mR90<OKWP38hJL0_nRJ0<?PSP34iiL0bO2Q0<g_XP2mgI40^=B90=3ZX037giD0g?2X0<?DS@27
Ue00UJ9L0<cSW@3>jJ@0c>JO0;G8QP1MFRL0GU8X07EWA02d/8d0alVR0:>/M`1MIbX0f^>R0=ORX02o
dhh0b>>L0=_k/03<lj@0aN^N0<kZ/03goml0n__f0?ogo`3oo_l0o_oo0?ooo@3ooo/0ooom0?ono`3l
moh0100000H0003oonP0Xiin0;gF[P1AMT/0X/fR0;gc_`2hm;P0O[]e2`3oool000X0oooo00P0m_oi
0=?T`P3>gkD0h>k:0>cjh`3eooX0ioS^0>oon080j_oo0700CfV206n8S@3mnol0ooSm0<?0^`26PWL0
ARhF0:29I`3GhJ@0a^JK0=3kZ@3AkjD0UJ=^0=7V[@3?kZ/0c?FV0<K]W03Cjj40`M2;0:nbN@2DUf00
c]>K0<OAU@3Dgi/0B5LD09n_KP36gIT0bnFN0<OVVP2lfhl0d>^X0<WQY`002P00fNo00<g]ZP2oi9L0
an6H0=SGU`2JWed0XJe[0<7=R`3>gIX0cnZS0=W^Z@3IjZ@0dnNO0=;WY034ci<0[II/06M?8`3>gI`0
a^BJ0<[WU`2P/FX0dNRR0<ORW@3@jZ<0a=nH0=C_Z02P^g@0PYaE0<gTWP39h9X0goB_0=;VX@3Ei:40
BU/E0<GOU@36h9T0c^BV0<OLX`3MlKh0d^Bd0<gM[P33d9/0g>N_0>3/[P1=Ea/0g^Fk0=OM]`3oonl0
oood0?ojnP3onod0oocm0:BKU01=A3D0oooV0?K_g03dmO00noo`0<oN/`3<hJT0bNBM0<?NU`3Jkj`0
cMjJ0=WVX@2i`7X0iO:Z0<c^X@3?lJ@0co6U0;cLT@3Gmjh0c>ZR0<CRW033hI/0e>nZ0<gXY@3@kZH0
bnVQ103o00000`3:i[d0o`000?l000020?l000030<3MVP39cZD0eMbb0080o`0001P0d>>f0=;f[033
hiX0a^BL0=Wd[@38hY/0c>>K08ZTF`37hiT0a^JK0;[OTP38kj`094TM0<oe^036jZ00cnjR0<GKV`3B
h:d0e^2/0;2eO`2j^940oooZ0?olo`3hn?X40?l000030<Zn`P3o0000o`000080o`0000L0eNnb0=GV
[`3eolP0e>BV05m_<@003P00J7=800@0o`0000@0ooco0?onn`3oooX0oooj0P3ooo/0M@3oo_`0ooom
0?klo@3oo_l0noKj0?ojm`3oon`0nooX07V7H`3>dJ@0/:Eg0>_RZ@2W[6X0b>fO0<C]WP3=iih0d^JN
0=S/Y03IjZ@0a=BE0=3PXP2IZ6l000/007Z<D033g9X0bNBM0<OWV`3=k:00i?^g0<gTWP3IkJD0IWXb
0=3QVP3=g9/0fnV^082;H@32bj`0iNcJ0=SSa@3Qm;@0dn>R0=CSXP3QlK00dnRW06=i>@3Jl[@0HG@m
04EC802[/HD0OXQF0=Wg[@2de8T0_=jA0=[j[P3Mlj/0fNRU0=[HW`2UWVP0ZYa]09F2F02QUf@0Z/1g
0<kRVP3ChYd0g>^X08ZKE`2hbhT0cN:O0=?XX`3<h9/0enJS0<;CS@38j9`0amnE0<cGT`2OZVH0f^jY
0<WXXP2bW6X0VXAB0<_aZ037lJL0^^jV05>HF@2YhJ@0bnV]0;c>TP3BdY`0b]jO0<[PX02UZFh0BDL>
0;^oQ035gih0dNV[0=KPZ`3;fJ@0a>BU0<[UX039hIL0bn>I0<gXV`3AkJ00an>F0=7]X038i9T0Uk5X
0=kh[`2nfY00anNL0<_]X@2lgY80a^RL0<k`X`3DmZT0b>ZM0<WYW@020<[YW@1N0<cWX03AjJd0cnBi
0?CoiP3don`0f_;B0<_T_02ofIX0a^2F0=3XU03`ok<0^l^40>O]_@3Oi;`0m_oF0>Kob03WolT0ioo6
0<_YX@3=i9h0gn^[0<[DU@2IWf<0^LF70<oMW`38f9L0fn^Z04MM5@0D:`00b^BK0<gYW`3>k:@0cNfT
0<GUW03DiZ`0cMZT0<kOZ03Xo<40cnFW0<SNWP35gY`0`]VE0<SOV@2=Xe/0gO6Z0<[GT@3Oj:D0V:IY
0:c?S@1MSgH05D8S0<SNS02caH/0b=nW0<G/W@36iID0bnjN0;[OT@30hYD0cNfQ0=SdZ@3;ii`0f?:X
0<?IT03<h9P0e^NP0;S8P@3GjZP0e>f[0<CUX03BkJX0e]:S0>KF/P3om]P0oooS0?;le`3Nk;L0alnF
0;^oQ03EfZ00l?k10<GIVP3BjjT0`^6K0<CSW`38g:/0looN0?omo`3on?l0oogo0?ooo`3oood0oook
0?ooo@80ooko00X02P@600/4003oonD0VYAb0>koi@3Loml0`N[80:kS^@2ckKd0W=VN2`3oool000X0
oooo07/0g?c:0<KXW03>l9`0`mnD0<gV[03TomH0i?oJ0=;fbP3Bnmd0[mW;0:cCfP3[ood0nO3[0?ob
l01_J5h0104009J3HP3ah;D0dn>R0<gcZP36l:P0fNbe09bSN@3gom@0fo^h0;SXTP33kiX0f>bU0=OP
X@1@Ba@0i>:Y07Ei?03DhIT0fnVN0:2aJP3Hk:D0c>JO0=3^Y035iIT0`n:F0=Sa[`39g:@000P00=GV
^@3ClZh0a^FI0=K^Y03Ch9/0i?6/0:c0N`1JKbX0SJ9M0=g`[P3;eIH0joBc0=SYXP3>hIl0eMnS081Y
?`1kHcL0d=nN0<KVV`35hY80e>BM09:WHP2^ah<0bN>L0=;YX`30ei40f>nY0>Ck]@3<hid0dNRR0<gR
W@3ZokX0a=VD0<kTW03IkjH0ambI0?SoeP3homd0n?oS0??nh03]m]T0hnK70=CF/@1@CB80VIaa0<WJ
]P3Gi/L0l__X0?com03oooX0ookj0?omnP3onO00oocc08alK@3hk>00n_gf0?col@3@i;<0bN>V0=Kf
Z`3:jYl0c>JO0=__ZP2gaX40UIaH0;W5O@30gi40d_6S0<SVW036i9`0eo:_0=gg]P3@jZd0dNZ`0=_d
^`3Yol/0`MfP0;WIT03Rm/<00P3o00000`3YmN40b^Nk06aF7@020?l000030;oRWP30gJ<0d=N[00@0
o`0000H0lOo:0<?QV`3;iZ40bn2K0<gRW@2odh`20?l000090<GUV@35jY`0`njV07n^M`2fiJh0a?2e
0<WX[`3Xol`0n_oL0080o`0000D0mo;N0>[TeP3ono`0o?Kh0?cfmP080?l000080=[X[@39fIX0ho>b
0<KIU`3:gih0bmfO08jOJ`2T/HD20?l000030?oho`3oo?l0ooko0080oooo103oood0L`3nn_L0nOGb
0?cgm03ckn@0o?oI09NYN@33fZ@0fnJ^0;6/M@3OeIX0Vi]K0<SWV`36jid0b^JK0=?[X@1]PCT0dnBP
0=CRY03SlKH0Pi1H008A000fB0h0bn6P0<OPW03ClJL0cNVO0<WIV03]oK`0V:]Y0<WLVP3FjJT09cT0
02/o103Un<40go6m0=GW]`30eId0d^nM0<7JR@2K[F40bM^?0=7YW`39i9d0d_6]0=Wb^02ibiL0?T<J
03@j303FkJT0`=jH0=7g[02mhYD0a=^C0=WUX`1dLSL0YIiW0:RQK@1PFRP0LgPn0;cKS`3Aj:00TYaM
06E]<@2@VUh0FfX_05=Y:@1GL2h011T006Ea<`2gaXD0eNnU0=KZX`3GhZ00T9]I0<WPW035jJ40TWi9
0;JQJP2nh9<0anbN0<7/Y00^I3801C@00;[EWP34fIh0/kQn0<gVY@3:hj80j^Va0:FKIP2ESe/0bMbU
0=KW/`3oomT0oooO0<?M[P34cIH0LgLj09ZSHP3=gIH0dnBM0=oeZP3HljH0`=Z@0<;LT`0gD@P0cnVR
0<GPV@34hYX0anNN0<k^X`3<lJ@0`>FH0<K[W@38jYd00P39jY/0FP3:j9h0cnVZ0<cS^@3Womd0j?oS
0>3hf03;i;X0e>fY0<kVV03Ej9T0[;ac0=_V[P3@ejd0hn_40>godP3>jk40`=nL0<kYY03Hij80e]nL
08bBDP1YLS<0QY9D0<gRW@2jdHT0g?>]0<SNW@0eB`d001<00=[b]02meYD0d>VU0<cVW`3>j9l0amVK
0=[//01dR4/0d^RX0>;k^P3Vokd0c^NU0<cSW`3Ek:P0XKE`0:JgL`1gPSd0J74^0<[PXP38n:h0]oGL
00Hk7@3EkIL0PY=M0<cP[@36kIX0cnnL0<STU`3ClZH0`N2D0=ck[`2jeX/0d^jS0<gYWP3?jIl0bnFK
0<SRV03BjZ00R9IH0:2bM03Gn[H0`^:Q0?oof03gkl/0ooWL0>omfP3Gl<H0a]nU0<OEU`1oQDT0CE8H
08jGH02HXVd0WJYd0=7RZ`3Ci:h0lokF0?koj03ooOh0ooco0?omo`80ooko0P3noo/0303nool0oooo
0;fi]P070`00h]fo09^HK`3SoMH0fOgI0<GZb@2ki/X09U@g04b4G@/0oooo000:0?ooo`1f0<_aY033
jXl0b>f=0<SYSP3;jYX0`MnO0<;TZ039k[P0^>C00:SE_P3Mood0l?od0?ool@3hjn<091L>02lV5@3n
mLh0oooA0=KYZ@31gil0a>JY0=?T]`30`Il0f>Jc0<OTXP34lI`0aO6L0;oCS03Oj:T0fMJO0=KGV`3I
hYl0]/]l0<gPT@32eXh0eN^S0<[UWP38iY`0d?2T0<CSU`3=hj80b=VR00@<003?g;00c^VV0<oYW`3A
jIl0g?2X0=O[Y03CkJH0]m:;08bSG`1=G1/0e=RM0>3TY`3Hj:40fNVX0=KPY02lYG/0FT8F0=k][02c
dhP0c^^K0<WFT02_`gh0T:MS0=W`ZP3<hI`0f^nZ0<gRW@36fiH0Cf@O0=K[YP3<hid0cnJP0<WPVP3G
kZH0f>bU0<CGU`3Fi[L0i_G>0?Koi@3lonl0o?o]0?ckiP3oonH0XIQi0?olgP3kond0noo_0?_ol@3l
o_<0lNkW0?onn03bjnD0oocf0?oil@2BQ7/0QWUa0?_hl@3oonl0d>:`0<_UYP38jYd0_MnB0<k/XP3;
iIh0d>FP0>?`Z`2BXU/0bNJF0<KRU@33giD0dnjW0<WRX@30f9X0L8M?000=0080o`0000d0d>bb0<[Z
X@3Hk;T0j^cQ0?Sgl`3ionl0a>2`09R2B03?]gT0`nNQ0<OY[@3Kml@0bmBY00@0o`0000D0hOjk0<3K
UP3BjjL0e>NU0=OXY0040?l000070<?XVP31kJ80`OFe04j0B`33lL00]]NX0>OodP040?l000050?on
mP29P7/0ZZ2Q0=gCe039`Kl01P3o00003P3IfK<0^l260>?b[`3<h9T0d>JN0<oVXP3Cj:L0dN:[0<cI
Z`3mon/0lO?X0?olo`3dk_X0ooko0P3nool0dP3oool0ooko0?ono@3imO80oooj0?onnP3oo_P0l>gL
07J0B`3Wol<0_mbL0=CTY@2_[g<0j^2S0:>RHP3Ajj40bN^N0<STV@3>iY`0L84j0<GDT@3DhZD0c=ZO
09n/M01WMSl06R`00<_QX@3?j:@0cnfS0=7[XP30chh0RYQJ0<GEU`3Vn;`0e>J/07>7C03:gj@0g?:d
0<GNW@3@jJL0cNRS0=?dX`3?jY/0Sj9C09RZGP3EkJ40e?BX0;kPUP3:jJH0e>V^09FLJ@16CAX0KH52
0<[UXP36k:<0cO>X0=;/Y@2AX5d0b<J;0>SSZ`3Jej00k_6j08RFF@39jId0a]fE09^SI`1VJC00GfL^
06Uf?P3BjZh0cNFW00@H002JYFT0RYUH0=?[X@3:gYL0XJaZ0;O1PP3;i:80aNZT06=?6P2ORU<0co:R
0=3cX@2jhYT0ZMNY055hB@3Hlkh0g?Bj0<SIU@2;YEh0c>>M0<O=S`2g]Wd0=SL00<SEX03Fh[80g^Jo
0?[oh03eomd0oooF07ii@P24PTT0I6d/06Yg<@35eXl0`MV=0<kXWP2gdHP0e_2W05Ma:P31fYH0c^VR
0<_YX@33hiX0e?V/0<S]X036jid0b>^K0<WZV`3:jIT0c>RM0<OUW@39i:l0e>o40=?]bP3So]D0b^Fb
0<cVW03RnjX0Sj5G08RGEP3:djH0o_oO0?CofP3<i;80c>^`0<k[Z03@ij40X:YU075d<@2@UED0c=NE
0=CSXP3Ajj40e?>U0;oJT`3CkJ`05B`0000=003>hj/0aMZQ0=G/Z02neHd0e>ZQ0<oTX@38gI`0bMnN
0<GKVP3RnkT0jOno0;gHT`3;i:00fO2/0<_PW@3BiJ<0VJIP0;o:QP3@jZ/0b_nb0:KZd@1CSW00eo6J
07f>F03?hk80`^RC0=7^W03FlJ@0`M^A0<gWW@33gI<0_m^@0=GaYP3@k:40bNFJ0<cXW@3Al:@0b^VM
0=GYY02``h40[/b60=C_[03Qk[T0koS;0?GmeP3Qm//0e>jn0<_XYP3DjZ80eN:L0=3KV@2LYf/0SiYR
03i84`3?g:H0e>6[0>cgc03lon@0o_of0?koo`<0ooko0P3noo/0303lool0o_oo06m`J0010P00a/JR
09bKK@3`ol/0anbY0<kb]@0J@Ph0[m^X08JkP`/0oooo000:0?ooo`1O0<?]U`36jZ80anRS0<[XX03:
iiL0bNNQ0<KT[P31g/00f?[k08R_]03Xool0h^cC0>gcf@2g^J@0;QP=06I??`3Dfjl0bMbT0=O[[P3e
old0nOoL0?7og`3oo>D0e=>W0>[j_02ojID0`^ZD0=KZY@3>f9/0h>>Z0>[f]02le8P0b^jD0;7:M`3R
n:d0d>ZP0<[XX03Hn:d0`>6B0=SgZ@3<hJ00kOc50045001CG340bMnN0=7WW03;hIH0e_FY0<[VW02n
gYD0c_2V0=G^ZP3Egj80Ee0I07Qc>@3Jij40`]:A0=cVZP2PREl0OfLk09NWIP3>kZ<0bNJF0=SUW`3<
gIT0c^>P09JZI@2odhh0bmnJ0=GYY03MlJ`0aMZE06^0>`3DkZL0c>NP0;_IT@3<j9h0Z[]e0=_[[@3A
gKD0hnk@0?[ol03nooX0oooj0?ommP2^XIP0oo_/0?ofj03oo?d0oo_i0?_cl@3Tf]P0]jf[0<Nn^@3o
oOP00`3oo?/04`3aiND0d;nh0?ook03Gi:l0bn6P0=?iYP37lId0b?>T0;SQT`39kJ<0_mfC0=ok/025
W4`0NI120=3VW@3;hY`0^m6C0<?HW`003000103o00003@3:kZ@0amn[0=_Od@3oooX0noo/0<gX]@2X
SeH0i<b@0<GTZ@3MoLh0h_cE0>Scb@3_oL`00P3o00001P38jIP0d>^X0=7ZZ02L/G00QYED0::^K0@0
o`0000L0`>>C0?l0003o0000MZim07BVP@32iLL0d>c600@0o`0000D0oo[l0?onl@3on_X0kn3S0?ol
n`040?l000030?ool@3on^@0CD0N0080o`0000@0enjP0=C/X037hIX0d^^W0P3o0000103doN00o_od
0?olo`3imol20?kno`1h0?koo`3oool0ooko0?chm`3oo_/0i^7K0;Ve[03PfLl0aL>Z0>3aZ`39iid0
b>ZN0<KLU02^/6l0hMJH09VADP3Aiih0anJJ0=7]XP3@j9h0DV<M0<kMVP3NjJd0cMRN09^UL01`OdP0
EFL]0<GKV`3=iZ@0cnfS0<oYX02d_Wl0hnna069a>P1=GRP0D68^0=O_]@2gdI80fON]0<GTU03Am9P0
a>R>0=7g[02mfi40enRQ0<gOU@3Cl:00bNnL0;SRSP38kih0/<b10<kGU02na8H0MHM=05Uc=036kZL0
^N>I0<oZY@3ChYl0Rh]?06UY;@1:Ba40TZ1S0;gCTP3AljL0_MB>0:^^M@0h=`40h^Jd0=CQ[03LmK`0
b>BY06Al@03;eY`0UJ=U0<WOUP2a`W`0_/R90=CNX@3;i:80`>RQ0:>@F02nZVl0_]n>0<KXU03=kZL0
b>K206f7H00W?`d0c^N]0<CbVP24Vd/0ioV]0;_CR@3GkZH0MhM60=[JZ03GgJd0a>6c0>koh`3CfKL0
kMfi0:NAJ03fiKL0fMNN08fBDP2?VUD0dnNO0<cTVP3@jZ40`M^B0<cVW`23VUH0V[=_0<_VX@39iil0
c>jR0<CYW036jid0b>^K0P3:jIT0GP3<jID0bnbA0<CTV03?kZ/0`^6X0=3^/P39j:@0bNFA0=ohY02R
/G00gnVg0?;hg03co]`0mooQ0<o[^03Al;D0bnBP0=CSWP1/JBH0VIAB0>GWYP3JiJ40`]NB0<k`W02j
gHT0d?6Z0<3NX01QNDT000d00<WL[P3Ahk40Y[Ui096RG02CYE/0X;I^0=_bZP2nf8l0foJ_0<OUW@3;
jJ40eo:[0<CMV@2V_g/0lOo30<cOW`3NkZL0aMB?0<GXYP2clil0AI5g05^LOP3>jhl0S9eY0=7R]@34
ii<0bnRF0;?8O@2O/6T0bmnG0;W?QP3Pn[00`mnD0=7`Y02ohI@0_^>E0<W^X037kYl0c>RK0<GKT03K
iil0Mh@o0=Og]P2ggj00^N:X0=oj``3Jkk@0a>2C0;SPQ`3<jhh0amn90=OYW`3Ij:D0gNV[0=oY[@3G
hZH0bMJP0>Kfa@3Yn]P0kOoV0?ooo@3ooOl0ooko0?oon`3noo/20?_on`0:06ecI@0f>bD0b<^N06]`
>P3Llj<0`Mb;0=7[XP3=j;40IhEC0;?KY`/0oooo000:0?ooo`1e0<7]V033iZ80b^RZ0<WRX@3:iY/0
`nNM0<[_^`3Nonl0DGEe04ibL032gLX0fN310>G_c@1fOEh0;b0;069B>03Jj;D0dn^_0=KZZ`3nom<0
k_[:0?Woh`3oo^H0/[290>Ca^`3?lJ@0aNRH0<?IT@3Tlk00cm^K0=;VW`38i9L0_^:;0=;]WP3@iil0
`=ZC0;oNV02kfi80d_>T0;oNT03Fk:/0]LJ?00H<003Cg[<0Bf@R0>;_Z@3Ch9X0aN>I0<cZX03:kZ@0
b>jS0<k/YP3GhJ80hnBZ05]M7P1GH1d0f^>T0>SY/02bVG00HTTP092LG02:YU`0a^>C0=GWW@3IkJP0
cnBO05EZ9@20TDd0e>>P0=7RWP3Bij80d^bU08VSG03<hYX0e^fU0=Og[036iYX0U:QQ0<[IWP3Bgk40
jOS?0?Woi03joo80n?k`0?kmj`2]YI00ooCR0?okk`3oo?d0o_Cc0=[@c`3Cb<H0nno_0=kBe03oo?d0
ooco0?_em@3mnOH0oocj08]gL03oo>/0fn:f0=3OYP32h9X0bNVP0<OXX@3:jjH0bnbW0=on^02kfI40
d>6K0<cMV@2:W5h0c=jR0<_NY`3@h[0000`000@0o`0001H0_=RK0=W/_`3dn>X0moS`0>odgP3Fi[l0
W8AF0=o7U`3EjKP0m?oS0>oohP3kon<0o?oQ0=?V[P3=hj80b^VI0=?[[@2DZ6T0c=bN0=OQXP3LiZL0
bmnJ0P3o00000`3BlZH0o`000?l000020?l0000400a06P2hh<P0an^o0>gog080o`0000L0oogo0?_f
nP3ckn<0oo_k0?oln`3jmO8020X50080o`0000<0oOgk0>k[g03oonH0103o00000`2?Yed0`]bC0?l0
00030?l000030?Cjk03ooOl0o?[o00D0ooko07D0oogl0?omnP2n^k@0/[2T0?ool@3RiLH0c^:J0<GT
V033iIP0fnnX0<G4Q03VhZ<0VYaK0=WZX`3:i9X0d>nS0<STV@1;G1H0dN2M0=gYZ`3CgZ@0V:=[000:
001XMch0dnFY0<cPX@3AijH0c^>P0;k=S03BhZ4000`00<oUY`3Cjjl0dNj^0<CQW`32hYH0anVE0<g`
TP39kI<0_>2H0<cZY03=hI`0fNZT0<gUV`3@kj40a^VI0<[ZWP3IljX0g^VU07R2@`1[OTH0FW@g0<c_
Z`3=lJ/0e>NU0=?LV`3VhJL0dLbB0>7PY`3?fYh0bn6P0<OYW@3:hI/0WJ9X05=C7@3GfjP0gNNb0<oW
Z`3@jZ/0cnNY0=3OY03BhZ@0d^RP05EY8P3Dh9h0fnNU0<gVXP35jZ@0UH1;0:ZCG@3:kId0b>^I0<;V
WP1ROUD05C0502i6501`S580_o:F0<kSU03JiYh0e>^U0<o]Y@26We/0XjI]0<cAV`3=i;00l_oM0=WM
^03SdJ/0WXUN0>?EYP3Heih0Zk5a09>NFP3Gij00en^S0<_UV`3=jj40c>jR0=C`YP2@ZV<0aN2I0=3^
Z03?kjH0b^ZQ0<WYW@39jY/00P3<jIT0JP3<jIL0dOBF0<7SS`3Gmj`0anJS0<CQW`3=j:40d>NI069g
:P3Cg:D0hNJm0?oojP3honH0m?oS0<3MY`3>jZl0dNFP0=GPW02JUUH0g]ZJ0=?JU`3IjZH0an6J0<SZ
UP3<kYX0^mZF0=We^P1OMDL000/00=OX^`3;g:P0_<b=0=KWX`3Giih0d>RN0<[TVP3Dl:D0a>>G0<[X
WP3<jZ00a=nJ0<gVY032eYL0mOo90=GTZ`3AhIP0cnBI0;oTX@2_k9h001T007ReT`36iY40TJA]0=3R
[P3=j9L0c^>F08fQF@3=hiX0eN^R0>3f[@3>i9/0d>JM0<[RV03?kZ80c^jR0<CYV`34ji`0`nBC0=?[
W@3Lj:00d]nI09blN@2hhIl0_NFW0?Cod`3Lk[@0eo6W0<oeX038jX`0cnbB0=;XW`3GijH0bmVK0=CP
X03BhIh0cMfL0>7e^P35fk@0eo3B0?koo@3oo_l0oooo0?coo`3lood0o?oo0?cnn`000P000@<0051C
902SZg00b=n?0=WdX`3:hIT0f?6g0;oJX`3?l[`;0?ooo`002P3oool02P2okYh0b^VM0<oWW@3@iJ00
b^VK0;C_U@2cm;@0eOoo07RZQ031jZh20?l0001W0009000V<P80c=^T0=W[/@3;gYh0bmjL0=WZYP2n
cHP0j_Nb055J8@2//Y00o?oV0>Gab`3<hJH0d>VU0=;aX@3Dm:40cNZJ0<[UV03<i9X0c>>O0;kGUP3C
k;80bnBZ0<OUZ@3;jJT0dO6V0<[ZWP3<ij80cNFW000<003=i;00`n:O0=3<S`3Ug:40cNBN08FSF`2m
ii/0b?BW0;gOU@3?fYP0`]fF0<[UWP3/j:/0Zi]X05e56@2/RfP0M5Pa0>7PY`3:ei80UkIV0<GTUP38
gYH0e>^U0<;LU@2>UeP0hN6U0=SRX`3:j:80a>fQ0=3bZ02DWUT0fnFP0:O<O03AnjL0e>jU09R]M@3A
iZ<0e>fL0<_WT03Bl;@0f?C30=3U[039eID0oocM0?oojP3fonL0loSR0;6`WP2SW980oo[o0?oio`3f
j?L0o_Ko0?ono`3go^h0moSV08ajKP0l;R404Pd00<K4[@0@3`004Pl006m]A`2?TFT02Q<00=cc_`39
gJ`000H003Y07P0?500010/0000600050?l0000J0=_W^@083000o_o]0:V`WP000`00ooS^00/00020
K6<0VHIh01D:001IDcT0D4/h00H00P27Q7d03Q<003I15`2<WV0000h005iU>@3Xjkh010L00>7//039
j:80`nbP0<7]WP35jih40?l0000B0;[_]`1l/YX0]NjY0<[/[`37fkH0o_ko0?koo`3dnOD0nOom0?oo
o@3ooo/0o_ok08J<R03nool0oO_o0?kjn`3joNX0XZb9103o00000`3DjjD0dN^Q0?l000030?l0000]
0?_omP3lool0o_go0?kfm03ono80oogc0?olm03oo?X0n^oe0>[Tj03ko?L0oOoc0?Woi03Sm<L0bnFK
0<WWW@3>k:80c]VG0<6bN`3Aj:@0/m:<0=WRX@3?h9X0`NRI0<[aXP1NLRX0d>6K0=7PW@3LjjX0Oh]=
00090024SEH0fn:_0=CJZP0`<`P0e^2^05af=@2lei00`>:>0<7USP3:kYL0a^^K0<K[W@38jYh0bNVM
0080c>VI0580`=jH0<WRX034f9/0nooA0<cFXP3@f:D0h>Re0?Ooc03Sl;P0f>N/0<;DVP088@00]<fC
0=?WZP3Bh:<0HElT0>[MYP1XEal0K5dV05YA603RiZ/0a=2@0>Ko]P32fI<0enJ[0;C1R@2R[700g>NU
0=OYW`3>hiP0f>jV0<[TX`3Bk:/0b^6M0=[`Z035fXd0`mZ<0=?^Y`36jJD0TG==0<n_R038jjL0^^:I
0<og[P2ieiT0Tjig04iU=`2R^XX0c_:J0=7NV@1HFb80e=b[0<SPYP30gYh0RIiC05AH3P3Ygj80k>N_
0>?Z]P2DSeP0Xj9Y0=[SY03Di:<0SIiJ04A@3P3[lZl0en6L0<_WW03>n:H0^>fE0<S`V03DmJH0c^bT
0<CNW@1`Q4L0N8a=0=CXX@3@iIX0cN>H0=3VW@3FkJD0c^JH0P3>iiH0H@3?iYP0d>BL0=;SW`37eIP0
gNNb0>O]`@3oomd0k_SC0>oohP3/oml0a]^S0>3`/P3RijD0cLn@0=?FW@3Lhjd0amZR0<kXZ`3=kJ`0
d^VU0=GZZ@3Fi[T0aM>_05ERAP0<5`00Y;660;c8V03@gJD0e^>[0=;OY`35giP0an>H0<WXW03AkJ80
bnNM0=;]YP3AiJP0nOoA0:JbP03jo]T0f]^i0=_`X`3DlYX0_^6M0<O^]`005000aO?20=So`P2mgI`0
Q9]E0=SNV01MG1T0`]jC0<?ZV`3<j9h0cnFM0<?>RP2`^GH0FV<P0=OWX03:gYH0c>^M0<W/W037jID0
aNFB0>So]P37gYH0dnFW051R9P2;VV40ioG00=c]]`3;g:H0e^Na0=kiZP3>jiT0amnQ0<gPZ@3Ai:`0
TJEN0=?YU`34g8P0e>bP0<GN]03Rn^80mOkm0?coo`3fo_l0n?oo0?Ooo`3nnol0oo_o00X0001fKU/0
CE4N0=[UX`3=iid00P3:jId30<WYW@/0oooo000:0?ooo`090<7^W@3:jI/0cnNM0=3UX03:j9h0]>jG
0;Gf]P2akn@0S<6E00@0o`0006D0=ST>0=7KYP3RkkL0hNna0<cKVP3Fhih0bMJA0>G`[01NIbh0b<j/
0?Ooh@3SklT0cnB/0<kWYP3:iY`0`MfB0=3ZX03Il:P0f^nZ0=?XY`3Ikk40eNjd0>Koa@3bom40j_o6
0=Og[03>kZ80b^FP0<[RY0002`00cN>b0<k^Z`3MfI`0i]fR0=?ZY02heXh0b?6U0;kXW03AkjL0emfM
0=?ZY03;iIh0UiMK075U<`1B?A80/I=_06E<903DdiX0f^JT0:_:O02cch@0d>BO0<GJU@3_ol40SYUG
0>7VYP3RkZ`0`n6I0<K/X@3;jj80XjaY0<O@S@36j9/0cOBQ0<SSUP2:Wf@0_m><0<[QS`3VojL0b>FU
0<GRZP38g9l0en>Q0=gE/@3oon@0g^o50=?O^@2AU7D0[J^D0?oel@3cin/0oo[o0?olo`3oo_l0o_od
0?ool`3onO80HEA<00D200030P00108000H2001hMEH0_l2N01`T002gcIl0h_C:0005001HGT@0HVQ>
00@:00060?l0000K0<gI/`000`00hnSB08^COP000`00n_CV03<U601WE4H0[ij<00X0002TWX@0lNoJ
00/71P0d<BX000D00007002^_h/000L004aA<@38bJL01`X009jXM039j:D0aN^R0<;/X036jid0b^VK
0080o`0001@0annX0;k[/P0SDS00FXY<0;gJU`3MkKh0nOCh0<71^@1fN6/0Q8V509fLVP3_k^X0HF=N
0?_oo@3Qh^@0ooko0?olo@3Wj]L0Uj5n0>Okb080o`0000@0fo2[0<ONUP2idHL0cNBL0P3o0000i@3i
onT0o_od0?omo`3nnOl0oogk0=O=a03ooO@0o?7[0?olnP3>`lT0l>[^0?oonP3noo<0k_WG0>3b`P3;
ii`0bNVN0<_[X03=fIL0_k9k0=3YY@3<jjD0hnb[0<[KU@2mi9D0b^nQ0;gAR@2_`g`0fNZV0=[ZZ@2B
X6800`h008>>EP3Pj;D0i>bk020V001VKd00`=RN0<gUY`3AkjD0bNVM0<W/W036jid0a^^N0<SZWP39
jId0b^VI0<[ZU`39j9`0foF^0<cOZ03komX0_<BO0=KL^P3Bf;@0m?g>0>Kc_@35eIH0W:m_05I_=@3G
l;H0b=bO0<kLW`1NGR80GU<K0=G6S`3Qe9d0h]^T0=kVZ`3Nk:h0]LZ70>3d]@3Tl[d0i?6l09>NIP2l
b8X0fnbV0<7GS`3>iJ40NYAE0<7KWP39hZ00bN2J0=gbY`3HkZ<0cnZS0<CTX@2CMDl0/91Z0=_k^P2k
h9X0_N6I0=3RY02>W6L0[[V?01LO0034iH`0dn>L0=gWZP3Mj[@0b=fR0=Sb/@35fXl0gNFJ051?3`1`
LCL0nOo=08J5C@3;dI<0en>S0=?XX`3Bhil0OXe:0>;YYP3BfiP0bnFK0;oQU035lYl0b_2K0<3OT`3@
jjH0dnb[0;S<S`2jc8h0SYmH09RZH02M/VL0UJ]R08JGD02KXU`0WZ5J09bRFP2KXU`0UJEN09BUG`37
h9h0fO>f0<;OY`3>k;P0b>Rf0;CBX03PoLL0cn>T0>3_[03NiJ80DEDH0=7CXP3Tj[h0b=N/0>Kic03a
omX0jocB0?Woh@3Vl=P0nood000400000`00d=S00:ffU`26T6/0fnG00>_ed03LlKH0cnRV0<kYYP3:
hj40c>FT0<WQX`2dai00SYa[0<C?Y03YkL`0ko3A0<gPWP2keXT0`^FS0;gUZ@1KRUH0HY9N0;7JX03;
kk40g_^i0<3=Q`3Qj:80bnNJ0<W^WP3<j9d0d>RN0=7QVP38eHl0amB>07b=AP2oeH`0_MV>0<[[W03;
kIT0d?2M0<cVW03Aj:00go:b0<KHW036eI`0^<VB065b>`2/_hL0f^fe0<SSTP2kf8@0dNZX0<gQYP3F
jZl0AUL@092SD@3Bj9D0dNNL0<KK/03/onL0nooo0?koo`3kool0nOom0?_oo@3oood0k>CR00d3000j
=1h0WZEa0=?OW@3:jId01@38jYd;0?ooo`002P3oool02@32kYT0b^VK0<oWW@3?iZ80bNRR0;ScX@2b
l[D0KJ^L0:OM[0040?l0001U020M003BeZ<0hNRb049<3`1^NSP0QY=>0>[e/@35d8`0dmbS0=GL^P3b
oMd0j_WB0=OY]@3Bij`0eNj/0<[SW`3:hId0bMjM0<oQX`3Bi:P0e^b^0<WQY@3dom<0ioo60<g/Z@3E
mJX0cNfQ0<[UX03;hjD000`00<gS/P2mgIX0eM>F0>WPY@3?i9l0a=nH0<cbY`2jhiL0f_B]0=cNW`3N
lZd0TZUS08nCEP3Wh:`0d;fB0;>FM020JT<0g]nV0>Cc/035i9P0Gg/`0=3SX@3Qm[<0/]650=3OVP2W
/6d0gNbY0<7OU`35jIl0cN^S0<oHU`2OZ6L0f?J/0<7VV030fh`0goFe0=GYX@3Ikid0`mf40<WVY038
i:X0d^JW0>?`Z`2TW7D0mO7<0<OLY03Bhjd0QHaP0;bnV@2;PgH0YI^I0?ofnP3iloL0o_[k0?komP3o
oo@0ooKe0?olnP0300001`D001@A0P0D3@001`400;2_T`3Cf;P0EfU30<_L^P0:4@004aP40=OOb002
2P001P3o0000B@3Sk/h000<00;2eX@3Vk]T04QL10=_F`P1FBcT0MFA@0:BDO@0h<AD0?c`M07UiH@01
0000C4a2014I0P001`00`m:Y000:001WJe@0g^760045001WLd<0bNNW0<G[XP32k:00a^^K0<[YV@3C
iYL0eNZK0<WXY02ohZP001<001Ln1@3CkJ<0e>6Y03@^<00k>2T0SXei04Q9A01MFEP0KFaX09VKUP3[
l>`0o_oo0?ono`3elO80]KRW0?coi02mcil0b^NT0<kTX`2hcXH0i?Za08jVFP2I/FL0enV[0<gKZ03m
onP0n?S/0?S^mP3onol0N6i]0=K;a@3_iM`0ooSb0?olnP33^[l0mNoc0?gnn03moo00f>K20=W[^@3:
jId00P35ii/0d`3Ah9d0c<690<cUX@3EmZl0gNJU0=CUW`31iYP0a>VK0>Gi/@2=XEX0e^NS0<KGT`2G
YVD0dMnR065/<P3Ihjh0;SH308B<F`3Jhk@0f^^n0=KZ]`3;iJH0_mbI0;WHTP38jZ00a^^N0<SZW@39
jY/0bN^G0<[ZU@3=jYH0b>:H0=c^_02lbj@0mOgV0?kok@3fn^<0nOoH0?7mb`2T/g00S:1K06An@@2k
eIP0g_:c0=c/[@1=CA40mo6g0>?FW`3@ai00De0I0<kIW`3GjJd0enV[0=CV[02lb9P0eN6a08^HHP1m
Re00dNFP0<oTW`3LmK<0<ThC09VeNP30fIP0g?Fa0<kTV`2oeH`0cNRS0<_[ZP1S@Ql0R6I1096_K`3<
l:X0co2Y0=WWZ@2AWVH0io;:01LO003HlY/0en^S0=c/Z`1LJc80c>2S0<SMW03Jkj@0d^2E0=_TX@2H
XVD0N85:04]A5@3Wlk40d>BO0<[QV`3Hk:L0RiYG0<kETP3Hgi`0go>/0=?aY`2oiYL0anRG0<gYW`3=
iZ@0b=jP0=oa]@3CiJL0b]^D0:VkL@2@YEX0YK]`0=k^Y`3JgIP0fmbH0=[MV03GgYP0dN6J0<gSVP34
hid0_mnL0<;ZZ`2ji:D0aNfa0=Kc^@3:h:80`]J?0<gMU01mQT<0G68V0=cN]P3_lm80j_?H0?_ok03h
on/0noo_0?_olP3loo/0o_oo024R90021`<0o?oc0?WojP3ionL0lOWQ0=7I`@3Okl00b]fV0=CY/@3?
i:`0e>Rc0<OKYP2JZW/0_LRN0<;:Y@3Fe[X0o_cS0=_Y]P36gZ00f?Ri0;?KW@2mkK<002X00;o/]@34
jk80_MnS0<[OVP38f8l0c>RK0<_/W@38i9L0c^JJ0=CXX03AhY/0hO:[0=;VWP2EZf80d^bR0<cXV`3D
lj<0`Mj>0=;ZX039giL0cN2P0=_][`3Ij:d0nOo?0>goa02V_7h0XKMi0=;_V`3;jI<0c>>O0<SLW@3D
iZP0DF8K069e903KkY`0dNFM0<cM/`3_onD0oOoj0?[jn03io_P0n?oc0?[ol`3no_80gMW>01D>0006
0P00]l290<oOWP38jYd01@35k9d;0?ooo`002P3oool02P35kY80b^VI0<cXV`3:j:80aNV[0;K_Z02l
nKd0@gmU0;S`/`2ijY/20?l0001W01X9002WVWL0f]JW0=;BW03>eiP0h^fY0=[WXP3LjJ<0f>RQ0=GS
YP3Ji[h0nOoT0?Soh`3Ei[X0amZ/0<kP[P3Lk;/0e^Bc0;[6UP3:eZH0g>Rf0?;ob03DjZ`0l?o<0;oI
VP3:ijD0b^ZO0<OVVP3?jZD0d^Z/000>003;hk40dOB`0861@`2n^7`0j?fh0=?]YP35iid0d_BZ0=?T
X03^j:`0?TL608VJEP3LjZd0g=nZ0>_S]@2[Ug@0EDDQ0=SMY`3@h:40bnVO0;gIS`2__h00f>^Y0<OV
V03:h9D0[kmh08bPF038i9X0bNNO0<SRV`3LiZT0b=:F0=cb]03>jJH0fO6U0=;WY03<gIH0M8Hj0=G[
V@38hIl0c>BX0=3RY03Afi`0J64c0=kM[@3ClZH0a=jD0=KVY@2FY6T0oooQ0?oojP3ooo<0hMcI0?;_
jP3no_80ooof0?O`m`3ooOl00000004000070000?c@^0554>`0A2@00FeQ70006003Hi<h000D003@m
;02KZ8`031X00=3Q]`040?l000130008001TLUT00@4000/=003<e;`03Q@00=_J^`1?BBL050L005E;
:02ATF/0D5D]02L_2P07300000@00=KObP001P00g>S@02/a9@0^<R40gn;=00/B001QKT80b^NW0<SY
Y036jih0bNZI0<cYU`3CiYD0cm^90>7_/@2R]Gd0an:[05=^>`2N/fH0NHE302/W7P0_:@l0T8]^08R0
O@20N7H0];>^0:f^Z036blD0o_oo0?omo`3KeML0o_oa0?coj03@hKD0aN:R0=7/Y`3Bk:80an:E0<WT
U@2[`gL0cMfN0?Goc03oonH0ooo_0?k_lP2^Wj80oo_j0>[Qg03ZhMX0`kZe0<Jl^`020?omo`0R0?[m
lP3lond0bMZ^0=CY/@38jYd0anbO0<CYW03=hI`0a;^20<_VX@3:jj@0WjQW0=?RW@3>l:<0bN^N0=3T
W01lT4P0g?2Y0=GYY03=h9h0VZY[08FEE`1BHBP0KW]30<_HXP3IiKL0n?o[0?_ok03gon<0f>k00<3K
Z038j:L0b>VR0<K[V`80b>^I0580bN^E0=OeV`34gi009CL70=[Xa`3ioo<0mo[c0?[mlP3JhL00g>Ff
08^JE@2U]W00HGXi0<cUY03=i:00f>^Y0=CHV`3PgZ<0X9eV0>?S[@3Af:80dNJ]0<CIX01iPdl0f^>d
0<gH[@3<ej`0RIMR0;W;S`3HlJd0cnZU0<cYY`2K^Gd0O9UO04eY;01SNcd0SZ=N0;W>R@2I/W00JXQ:
07aH=P2AJTT0V[9f0<?PWP3ClJT0`=R<0<WTX@38kKX0R[>709j/G@2he8L0c^jS0=G^ZP29V5D0c]VE
0<[LTP34gi80dO6V0=?^Z@3EhjH0cN:M0<[VV`33hYH0e?2V0<cSV`3JkZL0PHY90;FkN`3Nj:T0b]VH
0=O^Z03AkJ<0_]bF0=C^[@3Yo/<0eNV^0=W][P3?hi/0dNRJ0=7YV`3?ii/0b>:I0P3>jZ020<kZW`80
c>^M0380anNL0<SXW`34hil0bNRT0<OPWP3MjZD0g>JO08JCA01`ORl0W:]X0<oLY03jon@0oooc0?om
o`3omOd0oo[o0?omo`3mn?`0ooco0?C_mP1`Kfd000800=WMaP3EfKh0e=[00?kok@3amN@0TYN00;2f
VP3nonP0o?oX0?Ooh`3bnn00o_o/0>OZe@3Ff<<0lo3Q0?;/h03cn^X0i_CJ0<3MY`3>lk00/>:K0<Wm
^`1WV6T0/n:f0<Sca@2ih9l0cO:U0<WXV080bnRH0P39j9P0:038iiL0eO6T0<;NT@3JmJP0NHm609^a
J02CZel0Z<1b0<OMU03?hi`0`MF@0=S[Z@3=h9h0d^VU0=G_Z031giD0anJJ09biI@38i900c^FO0=ob
/P3>h:80Z[Ud069`9@3Vlj/0d]jN0=WQ_03TjM80ooof0?ool`3ooo40m?gN0?coh`31aJ@0h=o000X7
000D5P00a]FL0<gSXP33k9h20<;]W@80`nbM00<0aNbM0?ooo`3oool02@3oool000X0oooo0180a^f@
0<[YV@3:jI/0bNRR0<?Y/02mm;<0X=^Q04V5H`2]i:40_>fK0<oVX03Ie:`040000962H@3Qgjl0hNB]
0=kYY`3Dhih20<[NUP3o0<_QV03?hj@0d>6e0?3of`3gon80e^Nm0<gN]037eZ/0fNJk0?cog03dom@0
o_oL0?kof03jolh0d>BU0=7WZ@3DkZd0bnRU0<_ZWP37iYX0cnZU0=;Z[0003P00bn>a0<GZY@2UYFL0
i=jR0;W=R03CjZ@0d?2W0<SXW`38ei@0iM^P04aA4@3Ei:40f>Z/0=kU/@3hm<L0fLJU09B6H@3JhJ/0
d^BV0<SVWP38hi`0Q9AE08BGE@32hI40d>RJ0=?YWP2I/FD0?ET>0<WTW@34fiL0gnZ^0=cW[@3EiZl0
b^2R0<ONUP3IkZd0gNbY08jMF0065`00d^RZ0=?X[`3Kj[40f^>Z06aU>@3@cil0b^ZQ0<GPV@3Ol[00
TJ5S0?One@3oonP0ooo^0=_GcP31_[D0k^cO0?oom03hloT0ooko00020@0:2PP01P0006YOF`1GB440
<bTO00`900001@00c=S200LD00001P0000T0000:003=hZX0c^>[014U003:h;40`mR_0009001RL5H0
5AD9000200053@000PT00=gM^@070`0040P000X3001EF2/000P0000;00001`001Pl00<cF_@0:5P00
ioGN02T^6P0?500000H00009001NL3h0c>JU0<WXXP38jYh0b^VK0<cYV@3CiYL0g^VJ0=OSY@1NKC@0
g?Bj05Ua?`3GkJD0OHe?0>?TdP2g]YX0:RH=00L0000600000`00008300000P00IFMV0?omo`3Ugn40
oood0?3igP3eomh0b^JY0<7PVP2ee8P0_mj@0<?RTP3=jI`0S9mO0<SGX03gnmX0ooo/0?oln03@aL<0
oogk0?onn03onO<0oOGb0?W`l@3onOd0ooko0?Omk`3konX0dN>c0=;Z[P3:jYh0anbO0<CYW03?i9l0
a/260<SVX03;kjL0WjEU0=?PV`3:jYh0bnfP0=O]Y01?IA`0dNNO0<3ET03/okh0dNBT0=g_/@1EIb/0
RIQM0=;QZ03Gh[L0ooof0?gom@3/n^40jocL0=W`aP39ij/0b>VT0<K[V`36k9T0b>^I0<W[U`37hh`0
fO6U04AF903@gkP0lO[U0?col`3lonl0fn>n0<_DY@2;UeL0I7Da0=Wb/032fiT0_]FA0=3TW`3HgZ00
VY]O09nPI`3Uj[80a=6I0=[f_01;I2/0YJai0<S@W`1NJS`01a@00=KZ[`3DjZT0fOF[0<KTVP2ng9H0
f?Jh0<OTZP32gZ<0e^jb0=3UXP3FjjH0bN:Q0=[f^`24GC`0K4<S06=g?03DkJ`0bN>L0=7XVP2<ZV@0
^NRb0;Wa`P2LZ5`0d_>T00230;GLS@3?kJ<0Tj=L09^RGP3RlZT0c>fN0<;[W`3IoKD0enZZ0=3/XP37
jYX0bNbL0<?RUP31fi80f^jW08fHEP1SJB/0h>JZ0>;Z[P3BhZ40c^VR0<g/Z03Rokl0m?oC0<SMXP3=
hj<0dNVM0<gXU`3<jIT0cNVL0<c^Y032jil0`N^O0<;[W@32ji`0aNZJ0<OZVP35i9P0`=bA0=C[Y@3?
iZ00fnZW0=oVXP35b8<0IG0T061^8@3GijH0cn2Z0?cok03oooH0oo_o0?ogo`3on?l0oocm0?onnP3i
mO80ookj06=QDP0B5000d=F]0=KK/P3=djd0m?[H0?ooiP3oonl0ooo`0?Cei@3joN`0o?o_0?kol`3g
nN/0l?3T0?cjkP3Nell0oogf0?koo`3`n_40fO320;oRX02giYh0^^f[04f0E@2hil<0]nFn0=;o`P2^
fXl0b^VK0<cXV`3;jY`0bNZI0<G[UP36k9L0^]f;0<c[W@39iIP0g_B[0>Oh/P3?iIX0TjUN0=cbZ@3?
hi`0d>BO0=c`Z`3;h9/0dNRP0<3JT03LoJh0e_NV0;ODQ03FlJ@0b^6M0=3RY03CiJT0ho:a08nLE`3?
fIX0f>2W0?goh@3oond0oo__0?KchP3bl]X0dmjf0=gX_@1aMd/0BD/S00@5000Y;`40b]jS0=G_[P35
jih00P33k9d20<K[W@030<SZW@3oool0oooo00T0oooo000:0?ooo`2f0<S[S@31hY<0cNjO0:kEQP3?
mL@0CWm700<i002mlL40_>jY0<7]WP3DkJ`0m_;?00h0002NUW80d=BQ0>7//03@iYh0cNNM0<WZV`38
ji/0b>ZM0<SYY03Aj[40f>jo0>[md03hon40kogI0?Soh@3kon@0o?oQ0>cgc`3;eZ`0cMVW09BRI03=
h:00dnRW0=;[Z@34giX0bnZN0<g/WP35h9/0dNV[000<003>jKH0cO:]05aL7P2/YVX0f>bW0=G/YP37
iId0bNNO09^VI01DA@`0g]bO0=;NW02kdI40en6]0?oof01MCb`0Ge8_0>_d_`3<gZ00c>ZR0<kWX`3G
iJP0fNVX0<GQU03FmJD0`]n?0=WdY@3?ii/0AETB0<gPWP33ei`0fNZd000900002P00`mRO0>?d_@00
2@001@d004iG:01RL3l000l000<>000:3`00<2P400H400005000cNFc0<oS[P3Mk[X0YZj70?ooiP3b
m=h0c/bm0=ODa@3lnNH0ooo_0?koo@3cmO00LWE^00P90`070000OVmX0:bKT@3oo>h03`T000050000
2`00f>Vm0<SJZ03Fk:`0cNBN0=K^X03JmJH0e>jU0<oZY@3<iZT0g?C20?Cog@3akn00ooo_0<G>/@3N
iL@0d]N_0=WG/0071@00Lg=10=cW[`34eY`0e>R]0<_OXP3Plk/0bMZ^0>[jd`3Wn=P0g^Jc0:ZgP@3>
gJ80eN^Z0<OPW037hIP0d>ZQ0<cVW@3@jZ40c>JM0=_bZP3<gIL0PY=?0<gQXP33g:D0b>F]0<CT]@37
i;H0dN>i0?_ok03innh0BdI30?omn`3dlN`0gMkF0>7Tg@3Cdm40oOOk0?olo`3oooH0koCP0=GS`P3?
j[<0co2[0<GZVP36ji/0aN^H0<[]W@3>k:@0`]^J0=CT]@3>f;<0loGO0?ool@3oooX30?onn`0E0?om
o`3mnol0oooo0?_ok`3ion@0c>6V0<kWX`2nfXl0cNfR0<_]X@3Ll:/0iMnU0=?aZ`33iil0TIMG0=OT
W`3QoK80_]fA0<CLT01;HaT0c>>K0080dNRP08T0c>>O0=3WX`3AijH0cN>R0=3VYP3Fi[T0oogo0?oo
o`3ho_X0nOof0?Kok03:iJh0d_6]0<;UT@3<kYX0`^:F0=7_Y@35g9H0b=nK0=W]/037fj00fNZf0=GS
/P39ejH0a<fN0;JoT01UKC`0LWm90=K_[@2hdhh0c^FO0<KKUP1<EaD0D5HJ0=3CW03PjK00d>6Z000B
001IMS`0UIYP0=7IX03Ok;@0e^R/0<gYW`38iiT0b>ZF0<?UT@3:ji`0d>n[0<WUZ036gjP0d^Z^0=?X
Y`37fYP0FFd`000>002OLeH0h;>D0<gOX`2ldY40hoB^0>3LU@3IgY`0R:=^0;_R]@31bh`0b>fP0;o/
V`3Nojh0b=J;09fSF`3BhY/0co6U0<7aY@3@n[00dNRR0<CYV`3Iojl0a>NG0<KRU`3;iI`0dnVQ0<oP
W03IiJD0EE/O05AH7@3Ki:D0dnjY0<g`[03Lo;d0l?oC0<WVYP36hj00b^^L0<3QT03:kil0anbO0<O[
Y@3;k:L0bnZV0<[YX`39jIh0a>FF0<c]WP2oh8l0b^^J0<WZV`3BlZH0dnZR0>7UZ02ETeX0fN:O0=OV
X@3Bj:X0bN2Z0?;oi03noo40lnSV0>oMg@1WCdl0imgA0>CQd03ooo40ooc[02@U1P041P00h>Ba0=7F
X03TikP0o_oJ0>ocd03ooOH0n>c^0;BZZ`3oo?d0noOf0?ooo@020?ono@100?ggm`3onoT0eL_:0?Sd
o`3jn_l0n?oV0?7od`37jj/0`NRa0;;M_`0LARh04CdR0;k^_02hjjT0^]^D0>Ko_039jil0bo2R0;cS
T03:m:00aNfG0<WZV@3<j9/0dNFM0=?TWP3?iI`0`]Z>0<SNU@3GkJD09c`00<SMV03Bj:00e_2V0<?O
TP33iI40b>bE08JOF`3?hjH0k?o70?Coc`3>gjT0dMjX0=[U[@2DVVX0DUP/0?klh`3oon`0kNO?0=gJ
^@3Uil00dmfX09JTJ@3EgZD0dmNT00<6001aNDP0a=bP0<g/Z@34iYX0c^jR0<KUV@3=iid0bn>I0<OM
U0/0oooo000:0?ooo`3o0<KYS@3?kj<0anVL0=Ko[P2oikD0GXeG0;OY[P38ml40c?Nb0<7YX037g:<0
k>W800/1002MVGH0fN:]0=WWZP3=iid0bNZK0<K[V`35k9/0`nfK0<G[XP3;j:P0e>^g0=_a`03YnM80
h_3<0?Woi03kon@0j_K>0=gZ_`3=fZ`0Xk9k08nNG@3IjJP0e^VY0<kTX`3?j:@0cNVN0<[YV`3<ij80
c^JX02@j303:iK80_>6N0;6aL`2k]GT0`=B?0<oVX03>k:@0_mfE09JQG`1ZFb80hMnR0=kZZ03=hj<0
gNNb0=3BX`23ME80MVY408^DG@1cQDL0RjUQ0:S2N`2EXfD0Q9=B0>;m/02hehT0e?FT0;_HR03Aii`0
VZUT0;c<R`36gZ80XkR000HB000jAQP0eNVh09n`NP1_MTX0=chE010D001XLdT021D007MoFP1XJDX0
3@8003Da3P004P00<TLP0<CEZ03<g:l0/k^F0?ooiP3innD0g]c=0?Cah03oon`0ooo_0?_nm`3looX0
o_oh0002000@1`00U8Im0;:RU@3ooNl0fMC100XD000c@R<0b]fV0;?7S02jdHT0e>bN0<3IQ@34h8/0
^]F60=OcZ02hdhh0j_o90?Kof03oond0ooo/0=cRaP2maZL0em^f0=gM]`1BCb80UYQV0=7OXP3MlK80
cnRT0=O^YP2neI40f^ng065eA01EIcd0eMjO0;k=RP3>hY/0c^ZM0<cXV`3@jih0f?2V0=?ZXP3:hI/0
[lR403=<202DZfL0g?>]0=;[Z@3@kKD0fog108Z^R03<lLP0a>6Y0?Gok@3XknL02`D501TA3`1nNg@0
J6QP034d:`1PGe/0oogo0>cSiP3oooP0oooa0=GRaP35h:/0^]ZG0<_`XP38kId0^^2=0<?XV03>kZ<0
anBQ09JZM@26UfX0fnG30?Wni`3oooP0ookm0?onn`3oo_d0oogo0?cko`3nool0mooY0?OohP3=iZD0
d^bS0=3XWP36hYP0eO>Y05e^:P2IT5L0^]RB0<;VWP2PYVH0UJ9M0<[VV`32hID0aMfA06b4>P3>iId0
d>NO0<oVWP3<iYl0c>NR0<_VX@3>jJ@0i_nn0?Goe`3mnol0ooko0?_oo`3ioo/0m_o`0<_T[@38iZ00
a>JB0<c/V@33hIL0bnJQ0;K<SP1<HR@0ambK0=3UY033f9L0loo70?Soc028UF00b=2O01`S003=fJT0
bN:P0=_f/`39hYh0d>FP04UC502GWEl0eMZP0=CMY02DZ6d0D7@g09RfNP2;TE40hNV]0=_[[@39gih0
dO2R0<KXTP3;kiL0bNfF002L0<WZV@3:ij@0c^R[0=;Y/`3Jkk@0KH1001TY002N/7@0UZid099WA`2k
SF`0f^Z/0=W_[P3>giT0g]NA0>SYY`35fZ80bNVh0=SW[03@m:`0_nZK0;kOSP3Ci9H0bm>:0=?TW@30
hYP0]N>H0;cTV`37hIP0d?FW0<?XV032hi@0h?Z`0<_RVP3<hi/0g?6/0=OWYP3?ei/0^Kf208J?D03=
j:40bNVV0=;b/@3Jn;X0fOJf0=7^Z`3<kIh0co2O0<O/WP37kJ80bNbZ0<SWY03Ekjh0d>^V0<WTW@34
h9D0b>NI0<WXV03Cl:00aNBF0<?RU037gYP0RXmE07=b?03GhJ80bMVH0<7KW03Bjk@0jocH0?Woj@3o
oO40]JFH05I0<`3[i=80oOcZ0?ool03noN/0?ShT00L8002CUVT0Vii_0<G7W`3nomd0oooV0?oln03o
m_T0ooCh0;^`]03onol0oogo0>o[k03onod0n_Cf0?olo@3Ld]<0oo_o0?omo`3ionX0n?oM0<o/]P2j
fZ/0doKN0;3E``1[TWd06DHK0:_JX`3:kZh0]mND0<O[X`37kJ80cOBS0;kUTP35k9T0bNZI0<cYV@3@
iYd0dNFN0=cdZP38h9@0bMnF0<[PV02U^WD0X[Mb0:_2NP3>j9h0an>F0<SZUP37ji@0]<Z:0<oRZP3D
iJl0nOoF0>Ce`@3Pk[T0c=VT0:jeR@2?U6`0oooV0?oojP3[i/H0l_390<O:V`31c980?T`>0=KQY`3J
hJd05ad003Y44P3MmkX0]MBA0<cZX03?jj00`]bB0=S^Y@3AiId0iOF^2`3oool000X0oooo05l0b^ZE
0<_/Y@30iIL0ZmYn03eT=@39kkh0]]bQ0;gQX@31gj40`=^T0<gK]`3km^00204008F2H@3Nj;<0fN^]
0<[YV`38jiT0`nfI0<?]V`32kI/0`nbN0<_[X03?jJP0bN6U0<[M[`3Bh[/0m_oP0?Soh@3>h;00c>6Y
0=O_/@2>YEl0Tj9M0=_WY@3>gYd0dNJS0=?ZY03<j9d0cn^N0=?^Z@39hjH0KXAF0<SS/034jJH0]kMi
08J0A03IkJP0f_6[0<CTV`3Gmjh0fNRU06mS:@3cmKH0_lj;0<gRX@2e_XL0HV0`0>7BZ`2FR640fN6X
0=OZZ03Imjd0^=:90<cKVP3Cgil0//Io0=?aY`2jg8l0f?NY0=7SV@3JiJ00SIiJ0<c/Z`34hjP0[kb>
03<n5034eZ`0fNNd0=;F/@1/K58010<00;NmU`3Uk/<07B8406eZE`1GC2`0em6_00HB00002P00bMF]
0>[eb`2NYX40k_?E0?ook0020?ool`0B0?ool@3ooo<0jNcS0?Wll`3oooH0oood0?oml`3ono<0/Z6G
0?odj03oonl0g>S@0<cM^`3Tn;T0OiAC0=?YX@33fI00cNFI0P3o0000@`3=iih0c>FQ0<SRX@3Ej;00
i>?40?7de@2RZ8h0jo?K0:R/T`030`00FUXd09RNKP3DjJ@0i?ne0;gLS02kfhP0e_:U0;[DS@3;i:80
bn6S0>7YX03KkJ40b>6@0<7TT03<kYX0eNfO0<_PU@39fY<0b]fK0<kTX`32hIh0c>^W0;[JS`36iY/0
a^VW0;gUY`1LRFP0_^k60:WDS0003000FfEM0?omn`3on_T0f=?=09ZJT02DUX/0NWUd0>ONh@3onOl0
ookk0?golP3konl0`mV[0<CIWP3=ij00c>RN0<g/WP35iYL0`nBE0;OGR`33h9d0cNNX0=_b^P3gon00
o_od0?ono`3oood00P3oo_l05P3nool0o?om0>Cbf03FjK`0a^:H0<gUU`3Mj:<0U:EO06Aj<P2R[F/0
MfXc0<;MV031iId0fn6Q09JQG@3Ckj@0cNbP0<KQU02mf8/0cnVO0<cXW@38i9X20<g[X@2N0<WYX035
iI`0aNFL0<[SZP3no_`0ooko0?[oo`3iool0n?od0<gT[P3<ij00d^jI0<KQT03HkZd0`mRO09j`P03N
l;h0enbc0=G[[@37gI`0hoRg0?Woc01`ODL0S9IT01HK001UKT40Q9iO0;_EUP3Ck:X0amjJ04aF5`1_
MCL0k_:g000:001ZNCh0[ln@0<[WY@2V[FL0a]6=0<_QV@39iIX0_^B=0<S`U`2oiX/0anVC0=ok/03K
lK<0c=nW0<;CW@0_?PD0b=BD0<_GU@3@h:40d>FZ0:1eDP25FC@0UJQV08VPF03Jm:X0a=R@09nfKP3=
k:P0b>Z]0<gZ_02SaHT0`>2M0=;]X03=hYD0`=2508jRG@2oeI@0dO2Z0;oOU035iYL0doFX0<GQU`3T
nk<0]LJ00<GKT`38hYT0`N6H0<o_YP31eI00c=RF03]40`2Y_GH0enf/0>co`@3<h:<0c^6Q0=_^[03:
h9L0c^BK0=;]Z033h:00iOo80=Kf]`3Fm[D0a>>P0;_IT`3>iId0d^RO0=GRW03FhI`0f]nM0;>eM01K
G200W:A[0=ORZP3Cj:D0b^BM0=Of/P2mfid0g_C50?Kog03emLl0a/6I05U@9`3bmMP0m?WS0?komP3o
ooX01PL100X:0P3He/L0]kBS08R4N02@RGl0g=G?0?ojn03ojnX0ooCc0?okn`3oo?l0al730?ono`3d
l?40oogl0?omnP3Tgm`0ooco0?omo`3oooH0ooo_0?_ok@3hoo40ioW]0?3on@3aooX0eoCH05ekF@2G
_h/0ao2h0;gUYP2jhIh0a^ZP0<oaY03:jI/20<cYV@0Y0<gWW@3=iih0an>H0<c[W@3GlJL0eo6X0=3W
X@3IkZT0R9mI0<_UW03:iY/0bnZJ0<_/V`3EiZl0]/BA0>3^^@3Ol;T0d>:X0=_/]@3@hJX0o?oH0=GN
/@1KH3L0PhEM09VKJ@2IWV@0KWHj09>SHP3BhZ<0bmFQ06adA@021`00CeP[0<?KW`3Dljl0`^2F0<gW
W@33fi40gNjW096NF02i`gh02`3oool000X0oooo0780d>fM0=?c/03<lZD0_nj>05ImCP3<lKh0`N>V
0=3_Z`3LlKT0h??60=?K``3oo^d03P<007agF@3EgZT0g>Z/0<gXV`3:jYL0a^bI0<K[V`35k9/0a^^M
0<g^W`3=j:40bN:Q0<kR[`3DiKT0mooP0?;ofP3Aj;00b>:S0<_YX@2Ya7D0XK=Y0=WVX@3?gY/0eNZW
0<KMU`3;iiX0dnnR0<kYY03:i:L0H7I80<cW]02lhIh0hN6S0<_5R@3Cj:<0d^bU0=3bZ02lgY@0^lb8
04a21`3/lK40cMjJ0=SXY`3@eId0CDTI0=2nV02YVW40g^>Y0=?TX03;jYh0d^bR0=g/Z`3=eiP0joZi
0<OUW@39kZ00b>NK0=3PU`1FH1/0amRB0<ca[02beYP0e^>e0<gE[00X>Q00UjI_09BFL@1_KE@0;b`K
0=CI/@3@ej/0V9]l00l<001BB2@0h]fg03Q19P001`00e=fb0<cEZ02GWWD0k_7B0>g_e`3mnnl0ooof
0?Wek03oooP0oOoi0?konP3oooX0KfaU0;>VX02TTHd0_ZfV0?oll`3ooo<0f^OC05U/CP3GjJl0A5HL
0=c^/P3FjZd40?l0000[0=3UZP3Lm;X0bMZT0>;P^@3Mg[`0OXAZ0?cok@3joNX04Q400862H03MiKH0
aMbD0=;aX@36j9@0`N:C0<WXVP3AkJ<0bNFK0=3ZX`3DfIT0e^NQ0<gWW@38kId0b>^K0<[RUP3@hYP0
FFTR0<_LV03=i:00`^6K0;kSUP3BlZL0`>2D0<kcY@31jJ/0>VY20:oT/025/F@06S@=0<C<_@3oo?/0
ooWi0?onn0020?oomP0C0?7`j`3jlO@0ooWo0?onn`3WjMh0c=G20<WI/P3Ii[40e>2R0<cKVP3=hiX0
cnNK0=OcYP39j9X0dNbU0=3[Z03Fl;40jok@0?com0040?ono`3Q0?koo`3lood0h_7D0<gP/P3;iiX0
c^FE0<S;R00e@000Y[E`0=OMW@2YV680bnBP0;kOV03QijL0c=NC0=7]XP30gi<0b>>F0<gYW03<j9/0
c^ZM0<WUVP37iYX0bNVM0<c^XP3:k:00a^RL0<STZ@3oooX0o_oo0?Olo`3iool0n?oc0<kSZ`3;iIh0
cNJB0<[STP37fi`0UJQa0>gmd03Gj;/0fNfl0;gAX037fjP0h_C20?Wof03IiKD0/[^<0<;8VP1dOT`0
@5`O06R4A`2gd8l0gO>b09>MGP1ZKS40blb@07Em@@0e@`H0dNn_0=?][02LYUl0/Kii0<_UWP3:j9h0
b?2J0;gUS@3Bn:40aNJG0<ORW@3Kk;P0eN>b008?001hPd/0I6l]082;B@1jRTT0cnFW08]Q>`2oTf`0
fNjY0=SbZ02Ua7P0`^BJ08R]H02hhI<0`nfU08BZP`34hZh0BF<V0<cTV033fX`0iO^`09jaK`3Ai:@0
_mBA0<7MT`30hi40^]Z?0:_0N`2EYV80[[Yh07j?B`2Y`7X0coBW0<O/W`3DkZD0am^D061Z9@1CH1X0
f>BT0<K@T`3Nj:`0Ff<W08fFE@3Mj:<0enBN0=7QX`3=h:P0kooB0?7od`3AlK00cNZX0=[e/P3JkZT0
amJA0=gTX@3De9@0HU`P0517303OfZ80e=jQ0<[OWP2ofI00aNBH0;kNU@3?kZ/0k_o?0?Kof03oomH0
iNNf04]95P3@f;40h>g?0?KokP3looX06Q`K00H6103ooOH0ooof0?oil`2o]K<0GeED0>3?b03on?40
ooKa0?okn03/i>80o?Kf0?Sgm@3oood0oOch0?[glP3Ge<d0n?;b0?khn03oo_X0oooj0?_lmP3gn_<0
m_gf0?WonP3boo<0c^7>0<;E_`1mYWX0W/fI0;kW[@3<lk@0`N2J0<7OU@3=j9/0cNRI0<cYV@3:jId0
b^RN0<CTV03InZ/0^mZ>0=;^Y039h9`0dNRT08jUH@3?jJ80cNVO0<_ZWP3:jId0eNB]0>_h``3ZnKh0
`mFG0=[][@3EjJX0d>BW0=_/]@33dY/0]L2806Yc?020QTP0TY]J0;[5P@3>gYd0fn^]06efA`0K8P00
GV8o03<k4P34g:00cnjZ0<c/X@3Al:@0c^ZO0<oSV`2Z^W<0j?>^00/0oooo000:0?ooo`0D0<o[X@36
jJT0]]nC0;OZP`1EODT0b>Fe0=;/[@3?iId0o?oH0>gce`3oo_T0onkW00l0001/HDD0h>2^0>?[[`3C
iIT0d>NG0<gXU`3<jIT20<cXV`140<[[U03>ji/0b^JL0<oT[03Bi[D0gO330<GKZP3:jJH0b>ZM0<K^
V03BmIT0go:S092ME`3?gYT0RIiI0<gTWP3AkJ00a>2C0<cWXP39hjH0G7560<[T]035j:H0i^JX0>3J
WP2V^gH0cnVR0;cPUP3LokH0fo2[0=gIW03:eI<0bmnJ0<KBT03EeYd0Ng5007iX@@2<Ne00eM^O0=o`
ZP3:jIT0[LQk0<WJU033cX`0LWXo0:W4P@2jh9<0f_V]0=GRVP3=e900enRR0;ORV`30jZX02a/006Ia
AP003000I7@e018E000[9`X0>3<P09bOLP2`]h<0Gf4l00H1000o=`T0MFlm07UlD@052`020=CLX@0F
09RNKP3UjLH0oooZ0;Zg/P2:Q8@0oOOk0?oko`3_ko40oooo00d;300A2`d07@d@00h0000=0000R7ek
0?gjm@0040<00A@00<kK[`0P;@806RH0000800@0o`0004009SH?03e?9@2KZ7X030`000X=000A5`00
>D0^0>;Sg@3Ng]H020/007MoEP3<iYd0bnnH0<;XT@2jfi@0c^jU0<o[X@3<j9d0`mj?08B2F@3@gZd0
e^nf0<W^Z`39kJL0dNJQ08BCCP3PjjH0jOZc0=S_Y`30hi<0^Mn80=3`Y@3;jiP0d_N@0;gR[02gj[40
^o>Z0;GRT@3Gl;T0c=>d02lM6`0g:BP01P0003ll<`3hn^l0oogf0??Zk@2YWZ@0KfUY0:JVWP074000
b=>a09>>I01GD1`0N7<l0=SMV`3^n;<0dN>G0=gdY03Cjid0amnC0=K`Y`3Ik;D0o?oc0P3oool20?on
o`0H0?koo`3koo/0i?GE0<[Q[@3AlIh0aMf9085l?02f]WH0g^FR0>7QX`2KQU40SJAP0<3OV@3EfYX0
jOB`0<GQUP3Em:P0cn^N0<WUV039j9X0b^VK0<c[W@3<k:00bN^N0P33j9X0a`35k9d0bNNW0?3dh`3l
ooX0m_on0?Soo@3eoo00eNZ_0=3XWP3Dk9H0enbM0:NfO@2P[Wd0kOg@0>[kd@3fon/0f>OB0?Col`3c
oo00m_o_0>oieP3Uk/<0YZ]c0=kW[P37hjT0JXQ<09NaLP3:h:00e=fN06]/<03Lg9h0f]jQ086=C@2d
ch`0gOJb0<C?R`2M[6/0c>NT0<WZX`30ji`0^^FC0=?hZ`3;j:D0_]>J08ZBK@1mQF00d]^V09bTJ`3F
gIX0_/R30<oNV`3HkZd0WgE=0:1fC03Omjd0>UL70<WUVP27UeT0S9eI0<KMS`3@j9`0=VM:0>3id@12
DR40e>FO0<;NT@3<k:00]lb;096IH03Bf9X0eNJO0;KLQ`23WEH0]l640=KLWP3DfY`0b]VF08ZQF`2/
ehP0e?nb0<CYV`3:jI/0gNVQ0;fnNP1NEQP0ED`A061E7`2_Y6`0THM<0<>nOP3_jJ/0YJ=`07QgB@31
_IL0/jIj0>GGYP3cik<0g=2L07]i?P1RI2D0TIYI092LG03=gIh0eNNY0<_TXP31h9@0g?n[0=OkX`3C
mid0f?^Y0;oOU03:hZH0enbd0<SEW`3Ul;H0c]JJ0=CYYP35gIl0gNg60?Wok00g?C<01PT20?Caj03o
oo@0oo_`0?oml`3om>`0fLNi07QWE@2WVH`0n>cP0?gfkP3oooP0[ZfX0?oonP3jno<0nogb0?oom03^
j=X0j>3E0>cQi`3on?l0ooWo0?S/n03ooO/0ookh0?oomP3nooP0loG`0:cH]`1UVW00eoo@0=3e_`37
h9l0cN:M0=7UW@3?iiT0cNRI0<S[V`35k9d0b>nN0;OLS03AljH0`MnG0<_TX03Ck:P0Vk5`0=;XY`3@
jJD0d>ZS0<SRV`3Eh:H0hnbc07N6@@3DiY`0bn2C0:>kK@27WeD0^<n70<oUW@3>h9@0`mB40=?OT`3>
fY00ioN^0=?VY01QLcT0hng80<76Z00C4`00;38@08fRJ@3Km[40a>^L0<?ZV`39kZ00`mfC0;S>Q@3A
hY/02`3oool000X0oooo01<0c>ZP0<WYZ032jil0`o^J07BYL@2MaiD0b^^b0=S/[`3ooml0ooo/0?oo
n`3on_P05PD0069G>`3FeZ80dMNI0=CTV`3AiYT0cnNK0080cnNM05h0cNRK0<cZU03@l9d0c>RM0<[R
Y03@ijl0j?o:0<cU[03;k:L0bNjP0<S`VP35ii40c=fF0<kJVP3LjjX0FVd[0>3e/03Ckj@0]mJ:0<oZ
Y`38hJL0Kh9E0<WO[P3:jZT0gnRW0=7CU02U/Vd0b=jF0<caY02oiIX0c^>N0=SNWP1EFad0fNFS0>;c
[`3Beid0;RP009AnE@2o/XD0g^R[0<[KU@1`QcT0Jh<g0:VmM@2]^GL0dM^O09:XI`3Imjl0aMbD0=KQ
W02EWeX0c]nI0<cd[@2nij<0_m:K06=a?02fcY80c^BK09ROJ@1`KTL0;BP:0=OIY`3Mij/0HW0m08^C
K01JD1d0h]VP07f4CP3GhJD0e>>R0=cZ[02[/h80n?cG0?7af@3Bb/L0jN?W0?olo`3on_l0oo_o0?om
o`091`P020@30?olo@3?_l80814D00h41@3Kf]P00Q870007003Fh[X0:CD?06I_D03@fKh000H00P3o
0000@`2HYHT0gnc>000900002000;B/00=7BZ00E5@000@800<oDc@000@001`0000P70039hZ00c>nO
0<3UU@2ogYX0c>ZT0<7KTP3Cjj40d^RM06]cA03AiK00cNV_0;cQWP3>kZ/0am^F0<7@R`3DgiX0aMVA
0<_UV`31j9D0`njB0<;TV036iiP0_^>60<_`_@2mlK<0/>VL0<gjY`2geY<0g^bk0?3Xd`3ln^40o?oT
0<c@]`0010000@4001XE4P1bK6`0oooj06MYF`3Ylm/0e^2k0:JMM02`Y7@0VYEN06id=02h`gh0fNVP
0<cNTP3AhiT0e^NP0<[NV@3Agj`0o_oa0?ooo`3nool00P3lool0Z03kool0nOok0>Cee@39gJ`0c>NJ
0;W<O@1mOS`0f=nL0=3KU`3HfId0f<B?08jJG03MlZl0dMZI0=SWY02abh80an>H0=;^X@37hYD0c>RK
0<WXVP3<kIh0`nRJ0<;YVP33k9d0a^fN0<GZW037i:40j>cC0?colP3koo`0nooh0?Coi@3>hZ<0d>JK
0=O/W`36fY<0Xk9g0=SZ/03<hJP0cN6`0??oj03goo<0m_oj0??nmP3iooP0m?gP0>S`b@2;TeX0f^JX
0<o^ZP3<jjP04bd002e11P3QiZh0MG<j0>SRYP3ShjD0eMjM0=Wd/@2kfI<0fnbX0<KIU`3Hlk00_mjH
0<C[W037l:40_>2F0<WVY03Dik00Q8YV07YnF@2EWf<0en6R0=WTW`28Tdh0S:1I0<KQW035X7@0[HMJ
0<KMU@2=ZEh0dN^R06md?02GX640e>FN0<_QV@00;@X0_=NZ0=SY/`3QlJX0aN2A0<_ZW03EjZL0cmVM
0:2VJ03<fI@0RjYJ0=7[XP3Ei:40e^:P0<kIU`3Fij<0TjYR0<?/WP31k9`0`NJH0<g/WP3=gI@0dmVC
0>GTX`3Ad900k^Z]0=SDU`3YiJH0PH0o05YI6@1HEal0F5PV0?olc`3giKL0KUXX05Y95@1_HR/0bLN:
0>S][@3PlJ/0cN:M0<OTX@38jJ@0^MfE0<CYV@3:kYL0`^J>0;kRRP3AlZ40`n:F0=?YZ03@i:L0hNnd
0<gIV`3MjJT0_mJ>0=[e[P3<h:/0e>Jl05APC0012P00lOKR0>W]e03[jm40oooZ0?ook`3omNT0ooca
089fJP2>PGP0ooWb0?okm@3_jnP0/k:^0=gLe`3oooP0oOod0?ool@3on^h0iM[P0>oSl@80ooWo00h0
oocm0?O_k03on_@0mOKa0?ooo`3Koo@0SlN/0;KR_P3DnLd0d^N^0=GXZ03AiIh0cNRI0<[YV@80b>ZM
02L0a>FF0<kaW`32jIX0bo2S0<oYXP3@ij<0Zl1m0<oZY@39ij40cNVO0<_RVP3Chj80d>2O09V]I@2B
Ye`0c>6D06b3=@2^a7T0TjUN0=O^X03?iYH0enfK0=G[V@3;hY80amj@0<gRW`1kSe80G6Lo07YoG`01
10004AL0010T0036gi/0bo2R0;oVU`38kIl0aN6F0=?[X@3Ciil02`3oool000X0oooo0?l0bnjL0;kN
U@33jIh0]O>V097LV`1`/gh0_Njo0=SabP3oon`0noc/0?conP3omoh05@@004a29`3LgjH0dmbK0=?R
W@3?h9`0bmjL0>?g/P3@i9d0e>^M0<_XV03;k9d0cNbP0<WWW`3Fm:h0fOJd0<o/Z@3<jjD0anRQ0<3R
V03?kJL0enV_0=_U/03Hhj/0P91B0=3SX@3GlZ/0a>BK0<o/[03?iZh0HFa10<gM[037iZ<0`n6G0=;S
W@3Pfi/0[[]e0;oVU`3=ljH0c>6L0=S_Z`1YHR/0f=>I0=SdZP35f9P0IfLa07MQ>02k]hL0b]fM0=OV
X@2GWED0//Ah0:BjL@3FjZD0eN>V09ZZJ`3MjJT0gnZX0=;IUP1EIAh0b=jE0<CVVP32i9X0bN2L0<cS
W`3Mo:`0/M=o0=o^Z@3NhZD0C4D?0>CXZ`3=hI`0]=bC0=7`[01MDaH0i]RK0<oKV@3?hih0an:M0<[T
X`2AWFd0l_?A0?oih`3PeM<0ooKl0?Ogo`3no?l0oo[o0?ojo@051P00HVEL08J7PP1OFE/0D4M<00@0
0P3Mfmh000@0008?0037eK40H6]904A:;P1NHTL000@002h`6P38cKH0X:R@075kH`001`00318009B:
I`1iME002`0000P0003?f/X0008003hS700R2`00d^Bb0:O5Q`28Z6D0e>^W0=O/Z@3;g9P0eNBQ0;O3
P@2Zah@0bnbU0<k_Z031hiT0c^VR0:^jM@32chT0c]^E0=;XW`3:jId0`nnJ0;_ZSP32jil0`NJQ0<CZ
[@2ojKT0]^f/0;K^X`38nZ<0_nJE0<SVW03>gYd0cN>J0<oTX`3@hj/0Ig9@08V>N02CUHX0e]S=07n2
K`1SK4l0d=bf0>3Z^02WWg40lnfk0=gNY@1CHR40BEdH0<oNV@3IiZ40g>:T0=GIWP3Wk;@0mOS=0?on
jP3oooX0n_ok0?Soo`3ao?l0mOoo0?7om`3<fkh0f^Nl0=7LX01^NCL0/l9m0<oTW`3?iZ00fn6S0;ja
O02XWVT0eMBK0=?TX038hY/0R9mG0=K/X`3?jIl0cnNM0<cTVP3=jIh0bn^O0<[cY02ok9/0_^^J0<Ob
XP3<kZ40c>JO0?oog03hm^40m_KZ0>obg@3eomD0gNjW0=S]XP3@hZH0/L>90=__ZP38h9H0anNK0<k]
Z@3Mm<X0mOo/0?WonP3hooP0nooj0?OliP3Yl<l0TYYW0:>cM035jHl0a^VI06n;D00dAQ@0f]N/0:>E
J03?`8T0hM^M0=7HU@36ij00`>FO0=?aZ`33gYT0[lV00<KRU`2oh8l0bNbL0<3RV03AkZ`001d0dnJ^
0<G:X@2CUVL0d>2G0>7aZ03?hIL0Vk1U08FQEP34iYX0_Im]0:^9F`3NmK40Mi9=0=W^Z`27R4l0SiML
0=K/[P3ClKD08dlL0<OVZ`3;i:80f>^J0=CZU`3:hHl0cNBL0<oRX02KYfL0TIeM09N[H`020<gYW00:
0<COTP3Dk:80b>2F08JPE`3:j9h0aNFJ0=OeZ`33hYH0a^2F0=3VW@80dNFM0740dnBN0=CSWP3Di9d0
//9k09NWH02@W5X0X:a/0?ooc03moL40WimS09jPH@2NXf40c=VC0=OYW`3>jI`0cNbP0<W]X`3<lZL0
`NNL0<3RU@3HnJX0_Mj=0=GdY036hYD0c^RN0<gSV`3EjJ@0cmjK0=CQW03Jij80b^6M0<oZY`36hIh0
eNjd05AZAP004000b]ji0<[M[`3;gJd0nOoO0?WojP3oo_/0n_7d0=;7a@1UFUH0oo_h0?oel`3onol0
^[6f09jIW@3gnOH0ko;[0?oon03jnO@0lNg^0=cFfP3oo?l0ooWl0?omo@3ono/0ookm0??cl`3moOl0
gOoo09KBdP2ei=@0hOo[0=?W]P3Mkk<0dNJQ0<kdX@33jYL0aNNJ0<_UWP3>hiP0c>NH0<;_W030kI`0
c>>K0=7RWP3NkJX0cNnS0<3VV@30gi40f>ZP0<;OS`3=kYl0^]B;09V^J@28W5L0[Kef0=k^Y@2@Xe@0
b=n?0<_VU`3GljH0aN^H0=?iYP2dehD0f?:Y0=cb/@1/N4P0LGU@06ecC`094@00G70e0=?ZYP39jIh0
`^:G0=3^Y031fi80d>NO0;?7P00;0?ooo`002P3oool0LP32k9X0a>>G0<k/Y02ojJL0/>^Y04B7D@1/
YgT0c_OE0>_gj@3nooX0oogn0?oho`10;bP0?38I0=KIX03HhJ00T9mL08^KFP2lchl0jojl0<kRV`3I
l:80bnNJ0<[ZWP3<k:00a>BH0<CTV@3:jZ40anNN0<SWX@36iJ40b>NS0>ooc03eom@0k?[50<cIX@3>
gYl0dnRU0<OUW@39jZ<0c>^X0<?LXP1WLd<0d^2[0=C]Z`33j9/0b>:I0:>NGP2]^W80c?NW0<K_X03H
kJP0d>^X0:JFH`27Md<0a^BJ0>7f]@3<ciP0KUL^09VII`3=hj80cMbG096>B@3HjYh0c>JL0<GNVP2h
bY00o?oA0<oDWP3>dIX0inbb092QG@33fI40an>H0<cXW@3Il:P0bN2H0;oKSP39jY/0cN6I0=kXX`1:
APH0e^6L0<KRU`34mJ@0a^bO065E6@2YVEh0en^S0<SRV03:k:80co2[09VZM03Qi[d0oooS0?omm03o
n_/0nogo0?omo`3oloH0dl[5000400001@00o?oc09JISP0300000@0002X[9@0010000Ph00<7;YP3:
e:l0<S`I065XAP80o`000P001P00@P0kA2D0WZN806acDP041@0000L00:6IM@1;ARH0Y[JK0003002h
S8d0ZGag04127@2?WF`0e>V^07bAC01cR4<0S:1K07j?B`2Z^GH0co6T0<CVV@3;kJ00bNFJ0=kf[02?
WeP0a]J?0>;bZ`37hIL0anNK0<;/VP36k9L0b^RN0=3]Z`2mfJH0b>Rg05InB@2QcI80_^JP0<GUW03=
iI/0e^VJ0<gZUP3BkZ<0dNZX0=?T^03Ag;`0fN7:0=gUc@002@00looE0<3@W`3LjK40UYAQ0>KV/03L
iZX0f_6]0;kHT@1IKBH0Ef<Q08Z>D`2LWfH0W:5Y0:^/P03^i]40oocf0?ohm@80oogo06d0ooko0?kn
o03al=`0moKH05QE:P2f^H@0foF/0<KVW@39jJ00f^BU0<c2S@1??@/0hmZS0<;IU@3GmJd0SJ=K0=GY
XP3<i9X0e>RP0<kRVP3DjZ40b^BJ0<O^W`33kYh0_NZI0<7ZV`3FlZL0go>[09jQJP2^[XX0m?KN0?Om
f@3?fZ00bmj=0>3eYP1?HbH0R9]S0=G]X@39iI40b^fM0<WXY03:gkH0looX0?_on`3nool0lo?a0?oo
l`3konP0k??:096NJ@3El:T0anJS0<kY]03Sm/P0JfM208QjE`2XUVh0XIUZ02ld003Ko[`0_NFO0<g/
YP3:iIh0RJ5G0=;ZWP3HmJD0b>VJ0<WYX03Hlk00b]jS0:J/OP2c^XH0b=R?0>3bZ03Dj:00Y[id0:k>
P`36k9l0RVhl0=6aP02=Y600dNZX0=S][01oPdP0WZI[0=3Y[`2jfj80LYYV0;cKW`3;iZ<0Ria>0;O9
M`3DiID0b^:H0<cVW`3DkJ/0b^2O0=S^YP3:jI/0c>fL0=;aX`2ofXd0c^RN0:NoM@3Nn:l0^mF<0=Ga
Y`39iid0co6U0080b>ZM0P39jId20<[YW@0A0<[VV`3Bk:80eNnU0<cVW039h9P0b>6O0=C]Z`3Ak:L0
bNBM0=3_X`31h980bNZK0<_/W@3:k9l0c_2S0<_]X@36iIT00P38i9T07`2AZf40LXY00<OOU@3Ejj80
e>RP0=CUWP3HjJ80amN@09b/K@2odY80enZX0=SZ/01OKTl021H00=3P^@3;gZL0dN>W0=CU[`3Lj<@0
o_kb0?gil03on^X0M6QH0?olk`3oo?<0oo[m0?ojo`3onol0_knm0?Ojl`3nooX00`3oooX0>@3Bb/L0
mno/0?oln@3lmo@0ookk0?Kfm03oood0kO[o0>goo`0_GU@0D8Mb0<Ccd@3;lLP0OY]]0=C//P3:hj80
aN>I0<WYW@3BjY`0c>NH0;kXUP30jIX0b^BJ0<cPV03Bhi`0J8Lk0<3ST`3<iiP0i?BY0<WYU030iY40
anFK0=3[YP3Fk:/0c^:M0=SZX02fc7X0OiI40<oYW`3CkZL0c?:U0;kWV035jY`0cn^Q0=GZY`38eJ00
fN:g051H;`033`00d^BX0<gRW`36hIX0b^RP0<[UWP1^R440OIA>0:c1O00;0?ooo`002P3oool06037
lZ80`n6G0<[TW@39iZ@0eOfn09C>U00oNdP0/^Jo0>Wol@3hood0ooOo0?o`oP1ZFeH081D00?gob@37
d940e>>P0=GYY02Z_gh0JGdh03mE3@3KljD0bNRJ0<WYW@80bn^O0580bNVN0<WYX038j9l0cNbV0<SW
X`33hYh0dNj/0<kV[03Jjk@0UjI[0=?SXP3Cj:<0d?2W0<KZX03;k:L0b>FU06Ab?@3>gJH0`mRG0=?c
Z03;hYX0FEPG0<kSV02iiYD0^^FE0<gRW@38hIl0oNVg05a;5`35hiT0a]VI065T;@1E?QD0ZJUg0<kT
X`3DiIl0V9QB0<cQU036iIT0dNbW0=_^]`3hom<0];N809FII`31b9@0dn>T0=S]Z03?jIl0`=Z@0<KK
UP19GQT0e^fY0;kITP3>hY/0f>>N0?;e/P3EiIh0b>NK0<7`X034iY`0Z9UR08Ac>`3CjJ00bnNL0<_]
X@3>l:H0[/:70;JnS`3lo=P0ookc0?cdlP3no_l0n?Oo0?SZi`2HTHL03QL000D@003Rk=<0incH0>OW
f`3MgM40iNOI0P3o00000`001`00o`000?l000040?l0001a03e8800g@QX000L000070026Sf001AD0
03<a20071`00Vjj>0004002oShd0o/g800d9001NISL0cMbS0<;IT`35fYD0d>FP0<cQW03GjjH0a^RK
0<g]X@3<k:00c^RN0<7IS`2fah00dN:K0=GYX@3;ii`0c_2S0<;WV@3BlJ<0enfU0=CYYP3Fjk<0e^bk
01dm3P1PPE80`n2Z0=7VZ`3FiZD0cMVA0=3XWP3FlJh0bN6U0>?db03OkLT0XJZ=06=/C@3OjlD0iOG8
0>Oha03AgZH0SXiH0<cAU`3GiJL0bN>L0;oKT@3OmJd0f^VT0;6jN`2SZFd0SIMK08F8F@1KDCP0ooK_
0?oimP3oloP0ooWo0?ojo`3onOT0ooSY0?okh@1RFS<0jn^i0=OaZ03<k:<0b>ZP0=kZZP3;a8h0H4hL
0;J_N030ei<0c>ZR07Z@B03TmJl0d>JM0=3QVP2``7T0dN:K0<oWW@34iYT0`nZK0<K_X03<lJ<0aMnE
0;kBRP2oaHL0fn6c0:bbT03Wl<D0e^BW0=7WU03DjiT0`=JE0=oe]@3AjI/0f_FT0<[YX`37hjH0f^_7
0?Gok03lood00P3oool0?`3oooH0ooo]0;c0W@3>eZd0enVi0=O__@3<i[H0bmj`08B6H@1gK4`0KUln
079ZA@0<4P00Z<R90<_c[@2de8/0hObe0:c2N@37gI80aN:B0<k_X035iI`0cNZW0;kDUP012@00KgQ3
08VHD`3SlZd0`mNB0=3WX@37iih0cO>X0:fAG`1oGbh0c>FQ0<GPV`3Cj:D0GfDW0;FoPP3?jJ`0bnf`
05R2DP31hZT0c^RY0<KFR`2GYEP0dnBF0=3XWP37hY/0anBQ0<KTWP37hiT0a>>G0<CPT`3=jI`0c^JL
0<WQU`2bbX00`mfD0<[TV`3@kZ@0bn^P0;kSUP020<K[W@<0b>ZM00h0bNVM0<WXW036iIT0an>H0<gY
WP3=jj<0anNV0<_^[P34i:40_n2K0<c^XP39jId0anRI0<OVV080b^VM00L0`MfB0=?_Y03:iY/0E6hT
0:6kL@2kdhT0D6PN0080e>ZQ02l0d>BL0=KZXP37fi<0UJ5S0>C`/P3Cgj40en6]07UnJ0001000j?;@
0=cV]03JiZP0gnZb0=gU_03no^H0h=_50?onhP3]hLL0cl2[0?ohj@3hj>P0o?3b0?olo`3ooo/0d=7;
0?oon03cm>`0oooh0?onn03`jN<0_KJ`0?omnP3jmO40ookj0?SglP3oo_T0nooo0?Soo`2V`kh0GHMk
03YbF@1m]9D0d?cI0:6fR`35eZ80_]F?0<_]X0020<[YV`0U0<W/W03;jil0d>ZP0=?[X@3?iI`0dNbO
08jYG039gi@0fnfS0<SXU@39k9P0c>bQ0<_YX`3:iJ80c>>M0<gUV@3Aj9P0_MJ50<[QV@36gIT0a^RN
0<O[X@34iYX0eNnV0<cQWP3OjKD0g^Fi01@K0013C1l0cmnQ0<cOW@2C[VL0OieG09:]J03?j:@0dN^T
0;oFT00;0?ooo`002P3oool02P2kiI/0bnfQ0=?]Y03Dgi/0dmjL0<O[[P2@aHd0C91Q0=coo`3Uool2
0?oio`0@0;N/Z00n=b@0iNRi0>;[/P3Wn;@0c^BL0=W`Z02:XUP0TJUM0=C_X03<jil0bNVM0<KVVP3:
jYh0b^ZO0<_[XP80anNN04d0c>bS0<k^Y@3:jJ<0bnRV0<;HV02/`H00e^ZS0<_SV@36j9/0`NRI0<cb
Y`31hYd0Fg4c0=?UY`3RlK00Z/1h0;;6O`2FXed0b^VK0;?TTP33lZ40b^6K0=CTY@1NAQH0NFDb0=K`
Y`3@h:40blZD06U@:02BTV00c^NU0<GITP2XZf@0ennQ0<;TU`33i9l0k?oD0?7of03Qi/H0emRh0:nc
SP3@gjH0a]^J0<GMT`3IkjL0SIaK0<gKWP3?gZD0dnNZ0<?HT`2icHH0@U@:0<SUU@36k9T0`>VJ0=3Z
X`3Te:00G4lJ0<GPV@3>k:80b^fM0<CVV@3DjjL0ZKQo0;:jR`3oon`0ooof0??`n@3ooOl0dLRg06MU
C01<FBh0Gfm007:2E@2T[hL0Y:V90005000:0?l0000_0=_]/@3UlkP0gNF/0=gV[@35gYd0eO:`0<cE
WP2QZGH0`M^^0?coiP3T/j`0onKK0?3V`P2WYWH0bMBJ0<CPUP3=iih0d>bR0<STVP33giD0b^ZO0<_W
W@33gI@0`mVA08nSG03;hIT0cnJN0<gWWP3AkjD0a^JK0=7/Y@3BhJ00i^fY0=[PV03EfYP0Yjih02Xg
6@0_?RL0K7QR04Q?;@18Ba`0hnNZ0=WV/@3Ei[T0NHUL05m/@01YM4T00P3Ih[D0P@3Fh[00g^bg0<7@
V@0X=P00E5hQ0>Kg/`3GkZH0b>RL0<_[W`3Ajj40c^BK0=g^Z03JjjD0c>6L0=_Y[P22O5P0ooST0?o]
g`3okn/0ooKe0<R^[@1B>cD0CCh[065G?03imm00jO2m0<?OU@34iY`0d_J/0<gMW03AcYL0OFdj09fF
G`3GkZX0aN>K0<SLU@3@giX0enRQ0=OTWP2@VeH0fNBO0=SXX@3Bk:80cNbP0<3OT`37hiP0e^NP0<kP
U03HjiX0d>2O09>RJ`3CiJ/0eNVT0=G]V@2CZeL0bn>I0<GOUP33h900g?R]0=CZ^@3CiK/0nooa0?co
n03oo_l0oo_o0?olo`3oo_d0m_;Y0=GD`03ooo40oook0?Wol@3bom`0l_oH0=OT^@13@bL0ETdl09jI
Q@0K8@00eoFg0<GYX@3Pnk@0`MR@09>TG@2mdXL0dnjO0<[YV`3;kJ<0`^6K0<_UY01ZND80?T/E0>[e
^`2U/7H0e>BV0<gQXP3Hmk<0bO6Z0:B8EP3A/H00b>:K07NBB`3=ij00//5n0=OXY036hIh0`N6N04Z1
E`2oj[D0anR_0=OVX`2Q[6L0[k]c0=7UWP31fi@0do:/0;kPUP37jId0aN2I0=W^Z@3HkJP0f_2X0<[N
U`3CjJ40[/Em0<gWWP3;jj00`^BH0<[_XP030<K[W@<0b>ZM06h0anNK0<SXW03:jId0b^ZN0<;SW032
j:l0`>N`0<3VZ`38k[40_n:N0<GVW`36iIT0c^VL0=C/X039hID0]lf208>KD@2K/fT0c>BJ0=O_Y@3I
lJL0d>RN0<kVW03AjIl0bN6G0<gWW@3FkZ@0_lV:09nSIP1aM3/0hN:f075]HP0@2`L0moGN0?ooe@3O
i:80dMJF0=cOZP3^l;l0fm^Y0>_X/`3on/T0O6i;09B2JP3kjND0ooKg0?__l`3ooOd0n?Ca0>WYh@3o
ooH0nOK_0?onn03omoD0oogh0>GNf02:Pgd0^kJ`0?oomP3alNL0nOof0?con03on?l0ooco05R0P00<
ACh0A8Ih0<Oaf@2jekP0FV/g09>[K@38kZD0bnnU0=GYXP3Bhid0a>>E0<;UU@39jY/0d>2G09RRF`3I
iYh0dn^Q0<WYUP34iY80`N>G0<CXX036jjD0`nVN0<CVV@3;j9P0d^fP0;_;S03Iij`0bn>W0<_XZ03C
k:/0cN2P00lO001<EB00WjMh0=?J[P1VKd00LH530;G8QP3<iZD0cNZZ0<cYY`3>j:L0dNbY0<GPV`/0
oooo000:0?ooo`030<KZY035jih0`nFH0080o`0006D0f?:e0;SU[P2]lL00Z>OD0>3oo`3no?l0nO7o
0?kfl`0G50<0m?W@0<kHX`38f9L0`=J>092XGP2L]V`0g_V/0=;_W`3:jId0c>bP0<OWV`39jId0bNVN
0<c/X@39jIh0a>BI0<GUVP37ii`0anNN0;kMV@39hYh0goJ`0=;XW`3?iid0a^VI0<S_X031jY`0`NFK
06Z3@@3<gil0cm^K096RG03@i9d0dnVP0<7VUP30m:40`O2O0=K`Z@3Pk:h0BS820:FAGP3KlZX0fnV[
0:BSK@1hG3D0W9aZ0<oXYP3Fk:@0/kUa0=3[W039kZ00a>RR0>3gb`3gon<0jnoF0?7cf`3dmmP0eN:/
0>Ki^@35gI40c^BK0:nkN`3Sk[80fNJ^0=SW[02DZF@0TjUP0=3XVP37jI<0`n^E0<GXV03FjZ<0YIEQ
08UnB038iYh0bNVN0<[]W@34i9P0d>VU0=7SY`35dIl0oooZ0?oom03gl_P0oogo04i6<@3oon<0BeTV
0=3SZ`0H:@003a/00007000:0?l0001W0=?]YP37g9L0cMbG0=GLV@3Jhj80h?Ve0<SVX03PjZd0RI9I
0<kX^03jon40g[:U0>NgZ@25P5P0WZ9`0=3NX@37iYX0b>BI0<?RUP32hID0dO6U0<cZX03<iYd0b^2H
096UGP2[_gP0a]fE0<o[X@3=jj40c>bQ0<SXW@3BjJ<0f^FY0=oRW`3MhIL0YZUR08J;D@2KYH`0@Ti0
0=KPe@2]/Y/0W:5i04e@5`2e_980Ig5<04188@3doM00eMf^0=3HY@3Yl[d0fN:[0=CMYP3Jhj`0Ef8X
092LFP3:hIT0c^ZO0<[/W`39jih0dNfP0<_SU`3?hi/0c>:I0<KRV03FjjX0emZ[06MN?@1fJ4d0bkJU
04H_8@2eWi80m>?C0?ooi03lnMH0j>o30=3MY`3:i9/0_^:H0<[^Y039fIP0c<VB09N:EP2LUel0d^VU
0<GPV@35eY00cmbG0=?SW03Hhih0V9mK0=[TW`3Eh9/0cN>J0<[TVP3BkZ<0fo>Y09:RF`1KJb00gONP
0<;HS@2?Xf@0bMjM0<WOU`020:BkJ@1;0=;ZW03JmJP0d>bO0<GPV`3/o=L0jOKH0?[mlP3ooo/0ooSo
0?ojo`3omol0oOOi0=gEdP3ln>`0oogg0?omo`3looH0`=^V0<o]/@3Hj[X0Ifa<03La8`2GU840>T4P
0=3]Z`33iIT0a^6J0=S_Y`3>giP0GFlU0<gXV`38ii/0c_2V0<CUWP3Flk40fNf`09NVK@1PJSD0PXaG
0=WX[`3:gZ<0anJS0<_c[@2CNDH0XhEC0=;]YP2ddXX0SJUO0<WJU03Hk:D0cNRQ0;_JU00dMdh0[>6]
0;gV[P3Ej:H0a]>>09ZUH039fY@0bMjI0<oZX`34hYX0Z<Il08^RGP2U^7H0c=nM0=GYY03@hI/0//Io
0=S`YP3Jm:X0e?BY0;cNTP2ffhh0b>ZM00<0bNVM0`3:jId0K@39j9`0cNVN0<c[W`3DlJh0c>Zf0=oo
cP3Fm<00g_g40=Gb/P3Bkj`0d>ZQ0=G_Y@2kdX@0W[EW08bRE`2K/FP0Y;Ya0=[`Y`3BjZ00a]jD0=C/
XP3?jIl0b>:H0<_UV`3<j9d0dN^Q0<oKV@3AeiT0SiAJ04m@9P29PW`01P000;^fXP2YZWh0PXU305EL
601[LCD0ADT>05aM8@2ZZ6d0b/><0?[/a`2aXHL0k=[F0?oio03on_l0oo_o0?WemP31`;/0eMG=0?gj
m@3oo_X0knGT0?okn@3ooOX0o?Ca0>ORg03oo?<0oood0?olm03hlnd0o_oo0>_`mP3]mol0X[Jm09:d
/`0bK5@0PKfK0=?da`2T/HD0`nNW0;gUW`3<fiX0eN6O0<k]X@38kId0_=n=0=cXX02DUe80a]2;0=cc
Z`3AlIh0cNfJ0<GZW@37kJ@0a^jW0<3[W03=m:D0`^>D0<3JT02W]GX0TiaW0=_]^@2neId0d^F]065a
<`2AWf80gnRc0=;JZ@27Sf00UIm]0=WYZ`3>hIl0b^:T0<oY[039hjH0cNNX0=C^[`34hIl02`3oool0
00X0oooo00<0e>VX0<chZ@3o00000`3o00005@3Jml40`_?604>3L`1RWI/0iooo0??ko`3nood0K6mV
06=/C@3Gh[P0dnFW0:o4O`3EkIl0bnJG0<_VV@39j9`0c>^O0<_[X03<k:40bn^O0<SXW0050<WYW@17
0<SZWP3:kj80e?:X0<GOUP23Vdl0d>RL0<kaX@37kYd0bO:S0<7WVP34hYX0cnJP0=WTXP31bXL0fnZU
0<GWVP32k9X0_^fL0<3]W03Mm:h0f=jR075K:P2KSUT0cNNN0=KVY`28Qe40GD@L09bLJP3>jJH0dNRP
09NOEP31gXh0anjO0<;WX@3:i;L0mooV0?7ci@3mo_00ooo]0=KR/03Hjj/0dnbK08VND`3IiJL0fNBX
0<oNW@3?gY/0c^>H0=?[W@3;jiP0coFN0;_QRP3Hkj40cMVA065K7@3NgZ00c>bS0=3`Y`3Bl:P0b>>N
0=;Z[03<hJT0f>Rk0?oojP3ooo40oo_m08UkNP3[i/T0gn6j0<kPY03<hil01`3o0000c`2nbHL0o`00
0?l0003:iY`0a^RK0;gPT02lfHT0TJYI09V^G`3LjIX0f^FI0<_HTP3=hIT0SiAA0=[PX03CkkD0nOoJ
0>G3ZP3Xa:X0WJMc0<GJW`3;iZ<0aN6F0<OVVP3<k:00^=R<0=3bY@3:j:00cN:M0=GYY00lB`P0cn2L
0<[XX035iid0bnnU0=Oe[@36h9T0f>JX07V3CP2KXUl0SiE;08fCB@2la8P000/000DE2`0lCDL000L0
03E3801UK3T0=C@E044m803oon40G5/]0:BWLP1nPTD0C54A05EJ6P1eNC`0Wj=X0=3HW03Gjj@0cnjP
0<WZV`2hgHd0c_2S0<cVW03Bj9l0bn6F0=ScYP2aeXH0dO>V0<cXWP3Ai:80dn>U0=SOZ`3KgJ`0g=n`
0=SN[P3Ci:h0e^jd0;oOWP3:jJD0gON^0;_MT`3@m:X0dN6P0>;QZ@2RUF40DdhF0<[OW038giT0TIaH
09RQGP3DiIh0f>FO0:>XI@3EfYL0cMB@0=3PV@3Ll:P0e^jT0=3TW02HXeh0eNFJ0<_]S`37iHd0S:AJ
0<gRW@3AiZD0[L5l0=7WW`3>iYX0dN^Q0<kYYP3com@0o?oa0?_ol@3ooo/0oogo0?oko`3on_l0oO7m
0:RMY@3<`lH0ookj0?omo@3oo?l0f^7?0=?`/03;jj80cnFW0:F^P`25Pf`0KFeA00070034iIH0`^FA
0=ObZ`36gID0f>VR0=OXX@3Cjj40an>H0=Kh[02lgY@0aNBN0<CJV@2ib8d010`00:feQ03EhZd0cn2Y
0<GSX`2oij40YXaK0<RZN03>k:@0`^:G0<g]XP3?iid0cNNM0<[YW@39jIh0E:^00:[`_02ajk40b>NS
0=K[YP3ChYd0Uj=Q09>RH@2AX5d0QiIA0;g9Q`39eYh0RiQP0=GSZ03Rl;80amJC09:SG@3Ejj80e>bR
0=?aY`32i9P0aNFJ0<oWW@2db800QieD07F9@@3=hIT0bmnG0=7WWP3Fk:<0X[Q_096WGP2W^WX0SIIY
0?oog`3eo]<0nOoC0>7^]P3BhZ@0f_2X0<WOUP25WE<0bNBG0<ORU@040<oWW@80cNNM01L0d^bR0<o[
X03>jYl0bnNL0=7]XP3Cj:<0c>2K0=?SY@39eJL0B4Xo0001002JWXD0d=ZV0<cOT03Cj9T0bmnH0=OT
WP3Bg9D0YJYW061P902k/X/0k>3605I7A0020?ojo`0o0?kgoP3oo_l0oook0?oonP3[j^H0`knn089l
O03lm_H0ookk0?kim@3oooP0b<Rl0;k0/P3on?X0nnS/0>Smm03/ood0ooko0?ojo`3hj>/0l_ok0;oV
e00kJe<0PjVD0;c[_@31k;H0dn6/09>NI037iih0_NBE0<GZVP3Oiih0b<N40>7ZY`3<iYl0dNjN0<gX
V@35iIX0aNVO0<G]Y030ji`0c?FV0<GUV@3KmJh0f^Nb0>3V^P3/m]40]<2H09NTN01hQDl0Qi9H09>N
IP2HXVh0f^Jd0=3NZ@2=Wf40J7/i069g?P1WOTP0IWY706AkA`29XFd0`]^T00/0oooo000:0?ooo`03
0=OWZ02hi9D0o`0000<0o`0001D0c>Bb0>WoiP1c[Il0AX5o0=coo`3_ool0k?Cf0;Nm^@0jA2`0d]jj
0=CVZP1oTdh0cNFG0;cDQP3Qo:l0bNFK0<OUV`35iIX0a>BI0<OWV`3;jil01039jId09@39jY/0b>ZM
0<O/WP3?kJ<0b^BJ0:FkL038h9@0`nBE0<gdX`38lJ80^=n@0<GUVP3>iId0dMfK0:6XI@3?gYT0b_6R
0;oYU`33kYh0_>FF0;C;Q@3^kkD0DT0>0;>/M@33giD0h_:c0=[JY01/EB`0YZQf0<gXY@3;hYX0Vj=J
0<[WU`31j9T0a>ZQ0=?[^`3gonH00P3ooo@0803bln40cm^Y0<kQW`3;i940W[EW0=_WZ@3@fil0dN:L
0<kMV039fi40c^JJ0<[[VP2dfXL0h_nb0<SHS`2>UE40GUhN0=?LV@36j9h0bnZT0=7/Z@36gZ00c^:]
0<;EY`3Lk<D0g>7:0?_hj@3fi^H0HU1<0?oohP3Cf:l0f>b]1`3o0000X036h9H0cMfF0=[[Y@3<i9X0
an>F0<SYVP3=kYd0WkaZ07N@?`31f8P0YKIV0=OSU`3EgiX0iOF/09JIE03Pij@0_=ZL0>?e``3XbZh0
j<^]08bMIP2mfYX0a>FN0=GaYP3:iY/0cnjR0=CdZ03;jil0b^ZQ0=[_ZP37f9@0L7ll0=GVXP2ogiH0
`nNM0<W_Y03;jJ40e>VT0=gWZP0g@@`0a]6?0=GOV03SkJH0c]VO0008001>I5L0TZVO06AjI@0nE300
=40>00@3002a[8h0i>2k09ZJJ03IfZ40]kaj09BIEP2QYV@0]KYj0=7BUP3QijT0c>2H0=;aX`39k9`0
bNjP0=?cY`37gI@0c>2H0=K/X@3<iiX0bO2O0<K`WP36k9T0bNZK0<cXW@3@iJ80dNBT0<cNX03Gjj`0
`]bK0<CUX039lJP0c_:X0=C[X`2ogiH0co6W0=GUY03KfZ80^jij06iW<03Hj:L0dnRS08>:A`2:TDh0
`mN?0>3`Z@2EW5P0fMjK0>O^ZP3Di9d0d>BL0<OOU@3>hYX0]L1k0=7QUP3Dmi/0`NB:08VSF@3Cj:D0
bM^Q0=;TZP3HjZ`0amfE0=K]Y`3Aj;00mooO0?[mm03ko?H0ookm0?omo`3onOl0ooGo0?ojo`2NU9`0
ln[_0?_em@3onOT0mOG]0>7[d03>jjP0h?nd0=3UY00c?@/0W9Uj03hn700mAaD0e?JR0<oeWP35hi/0
e>jU0=;SW020T4T0`MN>0<kXWP2jfXl0bn^P0=_i/@3?iZ80S9aN010F001BFRT0fnRc0=[[]03ClK40
a>bV0;FKJP37ZGL0anFM0<CTV@3>kZ<20<cXW@0^0<[YW@39jId0AZ5e0:?]^02ak[<0^]jH0<_UWP3?
hi`0cmjK09ZVIP2LYfD0[[Md0=[PXP3Rk;L0NhQC0<?@VP3Jj:X0amJE09NVH@3Zo[H0a=bB0=kl/P2f
eX/0bnVO0=oc[02EYUl0Wk1Y0=CUWP2?X5T0_m290=7UW@3FjZ80Uj]S08nSF`3KjJ/0hnBh0?Wgd03o
omX0oooF0<SAV03GhZH0bMfH0:g3N`2mehh0a^:H0<[VV`<0cNNM00H0cnNM0<gWW@3=iid0b^BJ0=Ga
YP3BkZ<20<WUVP1C0<WTW@3Bk:D0d>JU0=GW/`0e?2`00@L00<?>[P3Ij;40c^ND0=3/V037hIL0e>RP
0=7QV03:e8l0TYII07MbBP1ZH4D0H5EA0=cBd`3/hnP0ooko0?_kn@3en>l0o_oh0?oonP3mo?P0J6AS
0>OShP3oooX0oooh0??cj@3joN`0m?WU0?G[j@3oo?d0mooj0?GonP3ooOH0ooch0?;PgP3jnO@0mook
01@n<016NFX0b?cF0<cgbP3Jjkh0Y;9m0;7?R@3CmJT0b^^L0=7KTP3OhYd0j_Fa0;[ET039i9L0d>RJ
0<o]X`3:k:80aNVQ0<S^X@2niIH0anNL0=7ZYP3aoLd0m_gD0>G^c`3eomd0gNS00;g7T`1:EAd0eN:Z
0<7>V03>g:L0gNjh03U=3P0]@P008SD0000<00002P00@5<V07fCI@3CjK/02`3oool000X0oooo00<0
fo2[0;kPT`36kI`00P3o00004P35gJ<0bMna0?;ojP3Yool0g_oo01<iA02=Z:l0i_Wo0?;oo`001P00
00L00<WJYP2;WUh0cnBG0=K[X03@iYd0a]fI0<WWW`80c>bQ00@0bNVM0<KVVP39jY/0bNZK0`39jYT0
AP38jiT0b>fM0<SWV`38hYP0d>BL09N[H`3=k:00`N>F0<gdY@3<lJ<0a>BH0=?]X`3>gi/0YJaY0=?R
W@32kih0_nBD0<GTV03Al:@0e>VT0=KDV`1QFR@0X:IZ0<[ZW`3DjZT0f=fU08MaB02JWV/0c^^X0<kU
W@2HWUH0a^6B0<CYV`3?lJL0b>2V0?Wog`3Fe/X0l>gT0?ool@3@gjP0gO>Z0<3MP@2D[ET0cmnP0=W^
[@3BkI`0e^JM0=OSX`3Fj:X0bnNZ0=?a]@37g:<0bl^E0>[Y/@3FiZD0cNNP0<OYW`3BkJX0lOo>0>km
dP3aon40l_oX0>cki03noo<0oooc09EjL`3Tc<80QhE/08V?J@3OmKD60?l000190<OSV03DljD0c>NJ
0<7LS`3BkJ00a]jB0=K^XP3Cjil0amnC0<cWVP36hI80c>NH0<oUVP1:Ea80CF4I0>?YX`3UkjP0b^^V
0<SMY03F_9T0nMfh08jPI02mg9P0bN^Q0<[QV@36gID0h?N_0<WPV03?jJ00_N>H0<;IT`3MkZX02aL0
0=S/Y`36jZ00`>ZN0<C^XP3DkZL0iO6_05mN9@3HiJd0gnna0<GCUP3IiZh0d^>_0;gF]P3]onl0F7eN
09:fTP2lgkD0d^Zh0<O>XP34aIT0i>Rf0=_UZ@3Ghj<0fNVR0=;RV@3AgYH0d]nG0=kYY03Fhid0dNVM
0=;aX`3<k:00bnVO065k<P2?WU/0cMZE0<WJU03AjIl0c?>R0;cXT`020<;^U@0/0<?^U@35kIL0aNbI
0;kST`3?m:@0bNjP0<?ZV`30iiP0dO6U0<gQVP3=j:40c>ZR0=kZZP3JeIh0bk^809R?F03BgYh0g>^X
09nNGP2TYVD0cNVN0<KLT`2Z]G00b=:=09bVH@1=GQL0TZQO04eW7@3>iY`0hO:[0;oERP30j980^mn8
0=C^Y`39g:@0Z[J>0=?M^`3Gh[X0e^F^0=SY/`3Hj</0m_oa0?koo`3oool20?ono`0X0?okoP3onol0
FU5D0?omo`3mmoT0noOh0?Wik`3Zo<`0fo:j0>[o``2lg9<0e^BV05EH8`0B3P00RHUG0=GQX`3CnJ@0
_nZA0;_PT`2mfi40en^S0<gMUP3Ll:P0dNVO0<OUV`3KnJl0dnnU0=7WW`2ochh0ko?108bCH02:Uf40
00`00<CSX034k:H0YHiJ0::6E03;jj80dO>W0;oTU`@0bNVM02d0K;N<07BdP02Ug:80`nVP0<SXW@33
gi@0d^RP0<GIU03GhZ00f=fK08F6C03an//0mOoF0?[oe03Ii:P0e>2P08nLE`35eHh0c^>H0<_RVP3<
iYd0^M>:096UGP3AhY/0`mB=0>3aZP3:gYH0go>[0=K/X`38gYD0hON^0=[bZ033e900i>Nb0?;``025
QE<0ADPC0=?MX03RkZh0eNRV0<CKU`37hYd0dNj[0<GTWP3:j9h00P3:jId30<cXW@1H05ei;P2<YU`0
`M^A0<GOU@3EkjD0a^RN0<_`X`30h9D0d^b]03A59@001`00f>^m0<?LV03<kI@0a^ZC0<gbY@3:j9h0
a^2F0=W]YP3GiZD0gnFg0=GF]03ooo40oOga0>oaiP3koo40lO_S0??oi03gonP0mOgX0?kol@3jo>h0
oooc0?7dh@3oon`0lOOK0=[V`03Pk<@0W;nN0<[Vc@3omnh0ooOa0?onl`3noo<0n?k`0?olnP1WFET0
a=?>0;kXg012LEl0GhUc0=cifP3@jl80Qj5T0<OPW038gYH0c^2D0=SXW`3<h9T0Bf@P0=S`Y03CjY`0
b^6I0<[TW@3<iYl0b^BK0=3ZX036h9T0c>:T0=CU^@3UmM40o?o_0?GjiP3amm/0hNfm0<cKY03@hZH0
00`00=?V[P3DjJh0bN:Q0;kGT`36eZL0i??:0?_oh@3ionP000L00?Wok@/0oooo000:0?ooo`0K0<k/
XP3MmJ/0cnFJ0>On]P33gYT0g?O00>WoeP3eon`0k_om0?3oo`3[ool0@5]R08fV[@3Yool0VJZT01@U
4`3Fi[L0h_Bf06eo=@3AhY/0f^jW0<[OWP38hi`0`n>H0<OWW03<k:00bNVM0080bNZK0P39jYT0B039
jiL0b>^I0<K[V`3;jIl0bN2H0=KWX@2FYf40bNFK0<SXW@3;l:<0a>VL0<;RUP3?jj00dNJQ0:F/J@2f
aH00]nJE0<OZVP3Ejj80amnE0>Sm^02NVF40l>ng0:JbM03=kj<0]m2>09bTJ`1[F2h0Ri9N0<cYYP3B
jJ40U9YB0:_3M@3<kZ40cNfR0<CIV03[n<X0b/Rk0<k<`03bln40c]fT0=W_Y02XaFP0V;AM0<WNV`3D
kJT0c>jJ0<gNU`3Nik00j?C20=oga`3Wo]@0e>2j0>[R^`3KejP0c>:R0<o`Z@37ii`0dNZY0?_og@3l
on@0nOoc0?Oon03hooX0ooof0?ogkP2INg<0jLg202PV4@2^]980amfO0<_VW`80o`0003l0iOJb0<CH
T`38gYH0cnjR0<KWV037j9T0bnZL0=;ZX03<hYT0bMZC08RIDP3Fk:<0bN6G0>7m/`2geh`0dnnU0<oR
X03DkZD0h>bT0<gJU039kJL0cnBY0:B8H@3^d:X0]lF80<gVXP39i9d0cn>N0=[^Z@1AIR40iOZe0=3U
X036kZD0c^NS0=[ZZ@16DQ80e>NU0<cbZ@2mjIh0`NfR0<kSX038cY00FE8K0<kIW@3Bi:X0XZmi0009
00003000k?oR0>;og`2TcJ<0CGI:06R?H02iej<0e^B_0=gX[P3DhZD0aMRF0=O/Y`3?iid0cNNM0<WQ
U@39gi@00P3CjIh03@3Cjil0bnNL0<KUV@3GlZ/0OY=>09JPH@2AVUT0e^FP0=?YX034jIT0_nVE0<G/
V@35kIL00`33kIL0E@2khXl0c_BQ0;kOT038ii/0c^ZP0<;IT@2O[VT0Y;ig0<?NU`3Ihj@0eLjH0<nm
R`2]XV`0d]^L0=SSX@2SWEl0Vi]K0<c/X03CkJ<0bMVB0:bgLP2KYV40f^jV0:c4NP2keh`0b^BJ0<gQ
V@3JlZP0a>^L0=OjZ02idY00UZQf0;BoX@3monh0k?;H0<WEY`3Njkl0n?od0?Woo@3loOl0oOgo0?om
oP3oo?/0ooWj0=S?d02SVY/0noGe0?omo@3mnOX0o_oc0<oZY`3:jJD0anRS0<[WY@0_>040PGm<079[
=`3[j[80en>S0;CKRP37m9l0d_VZ0<KVV`3BiYl0f>VS082AB`2:X5P0_=R=0=WeZP32g980_M690>[i
]P39cYP0YJaf0:ZeO@11DaL0aN:P0<WaZ`2XTEd0WX9@0<7QV03>lZP0anbO0<SZWP38jYd00P39jId0
;@2ajL80Q[R50;k[/03>lZP0dO6U0<g/WP35hiT0d>^T0=o^Z`1NIb@0gN6V0=kZ_03ao]<0n_oI0=3N
X`3Dh:00VjQS0>3`Y`3Giih0g?2Y0<_QV@2CZV80e>ZR0=K/X`3IkjH0amnE0<oWW@38h9H0dnfS0=7[
X@3:iY/0`n:F0=ke[`3Mjjh0d]^R0=gX[03Mjjd0bMVH0<CGU@3;hYh0g?>_0=K`[`2cd900^MRE0<WY
X0020<WYW@<0b^VM05P0eO6V09J`IP2K/fT0eNfS0;S@QP3;kJ<0_nFH0<_/W@3BkJX0G6i60008003E
jK@0b>:I0<_^U031iHh0bNnV0<_]X`38j9`0c^RN0<cQW03Ihjl0fN:g0?oojP3hoNL0o?o]0?;oh03b
om/0looJ0?Woh@3kon@0nooV0?kojP3cnMd0m_oP0?coh`3Xm<`0a]NS0=GV/02YbIX0UK690?kgi03o
n^l0oo[f0?oim`3ooo/0nOok0;k:`03;eLX0k_W[07VHT01fWY<0Ji9g0<?U`01jTET0Gg<d0>?d[P3C
jY`0ennS0>7k/P3>iJ40/<Ik0;oFR03LlZX0gO6/0=S/Y`3AiIh0_M690=7VX`3@iZP0bn2e0>3dd@3W
k]h0oooc0?kojP3bo]00gN^f0<gQY036g9h0c^JZ0<kXZ`3?jJP0eO2[0=WY_03Tl<`0l_cJ03M1:01n
Qg80l?SY2`3oool000X0oooo00P0a>^L0=3PU`1AF180Zk5a0<oOX03Jn<@0k?oO0?Coj`80nooo00l0
l?ko0>_oo`1FLg/0i?oo0>3blP001P00bm^^0=;TZ02R]6X0OHi708bMF@3QmKH0dNbU0<OWW036iY/0
0P3:jYh00`39jY/0bNZI0<WZV@020<W[U`2E0<S[V@35jYX0cn^Q0<gTW03KjZD0Xk9]0<cVW@3:j9h0
^n2C0<W^X@3FmJT0bNFJ0=7XXP2GWU/0SYeH0;GTT`3?l:40enNP0<cMUP2odhh0Ee8J0=_NY@3GjZX0
b^nR0=3[Z03DgJ@0Lf0f08nFHP38iJ80d^RP0::UGP2AZ5X0c^jR0<SWV`3@i9d0f^Jd0?Cbh`36`[L0
`L2/0=7PY@3?iYH0T;1?0<3OPP3DjjL0bnJQ0<K/U`2hc8D0fn6c0?Oof03eonH0l?oV0<76[`3Wekh0
hm^g0=?_]02ihI/0a^BJ0<kTY03iomh0oOo[0?[onP3eooh0n?oo0?_lmP3on?80YhEk0=Fg[0030P00
iNc;0;oGV`3BkJP0Q:1C0<KNU03>hYd0d^JQ0=ca[031h9@0b^fM0<[_W`39jY/0cNFK0=gaZ@1oS4L0
VJIQ0=KZY@3>iIl0_mZE0=Ok/`2mhIT0d^fZ0<KXWP3JjZ<0g^nX0<7UW@3Ejjd0JDTS0;^HLP2k`hL0
f^jY0=G[X`3HjJD0PY=?08bMF@1cQ400dN:N0<_eZ`3JmK00c=nM028^003Lkjd0`>JM0;[VV`36lZL0
g_6_0<kBU@3UfZ80cm^M0:6`N@1KIcL0o?oO0?Woh`3Dl<L0e?S:0;WU/P1XTV000R`00=Cd`P3Dk:h0
bn2M0<cSW`3<jZ80^=R=0<GWVP38jYd0b>^K0<[YV@3<ji/0cNZJ0<oZW@3;iI/0`mnE0=?ZYP2kbhX0
_L>705eS9@3Tl:h0cN6J0<W^WP34jiX00P38ji/0F036k9T0`nfI0<?]V@3@mj@0`nJF0=;^X`3Omjd0
WJiZ09RTHP34dH`0XKQb0=C^Y`3Nj:T0h]^U0<jjR02`Xfh0gN>U0=SQX02SVE`0UYEE0;7FR035i9P0
WJiW0:2`J@2c`7X0_mF<0=3ZX03>kJ40dnnT0=O]Y039hiX0_nFL0;cQT@3Gl:l0i?G80?Soj`3oooP0
o?o^0>;Z``3Zm=40nOok0?Ooo`3loOl0oOgo0?ono@3oo_/0no?`0:nWY03oo_X0ookk0?WelP3knOX0
n?o[0<_^VP2jgi40_=bK0;gIWP1QIC<0Mg510966D03Iei`0d=bJ0=[o]@2ij9L0_^VI0=;dZ03CjJ40
_m2:0=SYX`3=hi/0D6XP0<CNU03>iYX0h_BZ0<;AS02CV600f>2W09>NI00b@P@0cNZW0<3XX@3;]800
c[:00<CTV`34j9h0a>ZO0<SZWP38jYd20<WYW@0^0<S`c@2</800c>fd0;_KT02ogi<0a>NG0=Ci[030
hYP0aMZE0<;ASP3Hh:D0kO[>0?Wog`3domD0fnR`0=gYZ`2DXE`0d=fE0=SUW@2>WeT0T:AM0=W_Y`3?
jJ00b^BJ0<o[X034h9D0c^ZO0<o^XP3BlZH0b>RL0<g_XP3?m:H0c>bQ0<7JUP3BjJD0c>>O0<[QV`3D
kZL0fO>/0>7j]P2gd8h0b>2R0=Oa]03>jZd0b>ZP0<SZW@80bNVM0P3:jId0F032g980bn>I0=3XWP2o
eH`0V:iU0<c^Y02jh9<0c^nN0<OSV@1^Oe8000h00<cPY@39i9L0anZ@0<3VT@39kZP0b_2U0<O/W036
iIL0c>JM0<_MX`39ejH0o?oT0=_VaP3Agk`0enZl0=K]]`3HkKD0`]BP0<gM/036eJX0fN>n071kD`3e
omL0m_oE0=o`^P3<h:40ambI0;cAUP29WFP0n_oO0?ook@3ono/0ooCk0?WdnP3[mo<0mOoj09:EQ02^
Yi@0g_Cb0>Coo`20[IH0RK:@0=GY]P14DQL0c]ZH0<oZW@31hY<0_]bB0=O/Z@3=hiP0_MB606Ig<011
D0d0B5@B09^XH`2?W5H0dnJT0<kRY`3Wo]@0l_oX0?comP3koO00oOo/0>old03eom00amfO0=K^/000
6@0001000=Sg/`2nfiP0dN2e0>Wcd@3ionD0f=o=0?kom03nooX;0?ooo`002P3oool06`2oiYD0DUhF
0=?@S@3DcY80WjM[0<WU/P3=j;l0l?oW0?onnP3onol0ooco0>coo`1iVj@0Sk2i0>Goo`3XoOH000L0
0::[OP3Ji:L0bmNI0=GUYP3:hj80TjmU0<;QU@3?kZ80anFK0<SVWP020<[XX0100<cWX03=iZ80cNJR
0<gVXP3Fl;40dNJ[0=OY[`3>fIl0Uj9V0=?XY@31fYH0eOB^0;?DS`2=[6T0c^^Y0<OUW@38eI00/<5j
0<3YVP3@jZ00e^>N0=?RW@3;gY`0h^:V0=GOXP3?iZ80`nRK0=G`[@3AfZ40J5T^09BHIP3?j:H0b^2H
0=STVP2:XU@0c^ZP0<[VV`3<i9X0dn:Y0?klh`3`jmL0c/fa0=KTZ@3@iY/0P:930<g^T`3@k:40anJJ
0<GXUP2R]g@0fMni0?cojP3goo<0noom0::QW`3om^l0ook]0>koh03]omX0d^Z^0=7S/@3non`0oood
0?coo`80nOoo00H0n?Oe0?olmP38Z9d0]IN<038^8P3lonX20?l0001>0<OQV03Djj<0jOnl0<;MUP3<
ij00a>2F0=3_X`2niI80b^^J0<SPU034f900ZkQc0<gIU`3EiJ@0e^^Z0<cUX`39j:D0anZV0<K[Y@36
l:H0cNVO0<SRV@2mgYL0e>JX079E:@2POe@0WimS0>3YYP3Fhih0Uj=S05MS8`3KijL0f>BT05MV9@3;
k:D0d>NS0=KVY@1QLRh0cNBP0<CZW`34kZ80_>FI0;[>R@1_M3@0h=NL0=3IVP002000/kNB0=WO``3D
i<00b>V`0<S_[030jJD0bO6e0<G[^035jK/0`n>R0<GUV@3=kj80aNnM0;[UU@36lZD0`nnR0<C_W`35
kid0_^RB0<S^U`3Bkil0bN>I0<SRV@2CZ6D0YkMh0>3X[03Bf9`0TIaJ0=[YYP3<j9d0cN^Q0P3=ij00
:03<j9h0b^VM0<[YW@3?jj00dN^Q08ZKE@2N[FX0h^^/0=WRX@3EhYd0OHU70>gn^P3Ql:l0f]NP0>7=
V`2PSe/0inFZ0<cEU02PVU`0^;Yi0<ccY033iIP0d>RN0=KZXP30e8`0b>2F0<OSV031h9@0eOBX0;cF
S03@k:80b^^V0<_[XP32eil0ioGA0?com03oool0nocg0?ook03nond30?_oo`0[0?cmo`3ooO`0l^gZ
0<>l]P3ono<0ookf0?oml@3no_@0o_of0?3nf`32jH`0cO2N0<7OX@3Aj[<0X:Ih06IO<@2OReT0[j1Y
08b<CP3@m:`0]nJH0<?^WP3;l:80bN>J0=;XX03Dj:40d>JN049I4@3@iil0b=jE08ZKE028UE00f^:Y
0<oIW@2V]7H0e^VY0<g/Z033jj@0WH=B0;^LK@3;i:00aN2I0=7aZ0020<K[WP0`0<WYW@3:jId0Y[R6
05U^A@34fZ`0dNNV0<_UW037ii/0_NRI0;oXV@38hi`0Rj9L0<_QX03;hZh0bmn^0=;T/03Vm[P0fn^Z
092OFP1BHQT0/<1g0<oPV@3<h9T0bN2H0=3_X`3:k:00dO>W0;oQU`2ohiT0anbO0;kUUP38kj00`>VK
0<[cY@33k:00a_6R0<G^W`38kih0`>FE0=GfY`33hiL0_mfE0>;o_@3UoL<0mooF0<_SZ@39j:80a^^M
0P38jYd0FP39jId0b^VM0<gYWP38hYP0c^BK0=?WW`3AiId0b>RO0<W[W`38j9D0fOBW0<SLW`3CiJ/0
e^bT0<kWU02oh8T0d?>S0<_^ZP2mhiX0b>bR0<SWX@3=jIh0b=fR0=7S/@3homl0fnc00<GHZP3=i;00
bN>T0<kVZP35fZ40d>>[0<SIXP35dYX0Tj1X0=?SY@3FjJL0cN:M0<[UV03Ckj80YZER0<o9S`3kon40
m?o^0?Ooo`3goOl0o?_o0?omo`3nm_<0gmBn0=W;[P3cool0h?go08:`X`1YVh00anBh0=?T/02DWF@0
cNFK0<GVU`35jYd0gOB^0=3VV`3Djid0e^NP0=3OVP3Ag9P0fnFP0=ONVP3FhZ80dN>W0=C^_`35hKP0
d]o50=KOa038e[<0d>Ba0=C//P3BkJX0cNZW0<k[Z039j:@0aNVQ0=7e[@3?g[D0L7UL05iWC03jo^d0
o_od0?oonP/0oooo000:0?ooo`1T0<cKV01WOc<0cnbL0<[UUP2?Xe/0d]nZ0<cI[P3ionP0o_oh0?on
o@3oo?l0m?oo0:_>dP1nYZP0g_oo0>[oo`000`00J6MC0>;R_03goll0`MJM0=;h[`3=k9h0bNBE0<WS
V@3?jZL0b^:T0<OKYP3=hJh0ho340>[eb`3[m/`0j_;=0>?Zb`3Vk=00i^_=0?;id02<U6<0eNFW0<OL
V`3;j:P0b^N]02=25P37iK<0`>6L0=K/X@2AYEd0b=nG0>Ch/`3DijD0c^>P0=[_[03BgYh0m?nm0<oP
VP39jIh0d^FU09JNI@1LDB@0Xim`0=7QXP3DjjD0aN6D08NVF03<iYd0d>^T0<SYXP3AjJd0oooJ0?Gc
c@3>bZD0dmZV0>?a]026Xe<0c>jH0<[]T`38jI00c>6B07nCCP3FikX0mooV0?;ojP3foOH0/[:`0?ok
n03oo?<0n?o_0?Ook03JiLD0eMo40?7gj@3looP0noon0?coo`3nool0ookj0?ohlP34/:D0^:BI00L0
00@0o`0006H0c^BL0<GZW032ji`0a>fN0<kUW@3:h9D0do2F0<SRR`3<j9@0an:A0<oWV`3?iid0f>bW
0=CTX`3HijH0h^b_0=;QX037iZ00b>ZP0<cZXP3>jJ80cnJP0=STY02AR4l0]:]b09JLG03OjjT0e>2N
0:6ZJ`12C0d0eN6Q0=CSXP1nSTd0W:ET0=kYY`3=fIL0enfU0<7LU@33jI`0a>ZM0<[/W`38gYD0/l1j
07Yl>`3Ag9X0LG14040k6`3BfKX0`]V]0;KQTP3Foj/0`>2D0<k/[P3?k/80S;6@0<CR[P2lfiD0eoV/
0<7WU03BnJP0a>ZQ0<GZY@2jgiT0anbO0<K/U`35jHl0cnjN0<KUV@3:j9h0PiiG0=C^Y`3?hZ00h?2_
0:nkN@3<f9H0cmjK0=CXX`3GlZ/0bNFK0=gg[P36g9<0fnbU0=KWX02:WUH0ZKmf0=S`YP33gi@0d^jS
0=3QV`25QDL0ooo80;oJU@3Pj:d0elND0:B>G03_h:T0dn:O0:B]JP3@fiL0b>^K0<WZV`3<j9/30<gX
V`030<cXV`3:jI/0b^VK0080b^VK06T0c>RM0<oYX03?hk00iOG@0?Wok`3bnO80o?om0?gon@3nooP0
o_om0?coo`3kood0o?om0?ono@3ooO/0oo[h0?olmP3oo_<0ooo/0?ooj`3lonP0nOoM0=KaY034fY40
dNRR0=3[YP1HKS00FEdZ05Hf3@23HC@0IDhJ0<kVVP3:l9d0e_^[0<7TU03BkZ@0d^bS0=C[Y@3=i9h0
V:eZ0=[]Z`2kcX`0HW4^0:nmO`1OJCD0Lh180<OLV@3Ck:P0`N:M0<cd[P2[RV40WgQA08:<C`3?fi/0
en^V0<C[W037k9h0d?6R0<KRU@2W`FP09dDQ0:O3[03?h;<0dN2W0=K[ZP39kj@0aNRD0<_OU`2?Xe`0
aNNK0<c[Y`38hj00cNJR0<oVX033fY80^<j50:2hKP2oehd0cnVO0<[VV`3>kJ40b>RL0<7QV03Dljd0
bNRU0<?RW`3:jJD0`>2E0<o_Y03>k:@0do2]0<CTX@34jYl0aNNJ0<WXVP3El:<0c^JH0<oZV`3=jj40
e?6^0>[ob@3eomH0cN:Z0<cWXP39jId01038jYd0EP36iIT0dNfR0<SNU@3Hk:@0b=bD0<GPV@3=jj<0
bnRH0=3[W03Cjil0aMfA0=;]W037i900a>FD0<g]XP38jJ80c>JY0<cPZ`3>gk80dNJU0=7S/`3?gKX0
mOoT0=[Y`03@gkP0dMk40=;Q]P3=gkD0cn6i0=OT]P3AgJ/0en6T08nJF03Hij80eNJP0<cQW03ElZl0
c^fZ0;JfPP2i/XH0oooY0?omm03no_l0m_Wo0?coo`3nool0moKa0>7Eb@3UdlD0mOWj0?Coo`1QOWT0
L9n=0;[Za031iKT0UjMf0>G^[@3EiYl0bo:S0<SVW03=iid0cNRK0<cXV`3=iid0cnNM0=?TW@2/]g80
e^6O0<cKVP3AjJd0^]RL0<kWYP3AijH0cNNV0<KWXP34j:80bN^O0<SXW03>kId0cnjN0<[aXP3:ljL0
YKNA02`f7@2R[940mOkS0P3lonX;0?ooo`002P3oool07P3Efi/0cnfS0<?/WP34jIT0c^BI0=;HV03R
k;00d>6[0<WO^@3Bh/L0o?oj0?;oo`3Rool0Q;2_0>;oo`3Tool0k_;a00L2003oonX0o_oS0<WO/03H
o;h0bMnO0=_]/@3LkKH0l?oD0?Sog`3ao^00looV0?kok`80oooa04@0oood0?oon03oooP0ooof0?cn
iP38cZX0e^BY0=KYY`3CkZL0a>6N0=7c]`2lgZ40b>ZP0>So^03SnK00e>RP0<7GS`3;iIh0b^FN0<ON
V03IjZH0Jg0`0=WRX@3>jZ00fn^/0<[?U`1@Aa`0/ZYl0=[UZ@36gIL0`NBD08JVFP36fiH0g_F_0<[^
Z03:i:<0g^Nb0=gO[P3If:P0E5/X051M9@2/aH<0c^RQ0<[UV039gIH0UYYX05YP=03?f;T0o?o]0?ko
m03JdM80NVme0?oho03ooOl0o_ok0?con03nooH0o_oh0?con`3koo`0o?oo0?cno@3oood0ookh0?ol
mP1nL6D0glk60?onn0@0o`0006<0fNFU0<O/WP31kY/0_nbI0<gXV`3EiYl0VJYS0:2dK02leXd0c^ZP
0=cj/03MnJl0eN^S0<3AR`2LZF@0Be0>055J5`3?jZ<0c^bT0<g]Y03<jZ80d>6M0>;]Z`1aLc@0aLN8
0<OBT03NkJX0enRR0;oCR`3@iYd0eNnU0<KRU`3;jYh0gN>S0:>_K@34eI40dN^R0;CBR039jih0b>ZM
0<[[W03Dk:00dNNL0<GES01AGQP0fmFU0=37WP012000FG@m0;OTT`3FojX0a=bB096WJ@0aBa/0CWA?
08b[O`37hjP0anBQ0<?PT03]okT0eo2/0=;[ZP2of9L0a^6J0=KbY@3;ii80e>VL0;_?Q`3Vo;<0Qj5H
0=[dZ`3;iIh0cNNP08jUG`0oEQ80dNBR0<_PV`3>jJ80hofd0<CKT`2T^740S9eF0<OKT`3CjJ00c>JL
0<g/X03>lJ40_=n?0<SLU@22QdL0gnBT0=G^ZP34fYX0h<jL0;FIJ@3Me9/0d>6M09ncK03@i9`00P38
ji/20<WZV`H0b^VK04/0b^VI0<cYV@3?jJ00cNB`0>Cfd03hon`0nOoj0?_oo@3nool0oooo0?oon`3o
ooX0o_oj0?oon02f]ZX0oooa0?oojP3nonH0mOcK0=[Y_P3Ai;H0b^F`0<kW[P3?iZ00dNRP0<CUUP2o
hI@0g_Rg0=KOZP3df[L0nM^i0:RBJ`3Fj:X0eO:_0<CRVP3ClJL0a>2F0=OaZ02CZV80C68J0>3c/@3?
gj00fnV/0<C?U@3EhZX0a]NP0=W[[`3CkJH0anFK0<7UW@3>m[00c:Z40=FYQP2JXVL0g^BV0:VeL`37
iId0`MnG0<gUV`3@iIX0f_BC08JVS`3Xool0lokN0;6fS@3Ni[D0a^>Q0<3HRP3?eID0en6T0<o_YP38
jYh0aNFI0<KVVP3=k:000P3?jj007`3Ckj@0cNVN0<WXW03:jYh0bNbL0<7RT@3:ji`0dO6V0<WWW`3<
jZ@0c^bR0=KbY@3?jY/0d>ZP0=3ZX@32gIP0co6W0<[VW03Aiil0bmbF0=[YY03Ll:/0a^6N0;kKV@3:
hjT0d>N_0<_PY@3<ij00b^VM0<WYW@38jYd00P36jid0?P33iIP0cnjR0<CNU03>iY`0dnVP0<kXX@3F
lJX0`mfC0=[bZ03=iIT0a=b@0<?JTP3=i9h0cNFW0<OOY@35gZD0h_7:0?CmhP3iond0h^o30<WF^P3>
fLT0nOod0?WojP3ion`0nOoh0??oh03eon`0mOo^0?_oj03non40eMbX08^CF03Pk:X0f^^U0<WOU`34
i9/0_n2I0?kof03dm=80b<2c0?olnP3hlOP0ooko0?koo`3loo/0n_gf0?olnP33/;80ooom0>W_k@3Z
nOH0HYN707bZSP39k</0_=N/06UR:`3Ee9@0eOnZ0;[LR03<j9/0b^VK0P38ji/06039jY/0d>JN0=7M
V`3=eIT0jO>g0?Sod@3To<80b^JK0<SWU`37jI`0`nbP0<;/X035jYd0`^6C0=7/W@3Cl:00a>VK0;oU
V0002@004AH006]bD@3;eK00gNZo0=;S]P/0oooo000:0?ooo`1O09bWH`3Gmjh0a>ZQ0<;TVP3EiZ00
fN2J0=_XXP34gYL0`N:[0<SS^03foo80lOoo0=Sno`2Rc</0S[Jf0>?oo`3lool0:RDR081iI`3oonP0
cMfh0;gKZ@21TF00aLjS0=3K/@3eomh0nooZ0?_ol@3koo<0o?of0?oon03loOD0o?Wd0?ckm`3ooOX0
oooj0?ook`3LhL<0e^>[0=?VY03Flj<0`^6C0=Gg[@2mgiD0d?2U0<CNU02fcX@0F6hS0<kVVP39j9`0
cNbP0<[QV@3KjZL0CDdA0<W=T037hY/0e^JW0>3U[`1dJd00V91R0=COX`3CjZ@0bNZK08n^HP3;giX0
cN:O0<SWX`3<iJ@0e=fT0=;IX`3GfjP0g^Rc0=KU[P3@iJX0b^2R0=WYZ`3Tk[T0hmo20??ce`3Ee/@0
nOO[0?onn030[kD0GDUB0?odo03onol0o_om0?con`3mo_H0o_oj0?[on`3ioO`0o_oo0?ooo`3oo_l0
0P3oo?H0101PCdD0hM?:0?Sck`3goo@20?l0001T0=;GX@3Hh:@0bNVM0<?^W032kYT0bnRH0=GYX@2A
XF<0QYQJ0=;[Z@3CkZ/0_mfG0<_VW`3Ejj<0en^S0::bJ`2BW5L0W:MR07VDC@1eTd/0SZiU0:c:PP3T
mK40e=nM06AV9`1/KRl0fNBR0<_JU`3;giP0//mo0<c[V`3En:H0b_2M0<W_W03FiJ80`]JA0=[_ZP3B
kZ@0bnVO0<KVVP3<k:00d?6R0<[VV@39i9L0enfR08FEC01gMC`0gMFT07b4D`0Z@`T0bO6X0;kSUP3>
hIl0Oi5G0;[AV`2C^8`0Q:=i07REG`2A[Vh0d>RL0<_PT`35eY80bMVJ0<cOW`3MlZd0cNFK0<cUU03?
giH0g^^U0<7ARP1iSdL0dnZR0=?^Y`30fi@0]]B<07jIE03>jJ@0b^BM0<3JT`2leXd0]<j509nfKP37
giD0fo>Y0<SRV03<j9d0bnZN0<?SU`3Al:@0dNNO0;K1O`3Fgih0cN:O0:2mN`36/7l0[XmP0=gNXP3<
fiP0b=jF0<WPV080b>^K0`39jY/50<[YV`80b^VI06T0c>ZP0<gT/03Tm]00n?o/0?[on@3fnoL0oooo
0?omoP3oo_/0o__f0?oon03`kN@0ko7L0=SL``3Ihkh0k?W=0>?e``3?j:l0bNFZ0<SWZ`3;jJ/0d>NQ
0<_YW`32k9X0_>FF0=;XZ03Ih:d0fLJV07QUA`1_I4@0k_k?0<?LX`3?jZL0an:M0=G_Z037gYH0SjEL
0:NmM03:fiL0g^j_01@R003Vl;/0VjQb0>7e^03FjjX0`MfB0=?bYP3<lZT0_nRR0;FCK@2fRfP0U9iR
0<kHV@2EY640e>fY0=C[Y`3Dj:40c]nH0=7YT@1>KEd0jooo0?coj02m_iP0emf_0<kXZ`3>i9/0kNjd
0:R]M@2lfY@0b^bP0<W[WP38j9`0bNRL0<gYWP3?jj00aNBH0<CSU`3:jYh0bnfP0<OZVP35ii<0b^^J
0<OXV@33hYH0`^6E0;gLSP3DlJ40c^VH0<cWV039i9L0c>RN0<7QV03Ek:P0P9=A06ij?03GhZH0dN2U
0<gWZP3=jJ`0dNf`0<_UZ03AijT0c>NP0<WYW@38jYd00`36jid0?P32i9L0b^ZN0<STV@3:i9X0dn^Q
05Uc:P2bcHH0c>>K0=3WW`3FjZD0bMfH0<gOX@3KkK<0b]ZY0<oP/`3[o=00nooX0?col@3loo@0o?oT
0?_ol@3iooX0nOok0?Wol@3hoo00k_[^0=KT``3goo00n?od0>G_eP34cJh0WZEi07R1C034d900gNjZ
0<WOU`3?kj<0`nFH0<CDY@3oon<0gmc;0?ojm@3jlO80oogm0?oon`3nooP0n?Wc0?olo@3NcmH0ooom
0?koo@3hool0]ngO09Ro[03[onh0bNFm0=C8UP2ZY6P0aO>K0<_[UP3=j9T0b^VK0P38ji/02P39jId0
d>FP0>;a/02LXfd0o?o?0>?c`P3?hk80bNBM0<OVVP36j9`20<C/X`0<0<GWW@3;jIl0cnNK0;gER@3@
l:D0d_J/0:fmT01YLD`0LWQD07IoE00R:`00fN>a2`3oool000X0oooo0200g_2T0<SWX@34ijD0b>2V
0<_EV@3OjY/0b^690<?ZS@2djY`0]>NU0<SVc03]ool0f_cn06^>T03Bm?D0k_oo0>o`m@3onol01`00
0<O5^@3jonl0m?oY0<oA_03nnn`0oooc0?cmm@3cmO00n_km0?[no`3mo_l0o_oo0?ooo`<0ooko03L0
o?[o0?oon`3Yjmd0d]^`0=OV[@31gHT0f_RP0<OZS03;kY@0c^ZO0<KMU@3BjZ00S:MF0:O7LP37ji@0
anZF0=;XW`3Dgid0IE/V09NDG@36gid0h_2e0=gO[@2EREl0PGU;0=GOXP3;h9/0b>NI0<3JT02iaH<0
f^JV0<OMW03AiZD0]/F40>Sg]03kolX0en^^0=_`]`33e:L0fn>n0>?OaP3oo_40oo_o0?olo`3dj^/0
oo[m0?oal`2^TID0Ke9F0?oin`3onod0nooo0?Gnn`3nood0oOon0080o_oo0380oO[o0?oko`3ooOl0
oocj0?W/iP2bY9T0oocd02`];`3good0j_SQ0?koj03Gbj<0imn`0<_RVP38kId0ao6M0<SXT`3AjId0
_L^H08VGHP3:gjH0fO6c0=Gb[`3>k:H0eo6X0;gER`2R]f`0ho>Z0=3RV03>j:40cNRQ0<_YX@3?jZ<0
f>VU0=3KV@2`/W<0`lR80>7]Z`31dXh0e^fU0;oUT039lI/0a>jH0;GOR@2njY<0anVO0;oQU`37iih0
a^BJ0<?QU`80b^VM03/0b>VJ0<S[V`38ji/0bNRJ0=K/X@3HfID0G5PH0=GKW`1OM3T0_]bV0<gU/`3]
mLH0PXYG08VHG`2nhZD084DJ0<?T]`3Jml40VJYV09RSGP3=dhd0hnRU0=cWY@33dXl0en^V0=[^Y`3@
fYD0eMbH08VDC`3Fij40_mF=0<COV03ClJT0a^JM0=Gf[`38jJ80bnVQ0=G[X`2/`WX0_mV@0=3`Y@32
i9P0bNjQ0<O/W`36iY/0d>jT0<kZX02ofI00SJAL0<gTWP34eI40e^2Q0<;OW@2NRUP0GdDD0=OVY@36
dY00dNRP0<g[X@030<K[W@80b>ZM0`39jId0C@3:jId0c>RM0<[YV`38jiT0b^bP0<cT/03Tm]00n?o/
0?konP3hn?H0oogn0?omo`3ooO/0oo[i0<[0_`3oo_@0lOSG0<WI[034hIh0anNL0<OZVP37k9`0b>fP
0<WZX`3;j:D0dNFP0<S]X02ll9d0bOFV0>gg`P3dl<X0M6mK0?cjj`3dnn/0nooa0?3mh@3Fjk<0iO[1
0:o4P@2I[fH0e>VL0>Kh[03KjZL0e>:T04UD702IXWD0JgU60<3LTP3Ckj@0aNNC0<g`WP38lJ<0`NbU
09emEP2LMU40^<J90=SWYP3IjZH0Q9AC0:JeM03Lj:H0f^NR0<gYW`0?<R/0bn[_0>olh03oomd0`l^L
0=cc^`32dY40I64^07MeA03Km;80a>JJ0<O/WP39jih0b>RL0080b>NK00H0c>^O0<g]X@37jI`0a>VK
0<S]W@38jIP20<g]VP0D0=SeX`37i980`=f;0:G0L@2D[f80Rj=E08fUE`26WU80Yl5j0<7AT`3Lijl0
hnNe0;NlT`1bNe00bMn^0>;maP3Nn[d0b>:Q0<cVW@39jIh20<SZW@1K0<K[W@35k9d0aNbM0<CYV`34
iYT0c^jR0<[YW@39iIX0]M660=C`YP1nTe00X[Ee09ZTK`002000WJ5l09FHN@3YkMH0o_o]0?kol@3n
ooH0o_ok0?koo`3loo@0o?oo0?_oo`3cnoh0n?oj0?7mk`3goo40dN>m0=GTa`3OkM@0mooV0?Woh`3_
mm80kOK;06el@`39g9`0fO2X0<;TSP3Cmil0c>N`0>;gcP3Pi/X0ViV40>7Ha`3oon`0oooZ0?Kii03o
oo40lno^0?olo`3oooX0o__f0<74b`15NW@0jOoo0?7oo`3Zoo00bKNC0<RlRP39mIh0a^:=0<cYV@39
jY/0a^^K0<K[W@38jYh0d>FT0<cJW`1eN4d0no_E0=SO`03BgKl0dNZ`0<[YX`34j:00`n^R0<G]Y037
iZ00d>VW0<;EU@3?hZ80bMnN0<gXX`3Ai:`0d^>]0=g[]P1PIc40Kg8k05MB6`0;0?ooo`002P3oool0
6`3CjIH0cnnV0<c/[@3;gJT0hNRb0<oJSP3Hl9X0`NjA0;;aXP2jm;L0hOo]09ji]00mFed0]mKH0=Oc
mP3`ool0o_oo0?olo`0;0@80<2/W0?[kl`3looH0ookd0<Bk]P3ooOX0o?Sg0?ooo`050?koo`0j0?oo
o`3oo_l0oO_o0?cio`3no?l0oooj0=SO_P3Ehk80a]jD0<o[U`35j8`0`nF>0<o[X@3:hIT0d>RN0<KS
T@28ZU@0anjE0<;VS`3<hYT0f^BU065E8`2JU600_M>C0=3KX`3Ui;@0RgmE05aD9P3Ji:L0f_2X0=ch
Z`3AjIl0TIaJ0;6kO03<hJ00dNBR08JGD@3=gYP0en^T0<oXYP3FkkD0mOoM0?ooj03nlNP0j=SI0?ok
o`3ekOP0oo_o0?okn`3ghn80XHF1085UH@3on_@0oo[b0?SonP3eooT0n_ci0?[ln`80ooko0`3ooOl0
K03oo?/0akVf0=W;`P3om>h0If]^0??oo@3hoo@0m?OR0?k^c@3ijl@0cN2P0<WYWP36l9h0anVC0=7Y
V`2gaXl0W:]b0=S^/02jdi40a=nH0<WWW@3ElJH0RZAJ0<CLTP3@i9`0a=R@0<gTWP3=ij00bNNO0<WT
W@3:fiL0iO2^0;JhN@3^lk<0en>Q0=7RWP2;XUX0_n2?0<KYU`3>lIl0bnjL0<;XU@34kJ40^MnD0<O[
X@3:j9h0e_BZ0<CPU@3;jYh0dO:S0<?XV02niI@0c_6Q0<;MT03Tij80XYiN0=OMX@2[_XH0j_oK0=W]
bP3VilD0Viia08ZEG@3:kj`0CgY?0<O]a02cdj80a=NG09j[IP3PiYh0f^2H0=ORWP3Yn[H0bMjK04=H
5@1LJB@0T9]F0;k>Q`3BiYl0iObd0<GPV@3FlJX0`=jF0<[XXP3=j:<0bnFN08JJD`3:h9L0foF[0<GW
V`3>m:L0ao2R0<?YW03;kJ<0anFM0<WPVP3Il:X0Qj5H0=[d[@3EjJ@0c]NH0=O[[01[GRX0WHeI0=KV
Y@1EI240_=J=0=3`Y@D0a^^M0P38jYd0C`39jId0b^VM0<gWW@3<j9/0a^bI0<[/X03<i;00i?K@0?Wo
k03oooX0n_Wg0?oko@3oo?l0iM_J0>3Fe@3onOd0l^gW0?Cnf`3SmL<0]]J;0<S[U`39kIH0c>jJ0<g/
WP3Aj:80d^FS0=GTX@34iYX0^>VH0;oXW03nom40oogO0:VWVP3looP0koW`0>kajP3koo00j_c<0<_N
Y`2_`X00bMfF0<KIRP3:fhd0c=VD0;o;S@16D1/0>3lE05m]?02jfH/0cNbL0<;TT03Dmj<0]n2B0<3[
Y02`Tf/0YX=M0:JfN033ei80c>2K08BDD`2EYF@0bmZG0;2oNP3Bljh0BW=[0=GkoP3Yn]P0o_oJ0;o<
U`32fj80hoJd0=?@V`2VY740aMnH0<KXW034jI/0anVL0<WYW@3:jId00P39j9`06`37ii/0aNNJ0<GZ
W03;l:80c^fQ0=GbXP3=jYP0b>>B09F`H@2A[5d0]lj60<SOV@3?iId0e>ZQ0=;XW`3?iZ80a=:G0=WQ
[P3Vik/0^K^F0;FkU`3VnL`0l_oJ0>3m_@3?jZD0cn^P0<WYW@020<SZW@<0a^^M05P0b>fO0<OYW03;
kJ00bNVM0<KVVP3Hm:T0bnNL0=[_[035eIL0Ff<b00D7003Ui<P0UYF00>OUf03clnL0oooh0?Ghl@3l
o_T0o_om0?gon@3loOl0o?oo0?7io03hood0l?c^0?Coj@37gJl0e>Jl0=OW`P3Xm<h0lO_F0=kY_`3Q
kKl0RI]Q0=;WYP3?jJ00a^RB0<gaU`35ijX0h?c;0>gid`3ko=`0a;fP0;ZdU03el/l0i>[80>oef`3g
n?00ooko0<2m^03oo_X0nOco05Z6R@3Am_`0iooo0>gon@3onM`0`[Z<0;ONS@3Cki/0c>VI0<WZV`36
ji/0aNbM0<K[WP3?iJD0e>6Y09:CJ`3noMh0k>kH0>W^fP3Gk[X0cNbY0<KVX`33jj80aNfT0<OVXP3C
jJT0QI=H06Ab=`3JkZl0aMjL0=W[[@2P/780Tj5T0=;NX03WlK80gnRW2`3oool000X0oooo01/0eO2C
0<obXP37j:<0eNFd0=3CY028V5X0d?6/0;;XW@2[k[P0S<RT06Z8QP2L];H0k_oo0?3oo`3^ool0m?oo
0?ono`3ooOl0_;>h00L11@26Q8L0ooko0?okn`37^KT0ooKf0?omo`3gl_H01@3nool00`3noo/0oooj
0?ono`030?omo`0f0<75]P3lonX0h?6m0<gRY`2X`X40b>FR0<WTX@3@jZ<0amnE0<_SU@2/bGT0dOBR
0;_NSP3CjZ80c=RH05]D801FDah0fNJ^0=OJZ`080`00R7UB09:7FP2ha8@0dNNN0=3_W`36gY@0WJMX
0=SRY@3Plk40e^NS0:JkL03GkZ00b>>F0<_ZY03<jZ`0kO_G0?_mi`3kinP0JEQN0?_oo`3lool0o_oc
0?ook@3oonH0[Z23065B<`3Xhl<0eMZj0>OogP3aon`0noof0?_on03nood0mOGe0P3ooOl01@3jm?P0
o`000?l0003on>l0blBn0080o`000;`0lOcd0?oomP2QS7/0oogS0?;oc@31gJ00co>]0;gLT03>jI`0
Y[ac0=_aZ03Cjid0an:C0<cYV@3;jYX0b^VK09:^I02P^g@0cNJR0=3WX`3@iJ00c^FO0;oJT`3=ij00
d>6M0=3KV@2NXf<0d]RH0=KUXP3Ll:/0Ae`G0=OVY@3?gYd0f>NV09b[JP3KjZT0]MnC0<K_X`2ffY00
c^jS0;oKT@3<j9d0b^VM0<WZV`35k9/0`nfK0<G/W@33hIT0c]>C07ek@03GfJP0g^g40??ok@3hoo<0
ooo/0<[7YP3Khk00c_>^0;O[^P16NT`0c?S70<GSY`3CjJP0d>2E0;k?P@2<XEH0Fg8Z0<_VX@3@kj`0
dnjW0<_WW03=jIh0c>ZP0=;^Y03<iYl0dNRR0<oSWP24Te80cMNH05IQ7`3BgiX0gO6Y0<kVW03<kZ80
aN^N0<;/X02nii/0co2Y0<_VX@3;h9l0cnBQ08jXG`33f9<0fnbX0<kGV03BciP0LgPn0>kh^`2CWEh0
dNFP0<oYX036hYP0_=jB0<_]X@38kJ00bo2S0;_PT`34iYX0`>2E0<OSV@3KlZX0G70Y09R`IP2niI80
bo2S0<SOZ`3/o=L0nOoZ0?oonP3elO00ooco0?oen@2n];<0oocm0?[doP3oood0kO_J0=oc`P35giD0
cnZI0=3YU@2?WE00a/f90=gKXP2VXFX0i>R[0<ONV03=kZT0e^^`03h_4P20JE/0oocl0?coo`3gool0
ooco0?ofk`2Y^H`0]/BA0>?c]03DiIl0e>JJ0=GUVP2DXeh0TImQ0=KSZ`23S5l0//2=0<W/VP38jiL0
`nN@0<CWT`35kZ80_>NR0;ZNM`2LN5@0e^VY08BKE@3?iYh0bn6I0<cRVP3=hi/0dnVQ0<3]ZP14NVd0
/NCM0<OU/@3:h:00YKij0<GZY@3?kZ80fn6S0<36R03<kI`0b>fM0<?XVP36j9/0a^JJ0<OVVP80b>NK
07P0anNK0<W[WP38kIl0_n>I0<[WY@3HlJd0cNBL0<KNTP38giT0dNJU0<OIY@3;fj`0cmn^0<oPZP3>
h:80b=bM0?Coa`3^mL80Zjb40?Ged`3EfkT0c^2f0<GP[@3?k:T0b>JL0<_XV03<kIh0`N>F0<GUV@3;
jil0c^jR0<?UV03AljH0b^bO0<OYW036j9/0bnfP0=?dY@2ee8P0fNj]0<[GW`2n`9T010<008^6L`3o
nnd0oood0?oomP3jo?40hNSH0>S_g@3jonl0o?of0?clnP3nool0o?oo0?Won`3goo80ho[40=C^[`39
gYT0hOF^0=GXYP35eiT0Q9=J09FWK@3@i:D0d>JU0<gWX039j9P0bN^G0<O`Y02nhih0amVO0=WRZ`2M
WVD0KVlc0=[PXP3?gJ80eN>^0>Cbd@3an^D0T8Mn0?gbl03gool0j_oo07^a^`3Pool0m_[o0?olj@2N
Y7h0bN:P0<kXWP3FlZL0a>>G0=go]02efhh0c_>V0<SQW`3Kj[40VYYd0?_gfP3ooo40oood0>[md03S
o<<0e_Bd0<gcZ038k:80`mfL0=;U[@2AVFX08BT00>;b]03;gY`0[L5j0<SLU@3EjJ80eNbT0<KPUP3:
jId;0?ooo`002P3oool0703;j8/0c_6O0<OYW`3Ij[@0gN>c0=CX/`2oiJ`0bOo804b>J01AR740kOoo
0>3an03dool0l_oo0??oo`3hool0o?cl0?ono`3lm_X0QX650040103hl_H0oo[j0?oknP3ono/0oogo
0?chn@3oool20?koo`100?koo@3noo/0o_oj0?oon03oo_l0oogo0?olo`3ooOl0f=WA0?kok`3eom/0
b]b/06ImB@2neid0dNj[0<gWWP3FkJD0cnFL0=7YW`1iUdd0h?jd0=7XY03ChJ<0dM2H05mN:036cY/0
j^Vm01D<002BP5X0[:5d09RTI036gY@0d>nO0=KaY02CWEh0eMnR0=;UX`3:gYT0b]nD0:6hJP30fh`0
aNFL0<k/[03QlLX0l?CK0>kOfP1CAD@0m?of0?7nk@3ionX0nOoP0?[of02SWg80Helb0>?T^03Mj;d0
fOC70>Wof`3honl0nOoa0?comP3joOH0n?Kg0?ono`P0o`000>T0nogh06EAB03onNL0nooM0<7LY`36
j:/0foJa0<ONUP3?iiT0cNRI0<kZUP3Flil0`Mj:0<WYUP3:jI/0]mF;08VTG@3=iZD0c>:Q0=3UX030
ei40b>>L0<cVW`3@hId0gnZX09RMG@3Igil0enRT0;;7PP1EJ2H0a<bA0=oTZP3ZkkD08bP00=3EV`3:
l:D0`nNM0<g_Y@39iid0c^ZP0<cXW@3:jId0bNZK0<G/V`33kI/0aNbM0<[XXP3YkK80BDHA0=?DZP3`
o]X0lOo]0?CokP3ooNT0h]nl0=CLZ@2oij40^>fg01mE902WejD0d?6h0;WFUP3=hiP0`MR:0=?[W@37
hIL0eO>]0;oOW03:k:80b>ZM0<_]X038j9d0bn^P0=K`Z@38gIP0RYID069[;01dMCT0fMjN0=cWX`34
f900fO6W0;gMTP3AmZT0b>jS0<G[X03NoKL0m?o<0=;WYP3?iZ80bN>J0>;c[`33dXl0i>Z/0?7Q[P2?
WF00_=6@0>7WZ@3?hih0goV`0<_UW03AlJH0c>bQ0<_]X@2efXd0doR[0=Oi[@3FmZ/0dnfT05E[8`3I
j:<0_mF<0<C[V03CmJT0aMbX0>?ac@3lon`0m?7/0?omo@3Yh><0o??f0?omn`3kmOL0oogo0?koo`3i
onP0cn2c0=kd[03>hiH0bmb<06I^9@1ADA40GeDP06EI9@2GUe/0h?2_0=?YZ`3=ejD0GdXg0?oel03o
oOl0n__o0?coo`3oo?X0ooka09b/O@35dj00f^Z/0<KGT`3Fj9h0bmfC04]J5@3Di:<0c]bQ0<KBX03G
j;40`nVF0<KYU@39k9P0b^fK0<O]Y03<mK<0RF]709A`C03>hj80UJaT0=?]X`3=i9h0c^FO0<gTX03:
hil0_>b^03=[GP2Zh]L0_n>V0=?^Y`33gi@0a>bS0<KWV03Oj:L0_/V50<7USP35jYX0anVL0<WYW@3:
jId0bnZN0<c[W`3>kJ40c>^O0<OWV`39jih0c_2V0=3Z[@2ldY80d>NQ0=K^Y03EjZL0en^`0<kO]@3C
hKh0c]bh0<gL/@3<gJH0h?Bg0?cod@2^]X<0oooH0>_]b03CfK<0dNBf0=;]]P37i:40bNFK0<_XV03<
kIh0b>RL0=3_X`35i9P0c>^O0<WXW038j9`0_mnC0=7cYP3?lJ@0a^^M0<c_W`3Al:@0`=BE0=SW/03<
cZT01PD00=cG``020?ook`1:0?;fi@3Wk]`0d=g30=SUa`3fon80o?od0?konP3no_`0n_ck0?[onP3i
oo40bn6S0<;LU@3>iIL0b]n@09FZG`28W5D0d^FS0=?XY`3Aj:@0bnBP0<SSW037iYX0anRI0;gTU@3B
mjX0e>VV0=WUY@2JXEh0CUD?0=STVP3@i9d0d>BU0=OX_03Wm]D0XIR90<:g/@3gool0h_Go03MhO02[
g^80o_co0?ook`3<g;D0dNFX0<SRV`2mei00go^a0;SJSP2gg8l0b>fP0=?/ZP3;fYl0EeP`0=cI^P3o
onl0moSZ0?Woh@3/old0joo80<3RUP37jId0eNj/0<_LY@3JhKD0=3X<0<OEVP2GZfH0cNFK0>So]P34
g980an>H0<KRV034i9T;0?ooo`002P3oool01@3<jIT0bnjJ0<3SS`39h9X0dn:W0080o`0001@0CXY^
0=Soo`3Rool0k_Oo0?Olo`3enO`0o_oo0?oon`3oooP0moS`0?oon03no_`0n_[j00d;3P1nN7`0oocj
0?kck`3ooOP0ookk0?_jn080o_om0440o?ok0?kon`3nooX0o_oh0?oon03oool0ooko0?omo`3oo_l0
oood0?3cgP3Bg[X0h>o807F5H038h:h0h_nl0=3/X@2ldH`0e=nU0=kW/P3<fZD0V:Uc0=G[[@3EjJX0
`M2=0>G_/01IER/0a;ND01L4002aVWP0/jIj08RDDP34g900_^6?0<OSUP2IYfT0Tj5S0=;/Y@3Bj:00
dNFM082EBP3Cjil0bNNO0<k]Z@32fj@0dn:g0?Wjf`2;SVl0e^Vk0<SP[P35hZP0aN6T0<[SXP3Ij:L0
/Kem0=gWZP3OkK00dNNY0<cVZ@37gjd0b^2b0??oh03bo><0o_oe0?glm`080?l0000[0=kXj@1QEeP0
oogh0?7oi`3Uomd0k_oS0<oP/`2V]h<0c^fY0<CTV`3=kJ40anJF0<OWU038j9D0^mN:07>?A030fi@0
`=^H0=K_[@3=hI`0IW/f07^ECP24WUL0g>fY0=WTXP2Y[fl0gNJU0;c@R`2J/F/0`=FB0>7T[@3GfZ<0
Hf<]0<;1R`1jMd80X[Ia0=[_ZP34fI@0d^bS0<OSV@39jId0b>ZM0<S[V`020<K[V`3o0<SZW@3Fm:X0
^l2:075]@03ZjL/0Hfi@0=CWa`3=fkP0f=Va0;boT03lom40a^n[0;OXY`34mKd09E@N0<ge`039kkH0
`>6J0=OgZ`3Al:00a^:E0<;NU03<jJH0b>fP0<C[W037kYl0aNNK0<CTV@3Ajj@0aMVD09bWI@3Wjjh0
bLV=0=OLW03Ch9X0en^S0<oUW03?iYh0d^bU0<gVXP3Qn[H0iono0=?/Z`3AjZT0f_>a08>JDP3@i9l0
f^VV0=cGW@1TAAL0[/220=Cc[`22Rd`0cm^I0<gSV`3;iI`0go^a0<_WW@2geh`0bN^O0<OYW@3BlZL0
c>RN07B8@@3Jij80gnRU08NDCP3;kY`0aN>I0<SJZ03QjlP0ooo/0?omnP3llo@0ooco0?Sbm03onoP0
ooom0?Sko`3lool0m?cT0=cV`@1nRDl0Uj1O0=GNV`3cn;H0e]NK0=GBV`3If:00Ngm209jQJ01eLdX0
D4XZ0?okm03on?/0o??h0?ono@3oo?<0[JV>07UkEP3CiJ/0enV_0<cNX03:gId0Z[ek0<gQW00U>000
QiaI0<?FU03Plk<0e>^W0<S]W`3:kId0bNVM0<g]XP3FnKL0fOfo0<j]RP2^R6@0e^^X09>[H@3SoK@0
eNZa0=kc^P3Tn<<0en^h0=;nc@13NWD0[^?K0<?VYP2`bgh0cnbL0;gUW034iiL0dmjL0:6^J03@m9X0
anZH0<[ZWP38ii/0cNNM0<oYW`3>j9h0e_2V0=3ZX037iYX0aNFI0=;`ZP3Cj:l0gO6b086FD@2DZV40
e>JX0>gnbP3conL0n_oc0?KokP3ion/0i_G:0>Gm`@3Fj:X0T9iS0:B]MP3PjK@0eN:/0<cTZ035hZ80
b^RP0<OSV03FkZ80d>bQ0<_WW03IljT0d>ZP0=C/XP39hiT0_m^@0<GQUP3;jil0eONZ0<S]W`31iYH0
aNNJ0=oh]`37f:40KW=;00L8003/kLd0c]:a0?_og@3@hK@0dNNf0=7Y]@3>iJl0dnFc0>K`e`3nooH0
oooh0?ooo@3inoX0lOSX0=W_Y`3<i9X0/LEm06=g;`3EjJ40aM^B0;cDR03?jYd0bNFJ0<gYWP3?jj40
c>ZP0<OWWP36iiH0d_:O0=;VWP3NkJP0aMF<0::gJP3>ii@0c>jJ0<[[W03=ijP0hOJn0?ohf@3dk=D0
mOoh0>Ghm01IZ9D0@81_0?OhlP3honH0go_:0=_]/@39i:40TjQW07:7AP3Bl:P0_^2D0:g?PP3CkJ@0
cn:P0:2TLP3Zjl40oooV0?oojP3]mm80h^o10;W=TP38i9L0anJF0=CYYP3RkkX0a<VQ000905mT>`2M
Zg00[L5j0<WXV037j9T0b>NK0<7LU@3<ij@0foBc00/0oooo000:0?ooo`040<gXX`37kIX0`NN@0<oZ
V@@0o`0001/0f_oo0>7ooP3hn?P0n?Ol0?cloP3oo_l0nOK_0?ool`3hn^`0oOoc0?conP3oood0G5YK
00@0003]i=l0oogh0?onn03ooo/0o_kl0?koo`3lood0o?ok0?kon`3nooX0oooj0?oon`3oool00P3o
o_l0>P3oo_/0ooo]0?Kkg@3Ag[<0c]ja05i_A@3;i:d0/MJ90=gi[P3?hZ00fMf[0<_<XP2j`IP0ZkJ;
0<cTZP3BjjX0eNnU0=GVXP1UG3D0YiAc01L0001K@b40VHYO0:>_K@2R_G00aN^H0<7PU02c`h@0TJ5R
0<[UWP3?iYh0d^JN09>WG`2_`g/0d>^T0<[YX`38i:L0d^Va0?cof033cid0e^Z[0=O`[`35iZ40cNjW
0=7aZ03IkZT0aMBA0=KOX03DgIh0bMRG0=3SX`3:ijL0c>F/0>?dbP3OkLX0oOob0?Sjk`3al^d20?l0
002@09>CT`3oool0o`000?l0002DZ:L0Y[Be07QcN@3oo_l0m?of0>kol@3PoMh0e=nm0;K2W02mgZT0
d_6h0<o_[P31h9`0dO2T0<o[WP3@k9l0I80e0=G_YP3>ij<0dnZV0=[^Z@2BYf80YKmh07ZAB`1iRTH0
c]VG0;k4Q03BfiX0UJUT0:[1N`3JlJd0d=^O0=3JWP17C180eMZP09JIH01gOCd0dmjL0=7PW@3@iil0
a^:H0<SZW@36jid0a^^K0<S[V`39jY/0b^VK0<WVUP2FVf<0ZJIk08j<L`0oBR`0d>Fj0<_MZ`2X[G<0
cmVL0=k`/P35kZX0_nZS0<G^/P1aVV80a^jl0;ONZ@2lhI`0cNnS0<gZVP3Im:L0amfD0<7FT`3:j9h0
a^JJ0<GUV@3:jYl0a>:H0=_e[P3=hYd0f>BR0;_5QP35bH`0iNj]0<kOV031eHd0cN6I0=O[Y03Hk:L0
fnj/0>;e]@3Xo[h0`=RJ0=Oa/P2hdI00Z/1h0=od[`3<fiP0flbE06Q96`2HYVT0]]>@0:6]K@3Zlk80
eN^S0=K`Y`3JlJ/0_=J?0<o]Y@30h9L0eoN^0<k/Y02bc8D0W:eY0<_FU03BeiL0=3l00=GfY@33giD0
f>Rg0>_bd03emn40oogj0?olo@3eko40ooko0?oon`3in_D0n_ck0?_mn03oonX0e]bh06U`>P3?ei/0
gNJU0<cIU03Dh9h0fNNY0=?RX@2MYfP0RHaC089jEP1REd40ooSf0P3ooOl0;03oo_X0lo3O092FJP2d
_XT0c^>R0=O[[03QmKH0f^j_0=ga/P3Dj:T0B5dJ0=3WX@3<hI`0e^bS0<CNU@36jZ00bN^O0<WWW@3A
kjL0koo@0>koe03ohL40k<BQ0<gPWP2M]FT0bN2H0>_kcP3fomX0l_oK0>3`b`3WonL0E8B80:kLfP3C
lKD0Vk5X0<oVV02gfYH0b^RN0=;JWP2Z/g80_n6:0<SYV03;jYh0bNFJ0P3Cjj40NP3?iid0b^:H0<cT
VP3@k:40bNRL0<ORV`38gJ80X;=a0765?@2fbg`0bm^J0?7oc03koo40o?oh0?comP3loo40f>Nn0=Kb
]`36g9/0a=NG08:>D033ci40enNX0<kYY03@kZP0aN>I0<STVP3>iY`0cNNM0<cVW03AjIl0b>2F0<oU
W03@iYd0cnNM0=SbZ02eeHT0cNnR0<gbY039kYh0doRZ0=[c/P3colh0]kjD00460038cjH0e=f`0>[o
aP36h:40c^fZ0=7_/@3<jJT0cN:W0>3]d`3nooH0ooof0?ono`3mo?l0nOca0=7RW02db840XkEk0;c;
U03:g:00e>VX0<cTVP3El:<0cNVL0<o[WP3;jYh0aN>I0<KVW@3Vok<0a=f<0>3aZ`2ocX/0YKUd0=Sb
Z03:jiX0aNfG0<O^V`3?jZD0fo6c0?ghcP3Vh;h0iOSL0=K_fP0[NeP0=GQE0>SbfP3[o<l0c>R^0=S^
[@3<jZ80e^RZ0:bkP02T_gX0c^jS0>Oo^`3Dkj80hOF^0;BlP`2c]hD0nooL0>ode03Li;l0dMf_0>go
``2:YEH0TZeL0=3SX@35dYd0If]602@Y0@2BXV@0c>:I0=C_X033gY40i_nh0<COW03?k:`0_mfQ2`3o
ool000X0oooo00@0dNZ`0<O/W033jY40bnbA103o00000`3Mool0g_cb0?okm0020?ono`0>0?onn`3m
m^`0oooa0?gok@3]m>80noof0?7dk@3UiN<02@<30>[Sg@3mm_00oOSd0?_kn@3moo`20?coo`050?co
o@3nood0o_ok0?ooo@3oool00P3oo_l0JP3oood0oooh0>?Vb@3cnM<0gNVg0=o]^P1dQU@0c>F[0<3W
UP2acH00dnJT0=oM]02UWgd0dm:c0>7W``34fjD0a>6Q0=_l[@33fY80VHUW0:ZCM00F0000U7YI0;6P
M@3Hi:80T:]N0<S^V`35iIT0g>n_0<kQX@35iI`0dN^R0<oSW035eXl0XkA^0<cVW@32h9P0c^fW0<gZ
Z03UnKX0dNBT0<7CR@3EkJ40_nBF0<S_X039kZ40d^VQ0=;SW`1UJb/0PXM70>kc/`3IiZ40bnfQ0<cY
YP3GjkP0d^>i0?cok@3noo@0oooj0>OYj02MWZ00NW]m0?[ko@3nool0f^[W0>Gmo@001@L0RXVA0?ko
o`39g]D0anCB0:[6[`3Bf/80c]Nl0<KV`@2_cjH0_]nZ0<3OY02mfiD0bnNM0<WUV032gY40TJ]Q0<SR
V@3@iil0a=RC082ED03EkjP0d^VS0<kOV`3Qk:X0Jg4a09nXI`3EjJ@0eo6Z0;OARP3MlZl0b]fK0=c[
ZP38e9@0g^RY07Yf>@2^/740io2_0<SNUP3AkJ<20<K[W@2B0<K[V`39jY/0b^VK0<gXV@3ImZ80HVL]
0:2MM01]Je@000L00<gT[03Ml[40]/1g0=OTWP36fiH0`NZT0<oeZP2hg9`0bNnf01Lm3P34j[T0co>c
0;WMU@31g8d0b=nA0>Oi[`2ocX/0_mF=0<cVW033gi@0dNfS0<OSV@2K]Vl05S000:^oNP1IJ2L0hN^/
0<oNV`3Nm:/0iO^b0=ocZ`34dhh0/;aj0=OSY@3<fY`0e^RZ0<WOX@32gZ40O9IE0<OKU03<iYl0c]nK
07YS;`25JCX0^L>70=CZZ@2DYfD0alb<0=O[Y032g9<0_mB?0>Wo^P3@jj@0anFM0;oMU@3<ij00e_2Y
0;:nO03>eiH0hN6S055H502kfXX0f_B[0=7O[P3an=H0m??N0?S^k03oo?d0nO?e0?Kbl`3Vin80o_oj
0?oonP3ino00oooX0:Z/Q`2OXg00gnN/0=OSX`36g9@0cNNN0<7SV@3BlZT0[[mk05II8P2QTWD0elZi
0?Kgn@3_m?X0ooko0?oll`3oonH0d=jS0=S/Y`3Fk:@0b=fJ08jRH`26VUd0MHU>010T003EjjX0eNbV
0=3XWP3<iI@0c>VI0<SYXP39j:80`^2J0<OTX@3Po/80f?W20?oP`03oek@0b]jI0=WaY@1;HQ`0k_SE
0?coiP3konX0lO_R0>gol013JG@0Z<oD0=C[/`2FYF00d^>L0<7OX@3Ikjh0TIAM09FKG`3?k9P0b^JI
0<cXW@3;iI/0ennU0=3VW@34fY420<kTV`1g0=3ZX03:iY/0dnjW0=O][`2K[fP0a=V:0=gcX038fID0
eN>^0>kgiP3hoOL0n?gf0?col`3BhKP0_mfQ0=cg/P3XoKP0dN:L096QFP35fI40dnnT0<o^XP3AkJ<0
hofd0:_1N@28X5H0KXHl0:2fK@3Bj9l0OY9:02a0001eRd80dn^Q0<?RUP39jId0`^BG0<C[VP3?m:H0
e_6^0>oob02d_I001@`00:>/O@3Ij;40bnJQ0<?SU`3CnJH0aNVQ0<KWX03?j:L0iOCG0?komP3lo?@0
oo[n0?kko`3oooX0a=>@0;S9Q@3komd0hNg70=o_`03:gJD0eNnX0<?OU03=jYX0b^VI0<WXVP3=jj40
d_:Y0<CKS@34eXX0amJC0=o][`37h9l0`n:L0<W_XP2ojiH0`nfK0<[XX03@iZD0fmRU08b8F@32e:`0
do?>02ekB`2/l;l0cn6i0<cMYP38hZ40bnVO0<WYWP3Ah:D0i_>k0;7:QP2<ZV00`N:C0<cYV@35fXl0
emnS0<cAV`3am/d0oooO0?[ofP3@ej/0Gfdb0<cUU03?j9D0Y[Ye09bVLP1@E2l07R<00=;RY03:h9D0
d>^L0;cFS030fY<0c^JX0;kFW00O=P802`3oool000X0oooo00D0b^Be0<k`YP3<l9P0c_2A0=[gY`02
0?l0000@00Dm<03PooL0[;n[0=k>]@3@a[d0g]C:0?;Yf03hlMD0i>7209JINP2PYHD0em_20>o`gP3o
oo@03P@507UbK080oooh00@0o?ki0?coo`3kool0nooo0P3nool00`3oool0ooom0?ooo@020?ono`1[
0?ooo@3ooo<0d=V^0=CQZ`2c`hD0c]jP06Af>03Ajj@0_>:;0<;NT@3MkJ`0W9Qb0>KP`03_kmD0o_oV
0>Ooc@3NoL40`nVN0=?/Z037]i<0IE4`01D0002WSfd0jM^^0=WUX`2ZaGP0]mn90<[_W`3EkZ`0bN:P
0=3_X`33gI@0gNbY0<[FUP2AWEd0iOZg0=_e[P3EljT0anJJ0<o/W03Aj9P0a=>00=;UT`34hi<0a>FF
0<[ZW`3;hY`0cmnN0>?WZP2XZV/0Ng/k0;W0NP3@kIT0c^VL0=G[Z`3AiZd0nOoM0?_oiP3lonl0o_om
0:JXY`1=CD/0o_ok0?Son`3XoOH0N9NB05miN03cool0g^g`07fHT`3Ln_80kOoo0?Woo@3enoL0LXEo
0?;onP29XX@0aN2g0<[X[03<jJL0cNVN0<GQU02<YeX0c>BH0=G[X02N[f/0TJEP0<gWWP3@jZ40c^:M
0<kJV02<UEH0h>Z[0=?XX`37hIX0bnNM0<KLT`2>YU`0c^JJ0<?KS`3<i9H0g=JH06a/;02IWU`0g>^X
0<cPV`3<ij000P3:j9h20<cXW@3o0<oWV@3Jl9/0F5/R0>o/``0U90P0NhER0=;YX`1iScd0dN:60=7U
SP3Hlj80`NVP0=3]V`3Sn[@0X;b2035I=0004`00^]jQ0=cl/`3>iiH0[/Ai05IW803Xljl0SYmI0=O]
Y@38gYH0e>^S0<_RVP2>Z640aMnH0:>nM`37iId0_=ZB0=;^Y03DkZ@0en^S0;G6O`2`_7X0XZ9T0=3J
V`3UlkD0aMVJ0=C][02O/g@0//F50<oSW036hYP0g>^X07QJ:031ZgT0d<fF0>C`/P34giP0hnVY0=[a
Z@33hYH0b>:H06=m=031fi@0a^2I0=_f/@3;iIh0TjYR0=CUW`3Mj:H0V9UM09VRH@3:ji`0cNJR0?_o
fP3oonH0KFYI0?onn`3hm?<0o_oo0?Cim@3loo/0nO[d0?gci`3oonl0`;nS04]<:P3Li[80d=jS0>;g
]034iYT0bO:S0<WoZ`2hk9T0`]jD0=SRYP3oon<0ooo]0?;nnP3dool0o_oj0>3Rc@2HWGD0f?:X0<[W
T`3AiYL0e^ZS0<oQY`1ZNdD0d>F]0<gUZ@30g980c^ZM0<OTU036hhl0cNVL0<cX[P3AkK<0ioS40>Oe
a03<i;80b^Fb0=6[Q`23FC<0d=nJ0=7VV`3AhJ00f^720?Omh`3noo<0oooj0>koo@0J=dL0goco0<SH
Y`2Y/g@0d]nJ0=;Z/032eId0EUDU0=gMY`3:gHh0cnFL0=7XX03>iId0aMfC0:FkLP23VDh0a=Z?0:[0
M@1iSdH0OYA;0<oUW@1]Q3h0f>nO0<oWT@3>iHd0e^NP0<gLX`3Xl]T0nood0>kgi03ann80b=b[0<GU
Y039jJ00b>:I0=KZXP2AXEH0dnJG0<OOT@3=j9/0[/Z0082JD`2R^gL0cnVP0<_UV`3CjJ00a=R@0=OX
X@3HjJ80Y;Ya0<OOU@39j9X0c^nP0;oRTP37k9`0cO:R0<SSWP3CjJT0W:]d0<cKY03GjJ/0bN2J0=?e
WP37khl0_nb70<S`VP39kYh0b>FU0=c_d`3loo/0o?kk0?omo`3onol0o?[k0=cU]P36cj80jO3P0?co
n03[n=h0ho?>0<kV[035h9d0b>NI0<SWU`3=k9`0_Mb<09nnKP2FZeh0PI=909R[J@3:gYl0cnf]0<;W
XP35kjD0_^fL0<;_WP36j9`0c>NP08R?C02<STd0eo2_0:_IV01IYFD0XnRY0;_TZP3Ci:00dNJK0<GX
U03<lJ40f^Z/0=ORZ03AiZ<0_]R?09ZfJ@3>jIP0b^6A0=?SW03MjJL0e^BW0<gOY@3EgJ`0fN:]0<oO
WP3OnJ00b>:90<WMUP3>fjD0GVA0000903Dm503FjjP0d>bH0<_^W032i9P0cN^U0<[MYP0_>Pl0n_WK
00/0oooo000:0?ooo`0G0<SV/03:j:00cNRI0=3WU`3?iZ80PjF40;cRc@1=LfP0^<k10<kG`P3ommT0
oog]08f7I@2>RU/0cm2F061P:P3Jg:/0XZ5a08AmD@3Md[80oo7Q00h00025N7800P3ooo@01@3joO@0
o?ok0?_oo@3kood0o_om0080ooom04X0ooof0?ooj`3mo_T0o_oo0?_oo`3^nNT0e>Fh0<_OZP2CYVl0
cN2Y05a^<036gID0aNBD0<_VV@3AiJ00iNji0=KO/02jc:80m?oQ0>Oof03`om`0`=fW0=kb_@3JeZL0
XIQ_01D7001bH3P0XYMY0=GPW02<XeD0aN^D0<ccX03AljT0a^BL0=G[X03Bhi`0g^ZZ0=CNXP3AfZ40
n?o90?coc`3Pl:l0g^nY0=3UVP3EjYd0VJUP04mO603Hk:D0bMnG0<cQW03IkJP0`]>?0=c[Z03>fYP0
RIEC05UV8037dXH0gnZU0<cLV`3=hYd0d>NS0<kSZP3Ei[`0hNCK06]ZIP1kMFL0_;f]0=[ij@33iML0
c?;W0;;Fc02cdlP0G7a_0;cLd@80j_oo09P0IgV708^EX@3hl_@0oooj0?Wok03@h[`0_]^Q0<OWYP38
j9d0bnZN08ZVF`3BjZ00cn>K04aK6P22UTl0b^JI0;kJS@3Fk:@0c=bK09jYK@36e9L0c^FQ0<WUV`3K
lJT0W9QH05eP7@3DjI`0a]n>0<_/U@3Fj9`0U:5I06Ia;03=dI@0jnnd0=GJX03Sjk00eN6S0=C[Y@3@
jj@0bn>I0=[RV@2ETf00fMN^07MkFP31bJ80CehM09ZZG`3DjHh0aMf50=_lY@34jiX0`nFA0=3VW@20
W640>G5H04n;LP2nhZD0dNbO0<KSS`2=[fD0bnbW0<oSW02;ZEl0b>JN0=ObZ`3;hY`0e>VT08NLE`3O
m[00Q:=G0=3bY@2ghHl0coBV0<SRV@3ChYl0R9UE0>Ge]02LTeX0b=^I0<cZY03=iZ80b>VR04Y<3@3Q
hJ40cnFL0>Ce[P3>ei@0JUTQ0>?DW@2QWfH0f^>T0<OQV03FkJD0bn^O0<3VT`3?li`0b^VK092WH`3I
kZ/0bMjM000A0028Y5T0fO>Y0=_b[02KZfd0aMZI0=Ch/03?ij/0oooV0=G?_`3oo_H0oook0?_oo@3e
ood0moom0?_oo`3oo_/0ooSa0?ofk@1NGDP0WJB50=3R/03>i:H0d>NS0<gYWP3<jil0a>RP0;gQU`3H
m:T0b]nL0?[of03non@0nooa0?Sol03lon`0e]fl0;_7V@3KlZh0`=R<0=;ST`2Q[F/0JW550007003F
jK80cnZU0<S/U038k980bN^E0<cVW`3=iJL0e>Vn0=kgd080oooZ09D0cNBj0=SZ^P2YQeT0VgE40=7J
U`3GhZ00CedO0<7DW@3BhKH0mOk[0?Oml`3Pool0RZf_0>[oo`37gJ`0bn2K0<OOT@33hY`0d^^b05eW
<`2OYFT0f^:?0=_/YP3Qn[H0`M^D08bXG@22WU40b^NG0<7LS@3BjI/0c=fF0>;c[01KKbL0c^VJ0<g[
U@39iHh0cNJB0=GYXP3?hJD0i??:0?Woh`3]o]@0dnNf0<WSY03?kj`0`n6K0=S_Z`3Chj80U9eL0=KO
WP33chd0g^fZ09>ZIP38hih0b>JP0<CRVP3Jn:h0b>BJ0<oYX03Cjj40e^jT0<gUV@3<iiX0`N2@0<k_
WP39k9X0b^VI0<c[V`3Ajj40S:IM0<_RWP3DjjD0`mfC0=_hZ03<kI@0`nJ80<gcT03;l900b>bD0<kY
/P3Sm]X0nOoo0?[oo`3nool0oOco0?ShmP3nonl0n__]0;6aY`3fn>d0o?o]0?;mg`3<h:l0dnZb0=?^
Z@3>kJ40_]f=0=gnY`22XdX0c>VG0<SUU@3=k9h0`^6C0<S[V`34jIT0a^fL0<C^W02liY@0coBW0<k`
YP3=gYX0XJiX0<o^WP2jjiX0;Wi103Z8E02hll<0dNNY0=WVX03=j9L0`>^L0=;^Y034f940fO6W0<gU
V`38h9@0amnA0<kUU`2oehT0fO6S0<CQT@3>kId0dNJQ0<_OV03>ii@0b>R50<WYR03CjJ00dn:[0007
00033P00b>:H0<[[T039kiP0`nRJ0<SWX`1]P580NHMT0?Wkk@0;0?ooo`002P3oool06`2nkJL0`nbM
0<K/U`38jiL0a^ZP0;7O/00oKTX043hQ0<W[b02[aIP0f^Jf0?_oj03>hZd0d>VU0<SUT`39iid0dNbY
0=7ZYP3;gYh0d=ZX0?ooi00;1@L0Qgek0?omnP3lmo<0ooom0?7clP020?koo`050?ooo`3oo_l0ooko
0?onn`3ooo<00P3ooOl0<03kooX0d^:n0>?j]02neHd0I7U009Z/O01JJcL0c^:U0=KaY03Ek9`0enbO
09ZZH`3EiZ80d^fX0<3OV@3Cmjl0`n>J0=[aZ@3KkZ`0Wj=`05iK;P0:0`00XYI^0>[R]03LiJ@0ZK]a
0<;TT03FnJL0`N>I0<KXWP3:kId0cNfQ0<KTWP3Bk:/0_=BH0<cTZ02meiP0c^bV0=3`Y`35j9P0`nBE
0<cWX035hi/0SjeU09RfKP2ng9@0anNN0<WYX080_n6G00D0e?J/0;kJT01bP3D0AeLF0<cQW0020?l0
003o0=?^Y`34fjD01@/007=dK01cLEX0m?[F0<o__P3Jml/0j_oN0<;N]@36hKH0Pie`0<OL]@3aon80
moo`0?Cmo03noOl0^9nR0?okm03oonP0l?SC0=7X/03;iJH0bnJO0<kXW`2>Y5`0enJQ0=;QWP33g9P0
`=bB0;kTT@39ki`0eOFZ0=K_[@2=Wf<0jO^o0<3KUP3Gmj`0cnFM05543`2SWV@0e^FP0<gSV03Dlj<0
dnFI0>7]Y@3=e900XIaR05E<5@2MT5`0g]6L0:RMI`1GEQH0Jfh[0=GHU@3]ij/0Yj1b08J3FP3Pi<<0
fMfh08b?FP1aMSH0dmnC0=obX`3CkYl0anJJ0<cQU03ChYl0PIQP04ioH@13N5`0_=ZT0:k5P@33fHh0
d_2Z0=Kc/03MlJT0//Io0=k]ZP3Ii:80h^NW09fOH03ZjZ`0c]2A08bGD`3@giX0b^:H0<oYW`3Aiih0
/L9l0=3WW`2kdX`0/J]_0;oFT02igI<0dNnW0<[`Y@1GDaH0f]BF0=3`Y03=i9`0e>6L065O903TgjD0
Zjmd0>7[[03Hlj`0aNFJ0<_`XP32iI<0bNFA0=odY`2`]WX0YjYa09ZNH`3FhId0fn^T0=7UW@3Hij80
WJEZ0<SAV03Kk;D0l?G<0?ojk`1TBT/0TGIm0?oio`3oo?l0oooo0?ono`3on_l0ooSm08e`H01FA300
fn6o0?3oe03[olP0b^>O0=;/XP3<hiD0aM^@0<gWWP3@k:80cnbJ0<[TVP3?hjP0f^^g0<kK/03_o=40
Z[Z;0=3R[P39gZ<0cnZS0<_VV@2J[f00Q9=B03a36@3EgK@0amZR0<OSV@36kI80a^fD0<KYV@3<hjd0
dNBg0>knh`3_on`0oogd0?ohk03?j;h0e^Ze08M^=P1TBPl0am>A0>Ge]`3@hZ@0cNBP0<CIX@3ion`0
lOc^0;_bm@2A_:/0j?o]0=7Y[`21V5@0d^VQ0<3NUP33h9d0d^FS09RSG`38bh@0l?Vf0>7`[@3Ol:X0
dN^Q0<kZW@36iIL0aNBF0=3_X@36hYL0a^2G0=cf[@36iYX0c>bP0<[XX03;iZ<0d^B`0=3R/P3Ql<T0
mooO0=CX]`30eil0dN^^0<kV]P3gomd0enVi0=?Q[P30bi40VjIZ06Ea;`2JZfL0dNRR0=;]YP33hiX0
c^jS0;gOTP3?kZ80a>2E0=C^Y03Ajj40aMnE0<[TVP38i9L0bNRJ0<KUU`3Ckj80eO2S0;[DR`3Fl:T0
an2L0=;[Y`3;iYl0b>BJ0=KbY@3=jYX0cnbJ0=WdX`3Bk:<0d^Bl0>Kcg`3kool0o?oo0?Sjn@3ooo/0
oooj000o0?chm`3ooOl0i>3O0?oon`3nooH0o?oc0?Soi`3Xn]@0d>Nc0<?KX@3<iJ@0PYaC0:W1M`33
hYH0c>bP0<c]WP30hI80`N:A0<W/VP33i9<0a^NH0<[[W034i9T0bNVP0=7UWP2@XEX0e?>U0<ch[@2H
g:<0B8aK05fKJP3;kk80dnjY0=GdYP2oiYL0a>BI0=G_Y@39h9P0cnFM0<cRVP2?YEd0]/^60=gg[P38
i9T0d_:V0<WYW@38iJ80`=jH0<[[W037kY<0an^C0<kWYP3Ahk<00@/007V5G`37hYd0`^FA0<K/U@3D
mjD0`^6K0>Kic01_OE`0o_of00/0oooo000:0?ooo`0K0;k^Y032kYT0aNfE0<G]U033k9d0c_o802]O
;`005000cO?40:g<T`3?hZX0go;B0;oKZ03:jjH0dORU0<?/WP2oij00a>ZQ0<;OW02me9h0mooT0001
002AR8T0oocm0?S_l03no?l0oOco00@0ooko0P3ooOl0>@3ooOd0oo[o0?olo`3loo40d^:a0<KNRP39
hXh0T:IX086CH`1IJ3d0gNnk0<SRV@39h980b]b@04MD3P3Kk:D0dnfS0=CcY`2mh8h0bn^H0<_SS`3:
g900PXID0:BSM`0A2@00UXYT0<[1UP2`^7`0YkIa0<CQT@3Mo:h0`=jF0;kNU@30iiH0^n:C0<WZX`3G
m[<0`MnO0<_WZP3No;`0`>6J0<CXWP2hghh0e_^[0=3ZX`31g9D0c>NP059]9P34hYX0fON_0<GSV`3>
kZD0_MfD0;cLT`3FlZP0`<f508ZHFP040?l0003o0=KS[P0^;200^kJ`05aF?P3Adj`0aMfO0<CLXP3f
omD0fNfh0<kOZ@2;VV<0e=j/0?oog@3oonH0oood0?cckP2jXId0ooS^0?ooi03oomd0bMbT0<kTY03>
iIl0dNNO096RGP3JiJ<0e>2P0=7VX`3Pn[40dO:Q0<CUU038hYT0dnJV09ZSK03;e9/0jOVh0<cSV`1J
JbL0Qh5=0;k1R03<hIh0`]fF0<SXW03@iY/0c]nH0=_XXP3EfYX0UiMK0>ORZ03_jJl0dlfC0:NSH`1O
GQ/0YjIU09>=D@2RWVl0];:;0:BXQ`39bZP0inNe08:3B@3BfI<0bm^B0=S^Y@3;iI`0c]ZB0;[6R026
Vf<0GHIN01@n6039ikD0amnU0=;VX@3IkZT0bN2J0<cPV03?h9X0e=nM0=WRX@3Adi@0UiMI0=_IW03O
gj40Uj1M0=_XX`37gID0h?J]0=;XW`3Hk:@0d^bR0=C^Y@34`h<0g?>]0=Cf[03?kZP0`^JN05iI7`3N
f9`0d>jT0=CXX@3Hhj40EDlE0;nfO`2_[G@0fMfR0>3`[`3JkjX0eNbT0<7LS`38iI<0cnBI0>;Z[P1B
Ead0CeDI0=SUX03AhiT0dNJK0=CUW`2Y/gL0c]NN0=_W]@3ooml0oo[c0>W?dP0o92d0ooWo0?oko`3o
o_l0oogo0?oio`3onOd0GTdc09^BM@38eJT0amjX0<_ZYP3?kj@0c>^K0<_VU@3CkYl0c^ZO0<;NT@3>
jIP0dNVM0=;WYP38fYh0dn6/0<oPZP27VV80cnFW0<?LVP3Jn:h0`n:D08RPDP2:WE/0ADhQ0<cG[03<
h:D0d>bR0<3TS@3<kid0c>^U0=;U^03XmmH0loo^0?Col`3ooO@0oog]0>3lc03KlkT0K5TO06mK803G
ijH0_=2C0<gUY`3CjZ@0bMjU0?WojP3ioo@0Z^3Z0:kIa@3Pom`0cN>S082EE03;h9d0an6J0<[VW03D
j:00VZMR0?Kj_@3?eY<0d]fH08REC`36g9<0f_BZ0;oKT037ii/0a^RL0<o_Y034i9/0a^JM0<[[Y038
j:D0anFW0<_T[@3OlLT0i_KB0?WoiP3ion@0d>6d0<oS[P3AiZh0dN:n0?Soj03Ymm<0ioK;0=SZ/02^
`880HWH_09neK@3IljX0aMnF0<SVWP39jId0b^bO0<7QU@30gi<0d^bR0<gWW@3Hl:H0c^JL0<KPU`38
i9X0b^JL0<;LTP3<iY`0e>fY0=3YY`3<iJ@0dn^]0=Wa/`3BjZ`0c^NV0<WTX@3;i:00cnBS0=3QZP3D
hL<0h^[K0?WmoP3jnol0oOki0?SglP3oooP0ookm000n0?omo`3Ac=00oO_n0?kon`3nooP0lOgW0>;a
e036ejd0aMJY0<GGY@39fj40e^R/0=Ka[P37iZ00gofc0;gKT@3ClZH0aNBF0=KeY`3<j9d0c^ZP0<cW
X037h9`0dnBP07N8@P37i:40`NRW0;7X/@2^j;D0FI9O0;WUZ038kj`0`N>F0<obXP39iid0bNFK0=7[
Y03GkZP0b]nL0:FjM`2L/G00_=:A0=gf]02og9T0cNZW0<o[/03=jjd0anRQ0;_RS`38kId0`mbR0<7B
Z0001P00Qi9`0<OQXP3?kj<0_n6;0<c]W03@kZH0_]6S06UgE03loo8;0?ooo`002P3oool05`3<j9h0
cNRG0<oXU@3<jID0bNVM0<G[[P1RQe40^MjZ0<cXZ`2@Yf40cMbK0?WojP38gK80aN6T0=GjZP35jj00
_^BK0<gcZ033hY`0b^J/0>Cjd`000P00oOOi0080oo_o00@0ooOo0?olo`3oo?l0oogo0P3oo_l0>`3o
o_d0oogo0?ojo`3om_l0ooco0?ooh`3EhIl0d^R40<;JN03Tm[P0a]JY06EcC`3<gK<0c^:]0<_JX@3I
i:`0Yk1g09jYK`3Om;<0c>JO0=GdYP37hY<0eNRG08RHC`3Yll40hnJk00L30027NUX0bl6M09bOJP38
dY<0dNFM0<cRVP3CiZH0d^NT0=ch[@3CkJ@0dnZV0<CIV037fi`0_LnC0:BhN@3BjJD0b=nI0=gi[P36
gY@0g>RV0=GQW`3GiZ<0dn:O0=3OW02V]g<0aMJB0<KJU@3BiZ40cn>N0<oPVP3DgIX0f>2U00@0o`00
0?l0KUld0:29P@3niN40`jZD08^2F@3:i9/0b^BM0?Soc@3GiZ/0dM^O09bTJ@3Ig:L0oooD0?oog`3o
o>T0d/Vh0;ncW@3oo^40l_W?0<3>W@3CkK00bNJT0<_VX@3=j:<0SJAP0=CWY`3Bh:80jO6e08bGE@3M
kJ@0eNFL0<_AT@1;BQ80_K230>gO/03VgjP0inFX0=;CU`3Hik00eNZa0<KYY`3GokT0f?ni0:gFR02m
iYP0]=f?0<oeZ036jih0e?BY0=7]XP3KljT0b]b@0=g[X03Wlj/0f>>Q0=OU/03Sll@0enO007:1F03L
iKH0hNZe0=o][`3PmK@0aN2M0<?QV`29TTl0d>R^0<g^]@2ZcHd001/00<?]_`31j[h0`]jT0<7GS`3G
kj40aN^N08FQE`3FkJD0d>JN0=_/YP2CY5h0enJS0=WZYP2me900b>6M0<o/Z@36h9T0cMjG0=O^X03?
jY/0amnC0>3SX020SdX0a=^E0<kYYP3<jJL0HEXV0=gFX03<h9/0en2Q0=_IWP3?^HP0WhMG07=M;P1>
?0X0/:M`0>;KY02DSU80e=^H0;k[VP2igi@0`mbK0<_QX@3>hj80aNBH0<_^W03@mJD0`N>F0=;[ZP35
gJ40k_oF0?;ogP3lo?80m>k^0?olo`3oo_l0oooo0?coo@3lool0ooko0?oonP2:S6D0cm^]0=Sf]P3<
lJ/0bO>Q0;KNR038kYT0bNVF0<WVUP3?l:40aNBF05AV702=WE@0g>bS0<kNU@36f8h0Sj=K0>3f[@2g
dHL0dN^R0;?AQ`36i9X0bN>J0<GIVP1IHbl0BU8O0;o=T03:gYT0dN^R0<7JV@3=gjd0o_o]0?[mlP3l
ood0o_ok0?K^h@3UiL/0dNjd0=3YY`2aZFX0T8I90;oAU@38i:X0VKMi0<OMU@3AhjL0eN?20>KbgP2>
`]00dooT0=7ga03;hYX0bMVH09:PHP3Ciil0bN6=0=ccX@3EjJ@0HFdk04eF4`3Lii/0h>bR0<7ES@34
fiD0f_F`0<o`Z`38k:H0`nRR0<O/YP38l:T0`NBT0<cZ]P3Km//0j?oN0?Gol`3goo@0hnoI0=7K`03>
fjl0bmVT0?cofP3noo<0nOoa0?Wok03hon<0bNJV0<_[XP39k9X0d?6P0<kZX03?j:@0lOo80<GUVP3=
lZ80c>bP0=GaYP3=i9`0goJ`0?;o`P3Gk:T0`]NF0<cRX@3AijH0fNn^0=3VY@3:gj@0b]nV0<cP[@00
3000k?kD0?;of`39fK@0d>2k0=7Q_03amm/0o?kY0?oom@3ln?D0oo_l0?omo03oo_P0o_[a0?oomP3o
n_L003P0kNCW0?olo`3mn_l0m??h0?_loP3loo/0o?oh0::YU`3nond0l?KL0=KI_03=cZl0_]6S0=[b
_P36gJD0enjf0<7EVP3MlK@0fN^_0=OV[@3Ei:/0cmbV0=;OZP1SKC00_/V=0=S]`P3;hKX0dNRj0;[H
Y035k[H04E4E0;?c]P3=n;40`Mb=0=?_Y@38ij40cNRS0<SQW@3>i:<0cn>T0=7SY`3AhZ/0e^Vb0=W]
^02odih0c>Jg0<OS/P37iZd0`>>Q0<c/Z`3;gjh0eN6m0085001YK4d0d^>]0=O][080aN2?00@0`mZB
0>oocP3Ji/00k?7M2`3oool000X0oooo05/0f>6P0=SRV`3HhYT0e^>K0=?TX03Cik80320009FWM`3H
hjL0TieH0=oPY03dl]d0d]Jc0<G?VP3Dj:00`=N?0=[aZ`2gcXH0cN6L0>3_^03lon<03P`=0>;Hf@3o
m_`0oO;j0?ceo@3on_l0ooco0?omo`3oo_d0ookk0?oonP3oo_X0oo_o0?oio`3oo?l0oooQ0=KQW`3?
hh@0gO:G0=;QZ02?W700KgiC0=;S]`37fZd0f>Fi0=CM/P3CfJd0WJAh0<[KY`3Nlk/0b>2T0=7UZ03@
gZ40>dT>0>Cb`@34bj403Ph009nDMP35^iP0f=ZX0=oW[03EiZ00eNJR0=WWZ@3=fIT0d=^F0=3KU`3M
iZL0fn6U0=cQY`3^lKP0Zk1f0::[K03Wl:l0f^FP0<WITP3Jm:d0`]bE0;kITP3DkjP0d^fV0;_IT@30
gYH0aN>K0<c/X`31hIP0dO6X0<g[X`39hJ<0c^2R0080o`000?@0emVH08^9F03>`[H0oocc0:2GNP1j
P580_nZR0<C]Z@3]omH0bnVc0<kW/02:XF/0a]RX0?Sog`3ion@0mooa0?_ol@2S[hT0lOoG0<SS[P3F
n;`0/MbG0;k/Y02nk:40`^jS082ZHP38kJP0a^JS0=3VYP26We/0`^:F0<OVV03KkZ`0Y[5e0:NUM03I
ejH0eMRO0=cUYP3Afi`0a]>K0=KZ[`3;j:H0b>NT0<[WY02D]V`0cO6W0<S^X@2bgHd0_NZI0;COS`2n
iI@0c_6Q0=WaX`3EjYd0cn>K0<SWX@2lhj@0`n^_0<gd_`2lhJh0a^>]0<CPYP34i:40`>RQ0<Wg[P31
kj@0Vk9Z0<Oa/P30m;@0boZZ0;SSU02QgJX0V]V^0<;b^038kZ<0ao6M0;G[W@29ZF00aM^C0<[NU`35
fI80Uj]T0=KWX@2ebH@0c>>O0=[c/@37hJ00bMnN0=SSWP3>h9H0bn>G0=;XW@3SiZ<0PXU60>Oc/@3>
hj80b^2P065G9P3Ugj/0cNjW0=O^ZP3:f9X0n?>l0=S>V`2PV6L0emBO0=gQYP38c940QHI:0;W5P`37
l:80doB]0=G[Z`3=hJ80cN2P0=?_Y03@kil0a>FD09FcJ@3CjJ/0c>6X0=?Y^`3bomh0oood0?oonP1b
KVd0ooom0?oon`3nooP0o_oj0?ooo`3oooP0YImm0?7db@2gcHd0cnZS0<gZVP3Cjid0f>jS0<gMUP3G
i9l0_m2:09RWHP38dHh0_/N407R2>`1AGA<0WZaO0<7BQ034eX`0eN^R0<GKT`3BjjL0foB`0>Km^@3G
ijT0U9QU0=KHYP1dO400cm^K0=KVY`3Dhj`0i>c30?ool`3on_H0oogo0?onn`3_i]D0f=Nh0<OQY03A
j:@0YImQ07me>P3BgjT0b^F^0=Cb]P34f940f>N/0=CR`@3Vl]`0Gi6J0:OC^02kh[D0d^^W0=OZZ01Z
NCH0fn^P0=S[V@3?iYP0e>ZY0;G7T`2caG/0_m200=OWW03MlZd0d^RW0<SQX03:iZT0dNna0<WYZ034
i:40`^FQ0<CWY`3=jkT0hO_D0?7oj`3eooH0moof0>Ocg@3BgKd0cmf/0=;OZ@3bnl`0m_CU0?ool`3^
n=d0m_oL0<CUX02nhiD0^n>;0;kTT@32gIP0bn6Q0?Ood@35i9h0c?6S0=CdZ@34h9H0iojh0<7FT`2_
`X00`]FE0=CVZ03Kkk00d>BU0<?GV033eiX0d^F]0<gOZ`39fZh000T00?SoiP3ionP0m?oW0P3iond0
B03moO40ookh0?kimP3nn?P0ookk0?onnP3oo_H0oocd0?onmP2h/:h0fm;C0?gho`3^jo@0ooko0?ko
o`3gnOH0oOoi0>3Re@3[k=h0oooa0?onj`3oon`0nOoT0?Goh`3^omH0iOK<0=CT]`3Ch;80fnNi09bU
N02MY7P0OH9I07EjDP3;d9P0k?Fn0=GVaP3:f;h0gNRn0=c]^@34iJ`0@XM>08gFWP2jjjT0cnNK0=C`
Y@2hf8l0_MRA0=G_Z03BjJD0dNJU0=CVZ00oCQD0c=fW0=7S/@3Fj;H0_M>U0=K]_`2?ZWD0L8iB0<KR
Y`2O[h00IVa800H2002=RVT0c=FP0=_Y[03Djid0dNRJ0>?g/038eZD0i_3;02hc7@/0oooo000:0?oo
o`3o0;N`NP3Yj;00e]VR0=?KZ03JhKD0NX1L04148`2m_iX0[Zal0;BaNP3Hd:40k=_A0>oTb03/j;T0
/[Ue0:6ZI`2CWU`0[[Ue09NMG@2@TV40h=bo00P0002?QH<0g=CB0<2h]P36_L00i]gP0:JPX033_[X0
iN?F0<G7/P2_/IT0i^W<0<g=]@31_[D0_;bb0<O:[@2JX700a<j?0;O2QP2nbJ40PHaT02@d000Z?@00
9ST202Db100G8000<3H:02<Y001LJCd011D0000;0001400000H000<;000030000@`00045000:0@00
<RT:0:>UMP26SUD0Q9=B082<BP1kQDP0O8E6059G5@2@TU<0TI5E06QV:`2LUel0QH1807Me?01UIBT0
GElP07Ml>P2GVEP0OG/n09>?DP26Q4L0RHU;07mm@02h^7X0];Ig05eO802HVU/0d=:C0<36QP2ja8D0
^<270:f/M02HU5L0akeh0=;2Q`2XTFL0TW5Z0=Rf]03J^Z<0IDdY0<?3S`3Bd:00eLRU0>3A/03RcZd0
SGID0=c1Y03gfl<0h/Nd0?gPfP3]clD0c:j80>O;Y01oKCl0Z9YY0<S3R`3FdIT0W9MM0<c7S@2ESUL0
/ZMa0;jdO`2DU5h0Z[1d0<kIU@3;eI00cL^B0=oCX`2OQF00i<RS0;>MKP2`W6X0ZiaU0;ZaN02`Zg40
fmnR09FIG01fM3L0fLNE0:>HHP2PVf40a<j908^HD02jch@0W;5V08^KDP2f_GX0[[1a0:FPIP2o^840
Yj5]09RBGP2WWg40/:=i07EM=`2_UVh0X8]L0:6FH030_7l0VIEE091g?P2SW700WYa/0<RkM`3`gY`0
Y[2>041B>P3Xj/D0e/ZF0>WOY03FfjD0fm6L0=[;U03YgJ<0g]BG0>WOX@1IDA<0GEDG0>gW[@3RfJ80
mN^h09Z>FP3UeJ40e=ZL0=SWY03Ii:00gmjN0:ZPI@3WhJD0io>e0?;j_`1WFRd0`KN60<_GU`3Zk[<0
c/VA0?o[^P3oi;T0Z91T0?GO/03[fJL0h]6M06MC7P1SE1/0iNFW0<>mP`3cgZl0ZiET0:^EH`1_HB80
ZZ5N0>[RX@2SVEh0jmJ[0>3=Y@3Wf;L0oogS0:><Q03on?@0onk^0?oYi`3omO40on;I0?ofk`3om_<0
_ifK0>W3]P3omml0kn:^0?S_]03_iJL0l=nY0?oY^03ig;@0`ZEk0=S0T03@_8X0o?K40=kIXP3Vi:L0
d]>A0=[PV03Pj9l0e]nL0=;MV`3Qjjh0hNbb0<cJW`3KjJ/0e]jS0;VcO`3OeJ00SHI?0>?NYP3HeZD0
oooJ001?0?ooh`3ono<0oo[h0?okn`3ol>/0oO;F0=OE[03=gIh0g>RX0:BKI01KBaX0l>_10<CDY`38
gj/0a]BF0=k/]`3=f;X0i^oL0<[dj00YCSd0d?;J0;_GY03DkJT0[/=d0=;TT03Hj9d0d^JY0<gT[02N
_7`0`NBB0<KXU02ogi<0cnV/0<gT[P1GKCh0GFi206=bA`1NK3T0LGi806]m@@1TOSd0Yl:=09:YO`2I
[I40LhAa07N6K`1/NUH0JgQ:06Ab=`1IIbX0KWI306a[C@1bN5H0JGI806n4B@3>lj<0_>J@0<7[U`3<
lJ@0dnZd05YY?P38e:h0dnZb0<[WY@3>j:T0dNV[03=72P0Q<`00Hg8g0:BcN03@hZP0c^2V0<CHW@3>
hJT0d>>/0=CU/@37ejP0c=^d004<0002000500070003000110001PT200L10`0=10T01P0000d50P02
00H0000303H_9`25OWP0cLG20080oogj03d0;RX[08R6R@3oool0oooo0?KglP3al^`051@<02l[8P0_
:1h0;B<I034T6`0U:A/05b8B02Tb8@022@00B4di02DX4`0^<1/0<2dJ02/X5`0S7@l0;BDJ02XZ101^
Ld/0BE5402DX7@1cK4l0FEXb065eA01c]HL0=h1C0<3b_@38hZ<0a>2F07:BA`2V`WL0e>jT0<WQU`3D
j:00fNZT09VYJP1?Gb40RY]T09RYL`2AWf`0Tj5/09BUKP2U]g/0X:md09>GI02JUVT0X99[0<6dRP2l
^H80]KIj08VDDP1hPT<0IW4e04]D:@1bMeL0UiZ700/0oooo000:0?ooo`0I0=_JY01WKSX0Uj5_049C
:@1[NeH06B@608N=L@3Ef;/0Z:V10:JXN@3Jf:l0mngT0<O2Y@3_k[h0V:AL08fJE@2lbhP0/Kii0;:l
O@3:cIh0moKJ00d42@3YhMh0ookh0?omnP020?olo@3o0?onnP3oooH0ooo]0>obe`3EfkT0gnJm0<oF
[03lonL0ooo_0?coi@3Gg;@0d=RY0>7X_`3Vk=00c=>a0=CSX036fi00dnRW0=WX[@3=f9h0d]VS09nX
L`3Nk;L0_]2L0=[/_03@gk@0Z:b704eE;03Kl[h0cmb`00@:00080@00>C8E0=KHZ@3<did0aMBC0<gL
V@3GhJ80hnf^0:NbKP2d_G`0emfO0>KZ[@3Gf9h0iNJ/0=3DV@3Rj:X0dMZI092KF@2MY640bL>70>;L
X03MfI`0dlnB0>;NX@2h]WT0YJ=V0:2NH@2SXfD0PX940:BVI`2Y/W40XZM_0::SJP2GUEP0/:US0:NK
G`2dXGH0PfAO06M5@`2:Ie<0HTPU0:6OIP2]YW80VX]T0:B@K@3B^Y@0NV4i0;nSOP3A]980ZHia0:jA
P@33Y900R6Ln0:b=H@1VCQh0Ke/X09V<E@2VVF80XiIO0;jaNP1fIc00Y9=O0;>VL@2>SUP0TiQN0:>^
JP2OZ6D0YZ5Y0;BVM`2JP5d0b:b70;2HK03IaI<0YiQQ0:bVJ02JVET0SY=C07Ik>`2TXVD0YhIM06A9
6P2VTUl0XIeN09VJF039dhh0TiiI09bUHP2VYfd0/[5i09bBH@2bY7D0[Yi]0;b^O@2ZUf`0/IYa0;bI
N@27Hd<0`:=k0;FOKP2fZW00/JQW0;6DG02FQEX0T8=G0;ZPI@1aE1P0C4//03Q0:0070P00RGQ<09:0
D021NU00VhIK07QP<01/Eb80SWi308n1A01_HbL0S81406=D6`1GAa<0NfTg07eX>@1SB1d0NGU508fH
GP1IGb40MgLi06IE7@1MDAL0XJe]03]01P2YWfh0Fe@P07n;B`2X[6l0If8Z061<6P1mICL0IDhR081^
?P1gJSD0IEPS08Mf@01PDAP0H5HI05Y64@1dEBL0JDLJ08IV=@1UCA40P6`]09R5BP1SC1P0Sfm907=B
<@28Ke40ES/V0;BGS`2GN7D0on?R0:^2OP2ML6X0[h=j0<jRV@2[Q7l0MTi<0;RAS03ohll0E4HE05iD
6@29OD<0_:Qf08eeB@31X7l0PF0m081U>P2TSf80NFi105E=701IE1`0HElR07Ym>P1HGAX0Mgdm0;o5
Q`3@eI/0UYeW0;BmQP2FX6<0UYYO07Y`>`2/Wf/0XYEQ0;N]N02ITV@0kNFn0?ooh@2UTX<0Y9:80>CG
c`2lYIL0]Jf609JHIP2MZFT0TiaM08EkBP10;@<03P0000hE00035@0000X0000;00033@004AX900DV
4@005@X000/000@S0033h9h0d^fL0:c0J`3BhY/0h_Fn00210;kEW`1ALR/0a>jJ0<W`W`2nhYX0b^F`
0=;W_024U6l0Ef11051G=P1/LDP0Kg9303<l0`1YOS/0H7Lo06^0E@1/Oel0OHme06MjG01RM4@0GFhg
06Yj?01YMcT0CEDR03De3`20Qed0J7I1061f=P33j9P0c?>P0;kTU`32hYl0j_cB0=;M_@3NilX0amZ/
0<[S[03>iJd0c^>[06Ig@@1ZND809C@001XY000P<P00:Cd203=7301OLS/0HG@m01h^000lC1d031P0
0007003monT0loST0?7ciP3nooL0k^oY0=WEe02GTI40^;>]0:n[X03ooo<0_k^`0>CMe`3gkn`0oocj
0?omnP3onoP0n_Ke0?ooo@3hn?H0o?cj0?oonP3fmo40lNkW09:>Q@3km>`0oogd0?oll`3oooP0i^_T
0>O]h`3Uj=d0nog`0?oom03ooo<0knSN0:BMU@2i[jd0`kRf0?C`e@3^km00iNSO0>c[iP3oo^P0i^?2
0>[id02/i;d0GYmg0:oP/@33h:X0foJc0=;`Z03GljT0cNFK0<oUVP39gY<0cn6G0=_/YP2GYfH0b]bN
0=c^/P3?fZ00g>N]0=GSYP3Okk00amFG0=OGX@3QfjT0[Im`0:JHI`29Q4X0[:a^0>O]/@3IgZP0h>Nd
0=SL^@1WJe00oooc00/0oooo000:0?ooo`3o0<kKX`2Y`8X0c^Zi086TO02J_9/0@eU20=[/e03AglH0
cmZh0=cX`03Bg[X0m_W^0?;if03Nk;L0e^jR0<kXW`3>j:40eNnV0=O/Z@3Ehk80o_oX00401036aL00
oooh0?oln03onoP0ookk0?okm@3jn>/0mOSM0>[`cP3IhKP0dn2[0=KUZP3koml0nOoS0?kojP3Jh;h0
j>_>0=3D_@3MhM00hNO;0=k[YP3CiYD0cNFG0=K[X03ChiX0e^:J09JQG03EjJ@0d^NT0=?WZP33dY/0
d]RX04UC8@3@jK80b=RY000700070P00;2L90>KY_03DgJH0gnn^0<cMV@3Ii:80amJC0<WSW01QN3@0
d^FS0<WLVP3MkJ`0fNVX0<;BT@3<gid0d^NT0<CKU@3Bij80LWhl08:>C03Vl[00fNFS0>Gd/@3JjJH0
cMbI0=WZYP3<gIT0UJUT092TG@39h9P0dnVY0=K[ZP3>hY/0e^NI0=_VY03Kgjd0JEmC05=4?@2LR700
Q7]@0<oWV@3?hi`0d=^O0=3HW`3UjJh0VYaM0=OIVP3RiZT0e]^Q0=KL[03ZkKh0^K9k0<6lQ02>SE@0
HVHY0=gXYP3=f9H0d]fK0=[UX`2EX5h0emfO0=OQY03IkK80]<Z<0<cWX03?jJ80eN>V0=7EXP1YHSP0
/ZV00?;/_03ooll0em^N0<CAR@3?h9T0e>VT07>8@`3BhZ40lM6[08E]@@1eHc40e<nE0>c/[03MiZ<0
dmjL0<cFV@3Lh:d0emVZ0<o>XP3Ui[X0e=RV0>7U/P3=cI/0i^:e0>WI]`1cHd40m>Rn0=SGX@3Fgj00
dn2H0>CSXP3Si[40WZ9_0=oIW`2FTEL0S9id092ZQ@002P00/[^<09^QL`2o`ih0fljT0:BBI02JRUL0
clJ;08j8BP2HU5@0eM6A0:6KG`2XWfH0XIAP0;BOLP1eE3<0_KZ?0=7IZ02GVV<0aLV>06YE7P2MS5@0
eNBS09nWJ`2@Re@0EeXQ09nmM@3?iZ80UJAS0:2OI`2ZYg00QHE?09ZOI@2Z]7L0T9YM0;g3P`2:S4/0
HE/M071Q:P25JcX0WX9B0:>7E@1[EaX0ZIYI0;Z[L02COdd0e;ZG0:jAL`2VSW@0W8Ia0>kJd@3mi^00
oo7]0?cGc`3olnT0omoB0>k6^P3E/jX0PV=N0?SUg`3oo^P0TiQR09jWJ03Efid0c<^E0=cEY`33]I80
UXQS09bEI`3Je:@0/ZMj09jFI`2JUf80Z:M^0:Z^L@2:SU40^;j00:fcM`27S580OX==09jVK@14CPl0
Q8Q;06EJ901NCQ/0JETX0:jRLP2ESV80e/jW001/0;fcT028N5h0Q7EN0=WC_@2[UGd0S8YI06Yb=`1^
NSX0DePN06AH;P0Q3@00=b01030`2P1IISP0>dLE041;8@1bNVD0Nh=d05UaF@0K=2h001<>04i`C`37
jJ`0b>VJ05ac8@3?h9`0bM^W0=O/]01YRcl0a?2K0<OaY@32ij@0fO;80>kog`3AgLD0g^7>0=WH``3B
cjh0i>2j05MJ9@35eY80_=6F0<GIZ038f[@0mOoV0>Sme03Cij`0c^>R0=WYZP3Okk40[kV709:HK03M
ikD0cmjU0<OMW@39jil0`^NJ0<GSX`3Ak;D0h>k=0?WojP3EfLP0eNG10=GW_@38fJd0d^:e0;?0TP34
d:00VJIa082?F02<WV@0QIUL08>GFP0D9`002Q/002Le100G90001A0000@<003DfK/0hNG<0=gNcP3n
o_80ooof0;Jf[P3gmnd0VIZ808b;M`2AT7h0`l6b0?onnP3ooOd0oogo0?onn`3oo_P0ookk0?oon`3n
oOT0oook0?oonP3fmnl0ooce065ME03<aKd0oocc0?ofkP3`knX0o_ok0P3oooX0;P3oooP0oO[a0?on
n03ooOX0oock0=76bP2[Wj<0oo_[0?ook@3hmo80ooch0?ojj@3oonP0kOKG0<G^cP1k[Xd0]N>n0;kO
]02nfYl0d^b[0<WRWP3=i9`0dnVP0<_MT@3Nl:@0cMnE0;72O02M/Vl0bMjM0>?_[`32c8d0gNVW0=c[
ZP3Pk:`0f]^O0>GPZ01BA@h0GU4J06m[;P2LW5h0d]:P0>3N]@3Hf;80Z:R>07YlI`3koO8;0?ooo`00
2P3oool0FP0/B@H001<0000G001FRFP0AWIL0=onkP3^ooD0moof0<gJaP32dKX0m?oa0?Con`34gKD0
d_2d0<CZU`2khY<0[=:70=?g[@3Cl:h0c=na0?Ook00000T0o?oo0?Ogm@3hn?H0oogo0?oko`3lnO@0
oooc0?_oi@3WlL`0dn2d0<SNX038i9X0a=fS0<OM[P3domh0o?oQ0?;ehP3oooP0ooko0:n_Y@3IhZd0
dN:L0=C^Y03@j9X0eNZM0=[XV@3SlJ80PiY80=G^V`3Lm:H0fo2U0=gVY@2AWEd0aN6V0=W[^@002000
10<007AdDP1HH2l0dn2X0;_@R`3Bj:00`mN?0=gcZ`3DmJh0bnZT08jYHP3:iIh0f?:[0;oITP3Ajj@0
d>^T0<_YX`3<jjD0`mjI0=GQW`3Qk:X0b]FC06Ea;`3Pk:X0fnZW0=KUXP3MkZX0d^>O0>;c[`3=g9L0
V9mI0<_CU`80o`0003L0d>NG0<oPW03GhJd09A/B05e8A`3F]ZL0WHiU0<[cU`35ji@0a^:G0<GOU@3=
i9H0K8@`0<cYS`33hHL0a^RA0<_aWP3Gmj/0dN:L0>3a[@1iSTT0c^FM0<;NU035hiT0c^bR0<g[X@28
YU`0aN6F0=O^Z03mom40RiUN0=KVY@3GijH0f>2W0>?Q/@1>@1/0FT`W0>7FZ@3onLL0l?Jj0<gbY02b
fhl0_nZS08^eL`32j:/0gNJk0=GO[@3Fhjd0d>2R0=3PX@3?hJ<0c=jR0=7R[0002P0000L0008000D0
0<l0c]Vi0<WE/@001`000`@00?oojP1jLUd0j^_<0?cog03XoL@0bo2S0<g/X02GYV<0XJYa0=GP]P3?
h;H0_=^R0=3d]P1EODP0CgA;0=?`dP3`n^80o_oQ0=3LZP35e9d0cNJR0<CRV03Gn:T0^mb=0<KPUP3=
i9h0hO6`0<C4TP1XBCL0m_KN0?7lfP3TkL00bMZT0::BGP3IcI<0bNNM0=3TW`3GijH0fnnZ08^OF02H
YF00e]bL0>ORZ03Ie9`0Si=H0=CLX03Hj:L0g>fY0;[7PP3Gj:40b^JI0=O]Y@3CgIh0d]^L0=SQX03;
fi80cMnE0<OJVP38ej00oooQ0?ooiP3oon`0nOc[0=oYgP3[mN`0o?oh0?oml@3oo>d0ooKU0:JEQ@3M
eLP0ooof0??on@3_onX0`NRU0<C_X02mhiH0b^RX04=N9`34fZ`0c>Bb0:_;S03<iZD0g=nX0=KKX`3D
gJ@0c]VO0=OUZ039ei`0gnf_0=OSY@3DgYl0f^>R0=OSX@3:fiD0gNRV0>cV[03djK<0i]V/0>7J[P3M
gk00Si5O05YM:03Si:P0e=ZN0=OV[`3Yi:d0e^^P0<GQU035fYT0fN>^07agE`0?0000Ne]40>o[aP2l
ai`0aLnZ0=GN`@3bn>`0nooj0?ool@3[n_D0c^OS000?0033l<T0^^F_0<o]Y`2ebXL0f^f]0=g`/03?
jZD0d_>/0<c[/03GlL80mOo]0?SmmP3oood0oogm0??/iP3RgLL0d<^]0>GW]@2OZVH0f>J[0<SFX`3:
fJh0dNBf0=CY/@36h9H0c>BH0<kRY`3@h;40g>O90=;N^P3>fk00c]fb0<gN/@3@hkD0f^fo0=7Q_@3K
iLX0oood0?_kl`3jnOD0o_of0?com03lonl0o_o]0<K=[P2W[hX0f>Bd0=7OZP3?iJD0aMjL0<oXY03?
h:X0fnVh0<[HY@3IiK<0WZQf00080038cJ@0inW40=CC]@3oonL0o?OQ0?coi03ZnM80gnk30<ODZ@3d
oN00m?WU0?ooo`3ooOl0oo_o0?omnP3oooH0ookk0?ono`3ooOh0oooo0?ooo@3ooo/00P3oooX0=@3S
g]P0^[6/040g<P1PG540>CLZ0=cJc@3ooo<0ooc`0?_gj`3jlnT0ooOd0?olnP3oo?l0oo_o0?khnP2X
Xj00oogf0?onm03oooP0l?7Y0?Wll`3ioo@0d^?@07JIP@1APFT0^]Ba0<gO]@3>gZd0Sj1Y06Ie>P3A
h9/0fN^Q0<gRU`3?i9T0cNBL0<cSW@30dXP0G6`Q04eO5@2;XET0am^F0<gFT`3Gg9X0e]FD0=kMW@39
dY<0f>JY0?7/cP0:000020000?oom03oo?D0ooom00/0oooo000:0?ooo`0I07^FC`1iWf80EX9?045b
E01PSGH0k_ok0?;on03hooD0o?od0?_om03eoo@0ioO]0<gV_02kfI/0dONT0<K]W03PokP0b^ZQ0=Wa
/`3gom`0j_?N0000303fn_d0n?cm0?cmo`020?omo`0n0?ono03nooL0o?oZ0?_oh`3aom@0f_:d0<k^
X`33hJ<0eO2k0<OH[03komd0oOo[0?oon03:am00^;Jg0?kofP3Ok;@0b>:S0=;XY`3GjZP0cMfF0>;b
Z@1WOS00c^VH0<GMS`3<hIH0eMnJ09VUH`35hJ@0^<bG00@A00031000L71>0:niQ`2@Wf@0bnFL0=kf
[033fI00fNnW0=G`Z`37h9`0Ykih07nDC`2Y_GP0gO6/0=O/Y`3?iZ00b^>O0<cWXP3DkJT0a]FB0=?R
W`3Hij@0a]NC09b]J@3>hYd0d^JQ0=;WXP39gYT0e>VT0=7PV`2LWEL40?l0001k0=K]Y`3Bh:d09adD
08A_KP3_cL40K5Xf0<_cV`38jiT0c>NP0<cVW`2AYe`0_MB20=3^U03>ki@0c_:H0;CNR034jIT0c^BL
0;cBRP29XeX0e_:X0=KdZP35iIX0a^JK0=7aY@2L_700a>>E0=3WW`3_m/80U9mU0=[ZZ@3Ei:<0jo2h
0>WW]`2QTfh0iMNb04i66019@a40CE0G0;gGT03Fm:h0`NBT0<GWZ`1ZQUD0goC905I/>`3Cj;00Wk5e
08bLGP2c`HH0f>F_01<L002OY8@0TYIo0:NYV`3FfLh0OXIa07R1IP2j_j40l>kE0<k2]P2XVi80lO3K
0?coh`3OmL@0`nVN0<?ZV`2U/Vd0fMjT0=ORa03DjLX0iOo40;kOVP32kKD0?6Q40;_La`3loo<0o?oT
05QX=`2`aHd0^MZE0=co]`31jiT0a>^H0=3cX`3Onk40dnZT0<K:V02LOW<0oooa0?Ook03[n<d0dNZc
0:>HHP3ekk<0]M^>0=WeZ`3;iid0`MfC0<oOV02CW5T0WjAR0:6LHP1SHBH0^/240=[VYP37g9L0`mVA
0=7UW@3BjYh0c?>P0<KVVP3Bij80cN6L0=_/YP3Omj/0e?2S0=;_[@3On;l0mooS0?Cnh`3cm>H0o?oh
0080mOoo05T0k_Wc0?omm@3oo?40>bPJ07YZG@3oo_@0n?Wa0>KcjP3don`0^=fG0;gWU@38kIl0bnRV
08RQJ03=hk@0bn>_0=_k^03Eljd0e^:R0<gKW@3Lk[00d>BW0=CZ[03Bj:X0cN:Q0<7ET03Fij40ho2X
0<KHSP3KlZX0fnZU0=?AUP3Gd9T0a;f?09ZGK039d9d0TYeU09>OG`3?fXh0eNJH0<WTW@3Ef9<0c^^G
0<O_U`3=iZ@0b]RU06MVB00=0000^i^60?oof@3lomd0o?oV0?cok03looX0o?om0?K_i`3hoo/0l?om
07j[U`11LUD0V<JO0<[Y[@3FkJT0QII?07V:A035fi/0a=jM0=S^_@3^omX0o?oh0?gmo@3nnOl0m>gd
0?omo@29QW<0WIan0=KJZ037d8l0^LB:0?;nc03bom<0hO?10<SMXP3?jY/0d^fN0?7ocP3hon40nOoc
0?KojP020?SoiP0b0?CohP3ionH0joSJ0?cok@3noo<0oooj0?omnP3oo_d0ooom0?Oim03`l^L0loGW
0?koj@3oon@0eN:d0=WZ]03KlK40c^VT0<;MUP3/oLH0dMn/0>?a_034dI`0EUlZ00<;003FfJX0f=V_
0??`c@3jmmH0Wiam0?Coe`3`om<0`mRP0=c^^P3Gh/00o?o_0?_lo`3no?l0ooco0?onn`3ooo@0nO?c
0?Wbn@3ooOl0ooko0?gmo@3inOT0ooom0?oon`3oo_/20?omnP0b0?khjP3oond0cL^f09FCOP3oo^/0
ooo_0?ool@3oo_H0oogj0?SblP3`in`0oogo0?Oam@3/h]P0o_K[0?Smn@3kool0moSj0?_hk`3[kMl0
j?of00m4=03SoN@0i_?E0=o[``2U/X@0a=:M0:ZiN03DiIl0cN6I0=;XW`3EkjH0an6J0=kcYP3Gk9d0
aM^@0=SbZ`33fY@0eNBO0<oJUP3Kh9d0h>NT0>Kf^03EjZl0YZ2805=5>P2PThX0n?3]0?okn`3bl?<;
0?ooo`002P3oool06@3NkZ<0bN6S0<_X/P34iLH0h?cU0?WonP3oooX0oo_h0?okn@3on?L0oOcj0?co
o@3:f[<0c>:T0<o]U`38iI<0bnFN0=K/[03Uk/40oooU0?oom00600d0m?Cl0?Wlo`3gmol00P3ooOl0
?P3mo?l0ooom0?GljP3Ul=80f>O00<_TZ`33iil0`^FQ0<cZ[03Gk;<0aM>N0?goi03ooo<0b<;<0?[h
o@3ioN@0i>k;0<gR^`3]omD0iOK:0=CP[P2f`hd0a]ZK0=;YY@3>iJ40bMfH0=STY02@X5l0^M>D0=CX
]@002@0000H0071hD@39fZ<0]LV:0:6kM03Aj:80d^>L0=7PV`3MijP0d=ZK0=oXY`2nahH0gnRW09BM
G02EWUd0RIAB0:F_L02d`800SIeL0<c/X`37iIl0bnZV0<SWX`38ij40Z/b20<3UV032j9/0d?JY0<7Z
WP3CljP0e^:H103o0000o`3IoKd0fOC702d^9P2KT8h0ooWZ06AG=`39iZ@0dN^/0<[PXP3BiZL0BelJ
0=7UW@3<iiP0anND0<[[VP3<lj@0`^NJ0=K^Y026X5L0eO6W0<?QU`32hYL0b^ZO0=3_X`34hiL0TZiQ
0<cXV`3?jJ80i_W20:k1R@3>i:H0g_:e0>Wh`@3UkK`0UI]]0<W?X@3<eil0d=jS0=KNX`18>`L0SXAA
0=[FYP3Zi[T0L6Q30>OkbP0Y>@X0d=j]0>K]^@3>dIX0gMZW040i3`2<OV40oo_a0?odl03on_X0oogo
0?ooo@3nooX0`;^g0=S@cP3/gN@0oo[o0?oomP3ionT0gNo70<S]ZP33jj80e^6M0;g0R`3kooH0m?ok
0>kob02ofHl0_>R[01917`3TooX0nOoc0?coiP3Oj;d0Yk>10=c`/@39hYh0a^JJ0<CWU`33hY80dNbO
0=o_Z02BUF00`jjM0?comP3eoo<0jOcL0<7N/03MhjL0KWLd0;cZTP2lhXl0anfP0;oUV031g8d0cN>H
0>?eZ`3Hj:40b=ND0=3ZX`2[bH40Y<Ij0<?XV`32hYH0cnnS0<SXW@3CkJH0cn2J0=OVX@3>gYL0d>FJ
0=kdZ`3EjJh0e^Jg0?Woi@3oo^`0ooCe0?oko`3imo`0no[o0?omo`1FATH0JeIC0?oel03on?@0ooch
0?omn03ooN/0oooM0=WUW@3IiiP0f>:M0=_NZ@3Mf[40QGiQ092<J@3IgZP0XZa_0<SMVP2icX/0l_o:
0?;oc039jZ<0anRQ0<_YW`36hYD0c^JH0<[MS03@iIH0c>ZP0=ccZ`21S4X0TIUM0=CKY`3Khk80fNNb
0=KX[03;giP0dnN@0=?]U031jI<0eN^H0<?/T031l9@0bnbW0=;Y/`1YM58010<007i]D@2IX7L0MXMK
0;_:Z`3DhLL0o?oc0?com03imO80o?od0=?TdP28[9h0g_om000[6@2oi[L0aNFR0=7XUP3@iiT0^m2E
07J9DP3Uk<<0oooS0?oik@3oo_X0o?Si0>KQi`3ooOl0oooc0?7cg@3lom`0dmjV09ROJ`3Bf:X0e]fd
08RCJ@2^_Xd0d^bU0=3/X@3Fj[L0looS0??mo03^o_40kooV0=GUb03Mjm40koK^0?koo@3gm_80ooof
0?ool`3oo_@0ooKj0?oko`3fkoL0oooo0?gonP3ion<0o_oO0:jjR03=fjH0b^2R0<_VX`39jIh0koo>
0?Cod`3GiZ/0e^BW0=SSZ`002@00YJai0::YMP2MXFl0inZk0;^nT@3Jl;00aN>K0=G`[@36gZ80j_[E
0?7mi`3nool0ooko0?Wdn`00?`3dkn/0oo[^0?oho@3onOl0o_So0?olo`3oo_l0n?Wm0?cmo`3nool0
n_[l0?gko03ln_/0n__L0?Khd03<cZH0gMnh0:RYQ`2f]iP0`lJ[0<31[`3mo_00loC/0?oonP3ooOl0
ooco0<g1]@3Abk/0nooo0?Ono`3knol0n^[Z0?olm03^ooT0h_oo00l]8`0dBcT0V;2F0:VnW`3ChKd0
S91M09>KG`3Dkj80^mb=0=;bZ@36gi/0bnJG0=KcX@3@k9l0do6[0<CSW`3=j:<0d]jN0>Ga/@37eiT0
g_G105YdA@14?S80_:b/0?g_k`3onol0ooco0?kko`0;0?ooo`002P3oool05P3Aii@0dNRR0=7Y[`38
hKX0h?GF0?Wol@3joo80ooof0?ono@3onOl0o?Wo0?Woo`3Cj;l0a^2Q0<gbT`3<lI@0bNRR0<[U[P3/
nMd0nOo`0=_MdP0400020?ono`100?ooo`3oo_l0oooo0?cko`3oool0oOoc0?Gmi@3/m]@0b]nW0<_/
Y@36j9h0bnVS0<kPY03CgJT0o?cP0?ook`3FeM00oooh0?cok03UlLd0d^Bd0>7d_03SmK/0eN>X08bJ
G@3EhjD0bm^J0=S/Y`3;giX0d^JQ08fQG03AiZD0e^Vk000900045`00EF`n0<cWY034gYL0/L>5082;
D@2OXfH0g^>S0=OXY03?h9`0dnBP0=;VX@3?hih0e^^V0;_@R`3PmK00a]^F0=K[YP3<hIh0Y;Uf0:o1
P`3AhjT0d^BZ0=;VZ@2AYV40I7`b0<?RTP3?l:40]mb?0=CdZ@@0o`0003T0bnR^0>Wof03hoo40B3m0
09f;R`3on>H0B3LI0<kW/039hjH0eNnV0<COT02C[e/0c^ZF0<SUT`3<ji/0doBU0<CWU@3>kj00cn^Q
08BRFP39jJ00`^BJ0<CVW03AljT0eO>Y0<_WW@1BK2<0g?:Z0<gRW`3gomH0XkB00=OO[P3]ll<0j>jn
0=KN[@2IYg80amRQ0<SMW03EjZL0d=nN07Eb>`1dLcX0gN>W0=3HW02c_H00RiEH0:R`O`001`00e]nZ
0=7KWP2U[WD0@DLI0?ooj03oo_d0oogo0?okn03jn_X00P3oo_l20?ojo`350?ogo`3oo?l0o_od0?Wo
jP3Lk/H0c^b`0=;a]@36fYl0/KbA0?Wmo03kool0kooC0<GMW`34l;D03CdE07faS@37l/D0e_K70=OY
^@2a_h`0dMnT0<oRXP3<kZ80`>VJ0<C^VP35jiH0g_FU09RTHP3OfkD0o?o/0?_ol`3aon/0m?oX0<oT
X`1/QC@0aNZ=0<?US`38iJ<0bNJT0<WTT`3Jlj80a=f<0=?ZW036g9<0c>>K0=[aZ@2E[6H0R9eH0<WM
V03;h9l0dNJ[0<cPX`3AhYh0e^JO0=?SVP3IiYh0bMJA0=gU/P3@ejh0ooo/0?oml@3omoT0ooWk0?oc
l`3=`/00U8V50=O:`P3]hmT0oooa0?onk`3jo^l0fN790<kPYP3=hI`0dNVC0<oWT`3Ah:L0jO?@0?7f
hP3oooX0mOG[0?SkgP3EfK@0i^bn0:VcO`3Ikjl0b^FP0<GVU`34iiD0cNZJ0=C/WP38gI80SIQD09>R
G`35h9d0eo6Z0=;XW`3CjJ00d^FS0=?UZ@0`?`P0d]nW0=3KW`1OJB@0Lh<j0;oPT@3Dkj00aNJE0<S[
V`3:j:80dN^/05]_?0002P00l?_A0=KW^`3Om/P0d^g20<cS^@2P[hH0OX]P0>Gnj@3loo@0inWN05MR
FP3Too@0Q[6M09kAYP2oj[@0c>fV0<SZWP31jJ80a>:^0<K8X03oomP0l^[30?;fd@3NjLT0o?of0=WD
d03omO80o_G/0?GohP3:fjh0`/bH059E:00k=QH0ooo_0;6`W03YnlL0c^VR0<oTZ@3fon00n?cm0?Oo
mP3Qn<@0e>V^0=7U/03ioo/0mo_o0?ooo`3gnN40o_[D0?ooh`3;^kh0ooOk0?oio`3moOl0nOom0=c_
`@3UnKX0W:]Z0<oIY03Nl;`0`mfP0;oQU@3domd0h?G:0=K]Y`3?iI`0U:=/0009003IiKd0bMJX0=W[
/@3colT0iOJo0=;/Y@3?jj00c>JW0<WPZP3Sl]40noo]0?;ck@3oo_/0ooOe0:BESP3Oc/@00P3onol2
0?olo`0i0?ono`3oool0o?go0?gno`3lool0nooo0?coo`3iomP0cnBS0<SJWP3Hj[00l_k>0?Koe`3l
on40o?o/0?_ok`3`nn/0n?of0?oon03fknL0ooka0>OQe@3oooX0ooom0?gko03on_/0ookk0?coo`3g
ool002<F03U/F@2WhLT0hoof0<SO``3NdJL0YIaS0;?KPP2omYP0`o2O0=KYZ@37hiH0b^^J0=7]XP3>
i:<0anBR0<k[Z@3AcYL0eMFS0>3Z^00f@Al0<S`S0:2IT@3gkN/0oock0?olo`3onol0ooco00/0oooo
000:0?ooo`0<0<oXU@3<iYd0cnZW0<[R/03Ejkd0h_C>0>Ofe@3kon`0oooj0?_ioP3ooOl0nOoo0P3o
00002@37ji<0b>bE0<WWZ@3GlL@0lok`0?conP3Yj^D010000?omo`020?ono`0S0?ooo@3oool0ooko
0?ooo`3nooP0o_o_0?goi`3Eik<0`nBM0<_^WP38ii/0e>NU0=WV[P3fn]L0n?_P0?kok03Sjm<0n?oS
0=7R]P34fJ00gO:a0=_^[P3BhZ<0Tj=R0=CSXP3BhZ40d^JQ0<[NU`3<hi/0R9aE0=cRYP3Cf;0041H0
01@S101WNT`00P38hYT06@3Hk:l0enRa0<_GU`3Ql:/0TjMR09FZI@35fYD0d^VS0=?ZY03@ij40f_B]
0<cVW`37gYP0cNBN0<ONUP2[`gT0`mZF0=3TZ@3>hZL0cn>V0=cc[@3<i9P0c^^I0<SYV03AljH0103o
0000=P39iYH0`MFT0?WojP3moo<0Q7If08QaJ`3ifL00P6]<0>Oid`3Ci[P0`=NC0=G`X`3LnJL0TZmO
0<g[X@3;jJ40cNfT0<_[X037iYX0TZaU0;C?R036i9`0dO6X0=3`Y`3;jj80_mfE0=kh/@1jTD/0i?Rc
0<?HU`3Ik[H0moo@0>c_`02Z[7d0OH1A0=CKZ01nSE80ambK0=;YX@3BjZ00d^JO09^NI@1`MC/0c]NN
0=3NX`3BhJP0TXm`0?[fjP3kn?40GF1?03<i7@1RK4X0o?o]0>c^j`80oogo00@0oook0?oon03nnoH0
ookm0P3oo?l09`3jm?H0oooj0?kok03_nmL0gNg00<OJXP3Bi:X0c]Z/0?Kmf`3XjMT0oooc0?_ojP3e
on<0`^Zf0;[/^@15Od`0^OBn0;_T[03<hJP0a=>H08nHF@3JiZ@0a^:G0=?cY`34iYX0bNBM0=OUY`1K
HRh0oooR0?ook03Sjm<0h_7B0>_me@32fj40i_nn08fWGP2:Y5/0bn6P0=[_[0020<gSVP3I0=[bZ03@
iYh0`mVA0<cRVP3FjjH0cN2N0=_[ZP34e9<0g>n_0<_QX`3Fk:`0c>6L0=GYY03EiZ80QHmB05aS;@1g
NE@0OWeQ06iXFP1LE4T0KEiG06EDC@2bX9`0gm3;0?o`k@3oo?P0ookh0?cnl`3ko_<0lok^0=?Qb03:
iZT0c^VR0<WUT03>jYH0c^:W0>;abP3donL0n_oe0?WokP3non40l?O=0;c4T`30bYD0dNRT0<[VV`2n
hX/0`>:<0<;MSP3?hi/0gNb[0<kAW02JWV/0i?W10=K[/P3<iJ<0eo6Z0=?/Z03;hJ00;3h20=k]/P3?
fYh0LWdk06Eb;@37hiT0cNVN0<cXW@3:iY/0c>RN0>Go^@1@JbP001400=7Z/03DkK<0^LjC0=OSX@3F
hIl0h^RX0>O][@3In>P0iOW]0=_VgP3koo/02AH<09Z_X01nYhD0BGQ<0=CoaP3CoKd0eoZh0=cn`P3L
jZl0ooo:0;fmO`3FgZD0am2Q0?kok`2l]k40oocm0?_cl@3ioo40i?OI0>kfc`3oomd0ooWR0?olnP3j
mNl0dN2e0=?/ZP3<hZ@0nOoO0?koo@3goo40dnjY0<cXV`3:i9d0joWZ0?Soo`3am_00k_CB0>KV/03H
eJ`0oo_j0=6n^P3?_kl0nocn0?Son03=iJ/0b>2F0:JcJ`2PYg40nooI0?Kod`2edhd0l_oT0=ogd`3?
j:@0b>2F0:6dO@003P00`M6Z0<KJY@38hYT0cn^N0<WUV`3Im:l0cnRW0=7X/03Pm/D0m_oR0?SoiP3n
on`0l??N0?ooj`2g/I/0_K:N0?onnP3oo_l0ooom0?oon`3oooH0o_od0?col@3`mnD0noo_0?Cmj03e
onT0mOoM0=7X/P3GjkH0d^Ja0=3QZ`3JjkD0T:5[09Z]M@36fJ40c>BX0<GMX@3ooo40oogk0?S`kP3l
mo@0j^CT0?omo@3cknh0ooko0>o]kP3oo_l0kng^09Z?U`2Y/K@0B9F107kH_P2Kj//0amVc0=WEYP2d
]g80h?:V0<?YWP3Pokd0bNjP0<S[V@39iI/0dnFY0=?[/@3?j[<0oNk50>GP^03Kh[T0N7mP0;NiX@3f
mN<0oooa0?ool`3oooH0oooj0?gln00;0?ooo`002P3oool02`3<jIL0b^JL0<cYYP39iJ/0bnJa0=3V
]`3GjKl0kogJ0?komP3kno/0o_co00@0o`0004P0bn^O0<WT[@3Wo=D0nOoh0?koo@2i^KL010000?om
o`3oo_l0ooom0?oon`3oood0oooo0?gmo`3looH0o_oa0?kojP3Ahk40aNJQ0<W/W034hiD0enbW0=GU
Y`3mom/0E5Xh0?CmgP3Cg[`0eNJl0=;V/`3EkJl0`MNF0=;WYP3FjJT0RIaJ0<gMW03BiZ40dnRS0<gS
V`32g9<0PYI?0>_Z/@3CdJ/0108002P_401TL400g?:Z0=G/Y02neYP0b^:V0<;LT`3;hiT0dnNR0<GJ
U@1@IB00<4D006Qm>03@iJ00a]^F0=CYY035fYD0QIYE04mV7P33hY80d>bR0<OPW`3:hZ@0dNV[0;;<
Q@2H]6T0_mj>0<k_X038jZ040?l0000l0=C^Y03?hK40n?oW0?ool`3onoP0]9jC0?oXc@1eGSl0nOoX
0>gle@3BiZT0g_F_0;kHSP2nf8l0eO2[0<KSX036iJ40cNfT0<o]Y@2:XE/0a=jG0<oZX`3AkjL0b^RP
0<cZXP32gIH0a^2I0>;i/`35fYD0d^NT0<KKXP3=gZL0d]VV0>7U/`2MXFh010/008fKGP2_`X00f_:X
0<gUV@3@i9`0`lR>08^CFP39dIh0nOoC09:OL`0W8AD0ooOo0?oko`3oo_l0mOO/0>kbh@3looP0o_oo
0?gko`3ooOl0n_[`0?Kdi@3ooo00oOW]0P3oo_H0g@3ooo<0jNSF0>ofe@3lomd0nooJ0<cNY03<fYd0
nOkF0?OkfP3;c:d0oooT0>kfg`3gond0^Mjb0;GV[`3Bom00^_2n0;oV[@3Ll[@0g>b]09>MF03Pk:@0
enfR0<WTU`3=j:<0c>2Q0=CHYP1lO5H0];JP0?kok03NilX0kOkB0?Oog039h:`0^M2J0<;GWP3Ejjd0
01D00<OMU@33f9<0dNJQ0=S]Z03TnKH0]/^80=O/Y`3?i9l0f^f[0<GHUP3FjJL0b=fH0<kYXP3Bk:D0
cNBN0=CYYP3Ik:`0e=jZ0<[BX`3ko=d0oooZ0?onm03on_40oo_]0?oml@3on_@0ooGb0?okn`3oo?d0
ooWj0?oon`3nooX0moob0=WWd03El;/0eNn`0<ORT@3>jYH0cnFU0?3odP3aom/0nooZ0>oie`3aoL/0
_/^E0<WGW03@hZ@0cNVN0<GTU031iHh0anVE0<OOU@3IjJP0fnJZ06m/?`2SY7X0f^Vn0=KX^03Bijh0
`=RJ0;oHU`3=hj<000d00=OYZ`3MkJh0i?6/0<oPVP3:iIh0bNFK0<kZW`3;ii`0d>bQ0;SDR@3JmZ`0
b^FN0<oZY`3<iZD0d>VU0<oRT`3@h9D0e>6L0=gYY`3Qo?<0OYV@07F<Q03ao?H0T9F?0004002jek/0
b?;<000D0025/7X0an:[0<KUZ@3>hj00c=^F09FLF@1LHBT0G68d09ZIQ`3km_80ooko0?omoP3looP0
n?oa0?[ohP3moN<0ook]0?olnP3oooH0`m:W0=K/[03=hJH0nooO0?conP3gon`0d^fV0<k[V`39iI/0
h?;L0?KooP3kooH0lOOA0<oBV`2MW700oocf0?oll`2eZ:00o_ok0?Som03?i:/0c>6L0=GPW035c9H0
fN:e0<kOZ`39hZ00l_oV0=ged`3=j:D0bN>J0:JjQ@002P00f>^n0<_PY@3AkYh0bNVF0;kMS@3<i:H0
dNR`0?;oe@3eomX0hoS=0=GW_`3Jj<@0c=Jd0=gT``3oon@0oooP0?gol@3jooH0n_od0?[olP3jond0
n_oZ0>ObdP3=f;H0i?3<0=kZ`P3;f[40`=BQ0<WMZ03Ej;40cN2Y09RZL00mCaD0c=jR0<OLV`3JlJd0
b^FN0=C`YP3noo40jN3U0080ooco00@0d/c>0;Zd]P3oo_l0ooko0P3oood07@3jnOL0oo3n0?3Rk`1;
SH4097eW02b5J@3;l<h0dMVb05MF7@3Fg9`0cnZU0<g/Z@30iID0bNbJ0=7]X`3?hJL0d>N_0>[odP3o
o]`0em6]03<g4P3^mM<0e]^k0?ooj03konD0n_kU0?Smi`3nonl0o_oc00/0oooo000:0?ooo`0;0<WY
W@36j9`0anVO0<OXX@36iYd0bNNQ0<SQX03Hjk@0mooU0?[nl03oo_l0103o0000303<h:/0c]jj0>cj
h@3dn?L0ooko05iIG`040080oogo0?ono`3oood0oook0?ooo@80oooo03/0oOoi0?kom03mon`0c]nc
0<KTY039jih0bnbM0<3JT02M/Vd0d^6Z0;_9UP3Jk;X0c^:]0<;JW03Wol00l_o<0<3KV03@jJL0dnZV
0;G<R03AiZ40e>^U0<WSVP3:i9/0d_2V0;cBRP1UH2T0T8QS00l5000:0@00;b/009ZQGP2MZVD0e_2a
0<_[ZP2iiI00_^RB0=;WXP37g9L0fNfX0=__ZP2fbXD0dnBP0>Gf/P3>gi/0c=^H0;K7P`3<hYT0`NV@
0<CZU`35i:40b>BW0<_TZP3AjZT0b>6O0<ORW@2`bXT0b>BY0<oX[`020?l0000I0:JjN`3IkK80f^K0
0?kok03ooo<0ooK`0?SMdP31Wh@0_::70?col`3lon`0n?oE0=7SZ@1:Ga`0`mVH0<GOX039hj80dNj/
0<CSW@37hY/0_/n;0=SYY@3AiZ40a]fG0<gWX0020<oYXP1V04eW8031f980fo:/0<gTX036fY/0h_Jg
09n]LP1fOdH0b<fC0<kDV027T4l0]L9m0=CYWP3>i9T0g_2V09^SI`1ZLC/0g^Bn0?[oh@3noo<0GeEC
0?W^o`3onOl0o?Co0?ono`3oooX0o_om0?_jo`3oo_l0l?3X0;>dTP2NX7T0QXMM09ZKL@21PUH0T95U
09VLK@25S5T0]l6<0=CQZ`3DhjX0enFZ0<G?TP2[[8@0d]>[0=CFU`3NhZD0l??P0?_onP3Qn]d0anRi
0=[oc@1MQUX0<ePR0<WSY03Ek:P0f^ZO0<GCQ02>XE00RieA0=CPXP3Hgj/0in6o0:BNQP3ooo<0logR
0=k]a03:gJD0c>2[0=g^bP3_o]l0enG40>Shb`3<gY@0c=jB0:6cM`2GZFd0e>JX0=?VYP39g9`0c=nM
0>?g/P3:hIT0dNRP08bVG02edX80c>nE0<OYU@3BkJP0bN6U0<OKZ03[m]H0noo[0?knlP3oo?<0oogj
0?ojlP3oond0oooc0?ohmP3mm?T0ooKo0P3onol0_P3oo_l0nocf0?col`3ionl0jooJ0=_f`@3;ii`0
b^NE0<oWW@3<hZ40f>ba0<WJYP2]_8D0[l1l0=S/Y02nfh/0a>BA0=ChX@33jI80aNRD0<7PTP3AhjD0
f^B`0=KI[P3omm`0oooX0?Cih`3lon`0KgeJ04aM<`0kD1P01al00=G_Z03GkZH0b=nG0>?i/036gIL0
c>JW0<[TX`3=j:<0c^VR0<STV@3=jI`0b^NG0=SeY@3<j9/0d^jQ0<g/W031k900ao6K0;gXX`39mKX0
@5mR0<Wcl@3Nool0m?oo0?glnP3OeM<0;38T0>kol`37l]@0N9en05=T@P3=iZl0`>RQ0<S]Y`3Hk:l0
hN>d0>;I^03omN`0ookk0?Cio03io?l0ooko0?_oo03nooP0oooh0?onn03mn?@0oooc0;W6V`3<gJH0
c=fW0?_og`3LiM00d^Bl0<g/WP3<k9L0b>RE0=gcc03eonl0n?oY0>Kb`P3Rj[40]KR;0?ool`3on>T0
j>3C0?ool`3iond0e>Be0<oNY@30bI80k_C60?Kje@24Rf40X:aj0?Coi03NnM00a^>P0<kYY03=i;00
01<00<WP[02mf9D0`nB=0=7dVP3;kIT0jOc?0?3og03[oM<0goG60=C]]03?jk00f?Fe0=;/[`3<iZT0
cnJ^0<SLY`3;h;L0bmnj0<_P]`3;h;D0cN6`0<gQ[P3EjJh0b]bN0=;UY@38g9@0dNJK0=7VV@2^`gH0
XK=Y09RZH03=gYP0d^>O0=GXYP3?iJD0dnb[0=Kc/`2cdI<0M7I[0;^b]`2>QHX0T8Z>0<O1``3ooOl0
ZJFT0?ooo@3noO/0oOch0?oon`3oloh0ooWo0;k?eP3Oo_l0h_oo07BSS`1QSVl0]]^X0:_8SP2]^7`0
hnN/0=;^X@38jIX0b>:I0>?b^`3`om<0mOoT0?okiP1jL5D0P8AS0:jgRP2ja980c=nW0<CIX@38gJD0
bmn^0=?V^03TmlX;0?ooo`002P3oool03038jYh0a^^N0<CYW035jY`0b>^K0<_ZVP38i9T0dnVX0>Oc
c`3Zl]d0o_oo0?gno`80o`000P3RlLP02`3TlML0l?WX0?OhnP3ooOl0R8>:00@0103ooOl0ooko0?oo
o@3oooX0oook0080oooo03X0o_ok0?komP3monh0dN:h0<WWZ@38jYd0cNjO0<3KS02W_gD0bMfN0=S/
/@3Hl;H0an6T0=Gc[@3>k:@0cnjX0<WWX@3?jZD0_MJB0:FlMP3@ij40dnZT0<_WW@3=jIh0do:V0<kU
W@29RU40PGeG018;0018?Ad0E4`M09:BDP1MHb<0a]^P0<o][@35lIX0coZQ0=[aZ`3Kl:/0c>2K0<3A
S@2_`7`0cmjK0=7PW@3Wm[<0^/J40=[YYP3Aiih0_^J>0<O/WP3Fl[L0d^^d0=?W]03=gj/0fnjg0>Gh
`@3Di[@0fNbo0P3o0000O`3HiKT0]<BC0=WY_03?f;/0nok]0?oomP3on_H0ooW_0:f=MP38/9P0m_[[
0?Wni`3/n<X0eNB[08RMFP38gYd0eo6`0<WSXP37i:40c>bS0=?^Y`2ib8D0h>n/0=7RWP3?hih0d>NQ
0=cc[@2B[6D0NI=<0=K`Z@3=ij00c>>M0=_`[`32eiH0Pi=D09FSI@3Igj40i>R[05QM7@2V[FX0aMN=
0>Wn/`33f8d0LG/l06ig?P3Pi/80ooo/0>c]i@1eK5/0ooco0?cdo`3nn?l0ookl0>g_hP3oooH0j^WW
0?onm`3oonl0VIa]09fTL@29T5X0VZ9Y08fEF@2JY6D0UImP0:6]K@37eiP0fN^]0<_OX037fId0fnV/
08F=FP3FgJL0dMV@0=SOV@3UjM80o?oh0?Ool`3Qmm40`]f`0:2oT`1GNDL0^]VN0=7^[03<hiD0f>jL
07R;>@1;GPd0a<j?0=CIX`3AbjL0^;BG0?[ok@3gonH0kOkD0=3R[P33eJD0kOcM0?Wok03konP0nooM
0<_JU@3HjJ80PI5C0:fmO`33di@0gnn^0<KFU@3>hY/0d^JN0<cTVP2B[F00ZlQh0<c/U`3<lI80c?2H
0<o/Z@3Bjk@0dnFk0?KojP3loo@0no[e0?onn`3ono`0ooch0?onl@3ooOL00P3onol0<03on_l0oo_o
0?gfoP3ooo/0nO_^0?cojP3ionH0e^g10<[S[03>j9h0c>NH0=C/X03@ij40e>ZY0:JiP@1`PTP0c=nM
0<gSVP39ji@0cO6I0<_bV@31ii00c>fN0<gYW`3JjK80d=N[0<g:Z@3nlN00d/Jh0?Ogj`3moo406B49
0>Scd`2]`Hh0MHe?0<oYX032g980hO^a0<OQU`3BjjL0g_Fo0>;i`@3QnK/0h?Vg0<[TV`37hIL0cNRK
0=?^X@80dnjO0300bNBE0<gVU@34h9H0]mjW0<Oea`12Jg40g_oo0=_oo`3bool0n?Sh0>kTh`1YJV80
QIF80=?bh02Xa;D0?4hh07N<H@20ZFd0M:9T0;SBXP3XjLL0n^kF0?ofl@3blNd0n?oo0?Woo`3hloX0
o_oo0?_kn`3oood0ookm0?onm@3oonl0dMba0=?Q[03?gJ`0nooO0<SE^@32f:T0dO2P0<k_V03;jiH0
goO70??ohP3UmM00gN^f0:beOP2_]HT20?ool@0P0=K@a03ooo<0o_o_0>;]a@36dZ@0e]fa0<_@Z03m
on00WJ5n07b3FP3`om/0fOO30<WWW`3:iY`0b^6]000;003Om/80bNBQ0<k^V@3<kYP0_mnC0>Ogd`3e
onP0l_oL0>3fa@36hj<0_mjH0<W[W`2nh9H0a^RN0<_YZ@34h:<30<cY[`0j0<gY[P3?jJ`0d>RZ0=7X
Y03@iJ00dnVQ0=;WVP3OlZ<0bMb;09V/F`3>gi40g>bQ0=;QW03:fiL0e^VY0<3FV03;hjL0Tjme06b9
D@052000D4U307=[J01]J6@0QX5m0?[el@39aL80oook0?Gdl03oood0oOcj0?ono`3[jNh0ZZ:_0?ol
o`3Tjo<0dOOZ0:CI_@22^hP0eoo=055K7`3/iZX0e>bP0<SYVP39hiX0joS30?Cof03`on<0j=7306IK
A@29SF`0OhaG0>Wg^P3AjZH0cnfW0<k[Z03<iZL0cNNZ0<oX[P/0oooo000:0?ooo`0;0<_]X`37jIl0
b^bP0<O]VP3?mIh0aNR<0<_/U@3:iiL0cMn[0=GS_`3looH00P3oool0B@3nooX0o?oa0?col@3looP0
o_ok0?ono`3ooOl0d/cF00@01@3ooOl0ooom0?oon`3oooX0oook0?knoP3oool0o_oo0?kon`3io?40
k?[I0=Sa^P35hi/0cNbN0<SUT`38hi80cNNP0<cWXP3:j:80b^RP0<WZV@38jiT0bnfS0<7PVP35hid0
a^6J0;SBR`3DkZD0aMnF0<KRU`38ii/0bn^O0<KVV`36fYd0f^Ni0006003IeZd0h]bX09jHG01UHbX0
i>bm0=CR[@31h900d_:M0=7XXP3AiZ40[[mk0:>bK`3NjZP0dmjL0:JaK`2BWU`0/L1m0=?TX03DjJ@0
a=nH0<oWZ@3ioml0l_gM0?kojP3oon`0fmg50?ooj03oond0103o0000C03CflH0o?oc0?kon@3oood0
oogo0?o^l03onOH0`:BH0;>MS`3[l=`0o_oV0=3MY`3BhZ<0c>:G08JLD`33gI@0b^JL0=[fZ`3;jYX0
c>NH0:6`K@3JjJH0e>FQ0<kOV`3<hI`0QIYE0=?ZY03<iYl0d>ZS0=;]YP3:i9d0SJ=K096XHP3HkjT0
d>JN0=SQX03MgIl0KFT/09jLH@2GXF@0UjMX01/^002ha880eN2V0>7Wa@3io>L0ookj0:2LN@3oo?80
oo[j0?ono`3oooH0oooa0?colP3oood0l>oZ0?ool@2MXg<0fnR`0<cOW@3Ll:/0cNFG0=SaX034hHd0
cnbH0<SWV@3=jj40cNfT0<OUY@3;iZl0bnJI0=?]UP1nTCl0ioJa0:bcQ`3Df;L20?ool@0Z0?ooj01A
GBl0Af<m08ZaQ02lhjh0dON^0;_NSP3@k9L0d>RD0<_KT02g`h40U9eT096KJ@3DhkX0nOoT0=cZa`3E
hl80a=6c0?_ojP3lonP0fNBl0<oK[@1oS5@0/l640<kRV`38fI<0g^nY0=[ZX`3Chi`0H78X0<CIS03<
iI@0dNbK0<c/V@3<kYP0bo2C0<c^VP3=jJl0h?O=0?Coj`3ioo/0o?oo0`3ooOl0aP3oo_l0nOWk0?on
o`3oo?l0oO[o0?olo`3ooOl0nOSc0?_oi`3SkLP0dN:[0<gQYP3:hZP0cnFU0<WPV03Bj9l0cN:M0=S/
[@2ndYL0d^:c0>Kfa`3/o<d0dNJ]0;;FO`3IoJH0`NBB0<OZVP37iIl0k?o60<S@Z@2XZ8`0e<fk091n
NP3IalL0ooco0?ono`16Ad40o?oa0=?V^@3?ij/0c>VI0<SXU@34hi<0do6Y0>;n`@3Qll/0i_S>0=oc
`P3Rm/40a=ZL0=G[Z`31f980eNbV0<oVWP3=i9`0c^JH0<?PQP38jIP0]>:T09kBX@2_l>`0;EiK04=Z
I`3aool0koki0?Soo@3moO/0n?Ce014E602U/;80k_oo05iZGP1EN680OjfC0;CEa02h_kL0oock0?oj
n`3jnOD0j??]0?Woo`3nmoh0ooco0?omo`3kn_l0o_oo0?[oj@3`mmH0hNZk0<kGZ03DgkD0m?kI0:Zi
TP2J/GT0f_NW0<k/UP33i8d0hO^j0=[c^P3=gjd0d>6Z0>3Z^03Tj/@0moGY0?oonP3im_40ookb0?[k
k@3Ef<D0dmS20>K/dP3nonP0oooV0>GUb`3Pg/L0c^JZ0;WIS@3<kIH0^MJ60:VoSP003000a=ZY0<oY
ZP3=jj40c>^U0;kKX@3SlML0looW0=CV_P3=i;00d_:W0<CWU@2miH`0aNfE0<O_V@33jI`0bNnT0<kd
W`2khXT0_^6=0<g^W`31g9D0cnZU0=O][03@i:D0`]BF0<kNW`3=fid0Uj=e0=3K/@3LiKX0d]^^03Do
3@002P003Qd00<KJW@3Gl:l0[<^50;oNV03oomX0ookK0?ooh`3mo=h0P7iY0?onk@3ooo<0K6]V0450
?P3oo_l0n_Sm0?_lm`3jnO@0oock0<c2``3bk^l000D0000800003@00b>Fg0<kXY`22W5<0c>fN0;kO
T03Aj:00a]6G0=k/^`3Ah<40U7M_00/0003oon@0Q9AF0=7RV`37jI<0a^bE0<O]V038ji/0bN^N0<OY
W@/0oooo000:0?ooo`0;0<OWWP39jJ00bNVP0<_^W032iXl0bNb@0<c_U@38j9D0bMjU0<oR]03joo00
0P3oool0B@3oood0o_oh0?kon03koOP0n_ci0?ono`3`kO@0IEmY00l:4@3ooOl0ooom0?oonP3oooP0
oooj0?gmo@3oool0o_oo0?koo@3mooL0looR0=_b_P3@jjH0b^JK0<SUT@3FlJ00c>RN0<[XX039jJ00
bNVN0<S[U`38jiT0`^BH0<_ZY03<jZ@0`mjG0:S2N@1kUD`0eNnV0=C`Y@3:jId0a^JJ0<W[W`3Bkjl0
dnVh0009002n`940K6/c0:JQI`3[iK40oooM0=ON/P3DjYl0b^>@0=;YX`2kchX0N8M40>Oc/@3CgY`0
IG0^096LFP3NkJX0e^NS0=GZY@3<hI`0b^2P0=OX/P1hPF80b/fh0?Sij`3ooo@0knSN0?onm03ooOD0
103o0000N@3RiMh0oOoj0?ooo`3eloP0ooco0?GVj`3olo<0WhJ108inL@3/mMX0f>:m0<oNX`3KkjX0
bN2@069j;03CkZ40bNBG0<_WVP3Flil0c>NF0=3QW@3Oljh0f>bW0<WMV02V^WD0JWlj0=?ZY03;iIh0
d>ZS0=KaZP35giP0Vk5X0=7[XP2nfY00c^FM0=WRX@3HeYT0Ie`V05]D7P2DVfD0PI1G0=_]/@3;eiT0
gNNb0<K;Z`3oond0oooj0:6MNP3oo_@0oogm0?OemP3[k>@0m_[[0?kon03^ko40oooo09bLU03EfkD0
cmjW0=3UY031f9@0a^:E0=?`X03?lId0bNbH0<_^WP3;kJ00bnfS0<SXY`3@k[P0c_2J0=3bT`36ghh0
QIQF08F@F02f_8`0m_7M0?gci`3oo^`0P8=F0:k8Y@2oj;h0T;Z80;COVP37l:@0a>B?0=7ZUP3;gXl0
jo^b0=7UX03?hJ<0d>:`0??og@3WmM@0dM_30>ohh`3fon@0o?oV0=?N/`3<f:P0//6:0=o_/@3Wo;40
fo2U0<OIS`36eXd0C5TA0;o?QP3SmJ/0amnC0=?^X@3<jid0aNJE0<g_V`3<jZ00cnNe0>3dd@3aon/0
nooo0?coo`3oo_l00`3ooOl0ZP3no_l0oogo0?omo`3ooOl0mO;i0?oonP3io>/0lOcD0=g[^03Cj:D0
c^FO0=ca/03>hj00io^f0>Gh]P3CiJT0Wk1j09NWN03Ljl@0looK0>C_c@3?h;<0h?n`0;oPT@3Lo;40
^]R@0<_SY`3_old0VIin0?ooj`3oo_<0hm3B0<:b]@3on_l0m>gd08b<RP3Tj]h0c=nb0<WQY@39jIH0
cNfH0<k_WP3NoKT0k?o=0=3R_03Di[h0b=^]0<WMZP3DjJh0aM^M0=cb/@33fYH0SjIR0<cSW`3Bk:<0
f_b_0<G]YP2Oe:00@7eC05jVVP0=?SP0CG5]0>WonP3[oo`0//O00?coo`3oo?l0Z:6Y09JKX@1]QHD0
[[Nf0;WFd@25[ZH0b>_W0?Goo`2HUY/0o?3b0?onn`3koo/0nooj0?omo`3onol0ooco0?Sho`3lool0
nooV0>kic`3Pj[P0fn:f0=gU`03lon<0nOoM0=;W[P30fh`0b^NC0=7_V@37hY/0cnRW0=S[/`3DiJh0
o?oL0?WogP3oooH0ooom0?ono`32`;@0gmgA0?_kl@3nooH0nooa0?Soi`3nonH0oooV0?omiP3Ll[40
c^jI0=klY03Gm:@0fnk0000:003PllD0e>b^0<SSWP3`old0l_oL0?7oh`3ionX0bmja0<SOZ@2ngY<0
c_6M0;cSR036kI@0d?JO0<CYV`35jYd0_n>90<S]SP32iXl0_=f<0=Ob[@3;i:<0VZee06=d?P1TLSl0
6BD00;[6U03?fKH0BU<d03Hm6`1TK4L0/[ZA0>ceb03QkKd0gO2h0=;XZP3PoK/0a^FQ0=WR[@1gMTP0
_[bE0;noV@3oonH0oO_V0?ook`3oooX0^;Ne03Xh?@1oO8<0ooki0P3oooH06@3oo?D0[JbW0=[MeP3H
fm808RhF08jON`3<l;00U/9g09k5MP2;ZUh0WKE[0=7KWP3HiJl0d=jm0?oRf01mKEh0oooT092PHP3I
jil0a^Z@0<G^TP37kIH0a^bI0<K[V`39jih02`3oool000X0oooo00h0bN>L0<ORW@2nfI80`n>G0<CU
U038ji40b^fC0<KVT`3;iJH0eNbh0?Wok03noo/0ooko0?ooo`80ooom00d0no_i0?ooo`3kn_l0ooko
00401@0300D0oogo0?ooo@3oooX0oooh0?oonP3no_h0oooo0080o_oo03L0o_oj0?_ok03YoL`0a]nM
0=K`Y`3El9l0b>FC0<cXW@3:j:00bNVP0<WYWP38jiL0b>^I0<7SU`3<jZ80b>JN0<gXX@31fi80V[9X
092ZH02edHH0foZ/0;WJR`3DmZT0^=^I0=3]]`003000D5PU0:Z^L`3QgZL0d<bM0?ooh`37bJ@0d>2I
0<[OT03DjjD0j_ji04ED4@3;eiD0cMRF05AO7@1^NSP0cMjJ0<OLU`3Ajj@0a]nK0<cMYP3WllD0h>?>
0:j/X03onoL0[::S0;jd/`3ono/0ooWk00@0o`0006l0moOi0?Who@3oo_l0oogo0?olo`3/hNL0oo_k
0:RFTP26O780iO?B0<_J[`3CiZH0d^RO0<cUTP1LMB@0dNbM0<SSU03;iYL0g_ZV0<kYV03EjZD0ambG
0=;WXP36fYD0Qi]F07fBC@3DjjD0bN>L0<oYXP2kfI40UJmV0<?ISP35giD0c^jR0<[VW03HhJ00h]fU
08elCP36^8/0h>>f0<kK[@3AhK00c=VT0=GN/@3>dkD0ooo]0?onn03?bk80nOCa0?omo`3oo_l0o_ok
0?con03fnoL0loKo0?cko`3ZjNl0e=[00<kN[`3<hJH0cnNY0<SVWP2]cH80eONZ0<7VUP39kZ00`NJI
0<?XV`33iZ80a>F/0<[aV030iHD0a^:E0=G^[@2JZFH0_lV<0>OTa@3bjMP0ookZ08N8G036g[`0BFm:
09k8VP2hi:D0boB^0<[YV@3<iiH0c>:@0=K[W03:iIH0bnFN0=?V[P3kon40i_7C0:J^V@3NiM<0mogS
0?koi03Bg[00gnfj0=[//P3IkZd0]/j00<kUU`3EjYl021P007b9@`3Kj:80f^VT0=;WXP3DjjD00P3<
jZ802@3=j:40bnFV0=GZ`@3Vm]/0l_o^0?_oo`3lool0ooko0?omo`020?ono`0W0>3PjP3no_l0n?Ol
0?;blP3ooo/0o_o^0?koiP3@hJd0c^:S0=;]X03@j9X0h_>]0<oPW03koll0k_g607F2EP3AgKL0b]Fc
0?[oj@3lon`0hn_D0=OU`P3=iZ80d>VW0<;KVP3EkK40e^Rf0=CS^03oonX0ooo_0?K]iP3oko80ooWo
0?oho@27P8L0PX:20?con039fk40cnNY0080bNVD06d0aNJE0<CRXP3;iZl0eNNo0=c^a03^om40fnnj
0<OLX@3?iJL0IW`l00HL000J<000R9iM0=Oa]034jKd0_^_2056?MP01BSL0;7MP0:oRd`0060d0`=kF
0>Woo`1/Rh<0nooo0?oko`3onOl0o_ko00072@0Q92/0d>?Z0>Woo`2@/kT0l?oo0?Soo`3ooOd0oooj
0?3aj@3oooX0n_Cf0?oio`3ooOl0n?Wn0?Son03/nm80a]BO0<39U03TjL00c]Fd0?coi03homX0aMVL
0<kVVP3:iI@0cn^G0=3ZX03GlJX0b]jQ0<_LY@3Ul<P0mO_O0?oonP3_kO00n?Kk0?[fj`3Vh]L0oook
0>[/j@3hoo@0kOcO0?coh@3lomh0_[bS0;kES`3:ji80^=Am0<oZW@23UVT00A400<CGZ@3Jl;80dNZX
0?Cod`3boml0n?oV0>cje`3Hk;/0dNV_0=Sh[@2hfhT0bnnG0=WmYP2ig8P0e?BX0;gMTP3BmI/0dOBH
0<g/W03WokP0e>b`0<OKYP014000RYU`0=gY``3Cf[P0hNS607N1G03Fh[`0o?oQ0080k?C=02d0`<RO
0<oJ/03ChkH0`mBW0=;Z^P36gZh0CUDR09^KJ@3If:`0oooH0?ooi03oonX0ooo_0?knmP3ooo/0ooko
00401@1RGET0m?3U0?WmkP3jo^l0oood0>WNf03Hb/L000<006=cEP2iijT0aOfd0<ceY`30gi<0^]25
0<gFU@3Eh:@0eN6k0<V/WP1FASH0m?OH08VLG03Gk9d0an^A0<C]T@36kYH0aN^H0<GZVP3<kZ802`3o
ool000X0oooo00d0gnjY0>;e/`3_ol<0e>f/0=3[YP3:ji`0bnbK0<KWV035i9h0`n2P0=7S^`3loo@0
oooo00<0ooko0P3oool0603gnOH0n_ci07UkN0010@<0ooko0?oon`3oooP0ooof0?oon03oool0ooko
0?koo`3mo_l0o_om0?col@3bo]H0c^2T05]^;02U_Fl0]]620<[XWP3:j:00bNRR0<SZX080b>^K02X0
cNfR0<gXX@3CkZL0a]fE0<WPV02`aWd0QYiD0<WTU`3;iiX0e?>U0<CTV037iJD0dnbe000=003Ljk80
eN6Q0=CKY`3Kh;P0hnCB0?oojP2FXFD0X[=/08bQG03Oljh0K7/h0=_WY@3Tkjd0d]jL08jMFP3HkjT0
eoF]0;gSV03<kJH0eN>^0<kI[`3mo_00m?7/0?omo`3on?l0oo_o0?olo`3omOd40?l00080oogo07D0
oOco0?[io`3moOl051<?08B1O03oo_X0oood0=oecP3:h[80b^FP0<kZW@3@k9P0T:]J0<cTVP3@j9h0
ennU0<SPU02I]6L0c>bS0<k/Y03=ij00bN2J096VH@3@iJ00amjH0<WSW03EkjP0Y/Al086KDP3Cj9/0
bNFH0<K[W@2kfi00h^b`0=[BX@2gWgd0nn?70?chg`3MiLd0kogS0?[oj`3lonl0oooc0?kll02YXYX0
HV1C0?ono`3noOl0PhN602df9@2KYHd0g>OF0?;hm03kool0l_Kg0>kcg01NID@0?4PR09n^Q@3Hk[l0
b^:`06^7C@1GMCT0=E@A03ID3P1lVU80eo:[0=G_[P3=jIl0bnVO0<gZY`3:ij@0e>nP0=G^W@3BhZ<0
j?;00?oog02W[X@0PI1Y0=;_`@0bEb@0Qk1d09FkOP38hZ40e^^X0=S/Y03Cjil0eoZV0<c/X`3Ahk<0
m?kI0<79Y03Df[P0Fem40?ook`3nonl0e^:n0<CDX`3AjI/0d>bH0<g/W02D[f80AUhD0>7`[`3?fid0
jO:m0=;LZ03Gi;H0b]^^0=C[_`37g;40e>>j0=_W``3eo^T0nood0?_onP3lool00P3nool0A@3oool0
ooom0?ooo@3ooo/0i^OQ0?cokP3oonX0MGaK0<OCX`39ej80f>j]0:k9PP3SokL0J8@i030k001HHBP0
hnW70?SmiP3nooH0lO;/0?Ojl`3joO@0ooof0?komP3Uj]H0hNc20=KN]@1GHSX0EElj0=;K_P3non`0
oooc0?oklP3hl>d0oo_o085fNP2i/;40o?Kj0?cmo`3jooT0e>Nj0<gVY@38jI80c>fF0<g/WP3;i[40
d>Rf0<oRZ`3FjK40X[Ii08^OH02kd8d0fNj[0=O/Z@3Wo;T0//N60<cQX03AijH0bNNO0<CSW`2bf9/0
]n2X09GF[P1c[8/0PKRI02aMBP0QCCh0TKJ^0>G_l@020?omo`210?coo`3[moD0ooGi020N:@001100
SK:k04YcM`38k>`0nOok0?kgk`3onoH0oo_g0?ono@3onoT0ooko0?con`3hoo40amnQ07J<@`3Li:T0
dm>]0>_]e`3an]d0aMNS08VKG`3Hk:L0e^bT0<GKT03Dji/0d>NI08:DEP2S/Gh0o_oZ0?Ggj@3cl_00
n?Om0?Ccn037`K40mNkL0?onn`3emo@0jOoV0>KodP3?iJD0]/F:08N?H03Kl:d0an:E0<cRV@3Olk@0
cmfl0008003;fjh0e>NW0=G[XP3GkJ`0c>:a08ZLJP2R]Gh0aM^M0<7JV035hIL0R:AI0;_GRP36hI@0
d>RL0=__Z03:gYL0enbY0=?WZ03^ol`0iOG80=?N`03gonT0k??S0>kbi03dn>X0oood0?ool`3aolL0
dNFN0<SHV@2DXVL0kOK90?[of`3non@0koSS0?Sol`3hoo/0n?om0?7ae`31_Yd0kn_>0?;ae@3[jM@0
inCC0>?Qe03oooP0oook0?ono`3knO`0o_[i0?;ck@3_m^H0SHaj07ibI01O@D4080`>0<CPe01LRG@0
01@00;kO/P2ogY/0bnNM0=CYW02GX540g>RN0=SR[P3gfL403P000?ooi03>h:80[<=e0<S/U@34jYD0
aN^H0<OYW@36iIl0e_Bd00/0oooo000:0?ooo`0>0<WDT03col40noo=0<OLX@3AjJ/0b^RP0<[ZW`36
iYX0anNN0<;QW@34fZ`0nooa0?ooo`3oo_l20?omo`0=0?ono`3fm_H0o_oj0?3bk@000P0000400?on
o`3ooo/0oooh0?oom03oooP0oooo0?ono`020?gno`0c0?gooP3koo80c]Rc09BQJ@2BXV<0bMnD0=;Z
WP3<j9h0b^RR0<WXY038jJ80b>ZN0<WYW@3AkjD0b^FN0=;/Y@3?iYh0dNNN07N=A03@iYd0ho^_0<KQ
U03>jYd0cn^P0<;JW03AiZh001000<gOX`3EiJ@0d=fX0=gW`P3loo<0o?o]0;c;TP3Ol:`0@UHA0;W:
QP2LZ6H0e^:P0<G@SP2LZfP0QIIB0<[UWP37jIl0_^RL0<W_YP3<fZD0dMjc0?kolP3oooX0ooko0080
ooco00<0nOCh0?kio`3ooOl00P3o00004@29PGh0o_On0?olo`3oo_l0oooo0?koo@1mP7L0YJJN0?7b
jP3joo<0h?_B0<[V]@36iIl0c^fQ0<SUT`1ZQcL0e>^S0080cNBN01X0d>NO08VSFP2igI<0c_2V0<OR
V`38hY/0[lAo0=3UX03=i9h0dnZT0=7[Y02ng9@0^M>:0=;WVP2mfH`0doZ[0<CVVP39dYT0/:Qi0<>X
S@3oj=<0ooo]0?col`3[n>L0koW^0?Snm080oooh04P0^kB/07YkK@3gmoL0h>7S05YRD`2GY8H0g>_2
0<OE/P3ionl0mood0?_om03eo=/0g^?50<K:[`3LiLP0f>O60=OXa01IL480GgM506Mo@`1^QdH0XKQb
0=3VW@38g9D0d^JY0=3UZP3;j:H0a^BN0<GUTP38j9<0c^VJ0=G/Z03Um[l0bMF]08JBI03Aj;@0V[R2
05Il@@2P`hT0V:ed0=CSZ034di80fNnW0;[OS`38jJ@0j?SA0>ged02Z/HL0gN>g06]_C03ooo<0n?_`
0=[Wb`3<gZh0bnR>0<o^T03Ook40K8Pn08:ID`3EhjH0aM2H0=GL/03Dfk80k?SD0=g[bP3Un=X0h?3C
0>K_e03Zl]X0o_od0?con03noo/30?koo`380?ooo@3ooo/0oooj0?3bi@3ooo40loSJ09^QN`1[M4D0
gNba0=S[Z`3JmJh0foVa0<3TW02R`7P0SiMK096DI@3oond0oooh0?kmo`3ooOl0ooko0?ooo@3oooX0
ooof0>[]g03Wj/d0a/V/0:JZS`3:c[<0dmK10?ook`3im^d0oooh0?onn`3oo?l0=2/^0?cgm03oo_l0
nocn0?;il@37fZd0dnb[0<SYTP37j940`n:F0<;MZP3:h[80e^Z[0<kSXP2=XUl0WK9]0>;h/03Bj:00
bn6I0=?YX@3FjjP0^m2=0=;YX`3BlJ40]mJ60>oo``3Yokl0`_O905BCJ02Uj;l04Thd008b8P3Gn_<0
n?oo0>[]lP3lool0iN_Y0?con`3omO00MFY^00442`1kX:H0:EUI08Be[`3Xn^h0ookd0?ohmP3on_X0
m?3_0?obk`3oo?T0mogc0>ooi03?jJ80UJaL0<K?T030`9X0ooo]0?_oj@3?hJd0UjI[0=7QXP3IkJP0
^Lf60=S_W`3Dji/0FVX/0;W5U`3lon`0n?S^0?ono`3noOl0oooo0;J`VP3oonX0noSa0?con`3Ck<`0
`nB[0<WUV037gI@0k?Nm0<;FU`3KlZh0nOo<0?Woe03;eK`000H00=;O/@3>gi/0a]^<0=;XX03<hJT0
Jh150<;HV03Aj:@0gOJb0<gWX03>j9l0[LAl0=K/Y03TmJl0g^fZ0<??S@3?gJX0cMZ^0;[6XP3lonX0
o?oc0?;ek03fmo80oook0>k_jP3oooP0hN7I0?Sod03=hiX0^lj<0>?b]`3eo]40m_kG0?cohP3loo40
noof0>cel03iool0oooa0;RcX03Le/H0lNkM0?Gbh`3ooo<0oood0?gmm@3lnoH0m_Ga0?ooo@3ooOl0
oOWj0?7ijP1:BcT07a4403LG6017=cX0hooo01QC@@0??B00WK2D0=Wc]P37hiT0b]n@09nWE02d`G40
`ljD0=o0X`0>0000jN[;0<[NX@2J/VH0bN^G0<?YUP36jIT0b>NQ0<KSX@3Kmk`;0?ooo`002P3oool0
3034hiL0b^FN086LF@37h:H0kooB0?Soh`3gonD0n_oY0?cok`3loo40n_gb0?ooo@@0oooo00H0o?cl
0?ooo`3jn_X0oooo0000001eMGD30?ono`80oooo00<0o?cl0?ooo`3oood00P3ooo/0a@3noo40l_C?
0=GSZ03:hI/0a>^H0<7XU@38jYd0b^RN0<gWX03<j9h0bNZI0<S[V@33j9P0d_:V0<CPU@3>iY`0R9aD
0=[^YP3@iYd0c>JL0=7]XP32i9L0fNZV09EdE@2VUgP00`@006f:DP1HMC<0dMbT0:6RN03oo^l0o_o[
0<[U/P38j:T0c^VT0=?^Z@3Ak:D0eO2Y0;WDS@39i9d0f_F^0<3JT@3GlJP0e_2W0=3TY`35aJd0blZf
0?oom03oooP0nO_h0?gno`3nool0ooko0?oko`3oo?d0l>OX0?C_k03oo_l0nool0?kon`3on_40c[R[
0::4N@3omnd0`:^V0?ono`3lool0k>oV0?;gh`3>jK@0`N2M0=;OV@1iN3L0e^FR0=?^Y`34jZ40ZZY/
09^JFP37jI`0a^:G0;;3O01;Fa@0d>BL0=WcZ@3:k9l0aNZL0;oOT`3FlZL0d>BL0>;_Z@36jid0eO>[
0<OPW03Rm;X0WIY_0;nEQ@3of]40noof0?WonP3hoo`0o_oo0?oon03in=X0`KfG0:jWN@2f]8d0]ZMn
0;BZN@2@Y5l0TJQP09fKGP2CRU40kNZg0>Cgb@36gK<0jn[F0?ogl`2JTH00XZJ50<kTY02L/VX0Si]A
09VQF021RCh0eN>F0<_TT036kI@0e?BX0<cNXP1iPdh0R8YI0=kP[`3Ojjd0am^D0<gZV033hY80cNbL
0<cXW@3>j:40PI9209j_G`34hZ80T[Z80:7AY`2kjKP0RJAM0:_1N03>hj80i?Zl0??ob023V5L0Z/1o
0=3MZ02BR6D0oog^0?_om03Fh<L0jmg00<_QV@3CmZ@0bnVO08jZH03;iI/0f^f]0>?a_03oonP0oooa
0?Ofm03oool0o?cl0?oon`3oooH0oogm0?ogo`3onol0ooco0?oln@3mnO00ooof0?onn`3mmOl0ooco
0:ZXV@2][iL0f^Jh0<OFW`3@h:80d]fQ0=cWZ`3?gYd0e>RS0<kYVP3:iYT0hoRm0?;oe03koo40mOcd
00<0ooko0;<0o_Wc0?oglP3llnh0]Zj[0?ShmP3oool0oogo0?ono`3oo?l0oo_o03`c=P2FSX`0oogk
0?gfl03ooo<0^KnK0=?E/03oomX0c<fQ0<6oV028QF@0fMO20?OhiP3ooo@0m__d0?Sok@3BjjT0dMVM
0<S6S@3Gfih0eO6W0=GaYP2kaH00ViiK08fCE@38f9T0d^Z/0<OPZ@36gjH0c^JZ0<OOX`2<cLT0<XUh
03AnI`3Fk/h0`>6b0<7V/`3aoo40AFUO04YjNP2E_K`0n?on0?Cio03oo?l0ooKi06maL03[lO40[/c:
0;7oo`3Gool0ooco0?ojo@3omnL0fM;:0?coj`3SlLd0go?20;gFW03^old0mooK0?coh`3iomh0nOoM
0<[S[03>ik00e>?20?7ji@3nooP0nokc0?_ok`3?hKL0d>Jg0>?`dP3loo40n_cg0?Wom03gonX0amRR
0;2nR`3FhkD0mOo@0<cPX@3AiJX0i?g60<g[[@32hYH0]l290<k?Y`2^[IT0h>3H0=cIdP0>3000SY5V
061U:`2?X5T0/lV00<;NU038j9<0anRA0<KWUP37jYX0aNZJ0<?YU03:kY@0g?fV0;SHP`3>j:40`]JG
07A`I@27OX<0oogo0?oio`3knol0nooo0?com03lonX0iO380?[oa@2a^g@0PIE@0<WPW03>iY`0dnjQ
0<gWW@3=iih0Uk1^0=CV/P37f:/0mOoP0?Soi@3ioo@0moof0?Coj03OoL/0fonh0=Oo/P3NokL0b^BW
0<GGY`3cmN00ookd0?oom03in_80oogo0?Sdo`3oo?l0^;:T0?[di03kn_H0jo7a04U_HP3@onh000h0
05mdC@39gJ00amfM0=3PX@36]gH0dZij00h1001QKT00]nR?0<WZV`3Bk:<0cnVP0<GQU`3Fm:`0b>JN
0>;o^`0;0?ooo`002P3oool20<[TW@0:0<kWX`39hj80aMnP0<gT[P3>iK40d>>f0<cJ]P3>fKL0e]k7
0?konP@0oooo00H0o?cl0?ooo`3gmoL0oooo0000001nOX030?ono`80oooo03H0o_kn0?ooo@3ko?L0
oOki0?oonP3nonl0/kF@0>;`]@3BjJ<0bO2M0<S_W038jYd0b^RN0<gWX03<j9h0bNZI0<S[V@34jIT0
anNK0<3LT@3;hiT0VZiV0=O[X`35fi80d>ZP0<;NT`3;kJ00cn2L0::1HP3bhL<010@00<k[/@36iIl0
cM^M092CI03oonX0oooX0>_oc03ZolL0mOo?0=O][`3DjZ`0Ykb107F:C`3Bij`0cN:W0<KIX@3Ej;00
dnB]09ZVN03Ad;h0n__[0?[kl`3jo?L20?koo`3R0?gno`3no?l0oogl0>kVh`36_;X0o?Kf0?ooo`3j
ooh0o?ok0?oll`1@>Rd0ooO/0:^=P`3Sc<H0g][I0?_mnP3loo<0o_o/0>3kb033h:H0i_6g06AN;03@
gJD0c>JY0=7f/`1cLcL0i>BT0<kcY@3:jId0VJeU0<CESP3?iI`0jonk0<3PU030hYD0eoN[0;OAQ`3J
kZH0f^NQ0<7SU`3=j:40e^b[0=c[/P3fllH0djfH0?kMc03gond0jOKT0?GomP3Zoo@0l?o_0=khb@3D
jkD0cn>V0=S/]`3NhZl0d]ZQ0<o_YP3Fn:`0eMVL0=_DX01NFRd0k_cI0=3Na03on_40oo[j0?ook@3R
k<T0c^RW0=G_Z03Gi9h0bm:>0:^bK`3NjjD0enbQ0;oOT`3LnKL0dN6`0=GN/`0Z:080PH9J09:MH`24
UeD0/ln20=KeY`37iYP0c^RO0<_UW03Bj9D0goFR0;SET`2jgj`0@Vm607:PK`32j9d0T[5U0=;TYP3@
hZH0g?2a0;_@S@3<hZ40cM^V08=jF@3ooo40mOo`0?_ok03onMT0e^jT0<O]V038i9X0RZAJ0<kVW03G
ijP0c]RS0?SkgP3oonl0nOGd0?WemP3oo_d0oooj0?ool@3oo?L0m^[d0?oho`3nloT0no?X0?ook@3o
on`0mnoR0=W?d02d[[00ooof0?ook`3oomd0aLfL0=?MZ02DWfD0OheB08fOH@2CZ6D0RjEK0<[UV037
gYX0b=^T0?;lh@3loo<0moKd0?ono@3hlo00n_G_0;>^Z03ooOX0o?Oc0?[fl`3kmo@0oogm0?ohn`3o
nOd0oo_o0>KMgP3ooO/0ookj07MdJ`3ooo40o?oQ0;BlT`39cil0V9aZ0=gN]039bJD0n_cT0?ook@3l
ond0iO?I0=K[a02ng9@0b]BG0=GBW@3>dIX0RZEP092`I@33e8d0e=nK0;o7SP3DiJl0en^j0=kcb03Z
om40j_o90?7od02GcKD0OlFP0;Gbb@3;hK<0a>F`0;SMY`1WPV<0^=?20>;oo`3Kood0mooo0?Woo`3g
l_P0ooco06IVIP17AT@0Wjn/03AdL`2on?l0o_go0?ofn@2e]9P0clbk0?koj03]o=<0bn:^0?Coc`3Q
nK/0bmVT0=7MZ`3>g:T0c^6Z0<[QZ`3CjK/0moo[0?comP80oook00X0nOca0>olgP3bon00mooZ0?oo
mP3oooX0n?o/0?Goh@3<gjL0]<J<0P3Ch:P0?`3Pkk@0h_Jk0>?k_`3Flk00bNVM0=SZ[P3@g:h0nOkX
0?Wil@3[jn<00@800=?K[03Nk:l0b^2G0<SRV036hYP0bNJB0<SXT`37iYP0a^BJ0<KVV`38j9`0f_JY
0<KQU03BjJ40d>6Z0:>aP02l];40oo[o0?omo`3oool0nook0>[ei`3[nMP0g^g20=o]^P3>fiH0//1e
0:2eLP3<iJ<0c>NJ0=7/V`3>iYX0dNRP08BJF@3Nl;`0g>jn0>3```3MkL00j_OK0>_ig`3Wo=<0c^Jb
0<OVXP37iih0^]VC0=?]/039gJX0/kbM0?3egP3oon`0o_oa0?clo`020?oko`0G0>3Nc`3Kg/T0ookk
0?omo`1fThl0Sm2j0=Goi@30fkP073P00;_GVP3Ikjl0QgXf07AA6`2>PEh0G6Xi0=CoZ@3Alil0K8Pm
0<[XWP38iYh0cN^S0;cJTP3:jJ<02`3oool000X0oooo00`0`mRC0<KMU`39hi`0bNBM0<WTW`3@jZT0
d^b_0=;Y/@3?hK40e>Fh0>[ee@3nooH40?ooo`060?gmo@3hn?P0o?cl0?ooo`092@T0FUYL103oo_l0
;@3oool0oOgm0?ooo@3ooo/0oooj0?kon@3Zjm/0YZR30=cZ[`3FkJL0bO2M0<O^V`38jYd0b^RN0<gW
X03<j9h0bNZI0<S[V@3:kil0d_:V0<[VV`3IlJL0/<Al0=?WW`3?iI`0c^RN0=7]XP38jYd0dn>R08m/
CP3gi/P010@00<_Z[`3>kjP0e>BS09ZQK@3`k<l0k_CB0>Soa03Gn;40loo?0<_NYP3Ej;40f^bh0;W:
UP020>[jb@080=?P/P3>fjl0Uj9g0;BlU`3cm>@0oooc0?[mmP3nood20?koo`360?ono`3ooOh0ookk
0>cSgP30]k80oocm0?koo`3jooh0o?om0?oll`1TCT40ooO/07AFB`2PRH40^;Ba0?kon`3lonl0o?oV
0>[od`3@jkP0n?oA08QoEP3Lj;P0e>nh0<S/[P3MgZ80eMFE0<kcY@35i9P0]<R005e^9`3IkjH0]m67
0=7aY@31hiH0_mnC0=3ZX02[_7D0g^VT0<g_X`3Ak:L0`MNF0>?b^@3OgJd0m]6g0?oOb03ionX0mOoZ
0?;ok`3Zoo<0jooZ0<KW/03=k;00c>VV0<KOY@3DgjD0hNf_0<CVW035jYd0k>nf0>?K[01ECBH0nooZ
0?_ol@3oo?X0ooWi0?ook03YmLl0c^^Y0<[XXP3?gY/0c]BF0>OZ/`3HhJP0amJK0;_HV03=iZl0cm^c
0?ooh`1WI4D0W9ah0=WS[P2Y_7`0e?2S0<cXV`3?jj00bnFL0=;/XP3Gki/0b>2<08BNG@3?kkh0L9Yb
01e;6P38lZH0/M>6096SI@3Ij:d0_]:C0<cQWP3GkJ`0dn6/07Q_CP3no>l0n?oe0=CNa@3Yg;`0eNfS
0<;XT`39hiX0SJEK0=3VW@3Jj:X0dMZU0=SH_03oo^`0ookk0?ggn@3onOT0oo_e0::LS02QVY80gmGM
0=C:d`3@alX0ooo]0>cXc@2l^IX0d<bc0?olmP3onOT0n?_d0?kolP3enMH0g>:f0>7X]@2CWFP0ZkR2
0<kRY@3=hj<0Uk5X08NRE@2I/FL0dnNZ0<oI]`3@eL40ooki0?ghm03oo_X0YZ6K0=cGd`3nnOH0ookk
0?onnP3bkNT0_[Jd0?olo@070000Ng5b0=gEd`3PfmL0Lg1Y0?oom03XkMT0aM6Y0>;^`01/MCh0_/F?
09>FI`2MWgP0m?WK0?coj03/n]T0cMng0<3KYP35iIX0XZi`0<2mRP2=SET0c>VW0<[^Y03SnK40LH0m
0>7[]`3<g:d0d^Bj0>Kke03Xo]00hOS00>;i`@39nM<0T/jK0;7V/03:gZT0`N2U02a?5`1_SFT0gO?L
0P3Tool06P3]oO`0dmkH0?OenP3ooOl0e];C0<Bl^P1VK6P09emL07B_]@3/k_/0o_;b04eC;`3EeK/0
l?[G0=o_`P38gjL0hojk0=ce/`3=gj<0d^6Z0=?Q[P3@hZh0h_S70>Oid`3loo<0oooj0P3ooOh0103n
ooT0noo_0?Wok03noo@20?oonP0F0=o^c@3Bj[P0en^^0<WKW@3DhZD0fnV/0?3oaP3eold0d>VX0<GS
W@34i9P0`MVK0=?U]@3Li<d0ooof0<S8`00D5`@0f^Jf0<OIV`3?jIl0cn^N0<k]X@80d>fM02d0c>ZR
0<_VX@3?jZL0dnj[0<?LV03Fk:/0`MFH075lD@0_=Q@0oo_i0?oko`3=bLP0oooj0?Wol@3_oN<0hoG;
0=?U/`3?h:T0fnZW0=?SW02ldY40dnbZ0<kYW03@jiX0c>BF0=7YW`23VEP0l_o@0?7od@3@hJd0dnB]
0;g<Y@3Hi/80n?oL0=g_^`3<hZ80dNNV0<gSXP2kd9L0hO>o0>Ccc024Sfd0o?cR0?[ii`3fnOl00P3o
nol05`3ko>`0g>C=0?omn`3onol0fO;f06Z_W@30km/0cNkA0;_LY`1INcl0a=jO0<6fM01YB1<0LVE2
06UgAP2olYD0[]1l0::nL`2fdXP0_=N@0=7/Y@37hY/0`^2J00/0oooo000:0?ooo`0<0=GTX`3Olj`0
GW@[0=KcX`36iY<0co2O0<k_WP3<k:00c>ZT0=Ka[P3_om80o?oc1P3oool0103gmoL0lO7a010@4003
0`D40?ono`80oooo0?l0ooom0?_lm`3mo_P0o_oi0>k_g@3@dZd0cM^P0=S_Z@37kY/0`>ND0<SZW@3:
j9h0cNNP0<cXWP39jYT0b>^I0<;WU`32hYH0c>RM0<gUV`3Dj:00MXY20=S^Y@3:i9X0d>bQ0<k`X`3?
gih0L4/`0<B`U@031000cNb`0<3UV03<h9T0TYaP0=gM]`3:dJL0`^:F0=3bY@3GikP0j_[=0=GR]`30
c:@0bM>^0?Soh03]m=D0i^[A0=CH`@3oond0jN[H0?Gej`3gn?80oOon0?_loP3mo_l0oOco0?ooo`3o
oOX0ookh0>WPe`2f[JH0ooko0?koo`3iool0o?om0?oll`3@^Zd0IDPj06Y:?`2TSHD0LFaY0?Wll`3Z
mM<0d]bi0=O`aP3YomP0oooV08QlIP3Ih;l0`=N[0<ka^@3>dYD0hN>R0;ONS`3Dm:P0b]jF0=GVW`2P
]Vd0bnFK0;[JSP3;kJ00f?N[0<[TVP2gb840l?Vf0;oOUP3>jJ@0i_fi0?Soc038b9H0NeLg0;fNO`30
dJL0c^2j0?Coi03donP0mOoO0=3TY`36fiP0enRQ0<WKW`3QhZH0hnRX0<KPU`3;jJ40i^>`0>gO^02n
/9<0nooc0?_on`3onol0ooSb0=;L^P3KlL<0_n:R0<SXY`3Hi[D0i>W10?olj03oonl0o_oc0>cnj03e
onX0noo/0?3cgP3PflP0oocS0=CK[`3?gZD0X;Ya0:W5N`3>jYl0c^RO0<kXWP3GlIX0cnVB096ZJ02[
aID0a>[108fmR`30mJL0/mj>0=7QX`3JiJ/0enb[0=K]Y`3>ij<0kog:0;N^S`3ooo@0nOoh0=STc03e
j/X0b^:F0=;fW`3Aiih0TjQM0=?UV`3Egj00d=BQ0>?Oa031^j/0aKfk0?ogn03fk^`0g=S?0?goi`3d
mNL0noWl0?ono`3]k>P0d]Ff0>GZ`@3NiK80h>Fl0?ook@3nooD0nooo0?kon03mo>00emNc0<c=Y@2a
^X/0f>Jc0<_PY`3=hZL0fo:^0=C/X031fXH0cN>J09:ML`2<TG<0ZJNK0<K2^@3Ie<h0ookh0?oonP3o
o_l0ookm0:bSW02KTXd0gLo>0922P@3Zg=/0UX^90=G@bP3ooO@0ko7S0>W`gP3bonD0e>Re0<;FV`3W
mk00fNJN0:nhN@3Sj[@0lOg?0>;b`@38gJD0bnVQ0<_`XP33j9X0dn:Q0?Sa``3_k/00e?:d0;CLU@3=
jjD0G70a0=7N/`3?h;h0jokN0=g_a`39g:h0eNZ_0=3VYP3?l[00]n>F0<gdY@1XNC<0Ih8o0<ob/P30
gk<0BUTj0>?ol03Hoo4001X0Ef]Z0=;Re`3oo_l0oOSo0=W>dP28MG40BChh0<WbkP1=RXd0n?oo0?oo
nP1SN400RiAW0=cX]P3Ll;D0h?Zi0<cZY03<ij80eNN]0=SV]@3Xm]80i_GD0?Gok@3hoo<0o?cj0?om
o`80oo_o06@0oogo0?kon03mooL0n_Wg0?cfnP3oo_X0b]^_0=3]Z`2id8`0Uj]T09fZI01ePCl0amBL
0=c[/P3<iJ40bNNM0<SXW034i:<0eO6n0>kkh@3Xk^80ooof0004003Di[@0foBb0<SYVP3:kId0bnfP
0<KPV@3:h9l0d>N_0=?Y^03>i;D0c=na0;g>XP3Pk<H0d=Vj0?ool`3`knX0e/o90;jg[@3oon`0mOkO
0?Oog03Mm[l0cNNZ0<SRY@3;hjT0gO2i0=3Q[@3Hl;H0an6P0<WTU@3=iY80c>>A0=G[X02O]7<0RiiW
08>FG`2>Xf00Z;ie09fZLP2g`Hd0hnZf0=;DXP3Lg:P0j>Jc0>7Q[@3GgZX0l?W40>gnbP3homH0k_3;
0=[J`P3fnOl0oo_o0?ogo`3ooo40j_SN0=W=c@3nj_H0lOoo04B=QP2gl>X0]MoC0<W_bP0nI3D0f_S6
0??Z/@1dDbH04@H006MdB@2iji@0a^JJ0=7VX@3GjjH0`MF@06j2?@2hc8L0fNZV2`3oool000X0oooo
00`0fNFU0;c=Q`1@I1`0d^nM0<o_VP3;kIH0bNfF0<KYU@32hYH0a>:H0<gQ[03loo440?ooo`060?_k
n`3oool0mOGe0?ooo`000000c/k@103oo_l0>`3oool0o_kn0?gmn`3loOP0oooj0?oon03hnNL0j>[5
0=OUZP3GkZP0b>nL0;kUTP38jYd0b^RN0<gWX03<j9h0bNZI0<S[V@2mhY80`n>G0<?OU03@j9h0dnNO
09>WG`2hcXD0cnVO0<KRU`3;kJ00d>2O064l8@2eXHH02``00=7`]02efXd0gO6Y0<C>T@3SiKd0d=V/
0;oPS`33iYH0e^>g0??oe@3CgKP0VJ>00:^bT@3nonX0ooo/0?ook`2ZZi/0oooc0?oom03oooX0oook
0?koo`3jnod0nO[n0?ono`3oool0o__f0080o`0007H0VY680?ono`3loOl0nOoo0?coo@3oo?<0ooOZ
05i1<`1_Cd@0XhZ309nJU`3nooH0i_;<0<cF/@3<iK/0l?oR0?kojP2QTH80n?kT0>cof`3]omX0g^:U
0=cQW`38kj00do>W0=?YX03:gYH0VJmV04eW7@3SokL0^]b?0<KUV@39hIL0fNVR0=;KVP38j9l0eo:]
0<[QW@3:fIh0i>B`09AbC`1oHT00c]nb0=K[`03Zo=@0eMZj0<kCZP3QiJX0embJ0=;CS`3Wkk@0g]RN
0>GQY03>hY/0d^VS0>3JZP3oo]X0^j^B0?con03cnOL0oo_o0?onl`3:e[00`=RV0=?g]`2jfId0nooO
0?[mh03oo_P0m_;c0?KenP3gool0lOo_0?_ol@3moo40]:bO0?ook03Ih;H0fNRa0<_UWP1lV4h0gOV_
0<gTW036h9H0anB:0<GRR03NmkD0MXiN0;gS^P2ijKD0`_RZ0;SWUP39fI/0en:X0<[OWP3Aj:80bN:N
0=WW]02f[Hh0oood0>3Zg`3=fL40hMJf0=O_X`2nhX/0c^:J09>UF`3FiYd0fN:S0<c@W@3Pg<40gmS8
0?oln`3onod0d/S70=WEbP3lonH0oOo`0P3nool0J@3nooX0o_oQ0>oia`38diT0eMn]0?coj03ho_00
l?Wh0?konP3oo^D0W9Uh05QI<@3Cg:l0f>Je0=?Z/P3QnKl0dNNV0<SPU03;iH`0e^bQ0<oK[@3Mh/80
oooa0?Kbi`3oo_H0ookh0?oonP3dl_D0oocm00P0003gk>H0DTA108]lN@3gjNH0ooch0?oomP3knnl0
o_oc0?Wol@3<fkh0`m^Q0=[`[`36fHP0enJE0>?^Z@3Tk[40hO2i0=KZ[`3:hj40aNNA0<3XS`2fgH`0
gNf/0?kgb`3oomH0aN>W0<SaZ`3>kjX0GGDg0>cke03gonX0lOoX0>Ggc@3AiK80cnFU0<kUX@2ng980
f?jY0<c^U`36ehT0f_B]0<g][038j;L0E5lm0<_]e@1gX900lOoo0?ConP3nool0oogo0>_Oh@3]eM40
jMSA0>Koo`06@dH0mooo0>KVgP2je9L0GVPc0<KDV@3[ol00hoji0<o]Y`3;iZ<0dnB^0=KS]`3donL0
m_o`0?Gon03iooP0ooko0?olo`3on_l0ooGo0?C]m@020?oon`1Q0?olo@3omol0ookj0=;T]03<jZ@0
c^FO0=7VV`2ocH80HVlY0<CAV`3Kj[40an6J0<3OT`34i9P0cO2^0=Wg`@3hon`0o?of0>W[h0001000
bMfX0<[WY02kgXh0`NJF0<O/WP3AjZT0f>fb0>oodP3goml0hoG?0=KW``3con00cmRm0>kcg`3oo_d0
oogo0;beZ`3oo^T0h>K40=cW_031fIl0do2`0=?`[P3Fl[D0aMjU0??oe`3ioml0iok80<SRX`3;iYL0
c^NC0<[QS`3CjY`0e^VW0<gNY`3Gj;40c>:J0<SOS`3Ihj@0WJ9Z04m>601JE280JE`_05135P1FBad0
k>Zi0<gAWP3Kj[<0enZb0>CV_P35aJ/0noko0?olo`3omol0o_o`0?Ook03^h>00oo3o0>ooo`21c<L0
?WYk0;WVh@3Rond0CGI>05akC`3Sg:P0KdlX0<^oY`1iR640_o2N0=[j[`36ei<0f^VV0=_ZY`3Xm;80
U:1N09^VI00;0?ooo`002P3oool01@3IiJ<0DV<L0=;WW036hI00a^N@0080bNbB00D0b^bF0<k]X@3>
k:@0cN6`0?col`020?ooo`<0ooko00P0lNo`0?ooo`3]kNl000020>KWj`3oo_l0ooco0?omo`80o?oo
00l0ookk0?omnP3oooH0ooof0?cnl@3Qh</0g=jf0<kRX`38hih0b?>Q0;k^VP3=iid0d>JN0<SZX038
jYh00P3<jIT0:039jY/0b>NK0=WeZP32fY00goF/0=CZX@2G[F@0eNnU0<CPU@34iYT0dnNR095iE@2I
SVh00@D005Ye@0006P00bmnJ0>3/[P3Cg:L0fNJ^0=cm[036iiP0enNh0=_V_02e^9/0QhM]0:Z/U03j
on@0k_OH0>G`cP3GgL40lO3L0?ook@3loo40nOo`0?[omP3looX0o?om0?koo`3lo_/40?l000140?oo
l@3honl0nOof0?_om03oonl0ooc[0?okjP2VT880glk40<[9a@3joO80j?G:0<oL/038hk00l_oL0?[o
h@2IT7l0ooo/0?Ooi03`om`0U9mM0=7LU`39jId0a=jE0<_RVP3CkJ<0cNNM0;77O`31f900g?R]0<;R
U`3:i9/0dnBN028[003?jJ80cNNN0<_UW03?iZ80f>>W099`B`1O?Qd0b]N[0=GT^@3loml0i]fl0>?L
/P2PWVD0EU@G0491000b?P00IF<V05=?4P2IXFD0dMZS0?onfP3jj]00^ZfL0??dk`3nool0o_?g0?om
jP1NJCl0M8IF0<COZP3Dk;X0m?_J0?ook03gkn`20?omo`3m0?Woo`3iooX0o_of0?oomP3Hd/H0EE8o
06E^@`3KjK@0e>^U0;3:P@25WeH0dN^Q0=;aY@3?kID0cnVB0<gRX@2R]X<0b>fj0;SX[P2Cbh@0d?ni
0<[SX@3BiJD0eNZY0<oRXP3Gjj`0hO720:VXRP3nooP0nooj0?ook@1mLU80b>2B0<[/U@3?hIL0Tj1J
0=ORWP3Cf:00^kZ<0<W3Z`3<`k@0ooch0?7Ui@39_l00l>_U0?_ojP3koo40m?_c0?WomP3koo40e^>e
0<[IX03IjJ/0e>>/0=ST`03gonT0k_3_0?_jm@36`k@0fMO20?ooiP3gomh0nOoQ0?Oog03CiK<0a=>L
0=W/[039iI40fO6W0=3QZP3HiKL0o_oV0?ook03lon`0o_kd0?gjm@3ooOl0oo[l07U/IP2iZjP0nng/
0?kcl@3oo?X0ookh0?3bi03nonl0k_SO0=g/b`3Eikd0bN:Q0=G/YP3Fk9X0TjID0<cNU03:fiL0a=RI
0<_QX035hIL0aNN@0<WbUP34ji`0d^NR0>kc^`3Uk[L0a^FR0<;ZX`33hj00HW`o0=3R^03Hk/X0iO[I
0=[/a03Ai;H0dnR_0=od^@3Omjd0cnbJ0<CMRP3Hj9d0`]VC0<[XZ02V`i<0SI]h08n/UP1bU8H0l?oo
0>koo@3]ool0i_Sh0:^OX@3omOT0ooWk0:S1^`2;`;X0W/C70=oml`3:iJh0[kV70:FbNP3YoKh0i_nm
0=;_[032g9d0i?C70>Gac@3koo40n?of0?Ooo03fnoL0oogo0?gfoP3omol0lnK`0=G:d03_jnP0oOch
0?omo`3onOl0oO[e0=;T]03;iZ40f>nY0=7VV@3KkI/0YKIX0=[XZP3Ej:P0d>ZS0=7/Y@39ij40b>F_
0=kgc@3Zm^80o?oh0?CgkP001@00cn>`0;gJV03AljH0co:R0<OYW03<h:40eNJ`0?Soh03ionH0h^kH
0<oKa`2X[id01`/00;Vi[@3ooOl0ooSo0;bnZ@3oon<0hNk00=7T[03BkJP0`n6I0<SUXP32gZ<0bn>a
0>ong`3iond0n?oS0=;V]@3BjJD0d>RJ0<OPS@3?j9L0c>>K0<OMW@3Bj:P0b^:H0=SaX03>fiH0gnN[
0?Oga@3Qf[00hmFb0>SJ]@2WVg<0Ng]70>?[/03Gk:T0aMjJ0=;JZ@2_/900nogj0?oko`3om?l0nogb
0?Kol03omO@0cK_70?Ooo`3Bool0KYjP04afM@2[h<`0HXE_04=G?03UfZd0Kd/W0=oH_00]?1D0c>ZT
0<;LU@3Hk:D0d^JO0=7RW03;g9H0f^^U09RWHP0;0?ooo`002P3oool0;@2=WeD0c>2H0<_QV@35giD0
c>VI0=3aVP36iY40do2P0=3XZP3Bi[40j?OJ0?_on03nood0ooom0?omo@3oo?d0nO3c0?omo`3Qh>D0
0`H;08N<TP3lool0ooWo0?oko`3ooOl0oogj0?odl@3ldm40om?B0?o<a`3okn80oo7Q0;JQQ02QXFd0
eo:]0<3QVP32lj@0_?bV0>SWYP3Pg9`0^O2L0;kdX03Bhi`0en:M0=3VW@040<gWW@0Q0<cVW02/aW`0
f_J[0<GQUP2cdXH0eo>Y09n/M028U6H000X006]cG0094@00dMn^0=g][`2;XU80f_>R0<KPUP3AkJ<0
aMjM0<gFZ@3ol^P0ooWd0?olk`3Tm<<0e?>_0<7[U@3GnZX0_LR@0=;LY`3=ijP0b>6X0?Gog@3TnM80
looR0080n?o]103o0000@03<i9H0`]NB0<_MZ@3Ij[d0nOoS0??ogP3ionH0e=k60>WahP3cnOL0nooh
0>3b`P3@iJX0c^ZM0<STU`3ZoLD0]L2F0?GigP3PilH0amNX0=7`XP2YbGH0^lZ70=cUY03;jj80_nVM
0;kRV03HhJ00YZQY07N3@@3Dm:/0`^2H0=_`[@2@V5d0S9QF0=3YU@32hhX0_nVC0<KeY@1N?1H0V6]>
0>_Y``3gllh0_;B?0:^ML035^hX0FUXT0=gUZP32eID0`>ZD0<_OV03Cf9h0JULi0?ogi`3on_H0m^c[
0>WSh`3imO@0o_Gf0?onk`2`/HD0c]6R0:2RN`3el=d20?onl@1S0?Sah@3oo>/0bLRf0?Kdi@3ooOP0
ooco0?ojo03oooX0n_cW08fBM01;E2D0;S/50=_/Z03BiYh0b^2E0<?PT03:lJ00anND0<gTUP33cI40
VJEW0<c_W@2njY/0=FPm08:dT@3<ok80_nbI0=Wl_03Oj;T0n?_@0;>fV`3Bg/X0n?oo0?cmo`2iZj00
HE/k0<GPT@3:ji80c=R>0>?/Z`17C1H0RX=V0?ofh03jkMd0oo?U0?ogk03Wh=X0ooko0>[ZjP3`o^d0
moo_0<cN]P35fJP0cN:Y0=;XY`3>iIl0a]fI0<;FU`3Kkk@0o?oH09F;O`3Pem80oogo0?Sko`3kool0
koSc0?_omP3jonP0oooW0?ooj03oon<0gOJm0;_HV03=kj80`>>A0<CUWP31gj<0c>>e0?col@3QhMT0
ZIjT01862P2YViX0oo_k0>OShP3oood0nooh0?Sol`3KlLX0ho_;0=Sd^P3;jJ40d>ZP0<KKT03Aiih0
Y;ab0<[VV`3@kZ@0b>RM0080anNK0240b>NK0<[YV`3:jId0bn^P0<GXUP3:kI<0b>^A0<KWUP34i9/0
HWi4000A003<i;80d^Zf0=?Z_03SlML0iO?I0>?ae`3bo^H0m_o80=gX[P3@h:80^]2@0;cEU027XF@0
f?C409B^Q`3JlMl0joog0>?oo`2Qe/h0<8ag04><N03ono`00P3omol0D00b>2h0jooV03J<R`17Xj80
eOCE0>G[c`34bj80ioG40=K[/`3Bjk@0e>Zi0>olh03foNd0o_oj0??el03inoP0o_co0?olo`3ZhN80
_kFc0?olm03nlNP0oogd0?ommP3oo_d0n?Kg0?SmmP3YmmH0ioS;0;75QP3SnK40M8`h0=7YT@3BjIL0
d^RO0<KHY03@hKD0f>S30?Wkk@3oooP0n_Si0?Sfn@3noo/000@00=WZ`03Fjk<0e>jW0;WERP3Hm:T0
b=BD0>C[]`3oonP0l_;X0?Keo@1fM840m?;g0?ono@3lmo40ooS[0?ojjP3fom`0f?Fm0<c[Y`3;jj00
dO6N0<_ZVP34gYl0cN>b0>?ddP3iool0nooo0?kno`3oood0fNC40=[/^P37hiT0anJF0<WZV@39jId0
bNVP0P3:ij@09`3<hJ00dn:[0>_bd`3al^80mO?W0;>bWP2RZ8H0Vji^0=ObY@39kIH0^^::0=;VZ@2Y
/X<0ooo/0?olnP3onOl0l^[i0?olo`3oool0cLg;0=SAb`3oo?H0o_oo0;WHfP0]Ngd0e_7o0:nc_`2F
Rf/0LT4Q09FHK@16DBL0`:j60<OCT`36iiP0`nJF0<GXV037jYX0`^FE0<S[V`0;0?ooo`002P3oool0
;@2^`WX0f^nZ0<oVXP2ofY<0c>RN0<cXV`34h9<0d^bS0=7U/03DiK/0m_o/0?WonP3kool0o?oo0?oo
o@3oool0ooko0?ooo`0i>Sh0:Rha0?7fnP3oo_l0ooWo0>[Zj03oo_/0gZJa0=1mS`24:3D0[DaG08T@
6@2D4QX0Ub<T08eJ?@2^W6`0e^2Q0>Cc/P3Jn[40_?6O0=_LVP3If9L0`_JS0<;cX@3:hYP0e>FN0<gW
W@030<cXW@0U0<gWW@39hiT0bN>I0:>oM03=jIh0bnNL0<cVW@2@WfH0KWY<0007001@F4400PX00=;P
[`37eiT0F6lQ0<kWUP35giD0aN6G0<cWY03MjKT0f<^j0?ofj@3oo^`0e>Jb0=Ke/@33kIT0c_6Q0:>^
M01EH2P0goRd0=3XZP3Pml40amf^0=W[`@3=g[X0dN:n0<_K]P020?l0002V0<WKY`1VOS80J7li0<_N
Y`3;gJd0a]N]0=7P]`3Dhk`0nooZ0>kgi03Pi^80nooj0>7baP3?i:`0d>bQ0<[VV@3Kkk80eN6c0;c1
X@3MiL00dn>b0=7`XP35iI80YkQd05a[:03Gmjh0_nRL0=3`Y`3QkJ/0d=FE0=;NW01cSTL0f_R`0<CK
U`38e9H0VjYU0<[ST035hXh0_N:B0;KPUP2=JDL0f:Z@0?oog01ADRX0VIQ/092=EP1dMC`0b]BG0=7P
W`3GkZP0`nJD0<cLV`3/kkX0FTH]0;^SU`3oknd0[ZBS0??^j`3jmo00oogd0?7[d@28SED0hnRb09^N
L`3im>40ookc0?oklP3oo_<0kn_O0<2n/@3ooo<0n?S`0?onn`3oooP0l?7S0?Ojg`3Ni<80hN^i07f:
DP3;fiX0fNZT0<kRVP2P^fh0_nBF0=CaW`3:gi80eMfR0<G?TP36j9@0c_VZ06:CIP1AP5h0^>^N0;od
XP2_ijP0j?[B0?3]cP3MaKT0oo?_0?Who@3nool0YZJL0<?9[@3ClZh0bN^N0<gLU`3Sk[@0oooH0?oo
jP3oo>l0`[6Y0?KXg`2FSH@0f]G?0?ooo@3noo/0joWP0>3_dP38fjh0dNF`0=W^/`3Ck:P0cNNN0=Wc
[03Om[80PiUI06Ae@@3nnNH0oood0?ono`3nool0jnkc0?3el@3looH0ooo]0?ook02FTG/0hN750=SX
]`3Dijl0cnVR0<OSV037hJ00f_6k0=?T^P33aKL0RXEo08f1Q@2eYZ/0o?;`0?olnP3emNd0o_of0?Ko
jP3bon<0b>2^0<gV[03;iZ<0cNZJ0<cWUP3Smjl0Y[ac0<GMT`37hiP0b^RN0<[ZW`80anNK04/0b>NK
0<gYWP3<jil0c_FT0<_aW03<l9P0b^bF0=?^Y`3Bk:l0DF<i000=003?fkD0bMF]0?_oi03don`0n?o`
0?KokP3koo<0moo80=WYZ`3>hJ40foB`08JQG032hId0>EPO09BaP@3^on/0k_oa0<K/g@10RGP0O<Fl
0<Gfl02eZj`0ooOo0?cco`2JYih0XK2M04A_N00ZGVT0hooc0?Woj02a^8l0f^Jf0<CFXP3:h:l0j?[@
0?_ok`3noo@0loC_0?kon`3loOP0ookk0;2XYP2]YJ80oogh0?W_iP3Ne</0oogf0?oim03oo_/0n_Wg
0?gon@3konl0m_oS0=o```3hom@0cnJR0<_RW03KlK40cn>^0?Soj03ionl0l?_[0?gml`3fln`00P3o
o_l09P3joOH01@`00<SG[03Dijl0d>ZS0=gg[@2hdXP0WjU/09RLJP3lo^P0oooj09FCWP12@4d0ooko
0?[im@3no?00oooZ0=WE_03Jk[d0aN>W0<OTXP34hY`0b>>L0<7LU`3Zo/T0n?oO0?Soj@3bnO80o?oo
0??bnP3oool0n_oZ0?SogP38h:@0d^b[0<_XYP3;ijX0bnN/0P3=iZ`09`33dIh0jO780?ookP30_KH0
UY6=0=GAa@3oonD0hNji0=7UYP3ClZ`0doB]0<cQZ@2ia9T0gMc:0?omnP3onol0ooco0?KcoP3nool0
o_ok0<G0^P3cj^<0noGg0>[oo`1QZ:X0f_oo0>_oo`1UKDP0MT/[0=G@Z02CV7002P<00:K1O03>l:<0
`N6E0<WYW@35iIT0b>RL0<_[W`0;0?ooo`002P3oool03P3<iJ40`mfL0<cVY`3Ckk80b^NW0<KPW`3@
jZ/0looB0?SoiP3_nnD0nOok0?_oo`3iool0n?oo0`3gool06`3`noL000400?ckn@3oo_d0ooWj0?o^
l@2gKWT0[6Yd0?ohm03ok^X0ooK/0?oii03>eZD0d=fU0=ke/@2cch@0OGdo06MB7@2YU5l0a/J80<k/
Y03KhJ40h^NU0;[OTP2nhiD0d?FW0<GWVP030<WYW@80b^VM0?l0dnnT0<[TVP2W_gD0Pi]A0<gUV`3C
jJ40aMNK0<7>X0001`00N7eV00lE003DgJh0iO>f0:c1M03>iIL0e_2W0<_YW`2gfH`0e^b^0;FeT`3R
gL00oooQ0=S]/P3:jJ<0cOBQ0;kNTP3SlKH0c]bO08BMC030f8`0`=ZC0<kWY@3OmkT0a]jR0<_SY`3;
i:<0bN:Q0<[UX03:iIh0g_F]0<WPW02[`H<0]L^=0<_OXP3DiZX0cMjW0<CC[03Mil`0^;nh0>[ajP3S
l]D0c^>h0<SVX03:iY/0d>FP0<GDV@2c_H/0CEXU0>Oi_`32hi@0eOBT0=K[YP30gYH0Q:IL08j^I@3B
jJ<0b=fH0=WUX`32cH/0[;Me0<;LU@3Im:d0d^RP08NME03Jkj@0cN>J0<cTYP3;j;00K48Z081B>`1<
ER@0/[n:0=OY[@3Bj:00dNRP0<cXWP33hIL0eOBX0=?WXP2b]X<0Y9mg0;>LSP3omo<0ooKh09jDTP3o
ooH0n?[R0<O:Z`2c]hD0e^6E0=GNW@2DV6H0ooo_0?ohlP3oo?d0ooOe0<2k]@3mn_40inOK0?Ojj@3o
onX0hNK60>G]b03>ejX0c=JT08bGG`3Mj:`000/00<cKVP3`okh0/lJ408fXH@3Fji`0dn>H0=WQY@3[
mKH0[/]i0<7VV03:mLX0NJF40;KVW02nkYP0dON/0>We]@2m_X@0l?Fo0>Kd``3Uo=80jogE0:jfQ`3Q
k;00an^A0=GmY03Rn[h0i_O:0?koi03on_H0ooWm0?ogo@3onO/0oo[`0?ool`3ioo40n?o]0?7oe`30
dJ@0f^nf0<7GV@2O^7H0:D<004]W6P3Lnjl0bnNL0=;`Z033gI`0g>K10?SnhP3in_80oOcj0?ono`3i
m?40mo;/0?ool@1UHe@0o_c_0>3Oc@25QF<082400?3g``32bi@0d]bZ0=[R^`3Kh<80ETm507Y_J`3o
mOD0oo_h0>S/gP3noo40lOcN0>7ac03DjkD0cNFW0=?]X`3BkIh0b^JB0=?]UP3=iI40IGTb0<[PV03?
jJ00dNfS0<WYW@38j9`0bn^P0<c/X@3=jj40cNNN0<WXW032k9X0_^FB0=7aYP3>jjP0dnBh0=;M_`1_
KF403`P00?okk`3om^H0oo[^0?Sjm@3no_`0oOgk0?cmn03Lj[L0RY]T07Z@DP3Hm[00d?2W0;kPUP39
kZP0an^[0<ka^`2lgJh0Mj>008k?^`0iNX00gOoo024L602HPhX0j]WS0?Coo`0N;R@0nOSo079kS03S
ool0en[<0=KO]03Cgk40h>_00?7lfP3gonH0o_oh0?kno03cl_0000P0oook0;^i[@2ETHD0oo[^0?on
m03on_<0Uhf;0=C:b080oogk0640ookk0?kmn@3loOD0o_kb0?ool@3eon80WJn70<GP[@3Ak;T0h?[=
0>gogP3co_00koC`0?ono`2WWi`0YYnI0>gWi`2<QXP0ooof0?kok03>fZ`0c]fT0;c@R@2J/6D0OI=8
0>_`^P23PEP0o?WZ0?Wem03hm_l0o_ko0?koo@3dn>T0nooW0=GL/02l`i00b^>R0<KSX@3@jZd0c^F]
0?3oe@3fon00o?o/0?_ok03fn>X0m_K/0?ommP3oo?l0ooko0>[]hP3loo40nOoZ0?Ooj@3gon`0mOo]
0?Gok03gon@0mooQ0?kok03ko>`0b<C10?C^l03lm?80oogd0?ook`3non40jOK;0<WN/`36gkD0e^Vk
0=g/`@3Uj=D0bLJo0?oko03oo_l0o_oo0?Won03anN`0oooc0=3<`03oo?/0mOoo0=Coo`22];/0AGYd
06B>IP2CP600bL^S07Z<G03AhjT0CgDZ0;CESP3<jJH0cNRU0<KQW03Eljd0bNNO00/0oooo000:0?oo
o`0]0=_f[`3Im[@0f?Jf0<_YZ`32h:80`=bO0<gV[03comH0nOoZ0?GmkP3ioOh0o?oo0?Woo`3hool0
mOoo0?Coo`3Gi^40SYVC0>SWh`3on?H0oocj0?o^kP3ofn00agN20?oZl`3ooO@0o?oa0?cnj03jon80
aoBc0:gZVP2`lYP0_>RA0>;[Z01YCA/0VGU80=gBVP11E180VJES0;o:R03@k:80bNFJ0<S_X032ji`0
b>ZM00<0bNVM02D0b^VM0<OSV03BkZ<0d^ZP05id:`3<h9P0fNfV0=g_/@3Dh[4000P005eRB`001@00
b]:S0>7//P3>h9@0Y;U/0<WPV03;jIl0a^fJ0=Wb[P3Cf:l0OX1I0:>XO`3<hZ@0_]jE0<W_W03?kZ80
eNFW0=3PX@37h8d0d>VH0=WaY`3@jZ40^M><0<cWXP3?jZD0cnfS0080o`000>40bnZL0<SOV@3DjjL0
9S`005ec<P36fiH0en^V0=W/[03Kjk`0c]Vi00XB1`3ioo/0j_SQ0=W^a`38iJ80b>NK0=7WWP3NkZd0
c]VQ09BRI`3:gih0i?nf0;KEQ@2oe8l0b^jT0=Kh[P2ie8d0dNFP0=3ZX`37f9@0koZh0866AP3FkJL0
b>JN0<[TVP2H/6@0d^JN0=KWX`3JkKH0c>:c0?oJa03gbK80bmVT0=S/[`33g9X0`^6E0=SgZ`2de8P0
g_jc0<SXW@39diH0EE@V065I=@3on^l0ooOf0?g]k@1REe<0F5A80:jdTP3Dfk40g>JY0>CaX@3NijH0
VZ5^0?ool@3oo_/0l^W/0?omo@1EDTT0oOk`0?ook`3nonP0k_KA0=OP/`3;ejL0f^B_0<oJXP2nbHd0
d=bN051N803Pk[00^LN:0>gm_`3LlJ`0AEL;04eK403>eYX0b=BD09>_F`3EmjX0a>g3055jFP2mkJ<0
`^bH0<KLT`26RdT0U9]H0<SQW`3DnkP0`NN/0;gJXP2RYfl0f^>P0<CYS032jY40_m^Q0=GW_@3lonX0
oo[m0?OQk@3om_l0YHnB0?khk03gn^D0lOoT0>kog@3PlKd0cN2Y0=7UZ02=Xf80TZUU0<WUVP3Ckj80
_Mb>0=?bYP32hYH0dNnY0?Sog03kon<0moW/0?oonP3nn?P0oock0?K]j01BBd40blNl0?Kfk03elnH0
oooV0=_F]P12@aL0k_720=cQ^@3=d;400`<00:fVW03oo?P0oo_f0?ohk`3ionl0mOoX0=CV_03Aj;@0
bNBQ0<KRV03CkYd0dNZG0<[ST03Hkid0c>6B086GC`3JlJT0d^jT0<_YW`3<k:00aNFI0<SXW@3;jIl0
cNVO0<gWWP3<j9h0a^bO0<CYW03SoK`0g_Fm0=oZc03`ln80Mfm]00P0003om^l0onkR0?oll`3ln_/0
ooko0?olo@3oo_l0o?oO055Q<P3CiK40d>Z[0;KCT03Cm:d0b^jX0<KYY`35iZd0a^Nb08fcS01@QG<0
C9:J0;?Yl`1mMW00n^;R08=`LP3Wn_h0P8n<0?omo`1lPY00hooo0<3D^01UL4D0j_?80>ogd03nonX0
o_oa0?3bk`3oool0oocm0?onn`2CSh<0gM[;0?ool`3nmnd0ooSc09^ATP3>aLH00P3ooOl0:`3oood0
oook0?oon03ooo@0mOCR0?_oiP1iRF80a=n/0<[W/@3MmlP0m?oS0?Ooj`3oooH0ookk0;6XX`3Ug=L0
Bd930:jUZ02UXYT0nogX0=CM/03Jijl0k_ni05M/8@27Ve<0dM>Q05=?:P3oo?00ooko0?omo`3jn_l0
mokf0?cok@3lon<0VJI^08jJG03<iYl0a^6L0<_RZP3Ai;H0nooX0?cok@3ooo@00P3oooH20?ool`06
0?Ocm03lmod0oooj0?komP3eoNh0lOc/0P3gooL0:P3gooD0n?o[0?Soi@3io^X0oood0<g=a@29QX40
oood0?ook`3oonT0o_oQ0>3/a038gKH0dN[30<3FY`3Yo<h0o?o/0=KGb@2h]k80o?ki0?_on03hoo40
mOo/0?ook`3Kf/P0o_ok0>7_l03Vool0gOoo07VZYP00<`d0Hei00<gM/03Elkd0`mfN0<_[XP1cSD`0
bnFV0<SPXP35gYd0eo:_0<cWXP/0oooo000:0?ooo`0]0<KWV03;kJ40_=jD0<[[YP3=k:P0b^NT0<KP
X@3DjkD0eN;60=OPc`3inOT0ooko0?ooo`3lool0mOoo0?Coo`3eoo/0NX5j08b1O@3olo00ooKd0>k4
a@2dRX/0oogd0?kgk`3olNl0oooh0=g_e@3Dh/40clnM0=[^Z@36fh`0f^6A0=_WW`3[fZ@0g<2>0960
C03>e9P0e^n]0;K=R@33chd0fnRS0<K[V`34kid0a^^M00<0b>ZM02@0bNVM0<o^XP32gY<0dNNN0<_O
U`3Di9d0cMjG0=;WYP3:fjL00@d002X^5`072@00fMna0=GMY03OkjH0RieA0<kSWP38i9X0^^::0=;b
YP37fId0hO2g0=c[/P1?IR80_]Z@0<3PU03;jIl0bn2O0=3SX@3>iI<0dnZJ04=K3@2D[600e>nR0=7]
X03<j9/40?l0002e0<cUX`37h9h0d>NQ08jVG03BjiP0h_VW0<KMS@3DiZX0d>2c06=_F`3iooH0mooa
0?Coi`3@kZh0bNNM0=3YV03Eii/0f^NQ0<gNV0004000c>nO0<OXV@3@jZ<0_NVL0<c/X`3?hih0UZER
0<cZXP3CkJH0bMFC09ZHF`2ndXd0e?:X0<OXU`3ElJ@0SIiJ0=KQY@3]m//0nOoQ0=RYV@3b`jl0fo>e
0<3OV@33iIT0bNNO0<_VW`3:j:80a^BN0<[WY02OWf/0XIad0?ooh@3omn/0oo[d0?ohl`3onnl0oooZ
0=[R/@3GiJX0c=jB0=CUU`3=f:00cMB[0?Shl03ooOl0ooWm0?oonP3oonP0oooQ0=gV^`3Fhjd0eNFW
051P7`2@X5l0enRR0=_ZY@3Ij:D0TJ1M0<kJW03NjJl0H6/a0>7/]03EhjD0f>JK0<gJTP2>VU`0DV4N
092YE@3>jYd0HH5J000=002eh9T0b>fP0<gMW`2KWF/0RY5N0<g^]`2ijk00BGm5096jPP2:Uf80hNjf
0<O[Y@2oj:80a^Nb0=kdc@3kond0oo[o0:ZCX`3om?l0ooSj0:BOR@3Mi<80cNNg0<kZ/03Hk:L0e^ZU
096VH`2:We`0e>VV0=gf/P2nfI80d>jV0;kLTP3JnZh0_=bA0=?//P33eZP0ooo]0?cjkP3on?H0j][K
0:RJVP3oo?X0k>OS00L6102k^[H0ooga00d600092000hN;303Hh800D5@<0^kf_0?[jkP3ooo<0ook[
0?7df@3;iKH0anB^0<_ZY`3=kJ@0bnfI0<_[V038hYP0bn2K0=CVZ035dYd0UJ9/0<ONVP3?j:@0b^JL
0<k/XP33hiL0hOne0=GcZ@3=jj40b^FN0<kUX@3AiJH0g^nk0>Wib03loml0oOoU0?oom03oo?/0>C0c
00L0002<Pg80PGMN0?oojP020?omo`0[0?ohn@3oo?d0f]O@0?Ggj@3nond0nOoT0=o`aP3Ej;X0_]NP
0=G^]`3<i;00eNfk0=G_bP2=ZIX0L[Vm03UdNP2FQ800f<Zm0?col`3Lool0n?oo0=kNgP3bool0Y=cM
0<;Tb@2AXGX0LgeJ0?ooiP3dl^H0ookk0?ono`3ooOl0noWl0?cgl`3oo_<0oooa0?onm03onO<0oogk
0?oio`3oo?l0o_So0?olo`020?ono`0c0?oonP3oo_<0QWm]0=CK^@3Ch[L0_]ZO0<g]ZP35hYl0e>f/
0>3Z]@3FfZP0_KZ?0?omk@3ooOP0ooOh0?olo@2XY9/0ooo/0=[O]P3Hgj/0hnf^0=7MW@3Cgil0fmNa
05mH?P3`jN<0oo_o0?glo`3gnoh0nOo]0=OV_`39g:D0U:YO0=W`X03<i9X0amjJ0>[jc@3lonH0j>OR
0;jj^`3Bb=40oo_o0?oko@3oo?00ooo/0?Obk02j][<0o_gh0?konP3inO/0o?go0080o_ko01/0o?oo
0?col`3lon`0m?oS0?WoiP2V/Xh0RiM_0>?__`3DhZl0enJ_0<OLX`3VoLD0k_oD0?7ofP38iZX0b>6W
0=[W_03lon80o_oV0=SS``3]oMT0kooI0<?EZ`3:e;40UIYj0??omP3eool00P3kool03@3[ool0Nk6I
0009003<ml40Z]jL0=Cc[`28Te4000/00<kSZ`3AiZd0bMjS0<oTZ@3?iJD02`3oool000X0oooo04D0
b>bE0<S[V`38jYd0a^^N0<SZWP34hYP0cNRS0<kVZP3>g;T0eMo70?oonP3ooO/0oocl0?ooo@3hool0
m_on0?_oo@26Qh80ak>b0?ofmP3ol_<0FCHd0?cej`3lo?@0ookj0?okn`3onoX0k^;D0>KPb03Uk;T0
dMfM0=_]X@3;i900`n:F0>;RYP3Se9d0FdhJ0=;EW031h9d0b>FR07=l>`2ka840_]n@0<G/V`37jI`0
c>jQ0<KXV`3:k9l0bnfP0<WYW@35i9P0cnFL0<oSV`3JjZ<0c=fF0=[`[`3=gj/01A4007]oJ0010`00
I6Lj0<cAV@3Wm:`0SIeD0=CYYP39iI/0b>jG0<_/W@3Bij@00P3CiZH03@3BjJ<0HGdc0<WXW03CkjD0
enf/0<cQWP3Cj9d0e>ZO0=C/XP2F[V@0QZ1F0<GQUP3Dl:<0103o0000O037h9h0a]nK0=SbZ@2ofXd0
SJIB0<GOR03QnZH0d^NV0=?U/@0Z=ad0ZKFQ0?3oj03conD0anFW0=?aZ@3=iYD0e^^L0=GUVP2AXeT0
c>:G0=?fYP34iYT0cNRQ0<7]X039iil0b]^G09JRH033hiX0c^VR0<cKV02QXF<0e>FQ0=?_Y@3=l9h0
eo>V08RHE`3Eh:H0jO;70?Woh@3]_Zh0omK20<_UY01_TdT0S:iR0=_a/02ndi80dNNW0=G[Z`3eom40
n_S50:BQN01PFSP0h]O50?oll@3nl^H0ooo/0=kJ_@3Wl;/0dN2O0=K[WP3=gYL0g>Ff0=?J^@3ooo/0
ooko0?chm`3]kN40gnFo0>O__P3NjJl0fNZV0=KWX`3Cij00Mh]40=[[Y03QlZ/0d^6L0=?RW`3@gZ00
f>>Y06Qc>@2_^X80f^JX0=GSV03Di9/0hO6`0:g1NP2bc7D0bnJG09>]R00jF3`0_>NR0<7]WP38lj`0
^/RC0:b_P03Uk<80OYEW02iK901iYVd0KHY@0=Oc]P2oij40`njY0<WW/`3Bj<40noo]0?[^lP2BO8P0
ooOm0?o_k03dl=<0d]Za0<gU/@3=ijX0e>FN0=CXX@2Q]780`mRG0>7e]P3>i:H0c>BV0<SRX@3JmK82
0<cZXP350=K`/`34f:L0ooo]0?ool`3oo?X0bk^n0<Rj^P3oo?/0@3/h0;2^/@3ooOh0ookf0?ool`0K
7@L0IVYC06I[E`2e^JX0oOoc0?colP3oonl0kO3C0=kX``38ij/0b>RW0<SZWP38ji/0bN^G0=3_W`36
g9/0e^Va0=;O/@3Gg[d0Uj9j0<gTX03=iZ80c>RN0<KTVP3AlZ<0g_n`0<[XWP37hiT0f?:[0<oUY03A
hjL0gn>n0?[nf@3fnMX0oooZ0??cj@2ZYZ<0P7ai00P5003oonD0jng80=cM_@3Qf=T0oo[h0?omn`3o
oOX0oo[o0?oloP3oooX0nOkZ0>OaeP3Hi/D0dN:h0=CU^@3Ah[H0fNZn0?CoiP28YI40:EmO08bb]@3o
n_H0o_o[06n;LP1YXIh0hNkg04Dl?@2IZj/0<7mj0;GSa`35fKH0i>oA0?ooj`3nmnl0oo[j0?omo`3n
o_l0nOOj0?ojmP3oo?80ooK]0?kil`3oo_/0oogo0?olo`3ilod0oogo0?SeoP3hm_/0mO?f0=7=bP3A
b<<0jn;I0?kojP3ion<0m?oF0?7od@34gi`0bn:N0=cXZ01kPDD0ZZU`0?ook@3onoT0ooco0?gdm`2^
ZZ40n_WW0;NlU013BAT0en2W0<oHW`3Cg:D0O7MG00P0003oo_P0n??g0?;cm@3koo/0n?oV0<_M[@38
gZ00T:UH0<KOR`3Bj:00bMfN0?;neP3io^L0RXB40=[@f@3olol0ooCm0?ojo`3omn/0l^[G0;6_X`3=
cLD0oooh0?oonP3no?l0o?_o0?omo`3oo_l0n__o0?kol`3]lmT0amR/0=W`_03Bij`0SjEU0<WNV@3B
jJ40dNRP0<_VW`3;jJ<0aNFR0<W/ZP3_olX0g_^h0<_LZ03IiKL0g^Vo0=o_`P3@i;40d>Na0?;od`3O
k<40`LVT0>okk@3bn?H0oo_o0?cfo`3Xmoh0Q;NV00090032kKP0_Nj/0<[UX02i_gl0G6/b069g?`1M
LSX0P9EJ09FZK`3Bj:X02`3oool000X0oooo00<0bNbB0<W[U@38jiL00P38jiL0@@38jY@0c>bI0<[V
V`3<hJT0e>Fi0?kok@3ooo<0ookh0?oonP3nood0o?oo0?ooo@1nMW@0S6ma0?odm02nTY<0oo7b0?km
n@3oo_l0oo_o0?7@e`3MWj`0[gUg0<bWU`2eUgD0Y6E608]=:03Ae940`NJI0<oXY03AgIl0`kb80:6E
I@3?kk00]mjK0=7KW02a]gL0W[=X0=7YW@3<iY`0a^FI0<SXW038jYd0a^^M0<k`X`36iYX0bN>I0<_Q
V01?GaP0_m290<WRWP3@hj`02aX0061RBP0=2`00Gehb0>KV/037dH`0Y[=]0<KIV@3?iZ80cNjM0<k]
W`3Ajj40dn^Q0080e>ZR00d0c^FM0;C>Q@0K=`00gO^c0=KaZP3?hih0bMjI0=[_ZP3Sn;<0e>VT06Qo
>@1bS4<0c>JL0080o`0009L0a>2E0=C_Z03FlJ`0an6J0<?MT`3Kmj<0_=Io035:003:hYP0^Lf@05=T
>P1XN5<0gO;90?Cog036i:H0c>^W0<_VV@3Om:D0`MB509J[GP3>iYX0^]nA0<GZW@2adHP0bNnT0;S=
R03KjZL0U:=P0;kLU03Jn[40amjH0;:mN`3@g9X0dnVQ0<k]W`31g8l0c^:K07F3A@2iai@0fNbo0>Vo
Y`2KLUH0/m2=0<O/WP36iYX0TZ1U0=OT[03lom40b]NQ0<gKYP3Hfj@0bm:N0>[b`@19D2L0HfA204m:
:P1CCBT0GeXb05AG8016D140fNfX0=KXZP3domP0o?oX0<74_@3ooo/0nok]0>O[d03EgjX0amJE0<OI
S`3Om:D0e>FO0=o_[P3:fiL0WJiX0=OXXP3AhY`0f>VS08BDD`2W]gP0gnna02hl0017DaD0fo2U0=_c
Y`39i9l0b^JK0=3ZT@39h900cn2n08ZQQ`3?lk<0^NBB0;_WTP2_a840[KZ20=_^`030i[<0[NRX0:cU
X00SB@008D400<S^X@35jZ@0i?W@0?7oh@3cnnH0oock0>SIg02BP7`0bkf`0?ooh`3enM@0k_gB0=g_
^`2H[F80RYiG0=KX[P3Ql[h0i?C70=[Y`P3RlLX0l_oF0=g]_P3DiJl0cn:Z0=OZ/`3Mj[l0n?_Z0=OD
c@3WhN40oo_o0?olo@3ooO/0=c4a0?gkoP3oo_l0nOWg0?oon`3nooH0o?of0=cSf`3koo/0l?O_0?_o
l@3konX0d=^`0=?V[P35k9d0aNbK0080a^bG01h0bNVM0=3^Z03Hj[P0n_oP0>_ae`3EeL/0h^OA0<gV
Y@3;iZ<0cN^S0<[ZWP39jY/0a^NH0<STVP3:iIh0b^>O0=GYZP3EhZd0^KJG0=OG]@3JfkT0i^[90>CZ
d03cnn@0MH5Y000>003Fj[T0`mRO0<oO/03im^l20?onn0090?Wek03omol0ooSo0?oio`3oooX0oood
0?cok`3konP0nooT0080nooQ01h0mooS0?7oj03XonP0l?od02@l;013DS/0XKVS0<Skm01KQ8P0B4A5
04A@CP0/PgX0M[6M0?3om03hoo@0nOW]0?cbl@3oo?l0o?co0?Wmo`3oool0ookk0?olmP3oo?X0THb9
0<c7a03oo_/0hn;N0?oon`3in_D20?ooo@0^0?Kel`3Zj>/0oo_o0?oko`3kn_l0n_ok0?Wol@3hon`0
c]ff0:BaQP3>eZL0c]BV0=GGZ03gm>D0ookk0?oio@3ooOl0Qh9o00<1003Kg/40fMfj0=?J/@34bZ@0
/;JD09NBO`10>2d0ookh0?oonP3Wl=l0nOo/0<gQ[03AijL0^M>:09F`G`37hY40g^nh0<cG[03oonP0
oOcZ0?ojnP3om?/0oNcf0?ojo`3on_d0bl:k0?omlP@0oood02h0ookm0?omo`3oo?l0o__o0?gmo@3o
oo40jNoE0=7Y[`2kfI40`N6>0;_IP`3:ji80b>VB0<_[V038j9d0bN^O0<GZW@38kId0co:R0<CSU`3L
kjl0fNV[0<[HW@2^`H40cNBP0<KQWP3AjJ/0c=V]0>ged034^K<0ooWk0?o^l@3hnOd0joko031NG000
50h0b]V`0=[//P33ehl0fo2[0=gc]@38gJ80`MJM05Q]<P0iCa40b^2P2`3oool000X0oooo0480b^^D
0<W[U`39jiL0b>^G0<S/U@38ji40b^bE0<OWU03<i:H0en^h0?coiP3oonl0oood0?oomP3lo_T0oOol
0?kjn@1jL740R6i_0?oem01X?Sl0ono_0?oko`3on_l0onoh09ERJ`2`KGH0N3Td08A<?`1f?RD0WU@k
0:5F=`2=KCX0_=>=0<c[Y@3;h9l0dl^J0;ZRMP39iJP0`NRU0<oNW@3LijD0Ri]B0<OLS`3Ejj80bNFJ
0<_ZWP36j9/0a>VK0<;TU`31hiH0d>bQ0<SNU@2P/6T0WZmX0=C_ZP3Cj:l000T006a^EP040P00D4dR
0<g=U`3CgIP0U:5K0=[][@3<hZ420<WSV@100<WTU`3;hiL0c>:I0=7WW`33fI40^M280;kJT01kVdl0
NIM=0=KYY`3=hYl0_mBA0<gRW@3;h9/0cnBO0<_PV`2cbH40UJaT0<CKT`3Mm:`0d^jT0<;MUP3Fkj/0
cNNN0<_VU@3@jIH0`mb80=cdZ03Gk:/0e>Jd02i0403Cj[H0goS10<WYZP3=k:T0b>:H0<SMTP1iRcl0
c>6D0<[UV03:kj80c?:U0=Cf[03@kZH0fnbX0<SGU03:gYT0b^FN0<OWWP3@jj@0dNFP06A`;P2_`7X0
dN^Q0=G]X@3BiYh0b]^G0<OJXP2abID0Pei10;bEM03;iZ<0b>ZM0=CdZ080NXQ=06L0ZKAl0;o:TP3O
jK@0fN6U0=OUZP3Ljk80enRb0<cHYP3Xik/0fmNZ0=gFZ02/[7H0Jg<g0=7TY03@hZH0nooM0?_oiP3F
f/`0oood0?oojP3Zl/d0enFZ0=?TX03Eiid0a=V<0<kNW`34dYD0hO6b0:FeM018FAD0cn2J0=7RW03K
kjX0TjIT08JIE`3IjJX0Wje_0=S`YP36hYD0b^bR0<[ZWP3@jY40enjN0<GD/`1gRG40`nJV0<K[W@37
hiP0UJAY0<3BXP36klL0^OC80;Gla02hmKX0_=ZL00@M0034iJ00b^V]0?WoiP3honX0mo_/0?_cl@3o
n?P0ooO_0?ogj03oo^<0nocM0?koi03komd0SZ9J0;K9Q`3Bhjl0ho;70?Woi03konX0o?oZ0?coiP3Z
m=40gNRm0=3L[035dJ40_LFP0<W;_@3<blH0o_[k0?omo`3nn?X0oogm00<0003im?P0noWn0?koo`3h
n_L0oOoi0?SmmP3lood0mO[f0?Smm`3lonl0k_OH0=KS[P37fi`0aNfG0080a^bG0200b>^G0<WYWP33
gI`0ioW90?_oh`3nonX0oood0?SkiP3?jJX0b^BS0<WYX03:jYh0bNZK0=7bX`3FlZL0d>ZS0>_o_P3J
k;00a=>L0=7F[P3Ig[D0i^jo0=cU^03Vl/`0d^2m05a]B`002`00dnZf0=?//P3gomX0n_[`0>o_i`80
oooh05P0ooWo0?oko`3ooOl0oOod0?kol@3kond0j_SE0=SV`P3>gK80cmnb0<WJ[P3:gkH0bn6c0<GT
^`0B?bP000L0014I2P2:[jP0<F9V0:>WZ00Y<Rl0020I07^gZ`3Zoo`0l_og0?oon03ono/0oo[n0?_n
o`3go_l0o?oo0?glnP3oo?P0oo_k0?7YiP3oo_P0nOK]0?ool`3noo40noo^0?ool`3gmnd0ooof0<G3
a03oo?l0o_Wo0?gko`3no_l0o_ok0?Wol`3TjM<0]K^Q0??hfP3Uj<T0k?3?0?oomP3^j^T0oogo0?K_
mP3dl>l020P00>[/eP3`lmH0lOKH07AhG@1eNF80_;R]0?onmP3im^l0o?kc0?_ojP3EiKh0bMnO0=3Z
X@2O^Vd0_=N80=ObY@3Njkl0nOoO0>c[eP2]YiL0ooGb0?ojn`3onOl0jmcO0;2TYP3oo?T0ookh0P3g
n^l20?oom00>0?oonP3ln?T0oogo0?gko`3ooOh0o_oa0>W^e`3>hjX0d^fX0<SUU@2H]F40^]Z50=Gd
Y038iY`20<OUY@0N0<GVW`37ii`0bnbM0;kMT@3Ej:H0Y[Ig05QV:03GjZP0d^VS0<cUX`3Rn[h0i_;:
0?Ong`3Vem80Tgeo0?oin03lool0l?oo00`e>@002@L0gnO00<_@V03Rm:X0`MbE0<gWYP3>i:H0f_2b
0;[@T0097`00f>j]2`3oool000X0oooo00D0cNNM0<cXWP3:j9h0bNVM0<S[V@020<[_TP3J0<CWS@34
hYP0a^2O0=KY_03Fi<<0l__V0?Wol@3io_L0o?ok0?ono`1lLg@0RgUi0=Bl^P2JOW/0oncZ0?oio`3o
lo`0oo3j07/Y;`3NWiH0YUA609@b9@28:AD0aHm]0?2eU@3>M5X0e<R>0<_YX`3CjJP0imVZ0?BoX03C
h:X0`^JV0<kWY@34gYL0b]J>08FAA`36eXl0e>ZQ0<oYW`37ii/0b>ZM0<_`XP36jid0`n:F0<OQU`2i
cHD0Vk5X0<KTW03=iJ/01aL006Y/E0070`00GUTa0=;@W@3Ih9`0d=^G0;?6QP3Lk[00d^:S0=3TW`3>
iYX0c^JH0<oUVP34eHl0f>VU0=S]Z032gIH0a>VI0<S[V`1iSdL0EV`T06Um=@2jcXH0io^c0;o@RP3K
k:H0fnZW0=?RW`1nRTX0N8U50<;NT@37hiT0bnJS0;[ETP3GlJX0dnfS0<[UUP2J/V@0amnE0<CHV@3I
kjh0cNNN0<OUW@36iZ<0_MfL0=;[ZP1iST/0cMjG0<GJS`34gY@0`nNM0<K_X`31hiT0h>n/07n8A`2J
ZFH0g_F_0<CIU033hIT0b>bR0<3VV`3<eiD0Y:YZ0>Gf/P3Hk:@0f>fP0=3WV@3<k:<0^n2K0:R;H`39
YWh0dNZX0=Sf[03<jZ00dnbX0=S_Z`3@h:40dMfO0:bbMP3Dj:40b^JK0<OWV`33iYH0a^2F0=CKV03T
hZD0dlVD07A^?P26QED0gNZd0<gPX03=gjD0Z[R70?7kf03Qj<L0ino60?kofP3Njk<0]<B609>UI`2d
aX`0aM6Q09RQM01nR5H0OhaD092PHP39g9X0cnBO0=3WW`3XokL0OiU?0<gTWP3>hJ40OIa@0;_RT@2R
cX40g?ne0=OdV03GkI/0SYQf04eIA@12HBD0c>ZT0=?NYP2<UGP07S<R07Fb[@0SM6d0C9f:08?3Z`0Y
?B4000L009R^R03@hl<0n_O^0?oonP3nn_L0oogo0?omo@3oooH0l>[N0?ool@3on>l0^k6`0:JSU03E
j:H0f^bb0?_oh`3kon`0n_oa0?Cel03ooo/0kN[Q0;fi[@2MVh@0/K2D0<O4X`3OgLH0m_G`0?koo`3l
ool0n_ko0?coo`22PX00Hf9P0?olo`3ooOl20?koo`090?;bm03oo_l0m_Cg0?gkoP3ooo/0k_3J0<oC
/02LY6P0Tj=L0080b>^G0580b>^K0<WYW@3<ij@0fO6c0>3a_@2obid0QhiU0?ooh`3KhK/0i?k10=Se
]@37iih0bNVM0<OXU`39j9P0`mfC0<kXX@3Jkjh0VJ]a0;_?TP30gYH0a>:H0=;aX@3:jIT0a^6L0=K`
/`2AYgH0:T0B0=_a`P3AikH0n?oQ0?;gl@3noo/0n?[g0?ooo@3ooo@0o_oa0?Kni`3MjlP0e^S00=;X
^@38i:X0`]jS0<WVY03@jjP0cNJT0=7SY`3:k9D0]^^I0;7ff@2cak`0ZJBQ0?Oin03Vool0LGan0001
001^S8X08UEF0=ooo`3aool0o?cl0?ohmP3om_@0nOoo0?Ooo`3iool0ooom0?olnP2UVYP0oooc0?ck
i`3lon80kOK;0=OS/`3;ejL0cMJY092DL`3NhL@0oooc0?coo`3kool0ooko0P3onol0F@3oo?l0bl;3
0=OAd@3fmo80n?gg0?Kmm@3lo?`0lNob0?omo`3dlO`0ooko0000003ooo@0k>kP08>5NP35a[h0ooom
0?[im`3ooo/0ko7T0?cok@3Chk@0e^^`0=7/W@38i900OiY90<GLUP38gZ00o_o/0>WZg033_Jl0oog^
0?oahP3on^/0[InD0<Vl]03dj^P0l_3c0?ono`3kool0nOoo0?conP3ko_D0oooj0?onn`3oo_l0oogo
0?ooo`3moo<0lOWT0>C`bP3Sl<@0Zkb50;g?U@3YnlT0g>g30>?bd@3Tlm`0ho7H0>GecP3Rm<@0e>n/
0<kYY03CiJL0d^2U0;_6RP2/_7h0dNJU0=G]/`3bomD0m_oW0?oomP3oo_X0ooof0=SBaP3oood0nooo
092]_`19NG/001400;:nP03Fi9L0co>Y0<WXXP3<iYl0an2L0<?LV00Y@P00cNJR00/0oooo000:0?oo
o`3/0<oVXP3=iZ@0c>NT0<WYX038ji/0a^fB0<K]T033ihd0aNFI0<?PW@37gjl0aMVd0>gmh`3hoo40
m_oe0?Won@3oo_l0MG5`089gM@2]ViT0f<Fo0?olmP3hool0ooOg0?ocmP2D>cd0WBl`09/U6`2a@S40
N1800;i@?`3[OFh0Y5Xm0<nnR03@ij<0e^^Z0??N/@3oj]00jnnm0;WKWP3?k:T0fON_0>?_Y`2a^g80
YkA^0=7WWP3@j9h0bn^O0<[/W`2khY<0bNjP0<_[W`3BkZ<0b]jF0=3VW@36i9`0dn^a01HV001hN600
1`4009nGL03IeZ<0e=^G0=_VXP1_PD<0QIMK0=KQY@3Chj80d>JK0<oWV@3@iiT0h?6[0=3QW@39gYT0
cNRQ0<ofX`34jYL0`MN>0=;XW`3=hYL0W;5V08jPEP2BXU/0^LV20=OTW`39eI<0c=JG0<gLU`2/bg/0
RjYN0=_f/`35gih0cNJT0=;/X`34gY@0J80b09:ZGP3CjZH0amjH0=?`WP3:jId0bNVV0<GUY02`bX/0
SJ9Q0<_LUP3Ll:P0_mV?0<c`YP2nj9`0dO>Y09VTHP2^]7@0eNBQ0<gWX03MlJ`0_M^C0=Gk/035lJ@0
gNRV0<kCT`3BhIh0cMjG0<KMS@3@jIP0cNnR0<[bZ@1oI3L0YhIK0<GNVP3:iIh0anFK0<CVVP39iid0
g_B/0>7`Z`2;T4h0R:1F0<OXU`2oii40`^ZB0=ShX`3Hh9L0alJ506=J8@2i/H<0hMjc0=;N[03:gYT0
UJQV0:bkPP3Dgk@0d=R_0=_T]`3KiK<0YK9l0<GDW@3>gjT0ho?20<kF[`3]m</0_lRM0;2mR03Ljk80
e>NU0=ca[02meH/0SJMM08NSEP3=iih0bMjM0<[/W`31k9X0e_nh0:CAOP3=k8l0c>:@08R?KP1hPFh0
73X00;KLT@38l:L06C8801``5`3?lo<0eooo076iY@0UIDX0HH5J09fdRP1dSUh0XkB@0?olo@3oo?l0
o_Sl0?ojo`3dl?40oogf0?[fk@3oo?L0jmoO0>oOk03oo?X0_M:A0<kOZ03Ag;`0hN[E0?con03jn?/0
oogo0=C>cP3jlnd0oo_[0?oojP3oon@0ooo]0?Sgm@3ioOl0nOko0?Soo`3kool010H10:b[Y`3onol0
o??h0?_jo`3lnol0ooko0?omo`3oo?l0oogo0?omo@33_ZX0YJEo0:ndM03NjZ820<WZV@210<WYW@39
jIh0c>NT0;[BU03Dhj`0TYaX0<oGY03_lL80d=RW0=_g^P3Gm;@0anNN0<WYW@38jIP0g?^[0<oYW`3C
kJH0/LJ50<CFW03Nm;@0aO6J0<3[S`3;m9@0_^J60=GfY@33hI/0J7m;00HI003:f[<0d=nf0?Coh@3k
ood0o?oo0?Slo@3nool0o?oX0?;mg@3SlLd0bMn`0<7LY`2ng:00c^nZ0<g^Y`3:kj40bNbL0<7QU@3;
iYl0boB<0<?iV`0UGdL0:TPn09RSW@3oo_/0n?oo0??co@1VI6D0UZVW04UjO`3Rool0l?oo0?koo`3o
o?P0oogh0?Won`3eool0nOoo0?ooo@3_i>80l>GQ0?K`h03knn40iNW40=gX/03DhZD0c]bN0>Ka]`2>
U6P0c]:]0?OkhP3ioo80m?ke0?gnn03ooOP0oocj0?okn`3on?P0ooKg0?clnP3`m_80nOoo0?koo`3j
n_`0o?_o0?omo`3]k?802@T;0?SklP3hno00jN_V0?Ggm03mo_l0ooko0?Cck`3^l^<0hncA0<kQZP3D
jjL0e?2K0;[FP@2J]V80c^BS0=7T[03fn>X0oooj0;N_Y02<P780TH9]09R7L`3ooN`0o?;V0?onn03o
o_l0mOSo0?;io`3fo_l0o?ok0?konP3oo_T0ooci0080ooko02X0oooo0?gom`3ioo00o_oZ0?koiP34
cjD0f>>i0?coiP3kond0mood0?[ooP3hoOL0o?o]0?Oog`3;hjL0b>6P0=g//@3GhZX0fnJ^0=;PY@3=
gj<0c>>]0>_md`3honl0ooom0?WonP3Sk^00oooa0>cLg`3olol0IgfD03ahN02nk;/0GgXg0=[VVP2n
gYD0c^bT0<_WW@39i9d0`MbE06N2>`35h9T;0?ooo`002P3oool0P@3@iJ@0cnFT0<gVY039jIh0bNZK
0<;YT034ji00`nN@0<_[XP37i:@0b=j`0<WH]`3conT0nOoc0?Kom`3fo?P0oooo069QG`32^;H0[YnJ
0;>RVP3ooO@0lOoh0?_cl03omOH0ihjB0:<O:P2]7a/0kF]N0:4b7P2L91@0R1d=0;:;I03EdI@0amVO
0=ST/P3on]`0olJ^0<c?VP3LnkP0a>RR0;oSV`3Ci9d0e^:J08^KDP3?i9T0d>JK0<o^XP3=kJ40anfP
0<cbY@30hYD0d^jS0=kcZ02]`gP0_M^E0=;Y/@0[>Pl0LW1I00X4002FTFL0j^Vc0>Sc[P3=hIX0]mBB
08JSH`2AXfD0T:ER08nWG@2?Ye/0T:IK08jRF`2fbXD0cn>N0=gd[033hY80cNZJ0=CZX@3Bj9l0fo6V
0<OMTP3;h9D0ZK]_08RJD03AgYP0f^FQ0=CMW03FiYl0`nF?092_H`3<i:H0c^>X0<KLW03HkjT0`=^>
0:O2L`2@Zeh0e^b/0<cRX@3DlIl0`N2B0<WZY@3>kJX0OYQG0=3VY@3IkJH0eN^R0<oYX038k:80bNnT
0<KTVP2U/6h0e^6O0=o`ZP3?jj40ambG0=3`Y`2oj9X0_^fO0<kRW@3LiJ@0dmfN0=OVX@32fH/0dnjO
0<K[W@30k9l0IT/L09YiC0020<kSX0120<oYX03@lZD0bn^O0;oIS`3Cij00Uj1M08^WFP3Dm:P0a^RK
0<?TT`3:hY@0f]nM0::MIP1GCR<0j^G50?_jf`3/n<X0e^JU08>DD03FiZP0b]NR0=WU/`3EhZ`0dn:Y
09VXK`3=gjD0f>Vb0=CR[@3Ji[@0o?oF0?3nb`3Ij[H0bMZV0<kMYP3GiJX0g>b[09J[IP37hIP0c^ZP
0=C]Z`36jZ00`nfQ07^YH03Bnjd0d>ZC0<CGR02g_iH0ZkJH000>003;l:X0_^fL07>AG@15FS/0_m?B
0=cno`3@oo00Kj:30:[AY02mhK<0d?_>0=_hf@2o/;D0ooco0?omo`3oo_l0oogm0P3oooP06039_kd0
d<760?oio`3ooOd0g^jm0=CQ]P3JhlP0k_;Q0?WjlP3ooOl0ooco0;fd]`3on?H0ooW^0?ook`3km>@0
oogd0?ono`3nool0o?oo0>W^l@2X[:d0PH1n0?ono@80oo_o05h0o__o0?omo`3mn?h0oogo0?olo`3o
n?H0ooS`0::NP@2JVg40ZZm]0<gKT038jiL0b>^I0<WYWP39jJ00c>NT0=;[Z@2``X@0/l>50=SVZ@3>
fIl0f>N/0<W/ZP3=kJX0a^JM0<[XWP3>jI`0b>2D0=G[X`3BiZ40TJAT0>;a]P36gIT0a?6B0<OeT`2k
ihP0a_6E0<7VUP33i9d0F6lk000@003Ag;`0g>G80?[ok@3amoL0nooo0?[mo`3nool0nOoZ0>Cdd03H
j/80c^Jb0<kZ/03@k[00aNBQ0<SYY039jZD0bNVV0<k[Z`3Hl[D0b^^D0<[_X@2N`k40P9Z?0;2m]03o
noP0oo[o0:bZ]@0^<SD0d^_X04IgOP3Wool0m?oo0?ono`3ooOX0oooh0?WonP3hood0o_oo0?ono`3C
bLL0e=350?ooiP3?djh0dMVV0=GTW`3AhIP0QYM@096QH02`^XH0gNBh0?Smg`3koo40n?oe0P3oooH0
:03on?@0ooSg0?oem@3onol0oooo0?coo`3^mo@0nogl0?ooo`3fmo`0no_o0?Kgo0000080o_ok0?Wl
m@3oood0oooo0?klo`3Vi>L0ooko0?kom03`n>40d>6]0<_PW`34gHT0V[AM0:G1K@3CjZH0d^N/0>3X
d@3fn>d0kNWM0>?KcP3Nd/@0el^m0?oml@3oo_@0oO[e0?koo`3kool20?Woo`040?[on`3lo_T0oook
0?ooo@<0ooko02T0oOoj0?kon03ln^/0o?_W0>7Tb@3Yk=40o?o^0?[mm03loOl0o_ko0?kmo`3oooP0
oOo_0>Gfb@3VoLL0k?g90>;^_03EhZd0[;^009N[KP2F[GD0`mJX0>Oaf03[kn00hoOK0>3fdP3do]`0
mnKO0?oho`1nSj4044Q70;gabP1oYW40X[5f0<oX[`37i:40a^BJ0<g[X@3FlZP0KHQ109B_JP0;0?oo
o`002P3oool02`3?iJ@0cNNP0<cXW@39jiL0b>bE0<S[V@34iYT0do:/0=K]]`3Ai;H0en;40080o`00
0=80oooj0?coo`3jo_l0n?Sj07mkNP28MW80hL[40>C8_@3onNd0oooc0?okn@3ol?H0dGb?08/J;02_
7B00ZAH?08TL1@2aITT0oo3?0=_Q]@3:i:<0o?oX0?oim@3omOX0^j:>0=KOW03Ak9d0a>jT0<G^ZP3?
k:T0b^BK0;oFR01^PC80_]240<GKT`3DkZL0anfR0<3YW@33j9X0b^VK0=KWV@2@XUH0b^VV0=?Z]000
2@00LViE00T2001ACR40gn:Y0=;]X03Enjh0]>VQ0;[_Y`2jh9<0aNNK0<_UW03<iYd0d^bR0<GTV02k
fXh0V;1T08>EB`3:cHH0i^^X0<WLVP3Cj:<0dNRP0;cFS03=j9/0e>nP0;O?P@2DYU`0IgL^0>G_ZP3@
h9D0`NF=0<_WW02U/Wd0RI=Q0=_Y[03=hIT0`mb;0=;_W@2ie8d0X[J505Y^?@3Hlk00a]nK0=7[XP3X
okX0`MfB0<o[X038i9X0eo>Y0;G@R@3GlZd0`mjI08fSFP2oehd0dnfS0=C^Y03BlJD0`^:F0<c^X@3=
lZ@0anjO0<C[W030gi<0VImO0:F^K@3<hI`0c>NP0<ge[02iii`0Wh=C0;VDI`2@V5`0ZJid0=WSY037
gi<0b^FH0<?NU`32fiL0OHaA0=7`ZP3Kkk`0l?gB0?;`bP3[i[`0oO;D05E:>03on?H0mo_j0?KomP3P
llD0cmJR0;6fO03Egj80gO2^0=7VX@3?jJ00a^2F0<_QV02W^g<0UZMP0=OYW@3CkI@0a^ZC0;kSU@35
i:T0d^Ri0?ckg03il]D0cl^U0>[``035eid0d_:_0<7MX`34h;00e_74061jC@1oTf00h>b^0=KOWP2m
bH/0a]BQ010X201VOeD0dNVO0<_UYP1TOU40]LNk0?SonP3oond0f=o00<_Y``2gj/T0JlBb02adJ@2b
];40fnSO0?SonP3on_H0ooGa0>3GcP22OW<0oo_h0?ofm`3oood0nooo0?oon`3OgmL0ook_0?cijP3o
oo<0]:ZX0>CJf`3oo?l0oo_m0?oonP3ooo/0ooko0>SWk@0/:c000@0203D`=03Dc]00knW[0?olo`3o
n?`20?oko`240?cdo`3onol0ooOh0?kil`3oond0`/6U0:6SOP3Cg:L0dmfQ071m>03=i9H0a^jE0<G/
V`3@lJ`0eoJc0<WTX@2mf940ZlMj0<c[W@3=k:00c^jU0<K/X`32lj@0b_BX0;cGT03AiZ40e]nN0=cQ
X@2LXV80W:ET0=KRX03=hI`0a]jB0<[XSP3Clih0_^:L0<O/Z@3:k[00b>Z]09:ZMP0X>Q00k>oN0?3`
j03oood0nOoo0?coo`3jn?l0o__o0?Gon`3TmN<0fN_A0<SJ/P3;g:l0d^Bd0=WX_@3fomh0nooa0?_o
n03dno@0nOoc0?ook`3oo?40d/Jj0=GAa@3ooo@0ookk0?oko`1hPHH000T<00Y7@01`Y:80l_oo0?co
o`3ooOl0m__g0?Son`3looX0ooWf0?3Kh03VdmL0k>gU0>_kgP32e:00dN6R0=[ZX@1^P2X0/LE^0=7/
W`3@jJD0bmfY0=CQ/`3oonP0ooom0?kmo`3glo80ookj0?kdlP2f[:/0ooGm0?olo`3ln_d0oOon0?ko
n`3inoH0o_ok0?Kkm@3kood0G6ER00P>303bm_D0ooom0?onn`3ooO/0e<S80?3ZkP3ooOl0oOch0?Og
k@3Pi/@0c=FV09jcJ037gX`0h_^W0<GRT039j9X0cNB/0>Ojc@3ionl0nooj0?ono`3mnol0ooko0P3n
ool50?_oo`040?coo`3nool0o_oo0?7al`<0ooko00H0oogo0?olmP3:_K@0oogf0?omnP3ln?L40?on
o`80oogo01`0mOg`0?Sol@3/nm`0f>S30<_L[`3?iJL0c^BS0=?ZY03Nn;40Xkii0<OPW03<k9T0a=n>
0>km^03kmM40_KNQ0<cGd`3;j>H0C7Yg0=[oo`2J]K00;chi0<cW/P3Em;00/M2<0=Gb[`3DlJh0W;Md
2`3oool000X0oooo00<0bNVP0<WYW@38ji/00P36k9L01@3=kJ80a^>P0>?l`P3Wm/l0io;B00@0o`00
0P3kool0`@3oo?l0JEiR0;JNW03`c/`0IChi0?o[i03ooO@0oo;g0?o_n`1R0aT0okO809`Y902<7Pl0
TC8L0<QaH03oj=d0om;50>[[`@3oonh0oo[k0?oYl02kWi<0f=fS0=;ZX034kIh0ao2T0=3^YP3>iIl0
enfU0:bmM`23U4h0bn2K0=OaZP38k:80`^RK0<?XVP3:jI/0e^JK092RF02ifIH0`=VR000:001bL5L0
1`4005YF:@2m_8@0a=B;0<;IT@33j:D0b^n/0<[UWP3>iIl0d^JO0<cPV@3?iI`0e_FY0<SZW@3@kj40
fo>W09JSF`1>FaD0T:AO082ED03Il:X0`M^B0=SbZ@3Il:P0_mJ>0=o`[02a`7l0cmNK0=CSX038jIP0
e_2W0=_V[036ciP0dMfO0=o`ZP3<hYL0e?2S0<oYXP1fR5@0Cf4]0=[c/@39h9`0e^fU0;oIT03LmZ`0
an:E0<_UV`39hiX0f?:Y0;oITP2fd8T0`MV?0=cdZP37hIL0b^BJ0<KUV@3<jil0a^JJ0<OYW038jYd0
c?6S0=KbY`3BfiP0[;Mc0=7VX@3DkjP0`>RO0<GcZ02<LT40H3/>0=CNX@2e_H408B/00=3QVP3KkjP0
d>FT0>3b]02QZW<0cnZc0=c/b03lonP0oo_N0?omf034^I/0Ng1L0?onn03bn>h0n?o_0<[OY`3LiJ`0
kOJg0<gIU`2mdh/0b>2F0=KaY03>jI`0c>:G0<_PU@2J[680aMJ?0<oVWP3?kjH0b>bT0<c[Z03Cjjd0
^kf<0<O3UP3JfJd0ino00<gM[P3bom`0n?oS0?SojP3Wmm`0k_oS0:FeT@0d?@h0a<jJ09^XNP3Ej/<0
Li1j096/S@2:W600c^N^0;gL/00bDSX02b0=0=7@^`3jn=l0jOcP0=Woj@0aS7X09h9a066HQ@1@Ofl0
VK>X0;J?U03`^<<0h/C40?o`k03omO80on_/0?ono@3inoP0mOKa0?clm03imNT0a/>d0;NaY@3ejnX0
0P3onol0L03hl_@0o?Se0?kmn@0c=C@0DeED0?koo`3^k^`0ooom0?onn`3jm_<0mO3/0?O_k03`j>H0
a;^l0?ono`3ooOd0ooof0?ool`3>dKH0`lNV0<C;X@3Eh:P0gNV[0;S7PP3Fk:40a^bG0<kcYP3>jjT0
c>JW0=oh]`2=YV80aN2C0<WUV036hYL0cN^U0<GTWP37jj40`^:I0<kUW`3aol00/Kaj09RSH@36eI80
bmbH0=K[YP35h9T0f?J/0;gLSP35i9P0c>bQ0=Cf[033i9l0cN^[06IlC@034`00nOg_0?oon`3oood0
nOod0?conP3mo?l0o_co0?Son@3`nn/0hnoI0?;mf`3_nM@0h>_30?7heP3nonP0mOOY0?Cek@3noo/0
lOc/0?K`hP3oo?<0ooK^0?oom03jo?40ookm0?kenP21RY4000`?049oN01l/J/0lOoo0?kno`3oo?l0
o_oo0?Woo@3looX0ooWf0=K4a03WemL0n?c]0>ooh03Di[80dn>U0<gMUP31dX80iof[0<kXWP3;iZ<0
b]j]0=?R]`3nonX0o_kl0?cko`3glo00i^7K0;be[`3Bb/L20?oko`0R0?_ho`3mo_l0o_oo0?Oim03n
ooX0mocf0?Oln01iOgd000800?koo`3knoT0mo;_0>KNg03Zgmd0ookm0?ooo@3inO40oooc0>S`b`3H
i;80/<Ej0=;[V02ofhH0do2P0;WHS03Dk;00g_;10??oi03ioo80oooo0?ono`3oool0o_oo0?koo@80
nooo0`3lool03P3nool0oooo0?ooo`3oo_l0n_Kg0?olo@3elO80o?Kh0?olmP3KdLL0nO3Y0?okm`3o
ood0oooo103oo_l07@3ooOl0nOkj0?WonP3YmN40g>W=0=WW``3Ai:d0dNFX0<KKUP3JlJ/0Q9iG0=;Y
X`3;jYh0b>:I0<gKWP3OfKL0[jNB0??jl`3`ool0N:>L06nJT`3Gm>l0aMSB06=iB`2of9h0h_bo0<7N
W03FmK40bnbU00/0oooo000:0?ooo`0:0<7^V@32kYT0`^jI0<?]V`36jid0bN>V0<cP[@3ion40oooc
0?onn@@0o`0004X0nooo0?coo`3onol05@@<0?kKh@3olOH0UF=V0?oYjP3ol_40oocm0?oknP3mh]/0
W7]/081G>`39WWh0omc20=nn[@2YS8@0oo_j0?oom03onoX0ooOm0?obo`2TQ8T0l^o<0>Kc^`39jiL0
anZF0=3YY`3;gZH0cmn^0=OS/`3Ok;L0b]ZK0=?XX`3;k9d0`nRH0<GXV03<j9/0f>FP096PF`30hI`0
b>>/000?001^M5P00`<00<k<W01WIB`0d]>?0>?UY03LgjH0e]^Q0=_QX@3QiZH0g^>S0=kWY03GiZ40
e?BX0<G/W@37l:40anjM0<c[W@36hI@0bMfF09fbK@3?i:<0en^/0<cPX`3FjK80e^Nc0=WT^@3Bf[40
X:Ao0<[CZ080o`0001X0emnS0>?YZ`1`NSh0d^2U0=c^]03HkK@0`mNL0::`L`0T<P00e>JZ0<SJW023
UU@0RYmJ0=CZX@3?iIX0e>ZO0=;ZWP36gY@0Q9aB0:S0MP3>j9h0a^2F0=;/XP3DkZ@0bN>I0<_UV`80
`MfB0<d0c^ZO0<_WW03JlZP0d^6L0=CUW`2nf8l0^]Z?0=Ko]02^g940UGi:0<n]O@3Agj40cmfO0>;^
/01?F1T0RI=F0<SCV`3Dg:T0][>:0?Wol`3lo_/0ookm0?oll`3ol]d0UXQ]0?onj03dk=l0m__T0>ko
e@3>iId0gNRV0=GPWP2d`gh0`MR:0<[STP36hi40cNZH0=?ZVP3>hiH0U:IJ0=SYY@3@iJ`0aN6W0<cZ
[03@jZT0c^BS0>K^/P3Ef9l0d]JT0>K_`03iom`0k?cG0?Sfg`3oo>d0oooa0<G?]`34dK<0cmba000>
001XPEL0CVa806bFP00XCc@0e>g30<GQ/02ngZ`0f__<0?;oh`1mPV@0P89Z05e[FP0070`0<7MY04>7
NP2?/Z`0e^o/0?coo`3oj?T0bHjP0?okn`3jooP0mOok0?_on`3Zno<0mOom0?gnn@3bl^X0aL6e0?oo
l`3fknL0ooOh0?ccn03onOl0oogo0?[im@3joO80;S`S08^IP03?fl<0nOo]0?[ok03anN80o_o/0?_o
j03oon`0[:jH0?ook03Vj]40mOWN0?koh`31bJ@0`<bN0>3/^P3FiJh0mOo60?_obP3Dj:40enfU0<OU
W@31fiX0koo>0>Cf`P23U5d0[Kn10=W]YP3:gYH0d>JN0<[QW@3?i:40d]jL0<oNV`23U500Nhm:0<GL
UP38hY/0a^JM0<[/XP3:l:D0_^NK0<;ZY03=j;40b>FS08fYE02=Ye00b]nD0<KEVP2]^9X0?DHc0?Ck
m03cnOD0mOg^0>Ofb`3Qk<X0ko?U0?[km@3no_H0oood0?ool`3eln@0n_SY0?ool@3ooo<0ookd0;J_
Z@2/Y:40hMgJ0>CYhP34_KL0oo_h0?olm`3blnd0o?ok0?clo03oo?l0Qi2I00XV:P0PFE<0`>oW0?Go
o`3ooOl0ooWo0?ono`3dnO`0n_ok0?omnP3Wfll0ook/0?[oh`3RmLP0a]NQ0=7PY@0lB0P0d>2I0=;V
WP3<jZ@0cNf/0<SR/P3?i;/0noo/0?_om@3noo/0oooc0;BeY@3ooo40noS_0080oogo03D0o_go0?on
o`3nool0oook0?oonP3em_40>CTg0?koo`000080inOW0?ooo@2TWi`0]jn/0?kdlP3oooH0oood0?ko
k`3do>@0looD0:NkOP36hI80bnNC0=7^VP3;jIl0_=^G0<cRX@3=hJH0i_C@0?GoiP3mooL0o_oj0?oo
n03oooH0o_of0?conP3loo/0o_om0?oon`3nooX0o_kl0?ooo@3oo_/0ookm0?omo@3oo_/0mo;_0?om
o@3hlNT0ookd0=ODc@3oooX0oooo0?_mo0030?koo`0N0?ooo`3oo_l0oOgo0?cno`3ioOh0o?oh0?co
l@3Lj<80cMZ/0=g//`34eYP0ZKaj0;oBT031gJ<0d>Rf0<kI[P3Tf;h0YYN40;JdZ03hooP0i?oj0<?Y
gP1oX9T0cN[U0:NnXP19GcT0GWA=0=;^^`3;j[40`>>O2`3oool000X0oooo00/0`NjI0<;^V@32kYT0
aNbK0<SZWP3<iJ/0d>Bc0?Woh`3ooo@0oo_h0?olo`020?l0001:0?Woo`3kool0noko0?3Yl01_H6L0
UgMl0?o_l`3ol?@0dJNY0?olnP3looX0ingQ0?3bfP3oon<0mnW20?3Q^P3oo^<0ooo/0?Gbj@3gno`0
ooom0?oinP3oko<0^9:O0=Rg`P3oonX0m_oB0<cYV@38iiL0eNZa0=7Q]03@g[X0fnJn0=SQ]02KZfd0
/<Ao0<c[W@35j9H0a^NF0<gWW@3Hi:80TJ1M0<OTX@3?j:l00QP006=^D0083@00h>:a0;VhO`1bLBh0
Y:=R0>7LY@3QgZL0SY1A0<;0P`37ahT0emfM0?3m^02ogY80_NBE0<ojZP32k9X0bnjN0=C`X`1AIAd0
XKM_0=S/[@3@i:T0cN2Y0?OofP3`o=@0j_7@0?ooiP2b/YP40?l0003Z0=CHW@27SUP0oOoG0?7ndP3R
llH0cn2/0=3JW@0h@P<0i?6i0??ob02DY6D0c=bK0=7UW@3=hIT0hoV^0<kTV@27WE80dn^Q0=S`YP3B
k:80cNNM0=3ZX037hIL0a^2F0<cVW03>j9h0b>:H0=S`YP36gY@0b^:H09R/I@1UNc<0foN]0=cl/@2`
fXh0bON/0:N@G01TA1<0OY5A0<WLW03=fid0RY1D0:bdN@3Dg:T0oooH0=gG]@3dnO<0mO;i0?oko`3o
noP0PG1P0?oafP3ooNX0ooka0=oUb`3?gk80c^BI0=CPWP3JiZ@0]/F00<kUU`3CkYd0g?VW0;kKR@3J
lJ<0WkAY09:SG032dY40cnBY0<[V[03QoL80ho_10>Gh`02AVVD0U9]W0=kU/P3Pj[P0enRd0>knd@3f
lM@0ZjF=0<?3Z@3MjLD0iOC90<oPZP3Gj[<0SjYg09NfRP31kLX001T008V/Q01AKSh0BVHc0<oT[03D
iK40e^:l0=KSa@1cS7T0BfeM07BVVP1?OG<0mOoo0?Coo`3PiNT0ooCo0<ZV/P3cmO80m?ok0=[[h@3f
noD0m?oj0?Goo@32`kh0b<S00?chk@3imNX0ookh0?olo`3onol0oogo0?klo`3ooo/0k_GU024f3@2Q
]Xd0g>k80=c/a`3[nmH0j_KB0>;^bP2R[8T0e=^i0>W`cP3`n=<0bMB/09NRN02U/X@0_<ZG0=SZ/03<
gZ80b]bN0>Sk^@3[okX0bmnH0=?XX`3<ij@0bN6U0?KoeP3aom80TImZ0<cJW`3=g9L0a]N@0=;VW`3>
hj00gNf/08:8B02@VeT0fNZV0=gb[@34giP0a^JM0<7WW03:ljL0`^^O0;cVVP39lJ/0e_300=3ZZ`2i
dG/0_M5h0;S5O`3UkKX0LWIU0003003iooX0m_od0?Sok03Kk;H0c]^`0>;Ye`3cm^d0oogd0?oomP3k
n>l0ooof0?onn03ck^P0b<2m0=36a03KdLl0lNOV0?onn`3bmo40oogk0??Ui@3ooO/0o_ok0>W_j`3k
o?h0oo_o07n8T@1FKg@0>W5/0;k/hP3coOh0oogo0?oho`3ooOl0mo[o0?Kkm`3oo_P0n?3M0?ooiP3e
omX0jOg80=;TZP24TUD0gn^[0=SWXP3=hi/0cNbV0<WYZ031gJX0b>:e0?Ooi`3loo40nOg^0?ook03[
km@0][RR0?gnk03noOT0oogo0P3oo_l07@3nool0o_[g0?kkmP3fmO<0>3Hg0?ono`3gmoT0ooko0?on
o@1iM700oocf0?onmP3in^X0o_o_0?cojP3Oj/X0dnFa06Qn?P38iI<0b^NC0>?o[P3:j:80do6a0<cR
XP3;gj80dMfg0=cUbP3io?40o_oh00<0ooof00<0o_oj0?kon`3ooo/00P3ooo/00`3oo_/0ooci0?ok
n0030?onn`090:VTX@2c[Z/0c<Ro0<S4^@3jn_80n__f0?koo`3enOP0o?oo0080o_oo01h0oooo0?on
o`3hm_l0ooco0?ono`3moO/0o_of0?Woh`3non40gNVi0<_IY03Ei:/0f>N/0>Kod@3don<0i_3>0?OX
d`3^gL/0d/Zm0>;Vf03Qo>d0c_3R08FXX@1/RhH0ioo]07nGO@006@00`Mbc0<GR/P35i:T;0?ooo`00
2P3oool30<[YW@1D0<cXW@3<j9h0cnRW0<SPYP3AiK@0m_oS0?Wok03ioo@0nooj0?Woo`3hoOl0n?oo
0?_oo`3oo_l0kNS/01020P2:M7H0ooOh0<^]Z`2]THh0oocZ0=kUaP30fjH0cnbb0=CY/03GiK80l??H
0?ool`3noo/0ooko0?oio`3omo<0oo;Z0=Fb]P3ok_d0oo_m0?ckj@3@i:L0e^Z]0?Soi`3ioo40loo[
0?cojP3/m<l0g>N_0:blN`3>ji/0a^RD0<KWUP3=iid0e^FT09>OG`3CiZ@0a]VR00/L001PKdh01AD0
0=;PZ`3>g9h0g^ZP0=7KU02JWV<0UYUP0:R/K`2BTeL0XjEV079g=`1ZMC<0cNNN0<_[X032jIX0aNZL
0<3LT@2F[V80enfR0=G[X`3AhjT0e^Bc0<WE[@3;dKL0a<Nd0?Ogj`38aK`0oo_e103o0000M@3oomH0
oooN0?;gh03loo40h>WD0=cSa03RiJh0I6L^0>3W^`3]mLH0bmFP0<gHWP3GiZ<0enRR0=W^X`1fRch0
bN2B0=O]XP3?ii/0cNNM0<WSV@36h9H0b^BJ0:W1M`2F[V@0SjEL07>9@026W5<0RImF08bRF@34gY@0
gON]0<;PUP3MoK80`nbP0;[YV`2hXFd0^YaZ0<oXY02nei<0R9mK0<?>U03:eil0f>Bf0=SP^@3Cck@0
oogo0?oio`3on?l0ooCh0=K2^@1FAC<0fLbl0?O^i@3Ig/P0g>_40=?XY@3Agj@0o?o?08^KG03Ajj80
c^ZP0<_WVP3FlZL0TZMR0:ZmO@3IijX0e^JX0<oVXP35gih0i?c20=_/`P3kon<0m?kL0>Wcd036dZ80
c]fT0=_^[03AhY`0fmjU09NLHP2GXfD0eNfQ0=?^W@3=iI40e^fK0=3VW@2^ah<0bNVZ08^dO0006000
/]NT0=c_]`1iMS<0Lg@`0<cX[@1GOd/0^NS40<;Vc00G8Q40MWM_0?coo`3^ool0g?ci0>[oo`25UiL0
/lc60>Kkm03onOX0ooOm06mSI@1/J6L0oook0?kkmP3oooH0oOW`0?onn0020?omo`1d0?ono`3oool0
m?[^06IcE@3<jZ80b^FN0<gXY@3Hl[40_mNI0=CX[@3?hjP0`]BJ0>Wh_`3RlKP0amJK0<CIV039gYd0
e^fW0<_UW03:iY`0dNfR0<OQU`3BjJ40cnJP0;76P@3Bij@0g_>h0?Koe03kom`0n_oK0=SR/03Ag:@0
f>BR0=cYY03=g9L0Tj=R08ZIF03<eiD0eNBQ0<KMU`3Hlj`0b>bR0;gSV02igi@0dON/0<S/XP38j9l0
d>n/0<_T[@3DjZT0b]b:0=GRT`21PUP0ooo]0>GRj@1gN7`0mOoZ0?Gog`3;hZX0bMfN0=WY^03loo40
o?ok0?oom03ooOL0oooj0;2Z[02XXJP0eLkF0?ojo`3oo?l0oo[l0?onn`3ooOX0moWf0?oio@3ij^l0
ookm0>CZiP3good0k?3a0?omo`22QY4000D;04amM`2B_[40mooo0?olo`3omol0ooWo0?coo`3looX0
inGF0=KF/P3Dg:d0bN:P0=3WW`2:VeD0eN6O0=WSY03Pl:l0a]^F0<GWV`37jj40i_o70>godP3bomX0
d=nh0=cW_`3@g:`0d=bZ0=_T]`2j`Y/0ooo_0?oomP3oool20?knoP0O0?onn`3nnOH0oogm0?G_l`3n
nOd0oo_o0?ono@3jmo80oooc0?Ceh`3oond0i^_;0=SR_@3Ch[L0e>Fh08fVI@37hY/0^]Z70=gl[02o
gY80cn^`0<3KZ03=gj/0j?K50?[oi@3jond0o_oj0?WkmP3nooX0oooh0?oonP020?ooo`0@0?omnP3o
o_X0ookj0?onnP3mn?@0n_Ga0<K1_@3JeM40l^gY0?K^j`3onoP0oooh0?oomP3oooX0o_ok0?[ooP80
nooo0200o?oo0?koo`3oood0ooom0?olo`3onOl0oogo0?ono@3oo_T0o_oa0?ook`3oonX0Qhea0?[o
i03foMh0lOo`0>kok`3noo@0ooc_0?okk@2LS7`0jnCB0>Cbh@3Hk^40j_oo0:G5`P19K6H0Jhj709:c
Z02K^:@0EW9I0<[O`0/0oooo000:0?ooo`0>0<_NW03<h9/0d^NR0=7WWP3:hIT0cnVR0<gVY03:i:D0
e^jj0>?mc@3Jklh0o?oh0?koo`3lool20?Woo`180?CjnP3lool010<0089mN@3onO@0m=;@0;e`N03o
jm/0k^C10;OYY02kljP0`NJS0=CV/P3onn80ooob0?_nm`3iool0oo[o0?ohk@31YIL0onGS0?oeo`3o
n_l0noSa0>_hc03/nLd0m_k_0?_onP3hoo@0m_oU0?3je@3Gi:`0SimN0<k[V`37jID0anRG0<7MTP3=
gI`0T9aL0=STY03Qk[T05RH006=dD0002P00cnN]0<_TX03=iIL0d>JK0=;UY@3FiZP0g>JW0=cRY03P
i:L0VImO04YF503Ek:H0bNFK0<o_Y038i9T0dN:K04IH3P36gY00dnVQ0<3AV`3Ag[80fnG20;:eY033
`kT0oo_h0?;]jP3llo@0oogn0P3o0000L`3JekP0/:f<0?ook03oooH0mocf0>O]h`3Nh//0emJV06AT
<P3WjlH0d]N^0<K>W@3Mik80eNBS0=7RWP2R]f`0WK9W0<cSU@3;hiD0c>BH0<SRV03>j9h0c>JL0=Wc
Z@2CZf40UZiT0<SNU@3Ejj80dnVP0<kTV`3AjIl0cNVN0<[VV`39j9`0bNVM0<?YW02mjIX0XX]E0<NY
M@3>ij<0b>JP0=C_ZP3:gYl0eNV^0<kO/P3EhK/0`l>Y0?omnP3on_l0oo?o0?oin`3ol>L0ET@f0<>e
ZP3omO<0e]S;0<oJ_03Lk[@0c=VT0<oNY`2U]gd0c^NS0<oZY@3DlZX0`MbE07^?D03Bi:X0a]>N0=3M
Y`37gId0eNf_0<WNYP3>fk00d]jh0>?_b@3Ji[h0_/nK0=oa]@3@iJ80gNjX0=cVY`2KZVD0//Qm0=3a
VP38jHh0dNVA0=3VT`3?giH0_/f809BYJ03>kK805DTI0<S]^@3Dj:d0b/Z20:BXGP3>kJT0Pja`0;g[
_@3>kL/0RH]c03D_8@3kool0h_ck0>Ooo`2M][<0CUiN05E^JP2K/:/0n_Cf0<Nb^@2/Z:L0e]SE0?[i
m`3oooX00P3oooH05P3flN/0oogo0?Scm`3oool0l_C_07ImJ`002@00^mf70=7aWP38i9T0bnNM0=7[
Y03KlK00`=JE0<kSXP3FjJT0gnn^0<KFU@3>hih0c^FO0=3/X@3=k9h20<OVUP290=[iZ@3HlZP0g?>[
08BIEP3Cj:D0hoVk0=_^]`3homT0cmb`0<SBX038di/0d=bJ0=;OV@3JjJ@0BUXI0<_KVP3@i9l0b^6K
0<k/Y03@l:L0aN^P0;gQU`36j9h0g_je0<COV03Mm:h0bMnN0<kVZP29WUT0h>jS0=KOWP25PFH0oogj
0>;Nk01[K740h?;<0>Ko``37hYd0c^:W0<_K[P3goNl0o?km0?cjkP3ooOH0o_gi08=nPP3>bM00ooco
0?kho`3onol0ooko0?gln03ooo/0o_oo0?[_l`3on_l0ookm0??lm`3eoo/0o?oo0?omo`1gNX4000dA
04imM@1hY9L0lO_j0?omo`3on?l0ooco0?coo`3kooH0j>[E0>;X_03BgjT0d>jT0<kWUP3AhiT0e>6L
0=[TY@3GiJL0d^NR0<k_X037k9h0k_o:0?3od03SmlH0cMf^0>3^^`39f9d0fn^]0<?@V038e:80l?KJ
0?kok`3oooX0k>gX0?oon`3oo_/0ooOe0?omo@3oo?l0oogo0?oloP3oooX0lo?Y0?goj`3`m=/0o_oX
0>Wab03JiKX0d^:a0=3R[P2;Y600d>bQ0<;TT03<jid0a>:J0<[R[P3Gk/@0fNRo0>Wdc03lond0o?of
0?_ooP3lool0n_ci0?Wjm@3knoT0ooko0?[go`3on_X0oo[g0?omnP3oo_X0cl[60;F`[03Tgm/00P3o
o_X01P3nnOD0ookj0?oon03oooP0oooj0?kon`<0nooo0200mo_j0?[ln`3no_`0n_Wg0?oloP3kmOL0
ookk0?Cak03oooP0no_a0?oom02a/JD0fM_>0?oom03ino00n?om0?Ooo03nooX0oocc0?okk`2aX900
]:RH0?col`3eooP0kOoo0=omn`2D^;H0QZfZ051dL02fe//0dnoQ05YaG`/0oooo000:0?ooo`1D0=WN
YP1MHRP0GFDY07n<A`3<g9<0b^6C0=?^W`36iID0aNnM0;?NS036j:`0o?oc0?omo`3oool0nooo0?Wo
o`3`oOH0mook0>Wfk0002`0000@00?ook`3omn@0Z7eK06a:7@3/i:H0f=fM0=[a^@3Wom40noo]0?om
l@3on_H0oo7e0;nQW`3B^j/0oo_X0?ojlP3on_d0oo_o0?omo`3noo@0o_of0?coo`3joo`0lOoW0=?T
^P3:fZ/0bMNJ09^/J03>jYd0`nBC0<_^W037iYX0eNZU0;S9Q@34cHh0i^fi01DN001kRFH000X00<KR
Y`3<jjD0anjK0<S_WP3;lj`0b>^W0=KYZ@3=fid0XZ]/059L7@2CWel0cnBO0=7XXP3Aiil0g>^V08B9
A`3Mi:00goNY0<OLU`3Ii[P0SiUf0;:fW`3oo_X0ooco0`3onol0QP3onOd0oogo0:^VZP3ooOP0lncT
0?oonP3inoP0mogi0?comP3oonl0h]jh092<IP3jn^80gn;50?oog`3Dfjl0dn2X0>Kf]`25VE80gO>Z
0=G]X@3=j9T0b>>D0=K`YP2fd8H0SZQN04EO5@32g980d^bR0<_UV`3:i9X0c^JL0=3XWP3<j9d0anRI
0<_ZW03<j9d0bnNL0<OWV`33jI`0_jA_0:^;F034hYX0eON]0<_]X`34hil0cN^[0>ooe`3gon40a<Ra
0?ool`3onol0oo[o0?oal@3mkN00^JVL0?ohlP3onol0ooom0?col@3komX0nooL0;k?V`3Om;/0cNRU
0<SUXP3=jjD0f_Fb08jQJ@2HYW<0fnNi0?Wog03[omL0mooL0=GV/P38e9H0g>^X0=G[XP39hiX0dNZY
0=?X[`34eJ40o?oJ0<7>X03<i:H0b^VS0;WSS@36kIX0e_2Y0<[JW02MW700EU<Z0?;]a`0f>1<0a=Fc
082ML@3@k[X0f_^f0<CTV`2AZ680bMbJ0<SEX03@fJX0nooM0>OZc`2MR940CTA<00<11P1DDEP0NGj2
05V?PP1_[il0c_S^0?Goo`3oo_l0n_Kg0?ono`3dl>d0S8N1092;Q@2j]K40e];A0:>RX0021@00JG1N
0=7O_03IkKP0cN^C0;gKQ@3BkJ00c^RO0=G/Z03:gZ40g>jd0P3colL0O`39eiT0f^Z[0=7XXP3>j9l0
anJH0<OXU`3<ki/0d_FQ0;_MR@3@k:40_]F=08nRHP34fIP0aN2K0<OOX@37fJD0UJIb0<GDV`1bP480
C5`E0=CVW03Bii`0aMZE0=3ZX`37jj40`nNM0<CXWP3<kZ@0f?R_0=?aZ@3GkZP0eNZU0=S/Y`3?fiT0
I70^0<gMWP3Ei:<0eMjU0?Clc@3jnnd0oooo0>O[k01TK640amjV0<kZW`3EkjD0l_oK0>gjgP3noo/0
ooko0?oomP3Jem00_k^h0?ono`3ln_d0n?Kk0?ono`3noOl0m_Kf0?Sjm`3ooo/0o?_i0?oio03onO/0
oo[f0??mm03aooH0n_oh0?omn`3oo?d0N8=o000>101hYid0m?oo0?_lo`3onol0oooo0?WonP3bon@0
aLfX0=gX/03FjjP0a>ZC0;cIO`37ehh0en>S0=;KYP3nomH0nOoA0<STV@2oh8l0foZ^0<[UXP3Ej;40
dnF[0<WKW@33fI00RIiC0=;VW`3AhjD0cMVa0=[SaP3jo>l0ooof0?Wil@2HTi00G5IF0?omo`3[iNT0
oogo0?okn`3ooo<0[K:L0?Oog@2mcJ00cn6]0=?MZ03Oj[80_LbC0=c`/@2kehd0do:T0<SWU`3ElJL0
bN>T0=WYa@3gon/00P3nonl01`3noo/0o?oo0?_no`3lool0o_oo0?ooo`3fm_P00P3oo?l01P3ooOl0
ookk0;F`[@2e/:d0ookk0?oln@80ookk00<0o_gi0?oon`3ooo/00P3oooX00`3ooo/0o_om0?coo`02
0?coo`0;0?koo`3inOT0m_;_0?oln@3glnP0oooc0?oom03no?00ooof05MDC`3Hem<00P3oo_l04`3m
o?l0oogo0?Sko`3lool0oooo0?olnP3oo?@0f<Zo0?oml@3kmn`0oooh0?Coo`3WnOT0k_oo0=Ocm`3[
ool0:4I60;KDdP1hV9<02`3oool000X0oooo00P0eMZT08nDFP3Fg:00O8M30:2]I@3Aj9X0f?>R0;oO
S080o`0004X0a>NW0?col@3ooOl0ooko0?coo@3kood0jOC/0?SonP3aoO40;CL/0007003_mn80oooP
0>CDX`21JSH0O5hX0:bBG`3om/l0oooR0?ogk@3oj^P0omGH0;n6S@2ZQhD0oo[_0?olk`3djn80l^[X
0?omo`3oo_l0oooo0?ooo@3kool0l_ca0?3og`3:gZ/0bMbU0>?c]02I[FP0c>^M0<;UU@3:kil0b>VJ
0=G/Y03:gYL0g>FT0<kEX@1UK400LWaJ01LS0038h:H0b>JP0<CZU@31jiL0`^jS0<GZY@3JjZ/0f^JX
09:KG024SDh0f>BT0=__ZP35fYD0fNfV0=;QW022Q4<0hNRT0<_VV@3=i9h0a]>W09VPO`3oond0oOGc
0?okoP80oo_o0<40oocm0?_bl`2/ZZl0noKl0?S_lP3oo?l0ooom0?con`3eo?@0jo;P0?coi`3;aJ40
S8IT0?;ag`2Z[9H0oooT0<gE[P34dYd0d^BX086FD@3Il:P0b^BJ0<gXV`3<iiX0_MN=0=7[X@1lUT`0
an6G0=OaY`39hiT0a^:G0<[VV`3>jYl0c>RM0<OVVP3:kId0cNbN0<[VV`39iIX0bNRL0<S]X02^T5`0
Wgm<0<cZXP3>l:H0_^:H0;cNU033iZ80cNRe0>koeP2k_JD0noW/0?kemP3on?h0oo_h0>WKcP3mkn80
oo;/0?oko`3jn?T0lO?V0?GoeP1gQ5H0`=>L0;kCV03=jjD0anNN0<KTW02mf9<0dnN/07Z8E@2P[7h0
o?oQ0?Goi03/oM40aM>P0=[UX03SlJ@0c^RA0=SeX@32gi`0goBl0>Cda`3dnmT0Z[B?0<[SZP32hYl0
]n2A0<[cY02oei/0dn6`0;B_T@2UVh80ooGK05UB>01jOF808CTE02E97@1_Wf<0cONg08BGE@2nahH0
jNJ_0>7S/@3Sm<P0o?oV0?oam`2AQXX0MFma0?olo`32alX0Q<:c02aiI@1SUHX0m?oo0?c]m03on_l0
ZjVZ0:bXY`3Ke]80Z:>M0>oZiP030000HV5M0458>02PZY40LH9F05aa>039iI40`mj?0=?ZYP37gId0
dNFZ0=g]_03Tl/40f^Jf0>7Z^`3Zm<00gnbd0=3VY@3=iZ80c>bP0<c_W`36k9L0a^VE0<S[V@3ElJH0
c^FO0<WIVP2Y_7`0anFK0<_VX@3?i:/0`mJN0:2bMP2fbHL0d>FH0=caY038gi40b^6I0<WWW`32j9d0
a>ZO0=3bZ03<k:<0]m6:0<ONV03BiZ40eNJR0;k?R`2DXf00]LB30<OBV03TkkD0am6O08jFK@3hon/0
m?[`0??nkP1fQ6/0e^jd0<oYXP3?j:@0nOoX0?_ok`3knoT0o_Wo0?[ck@2c[ZP0ookj0?;]jP3on_X0
ookm0080ooko0P3oood0<03hmo<0oogm0?k[k@3onOX0ookh0?Clk`3fooD0nooe0?okm@3ak>P0T9F?
04]dIP1<OWD0l?oo0?Wno`3oo?l0m_Wb0?Sol`3boml0a<nT0=KTYP3;hYX0aNfE0>;oZ01<FaP0C5DN
0<G:X@1GGcH0`<jM0=OaZP37iYP0dnfT0<OMW03?gJP0e>F^0<OKWP2O]F`0^]250<7GS`3Kl:l0j_W@
0?_oj03nooH0kNgU0?Gbk@20O7/08Q`L0?oko@80oogo01D030P507n2L@3doN80enVi0<7FW@3BjjX0
eN2T0=[TZ03QlK<0ambK0<?OU03>kId0b^JI0<gXX`3=iJ/0looT0?_om03ooo@0o_oc0?cno@3ko_l0
0P3lool0503dn?/0n?Sj0?ono`3`j_@0ooOo0?oloP3Mf=D0l^gZ0?ojnP3ooO`0ookk0?ono@3lnoT0
n__f0?oon`3oood0oook0?oonP3oood0oooo0P3nool04@3in_`0oooo0?ooo@3oo_X0oogj0?ool`3f
ln@0oooc0:>QU@1cL6L0o_gi0?glnP3oo_l0oOco0?klo`3ooOl0no_o0080ooko00h0ookk0?omm`3I
c<@0ooS_0;B[Y03mn_D0nooo0?Soo`3dool0l_oo0>koo`2G[jl0UkB`086QW0/0oooo000:0?ooo`07
0>3[/@2BW600i>ja0:VfL@2=WEH0b]nD0=_cY@040?l0001Y0?col@3oo_l0ooko0?kon`3loo/0o?oj
0??ik`2k`KD0em[?0002001hPVX0an:e0>3d]`3Ki:D0[iER09]aB@1Q7a<0VDiB0;aWNP2XDF@0/EQ/
0>VPZ`3oiND0oo[f0?oflP3ooOP0oooj0?kno03oo_l0o?_o0?kmo`3io_L0k_[R0=C/^P3AjJ/0d^RX
0=ka[`2:WeX0cN^Q0<GWVP38kih0anZJ0<oZW@3Bj9d0Z[Ec0;O0R`0U;000PhUW02/a3@3Ij:l0f>fX
0=7aWP3;kY`0`N^Q0<KZY02nbX`0fN6U0:R/L@2QYf/0en6R0=?VY03;hY`0a]^F0;O8PP3CfYL0eN2K
0;_FR@3Lljl0j_G;0?goi03mo>X0oogk0?oko`3kk_D0oo_m0?olnP3Dc<T0l_7_0?oko`3on?l0nO;j
0?ooo@3looP0mOo]0=WTa03[lLd0^;:>0:6JO@2XZ9`0`L:b0>ocf03non<0gN^j0<kOZ02Q^7@0b^BM
0<GQU`3;ii`0cNVN0<cTVP2M]F/0`M^A0=cf[035hIH0bnNL0080cNbP0:<0bn^O0<KVVP35iIT0b^fM
0<_ZW03;iYT0c>NJ0<o[X03@lZD0/95K0;6@F`3=j:40_n6G0<;WVP34jI/0c>fV0<KNZP3bomL0];:I
0?oom03oo_l0ooco0?ojn02KTHD0ooc^0?oklP3onol0n_Kc0?ool@2obi/0U:9_0=ga]P3Fkjh0anFK
0;WJR`33hY@0eo>X0=KZZ`3PkkP0f>Bd0?Coe`3Wo=D0gNg0079oB@1[MB`0WJaK0<WVS039jY<0b>NQ
0=O_]@3iom`0UY]k0;c3X@3Bi[<0aN:R0<3YV`3>mj/0d>Vb0=GT^`32_JT0ShIe0?olj`2AQW@01`40
06]oI0003P0003@:01=34@3BhJP0_l2407]`>02LVF@0f^c20?Ooi`3mn?@0c]?=07b5P03lool0_l_;
04V7N01JXi80bo3Y0?ono`3oj_P0h/;?0>gXk03cko006aHB08j9P`30^kD0oooj0?oon03/m=l0n_oU
0?SoeP2jd980U:]S09fdL033eYl0bm^Z0=c[`03Zm=40mOoM0;c3XP2Y[hd0oooQ0?gof`3HkK80c>FT
0<_[XP3=kj80`^VF0<?YUP3@lj40c^RN0=S]Z03Jj:X0O8m=0<W/VP3AlJD0`]bK0=;Z[030eYD0`]R@
0=7ZV@3=iYD0f?>T0<;NU03BlZL0a^bQ0<g_Y@39i9d0b>:K0=[[Y`3EiZ80RiYG08fNFP2Q]G00cnJP
0<gPX03WkKl0nOoA0<7<XP3koml0iOCC0=OVa`3@hKd0F6e20<GLY039hJD0bMfX0?Goj`3koo@0ooom
0?omo`3UemH0oo_g0?oln03ooOP0ooSc0?onn03ooOX0m_7^0080ookm05H0knWY0:^SX@2oZZT0^ZFR
0?okl03joo80mooc0?kol@3oo_<0oogd0=3Ba`3Wood0DHIn0>Ooo`3hool0ooko0?Clk@3gond0enfo
0:^iQP3Bhil0bN>I0<?]U`30gHT0i_Bi0=CK/@3dmmX0hNG:0;2jU`32f9X0cNNP0<gRW@3>gZ00jO;3
06ioB`2?XVX0bn:N0<[RV03KlZ`0fo6c0?Soh`3kon`0o_oj0?oon`3oo_d0/jn`0?Ocm03on_h0oogo
0?ono@030000o_o]0?_oi038gJ@0e>n/0<GSV@3<f9P0T9QL0<7@S`3Ej:H0i?nb0<7NSP3;iid0b^>R
0<oS/03konl0o_oj0?gnmP3loOD0o?go0?coo`3kool0nOko0?coo`3oood0nOSf0?olo`3onol0`[c0
0<[4a03jm_D0ooko0?WemP3oo_`0oO_l0?clo080oOol00@0o_oo0?oon`3ooo/0ooom103oool0803m
no`0ookm0?oel`3om_@0oood0?7_hP2m^[40ooof0?oon03ooo/0oOcj0?_ko@3noOl0o_oo0?gno`3o
oOl0ooco0?ono`3noO/0n?Ca0<>j]@3oo?P0bl2n0>OMg03imoP0moWh0?Kko`3iool0loco0?Coo`3U
n?@08Sdd2`3oool000X0oooo00L0eO2[09ffLP3>iIl0dnNR0<;CS`2V]g<0Z[]g00@0o`0004d0o?oc
0?ooo`3oood0oooj0?oon03oo_H0ooO^0;j_Z03_g]L09Q<=00d0001cKD/0KG@n0=;LX03JgJP0k>Bm
0?o]j@3ojo<0oo?o0?ogo@3oo_P0noo^0?olmP3on_l0ooSo0>_`l`3_nNh0o?of0?kon`3mnOl0ooko
0?cojP3WnLT0e_J[0<_[V03Cl:00`]R@0;cCS@37iih0bNnT0<7ZV`36kI`0b>RE0<gZV03<h9/0bMJN
00@=002NWGh0>3<C09VGI03@dY<0dMnB0<cQU03Ak:L0Z;el08R5CP21O4@0FU<L0>;PY`3]lK@0e^VW
0<3IU@3>k:@0SJQQ0<OKUP3BiYl0gON]0:c2P@3Sk/H0hNG:0?[hj@3on_/0ooWm0?ojo@3di^D0k^CJ
0>cVeP020?l00080oo_o01l0nooj0??oi`3hon40enRa0=KPZ`2VXgX0in;502h]:023QGX0o_o]0?Ko
hP3>g[40`M>O0<CMW02ofYD0bnVQ0=;bYP3:jId0SjEL0;38OP2je8X0_]R>0<OVVP36iYX0a>JI0<7V
V031j9T0anjO0<[aXP35iYD0aNBF0080dnVN08D0a]jD0;gLT02EM3l0S6Pd0=GaY`35ii/0_N:D0<[[
VP35iIX0d^F^0>_db@2cZI00jN_X0?kno`3ooOl0oocl07YbI@3oond0ooca0?ohm@3ln^h0j>_@0:Vd
N03Nl;80`MR@0>oo_@37j940`^F90=?dV@35hhd0_]B;0=g][P3ZmK/0RYMQ06R1@03HjjT0b=BD0??i
^@3;eY@0bnJQ0<g^Y`33hj00e_2_0<7EV03Ti[@0fmZ^0=_VZP3@iYd0a^fD0<O_V@3bom40mooL0>KX
d03LflL0lNcF0?WdgP3Fe[h0IGE[096ZYP19L6/0H8Ed03A76@1KI2/0h=nO0=KEW@2BUgL0X:>>0:6S
U@3Dh]40c]c?0;jd]@1jJG40P8R;0?;oo`2;Vi/0a]CE0:;:`@2nhMX00`04089nO`3oo_X0mO3Z0?oo
n03no_H0oood0>cgf@3Hik`0_=:B0=kd/`3Fi[L0a]>X0?WoiP3lond0o?oc0?oon03jnO@0oooj0>WV
g`2TX9L0oOk/0>Wmc03Kl[h0a^BT0<?WX@35k9d0anbL0<3ST`35giH0e>NU0=;MX@27VeH0`>V;0;oW
S`3AljL0b^ZQ0<GQU`3;iiX0bnRD0=knZ@3:jYL0c>bP0<GUVP34hYX0b^BM0>?b[`3?fYP0OH=30;Fk
N`3>gIX0cN:M0=G`Z@2ni9T0bnNZ0080ooo/05`0dmbm0>7bb031gYh0`N6H0=Og[033hI/0k_oC0?7o
g@3/n>00m?kc0?conP3oo_/0oogh0?ogn`3ni^H0oo3]0;:PUP3<^Zh0c[j_09N9OP2CQ7d0^Zb[0=C5
b03on_d0oo;a0?ogl`3on?<0f]C40;_5[@3Mjm40b/jg0=c@`03oo>l0l_7O0<oah02Zh]l0R:V`0>Wh
o@3kool0looX0=?Y``38hJP0Sj5U0=;VWP3=jI`0^>>A0<CRVP3loml0ooo/0?oon03oooX0oooc0>gm
d02Q/gT0QI9J0:N_OP3AeK80nooQ0=kaa03Bj[00cNFW0<WSYP3Il;X0n?oZ0?SolP3oool0OW^200<0
1`3bl?D0oooo0>g[kP3ooOl0oook0002003Tkm40lOoF0<7OU`3>lIl0`NR=09VVH023RDT0d=bJ0=CU
X@3@j9`0a=n@0=3ZX`3AiZ/0c]ja0?_nl`3no?l0ookk0?oonP80o_oo0P3kool01@3_mN/0oOod0?oo
mP26PGd0`KRi0080oogo00<0o?[m0>k/k`3hm_T00P3oool01`3nool0o?oo0?Omo@3goOd0ooom0?on
n`3oood00`3oo_l02P3imoX0oogo0?omn`2dZJL0UHN40?onnP3hm?40ooom0?[im`3in?H20?ooo@0E
0?kon`3lo_T0nokg0?conP3oo?l0ooKn0?omo`3nool0o?oo0=;@d@3omoP0oo[m0:fMX03on?/0mN_/
0?;/kP3oo_l0nOGd0?oonP3oooH0^[R[00/0oooo000:0?ooo`080<gRZP2kd9D0enf]0=7VX@3LlZT0
`mN?0::fK`37fiH20?l0001=0?3odP3koo<0o_om0?oon`3oooX0ookh0?okm03oo?@0i]C@0?oflP2g
XYl05@4009F5K023P5L0`/FF0<gFZ@3Kg;X0oocd0?ojn`3ooOl0nOom0>com@3^ooH0oook0?kfo`3o
o_l0looc0?Ook@3fonT0nooc0?cmo`3nool0n?oX0>?da`32hYL0cNnK0<gXV@2;XET0cNBN0<GTWP3<
l:P0`>VK0<S_WP38jYH0c>VI0=?XX`3Jijl092X009B?K`0Z9080S8mJ0=gSY@3FiY/0dn>J0=WXY@2B
W5l0a/V@0;2aN02@TEL0gn>V0=GNW`3AiZ40e>jW0<3PU`2ZaH00`mZF0=G/YP32g980TjUX0=oZ`03S
j//0a/Rc0?omnP3omoH0iMWI09nDT032^K00103o0000o`3ekO`0o_oj0?_ok@3hon40d^BZ0=?QYP2E
UfH0gMfg06IZF@2UZY@0nOoV0?Oog`3?hK40c^2/0<_TX`3>jJH0e?:Z0=3`Y031gI80TZIN0<cRV@3J
m:X0dNfR0<GTV03<jil0bn^O0<c/X03;kJ00aNZL0<;WV@3;iiX0bn>I0=GZW`3CiI/0]ln508RXG027
IS40Id4@0<OLU`3Ek:P0c>RN0<c^VP3:jId0bmjV0=?L[`3;a:P0inOU0?[io`3ooOl0oo[n09N@RP3o
nnd0noCZ0?onn02o`;80hnW?0=SU[@3;fYL0noo10=W`X03Bki/0b>VB0<?US`3?kiX0hoja0;gCR`3:
gI/0e>NU0<STVP38g9D0gNVW0:N]K`2W/G@0c^VR0<?UV@30i9X0`MnI0=gb/@3JgJP0l>g00?3i`03U
m[80bn^H0<OXU`3OnKX0gO6l0>;Za@3Ni<80PXIQ0?[ng@3`kmX000D006MkO01>LW80?F9J05AbD015
G2h0HFPe07YkC`3IdkT0knSF0?Wkl03hooH0cMW;08b1O@0P0`L0[:>V0<S=d028W9d0aN?S03igKP19
NW@0R8^B0>CZjP3iooD0o_od0?oom03ooo<0k_;Q0=OY``3=hk80eNnV0<SOV`3TjlX0d]^n0?cok`3f
o>h0m?[`0?_mn03ooo/0i>CL0?Wfk@2LV8`0i>K>0>Kha03Un<X0d>Zm0<ST/@39jZD0anVM0=3`Y03@
ij<0cn6U0=GN[`2?WVD0bnfF0<OYU@36iiP0a^FG0=7`X033hY80`>:>0<[]V@2ig8X0_^>C0<OYW03=
iZ80cnFT0=?QY034d980VJAP0=3MU@3HkJ80dn^Q0<SUXP3Hnl40a^2c0?ool03Ff<<0d]jj0<_O[03>
kZ80c>jH0<GUTP3:iJ00gNc;0?Kol03kooX0m?Wb0?kon`3kmo@0oogj0<2/[P2eXJ80^ZJU0;JUW@3j
k>40ooS]0<Vl/`2i[:H0oo_k0?oko@3om?/0ooWm0?oin03ol^X0gmo70;o=[035ek40dmfj0=oK_P3o
nN<0no[V0<;MbP2hj=X0KYJH0>_oo`3lool0nOoP0=3T/@33hJ<0TZIW0<OOU@2ogi<0aNnW0<OPY`3l
onX0n?c]0?oon`3loOP0mo_]0?Kog039fjL0eNB]0>C`_P3noml0nOoV0>;cd@3?hk80bn:Z0=C[/`3A
iK@0nOoZ0?Kmk@3jn?/0LFac08=iQ03oo_l0oooo0?Sgl`3ooo/0^KRc0043003IiL40amVU0<SYVP36
k9D0^^:90;C4P`3OjJd0enRT0<cRVP3Ak9l0cNVL0=7ZZ000203?hJd0d=bf0?oon03lm_X0ooci0?om
n@3no?d0o?_o0P3nool01`3oooH0oood0?7_h`20N7D0dl[;0?oko03ln_/00P3oo_l01`3oool0o_kn
0?koo`3in_`0nooo0?SnoP3ioOh00P3oo_/02P3ooOd0ookm0?ono`3oo_l0oocm0??]k`3Xgn00[J>R
0;:VYP3oo_d20?klo@80ooko00l0o_kl0?Wim`3loOP0n__e0?oonP3nooP0oogm0?ojo@3ooOl0ooko
0?[im`3?blX0oocm0?KZk02TV9X00P3onol01P3oooP0oood0?klk`3oond0l?3H0=WJ^`/0oooo000:
0?ooo`1G0>7Hd`3oo^T0jNo=0=;WYP3;iYT0cNjG0;gOR03<k9L0b^6I0<KKV03Di;D0i^oN0?GjmP3n
oo/0ookj0?onn03ooOP0[jJQ0?omnP3oo_X0mO7^0<2o^P000P00cLjn0<g>_01>BcX0ooo_0?ool@3`
k>00o_gh0?kno03nool0o?oo0?kno`3kooD0m_oW0<WSYP36hIh0cnb/0=7/]@3eonH0n?o_0?Knl`3Q
kmD0eO6d0=C`YP3Aj:00g^fZ0:blN`3=iZ80bNRR0<KZX038jYh0b^VM0<cXW@35f9H0g^J]04M55@2e
Z8H0>38>09:YL`3BmKD0cNfT0<gNV02gZ6l0HEPO0<g]ZP3Al:`0bnVO0=3/X@3>jYd0b^FH0=?^X@2h
dXT0e>fY0<_UY03=j:D0d>NQ08FJF@3Ij[H0c=V]0=7K^03hnnH0oooa04I6?03oooP0oooj00@0o`00
01X0oo[n0?kklP3lonl0nooZ0=SZ^03DiZ`0W:MS0<3=R01VO3h0Gg@i0<_PY`39gZD0f^fe0=CW[`3X
o/00dNZX0=3ZX`3<iY`0cN>H0<OBS@3@hIX0dO2T0<SXW037iYX0]ln50=[^YP80d>BL09H0d^bR0<gW
WP35e940gNVW096LE`2DY5d0fOR/0=Gl[@1UBAL0/haQ0;ZlRP3<bYX0inbf0=co[@3=k9h0cNJT0=;V
Z`3DgkD0[jVM0?olnP3onol0oo?o0;fc_P3glo80oooh0?Okk03bo^P0moo_0?Woh`3Hgi`0fN2B0>;/
X`1`Pd<0a]bN0;WEV03Gm;@0c>ZR0=[fZ@34ghh0hOjZ0<g/WP3Cj:D0fnV/092JG@3kolD0cO2B0;_U
P@39l9<0f_JY0<3BU011@a`0G60k0<_CZP3Rjkh0dn:[0=OV[@39gYd0_mBA0<oTW`3Cj:<0`]NB061]
=`3Lel<000800006001>N6@0[n;A000[8P2F`k`0lOom0?_omP0=0000HEA10002001UKF80nOod0?_o
j03oiML0nooa0=cfj@2Ca<40>gah0008401IKGP0iooo0>Goo`3<jl/0g?G>0?CofP3Bf;@0e=ji0<WV
]P34j:/0c?:U0??ocP1[Ieh0^[N^0?Cjk03hoo80n?oc0=SXc@3/nm`0gn[20=;I[`1fN4T0SI9H06n0
?000200000<500050`1OMDL0G7Dd0<cVW@3?hJd0f>K2000900001000=c/80<kHW03TmZX0d>NE0;KG
P03>l9`0_>6C0<_aY031iiX0coJU0<7TU03<gil0X[Em0=7W]P3:hj`0b>VH0<W]S@3<kXd0do2N0<?K
X@3eooT0n?oo0?WojP2DXWl0fNjf0;gFU02keXD0c^ZF0>?h]`3Lk;d0l?G_0?omo`3oo?l40?ooo`03
0?ooo@3oool0oooo00<0oooo05@0loCf0?7bm03nool0nocn0?koo`3onol0ooko0<K9_P3Um/X0dnZb
0<?MW03>ijH0e^^c0?Soh`3nonl0b/fj0=KO/P11L6H0P:RZ0?;`l`3oolX0bmj=0<CcY@2of9H0e_B/
0;kOV03?j<00inoP0>SZi@3loo/0nOkg0?Wol`3Ymn00c=fi0<[O]P35gZL0a>2U0>7ia`3hoo<0n?oh
0>WcfP3Lj<@0bmJ/0?kog`3MglT0Xj6B00L0002WWIh0oo_m0?ooo`3loo/0o_o]0?ook@24Q7P02@`0
0>kkc@3?iId0co2G0;oUSP3En[@0c>Vc0<7LY@3@kZH0]MB60;_JRP3;iid0_LfL0?coi03oon`0oogh
0?oclP3ej^H0oocj0?_alP3on_h0^k>a04a5?`3YhmD0noGW0?ool`3el>`0oo[l0?oon`3oooP20?oo
nP80oook00L0ooom0?koo`3nool0ko3b0?Gem`3onOL0oogh0080oocj00D0k>CR0=gHe@34_[h0ooko
0?omoP020?ono`<0o_oo0`3oool05P3oo_l0o?Si0?oko03oo_d0n_Ke0?OflP3oooX0oogh0?oin02=
N7D0cKji0?7VhP3dmO00o?om0?3fmP3lool0d]fm0<oO/P3Ahk40enbc0=;XZP3>jJ@;0?ooo`002P3o
ool0F03mmn/0ooo]0??gg03[nlX0c^>X0=;aY@39j9P0b>BG0;77QP3:gZ<0fnO10??ij`3WjNH0oook
0?onnP3on_@0oogh0<2f]03lm?80oo[j0?oko01aL6h020T10=[JcP3gn>X0oooa0?G_h@34`;@0XinD
0?oon`3knoT0o_oo0?_no`3no_l0nooe0?WojP3?jJ`0b>>P0<SWY030g:40i_[E0?3ni03Gh<l0dN31
0=7]/03AkJ<0_mJ>0>;a[P2c`h80cNJR0<WXXP36jZ00b>ZN0<[YW@3<j9d0cN:O0=[RZ@1aKcl0PgUF
018>002Y`8X0a^JW0<OWWP3Fij40WHaD05mE6037jYX0aNJE0<_XUP3<jIL0c>RD0=SaWP2jdh00a=n>
092[G03Qo:l0a=nB0=of[P2<XEh0g>ff0=OU]03<ejl0o_oZ0?ook@1GF4X0o_oa0??ci`3inNl20?l0
002/0?okn`3llNl0Pgmc09bNR@3doMh0fnVf0<gKX02//Fl0fn:O08BHF`1KKc@0f^fe0<WLY03/olL0
i__20>7g]`3@jJD0d^bU0<WUVP3>i9T0WZUT0=?TW@3>kJ40anNK0<c[W`3HlZP0cN6I0<_OU`3EjJ40
_m^@0=3/XP3MlZd0[L5l0=CTW@3Gj:40bNNM0;WOU02ENT/0W7UA0>geaP2=SfL0c]RV0<W`X@33iIP0
eO>[0<_UY03fomH0^kBT0?ommP3oo?/0oo_o0>CIg`3oooH0oooa0?ook03[m=D0k?[I0>ckdP3AhJ80
fnnW0<7FT@2ldY@0MHeC09J^M031eY/0YkMf09fZI@2<V500b]R=0<oWW@39g9`0d=jS07j7CP3>g9h0
bNVF0<O[T`33iY@0bN:N0=GT[@3ooml0h^^n0=WU/`32dIX0RI]M07V<C02ebXD0hoVa0>;i/@33fI40
cN>K0<SGW03:cZT0/KRI0:^jV`006P00<eU00:cEa`1GOg@0ZLRi0>Sok03honH0nooS0?coh`1`NE`0
10h005]NB@1UBT40O85k09jh]@008RL065YH0>Coo`3Wool0PkNZ0:W@^`3;g;80h^jl0?kod@3JhJh0
e]b^0=cT_@3Gj;`0a?2c0>Wof`2_[9d0l>oM0?3hh03gonH0kooK0>ooeP3hom`0en>a0<WAX0062000
N7e3000?000[=Q@0eN3L000=101WNT`0//R:0=?YZ01XND`0bmVh00050037cK<010@009JIJP2;VUL0
W;5V0>?n[`3<j9/0c>bQ0<?SV03?kj@0`>6@0<_[V02BZ600TJIU0<;JWP39hj@0aNFB0<KWS03:j8h0
c>RK0<[RZ03_o>X0nOoc0>G`a@2<VF/0c^2^0=kc^`80cnBY00D0k?k>0?Soh`3loo/0n_So0?omo`04
0?ooo`030?ooo@3oool0oooo00<0oooo05@0o?cl0?koo`3loOl0o_oo0?KenP3on?l0]Zj/0:BRU@3P
j/D0c=b[0=_^]`3?hJl0d=nf0??hi03oooP0MVmU0=[@[014HUP0Dfm`0<g<b03FhZ80dO6L0<OlZP27
XUd0cn>N0=CTY@3oon@0oOob0?oon`3_lN`0nokg0?com03koo40j_WJ0>_ke`3BiKL0b=n[0>Ggc@3k
ooH0nool0?WokP3Qj/l0i^g<0?Smg`3IelP0f]K=0<2f]`2ZX:40oocm0?Wkn03dno<0j>gF0>GYdP1c
MFP000<00<7=W`3>hY/0bNZA0<7USP3?ljd0a>BS0=[i]@37iYH0g_jY0=7/W@3GkZP0cmba0?kojP3o
oo00iMgK0<Fk_03[hn40c<O40?Oal@3Je=H0/ZfW0?[fj`3oon`0n?OR0?ook@3oooH0ookk0?oon`3n
ooX20?kon`80ooom00`0nOWg0?gmo@3dm?@0oooo0?ono`3ooO/0ooSe0?_cl03ilNl0a;nl0:ZVX`3Z
i^D20?ono`80oooo0P3nool00`3oo_l0oooo0?ooo`020?ono`0E0?oknP3ln?L0ookm0?oln`3ooo/0
o?_f0?ohmP2kYjH0ooWh0<^l]`3oo?P0o?gh0?[on`3enOX0o_oo0=WSb03?g[D0amR/0<_MZ`3;h:P0
cnNY00/0oooo000:0?ooo`0e08n<J`3noNT0oooc0?Oom03honl0c>>]0<[SXP3Mm[80d>>[08bKL03_
m>00l?;W0?oonP3lnO80ookh0?ojm02;Ph00nO7_0?gho03knOh0ooko0?koo`2QXj809RLQ0?oonP3o
ooP0ooof0?C`i`3?b/@0oook0?ooo@3^k^h0oOko0?ono`3fo?00nOoX0>_oaP3Im:d0bn^R0<k]ZP3L
l/<0m_oP0??oh03WnLl0c^fZ0<3LTP3Sn[80f>NT07>3@P3=iZ80bNRR0<KZX038jYh00P3:jId08`3J
mK00cM^P00@6002MUG00@ClH0=?[/@3:jZL0bnVO0=CQW01WDQ/0OW8f0<SZU03;jiP0cNNM0<SOU`39
giL0^ln:0<SLU@3DjYl0UJeO0<gYU@3BkYX0amjF09V^J@37fih0eNJ_0=3Q[@3fomL0l_[E0?goh@2H
WGd0l??D0>[_d@3non`0ooo/0080o`000;40oooX0862HP3cnM<0d]bW0>;Z[`30`800k_2_08fKH02P
[GD0c]fT0<WKX@3Smk`0joo50<gVY@39i9l0cnZS0<SWV`3BjZ00UZ1K0=KVW`37hiP0cNbP0<STV@2J
]6X0g?2X0<oSV`38gYD0[/f10;oQU03;l:<0`n6G0=_/YP3Fij40_]NC0;gPW03B]I<0^iMm0?Soj03X
m]`0cM^g0=k[YP3]n;<0en:P0=?KW`3oomP0gm[40?onl@3hknH0ooch0?omm03oonP0m_7A0>k/``3@
e:40g>>_0=WS[`3/n/T0b]bZ0=[/^P3:g:P0h?6k0?_od`3TlKT0g>BY0>7WZ`3cm;P0Ee/N08ZIF03Z
ml40gNFd0<76W@3Mi[/0e^Ze0<gV[@33fZH0e^Fj0=kU``3ioM`0gNjg0=;/Y@3Ajj80amnE0<[RUP3G
kj<0Q9a@08VQE`36gID0e^fW0<oTX@3Gk:T0k_jo0:NeNP2QZW/04ad005i`FP31f<H0KIN102=H>P2Z
kl00__Zn0=;WW03NjkD0aMFX0=[U``2SUGX0VjZE03=CB00HA540d_oo0>3onP2:/I@0D7=C09B]Q@3;
iZ40`nJF0;KWSP2diIH0b>^[0?7_eP3ooO40ookk0?oonP3cl]d0oooV0<SDY03@hZP0aMRF0=CZW`3I
kj@0eNBQ09fXK00K7`00B4/L0=_V_P1`N60000D0004?003?hJd0eNR`0722CP1:EcT0[[RP02@[2@1c
NEL010800>g/cP3XlK`0f^R[09ncKP3Qm[40f^n/0=ca[032f900a=^;09nfI03Ln:<0d^jJ0=CaX@33
hY@0bNRL0=3/XP3;i:<0enba0??od03homh0mooE0=OQVP3:e9P0bM>`0?cok03fooD0nOoh0?_on03c
n_80o_om0?OhnP3nool0303oool0B`3hn?P0nOWi0??_kP3olo00ooC[0>KOc`3Ng/H0oooX0?oojP3n
onl0oood0?omo`3hk_T080dA0<jdV@15Bcd000@0024M4P3;fIh0`=nC0<OaY@33f9L0b<^B0=?AX03o
m>00hm[C0=oIf@3jm_D0ookm0?_jm@3ko?@0o?oa0?[ok@3]n=X0i_7?0?;kh03oo_X0oogo0?olm`3o
ooH0/[2T0;>`Z@3bk>h0oOOk0>gWi`29Q800ookf0?Won03doo40dn320<kG^P1]Kf400PD006]gB@3@
hI/0b^J?0=OgXP2kfYH0bO6K0;KMP03;kHl0S:U?0>Ce/@3@fZD0j^[B0?gkkP3oooX0_Kbj0?ooo@3k
ooT0n?og0?_omP3loo@0o?oZ0?_oh`020>[gb`030>chd03gonT0mOg^00<0o?om00D0o_oo0?ooo@3o
ood0ooom0?glnP020?onn`050?omo@3VhMd0g]_F0<6m^P3Xi>400`3oood0103oool0o_oo0?koo`3l
o_d50?ooo`0G0?ono`3hm?<0oo_j0?ono@3oo_/0lnk[0??dk`3lnoL0bl?00?oin03on?L0_ZbX0?ol
n03ooo/0nO_f0?[ln`3lo?h0koSW0=o[d`3BglD0c]bk0<gK^03>g[L02`3oool000X0oooo0180e]FU
0?oojP3ooo@0mooo0?SonP3Kk/40^=2F0=?YZ03Ol;X0hO390=CHbP3CdlT0k>WP0?oomP2`[:<0E517
0?onnP3oo_/20?ono`0Q0>WYl@3lo?l0o_oo0000003clo40ooci0?KckP3ooOT0e]7=0?chm@3ooo/0
ooom0?kno`3oo_l0mO_]0?Woj03SoKh0d>jV0<3PU@37iZ00c>F^0=gca03eomh0hOG40=[i]@34h9H0
d^VQ08bKF02jbXT0cNJR0<WXXP36jZ00b>ZN0080b^VM0280`n6K0=?RZ@1QIC<0PGaD018C0035gJ40
`^>N0<_WW@3DhI`0JUDP0:NHG`3=k9h0f?BZ0=kd]03Jk[<0e^N`0?3nb@3Ei:d0KX120<GJU`37hYD0
c>NJ07fEB`1ZP3P0ambK0=3TY`3Dijl0i_C10?KodP3HhKH0Xjb10=_R^@3<djX0looK103o0000Z@3S
j<00o_oJ0=7LY03Pj:d0UiMG0=SHVP2GX6L0TYeU0=OT[036eI`0d>JX0=O][`3<ij@0cnZU0=7_Y`37
iYX0bn>I09JPF`3FiYl0b>BI0<SWV`39iIX0ZL=i0=KZXP3KlJP0e^bS0<;QU@3CmJP0`>VK0<3PU@3G
j:80e^>N0>Ci^035hj<0/i5e0=njY`3_o^L0mOoc0<gK`@2mah/0a<f>0>K_[P3Jhj@0noo>0;fhXP3o
onl0oogb0?oek03ono80e<Z_0=[E[`3^k;`0j>ba0<[@TP1EG2H0<cP?0=oU_`3:dJP0mooA0?SocP3<
fJ40g>Z_0<cGV`3;eiT0bmFH0=SSY`2P[W40oOoB0?kof02AUG80d]Vh0>cle`3gon40n?oT0?coj03l
onT0oooV0>Ci_P36i9X0cNVN0=?^X@3Lm:P0cNFI0=3XWP2;XU`0SjIP0<GKVP3HkZd0b^6K0<oNV`2J
Y6D0f=ZY09NGL@001P00OHil0;gWd@2^ilL004/K08kDUP3<iiX0_m>H0<[N[@33eZP0[:Yj0<_R^031
hlX0G8:;0<Wno`1cX8T0D7ED0;oO^03InLP0`NVP0<?bX@2dk9D0^>ZQ0=_ob03io>/0oo_i0?oao`3o
l?X0Vif70=?H^P3Ok;L0cMfL0<KKT01iTCd0UJ]I08FDD@3NjJd0=cdA04147`38c[8000@00>Oaf02<
VWH0VZee0:>fO`3hom`000D003e5<01RJT<00PT000@3002DUgP0cmVT0=k/[`2>XUd0Y[Ug0=_^[039
g9X0bMfF09>UF@2ldX00cNjE0;_IP@3FmZ40b>NG0=cg]039hjH0hoO60>Gga`3VllL0i?300>_f_P3A
f980i>bc0>[^e@3ko_<00P3io?l20?coo`030?koo@3jo?T0oOon00X0oooo00T0nOWi0?ooo`3oool0
ooom0:ZUXP3oo?H0ooW]0;>YW@35`[<00P3ooo<0B03nooT0o_gk0?oeo`3om?l0UhJ<02hH001fNFP0
3aL<04Q2=P3Rj[L0enb[0;gHT`3XlkL0VI]Z0::PM`2j/j<0a[fh065HF@3ooOd0n?;b0?ono@3in?@0
oooh0?oom03nonl0o_o]0?ool@3oo_d0nO3e0?omn`2k/k00oogk0?ohn@2ESYH0o_Oo0?onn`29QG`0
nOOX0?Kol@3]onL0f>S40=KQ`@1aMF@00`H009NSM@3Bhid0an><0<cYU`3Flk00bo>J0=?mV`3@ki80
d^^G0;>mP@3[k/40o?WX0?oomP3Vhmh0eMOB0?Gjl`3donh0n?oa0?Ook03honX0j__?0=CV]03BiJd0
aMRQ0<OIZ@3hon`0n?od0?_oo`80o?oo00l0o_oo0?ooo@3oood0mOCb0?[fl`3elNh0jNCP0<G0_@2b
[jX0gMcG0?ckm`3mo?P0ooom0?;bl03gmoD0103nool50?ooo`0G0?ono`3nn_T0nOGd0?ono@3mn?D0
eM3=09BET03Yj^D0no?a0?kZj`3njNP0e/C00?ohm@3oooX0m?Ka0?Shn03oool0nooh0?Wom03foo00
noo_0?_ok@3konX02`3oool000X0oooo05T0dmj?0?7hcP3[l=`0n?oo0>_emP3WnM<0g?6h0<WNV@3C
i:d0d^6h0??jjP3oonl0ooo/0?ooj`3blMl0h^?A0?oom03emn`0o?kk0?Kjn`3kool0o?oo0?koo`13
@TL000040?omo`3ako00ookm0?[fl`27Ph00k>SU0?[fl`3oo?/0o_co0?OnkP3`o]d0a^6N0<KUV@3>
lIl0`^BG0<_ZYP31fih0jOk50=C/[P36iYd0c>RN0<oVWP34di00e^JU0<gVXP39j:80a^ZP0<SZWP3:
jId0bNVN0<g^Z@3?hjH092`006eZ?`031P00b>:S0<c]YP3:iY/0f>FP06=<602[VfL0cNZ`0=kfa03^
o]X0lOcN0=cTc@3Oi=00gN;<0=cXa037eZd0`]VQ0=?[[@3Aiih0enfU0=3WW`3<hid0dNRT0<_QX03B
ijH0h?2b0<CDUP2MZ6`0b]VN0<;NX@040?l0002`0?Sod`3gom40dnNX0<cLW@2RZfX0em^N07f0B`2M
XVX0]/670=;RY03AijH0bnBR0<_YX`34hYX0`MnE0<g/X03EkJ<0[[Ud0=;SW03Dl:D0b^VM0<;NT`3;
iI/0eNVQ0=W]Y@36g9<0cNVN0<3RU@3:kj80bnNL0=SRW@3OhJ00h>F[0=WZ/`2_PG40[7eg0?Oon03h
ood0m?of0:NeTP2LZh00dNFV0<oVWP39i9L0VI>50?oilP3kl^d0oo_h0?ogkP30]IT0oooH0=ODX@3J
fYX0TiIA0=ODW@3on]d0O6MB07IUB@2YX7L0F5@T0=oW[03<fY`0eO2]0;SGU03Dmk<0a^BV0:6^N@3W
k<<0a/ZU09FIOP1_M5h0eMc<0?comP3oooP0oooj0?kjm`3oonl0hOS40<WXY03>k:H0a=fI0=7XY03L
k[00amVM0;g@V@32e:00cMn_0=OY^@3Hi[<0`l^H08nBH`3fl/d0noGK06EUF@000`00kOok0=gok`2`
jLH09F0`09S4Q`30hK80`nBe0<;ZY02`aW<0aNfG0<7XY`3QmNX0K8n909NkX@2mhkh0]nfk0:__]P21
a8h06E4P05f1F`3eonl0loob0>ooo`3eool0oo;o0?oho`3Zk=l0/;FO05aZ>@28V5X0en^T0=O/W`33
f8d0cmjW0=;M/`2c]Z40GV5@0?[nk`3noo40:CD=000=003Ej:H0Kh1:024`2@0b>C40JW1T0=OO/008
4P0000T00:6bOP3BjJ<0dN^Q0=3[WP2dcXD0Z;mk0;K<R`29WU/0`mN@0=G]X@2mghT0eONP0<o^X03?
jZD0i_W<0>Gef03ioo40noo/0=GO_03DgjL0eMnS08nBH`3gn=H0oooh0?ono`3ooOl0ooco0?KenP23
Q8H0[[2[0?[ln@3nood80?ooo`80ooom00`0o_gk0?ooo@3QgMX0f=CA0?ojmP3oo?D0oo[e0?kfm03i
m?P0oogo0?7`n03no_l20?omo`150?ojo`3oooX0KFaG06Q`F`1EG4`0D51405UH?038aJ80nOG60?Sd
a`3Zl<h0noo/0?Son`3mnOH0k>;S0?[`l@3onol0no;g0?olo`3on_`0oogm0?onn`3ooOP0ookj0?ol
nP3jl>l0`kRf0?okn@1gJfl03`890?ojo`3onol0[J^O0?ook03oon@0mOoT0?CoiP3homd0nOoO07b1
J`001000KWY<0=CSWP3Dk9P0dNbK0<7LV@33jYT0cOFO0<_UV`3GijP0f=J`0:RRR03Sf]<0f]?=0?oo
mP3Zm=`0n?oX0<SS[P3:iZ`0b>BW0<_XZ03=j:40aN6F0<gYW`3:hj80a=^U0?Gok@3aoo@0nOoo0080
o?oo0140o_oo0?ooo`3oood0ookk0?onnP3onoL0lN[T0?onn03ooo/0o_oj0?oon`3koOX0nO_h0?ko
o@3inoP0o_om0?goo0020?koo@80oooo0`3oo_l20?ono@0E0?onn`3on_L0YZ6N0=KAcP3oood0mOGc
0?omo@3onOX0onc^0;JRX@3onoP0n?G`0?oonP3jnOL0ooko0?koo`3kooh0o?om0?con`3koOP0o_oj
00/0oooo000:0?ooo`1J08BE>@3?g:H0iO3B0?Woo`3hood0mooO0>Cj_03Aiih0eNVZ0>?ea@3lon`0
oooX0?ooh`3oonH0n_kS0?[oiP3jond0o?oa0?Oom03foOH0nOoo0?Olo`3nool0ZjZ`0000103hn?X0
oooo0?omoP3oood0^[Jc0?_flP3oo_X0ookk0?gkoP3loo<0iO3>0<_VX`3<jil0b>^G0<K[V`39j:80
b^NT0<gVY@3<ij@0bnfQ0<[VW039h9P0e^FR0<7AT03=iZ80bNRR0<KZX038jYh0b^VM0<WYWP3Em[40
bMfP0009002FTfP0;S420<KPW`3<kZ@0c>RM0=?PV`1MB1<0[9aY0<_X[P3;hk40e>C009BOP@22RW<0
ooo_0?Smi`3goml0nOoO0?Goe03;hjD0g?2Y0;oES03>iY`0cNNN0<_UW03@jZ40d^VQ0<[OVP3Fij<0
V:MT0<kSX033ij40b^VV0P3o0000ZP3CjJ/0cnVZ0;_HV03BkJX0amjJ08VHE`2MYFT0TYEP09JKH`1U
L3@0c]jP0<cSW`3;i:00dNnW0;cJT03CkjD0cn^Q0<kUW@32chT0enRQ0<STV@3=kJ40anJJ0<oWW@3;
g9D0dnBM0=3TW03GlJL0`^6E0<cZX03GkJ@0Y:MT05A@4@1FEAd0Ef4/0:IbI03JYJ40oOoj0?coo`3o
ood0o_KQ0?omh038aYH0i^J`0=kSZ@2_Zj80oogk0?olo@3omoT0o_?_06MM@P2?RV@0inBa09NIF01H
GAX0inJ]0?ongP3KbK40n^W=0?W]a@3PfZX0c]6H0=[TY`3<iJ<0^mZG0=ko_@3ElkL0SYMX0=_M]P3D
f;<0oOoW0?OliP3<cl@0oook0?ono`3flOD0oo[n0?gol`3FkL40a^>Y0<CPY@3AiZd0enRa08^IIP1B
H2l0cmnb0<oN]@3Di;l0cMRf0=[O`@1dMEH0clj`0>KTc@3oonl0O7eh00D9201YN7<0j_oc0<;PaP2o
il8001H005b2F@2mi;L0[=^C09FbH02kiHl0c_>]0?Ooj`3`oo@0`N6j0;WO/02]jKH0Z?3007FkV@2?
bK<0gool0>Wlo`3aool0kOoo0?7oo`3on?d0ooOk0?gon@3moo80en>k0<[HY`3Eijd0cn6S0<gOX`3E
hKT0en330>c_i03looP0o_od0?gol03com80kOo30<kTW03=hJH0b]Zc0<[Ab@3Efll0en2a0<_IWP2<
Y6P0b>6O0<_XUP32hh`0a^RB0<WZV`3:j:80c>NT0<gVY03?iZ80cNNN0<SYVP3:jI/0b^FR0<[SZ@3g
onX0n?oc0?Won03koo<0d]^l0=ORZP3Jhj`0bl^_0?[ii@3oo_d0oOSn0P3ooOl01@3kn_P0RHZ50?Gf
l@3oood0o?cl00@0oooo00@0o_oo0?ooo`3oool0oooo0P3oood00`3onoP0ookk0?onnP030?onnP<0
oogo04X0oOgo0?[lo`3lo_l0o_ko0??dmP3nood0o_oe0>?Vd`0X:aP0Yj^L06]fIP14BcT0ZjfE0?on
eP3oomX0o?oZ0?Som03eool0ooom0?oln`2_YJH0ooSl0?olo`3onOl0oo_o0?[amP3jm?H0oocl08Ao
O01HD4d0`;Nb0?ohlP3onOH04`@70?ogn`3fjo40ooco09^LRP3oonH0o_oO0<[L]034fk40b]bZ0=[Y
_P1iOVL01@X009RTM03JjJH0_mN30<oZV@3Hlk00a^VU0<SXY@3<hJP0d=bZ0=KB]`3Hckh0VI2;0>oX
hP3ooo<0joWF0<OJ[@3<jjD0b>RL0<[ZWP3<k:00b^VI0<c[V`3<j9h0bN:Q0<KMZ@3`on`0mook0?Kk
oP80o_oo00@0oooo0?ono`3mo?X0ookk0P3oo_X00`3lmo40ookh0?oon`050?koo@070?_mnP3nood0
o_om0?oon`3jnoH0ooko0?[hn@020?ono`070?Gal03mnOP0ookk0?onn`3gl^l0oogj0?ogm0020?oo
o@0;0?ggm`3onOX0ooKh0?GQh03onoP0o?Oc0?oonP3ooo/0noOf0?ooo`3fmoT00P3nool=0?ooo`00
2P3oool0F@23VCD0_]6A0=7P]`3aoO<0n?of0?Coe`3QmkH0cnNK0=CYYP3JkKD0i>o=0>[`c03Xk/P0
k_C>0>C^b@3[mm<0n?oW0?Koj@3Ul=l0joKX0?Won03goOT0nO[l08^:S`0000@0o?_o0??cm@3oo_l0
m_Ce0?WelP34_k/0nO;/0?_flP3ooOh0n_k]0>;]b`3:iJ80b>NI0<K/U`36k9T0b>ZN0<WXXP3<ij@0
c>NR0<OYW@34h9H0f>nW0>Ke/P3kolX0cNJR0<WXXP36jZ00b>ZN0<[YW@3:j9h0_=fH0<gQY029TUd0
Q85D06IZ>03>jJH0bnnU0<GTUP3Ch9X0GdXE0:FHH`38j:L0d>ba0;o@X`2X]8h0i_3>0?ooiP3jon00
nooL0?Ooe`3aol`0d^^Y0<gQVP3Qmjl0an6G0<kZW`3<j9d0bnNJ0<COTP3GkjD0am^C09:SG@3Il:P0
_>FI0080o`000;80an2L0<GPW@3:jJD0d?6/0<_/Y`3;jJ<0hOBb08RDEP2^/G`0e]VR0;BoP`3FiZL0
g_Ra08fWH039iid0gOV_0;_GS@3<iYd0]lf50=SXX@3JkZH0aNBH0<_[W`36iIT0d^ZP0=GUWP3RlZ/0
b]^D0<?KT@3?jJ00d^VS09j]J01RHB00O7Lg0::PI`2:TE/0Qe920:ecK`3oo_/0i^CW0?omo`3oo?<0
o_KS061L=P2HUfL0c]6L0=KAcP3ooOl0ooco0?ojo`3oo?/0/ZbD06=O>P2=S5`0EEXJ06]b;P36c900
oooK0?ooh`3ilm40eLjT0=_DZ01UIC40i^^c0=SW[03?iJL0f_Bg06Z1B`2NX7T0f]Zf0?_ofP3lon@0
o?oZ0<G7_03Kf]H0o?Gl0?oko`3oo?l0o_oj0>[nf`2neJL0j?k?0:^kSP1ZMDX0f>2i0<cD[@3Ylm00
nooV0>_hg03lond0noWZ0?ool@3oonl0oog^0?Ogk@3nool08bLX03Hl>P1^MFd0f>7>0<ON`@2AaYP0
5d0F000A0035n;D0L95:0<C`Y@3?lk<0m?OH0<cM^@34hZ`0e?_20;ghb02SiKl0@81b0:KPh@3Lool0
a^Oh0>Woo`3Wool0m?oo0?oomP3oo_H0n?gf0?com03_n]X0e^:l0=OW^P3>gZl0f>Rk0?WoiP3koo00
mO[f0?_oo03loo<0lOWT0=k^_@3Ml[40c^JJ0=7UYP3Ol<@0i_3W0>[bi@3Lj;X0fNR]0<CRVP3@kj<0
anZ@0<[_T037kY<0a^bG0<SYXP39j:@0b^NU0<cWY03<ij00bNVP0<cZY03Ek[L0hoW;0?Sol`3bo?<0
n?og0?Ook`3NilX0j?Fm0>K`_03Wj]T0ooof0?ono`3on_h0ooko0?onn`3oooH0nOW_0?oon`3inOT0
moOg103oool0103nool0oooo0?ooo`3oool20?ooo@090?gjm@2]Z:@0m>o[0?okm@3lm?40ooci0?om
o`3noOl0oOgo0080nogo04P0nooo0?3cn03`mNl0o?oh0?WmkP2FUXX0DTdj0;>fX`1RMF80FW5Q08bK
QP3bll/0kO?70?Kni`3iooX0n?oo0?WhmP3ejnT0knOU0:^QXP2[XZL0elgE0:VRZP36_<@0l^c`0:JP
Y02UWil0knSR0?7Xh@3mlnX0b;je09Z<R`3on_d0o_?g0?G]j`2c]J00o_oT0??ne03Sm/T0`MNX0=KY
/P3XmLL0P8I/0004003Hi;@0AEHB0=G^VP3?jYT0bNJS0<_W]03<i[H0e>Fk0=_R`03SgLd0i=_B0??Y
i`3oo_P0oooa0>[id03>hZl0a^NH0<;TSP36iID0b>NG0<[WU`3<j9/0cnVR0<gRY`3?h[@0loo`0?So
o`3mo_l20?ooo`090?kno`3mo?X0o?_i0?okn03[i^<0[JRT0?onn03flNd0ooom00H0o_om0200o_kl
0?clnP3ko?L0oook0?ooo@3oo_l0m_Ce0?oln`3oo_d0n?Cc0??^j`3oo_/0aL2m0?oln@3klo00inOU
0?ooo`3ooOl0ooWk0?odmP3kinH0n>WV0?onnP3oooX0oogj0?oin@3hm_T0nOWk0?ooo`3gm_/0m_Gj
0??bm`/0oooo000:0?ooo`1H0<_YQ`3Ajj40bn>W0=G/`P3Rmlh0mOoA0>Ko^@3@ji`0c>JL0<kWX`3@
iJ`0e>F^0=3RZ03?hjP0b>2T0=7Y[`3Xol`0goO50=?U_@3Rlll0m_oT0?Wok`3nooX0o_oo00`=3`2c
];P0o_oo0?ShnP3oool0m_7^0>GMfP3Oe]40oogh0?kjm`3jon/0j?C@0<gXY@3:ji`0a^bG0<K/V@36
jih0b>ZP0<[XX03:j9h0`>:F0<KRV035g9@0dN2M0?3o_`3=iZ80bNRR0<KZX038jYh0b^VM0<[XWP3?
kZX0dnFY04UB7@29QeL0U9QU0<CRVP33jY/0bnjL0=oaY`1YFR<0WiIK0<cdW03;kYX0a=jD08BHD@3O
kZT0i>n]0=k[YP3Bii`0a]j@0<GWT@38j9D0PI9>0:ZnM`3EkjD0c^fO0<WZV@37jID0e_RT0<cYV@3A
jId0[l=k09VaI`@0o`000;40`=jF0<WZX`30iYd0JHi805n0>`3:hj80c]fR0;>fP@1XKCL0gN^]0<KI
U`3DkZD0Sj]Q0<GQUP3Jm:X0`MR@09Z^I`2EYV00b^2G0<GQUP39kZ00b>fO0<[YW@3Dk:80WJYT09BO
FP3Ii9l0bm^D0<;CS@3=g9/0c=FD0:NTH@3Qg9X0g^2O0<[FV01O:a<0NClc0?ollP3oo?X0ooco0??h
o03koo/0iO;D0<_J/@39gJP0l_3c0?Odn`3oo?l0noKm0?ono`3oon`0oooQ0=7IZP3Ei:<0fnbV0<gV
Y02ng:P0i_oD0>oof@3Mhkl0g]jl06MQ@@2f[H`0no??0=[D/03MfkD0oogJ0<FnY03oomh0o_oM0<oO
[P3IjK`0kNoI0?C`i@3onol0no7j0?oko`3lool0nOof0>kghP3nonl0`L2[0>CRc@3oonX0oocX0?oo
k@3en^@0nooa0?;ij@3Ke]80ooof0?oom03ooo<0o_of0?koo@3WinL0Qh9o075XH`0;0000[:jH0<7[
``3Cl<80eO?107RTL@1NP5/0`Ng<0<W[b03Wi[H0amZJ0<3]W033nJ/02D@F092nY01JQHh0>f]o03Ea
R@22`<l0>V]b0?Gom`3gn^D0o?oO0?Oog@3gonT0nOo[0?[ok03eonL0n?o/0?_ol@3gonl0l_[]0?Kn
l`3hooL0n?oa0?Coh`3JilT0a]RT0=3WX`3<jY@0cNNM0<[RZ03hoo40n?oc0>Wgd`3Fj;H0a^6L0<SW
V@38kI00ann?0<?/T035kIL0aN^P0<KZY038jJ@0bNVP0<[XX03>j:T0b>2/0>3`e@3foo80nook0?Wo
n03QjM80h^g=0?;oe02``HX0UJIb0>Gaf`3[m><0o_oj0?oon`3oooP0o_[_0?ool03ooo<0oook0?kl
o@3no?l0103oool30?koo`0<0?ooo`3oood0ookk0?onnP3ooOL0oogf0>cSg03oo?@0oooh0?ooo@3o
ool0oOco0P3lo?l0C`3kool0ko?b0?Wol`3loo<0oooc0>_Kf`1^Dd00clZ/0;?H]`1k]:40MZ><0=SZ
^03JkkH0j^oI0?onn`3ooOl0o_[g0?Wfk`3ooOP0ookk0?ono`3ooOl0ooko0?kio`3nnOd0ooko0?on
o03gm_80oooj0?Sai`3on^l0oogd0?ohm@2=Ph80[:BQ0?ool@3DgL80en>o0=?U/@3Sn;d0aMNI0=GR
[@13Ab`000@005EQ<@2N[f/0b^JA0<KVT`3;jZH0moo]0?WomP3loo@0o_of0?onn`3oo_d0ooko0?Wh
l`3noo<0ko_E0>7a`035giH0`mnB0<kWY@3Cj:d0cMn[0<cNZP3Hj;/0i?3:0??nh03looX0o_oo0?ch
n@3kmOD0oo[j0?omo`2e/K00OWYi0?chm`3oo?/00P3ooo/00`3oo_`0oooo0?koo`020?koo`<0ooom
0200lo;^0?oln@3oo?T0ookj0?omo03ooOh0lNg/0?3/j`3Lf=L0KFQU09ZETP3ooOX0ooWf0?kfl`3o
oOP0oooo0?CdmP2j];H0k=WM0?;LgP34[jh0j]_F0=G>b02h/jd0]jn/0?S^k@3ak>T0oOWf0?ono@3o
oOl0ooko0?olo`/0oooo000:0?ooo`080<;SRP35i9P0`n2M0<gX/@3Gl;T0kOo60=gh/@3>jYl20?l0
001>0<oZY`3Fk:/0c^FQ0<kWX`3<jZ@0cNZW0<[XZ039ijT0d>Rd0=ka``3/om80m_oS0?kom03^l>d0
:R`Y0:>WZ03lool0o_oo0?7al@3oo_/0l^[W0;fd[`3oo?L0oOWf0?coj`3Xm<h0a^6L0<KVVP36k9T0
aNbI0<K[WP38jZ00bNVP0<WYWP37jId0cNVO0<WPV03JjJH0aMFD0<gVXP39j:80a^ZP0<SZWP3:jId0
b^RN0<CQW`3Mk;40FF0/0:j/N`2TZG<0b>RO0<S_WP37jYP0d>JK06YM:02QWF00`NbC0<K/U@3BkI`0
V:mO0;;3M@3Fi9L0e>FG0<kUT`3AkIT0co>L0=CdX@2DYF40R9aE0<kZW`3:jI/0co2O0<7TT03En:@0
bnRH0=geZ@3BiYl0/<In103o0000:`3OnK80anJP0=3aZP39k:P0Z<N40=G[[@3GiZd0e]VT07f4CP37
eiP0e>VV0<oYX01bST<0c>JL0=G]X`3:gYL0Wji[0<SIT`3=iid0b^ZN0<_bX`34ji`0bnZN0=?[X@3A
g9L0];ii096KEP3Qk:L0g>VT0<_GV@3Ykk40TiA@0>?TWP3:eXh0aMZE0;Z=KP1nBCL0ook]0?kaj@3o
o?X0oogo0?oln@3dln400P3oonX0JP3fm_H0ooko0?omo`3ooOl0ooko0?GihP3`n=40fnVf0;cCS`3<
iYd0a^FQ0<kd^@3XomT0l_oS0>CZcP3Xj=00]jbJ069EA03ml]`0o?CM0?3/d@3oonH0hMK40>_/bP3Y
l/D0c>6V0<gPZ03/l<l0jnKC0?oko@3nmOX0oogo0?coo`3go?H0o_kd0?oom03Dc;l0iMc=0?omk@3o
m^D0ooo[0?CghP3lonl0o?oa0?gnkP1GFD@0XjF?0:naV`3Si=80nOW_0?oom`3im>h0ookd00T20002
1P00`mbo0=SU^P36ej40aN^h08NVQ`0fHDd0W;jS0=kQZP3;iI`0^?:U0:W_YP0XLc/0`?KF08>RY`3S
ool0i_oo0>Ooo`3Wooh0l?SP0?coh`3FnL<0goo<0>ckdP3Vm=00iNoF0?[okP3koo<0nooh0?WomP3k
ooH0nOoc0>gih`3Mj/h0h?390<gM^@39gJP0e>f[0<WZT@37i980h_fj0?Ook03^oNP0n?oX0>Ceb`3D
jK40dnb[0=3_W`3;kIL0bnnH0<K/V@36jZ020<SZX080b^VM01H0b^:V0<kT]P3]n>X0m?[f0?con`3l
oo@0g>S20=OT]P3Mk[P0//J;0;oDV`3@h[P0dn;10?Wol03nooP0oooj0?onn03ono00ooof0?3/j@3g
lo@0ooko103oool30?koo`0<0?ooo`3oood0ookk0?onnP2bZjD0n^oY0?omm03om^d0oo__0?kklP3o
o?D0ookm0`3oo_l05P3oood0o_oh0?[mlP3oooH0XHj@0:>3JP2UVgL0^N:h04f8LP26/i`0_/^E0=S]
[03Yk=40ooof0?omo`3oooP0nogb0?oon03fmo40o?_i0?ono`3gmoL20?ono`0W0?clnP3oood0o_oo
0?koo@3oo?<0n?7W0?ohk`3cj>80oock0?omn`3ino00n_o_0>Oaf035eZ80hoFg0>Gc]@2laY40C54c
00T=003IiKD0d>BO0=7_V@3=kYd0^mnI0?Sol`3lo_d0n_cg0?[kmP3hn?P0n?Sj0?koo`3inoX0o?oh
0?Cmh03kon40cn:Z0=7V[@3^om<0nOoS0080nooX00l0mogQ0?coi`3oond0o?_f0?kjn`3oo?d0oock
0=;:b02dZj`0n?;b0?omo@3oo_d0ooom0>o_k@3oood01@3oool20?ooo@0K0?WelP3oo_/0noKc0?on
nP3]iN80/:b[0<[6a@3onoX0ookk0?KakP3oo_/0oOGb0?[bk`3ooOX0oogh0<Ro^P3Kfm/0`l?50=K@
dP3onOd0ooSj0:VDT`3on_H0oogh0?onn03Hd<d0j=kL0080ookh00@0ooch0>o[jP3jm_L0n_Sm2`3o
ool000X0oooo00<0`NFO0;oSV@34iY`00P39jJ000`35i9h0aNBP0?l000030?l0001>0<WZV`36jID0
a^VE0<K^V035kIL0b>nN0<W^X03:j:80b^>R0<SNX03:fZ/0jo3J0?comP2j_KH0>3di0?_oo`3gnOP0
oooo0?oln@3oo?X0i]_G0?okm`3oo_X0l_OP0>?_b@3;iZ40bNVM0<K[V`35k9/0aN^P0<KZXP39jJ00
b>ZN0<?UV@38i9X0aMbD08RGE03Pl:l0cNJR0<WXXP36jZ00b>ZN0<[YW@3:j9h0`]bK0=CRY`3JgjT0
[ZYj09JKH`39jIh0a>jL0;oVT`3BjYh0Y9]T0>?RZP2kiYl0bO6Z0;oKT@3IlJL0b]bB096QF02BY5X0
RJ1H0<SSWP3DnK@0bn^X0=o_[P2GZfH0b>BI0<WZV`37jYP0bNnL0;kTT@3<jid0`mfD0<WMV03Dj:<0
am^F0P3o0000/P2BVeX0]<F10=C[Y`3CkZ/0cnVX0;C<SP3Ij[<0KGY403m6402X/GX0g>n_0<WPVP2=
ZEh0ZlMj0<GMT@3Hk:@0SIaG0=GNW@3DhI`0anNK0<CYV`2mj9P0`NbL0<g]X@3Bj9l0e^2K0=KKV03Z
kj`0G64N09JOGP3HhjT0dM^N03a6003Lj9h0b>FC0<ccXP3=[840^Xm_05iJ?`3?ak@0oOGZ0?koo`3n
ood0oooh0?Cek@3ooo/0o?oj0?coo`3ho?d0o?oo0?conP3VlmD0c]nc0;kFW036iY/0co:R0<?WW@35
hJL0mooR0?coj03ooo@0oock0?oho`1OE5X0oook0?WonP3]o^h0e^??0=;<`03oon00d^2]0<cXW@3I
lJL0/kV90:6NO@3ej^H0oo[j0?ono`3kool0ooko0;FZ[P2cYJD0onkZ0?ojl`3nk=h0ooc/0?7[e@3/
j]<0k?;H0>kif@3Znll0joW60>gg``3in<X0clZT07QaE`3Gd;d0n_g/0=o[d`3OmmD0kOoY00d32`0>
0000KVL`0<k[Z02keJh0EhQ[03i[A03BhI`0_^NK02MfB@0:ERl0a>nj0;g/`01mY8l0j_ok0>comP3_
on80dN>k0=7]/`2^bXl0enRd0=7PY`3Aii`0bMbL0=OS_@3honT0n?oa0?[onP3kooX0lO[U0>WgeP3L
k[`0dnJ_0>3e_@3Ol/D0c>Bb0<cYZ@3;kY00f?^M0;SGQ`3Bj<40mOo]0?7oj@3ionl0jNkG0=CN_03F
ik00d>JU0<cVW@3<j9h0b^RN0<[YW@3<jIT0cNVB0<gYU@3MlkD0k_kG0?_oo`3lool0o_oh0>G/c@3P
l:l0g?6V0<kTV@2hdHl0c^VT0<OYTP3;jJ40n?oV0?[olP3ln_l0oogo0<c3b02`YjX0ookk0?omo@3g
lo840?ooo`1A0?coo`3nool0o_oo0?ooo@3oo_d0ookk0?onn02RVI80oo_b0?omm01eJE/0HU]1079[
C`2@RFl0e/Zj0>CHc03Tf]40ooGc0<Vo_P3SgMl0oogo0?khnP2FTHh0[I1X0:ZMJ@2mgj`0A6YE0<gL
a`2ZUed0h>2F0?7cb`3oon`0l_oc0?Wol`3ioo40noof0?con03loo/0m__e0?Kkm`3dm_<0o_ok0?ko
nP3bmo<0nooo01DL903jo?T0ooki0<Fl]@3ooOP0ooWl0?ojoP3oool0o?om0?Onm`3SlKh0eNBQ0;o<
Q`23S5<0Gf9300<7002jb9L0hOJa0<KVT@36k9T0b>fW0?gnn03onOl0oogn0?ooo@3kool0nOoo0?On
o`3iool0nooo0?kon03ooo<0mooZ0?CmjP3lood0o_oo0080oogo00h0ookm0?okm`3on_@0oogh0?S^
k@3EalH0k^3M0?olnP3onoT0oogk0?omnP3oo_d0mO?d0?cloP80o?oo02L0o_oo0?ono`3oo_l0ooko
0?ono@3ooOd0ooci0>OOg03;`Kl0j^3N07I]J00A30T0U92?0?ono@1/If@0fmKC0?okn@3lm?40f<o:
0<_2_@3oo?L0oogh0?cloP3fmo/0oogo0?o]l@3oko40im;A0?ojmP3ooOH0ookf0?omn03oo?X0ookc
0=?=_`2l]ZX0ookh0?omn03fm?D02`3oool000X0oooo00L0bNjX0<?WW@35jYd0bN^N0<SZW@3:jYl0
bNVP00@0o`0001l0bnbM0<c_V`36k9L0`nVB0<C/U037kIP0a>ZG0<OWW03<ij80cNRS0=OY]@3/m=d0
noke07^0N@1_M6d0l_Oa0?oon`3jnoH0n_Gb0?ojm`3oo?X0hm[E0?cjkP3Ki<D0dN6d0<_VX@37ii/0
a^^K0<G/V`36jih0a^ZP0080bNVP00L0dO6V0=gi[`3=ij00e^^X04UN6`3=ij00c>RN0080b^RN05<0
c>RN0<gWX03JkZl0TIYS05AF902NW6/0Ri1H0<WWW@36ji/0anRG0=[[Y02SUf<0g=JR0<k/[03Ajj`0
c^FQ0=G/YP39giL0gnbV0=;OVP2@Yf40bnZV0=3e/P2ogi`0dNBR08^OFP3LmZd0dNfR0;_JS039jY/0
`nBE0<KRV03?jJ80fNj]0<WLVP3EiZ00g>^V0=[VY03Dhj00C5lM0<_QX03?j:L0c>JU0=C/[P3=hjD0
RYaP09^VK03@fil0bmjL0=3UX017HAL0e>bP0=K/X@3<h9P0AUL@0=GPW03Ei9l0cNfQ0<[_X@33k9d0
a_2N0;kPT`3@jZ00f>FP0=oXY@3:dHh0Gf@T09:KG03ChJ@0dmfP05eT803>f940anJF0;gXUP2VSV00
Wg]I07miG`1VFDT0ooS`0?koo@3inoH0o_oh0?oonP020?oon`230?ono`3oool0ooom0?Wll`3/mmT0
bmbb0<oV/034iJ00a>RN0<c]YP3>hJX0AU4Y0>[ad03jnn/0ookh0?ojo`1EBU00lo;`0?Glm03eooH0
en_@0<K6[P2CVFd0b]VP0<WSV@3;hYX0`LVH0=3A[`3oo_P0oOWj0?kmo`3kool0ooom059>A@3oo?00
ookZ0>SLa01UFS`0E4/Z061M>P19BRP0dmfj0<_J[`39gZD0c^2R0=OUZP3>did0jNRh0<k<Y@2e]I40
c]Fc0=[V`03>i;H0looT0?_`mP0A1@0020@00?Goc`2T^I80ao3@01To5P3BjjL0aO2X04N<H01c/HX0
a^F/0;GMZ@1EOeL0hooR0?7oiP3<hjl0a^2S0<S/Y03Cm:d0fnV^0=3LWP3@j9X0`mRE0=[V`P3fonX0
n?kd0?Kjn@3lood0mok/0>K_dP3DhKH0cMf/0?SofP3hon<0d^Bn0<[P[`3Bkil0`mn:0=ojZ@36fZL0
f^_70?Coj`3bnnP0nO_]0?goj@3oomX0j?6j0=CSXP3Ci:00cnJN0<gWW@3?ii/0dNNE0=7VV`3bom<0
nOoV0?Kkm`3lool0noo`0?7heP3AhJ80cN6J0=;VX@3DjJh0cnRV0<?XR`3:jId0mooR0?Wok`3noOl0
o_So0?kgo`3nmOX0g=OD0?7/j03oo_/0103oool00`3lool0o_oo0?koo`030?ooo@1<0?Wcm@2i/k<0
H5UA081jKP3MfKh0h^:l0=WI/`3XiL@0ooo/0?onk`3onNl0ooch0?ojn03/hn@0mNoa0?omo`3oo_X0
GT/[0::MM@37il80i?om0?;on02/UVL0i=RL0>K]a03honL0eN3?0=;L``3kon`0noo_0?Gnk@3kooX0
noom0?coo`3moo`0nocg0?kmn03Xin<000070:^[]`3dm?@0PhAl0>?QdP3ooo40oood0?oomP3nooH0
nood0>cii`3Rl;D0hNjX09VUH`3JhjX0KgEC0005003Ul/@0b=bM0=3/XP3?kZX0`N2U0?oon`3onol0
ooko0?kno03kooh0n_on0?Woo`3kool0l_Ki0?kno03kn_D0o?oj0?_on`3nool0oogo0?oko`80ooco
0P3oo?X01`3oo?L0g=?>0?gcl@3ll_00oock0?ojn03jm?@00P3oo_d20?ooo`030?;cm@3lool0oooo
00<0ooko0P3ooOd08@26OW`0oogk081hM@070000E4Y80?onn`3ooO`0lno^0?omnP040000oogk0=S@
cP3ajNH0oogj0?ojmP3oo_X0o_oo0?cmo`3knO`0oo[k0?ohnP2kXJ80ooSb0?ofk`3ooOP0oocj0?oe
l`3oo_@0ooc`0?cej`2/Yj40oocg0?ooo@0;0?ooo`002P3oool0203:kj40doN]0;cPUP3Cmjd0b^bP
0<W[U`3:ji@0c>ZB0P3o00001@3?iJ@0bNRR0<SZW@38jYd0bNZI00<0bN^G0<T0bNZK0<SZW@38jYh0
bNJ/0>;ag03koo/0mO[c02PY8@3oooH0ooga0?oom03no_H0oooj0?oon`3dn>X0fn>n0=GT[@3<h:<0
bnVS0<KVV`38jiT0a^bI0<S[V`39jId0b^RP0<cXWP3;hYX0b^RP0<WZX`3>lZ`0b^^T0=C/XP34fHh0
X;1Y0<gLV`3<h:D0c^6Y0<G=TP1[L3X010H004=:5`0e?`X0b]fK0=;XX03OjZD0Rh]=0;f[N`3[fjX0
inFZ0<:gO`2b_G/0d>NQ0<c/X`3Jhj00aLZ80;[AR@3<mjL0_NBE0=CdZ@1jTDd0b]nJ0=7UWP3@hI/0
bMRC0<?BS@3HjJ<0gO2^0=kc/P3?iJL0bn6Q0<_SU`3:iY/0a^ZP0<K/X`31i:00^mRH0<kXY`3Zol00
bNRR0;[SU@37kJ00a=bB0=O]Y03:gYH0bmbE0<gMUP3Di9d0_<f60:g1N@3<hYT0`]Z@0<gUV`3BjZ00
d>^N0<CUU03<lYl0c_FR0<gbXP33gYL0fNn^0<_KW@2`]840/[^40<;IT@3VmK80IehW0?K[]@3@iJ80
`_FX09bFIP2eWWh0oocc0?oenP3omOd0LVQO0<2f[@2g[:H0WiB@0?ojmP3onOl0oNg`0?ojo@3onoX0
ooK`0?gljP3_lmX0dmjn0=cca@3Hm<40e^ne0;_0R03NjJd0UJ]]0=;^^`39fk<0ooga05]6@`3on?H0
ooW^0?onj@3?h[@0f>RW08jMF03HijH0cmbV0=CP/P2i`ZD0o?o]0?conP3enOX0o?oo0?Woo@3eonH0
`]VS0<kSZP3CiZ@0f^VT0=GRVP3Hj9l0U:EO08fPH03QmKX0aMVL0=7QXP3CiJ/0fNbe0<gS/P39h:`0
_=:B09N[IP2:U4d0ZjiY0=kHVP21OdH0amBY0=;W_02dcJ<09C<@0>S[cP3Bg;X0`MR^076UI`2gk:P0
d>n[0<[QW@3@jjH0b^RP0;7CQ`3Go:h0a>^J0<7[U@34k9H0anZF0<W[U`3<jIL0b^NG0<o/Z@36gJL0
l_kX0?_onP3nool00P3oo_l0<03oooX0oooh0?_mlP3noo@0oood0?oonP3no_l0ooom0?[oh@3Dg:d0
f>>W0=3LWP3Ihk40o?o[0?comP3nooP0oo__06eG@01MA2H0X99S0<k9TP3<ei/0e^BY0<_HXP3oomP0
oooS0?ono@3oooX0n_k]0?Woj@3MjLD0d=bd0?_og`3loml0n_oO0?koh`3kom`0b>RL0<SUXP3NlL@0
k?_L0?conP3oool0oogo0??]k`3ooOX0oogh0?onn0@0oooo00H0n_ko0?Omn@3jooD0n?o/0?Ook`3j
ooT20?_oo`0j0?_om03jonD0d^JY0=;_[038hJX0c^2f0?gol03ooo@0noO^0?onm03>akd0n?S^0?oo
mP3oooP0oo[c000;1`3Vo_l0i_oo04B4QP2`kNP0_/Bh07IPE@3bonD0moo_0?omk@3Uk<00fNVh0>3a
a@3ZnMP0n?od0?WonP3bm_D0moOg0>cTh@0j<BX0d<>m0?3Oi@3on_l0k^kT0;>mY@3/o]@0hoO60=c[
/P3<g9h0cN:Q0<kWY@30gIX0QI]80:foK@3?gih0bMRQ06AaAP002000jOGA0>Kac`3Xl]L0i_;J0?Ko
jP80o?oo01P0o_om0?kon`3mo_P0o?ge0?oonP3ooo/0ooom0?ono`3ooOl0nooo0?Woo`3nool0n?Kg
0?omo@3ooO/0oO;`0?ogl`3on_<0jNGJ0>OSfP3inoX0n?co0?_oo`3mo_l20?koo`80oooo00D0moOg
0?ooo@3blNl0oocm0>oVi`020;N^[`050?omo@3on_X0noGe0?_gmP3nn_T00P3oo_d02@3ooo/0inSR
0?oon`1nNGH0kn[W0<k5aP3fkNh0ooko0?knoP020?coo`80o?om00d0moch0?omn@3ol_<0l/k@0?oo
mP3ooOX0oo_j0?onn`3nood0oOcj0?ono@3fl_40_KVh0080o?Sg2`3oool000X0oooo00`0c>R[0=[f
^`36hZL0b^NW0<OTX@3:jIT0b^^D0<[[TP3:jYL0b^VM0<[XXP38jZ020<SZW@D0bNZI01<0b>^K0<SZ
W@3:iZT0h_;G0?_onP3hoOL04Q8B0?Oen03ooOh0ooom0?oon03joO80m_[[0?Ooi@3`nm00enJ]0<kR
X`3>jJ80`n:F0080b>^I0640b>^K0<WYW@3:j:00c>RM0<gUU`3;jY`0anVL0<[^Y03?l:T0fo:^0=WY
Z02IYfX0bMJP0=[^_@3Cik@0hNb`08N@F@002@00TI]W09ZYLP3=iZ80b^BK0;k?R01fOch0]:eg0>CM
Z@2i^Gd0RH1709FQG`39hi`0c>bS0=GPW02a]W@0dnZR0<WbX`32iiT0bnVO07J=B@3HkJP0dNFN0=?W
X03Gj:40fNZS0>7b[031eY<0dnZV0;cEU02_b8H0TJML0<[TVP38jZ00aNVQ0=_k^02E[fh0a=fL0<CM
V@2kfI<0g_ni0;gSUP39hIL0goF/0<WMU@3Rlj`0dn>L0<OGT022Td`0b]jF0=G[XP3@j9h0c^BK0=3T
W03Aii`0`n2@0<3QT02dehD0anRI0<oVX03BiJD0d]fQ0<S:V02e^X80`]R@0=OXY01;@P/0d<>>0=g]
[02fjid0UiEU0:VBL`3on_40ooKi0?ogo@1_G5D0OFYS05]8@P1]FUH0dl2l00<0oocf04@0RGad0;F[
X@3mn^L0loGM0=KO`03goml0m?oM0?Ooe02V[g00dn:M09:YI@3?jk40a=FY0?olkP1C>cT0ooGe0?og
kP3lonh0e>Vn0<?CU@2AWEl0am:J0>3X``3amm/0hNGD0?kom03amNH0o_oc0?7ei03Qk<`0goK00<SQ
X03HkZh0c^2R0=KTZ@3GiJX0e^BW0;G5Q`3=gj<0c>2S0=OZ/P3Ym/X0hNo<0>?bd@3Ik<`0gO?=0=S/
^@2W^X80U9aQ0=cOYP2MUfL0Ph1=0>Wh]`3>i:@0eNfa000:0027RF40f>>k0<cW^P0VHRH0KZa[0;o/
Z`2jgI/0a^:H0<cZX03>l:<0bNjN0;cST080a^fJ0140b^fK0<WZV`3<j9d0c^ZO0<o]Y`3?iZh0n?o/
0?_omP3jo?L0o_oj0?cmm`3noo<0o_oa0?cok`3loo40oook0?ono`020?omo`0H0?kol`3FgKh0f>>i
0=?N]03Ih/D0loOf0??ho03enO`0oogo04lh<02?MFP0DD0T07Q_CP2^]8h0];^I0<_B/`3no>L0ook`
0?oon`3oooP0o?o_0?[oj@3<fk@0e>>h0P3iomd03P3jom`0o?oQ0>knc`3:ji`0bnVQ0=;V/`3Lk<D0
n?o_0?Ojl@3oo_d0^KFd0??^j`3on_L0oogj103oool0A03hooH0m_oX0?Soh`3hom`0n?oQ0?Soj03^
nnX0n?of0>oofP3YnlL0cNFK0<o/Z@3Fk;d0fn_70?kol`3oooP0oo[f0?ojm033_;H0o__d0?oonP3o
o_P0oncR00XF2P2dcLL0l?oo05V9R`2Odll0bMgD09J=QP2naK<0locY0?onk`3homd0c=^b0=GU`03]
o=/0m_o/0?;oj`3koo<0o?od08j?P@10?Bh0m^kS0?oln03on_D0]kbV0<_H^P38g:/0b=fU0=GWZ@3>
gYl0a=VH09>/JP2>ZfT0W;Q[0<KQTP3GkZP0bn6Q06]mC@002000n_o^0?col`3noo@0n_k`0?ool`3h
oOH0nOkh0P3nooX0103nooT0oOkh0?ooo@3oood20?ono`0@0?omo`3lool0jNg/0?clnP3oood0oogm
0>SPgP3Tf]P0k^CR0>cUg`3IeL`0i^7K0?koo`3kool0o?oo0?koo`<0oooo0P3oood01`3`knd0ooom
0>oYj@3ooOd0^kFe0>WSh`3;aLD00`3oo_d0303oood0no[h0?WhmP3nooX0oooj0>WXi01VHEh0ookk
0=37b03ooOd0oogn0?Win@80o?oo0140n_on0?_oo@3hoOT0ookj0?oinP3og>00oooh0?onnP3oo?X0
ookm0?koo`3oood0lNg/0?oln`3Cclh0ookm0?omo00;0?ooo`002P3oool0303doo<0M8Eb0<OF_`3=
gkT0dnFe0<oVX03<jIT0b^^D0<G]U@33kIT0`^bP0<K[WP@0bNVN0P39jId20<WZV@0B0<W[U`3<ij80
j?O@0?[om03go?P0000;0?Sgo`3lnol0mo[o0?Wol@3eon<0g_730<cRY03AhjD0g_6_0=GZY`3?jj40
b^VM0`39jId0NP39jIh0b^RP0<cXV`3;ii00b>V>0<W]UP37k9l0b>NQ0=GX/03<fZL0V:9m0=?M^`3g
onX0mOoS0<?HU`2U]g/000/009RYLP3Kl;D0e_R^0<?XVP3?lZ00cNNM0=WUY@3>f9/0fMnQ0:FSJ034
f9<0c>ZR0<?WW@3Hhil0UIaI0=K]Y@38kj00a>JI0=?_Y@1:Gah0WkAa055U7P1GJb@0BEdE09ndJ@38
gY<0cNNM0=?_Y@3:jZ40a^6J09NTG`3AiIh0bNBO0=3^Z02D[f`0d>JU0=;WYP36gIT0gORa0<cbY@3@
mJP0dN^Q0=cdZP31eHd0b=bD0<CESP3QlZ/0cn>K0=3TW03?iI`0a=bB0<cTVP3>giP0e^NP0=cbY`3C
jil0dnjQ0=_cZ@3:fiL0fNFW0<oGW02o_hT0`lR>0>?d[P3?gih0W9=L09N:E@3:fIH0^^fP092>GP2S
SVl0ookb0?ginP3onoh0oo[c0?ojm03ol^`0ooG_0?ojmP3Xglh0ook]0?oij03onNX0oog^09ZEPP3o
on`0oooZ0?koiP3lon<0fnVh0=7QVP2;XU00c^VJ0=7WZ@3Qj[d0/j6C05Dm>@3oknl0oo[d0?Knk`3A
jlH0a]BO0>G[_`3oon@0oooj0P3oo_l0J03al^`0jNo=0>O^^`3:eI<0cmnD0=CZ[03<i:X0d>JX0<gQ
W03MkZP0cn2L0<cLV`3Iik80nOoL0?Soh`3gonT0j_OS0?Gom03_onh0m?o_0>Olf`3@i[D0iO[20=3K
X`3Ih:d0EeD^0?ooiP3inoP0nOom0?Soo@0;2`T0C4930?Skl03]ond0@HME04NEF`2]kjl0]NbX0<WU
V03ClZ@0doBS0<CWU@3?lZ00bNbL0<GWVP37iZ00anBQ0<SRY@3>j:L0d^jT0<7IV`3Gil00l_oQ0?Wo
k03Qjm00f>?30=3O]03Ah[D0c=na0<kL^03kn_H0ooko0?klo`3no_l0o?ok0?_ol@3ionX0looW0?7o
l03co_l0lO_o0?coo`3on_h0oo[j0;jYYP3ol^P0ooga0?oom02:RX80UY:?0?kcn`3oo?l0o?oc0?Oo
j`3bon80k?kH0=7W]P3Gk[P0l?o?0>[ob@2V^XD0a]RV0=;W[038jY@0bNRH0<[UX03=iJT0f>Vo0?_o
iP3noo<0PH9j0?Sdm@3lmod0oogo103oool0B03NllP0c>>[0<cVY`3>jJ@0cNFW0<cU[P36g;D0m?oR
0<cSZ`37hYd0b>>F0<gT[P3hon`0nooc0?GdlP3onol0ooco0<:h^@3oo?d0ooko0?gkoP3oo?d0oo7V
05eF@`021P00O8Qj0?Ooo`3Yo_l0U<C4086ZYP1[I5h0oo[]0?ooiP3bnn00eN;60<WH^@3honH0bmfg
0=KX`P3Kjl@0f>S10=CO_@3>f;H0Q8UY05IG=`1TJ4D0j?S90<ONZ03QnkX0bnJQ0<OKUP3Ci:00c^>P
0>7h]03FlJh0b>b/0;cSXP3?ljT0bnfS05U_?P014P00n_ko0?[ho`3onol0ooOh0?ool`3oonX0o?oZ
0?cok`3moo<0oook0?knoP@0ooko00D0oogo0?oon`3mo?L0oo[f0?ghm@020?omnP050?omn`3mn?D0
oo_h0?oon`3hnO@00P3nool07`3loOl0oOko0?knoP3no_h0nOSf0?ooo@3in?H0bLG20:jZY`3oo_d0
bLG4089nO@3oo_d0oOcj0?ono03lnoT0m_Kd0?_mnP3lo_/0n_ci0?oon`3oooX0Kf]X0>cWi01:AD80
oo[j0?olo03ooOh0oooo0?koo`3jo_d00`3iool03P3oo?/0oo3b0?KCf@3nooX0ookk0?olo@3oo_l0
o?oo0?ooo@3oo_d0mo?b0?ono@16@T40o_[i2`3oool000X0oooo00`0j?cj08NGU03UmN/0n?o]0?So
h`3@i:D0cNNM0<[ZU@35kID0`^jI0<;]WP38jYh30<WYX00I0<WXXP39jJ00bNVN0<WZV`39jYT0bN^G
0<cWX03Wm/l0n_od0?Oln00000/0o_go0?_no`3kool0looV0=kda@3:i:L0d^jS0<SNUP3AiJ00e^bT
0<gWWP3>jZ00b^RN0<WYW@020<WYWP0`0<[XX03:jI/0bnVA0<OXS@3:kYH0b>fP0<WXY03GikH0eN2f
0<K=[P3gonH0mOo[0?Goi03TnKP0G6hb000<003?h:T0bMjS0<OYW`2lhi80a>^H0<WZV`3JkjX0f>RW
0=WSY02EUUX0dnRS0=3`Y`34jYl0UjAO0;BkN03Djj<0`NRI0<GWVP3BkZ@0d>FT0<kSX03:gYT0cN6I
0<kRVP2oeHX0e^jR0<kZW@36iIT0anVM0;7=P`2AW5X0f^VV0P3o00001@2meY@0[lB30>;g]039h9`0
c^VR0080`nRK02L0`M^A0=;ZX02]`gX0go>[0=_/Y@2fah00gO6Y0=7WWP3Cjj40gON]0::jL01eQSl0
JGXc07J<@@2BZ5d0b>2F0=CZX@39fYH0f^VX0>kh^`2DVEl0[;Ah0=GVXP3AgId0IehW0:RMI@3Fij<0
`NnT0:RTM@2ST780n_oe0?coo`3ln_d0oogd0?odkP3oo?H0oo_e0?ohlP3iln<00P3oonl0P@3oo_40
ooW/05mIB@1@BcP0EU@o0?ooi`3lon80cmR[0=?TWP2^ag@0b^FF0<[LX03Efjl0ckb^08mfLP3onoP0
ooof0?Kol@36h[`0SY]]0=gQ_P3oon`0ooko0?omo`3oo_l0n?Ob0<[?Y`3BfYh0O8Li0=SWTP3BijH0
c^J/0<WNX`3<h:40cn6S0=c/[P2mc9<0eN>`0?Sof`3ion40n?oT0?Sok@3eoo40k_oX0?CoiP3ZomT0
_MFI0<[PX03OkJl0e=fV0;6bR02m_J40o_ko0?Woo`3an?h01@0702lO:@3ooo/0m?oh0:OZ_`2Mj[H0
U]ZQ0;cb]038i9L0bNRJ0=SgY`2oh8l0d?6P0<c/X036iY/0cnj[0=;^/@3<iJh0cnV/0=C`Y@34gI/0
e^Vk0>[jd`3doml0g^o50=KW^P3AiZd0dNV_0<cUZ`3Ai;H0nOW_0?oon`3oo_l0o_oo0?_omP3ion`0
n?oV0?GoiP3eond0m?om0?Goo`3XkNH0oooh0>gPe`3YfL`0oo[Z0?okk@3lmN/0VIB>07YaLP3on_l0
oocm0?Goj03Wm=P0e>Jn0=7W^@3=jJl0i_o50<WVYP3MmkP0aMnR0<kVZP38hIl0anVB0<SXT`3<j9/0
cNRQ0<kR[@3Ei;T0o?o]08>7N@3Zj>/0mNoi0?omo`040?ooo`0C0=gbb@3>iK40c^J/0<gUY`3<hj/0
cN>b0<oS`03eonP0cnFf0<cTZ03?j:L0l_oJ0?_ol`3gn_40o_Wo0?olo`3om_l0b[o30?olo@020?om
o`0d0?ken03on^l0JU=100/00026SG/0ooko0?Woo`2Dblh0JZRU0966Q02<LVD0e=bc0>O^c@3Gh<<0
bmJf0?_oiP3ChKd0bm^d06EfC03Ah;L0^LFM06mkD`2U[H@0alnP0=OO[P3Ml[L0e_2_0<GSV`2ofi40
b^2G08VMEP3GjjH0`MRD0<GPW@34ijd0`n^_0<O/Y`37ij@0HWY:000=003kool0oOgo0?omo`3oo_/0
oooa0>_`d03Vl<d0kO;K0?GijP3oood0oooo0?ono`80oogo0P3oo_l01P3oo_P0jNCN0?onn03oo_P0
PWYg0=;:a`80ookk00<0oOcj0?koo`3nool0103nool20?ooo`090?ooo@3hmoD0n?Oe0=GAcP3]jNH0
GEUH059>C@3oood0ookl00<0ooom0200o_om0?[ln@3fn?D0o_om0?Kel@3mo?L0O7Qe0?onn`2]Z:D0
mO7`0?ono@3oo_l0oooo0?[ln`3mooh0nOoo0?Soo`3iool0ooom0?ohn`3ohNL0o?oj0?ono@3oo?d0
oooo0?coo`3oo_l0iN7P0?ono@3ln?L0ookm09>?SP/0oooo000:0?ooo`0X0>Ooo`2<Z;@0/lcC0>Cg
l@3Tmn<0cn>b0<oUY`3=iih0bNZI0<S[V@36jih0b^RR0<cVY@3:ijD0bNRT0<SYY038jJ80b>ZP0<WY
W@3:jId0c>RK0<oUY`3Rk=40o_oj0?[lm`000@00o?oj0?Wok`3[n]T0b>6X0<OVXP3:kil0b>bD0=;Z
W02:WUH0`]J>0<SOV@3Aj:80cNJR0<cWXP80b^RP02l0bNVP0<WYWP38iiT0bNZI0<S[V`3:jj@0go^n
0?_og`3non@0emg30>ojfP3Il<H0b^:`0=GXYP2:VU`000X00=;LZP3Ij;40bNNQ0<SZW@31ii80`nJD
0<kZW`3CjZ80f^VX09>GFP3<hid0a^RN0<G[X012C`X0mObi0=CZXP3=lZ@0`>2D0=;/X`3AiZD0cN:O
0=[^Z@3AiId0cn>K0=;YV`3;hiD0dNfP0<7QU@38jYd0Q:1F0>3TY`040?l0000402Lg003=gYX0b]jI
0=G/YP80b^bP0:X0SZQN0;K>Q03>i9/0a]bC092QFP2daGh0c^BK0=3VW@38h9H0S:IL0:S2N03@jZ00
b^BJ0<SRV03Ajj40Y;]c08fTG03>hih0c^:M0<7DTP39fIX0e^^X0<kSWP3HeY/0H5LN0=gMW`3=iih0
anNN0:nMM@1MCS4094Th0:bn`03iool0mogi0?coo@3loo/0n_oj0?Glm03oo?T0ookk0?oln@3ooO/0
oogj0?ommP3on_40o_KY059:=@2j/Y/0fm^g0=CU[P3:h:00c^:U0?7ibP3ooml0_Z^M06aHC`3oonl0
n_oV0>Sle`3:ikT0Tiek0?ook03ooo<0nOKa0?oonP2NW900^kZU0<_>W`3NhjT0i^fW0=CPU03Ai:@0
d^Ja0<SLZ`3hon<0m?oO0?Woh`3ioml0c]bY0<3?UP2N[f/0i_Vg0?Ooc`3;hjT0d^Z`0<OQX037hiT0
d^jI0<;LQ@3KkYl0b]VD01dV002OZ7/0mOoS0>cog`3gonX0JFAA00l00021LV/0oood0:;=/P3:oMh0
01`107VLM03Dl:H0bNFK0<gYW036iIL0dnnR0<_WW@35hid0ioo40?3odP3@j;P0b>6Z0<WTU`39hi`0
l_o>0=;[/P33g:80d>^X0<_YX@3<jid0b^^L0<OWW03?ij/0no[U0?ook`3noo00noo/0?Woh@3Bh[<0
cnB[0<kXY`3<jJL0bNJ/0<kW/03]m/T0o_oI0=KG[@2d/HP0g]Rd0>SO`03oo^P0YIf:05mFA`3ooO@0
noSY0=GV^P3?h[D0d^Va0<kZ[@35i:00a>JL0<SXW@2jfXh0b>NK0<CPU@3=jI`0bnbE0<g^U`38jI80
anNB0<kYXP3;hjD0l_oM075jI`3ViN/0oo_o0?[fo`@0oooo00l0nooh0?[ol03ionl0mOo[0?Wok`3i
ooH0l__h0?_oo`3foOD0nOod0?_ok`3goO40oooo0?gko`3lm?l00P3onol0=`3oo?d0c/G60?ono`3j
n?d0ooko0?onm@1kAT80LD0k01PA003onod0oo[o0=_oo`1AYih0`/Jg05A39@3Hhil0h>BY0=SGZ@3/
kLD0jn[;0>g/f01fMfD0mo[U0?oojP3eoMH0/;V<0=KQY`3Ghj<0c]fH0<[TVP33i9D0a^VG0<KWUP2C
ZEh0Qi]C0=[^Z@3DjjD0`=VE0<ORZ`3=j;D0ho[@0>?id`1ZOF4000`00?Cok03Zm^80jo?L0>O_e`3]
lmT0e=ne0=OR]`3]lmL0n_k]0?knoP3jnOl00`3ooOl07@3oo_l0ookk0<Fl]@37_K@0mNcS0?ommP3:
`[l0ookj0?ooo@3no_h0nogl0?koo`3ho?l0n__m0?koo`3gnOP0kNg]0>k]j`3em?80nOSf0?;^j`1l
N7D0l^k[0;Fa[P3noO/0moKd0?ooo@3no_`0nO_h0080o_om00/0o?om0?7flP3lood0o?om0?Cck`3o
ooX0l^k[0:n[Z03oo_/0ooom0?ckn@030?ooo`0=0?koo`3iool0n?oo0?Woo`3oood0ooSk0?oTj`3l
oo/0ooom0?olo@3oool0o?oo0?OemP030?ono@030?Wem03oo_d0oooo00X0oooo000:0?ooo`1I0<C_
mP0G?DH0h?oo05IcK`2AZI/0enk40>3g`@35gY`0b>>F0<[VV@3DkjP0jOo30=3Z[@38iJD0a^FQ0<[[
YP38jJ80anVO0<[ZX@39iil0bNBM0=3R[P3foNd0o_om0?konP0l@2l0j?7F0>;aaP3Zo/T0_]bF0=;d
Y`39ki`0c_:K0<oWV@2AYEd0/LEn0=K[Z03<hJ00dNNW0<kWYP3Ak:L0cN^S0<GUVP39jJ00b^RP0<_[
XP3<kZ@0a^JS0>3i_`3kon40m_gN09bSQ03Ji/00c^N^0<oYZP3=gI`0LGa20089003GfZ/0e]j[0=CY
YP3BkZ@0d?>O0;oQS@3CkZ40a]jD0=;NWP1PHBD0cN:M0;WKT@3Ho[<0CU/F0<gDT@3<hYX0`^NI0;oN
TP3<iYd0d>JU0=7VX`3Hk:L0b]jF0<OKT`3Fk:40a]jB0<o[X034hiL0bnfQ0<_UWP3Kgj@0103o0000
2P2faH80Q9=@0=KWX@3?iId0a>BI09:dJ03GljP0dN^Q0=CZX@36g9<20<oSV`0L0<gSVP3Bj9l0f_:X
0=OaY`38i9T0bnZN0=KeZ@34h9H0e_:X0<_UWP3>j:40S:=M04eT7P2U_7H0cnRT0<g[Y@3;i:00gmJM
05mI7`3QjZT0a^BJ0<cSW@2_Ug40Ge4f02aOC03MmOL0Q8bG0?coo`80o_oo00@0o?om0?3ek`3jmoh0
o?Wo0`3ooOl0O`3oo?X0oogf0?okl@1QET@0^:fG0?ooh`3Eh[L0d^Bd0>Kfa`3ooml0oooT095oL`2d
XYP0oooZ0?koi03Lkl80lOoJ0=?L`@3oo_40oooa0?ookP3oon`0h>340<_<ZP3Qi;L0[[6209FIIP3A
fJX0i?7E0>gmh`3gonP0mooJ0<oRZ`3FjZ/0a=VH0=g_/@3:fJ00RiUT0=3RZ03@iZD0dnbX0=3YY@38
hY/0c>JL0=GaW03<iI40Y;U/08nOGP37d:40gNRn0<_Q^P37h;T0d>C10?omjP3:]:T04@000<c3^P3]
ooD0j?oc04eOC`0T=1T0d^fZ0<kWX`3EkjH0c^ZP0<GOUP3:i9d0dnjY0=cd^P3eomH0m?oM0<oX/@3=
j9T0c>RN0<cVY@3:ijL0b^NU0<_ZWP39jYT0cNnK0<c]W036iY/0c>BZ0?[hj@3ooo<0oooa0?WojP3i
on40f>Rg0<gRY`39iI/0bnZN0<SXW03?jJ80dmbU0>of`01KGbd0Fed^0>OS_@3ajlT0oooV0<g2[P1a
IED0ooga0?ook@3GjKT0c>2_0=S`]P3Nnk/0anJP0<g_X`3;k9d0d?6R0<OVUP2Wa780dNjL0<SUT`3E
lYh0b^^D0<_[UP3GljT0eNj]0??og@22RgH0i>?Y0?olo`3mnOl01@3oool03@3ooo/0o_ok0?kon`3o
ood0o_oo0?kno`3ooOl0ooko0?koo`3ooo/0o_gk0?ono`3ooOl00`3onol0A@3oo_X0oo[f0??_k03m
no`0ooko0?konP1`>C`0e9bM07eWG03hk^l0oogo0>7oo`24cL@0/Ljb0=cS^@3BeX`0jNVO0:JQI`1P
FB/0Fe8c06YPE`10=SD0oogj0?oll@3oon<0Y:Ml0>;//03LijD0b]VD0<KPUP30hI80_N2@0<_/W@1k
TDH0]LV10<cPV`3BjJ<0dNZV0<_OY03GikH0nOo/0?Wom00b?S0000H00>oof@3Hjkd0`=>V0=KX`03@
hKl0c]^`0>3[`03nonP0o_oa0?knoP3oo_l0oogo0?olo`3mn_l0ookl0?oonP34^[40`;>Z0?ojl@3o
oOH0n_;_0?onnP3oood0oooo0?koo`020?coo`090?koo`3oool0Ng]k06ARH`0U9280Cdi<04]7A01T
H5d0EU9?0080ookj00L0o_gk0?ooo@3moO/0o_kl0?koo@3moo`0o_om00@0o?om00D0ookk0?omn@3o
o_/0dlo<0?_gm0020?ooo@@0oooo00`0nOoo0?Ooo`3iool0ooom0?ojo@3ohNL0o?oj0?ono@3oo?d0
n_[j0?coo`3jn?T20?ono@030?gin03ooO`0k^[Y00/0oooo000:0?ooo`1J072SWP1eXj40b_Kg04e`
K02^c/<0l?oZ0=C``03>ijd0enjX0<?KT@3FkJT0l_o>0=S_]`3;iJP0anJR0<[[Y039jj40a^RN0<SV
X03;iJ@0cNFW0=;Q^03LhMX0o_oo0?Wlm@0B6000`lfX0=CU[P3CjJP0anNK0<OZVP35jiP0c>nM0=_c
Y@35fI40YKUd0;oAT`3OlKD0cN6V0<gSY@38hj00aN>M0<_[X03?kjH0b^NU0<WZY@3;k:L0a^JS0=_d
^`3lon<0oOoU09jUP`3Ul/H0`=jH0<GQU`3<fY`0SiQO01TM003Mg;00loG60<SFV@3Ejj<0d?2M0<GU
TP3IlJD0eN^R0>G_/01>CQ80fnnZ0=Ge[02igI<0AE0<0?3e/`35fi<0c_>U0=GdZ03Bk:<0cnJR0<cQ
WP3AiIh0hOF^0>7e[@39gY<0g?:Y0<WSVP3Pn[<0a^BN0=G[ZP2Y[W@0e^2T0P3o0000/@3Hk:L0enJS
09VVH@3FiJ00e^ZS0;GCR@1jVTl0c^ZO0<SRV03>iY`0U:YQ0=3TW03Hk:@0d>JM0=O_Y@2keH/0]M66
0=Wh[037jI`0bNVM0<o]X`2lf8h0fO>/0<_UWP2mei00WKM`0<gXX@3;jJ40an^Q0<oZY@3Vfj<0GeXP
0=kZZ03@l:D0c>2K0:f?J`1VF3d0@7iY0>Ooo`2:U:00n_Gk0?cgo@3glo@0ookk0?oon03noOl0ooko
0?_jo`3dlOP0oogo0?ojn03ooOP0oogd07e`H02VVHH0oogS0<oH^@3:eK<0k?KD0?kmh@3oonX0DD<h
0;2RU`3oonP0o_oQ0=c^_03Rn/H0g>7=0?_ik@3gmNH0m?GF0?kog@3?dZL0inZo0<73V`2GVG@0/;6?
0=cPb@3Wkn@0mooc0?Ook@3/om40d>>[0<7FT@3Aiil0dNBR0<GEU`2BWfT0gNbc0<WNW@38hIl0bnBS
0<oXY`3@iZD0a]jD0<cRV@2EZ6H0YKAk0=WT_037djl0b>300<SQ`@3Dj<`0ooo_0>G>b00c5aH0PG9]
0?OomP3cooH0E5A<014B002cc980e^jb0;K?S@3Lljl0fo:/0=;YX`3FkJT0ho^o0?Goe03`omP0an2Y
0<cYV@3<j9d0b^RR0<WXY039jJ00a>FD0<?US`37jI<0a^NF0<[XXP3DjkD0oO[e0?oonP3nooL0nooa
0?_oiP3?g[D0cn6]0=Ob[@3ElJH0b>RE0=3XW03IgZH0^[n90:BZNP2EV6/0oooN0?ohf`3onNH0o_7Q
09J:O03oo_<0m_GQ0=KW^P3?hK40iOc40>gobP3<jjL0dO2Z0<_[W`3<jid0cNbN09VfIP2L]fP0eo:U
0<ORT`3Gm:80a>BA0<3LTP38h:80n?oS07b5L03ViN/0o?So0?olo`040?ooo`80oogo00@0ooko0?om
o`3ooOl0oogo0`3oo?l30?omo`180?ScnP3ckOL0mNkf0?oio@3ono/0oood0=OEb03Lg=80o_oi0?[l
n`3go?D0_92A06Lc=@2cT8`0oocm0?[ko`3Zool0/nSR07f_RP2kgJX0cm680?OdY@1@B0T0PWM9089d
F@1GAdP0NFUc0?ogo`3oo?d0oooV0;FeS`3;d9P0cMNJ0=g/Z`3CkJH0c>ZP0=;bY`37iI/0[/Ak09fa
JP3EjJ@0amjH0<SRV`39eiX0gNFd0?WmkP3`m?<04ALE0009003Olkh0eo2_0<;KX@3=ikL0fO7=0>;a
bP3_nM@0o_o/0?kol`3moOd0ooko0?glo`3ooOl0ooko0?ooo@3oooX0oocd08j0M`3ono80oogf0??^
jP3oooX0ooom0P3nool20?coo`0=0?[jo03]kNd0YZJV0>;Qg`2LViT0Q8>10<_7a03[in@0cLW60?Sc
k`3km_80oo_h0?ckn@020?ooo@040?Kfm03nood0o_om0?koo@<0o?om00L0ookk0?onnP3nnOH0i>3M
0?oon`3hn?H0ooom00@0oooo00h0nooo0?CmnP3iool0oock0?ofn03ogN<0nokg0?oln@3oo?d0ooko
0?_ooP3oood0k^[Y0?oln`<0ookm2`3oool000X0oooo0?l0^nbo07b]S`18NF<0gooo0=Soo@3RooP0
SkRF0;CI[@3AkK80dNZY0>Kh_P3ioml0lOoI0<gU/@37j:40b^bO0<_`X037k9l0c^Z_0>7ia`3comd0
n_o`0?[no`3nool0o_ok00X?003homl0fNRa0<oSY03@jjH0cN^S0<g_Y@32hYT0fO2X0<?FU03WnK/0
gnfh0=CR/@3iomP0n?oF0=K^/039i9l0bn^O0<?UV@39ijL0a>RR0<S/Y038ij40c^JZ0?7heP3`mML0
@TXS0=3OZ03OojP0b>^A0>3_]02NYW<00`H004e78`080`00LGQ40=GSY@2I]6L0`Mb=0<kVVP3Wnk<0
HfLZ09J@EP3Cgid0d^bU0=_k/P38dHh0Jfd/0=7UWP2nh9<0/]650=G_YP3GlJX0RZ5K051T7@13Ea00
HG8/092OFP1=G1T0f>RZ0=OVZ`38fZ00bmZQ09^TK@3Kj[40IG/k0<WPW03>hY/0fNVR0<oLUP3Eh9/0
SYeH0<;IT@36hYP0a^:G0=SbZ02?Yed0aMfC0=;XW`3KlJP0eNfS08FMD`30fY00c>RM0<WXW03?kj<0
cN^Q0<GLUP3Gk:L0gnn^0<OGUP34fI@0c^RQ0<gYW`3@lZD0`^NI0<o^Z03FfYl0FelR0:VfL@3<iY`0
c>2I0:nAK@19=al044Xk07bXZ`3^ool0]JFX09V9RP2n[jP0ooca0:RKRP3mooL0Oh9i0?kon03nooX0
j^cW0?Wfl@3oo_P0oogf0=g?aP2MS8807Q860>[Xg03knNd0SHUm05Q@A@1YH5L0ooWc0?oomP3Zk=H0
gnK40>Oca@3Mj;d0Wj6F0?oon03oonl0gNBh0=3GX`2:TUT0eMjY0?[og`3ko>`0oooj0?Sin`3kooP0
m_o]0?Goi`3Ahk/0b]f_0=S]]036g9h0S9mO08>CDP3dol00bmVN0<oO/03Ch/40hO3C0?Wok@3ion`0
nOoT0<kJ]03?fkD0nooS0?3igP3konX0jooS0?3oj`3aon`0ooo^0>SHb`2YTX`03@000?cnl@3gmnd0
aZRX05<k=`002P00BUhi020b003BiJd0fnfa0<SLU`3EjJ@0g?6`0<GKV`35gZ@0d^b]0<[YV`3:j9h0
bNVP0<SZX038jYh0aNRD0<KYU@37iYX0a^6N0>;f``3honL0oo_o0?olo`3mnol0o?co0?coo@3kooP0
ko[Y0<WI]03=h;80dNNY0=;OY`3GcjX0?cdG0<[?[`3_mMT0oooa0?omm03onOX0oo[j0?okn`3He=40
oooh0?_oi`3eon80n?oS0?Koh03=hk@0b^2_0=C[/`35gJ400@3?iJL20<WMWP0;06Af>P3:g9h0c^BS
0<gVY03IlkH0dnZf0?Soj01jPg00TY2E0?oko`3lm_l0103oool20?onnP030?onn`3ooOd0oogm00@0
ookk00<0oogm0?omo`3oo?l00P3ooOl0AP3oo_/0kN[Q08j?O@3Uj/X0o_oS0?_oi`3honT0nooc0?_o
k`3`kM`0jmO>0;N4R@0I3a0000<20??mo03bnoP0@HaU0;;kc@2RYGX0Bd/?0>KN[@3Ygk/0oocY05U5
CP1eH740ooCo0?oio`3oo>l0n?CK09nQNP1<CBD0jo750;o?WP3Om/00b^>Y0=;/[`34eYP0gnn`0<OL
U`3Ek:H0c^ZP0?7j^@3ooll0m_?Z0?_ho`000@H0IfeS0>?f_`3KlZh0lOoA0>OoeP3`ond0nOoa0?_o
l03ko_<0o?of0?ooo@3oool0n_[l0?omoP3oo_l0oook0?onn`22N6l0o>oW0?olmP3oo_H0oooj0?7b
k03oood20?koo`80oooo0P3moOd02P3oood0lo;`0?_gm03oo?T0oo_h0?onnP2c[ZX0n??_0?ojm03j
mO830?ono@040?ono03mo?X0ooom0?ooo@<0o_om00L0T8^8075YIP3oo_/0d<c90?ckm`3hn_L0o_om
00<0oooo0100ooko0>gal03en_H0o?ok0?[el@3om?<0oo?f0?Ogk`3oo_P0oo_j0?ghm@3moO/0ooom
0?ono@3[inH0NgMf0P3oo_d;0?ooo`002P3oool03P34k:d0VLBF08NeT@34n>/0fooo0<[okP1LTGD0
^NW30;gSZP34i:D0gO:i0?Woi03hon<0cN>b0P3o0000HP35jiP0`^NI0<[U[P3PmL`0moo/0?_onP3l
ool0o_oo0>W[j00c=bT0m__W0>[fdP3YnL`0bN6W0>?m_P3Mn[L0anFM0;oFT035eiT0fnfc0?Ooe03F
hkL0ho?60>Wkb`3@j:`0bNBQ0<k_X036j9/0b>VR0<CYV`37k9`0b>RL0<[SXP3Xkld0oooW0:jfT@2l
bi@0_=n10<[_T03Fjk00P8iK01LL000[9PH030P00=KMZP2c`HH0cNNM0<SSU03?jYd0a=R@051>4`3<
`HT0g>NU0=3UX032gIH0jO2]09:BDP2S]g00RJ]N0=GdZ03Ajj80QZ1I08ZQF`3BiYl0eNJP0<SGTP2Q
[Fd0AU8D0=SSZ`3Bg:L0d=bZ0;_7U@3:ej40enV_09RaL03?jZD0dNNO0<OGT02DXET0a=2808NDCP39
giL0eo6X0<g/X03AkJ80YKec0>7i[`3@iYd0fo6X0=WaY`2K/fT0d>ZP0=3/X@3>kJ40a^:G0=SbZ@2>
We/0V:MV0P3>f9/06P3Ij:D0e^ZU0<cSV`3Al:80_mnC0<o/Z@35f9P0L7Tj08fFD`3?h9T0eo6X0:^A
KP24KUL0J9Z>03Y]L03Tool0oogh0>cSfP3oon`0oooX0=WD]02NZ8H0mOkO0>_de`2_]j80lo[X0P3o
ooH0D@3jln/0l^GO0921O026Mg80Mg1Z05eFCP1LDdX0oocf0?kel03nn_L0oook0>;TeP3MhLP0em^h
04iB;`3Fell0o_og0>;Wd`3JhkP0h>Re0?ood`3kom<0o_oX0?oom03fn?D0oOgo0?Wno`3donl0n?oX
0>oob@3HlZ/0c^ZF0<_TT`2ndI40bMNR0?koh@3monD0nOoX0?Kol@3iooP0noom0?_on`3_n>D0o?oZ
09fWQ02EWgX0jO?>0=;P[`3<iI@0b^VI0<OWV`3KjJ`0e]:S0=S=[@1OFSd0JW5O0?Kfk01UA4/0O69U
02Xm:@1UMed0KWmE059R<@0nCA@0f^^W0=CXX@3?iId0amjH0<_VX`3=j:<0b^VM0<[XWP39j:80b>ZP
0<SZWP38jiT0b^^J0<_VX@3:gjH0i_G>0?_ok`020?olo`0X0?gko`3lo?l0o?oo0?coo`3fo?P0iO7K
0>Wff03Vm/L0i>bm085dE02ZYHD0i>S=0?kok03mnnl0no3Z0=_7b02QSY00LFIT0?oonP3nooX0oooc
0?kol`3konl0nOo]0>Sif@3VmmD0jO_C0>3aa`3Rl/D0d^2_0=g[^P2ha980_<ZE0=GZ/P3?iZh0d^Rg
0<WN/`3ion`0Mgi^0:BRY@80oo_o103oool01P3oooP0oooj0?onn`3oo_d0ookk0?oonP80ooof00<0
oooh0?oonP3oo_d00P3ooOd0?02]Z:D0`/:h0=[Kb@3MhLH0k?O<0>[gb@3[mll0hNo<0>Odf03Lj/H0
k_gN0?_hi@3ofM/0U8650:6QW`2k`[/0oook01mMA021aZX0hO;O0?_og`3Dcjl0h]c40?cbiP3=_/40
UXN>0?_^m`3onol0o?S]0?;ag`3QhLL0oooV09fLP03QjlP0a]J_0<OM[P3@ik<0_m6G0=[Y[P2J[f`0
^=:;0=7_Y@3Wlk40mO[40?ool@3oo_l0000206]aI`3>f[80b]ZY0?Soh@3hon`0n?oh0?_on`3kooX0
o?ki0?kon`3oood0oOgk0?ooo@80oook00T0hN3L0;fi]P3omNl0oocf0?C[iP3oo_P0o_gh0?oonP3n
oo/00P3oood30?ono`0<0?Ofm03oood0oogj0?[fl`3ooOX0ookj0?Sck`30^kL0oOK`0?onn03oo_/0
o_Sh0P3ooOd00`3nn_T0ookm0?ono@040?ooo@090:VQW`0e;BX0in?P0>cXi@3ooo/0l_Ca0?koo@3n
ool0oooo0080ooko00h0o_om0?kon`3nooX0ookh0?oelP3ecLh0ooof0?ommP3jjnP0`;Re0<K5`@3?
c/`0dLg<0;Nc/P80l>c[00<0noOf0?ooo`3oool02@3oool000X0oooo00d0b=f00<[XXP35j[@0Xm[3
0<Kom`0`MfT0EIf707NjV@24^h@0Z=RL0=7_^@3QlML0n?oX00@0o`0004T0bnjN0=3X^03Rl]L0mooi
0?Wno`3dn?L0o?km07YkO`1gMh<0moGo0?[no`3kooX0hO3?0>Cha`3IlKD0cnZS0;gCTP2>WfP0R9UU
09ZUO@3;eK80d]jh0=;Q]P3?ijd0c>NT0<OXU`37jYH0b>^G0<K]T034k8/0b>ZC0<oVWP3Zl<`0VIb1
0>K]c03Lj[L0bNb@0<gdU`2lgZ40_=BP00/J000R8`@010<00>;[_01iRe40eO>Y0<?SU`3GmZX0bn6I
05583`1hIc40TYMG0=7RWP3=ij00f=ZI0>KUY@3DiIl0`nFH0<KVVP3Hm:T0_MV?0<oYX033ei00enRR
0>Oc/@2OYf`0JVlg0=CHYP2KWW409bT201HM002ndIX0eNfc0080o`0008D0c^JL0:JgL02BWUH0KGL`
0:>^J@3:fiD0g?:Z0=3_X`2nfXl0_]J<0;oGS@3>i9/0f>jU06j6?03@jZ00e>jT0<GTV03?jj00dnBM
0;G2O@2g^gh0dM6E07]f?`1ZIBd0/;5e0:ZcL03Jij40bn2C0=G[X03?jZL0_NfS0;c<R`1nOCd0g]nM
0;oXVP2NSfP0L5=10=G_k00gM7D0H:>L0?3ok03`onH0bNNe0<c[/P3Fm[<0dn>H0=3QV`33di80gNjj
0>Gdb`2;Tg/0o_oa0?oomP3mlo@0ooCi0?oio`3onoP0n^WR0?ohl@3omO40oogk0?CenP3hnol0o_oo
0?oon03oo_40ooo/0?onn@3looP0o?oc0>Wcd@2nbJ40cmZ`0=;L]`3lon`0n_ob0?conP3`mO40noof
0<kM_038fJ`0dN^R0<;NRP3Hm9d0aN2?08RIHP3:eZh0oooc0?kon03looH0n_on0?[mo`3no_l0o_oo
0?col@3Pi/X0e=jY0=OSY@3Giih0SYaA0=3PU`3GkjD0dNfS0=W]/02g`8/0g>6i0<SD/0002@0000L0
0=>i^P1jI6L0l?om0<CAb013D3@0amJ_0;[8U@2?WU/0]LIo0=K]W`3GkZ00e>nR0<[VV`3:j9h0bNVP
0<SYXP36jZ00a^^N0<GWVP37iih0cnB/0<kM/P3Tj=L0loK[0080o_oi01@0oooj0?oon`3no_h0oOgo
0?koo`3mooL0n_k]0>ofe03[k<@0eL>K0?7X_`3Zl<`0iNo=0?ooj`2YXY00`;2Q0>WIb@3]iM80o?oZ
0?col@80ooco01@0no_o0?coo`3ho_`0noom0?_on03loo@0o?oc0>O/f03Wjm80hNO10=oW`03Hil00
mooQ0>ooh03Xn=/0koSU07EhK@1jM7@0oo_o0?oho@@0oooo1P3lool0?P3looX0o?oh0?con`3lool0
o_oo0?oln@3oo_P0O7U`0?3dg@3ZlM00f^Fj0=[//03Fj:X0b]fU0=GY]P3IkK`0a^2O0<cT/03ion@0
ooo_07QEF`2jVj00LgI[08ZJS@2M];X0<E9Q0:GEj`3aool0l_Gl0?koo`3ZjND0oooc0;2]W03oo^`0
oog^0?oomP3looP0oook0?olnP3nl>d0fm_?0?Gnj`3Yn]X0mooS0=o]_03?gZL0dnRU0<WSVP3<jid0
c^>R0<[KY03`nmT0d=[20002001jO7L0no[e0?oonP3ooOl0ooWo0?oko`3noOl0o?ko0P3nool03P3n
ooX0o_oi0?oon03hn?00moO_0?onn@3ooOX0m^gX0;jc[`3ooOX0oOSd0?Gdk`3oooX0o_ok0P3ooo/0
0`3oo_d0oogm0?ono@020?ooo@040?onn`3ooOX0oogj0?onnP@0ookh00L0^[:`0>kUiP3oo?d0oo[k
0?ojnP3jm?@0oogm00@0ookm00D0oo[i08=iM`2NVIH0ookk0?gnn@020?coo@80o_oo0P3oo_l0303n
oOP0n?S`0?oon03Ebl80b[6/0?;9a`2QWI40hMO=0?ofl03oo?L0ookg0?gimP80ookm00<0_[Zi08N3
PP22OWd02`3oool000X0oooo00d0d^N20=;^X@2kgj80[N;807VfY01KWhP0:6i<07JgS031mKD0]NBN
0<k]/@3HjLD0n?oS00@0o`0004P0b^ZN0=7W^@3QlML0mooh0?[oo`3go?H0o_om0:FUY`20OXT0oogo
0?coo`3hooD0m?oO0=KX]P3;hJ<0c>>M0;_>SP38fZ00f^^e0>[jc@3iomd0d^>f0<oS/P3@jZd0bnRU
0<KWV03:jiX0b^bH0<W]T`36jY00bNRH0=7WYP3WklX0VIf20?goh`3Ch;80eoBT0;oPS`3>jk40eN^j
0008000S8`L01@H00<gFY`2eahd0`=bB0=GaYP36hI@0e>RQ0>CSZP2ZXFP0E5TG049=201BHQ/0YJ5Q
09jFE`3Oj:D0b=jF0<oVWP39h9P0dnnR0<SRV03Kl:/0dN6P0<[HVP2BWF<0Uj1Y0=cU/00I7`00U9Y^
05mX>@1>GbP40?l0001K0=g^Y`1@GAD0gnZU0<[GT@3NkjT0bMnG0<cXWP3>j9l0Rj9J0=CZXP3Aiil0
cnFL08FMD`3CkZ40aN6D0<o`X@3<iiX0c=FB07f4@@3Kh:00gmnS0=_IX03Ed9P0ShmA05YL6`2EW5P0
ZkQ`0=[WX@3AiJP0ao:[0<oOWP1gMSH0e]NE0;kTU`2NRVD0IT<`0?Coo`1n/K80AH9k09k6X`31j/00
_nNb0<C^[`30jZ80bN2>0<WPT03RnZ`0bn6P0<gPZ@33cZh0o?o_0?3aj@3oo?l0nNkf0?odn`3oo?X0
oocf0?ommP3nnO<0ookj0?coo`3fnol0mo_l0?GdlP2VWiT0ooca0?oon03koo40nOoZ0<SD[02[^8X0
fnbh0<CDX`3aomT0ho7@0>3Zd@3Xl=T0i^c@0=KO]03Bh:/0fo6Y0<ONT02Y`W40Df/O0=?T[@3Njkl0
m?gR0>Wag03loo40oOoi0?gooP020?koo`0O0?kok@38cjd0eNFW0=OYW`3JlIT0/<=a0=;MX@3>hZD0
a=VP0>Khb03@f:l0i>_<0?7kh01]OfT02A@40?o]k03ok>h0WJJS0>CWh01kOVT0Vj:30=KR^P16FQl0
EFXY05EV7`1gRCl0c>>E0=3XW03@iJ00c>NP0<[XWP020<cXWP0b0=Sg/`3Jm[T0i_G<0>[`e03gnN`0
ooof0?cnl`3moo@0ooof0?oon03mo_T0o_kl0?gnn@3ooo@0ooo_0<O;ZP2SY7X0fmRS0=kM[@3Be[<0
oOoQ0:VXS01bKE00oooQ0=_G]03CeK00k_kG0?Wok03onol0oOWo0?gmo`3no_l0nOco0?coo`3nool0
mOOb0?gnn@3jno<0oooc0?ooiP2j_:@0noo]0>gih@3gond0mOoZ0<cI_`1QJE@0/K2[0?ono`3oo_d2
0?_omP80o?of00<0nood0?_onP3koo/00`3kool20?con`80o?oo03l0o_ko0?ono@3oooH0oooa0=?H
^03<ej`0dn6/0=;UY@3Dj:T0d>B_0>god`3@iK`0a^6/0<;I[`3ionP0n__[0;FCU02:J6T0`<:e05IV
F@3eool0i?[o07jbb03RoOl0mooo0?_oo`010000ooga0:BST@3ko^T0ooo_0>[bi`3loo/0oo[n0?ok
o`3om?@0b/W40??fj`3ionl0nOoZ0<[F[P3IjKP0cnRW0=Sc[030h9@0d^fZ0<7IW@3Kkk`0[;bE0008
001lOWT0o__o0?omo`3onol0oo[o0?ofo`3knOl0n_go0?cmo`3ko?l0oooo0?ooo@3oooP00P3oooH0
1P3oooP0ookj0?oim03kl>`0oocj0?gelP80oooj0`3ooo/0503oo_/0oogm0?cmn03ooo/0^[Ve0=_G
e03lmo@0ookj0?onn03oo?H0oo[d0>k]j03ooo/0oOSe0;fh]@3Wh]h0ookj0?cgm03oo_/0oogm0P3o
o_d20?oonP0L0?olnP21MgD0X9^G0?Ofl@3in_@0l?G_0?coo@3nool0oooo0?omo`3oo?l0k>WT0;Ba
ZP3RgML0b;Vb0>S?bP3olo40oooc0?ojl@3onoH0ooOb0?Wdl036`/40moKd0?ooo@28QhD0U9>A0;2_
[@/0oooo000:0?ooo`0>0<KZRP36k9l0c_Jg08ZgS02C`YP0[MjV066BD033kj@0b>ZF0<[VTP3EjYd0
bn:J0=7/Z@3>jJH20?l000190=;]YP3?jZL0eNVh0>Kdd`3gonl0noom0?3hk@3ooo/06ADB085lN03]
jml0dmnk0=CX]`36gid0iobi0;g>RP2FX640JgLg0<oOWP3IkZ/0bnVS0=Of/02ohi/0b^jV0;gNU`37
iIl0dnbX0<?MUP38i9X0cnRT0<kWYP3EjK@0hO?30?Goe`3komd0b=BV0<O@X@3Khk00eN:/0=gb^P3C
hk@000L005IF>P011000fnVh0=;VZ`2J/6P0e>RP0=3MU@3HjJ<0`MnQ0<WTW`3KjI`0e=^=0=WJS03V
fiT0jMjP0:FJI02f[gT0CdhH04aB4P31fh@0bN6C0<oUY`39gZD0f>fe0:g2Q`3CjJ/000l00=G/Z027
WUX0dNJU0:ZhN`040?l0000k0<cVW035giH0eo6Z0<[QV`3FjjP0eNZW0<7DTP3Rl[<0/l>40?[ob`35
eIH0fNbZ0:g7O@36hYD0dO6N0<KZT`3:iI@0YjEX08bAD@3BiZ40b]nJ0=3TW`3FiJ80i>VY0=WKW03D
eYL0Zk1`09fPI`1NGC40Ti5Q0>;SY`2@UE80VJIN0=S/Y`3@XHD0[GQZ0;6dZ`3Df]P0m?oo014l800b
Fc/0_nBh0:W>VP2ohZ00`^NT0<3UU`37jYH0bn^F0<SRV03Yn<d0YJnF0?_nm@3`koD0l^of0?_ko@3n
ool0mo_j0?goo03mooT00`3oooX0GP2UXIh0oOOg0?_em`3ooO/0ookc0=kM`@3>dj/0dNBT0>;h[@38
iXh0a^B<0=3]V`3:i9X0d>NQ0=GUY`2`]7T0Si1D09FJFP2<UE@0VjQS0;?4OP3?hi`0`mZB0=K`Y`30
fY<0g_Bd0>Kfa@3Rk<L0iNo=0>_efP3Vl=L0m_oU0>?cc`3?j;40b>FU0<oaY03SokL0`<JH0>7V_@3a
mM80oOcW0>GSeP3oo?T0noGe0?ojoP3kmOT01P0204e5@`2[XY40Ie=80>gId015?C00<3`X096`SP30
gkH0a]JU0=WRZ`2OZVP0UI]K0:bWK`3OiJD0Vj9N0<37P`3QijT0dn>d0>OgdP3am>40nO?W0?oom03o
ooP0oogo0?ono`3fl_<0ookm0?oomP3ooo<0n??P0?K`eP3Ke;L0FE4]06ac@035jY`0bN6W0>gXe03V
f/h0IeQ30;:]Q`3GiZD0e>^U0<OTX@34iK00lOoV0?[no`3lool20?koo`1/0?kno`3oo_l0ooko0?_g
n03cko00oogo0>WPh@0g:BP0g];F0?omo`3clo/0n?oh0>gmh`3Di[`0NhiQ07n>K`3conT0dn?80<[X
/P3<jK<0looI0>ooeP3BjjX0f>fb0=S]]@3Vml/0nOoT0?WojP3hoo<0o?ok0?Oho@3alOT0oogo0?7_
nP3ooo/0oooc0=_S_036cj00a=6L0<kJZ03Rkl@0joOS0?Gom03gool0looo0>oin03joo/0oooh0?ol
k`3[fl`0^[2T0?3^hP1`OgX0jOol05b0OP1SSXL0i_oo0??no`0400@0ooSj0;^c/@3looP0mood0>S^
k03oool0oo[o0?Wcl`3ooo/0UIBB0?Wem03ooo/0n?Wa0>K`f03`omh0an:]0<_Z[P2lgid0/mB?0<[Z
X@2C/600bN>L000:001aMgD0oogo0?ono`3oo_P0oogj0?kcm`3oooH0moW/0?ono`3jmol0ooco0?kh
o`3ooO/0ookd0?ogjP3il^80l^SL08QoNP3Zh=h0oocj0?O_k03ooOX0l^gY0?olm`3mn_D0o?_f0P3o
ooX0<03goo00nood096BS03onoP0oogh0<Nn]`3oo_<0oooc0?oomP3iool0loko0?Slo@3blnh0oood
0?Cei`38a;T0ookh0?_em@3ooOl0mO?f0?oon03nooH0ooWe0?g]k@3TgM<0oooc0?Sij`3Fg=80^;fi
0?koo`3ooOl0no3d0?oko@3jl_00oo[h0?oknP3onOP0lMcK0?oim@3oo?P0n_Kc0<:n^`0g;S40^Jbc
0?[fm`3oool0o?cl0?Shn0d0oooo000:0?ooo`0/0<CXXP35k:T0`>VW07FSI@2fiZP0b_Rj06NCE02]
e9<0a^>Q0;oHUP3>hih0c>BJ0<cXW@39iI/0b^VM0<[YV`38iID0an>H0=3U[03Sl/T0m_oW0?con03k
ooX0oooo02/V:P21Ng/0oooh0=GP`02fbI`0amnQ0<SLW@3GjZX0UJ5S08nKG@3>gYd0dnRU0;oMU`37
iZ00b^jV0=co^039jZ<0b^RR0=3YY@3CkJ@20<_XU00Y0<WVUP3=i:00dnNX0=GTZ`3FiJX0Z[Qk0=OS
Y@39e900e^VW0<[]/`33hJl000l005][AP002@00cnZc0<o_[P39jil0NIU>0=;/X`3?j:@0anNV0=Ce
/03ElJ@0c>NH0=K]W`3=g9L0fnNW0<kCV`3FfJ@0hnJa05UO8`36g8X0g_>X0<oQX`3@hZP0fN^a09:T
J03Bi:H0cn:P0=3SX@2J[Fd00P3o0000>03:hj40o`000?l0003Bm:P0c>jR0<W[W`37j:40dO2Z0=?`
[@38hJ00g>Z_0:JaN@3dolL0o_oA0=oZ/03<fYd0a]VG0=[aZ`2ofHl0dO2P0<GPT`23Sdd0Sj=N0<;R
V@2igI<0bN^Q0=3^YP3BiZ40e>FQ0=WZYP38g9L0c]bN05iG:@1ZHS40AT0409VEE@2HWEX0fNBR0<J=
LP2bM6D0oooa0<g:``3kooX0A6E8000O0039jKP0d_6h0<[ZY`30hj<0d?:X0<SWV@3:hi80c>2I0=oW
_P1kOfH0oood0P3oo_l0<`3ooOX0oo_k0?ojnP3onOP0oo[d0?ohlP3onO@0cKRc0?oimP3ojNT0ooOj
0?odl`3ono40X9Uo0;biUP3BgJD0c]fL0<oUVP3LljD0^<b40>Oh]03EiJH0AeDG08BAC03Lk:40e^VJ
0=;YV@3BjY`0eO:R0<WVUP3Ko:/0]]N80=OhZ@2ogi@0^]VF0=;[]03?ikL0`MBd0<kPaP3eoo@0lOo`
0=O^e034gKl0cNW10>_oe`24NeX0ooSK0?okhP3ooO40e/_50?olo@030?omo`2F0040000;1`H0oogd
0=K<`P3Rg<h0d=6o0>K`e`003@00;dhT0>Ood`33fZH0h>Zf0=gQ[P1FDb00G54S07=bAP12B1P000T0
0<W>V03`lkh0fN6b0>C^b@3oonl0ooSc0?ojo`3ml?T0ooWo0?ojn`1GA3d0IeE706UFA@3kj/`0[9aj
07a_A@3oom00_n>K0<7HXP3nnNH0oocc06EEA@2`ZXX0cmZP0=7UYP39hJL0a^6d0?Cok03jn_l0o?go
0?_jo`3jn_`0ooko0?[fm@3oooX0l>_U04a8?`3oo_@0ookf0?ojnP3oo?d0ookl0?kon`3]mnh0n?of
0<GC^P1bPF00FFPm0=?P/P3;g:H0e>f/0<_QX`3Jjk@0f^Rc0<OUY@36i:P0]mBJ0<_V/`3FkKl0eNc2
0<cL`@3hoo40lO_c0?Woo`3lool0oo_o0?ojo`3onol0ooce0>g[gP2`[Yl0l_?Q0?Wjk03fmo80oooo
0?_lo`3en_d0nogj0?Sgl`3ooOH0oo_a0?okk`1[GE80kNCK06icK@3:eM40d_7/07JWX`3^ool0k_[j
014J5@3ol^l0d;^h0?oglP3kooX0oogm0?olo`3gnoX0oook0?oonP3oo_/0d<[:0?;]jP3oo_P0ooo^
0?goi`38f:/0en^f0=S`]P3NmKd0`]NL0<3DS@37fYX000D008V;R03oo?l0oo_o0?ojn03oo?X0n>_b
0?kenP3ooOl0ooSo0?oio`3fjOX0oo_o0?omm03mm><0oooZ08^4JP3TfL<0ooof0P3ooo/00`3kn_H0
oook0?oon`020?kon`0T0?con`3fnoD0o?ok0?colP3ooo@0]K:]0?onn`3llnh0oogd0;>[WP3ooNh0
oood0?Win@3lool0ooco0?ojo`3on?d0oOGc0>GKf@2_Xj<0ooOk0?ojo`3onol0ooco0?cio`3omoX0
oo;b0;:OV03olnP0ooka0=oOe@3JfmH0oooo0?3`lP3on_X0oocj0P3oo_/0303nlo40ooWh0=2k^P3o
n_H0o_?_0?onn`030000ooco0?ojo`3ooOl0ooko0?GalP80noOh00<0ooko0?ooo`3oool02@3oool0
00X0oooo01h0KiEl08bfQ035kjd0^nR=0<;]T@2mhIT0KhiC05=_?`1WOEL0HgQA061cAP1PMTL0H7M9
05miC01/QUH0K8MD06AlB01RNTX0I7=D06ehJ01eNgT0J6Yf07IkO`14@d/00@0700<01001000000L0
000:00003@02000B000f0:RfN`1]NC/0b]^G0<oTW`3Imjl05CD00<[^Y03Ho;80c_2V0<?QV@2keHh0
<4X9000?00003@0000`0000;0000200000H00005000D6@<03A4000<5000D5@002P<003d_300F0`00
BB`>03hQ002QS5d0F4LA05m@5`2m[7P0ID`S07AG;`2dUFH0]Ya[0;^^NP2TVVL0YIe^0<JjT031/X/0
ZHIX0=6UR02>ECX0PTT[0;2:F`2YPe@0_IMZ0;2:G@2ZQ5D0Yh5B0;^EIP2`RUd0cjQm103o0000W@3S
bY@0^jA^0;2KI02UTUX0e<2;0:nIJ03;/hD0lMF]0;JFK`3ibZ`0QE@f0:]hG@32Sg@0[G]P08EF>03_
a:40WWM@0?OBZ02UQEH0]9AS07]J9`2QQU40W91F0:VPI@2]XfP0[iiV0:27D@2aUV40]IYU0<RaN`2V
S5T0ZXAG0<ZTM@2aReX0_9MS0:n?G02dVVL0eWMU08hY7`3oim@0on7@06I7=@3EbK40flng03<X300k
<1@030D002D?002/U6P0[HiO0;nEI@2mSV@0aHef0=VMTP3EV9D0n;g10>J^/@3R/Zh0ejjX0=JaZ03=
ZId0f;BT0=bhZ03]b[L0m=6n0?oUeP3om^X0onOK0?ogjP3okmh0hm>j0>;D]`3PgK@0l_C50=cS[@3K
hjX0g>6W0=oOZ@2LW6H0emNQ0=WLX`3Wk;80eMZR0>K]]`3Hgj/0c]BT0>CZ_03oomX0oooL0=WN]P3R
j[T0dn:M0=[VY03Tk[80l?3<0?ooiP3ooO@0ooch0?okn`3on?P0ooSf0?okm03om^X0oo?Y0;BCS03j
h=l0ooSj0<^l_`20MgP0KVmZ08N:P@1fPG40A4Xn00H0001iOgD08c8M05ARB@2[/IL0dn>o0=7]a@13
MdT0DX5G0::_U@1bN5@0am6:0>oY[@3Vi;<0h>Nc07F2BP20O3l0W9=H02D[001TM500MG=d08>0Q`3M
k>T0n?oo0?konP3ooo@0BD@`0>;N``3Uh/<0fMnc0?;lbP3=gjD0bn6S0=ch_P3`omT0ooS_0<Be/P1N
CdP0c<Ba0?WofP3Ji[h0eN>o0>gjiP3fooD00`3ooOl0903oo_/0/k6U04i;>P3]k=00oooS0=SE/P3G
eJh0inC30?ool@3hmN@0oOk^0?oom03looX0k_?]0=gQd01WKE40KGLk0=SRV`3=eYD0fMjn0>CWbP3o
onX0m_CM0>_d_`3HhJX0cmRO09VQIP1kP4H0Y:Uc0=[H[`3ooml0ooWX0?ohkP3ono/0ooWo0?ofo`80
ooSo00D0oo3l0?ogo`3ol?@0aK>c0?[Yh@020?olk`1Q0?olm03onoP0ooWd0?ogl`3onO@0oo3[0?gX
h`1mJ6<0ooC]06UJD`3dnOD0hooo07nVY@3Mn?4000D00?olk`3ok^<0VWAa08IWI@3omo@0oooh0>_g
j`3oooP0o?Ca0?oln`3onod0oo[m0>OIf@31]:`0fLo30?ooj03oon<0o_kL0>WYc@3]k/h0jo2h0<?6
T@091000LV]S0?;VjP3fjnL0l>?K0?oakP3Vemh0mN?O0?ohl@2_WId0m>7U0?CQh`3MblT0X9:90?;Q
e`3Uelh0d/;30>OFgP3<]K/0k]GI0;NLX@2URXl0n=gR0?[Oi039[;40onCY0?_Pi@2_U9T0c[6f0<^D
V@3?TIH0hJ>`0:5SLP3PY:h0e9VO0;YoP@3GViX0ZVa]0=NEX`3h]LL0`W^I0=6;Y`2_JG<0eY2@0?Nc
Z025@CH0]g9[0?o6bP2aL7P0h::]0?JjaP2fOhD0cifP08MOG@189b80c;>^0>gRg03PfM<0n_Wd0?oo
n`020?kon`0A0;:a[@2?RXL0_[>a07]WIP2/UiH0ooC`0?cak@3oo_/0oook0?oin`3on?h0oo[n0?kc
m`3onol0ooGi0>cQi@3on_h02`3oool000X0oooo00/09Dhn04UdA`38mK@0`>b=0<_cT`2I^Fh01B40
000<00035`0000X0000E0003000<0018000C00004P0000d0000<00001`0000D000<92@0000`00007
00/:4P0;2140KVU`01/J601WM5X0DV@n01Pa001HL3@0:Sh109>QIP1?Fa/0gNjZ0=K[YP2kfI401BD0
0<7UV`2mhIL0bN^Q0<GSV`3DkZL0Ih50061mA`1NNDh0GgYA06=hF@1TM5T0LGeW071iI01cN640FEe6
02HY3P1TIDH0NgA:09j@J`0B0000Ke4_08i^B02kY780^JA]0:ZGG`2aVfX0HT@R07UG=01cDB40Ke0R
09Z9GP1QEBd0HEPa0;:XQ@36]IL0TW1E0<VMQ01W:QD0ZW1H07YG;@1`CR40UgE508ET<@1jFB@0FCP5
085P;@1VA1L0PUle103o0000o`2BM400K54L08mh@P24KCT0RgE3089Z?02jWg@0i<JP0:1nF`3oe[H0
U6M80<RIO@32TgT0/hAX0:]nH@3P^9D0XWaG0=NdS02]SV00IDDF095]>`29JcL0JU/R08Mm@P2CQdd0
RGQ006]B701hGBP0Of@_0::;E@1nIc40Ke4K08Y[=@1^CaT0UWM107eS<01SCa`0`FUC08LZ6@3M^Y`0
lmBg0:66J`3<_:D0dKnY05Y:<@1?@BL02`00040`3P1UCbH0LUL/0:1fC01`@aX0YViE0;b3L02;DdH0
Z7I]07];@@2dSGh0SfiK0:R9M02aTg/0d[NJ0>;7ZP33ZX`0b[6C0<feV@2QRFl0f/:Z0:ZDO02`Vh00
aKBF0<2cT`2ET6X0e=:Y09^NK`1mPDl0Z:Qd0=GBW@1?BAD0f=:N0=SFY@2l^hd0_kjB09fIL`2aZhT0
^K:E0:jTR@3gk=H0i=W30=kC_`3@bZP0VYYN0=?CT`3EdiX0YYYb0<VjV`2bWH`0/YZ>0;bTVP2nYY`0
/9Z=0;2FR@2XPWD0dZfT0=FcZP3?/jl0SGQe02/P6P0D3@D000<000`E00001`0000P000@000074P@0
3R0:0007001aM5l0h>gC0=Sad`2dj<80E8IS02/j9`001P00j?fb0<SCSP3OjZP0d]jL0=7MV`2h^7X0
hMnV00T;00001P002PP90000101YOg<0X;6W06idIP2@Th80:2@;06IRA`1hMeP0JgA904]H:P1RND<0
I7e406^1DP1kQV@0MFaU05A4A00a91h0KVMG07UnH01XLE80IW1G07EmLP2BUi40oooo0?KfmP3oo_T0
oOga06EWD@0M7@40oooM0?oofP3DejP0hNB_0<gAW`1[Kdh0WZ66079eI022Q7L0MWQ]08J8N`1]L5D0
=c/F07UnAP3?diH0hnJ_0<g;]P3CdK`0lnkK0=kHb03Rh:d0Xj9Z09fLH`2<RTd0H5`O07E_=@2FReh0
kMnl0?okk03Ha;/0on_Z0?CRh03on_X0ooKh0>;=e03RcMH0ooSo0?7Kg@2]V9D0lMk@0?GPc@2bX8`0
oo?Y0?_Yi@3on_H0oo?a0?ojn03onOP0ooOf09Z2P03Nal40flBn0?olnP3dool0DFma0=;XiP0@4Pl0
oo[_0?oejP3Z]Jl0Yfe[0?ofk`3ooO@0oooh0?Kck03oo_P0ooGd0?oko@3omOP0oo;c0:^LV@3Yf]<0
e<Rh0?oki`3oo^P0ooc/0?oojP3Hf:H0e]BQ00L2001oN6P0oogf0?oml@3onNX0mngS0?odmP3okN<0
oo3Q0?ojl`3on_@0mnKO0=G4_0000`2o/J@0ooC[0?okn0020?oho`0m0?ofo`3om_/0ongb0?oUjP3o
m_/0ooCj0?oSjP3ok_D0oo?j0?o^m@3ol?L0on7V0?o7c03BUZ00om_V0?o<e03e`l@0omC@0>ji/`3o
bLD0omCL0?o<f@3ocnL0olcQ0<5oP@3g]:h0omW;0;YhK03FUXd0omkO0<V<T@3_]kX0om?F0<N@T`3?
Vid0c::S0:N3P`3igM`0PGA^08EnN037a/40RX^50?;gl@3lood0>c`g00<0000a9bD08Ph=085/J`3d
h]h0l^OS0=WEdP2l^kL0kn_/0=S?e03@aLT0knCX0>cPi03Zg^80UX^?0?;Wj`0;0?ooo`002P3oool0
2`1NRgL0=V<h0<ch_@35kIL0eOVQ0<;NU030fIP0goK00;?9V`38g[00_mNS0080cNV_00<0bNF[0<WW
Z`37iJL00P3o0000A@3Jjl40joGL0?Wol`3gnoh0o?oo08F4RP0710/0n??i0?7`k038eKT0]LZO0<WU
Z03KlkD0cN>S09>SI02AX5l0c]nK0<KKUP3No;@0^MV@0=;f[037jj40c_2V0<_YX@3;iIh0a^:H0<_[
W`3;jj00bNVP0<SRX@3:h:80amVO0=GTZ`2P[W<0T9]Q0:RbM@3ChJH0b>2/0>;b``012P00WYe_09jL
J@3Gg9`0en2M0=gWZ03Li:/0m?C>0=KCZP2][G40N7]40=kZ_03=g;<0enO20?Cog`3`n]L0oooQ0;V^
SP2OR6T0ookL0<cFY03:eId0fnNU0=?PVP3?g9@0YkA_0;c8QP3HhjT0b]BO09:LJ0020?l0003o092@
DP3XkJd0fMnO0<_FU03Fh:40cmVL0>7X/P3YkK/0oooF0>oa`P3enLL0ZZil0>c^_`3/kL40i^Fi0>c]
`@3TjkP0g>F`0<kIX@3Rl[@0JG<f0>GQY03SiJH0f^^W0>;g/P3:gYT0c=^H0=OMW@3Sj:P0h>FU0>7Z
Z@3Fgi`0jo6[0=7DS`3KgI`0gn6P0<G>S`3?gIl0diei0;YoG@3Iej@0j^bj0?oof01hNV@0]kNO0=oR
``2>TVl0ZK2603=C8P2dc9X0O8iJ0>7V/03/j[L0m^g20>SO^03onM@0jnS50=KH/`3IfkH0h]bh0??Y
a@3`il00gmR/0=kGZ`3AcIh0aL>C0=7@Y03Zj;l0f=J]0>WU_`3mlLT0UHUQ0<[1VP3_k<<0oooH0>CW
^P3ZkKh0MgM30<k;UP3jmKh0k>N`0?3^_P3dl/T0fMF`0<FlW`3Re[h0bk^[0>WGb@3Yeld0onkT0>;?
b03okm/0kn>c0=G:TP3@`hh0UX=H08QbB`1^ES80O6A00:F>I@2^V6l0/Ia]0;:MLP2aTWd0^Yj90<fb
W`3eh]<0ooc]04a5<P2NWXH0Qi1a08NEL@1jSF00V:N00;fn[000200000H0038j:`2i^Jd0l_[]0?;o
mP37lmP0^nK:03U<>0003@00a>BS0;oUVP39iI40f^fK0=WTUP3Pk:h0c]RV0<O5[02ARWP0j^_M0?_o
m02:UhH0Lg]/08N4L`23NVT0AC<O0:BBO01fITd0RHAV07b0G`27UVl0K7eC07>2F`2;TGD0?34[07QX
J029O7H0SXIk08^>N@2<TG/0S9>308b>R`2b];40nooc0?7eiP3^lmd0gnG;06]cCP0c>a80a]2L0>?^
]P3?fYh0hnf^0>3/[03Nj;<0PHMQ0:2STP3Uim`0/;6O0=?C]`2FV6T0MgU70;VhS03Ng;H0mO;A0?3/
d@3Th<D0j^K;0=oK_P2XXF/0WYQN09jHG03Gci00]:Y/0::HF`2o[X80h/j]05Tn<`2bUYD0fL330=C3
^`1gJEh0R7Y_0?c[h`3_g=H0k]_E0?odj`3kiMX0m^7@0?3Ia`3lim@0`jnT0<Zg/@3]fmT0lN7Q0?c^
kP3nko80^ZNY0>?=c`1_De00Q6MS09QjNP3G`lh00PTC01<G800/72L0m=SE0?kId03o`;<0`FmT0?oU
g@3oin80ooKl0?olnP3gm>d0oOSe0?olo@3onod0oo[m0?oinP3on_P0[YfE0?SWg@3oo>l0oogd0>7J
bP3LfZX0c<^E00H3002;Qfh0oOSU0?ooj03^kM40^KNR0=_GcP37]jP0gLbj0:jNS`2^WY40[Z6A0007
0?3Ud`3om>80ooga0?W^jP3on?l0ooCo0?GXl@020?oko@0f0?_/k`3om_T0oo?f0?oio@3om_/0oo7f
0?oho@3omod0oncU0?okl@2]X9X0oogh0?oml@3ooo40o_gX0=7;/@3oo^P0ooW[0?ohl@3omod0onge
0?ohm03onO40ckV^0>?<a03omO00ooWj0?o`l03omNl0ookc0?odl@3olO<0onga0?odn@3omo/0cL;0
0928Q@2m_;L0HfAO0?koo`3jo_l0o_om0?;ak@3oo?X0o^[Y0?GPg`3om_80kN;N0=cHe@3jnOD0ooko
0?ojoP3oo?l0k^GX0P3onol20?olo`/0oooo000:0?ooo`0<0;[]]02NcIT0@fdk0<KV]034hJ/0b^>Q
0=;/X`3>jIX0bNJF0<o^WP33hiL0bNVM0P39jIh00`38jYh0o`000?l000020?l0003o0>;^b03fo^H0
o_oj0?conP2n_K/00`000?onn`3fm^X0c]jg0<[S[03=kJ@0c^fQ0<[VV@2jcXH0SYeH0<oPVP3HkZH0
`^2F0<CTV@2lhI@0aNZM0<SZWP3:j9h0dN^R0<_WW@33hIL0c^bT0=Sf/03Ilk80`mbK09N[KP2^`8@0
f>RZ0=KVZ03Bh:80eNFW0=3T[`3Fh[800`H005iF:02VWf/0inJV0>OXYP36c900g>2]0;2]S01nOeL0
gNVY0=;KY03]k<d0n?CK0>WSc@3oonH0ooKI06iXA03dl</0j>S60?ooh`37g[00f>ni0=?]Y03AkJ00
b>>D07F?B02F/6l0dNZa0<WPZP0Y@@L0cn>V0=oXY`1nQd@0fNJQ0=KUX03JjjL0dn>R0<kNW`3Ah:L0
dn2[0?kof03AgZT0a]bK0<GJV@3Bi:H0_]2D0<kMXP39f9d0eNVZ0<OMW03<iJ40a^:H0765?P3WgZ<0
f]RK0=CSX03@i9l0eNVT0<gLV@1DFQX0X:IV0=GJVP3:eI<0g?2Y0;STS@3Bo:P0^^>D0<[cY`34lZT0
[N6G0:BDH020K3T0annV0;CPU@36k:<0V:QY092NH03IhZ<0fMnQ08^?DP2ojKL0;54N02U65P3:gZd0
DV<_0=GOZP3Oj[80d]fS0<[LXP35fYl0bN6W0=K[/03KlK40bn6P0=G^ZP34gIT0b^FP0<_YX`35i:00
bnbW0<SXY@3Ck:/0h^^/0:Z^L@3Fg:00dMbT0=;OZP3<fJ@0d]nY0>7Y[P3Kgj80PH=20=cVX@3<j9d0
anVO0<_ZYP3>iZ`0d^B`0<oL[P3NjKh0e^6g0<oL/@3Mk<<0a<nT0=cR]02IVfX0]KN60=7DW`3NhJP0
f>6P0=SSWP3Ai9<0enfH0<WVRP3Hl9`0fMjX0=_O[03NhZl0dmVY0=cT/`1ZM400d]nY0=?VYP3AiIh0
d^NJ0=7WWP3AgJ/0oooM028D2@0:0000>c4j0?Kjo`3hool0mooo0?;ol@3conL0GGaM07fhXP1_]hl0
^_:a0;gXX`3Im[<0dO6`0<GSY`3UjKH0l^Rc0:Z]IP3KiZ80dM^h0=3F]03PfK`0fLfc0=K1[P3on^`0
oo[_0?olmP3oooX0nooo0?_onP3joN80UiEn06YNDP2gZZ40nO?W0?ool@3ionh0o?oc0?komP3oo?/0
ooof0=3W/`35g:H0eNZb0<cTZP3?ijT0c>FT0=;[Y`3KmJh0a=jE0:O1M`36hI@0SJ=K08jPIP3non40
loOF0=oN/03Thj/0g=bP0;:`O@3ooNd0ooco0?ojo@3oonH0oooT0=SN^03Pikd0]Ln5001>0<kVVP3A
jId0dnVN0=;VW`3>hIl0b]NY0?coi03nooX0o_oo0?Keo@3oo_/0ooc`0?ook`38a:/0cLN]0>gWc@3o
o^T0oog_0?oemP3on?l0ooKn0?oel03ooO<0b/>i0<c9`P3inOL0oOon0??_kP3onoX0oo7^08]_K01@
=c0010400?Coo`1FLg/0A7Io0=Soo`3Yoo@0hnjd0<_DT`2^XW`0oog/0?Wjo`3noo/0m_W`0?kon@3n
ooX0ookm0?khnP3oo?l0ooWj0=C6aP3on_T0ooSh0?cek`3oonl0fn2Z0>O`[`3^mL40j_;30>Wdb@3Y
m/40i?Fn0>?ca03SlLd0oo_l0?ojo`3mm_h0ooWk0?ool03fnMh0j_770>[aa@3Yl/D0j_7?0>_ae`3U
j^<0m?[f0P3lood00`3nood0n_[h0?gin0020?ono@80oogm02h0i=_B0>gWf@3oooH0o_oh0?;nl03g
oo40g>cA0?Cnf`3/l/h0[jZ=0=;:/`3em=P0gMg10;nlZ@3KeLT0oOCi0?ojo`3nmOl0oo_o0?knoP3Z
lmP0io?=0?_dhP3on_80oo[n0?oho`3oo?l0oogo0?clo03oooX0o_oj0?omo`3nn_l0o_oo0?KglP3m
n?@0oo[h0<nj^@3on_H0oo_h0?onn`3ooo/0ooko0?omo`3oool0o_oo0P3oool20?koo`/0oooo000:
0?ooo`0?0;3UU`2iiZ/0_NNe08BTO`3?jl<0`mnR0>Go]P33hH/0b^b>0;kQP`3Alid0bNZI0<WYWP39
jJ00b>ZP00@0o`000400jO;C0?Slj`3lo?X0o_oj05aKE`0N6QT0n?G^0?ool`3@hKD0b^>Y0<GWVP39
jYT0c^^I0=7VV@3AhIX0c]nI0<_QV@3<jZ00c^jS0<[_XP39kZ40`nFI0<KTVP3;iI`0bN>J0=ObZ`3@
jjH0^=>@0;WBT@1_R4L0`mVK0<_OX03Dj:T0d^BV0=7QXP3AhjD0bMZV0=kV]@0>3`00DTDI09nCH`3R
g:00o?^k0>?W[03oom<0oooO0?Khd03=h9h0dn2Z0?ooi03oln00oo_[0=_7[P3nkLl0ZJAj0<o@Z03h
om/0kOWE0<WK/`3Di[@0cnFM0=?[W`3Ejj00UJYY0P3o0000N`002`00HWHk0=SZ[03JiJ<0Ae@?0=KW
X@3>hY/0dnVQ0=?XX`3=hYl0d^JY0=;S[03jomD0dN:[0=S^YP3UnK@0UjMV0>3`[`3IijT0dMnQ0<kN
W@3Ll:/0enfU0<[RV03Di9d0FU4F0=gKWP3Cgid0fnbX0=KWX`2AWE/0gnFU09>HF01NHb<0e=nM0<WM
UP38l9X0[]B10<_`XP3:l:D0]=nG0=7o^@3Da900a;1m0;OOUP3GokP0b?:Z0<?QX`3=ijP01AT007B4
AP2DWV40^mf[0<7N/0003@00cN2b0<[JZ@3AgZH0f>JY0<oNW@3FiZL0dnFW0<GKW@3;hJ40`=^F0=;]
YP36i9X0a>:H0<c/X038jYh0dO>Y0<KZX036jZ80`n6K0<CDS@29U4l0enJQ0<[MW@3OlkH0g?2e0<gO
X`3<f9X0WJQV0=GLV@3BgiL0c>nO0;kYV@3<lZL0anFU0<CMX`36fZD0cn>`0<WP[03<i;00l_oF0>Wo
bP3<f:X0EUh_02@/003UkkX0fnR`0=OZZP39h9X0do:T0;SKR@35l9L0`NND0=7VX`3@iJ80d^NV0<[N
X@3BiZT0HW@f0<cOW@3>hiP0cN:C0<kUS@3>iY00hOBd0?ooeP0l91X06@0400h03@020?cmo`220>WU
iP3ooo@0l?oO0<?W``0hOF/0@haa0:[Y^P2mlkl0_>Vb0<?ZZ`39jJX0eN6O0>KWX@1PHPl0e]f@0=OW
^03Lik`0f]be09:?K03]hlX0ook/0?oml@3oo_d0o_oo0?Soo`3iool0ViMn05UC?@3ooN`0nNkL0?oo
k03gnn@0noo]0?_ok`3loo<0oooj0?Kij03;iJH0bN>T0=;/Z`39iZ<0anJP0=3^Z02ogiH0a^JK0=Cd
Z@2=[F40E7<W0=C^Y`34f9T0;cT505aS<01JFB40alF:0=_HX`2?RV80ookf0?oko`3oo?l0oOoX0>kb
e`3Ji;l0cMZ^0<7VUP3;kY`0anZH0<WYW@3<jZ80bnRV0<SO/@3eonX0m_ol0?Ooo`3iool0o?om0?oo
l@3non/0o_oO0?7fcP3Ri;`0ZZ^;0?;`f@3ooO/0ooSo0?ojo`3ooO@0oO[Y0?ool@3CelT0nOoj0?Oo
n@3noo/0oocg0?o]j@3onO@0RWI]00P6003hool0dNkf039^N@3Bool0e_oe0<Sa[@3CnZ/0WIa^0?on
j03lool0m_Sc0?SklP3nooX0o_ok0?ooo@3no_h0ooko0?Oal`39`<<0o?;c0?oko@3oooP0o?kY0>3Y
/03>fiH0c]bQ0=;PZ`3@hJd0d>BU0=3YY`3AjJd0d^Rg0?_oo`80oogo00@0ooko0?OkjP3]m]T0dMf[
0P3ChZT02@3@hJd0cMf`0>?Yg@3bmo<0n_ok0?cnn`3oood0oOgk0?oknP020?ono@0`0?omo@3glO40
cL>j0?oml`3nno@0n?Wc0??kkP3ioo40i?7G0<[B[@3:cZT0oooQ0=K?/P1EERX0JVhl0>?S`@3oonX0
ooSi0?ofo`3onOl0n_Gl0?oonP3IgkT0dmfY0>oef@3innh0o?go0?_ko`3no_l0o_oo0?Oin03oooX0
oook0?omo`3on_l0o_oo0?kon`3ooOP0o>[X0<:][03gi>00oo_h0?onn`3ooo/0oooo0?ono`3nool0
nooo0P3lool20?_oo`/0oooo000:0?ooo`0@0<?aS`2ji9X0`nZa096fU00lGch0d?Fo0;_SW@2ihhl0
/m]k0=ClV`2mhHL0b>^I0<SZWP38jZ00b>VT0<WXY080o`000400nooT0?col@3oood0oogo0?koo@01
0000kn_X0?oon03cm^D0cn:d0<_WZP39ki`0bNbH0<SZT`3<iI@0c^2F05m`:P2bb800c>ZP0;kNT`37
k9l0`nRK0<k`Y03@kZ@0cNNN0=3ZX03EkJ40e>^M0<SOS`20VDP0h_^Z0<WTT`38hi80b^NE0<k[V@3<
jIL0anJJ0<cUZ`2baHh08b`007QeC01oNdh0VIaU0>[d]`1lTE00fNna0=3T/@3JlKT0a^NP0<WUZ`2Q
ZhT0V9]n0<c8Z`3IejL0l_>j0<kLWP3Qm[/0cno00;GAZ@3Um<d0VZYi0=CXX@3NlZX0cN6J103o0000
H02ld8/0KHDk0<o_YP37jId0]]f>0;GNS`2fhI40a>nO0;cWV034kZ@0`NVR0<kc/036ij80`mj?0<_S
U`1mTDT0_=290<[KU@3>gi/0NHY40=S/Y03DjZ40e>bP0=GZW`2SZFT0RYID0<SSW038j9l0a^RN0:[8
P03CjZ@0bMjI0<cSW@3Hlj`0Y;ig08ZGD@3NjjD0dn2K0<_LUP39hi`0bN^Q0<:QM021GS@0cnV/0<?Q
Y@3Dnl@0B8IQ06>MM`2;^i40`o730;[Q[02:Xf`0bn>c0=Oaa0003@00b^Je0;oLVP2M^g<0P9Y@0:g1
N@31dXh0Pi5C08^KFP2od8`0b]jG0<kRVP3Gk:40goJX0;O=PP3OmJ`0b=bE0>Cj/P28WUH0Ykeb0=cd
YP36hI@0b^ZO0<7QV039ij40fOBa051S8`2c`H@0aLnB0<kIW`2ic9@0g>jl0=7Q]03non40oooS0?co
h@3oon@0nooQ0?OogP3eom`0i?S70=gY^@80oooH08d0o?oC0=;JZ@2>VV`0Y[>70?Cog03/om/0`=Ze
0?3og@3=m:D0a>ZM0<O[X@39jZD0d>n/05ml>@3:iJ00c>BH0<[STP3>iY00c>RA0=GaYP3NhJP0TWIQ
09]nN03Rc/l0JfA/02/Q:P0=0000P7AX0<KD/037jk/0[?6k0;S/aP3Hoo/086E904fDM02li[P0a>:/
0?Cob@3Uo[X0/j]j09>9F03aolT0go6g0=?T[P1FIc<0bMR_0?WoiP3iond0mooo0?Goo`3ao_l0moko
07EWC@3omMP0knG10>_V_P3:djH0bm^^0>Kmd`3Ml//0gnk=0>W]e03Cf[T0gOJl0=Kb]`2ofih0b>BW
0=gl^@3?kZ/0`^>L0<[[Y03=kZL0bnnU0=;f/02ieiT0b^FR0>[j/`3?fI@0^[V10=K?X`3/i<d0lncJ
0?ool`3Wj=X0ko;O0<O@/@3?f[P0JGY=0=3W/`37iYH0cNbP0<cXWP3<iJ@0b^:X0<SLZ@3Pl<`0n?oZ
0?Wom03eoO80i>cQ0?7ni03DhkX0d>2_0<oRXP3BiYl0f>bT0<WLVP2a`hL0UZ9l09^VR02LYXh0iNo=
0=kX``3Tll`0l?oK0;oC[P2fbZL0e>;80?Ooj@3eln@0ookc06IBB@2QP6l0Lf5Q0>SUl03gool0?6=Z
01E3>@007P00`MbU0:n/P`2;NV00dK>a0?GWi03oooP0n?Ob0?oon`3nood0o?om0?GgmP3nool00`3o
o_l05`3nooP0lo_S0;;1QP3MlJ`0iOS00=OY]`3Aj;80c^RW0<c[W`3;jj80bNNW0?Goi03eonP0moo]
0?Gok03Fi/T0e>G10<oS/P3;gjX0a]ZU0>7gb@3comd0o?ge0080ooko00@0oogn0?ono`3ooOh0oo[l
103ooOl0;@3oo?H0e/o70<o:a`3oo_l0oooj0>oci03Sj=40c]Ja0=[R^@3Yl/L0gNFl0=7RW03;h9<0
gN^]0=?MZ@3IgL@0loCT0?oon03innh0ooo]0=cV]03KijT0iO[?0>[oi03dood0m?oo0?Goo`3good0
noof0>odh03Si]D0oo[n0?olo`3kool0o?ok0?oonP3ok^`0d[fl0?o/j@3onoP0ookk0?oon`3nool0
oooo0?coo`050?_oo`/0oooo000:0?ooo`0;0<G/S`3<lZD0_nJU0=CncP1oZWd0GHUD0=?o``2jij80
d?VZ0;CKRP39kiP00P36kI006@36kI80b>bE0<W[U@38i9L0cnJP0?_og03monL0o?ka0?klo`3oood0
6QPI0>KRh`3oooX0oooc0<gO]@39iJ/0b>fM0<_^W03=kiT0dNZI0<kPUP27V540b^2G0<o^XP30h9@0
0P36jid0:P3;kJ00b>NK0<OQU`3>iYX0_mJ80:2eIP2AYeD0bN2>0<oXU@3<j9@0cNZF0<g]V03<k9L0
a^RB0<GVU@3>j:T0RiiW02/d1@2?RfH0RHAN08jBG`3:eI/0SjQV0=K`[`3Fl[L0_]ZM0<3MVP3JlKT0
FfU50:jjUP3]n<h0d^2R0<WITP3Fk:40_MRC0<o[^`3Gl<P0HW=904YL:033f9<0e^bT0<7FT`@0o`00
0240[/Ai09ngJ@34j9h0_>6D0;7JR`3QokX0a_>P0<?`W@2mjYT0`^jO0<3ZWP32jZ<0`nVN0<o/W03A
k9l0HGT_0>Cj/P3@i9l0e>NU08jRG@3:h9P0bn:J0>Cn]02ichH0`LZ907F4@@3DlZX0bNfS0<7UV`2n
h9H0b>>L0=;/Y@3KmZl00P37iih0iP2BZF<0]<^50<_UW03AkJ80_nFH0;g/WP2]WFX0OV`n0<[b]P1m
ZVl0D89708g1P@2diZT0`N^/0<;VZ@39ij/0^lnD0;gDX03Fl<4002000:C9U@34k:H0aN^N0<[]W@3L
lZT0b]^G07R2AP27UEL0gNbY0=c]Y`3MkZL0a=B;08^KDP3Lk:<0bMVB0<kKUP33dXl0FV/W0=7WW`37
hIL0d^jS0<SXW03?kj@0b^RR0;kIUP16F1`0PHiF0=kW/P3Mh;<0l?7A0=?A^P3Qg<P0ooW]0?oklP3o
nO00ooW]0?oojP3jo^<0mooO0>[gc03?fj/0oooC0?Kmb@3oom<0m_S70;bmT@1mOeL0oooS0?OlgP3T
jM80lOoL0=?g[@37jj<0b>VT0<SVZ03=jjl0H7a10<_UZ03=iZD0bnBP0<oWW@3=jIh0d>nY0=GPYP2_
Wgh0J58k08QbI03fj=l0NVeU014700060000k_OL0<GL/P2hjjH0^^6/0=gom00LFd002Dlc0<_he`38
j/D0kooK0=kjb@3KeKD0J5Th0?gja@3ooll0TI5M06i`?P3_mLT0o_oM0?koi03oooH0ookm0?olo`3o
nol0TgmT0?ong@3cj;/0g]^X0=o]/P3;h:L0cnbf0<cX]`3>i;H0f>>k0=GO^P3_omT0j?[@0<SN[`3D
j[T0k?o>0>?oa@2mfYX0cnj[0=Sg/`2kfY@0_]nJ0=Og]P3El[00c]bO0=kU[`2LV7<0oooT0?olj`3j
mN80jo3B0=KN^@3Fh[@0g^b_0:RhN@2ebh<0bnJI0=3TW03Cij80d^:S0=KS[@3EhK40d]^`0?_og`3n
on<0oooX0?Ogg@3Ef[`0cm^e0<gO[@3JkKD0aMZG0<KLU03Ejj00dNNL0<GMT`2>Y6<0QYaL09nbNP1^
Od/0b=VU0<CGX036fj<0fO2j08^RKP3Ij[h0h>c80?Wmi03oond0Sh=e05Pj;`2DRh@0M79c0?G_o@1T
PHD03S/d000A0027X880g^k70:BXP`1jGdh0cKbd0>OLfP3_in@0ookj0?gnn@3lo_T0o_om0?[ln`3g
moT0lo?e0?glo`3nooX0noo/0:NfO`3Ml;00/lFC0=CU^`36g:d0bN6U0<[VW03:j:00c>VY0>Ko_P3P
n;X0ho[60>3caP3@hKd0e>K00>Cfc03XnLl0jOWB0>oohP3aonH0n?ok103hool0<@3gooh0n?oo0?Oo
o`3gool0lOgi0?Ooo`3oooX0oooh09ZFU`3onol0ookk0?oom03Tim80h^c70<oL/@3Ol<<0fNbn0=G^
]@3FkkD0cn>^0<?DY`3/mMP0o?oa0?kon03noo/0o_oh0>K^eP3WlLl0f^o40>7gd@3eooP0mooo0?So
o`3iooX0nooa0>?Zb`3Hg<<0no[e0?omo`3iood0nOoi0?oonP3onOL0fLC30?oimP3onoP0ookk0?oo
n`3lool00P3nool50?coo`/0oooo000:0?ooo`1C0;cGT02ef8P0g_nd0;CZUP2ajYd0[NJa08:gR`00
6@00bO;:0;?H[03;kZh0a^^N0<K[W@36jih0b>VT0<WXY@3?j:h0cn>`0?cok@3nood0oogo0?ojo`3^
k?L00P080?olo`3mn?`0loC^0?Goi03Wom00`^RO0<;WVP37jI`0c>JL0=?TW@3LkJH0dNNN0<g/X03;
jil0`^NI0<W^X033iIP0bNRL0=7[X@35g9@0VJUX0=_ZZ@39fIP0c>2K0=?YX@39iI/0anFK0<?UV@32
iiX0anfR0<g_Y@3<f9X0dM>Q01TD003NbJh0g<N/0??Z``3hmlL0@U8C0=O/Z@36gIT0fNVX0>CNZP1Y
IST0n?oI0=SW_02icIP0`Mj:0<cYS03=hHP0f>FM00T:001CEc@0eNJj0<[MYP3FjjH0fo2]0;W=T03e
on000P3o0000o`3<gZ`0amn;0=C/UP3Ll:/0c^BL0<kXWP33gi80bNVF0<[ZU`3=kYd0b>NG0<o[WP3;
iI`0c>RN0<k`X`1BLRL0c^bV0=Ob[`3EkZd0e>ZZ0<kTY03DkJ/0d>^X0<WWX@3;h9/0LW0c0<oDU038
gIP0c^RQ0=_f[`3HkjT0bmbH0=;SW`3Hk:L0d>NQ0<SOV`3@gZ<0SimP0>7e[P37giD0`^BG0<OcY02i
ZGP0hm2V08ngQ@2nk;d0^>Nk0<SbbP1KPeh0_Mnl09FdTP004P00[Kak0;37S`3Bk[d0_n^j01E83`2a
ii/0^nnL0;o/U`3BkJ00c]nK0=oZ/03Kkk00c>FQ08nYHP3<i9X0g_B[0=KZXP35fI408c@005=R7`2;
VUT0d^:S0;G9RP3@jJL0^mJA0<[ZX@32hYT0bNBO0<kWYP3;fJH0n_oE0?oog@3kmmX0o_kR0?oojP3o
on`0PWUZ05aCA03oon`0n?SP0>Whc`3>i;D0a>>W0<GYZ@2ok:T0]N2I0;_SVP3<k:40e>jU0=7UWP3>
gi/0ZkEi06A[=@3iold0l_c:0=_]^@3?hk00cn>b0=3U^P3LlLX0GG==0<KO^03=j;d0c>Nj0<_Y]@3:
j;@0b^^f0<c]]03FhJL0fmRQ0>cHYP1SBal0M6Dl0>ojfP3iond03``700L0003Ti[h0cMjd0;GG]P3U
oo80h_ok04f7N`27`K<0j_od0=g^cP32cI<0hn^_09fKJ02LWfP0b]RK0<?GV03CkJh0bnN/0<cT/03S
llh0mooV0?[mk03gl=h0GdHW06MA:01eK340EeHC0<_PT`3=k:00`nRR0<K[Z03;jJT0hO>i0??nd`3m
oo`0oOoj0?Omk`3gon/0mOoR0>3_b03?hJd0c^6Y0=G[[@3@ij<0_m^>0<G]U@3Em;40moo`0?CdmP2]
XJ/0oo_k0?_hf@2MX740f>NV0=W]Z03?hi`0VZAM0=WVWP3[ok<0_mJ80<[ZY`3<jZ`0c^^a0>Ood@3a
om`0l_oM0?Cof`3;gj`0cn>T0=7VX`3Gjjh0nOoS0?SojP3YmMd0moo/0??oi@3Sl]40c=na0<[RZ037
hiH0b>FA0=GcV`2jdXH0T:EJ0<GJS@3<hI80`mV70=K[W02=WUX0a]FJ0=GP]P3DfkX0n_k]0?Kfk01N
DDP0<RHH0=CA`03Tl>`0l?oo05N3S02B`lL0GG]Q0<gP/P3Yj;00oo_/0?;Hf`2IQHH0YYJF0?omnP3o
o_T0oook0?_kn@3jn_X0oooo0?cjo@3nooT0m_[Y0<kJZP2=VVD000H007AnI@3honL0n?oK0=W^[@3<
hZ40c>:T0<kXWP003@3@jZ00d>F/0=GX^P3don00nOoT0>3_b03Ag[<0d]nd0=7L]03QjlH0oogg0?oj
o@3onoh00P3ooOl0<03oo_l0oogn0?[hn@3no_h0oooo0?koo`3alnh0o_ok0?ono`3ooOl0b/C60?on
n03nond0l_kH0?Kof`36i:h0a>Na0>[of@3MolP0`nNO0;kNTP3=iid0dnZT0=KZ[`3JjL80mOoT0?So
l03ioo<0bmRZ0=GQ[`3gonL0o_od0?gom`3nond0i^g;0=_T]@3DgK00mooX0?con03fooT0nOok0?gn
n03on_P0k]WH0?oimP3onoP0ookk0?oon`80o?oo1P3oo_l;0?ooo`002P3oool03P3DlZ`0d_FU0;7I
P`37n9l0^^^I0<7c]P2eikH0Pk>;04ejF`2;^9T0a_760<;Z[P33jjD0aNZT0P38jJ@0o`3?hjh0c=fc
0?KolP3gool0nOgo0?ofo`2_ZKD0JVM^0?CanP3oo_l0o?kk0?GojP3Vom<0aNFR0<OYW`3;kJ00bnJI
0=SYXP38g9D0e^jT0<WYW@2mgi<0aNNK0<o_X`38i9T0cNNN0;_BRP2I[VT0QYYK0<?HU`3AiZ<0bn:J
0<cVW03<jZ00c>ZR0<c[Y@3;k:L0anNT0<SSX02DVUh0gm^[00h0001YCcH0Y8Y_0?oid03Xj;H0]/V9
0<cQWP2M/Vl0IW8d0=kBX01OF2X0nOoF0=_X^P3Cj:l0e_6P0<?MQP3OkY/0/;Yc07YiB`2DUf`0g_6j
0<GHX03;gZL0dN>a0=KW^`3fon<0n?oX0?Sog@3FjK40Z;m]0<_QSP3=gYP0bmnH0<oWW@3>jI`0bNJF
0<OVUP3>kId0aN:B0=3XW03>i9/0cNFK0:S:OP2R`WT0bnJQ0<CMV`35gY`0ZlB30;kIUP3>jJH0dNj[
0<k/YP2X^gT0ThY?0>3RX`3DjJ@0c^VR0<WTW@3BjJ<0f>NT0=_ZY`3>gi/0fo:/0<_PW@3GhZH0]/:4
0=GTW`3?h9T0cNVN0<CYW01oIcL0ZXiV0<OY]P34j[T0_>Fi000?00007`D0C6eB05eiH00Q>B40IH<k
0<kY]03<jKT0_Nbh06RMI`2jm[00_O>U0;STS`3BjZ00b=bG0<_PW@3:j:80bNRR0<WWW`3?jj40`]bB
0=7[X@3<iY`0c>>K0<_RVP3IkZT0d>FR0=oh]`34gYd0gOZg0<KUW`3;jj80j?nn0?3oaP3ChK00e]je
0<O=Z@2@T7P0TYAn0?;dgP2BU7`0mOKG0>SYb@2KWgX0XZZ10=3R[P36h:<0`^NQ0<G_Y@2ijIl0b_f`
0<3_X@2ki9D0coBT0<WUV03CkZ40c=fG0<7@S@2jaXH0o?o?0?GoeP3Ul/L0f^W20<_J^`3Bh/D0OY1f
0>_nhP3bonP0l_oT0>oog@3^om`0k_oN0?3og@3Ehjh0gMfW0?3P[01[EQl0EDXD0=?P]@34dK<0o?Wd
0:bQW@070@0000L00=;[cP3=jM00an?=02EQE@11Q7/0f_ob0>gof@39gih0eNbX0<kIW`3OkK00c>>O
0=;]YP31hY/0bNVV0<KUZ@3Pml/0m_oS0?Koi@3]l]@0XYI^0:2EI`3=cHd0lONa0=;WVP3:i9X0bnZW
0<gY[03DjK00l?[60?gog03onod0oo[j0?oonP3oooH0o?o_0?3jh@3UlLd0i_;:0>GbaP3Wll<0jOg2
0<GUV@3HkkT0o_ok0?3]n02cZ;P0ooOk0?onh@3HeJP0d]fI0=S/Y03=i9H0en>I0=?QUP000`33e900
enZZ0=_ia@020=cjaP0m0>;ocP3Po<T0f_K30>kod034gJ<0bnBS0=;XY`3Xnl@0mooV0?con03koo/0
nOok0?ComP3YmnH0c>2k0<[R/03=jj40bnfG0<SYSP3HlIh0SZAB0:VoK@3DjYL0cnF@0<oUTP3CiIT0
^<V50;?1S03Ii[X0nooX0?Wol@2UYi40NWYR09nTSP1WL6d0YkBl00h_?P14NX@0CG5S0<cX`P3ZnkL0
oocL0?oil@3oinH0_:RY0?gclP3ooOd0ooom0?koo@3ho?/0o_oo0?cgo@3ooo/0nOc[0=oX_@2?V6/0
3aX007EoIP3ion40n?oH0=[^[`020<cQX00<0<ORU@3>jI`0b^2R0=7S/@3hom`0nOoM0>7__P3Agj`0
f>Ja0<_IZ03Ii[P0ooof0`3onol0<`3onOd0ooSl0?olo`3omoX0ooWk0?oln`3kn_P0oooj0?kom`3o
o_X0n??i0?_do03nn_L0oooZ0?God`3dom@0bnnb0<K][03Yom40eOVi0<[/XP3<k:00c>JL0=G/Z03F
jZl0dn:k0?_oj03joo80n?oc0=?L[`3KiK40oOoY0?kol@3loo80o?o]0>cfe03Ii[X0b]Z]0>gkh@3h
oo@0m?ol0?Soo@3oood0ooWk0?oVj@3omoL0oo[j0?oon`3noo/0o_om0?ooo@060?ono`/0oooo000:
0?ooo`1B0;oYW@3IoKL0b^NU0<[OW03]okX0dNbM0<W[WP2ojJ40/^c408o@^01KWYD0XMVl0=_oc02m
hYl0a^N@0=?eWP3Bh:D0k_W>0>col@3UooX0k_ol0?oaoP1_IFH0MGMd0?GgmP3ioOl0mogm0?Som03g
on`0b^6[0=7ZZ039iIP0[LIb09JVG`3IkJP0cNRQ0<G[X033jIh0d>^T0<WPVP3IiJ<0cm^I0<;>S03>
hIl0cnf]0=?i[P2oiY<0^N230<7VR@3?ki`0`mnD0<KJV`3:g:00g>Va06ii?`2PYFl0kn^l03<T001a
FCL04P000>g`^@39fIX0W;]e0;kKV02^`HT0EV0[0>GRZ`1`Lc`0d=fU0<SGWP3Sl[/09Rl006E]=01N
IRX0hnn_0<_PV`37gi<0dnjM0<WNX`3conl0nOom0??im`80o`000?l0c>:J0=O]XP2P^6h0Y;ab0;kF
S03HlZP0`>:E0<3UU`38lj<0_NJG0;[SU03Bm:L0c^fQ0<WOUP3Llj/0JX@m0<GLUP3@hId0f>bW09Za
J`2ZaGh0a>JL0<CTV`3Lmk00b]jI0;G0OP29P4D0h>FU0<_YX@39kj@0bNfS08f[H`3=hI`0dNFP0=C[
Y@32i9X0b>ZN0>Sn]@3;g9D0YkA_0:ZgLP3JjjD0b=nI071:6@2`R5L0c^FQ096/I`1SPTH0Li9b0;;B
Z`3?k;h0SJMh07F7G@2GfHl0^^Bd0<?T^@31j;<0b?W<03Q[@034k[`0//n?0>7a/`33fI40c?ZH0<?c
W@31iiX0b^bP0<7MT`35hIL0b>ZN0<K/W`31j9L0`NJF0<[[VP30ghl0anZJ0<W]X`36ij00a>>O0;oM
U`3BkJH0dnbX0<kSZP3=g[40e^C00?Knk`3no?d0l_GZ0?_ok03AiZh0aMVJ0<oPW03<fiP0`<n>0=S/
Y`3=jj40b>NK0<STV@34hiL0a>BH0<;WV@2kh980a>VK0<K[W@39j9`0dnnT0<OOU@2aaX40Yk>10;S3
V03Hhk/0h^_@0>7[d`27T7/0noo]0<?A[P3EhKT0c=ZU0=SY/`3Ij[h0fnW50>gce`3/km80emRf08J6
E022PDT0gmfZ0=WG[P3oonX0n__[0;W1]022QWP01@/709^SV03Hf/80b__V0:gdi01X[i40QJQ`0<;V
^031j;T0b>ZP0<GWW@3;iiX0an:C0<SPUP3<hZ80c^:]0?3og`3gonP0goC=0=O^`03:hjX0an2V0>co
aP3KlK40FVT^0:jiP@3Pg[D0f]B`0?__e@3bgm00S7IY06=8?@2lYId0ooS_0?kkm03bn?@0nooo0?co
o`3nool0oogo0?oko`3ooOd0m?_Y0?ool03oo?<0oogg0:b^Z`3oo_l0ooOd0;fOU03Qfj/0c]fJ08JN
D03Sn:T0cN6I0>Cb`@3_nmL0mooi0?Sol@3bon<0d>Na0<gWZ03CkZ/0cnNY0>7f_P3VlM40k?CM0?oo
nP3oool0oOco0?koo`3kool0mOki0>gkkP3PmMH0e>k10=3`[@3>ljH0co>L0=;/U@3Kl:40RZ1E08BH
D`3PmK00a=ZB0=O^X03@iiT0TJMO0<7FT`34ej00cN6`096mPP1cWF/09CPU0:Ba^@0l@d/0n?ck0:?6
b01LQY@0e?kj0;_YZ033gj80joG30?oki`2<M700oo[o0?gbn03cl_00noom0>_gm@3jool0oo[o0?om
m`3oon`0UIab0=7K]P002000IgY=0=?]X`3LmZ`0d>JX0<cRX@35g8X000l0eNjJ0<KQT03@iYd0//N4
0<;FT@3QmJh0a=V>0=?YWP3CjZ80`MVM0=C]]P3koo@0oOol0?glnP3oo?d00`3oo?l0<P3mmoT0mo?b
0?oonP3nooX0no?`0:BLT@3`k]L0oogo0>[Xo@3kool0e^Rh0=;^X@3:jYl0_n>M0<C/S03@kI/0hoZd
0>Ki`@3@h;<0d=[20??jjP3eno40o_om0?CdlP3ooo/0mOC`0>G[b@39dJP0o?o/0?col`3eoO00i_;T
0?Ool`3Yo>00dNC60<CL_03Wo^80i?_a0?Coo`3oool0ooCo0?gDhP3ol?P0ooSj0?konP3looP0oocf
0?ojmP3kmOD0oooo0P3no_h=0?ooo`002P3oool0D@3Gn[H0EW8g065i?`1]Od<0C5lM0<_SU`33hY@0
`>JM0;ga`038omh0KJbI06BTR@3^on@0cnNe0<W[X@3;jIl0cmfZ0?Woh@3Yoo00moom0?Sio@3on_l0
3@T807anN`3gnOP0o?oo0>oem@3iooH0lOoX0=?V^03AiZ/0b^BM092WF@1_O3L0e^ZU0<?MUP35jIl0
a>RN0=3[Y039h9X0b=ND09j]JP3LjjP0dnRU0;KCT@3<k:<0`^>D0=klYP3<j9<0fo>W0<WNV@3Ij:d0
JGPo000:001RL3D0dn2[0=?BYP1NE300Ie0a07iZB@1CEB<0GfX`09J_KP3<hZ@0g^Rf092CI03NfjH0
WZ5Z0=[W[`3Hijh0enJ_06mj@P2`^H00`<Z=0=k][03CjZ@0eO2S0=C_X03:gj@0mOo^0?Son0040?l0
003a0=;]X030g980b>:I09>YH@3FkJD0a^JK0=Kk[P38lJ<0cO>V0<G[WP37ii`0`mnE0;_AR@3Mlj/0
c^RQ0=O^Z03<gIT0c^:M08jUG`3<iYl0_]bD0<gXX@3DkZL0bMZF0>_f]01IEAP0h>JV0<cWX03:k:80
bNVP0:6kM03BiZ40d>BO0<gTWP32iY`0cO:U0<GOU@3Aiih0bmbF09JWH@3Aj:00eO>[099a?P3M^HL0
an:M0=Cc[@004`00P:M`0;7GW03<k:d0R:IX08JJI@14NDD0AV`i0;kQZ`2oiJ`0[mZU06bEJ@0D=`d0
fO340<?CU@3Bj9d0^n210;GLR@36j9/0bNRL0>Ko]`2ieH/0`>:F0<W_XP33jY/0co6T0=CcY@3CkZ40
_]n@0<GWW@2lfiD0cNbX0<_YX`38hi`0bN>L0=;W[03Kkk`0ioO@0?SokP3mo?X0o_of0?Wok@3<h[40
bMjV0=CSZP3AgZH0X[1e0=;TYP39ij40`^2F0=;^Y039j9`0dO6U0;OLSP3Mok@0aNZL0<kcY@36iIT0
`MfB0=3XWP3DjZ40d^>M0<7ATP1@Gb@0bMJX0=k[`01JI3l0o?oO0=GS/P3AgZP0eN>U0<_NW030gI/0
bn:/0?Woj03fo^H0k_3K0?_gfP2[Yh@0N7==0;RbT03oonH0o_cU0??fi@3oo_P0>39000402`1WHf80
gOof0;;]f@0HF3H0=U`]0=gihP34h/H0bN^O0<OWW03;ii`0b>:H0=3UY03Ej;40e^Nj0?Soj03honX0
cn2l0=3U^P3Aj;@0b=nY0?Ood`3[olL0SIaU09bYM026QV00ShYZ08n4KP2DPW@0`ZbQ0?ohk@1B?SD0
oocf0?Gbk@3kood0nooo0?coo`3nool0ooko0?oko`3ooOd0ko?T0?_ej@3oo?H0TXZ70?koo`3Yi>P0
ooOf0;:DRP3dkKl0d^2R0=;YX`3HjZh0c=fW0?[ohP3kon`0nOoj0?Sol`3donT0dNNi0<cR/@3>iJl0
enfl0>ooe`3iond0n_od0?ono`3oo?l0o_co0?oon`3noo<0noob0?Cok`3goo@0mOo_0<WRZ`37iId0
`N230=;YU`3MkZX0UJQX0:flP`35eid0h_Bh0<WLVP3<hIh0Zkn204AG7`2kcJ<0U:b<01Xo2@1fUf00
JgIF0<;Fc@3Sm>`0o?of0>7om`1ONhL0CVeb0=Sog03`om`0kooA0=WL_@1_HU80ooOf0?ofm`3loo/0
n?ol0?ooo`020?ono`1C0?gkkP3oon@0YJel0=SQ]P0D8P00Gg130=7YW`2me8`0gNjg07b>DP1CIA/0
QI]B08ROF`36fY/0Y;Ij05AT9P2@X5l0KWlh0<7BR`3UnK@0g>ng0<gQ[P3loo<0o_ok0?oon`3oo_d0
oocm0?oko03oo?d0ooci0?oonP3jno<0dMC;0=oFe`3jl>h0ooo_0?gimP3no_l0lo[c0?Koh`3<hjd0
`mnU0<__Z@38ki@0d?2M0<WTW@2ndiX0g>g00?Ooj03loo<0oooh0?ono@3ooOd0ooSg0?W_kP3@ck<0
jnc<0?gnk03moO40oooh0?komP3go^`0lokP0>_fe03GiL40h_3?0?Oom03hooL0n_?]0?oSi`3id=H0
ooGh0?oin03jn_80oooh0>[Lf@2kXj<0bl;30?ooo`3moOd0n?Sh0?ooo`3no_h02`3oool000X0oooo
01P000d00=?P/P3Gi;P0_L^J0=WZ/`1SNC40TZeP0<_ZW033j:80^n:S0;KV_00/L5T0joom0<_Ib03;
gkX0fn_60?CojP3doo40oooo0?ofo`3olol0Kg]k0002003nood30?koo`0f0?con`3looH0nOoQ0=GP
]@3AgZT0UJAS09^TI@3Fij<0d^VS0=;dZP2igI<0bNBM0=7XXP2^`Wd0/LF00<GLUP3>iIl0cnRT0=cc
Z`37gI@0c]jG0=COW@2k`X`0Z:ml0869F01GHB`0f^RZ0<_MW`3FjK/0o_oO00L2002XU7/0RGEJ0=KC
Z03IgJ/0d=^S08fDH@1/I3l0CTDN05=A7P1XJcH0fnRb09b]MP0hBQ00enB/04]I7033di80g_F]0<3S
T`3<kid0e>jU0>7f^`3honH0n?oZ103o0000_`39jY/0bnbU0;kKV02M/F`0d>FP0<7OU`33hiX0b>bR
0<7SV@35iid0b>JN0=K`Z@3NlZd0HgLb0=SbZ`3DjjD0b=fH059V8@3>hYd0dNFP0=3TW`3<gIT0Wji[
09ZVI01/McD0c=FD0=3OW03Ek:H0bnFN0=7XXP3EjJ@0fNZV0<cQW03BkJH0ao6U0;cWV03Gmj/0`N2D
0=C^Y@3=iih0QjML0=oo^P2AN480XhEA0<KWX02fg9<0a>VT0:k;T`2H]g/0N:1R0=7j`00iIcH0MY25
0;SOZ01RRdL0k_oF0=3][@2S^8d0LhIZ0007002Q^Gl0XKU[0;;8MP3;hiL0_=:90?Ko`P3;hIP0hOV_
0<SZWP39kj80bNjQ0=3^Y036gID0fNZS0=G`X`36i9X0anFM0<cWXP3KmZl0c>RM0<gYWP3@jJP0e^fe
0>3fa`3honX0o_oc0?_ol@3honX0h?O=0>7fb`3aomT0k_[D0;O4V02b`Y40P9eK09>aJ`2>Z5l0Xkec
0;C@Q@2kfhl0/]:60<W[WP38jYd0anNK0<g/X03ElJH0d^fN0<;JPP3Aii@0hoR[0=3SX`3?gZD0Hflm
0>_ga@3DgZT0cMRP0<G?TP3IjZ@0a^jF0<O[X@3NmLT0kooP0?_ok`3dmND0ooo/0?onj02g[iX0]j^K
09^DNP2JV6P0O79?0?oik`1mJV@010000=?]bP3?ll<0]^F^05B5EP3Mm]P0bn2i0<_[W`37iYP0bnFL
0=CZZ@3jom`0mOoR0?_ok@3Uk]T0e=k60=k[c`3TlM<0m?oQ0?Woi03BhKX0e>>l0>3/aP3?fKH0oooX
0?[gi03oo_40ooWc0?[YhP1gHEH0iM?90>cSg03oooX0n_ok0?_oo`3lool0o_oo0?ooo`3oo?l0oogo
0?oonP3oo?X0[InN0?oem03nool0nOCh0?o_l@2kW9L0h]Rd0=[T[`31dil0f>C@0=[Ue03kooH0moob
0?Wol@3hond0n?o/0080mooZ04/0moo/0?7oj`3hooH0mO_i0?Slo`3mnol0oo_o0?oloP3ooo<0oooX
0?ook03ooo40moWd0?gom`3lomd0fn^/0=W[V@39eIL0dMZ]0=KN]`3Cf[P0d=Zh0=OS_@3ZnLh0d^6f
0<gM]P3Jj/H07C@J03eOA`2ogIl0dNFN0=cKX`1NN5l0AfIF06I^H@3WlnD0o_ko0:jh`P08=R`0Eh9W
0;gW_`3=kK`0SI=W0:N9K`2hVhT0o__d0>_Zj03oo?d0ooci0?OomP3Hh;/0e=fX0>Wf/@1XMS/000`0
04MH903;giL0`mJD0=;O/@3BgZh0fNBX0<OHY03Gj;`0k_gB0?cog@3;dj80[[N00;c4R03`n;d0e]nX
0?;jd@3non<0o?ka0?gmm@3oooP00P3oo_P0>03ck>H0ZJ:L096<QP2SWYP0n_[b0?oom`3on?l0oo_o
0?gimP3ooo@0o_oc0>cdi`3goo/0mooj0>Cgh@31gJ80b>JL0=;aX`34hYP0d>F/0<7BY@3nonX0ooo`
0?Wek03ono/0oo[k0?ohnP0g7al0ooOX09V<O03Ca/00ooKe0?okn`3lknT0ooKX0?ooh`3ooml0m_;=
0?7[a`3oonP0mo3M0?ohj03ojN40j<6j0:B5P02gXiX0MVaR08f3NP3H_;/0omkQ07U_L03jn_X0oOgm
0?Gem@3oool0oOgm2`3oool000X0oooo01P000T00=7M[`3;f:`0c]j]0=?V[`1RNcL0LH]10<3LS`3A
l:@0`^:I0=Ooc@0gM680b_?]0?3oo@3Af/L0fN7:0?3ok`3booH0oo_o0?o]o03omol0010<004:1@3n
ood20?koo`0h0?gno`3lo_/0o_oh0?_oiP3CfKD0cMBZ096JH@1jP480g^fZ0=C[Y@3Emjd0aNNM0=3[
Y039h9X0RIiI0<oTW`37hIX0d^fV0<cVW`3?iId0gNjW0>7/ZP1HGB<0Si1T0=;D[03NiKT0eMn[0=KV
Y@3;h9l0mooM0<C:YP0D3`00GdTb06E@=@3Yi;X0hN>b0::[M01PI380akjG08b0F03BdYh0f=fW0=;Q
ZP1cQ4d000`00<kMXP1DHRD0cn>N0;[DR`2lhi00a>ZG0=O`[03Wo<40m_oO0?Koh@3eom`20?l0001V
0<GUTP37jYX0dOF_0<[YY@2_`gh0hOJa0<kYXP3<jZ80`n>J0<WYX03:jZ40a^6J0<oVX03?hih0CV8M
0<[QV`34fiD0eNZU0;[?RP3Ol:`0enJS0=[VY02NZFL0Ae8@04eI5`2IYF<0k?^h0<OKUP3Kl:/0cnBO
0=7RWP39f9D0cn2L0<oTW`3=j:40a_2T0<7/W@3:jYh0a>>G0=?_Y@3BkZ@0PJ=G0;SQU@1OAQ00]9UT
0=7bZ`3?mJ`0_=nK07:9E@006@00c_Fl0<gla@20^8T0FFaZ0<7X/@31kZ/0k_oF0<3HVP2@WG80aM>i
0007002:Yfl0Qj=H096QF039fY<0eNFN0=KVW`3AiId0cNFK0<OYW@36k9l0dO>W0=K`Z@3Cij80a=6<
0=K/X@3Bk:80fOF[0<KQVP3<ij00bNFH0<[VV@3:hil0bn>W0=C[]`3aomh0o?o/0?WojP3gonH0kOoJ
0?3og`3ion@0m_oO0?Oof`3_om00`n2N0<WWW`32g9<0an6G0<;LTP2ngI40DG0T0P3=kJ405036iYX0
`n:F0<KUV@3;iiX0foBP0=G/W037gI80dnFW0=OV[`1YMDL0dMba0=?L/@1BFBd0YZal04AB5`37kY/0
an^Q0<cW/P3Un/l0m?oP0P3oonP0?@3oonX0o?OT0?omlP3Je;h0jNR_0<VoSP35ZhH0j]Fh00H5003X
n]00a]nX0;oV[@24^i40k?oL0<SMY@3>k:80b^JI0<WPV03BiZT0o?oX0?_ol03looH0g^GE0=?KaP3e
oNH0noo/0??ki03lon`0e]o40=kYb`3fon80o_oZ0?ook`3ooo<0ooS`0?okn`3onoP0I4e50?ojl`3o
o_H0oooj0?coo@3kool0o?oo0?koo`3oool0oogo0?ono`3elO00oo_k0>;Dd`3on?H0o_om0?ono`3o
l_<0nM[E0?oog@3CgJT0AULZ0?Gom`3Xl^X00P3kooP0F03PkLl0b]Vj0<OF]`3Bh/L0hO7G0>kmj03c
oo40nOok0?_oo`3lool0o?_o0?omo`3oooX0oood0?ook@3oonl0oooc0>_[h`3Ifld0dMR_0=[UZ`3L
ij80VZ=^0?7gd`3oon@0mOWN0?cojP3hon@0nooS0>gke`3BhL80bmVo069hH@36jLT0g?^e0=GWV`3M
fj00]Lnf096]X@000@00NH1h0?G_l`3Qi>/07da504^1JP2ajL@0^=fY0=CQZ`38/X/0KE@f0?okm03o
o?d0noKc0?oomP3ao^X0m?oA0=SVZ03:g900dn>R000:001TMd00io^d0=?VYP32cj@0f^Nl0=[W/@3E
iKP0eNFn0?Gog@3cn]P0jNk508V<G@3Wj[D0cm6O0>3Q]@3Ng/80n_cW0?Gek@3oooX0b<Fn08n:Q036
_kL0o?G]0?onmP3oooH0ookh0?onn@3mo?L20?oko`0M0?ooo@3ooo@0o?oc0?con03go?l0mooo0?7o
m03<i;80bnFV0<oYX03;hY`0a=FN0=;O/`3nonT0oooa0?onmP3omOD0ooSh0:>;R`1XCTd0oo3V0=O6
_01SDE40oo7e0?oen@3on_P0oo_a0?ohgP3oo^400P3ooN00403oo^P0f<^j06UCA@3om^d0o=O?07AI
D01KBCl0l>?J0?oll`3okN/0oo?d0::FV03lo?`0oooo0??cl`3no_h<0?ooo`002P3oool0j`3Hhj/0
bmVV0>Oha03=hJ`0c>>[0<GRW`26Y5`0fOFZ0=ObY@3<iiP0f__20;_[f`1k][00h_oo0<k;aP3Fe/`0
jOo^0?ConP3on?l0ooGo0?ojo`001P00;SD^0?koo@3koO`0nOSm0?ono`3gmoL0oook0?[li`3Qi<L0
g^:m09NNJ`1TJ2d0d^6N0=;YX`3@lZP0c>jT0=7/Y@3;hY`0T:EP0=7XXP3;jJ40cnfU0=GaY`3:h9P0
d^JO09ZTJ02<T5d0i^K207MhEP3Ki;T0bmNU0;kCSP3FkJT0mooH0=kP^`0>1@00XXQa0:ZBMP1FDRD0
DE<Q04E@503^mKl0n?C70:RQM@3[k[T0c=>O0=;S[02GZW80XkMl0=CSZ02N[Vl0fo6Y0=WeZP3Foj`0
a>jL0<GNW03=iJT0d^Je0=?W]P3EjK@0c^FQ0=?]X`36j9@0aNRH0<CYX`37ij@0X[Ec0=W^Z`3^ol<0
h_fh0<?QV`3<jZ@0b^FP0<kWX`3BjJD0cN2N0;C7Q@3golP0`]VC08^RG03?i9l0c=^H0=GPWP1WKBd0
EU`L08fCD`3Tkjd0cMbI0=GZY@3@iJ00fNfX0=3QW@3BgY`0eN6O0=;SW`3=i9h0aN>K0<SbYP35l:40
b>BI0=C`Y@36h9L0cNVO0=7aYP17KB80M5/U0;bNJP2kfY@0bnnW0=Gc/`1OKd8000`00<O/]P2VeIl0
PKb>0:Rg/016L3h0^^Z/0;WNZ03Vnl80VJ5h0=GRa02I/Y`0QZed0;kNV`2AWEd0fnNU0=[UX01jQD00
TjAM0<SNT`3<kZ40d?FX0<[ZX@34fiL0bMVH06Ia;`24VDh0Z/9h0;_ES02gdHX0]<j70<cWVP3=j9/0
b^FN0<[TX`3?j:l0hOC70>chdP3QlLX0i?W>0>WoeP3/omT0h>o>0>;]c@3eom/0iOO50=7^Z`32h9H0
bN>I0<cTVP3HlZP0eO6V09RdJ@35i9P0bNVM0=7aY@3=kJ40c>bP0=7`Y039hi`0a=^G0>;h^03;gJ/0
g^g205eVA`3_n=/0Vin60:f_U`3Jf/00/[ZE0<[YY@3<jZX0bnFX0=[b^03VnL40gn^i0?Ood@3Wk<`0
ooo/0?KfkP3Qh]00iNJ/0>_UZ@23JRP0flR>03e26P3[n<d0ho700=KhaP1o_9d0g?o50<oVX03=jj40
c>RK0<[OVP3Bhj`0o?oa0?kon`3nood0k>oT0>KZf`3noo400`3noo<04P3Jg/d0emk<0?_okP3gnnX0
o_kd0?oon03ooOX0oo_o0?SZjP1bGUD0oo_c0?onmP3Yi^40koC`0?_oo`3lool0o_oo0?ooo`80ooko
01L0oOOk0?OXj`3on?P0oogh0?3ekP3hmo<0oo;a0?cOf@2o]9@0_lRI0?Soh@3iool0loci0?_omP3`
nNP0h_?60<kO/`3>g[L0g>_<0>Wgg@3don/0m?kc0?WonP020?coo@040?[lm`3ooo@0oood0?oomP80
oooh0440ooof0??fh@3Kgl@0i>^o0>?[^01@Eb40`/RJ0?ooh`3oonH0oooZ0>cdg03lonX0mOoN0?Wo
i02DXhH0Y;:I0:BkW`3=kk`0_]n>0=S]X03GeYd0HGIS06n5PP3Men<0<cLj0?olo`2l^[/0Tkn`0424
K@27cJ/0`NB^0<kRX`3oolX0g<fV06e>B`21JW00o?oj0?Ool`3honX0e>N_0<WOU`3AjYH0fo:Z00XN
001MLSX0_mB?0<CHV@3ion<0n?oP0=CR[`3fom/0kooH0?_oi03Lhl80];JA0:VYP`3ln]40oO_D0?om
gP3ooo<0oogi0<O3`P3?blX0fmSC0>gXhP030?oomP0e0?olmP3lmo<0oo_j0?_gn03on_l0o_[o0?Wi
m`3fmnl0o?oj0?Oln03kool0m_on0?ComP3TmM<0e>Rg0=?SXP3Dhj00BE<O07n6G02MW8L0g=K80:BK
U02o[jl0Gde=06IBD@3ZeM80oo_a0?odj`2_Wj00R7Ek08YfO`3onO/0oo[d0?olk03oo>P0[9^707IU
D`1MCd80TX5g0:VBRP1gF5<0EcPc0?[Sf`3oo?40ooga0?oll@3omo<0llg:0=kDd`3no_h0oooo0?Sh
n03no_h0303oool000X0oooo0>/0d>JK0<gWW@3:j:00a^VU0<GZY`2=]7<0GX=00<GXY03:iY`0a^6D
0=ge^@3`oo@0A8el0;_mk`3ko?l0oo_o0?_on`3eo?@0oo_g0?olmP3oooP0008006MYI03oood0oooo
0?cko`3oo_l0noWj0?kmn03oonh0oooX0?Ohf02[[X40kO:h0=[[Y`3@ij40anNN0<[ZX@3<ij00bN>L
0=ke[`3;iIh0b>ZP0<W[W`38j9d0Ih<i0::iM@3@gjH0P8eO06]eD`35d;00n?oO0?;od`37hY/0d>NQ
0<6mSP24MTl0>R800<6OP`3:[H/0h=fV0=KQW`3Dk:80eN^S0=;PX`3Fh:@0SiMN0:jiO`3<h:D0d>BY
0=CX[@2AXF<0dn>T0=3WW`3?kZ80ao>N0<7/VP3Ekk00b^:T0;kFVP3DkJ`0cnFT0=ObY@38iI<0co2O
0;_MT03?m:h0`>2M0<3ETP2:We`0aMbH0=;[Y`3>ij<0cNJR0<cUX@3;hYh0c^>P0;;7Q03DijD0e^ZU
0=3WX@22W5D0bN2J0=gYY`2c^7P0Yj=V0=WGVP3Qhj@0c]fJ0=O/Y`3CkZL0_]RA0=3OW03Ag9X0LW/j
06Ye<`3AiJ00cnVR0<k^Y@34jYl0anVM061a:P2U]Vl0cMjH0<[NU`39hiX0aNFL06U85@2aReX0cnBQ
0=Wb[P39h9`0SJ1N09FZI@3JmZ/0anNL09S0N@003@00V/VO01aA9`29/XP0Ujb;09FQN`2X_Xl0_nVZ
06FHH01;MdH0fnnn0=;TZ03=fIL0gNZU0<WITP2jch@0an>F0=CdZ03<jZ80bn:N0<_IV`3Bg9d0d^BJ
0<gSVP3CjJ40dnZV0<kUW`32gI00eo:S0<WSV@3Im:d0_MNF0<_SZ@3>hZD0cNJU0<WVY036iZL0b^N_
0=S[_P3Xmlh0g^jm0=?W[031h980c^jK0<WUV035giD0cnVO0=?]X`2;YE/0dnfS0<_WW034hiL0bnZN
0<SWV`34hYX0b>6W0=3Y/03BjK<0f>[00;;2W@1:Ec/0[KNO0?kol`3fn^`0ooof0?Wlj@3Rk;X0fNJ^
0=_/Z03@i9`0`mZ<0<kVVP3Ajj@0dNZa0=Ka_P3HlLT0cN>m0<oJ/03Ig:d0Je/O0>7EX@3@fKh0;30Q
07UjJP3?jM`0N[^o0;;P_037j;40cnbZ0;oIS`3@iJ80bmVX0?koo`3ooOl0ooco0?oon03ooo<0oooj
00<0ooom0:P0oook0?konP3nooX0oook0?[im`3oo_l0oo_m0?oko`3oloD0b[N`0?ofk`3on?80oooj
0?koo@3lool0nOgl0?_ooP3nool0ooom0?kmn`3lloP0d<310?oklP3ooo40noo_0?_okP3?_Jl0[YN7
0=kH]03Fh[80kOkB0?[om`3gonl0nooT0=WV^`3CjJ00a=VF0=CXZ`3iomX0kokE0?_oi03bnn00nOoY
0?cojP3fon80l?_I0?Soh03honX0k_cU0?Som`3iooP0m_oc0>Kad`3Fh;d0e=nd0<kJ[02FWg80XJUh
0=WP]P3cnm@0o_oT0?[oi03eom`0kO[?0;g<X`3bomh0m_oV0=;T_03<iY`0b?>S0<?XX`3Ei[80n?oT
07V3J`3onOl0Zk:l0>c]l@3_k^X0ioo]0;_ok@1gaJl0_nNe0<ka/@3>g9l0oooC09UaL@1fEel0noof
0<SJ`039ek<0b^JY0<g_Y@38k9@0`>2G0;SCWP2/ai00b^RR0<WUZ03bonH0iOkG0?;ofP3AiK00c=j/
0<_F[P3FgK`0]kNM0=[H_`3^j=80f=6o0<Nn]@3omOl0ooSo0?oko`3ooOl0ooko0?onn`3oooP0o?cb
0?_jm@3oo_/0ooko0?oio`3oo?l0oOco0?koo`3loo<0o?oo0?cmo`3lool0o?o]0>SadP3konl0nOoi
0?Soj@3DdYl0in:[05QA9@3Ug;/0oog/0=[Ba`3mm>l0oo_i0?onnP3oo_P0ooof0?onl03ooo<0oogk
0?oko`3gjoD0XiRN0;fa/`3oo?X0ooWg0?ojo`3om_d0oo_o0?O/lP3on_l0onkb0?ojn`3om_80ooWb
0?ool`3mmNP0akFW06MAA03oo_X@0?ooo`002P3oool04`3=jID0b^ZG0<S[V@33k9h0`^bT0;gVY01K
PT<0a>RZ0=?b[P3Nn[00l_o<0>ooi`2>ckT0>gmZ0>[hn03onol0o_[g0?oonP3dm>P00P3oooH0?@08
2`80VIZE0?;blP3no_l0nOSm0?omo`3mo?X0oooh0?ook03Kfkl0d]>c0>7T]@3Li:T0dNFP0<cVW`39
jJ00bn^R0<cWX03<hid0cnJP0=C^Y`3CmJ/0a^RN0<[ZW`3DkjP0b>>N0=kc^P0nDR40g^o;0?OoiP3b
om`0bn:^0<SQW@3Dj:<0Fe0R0=:lU@1YC2X0N5@d09anFP3Lg:00f>FO0<;QT@34h9<0e>VT0=CTX`3J
iZP0_/j@0=3TY`1NLSD0J7Xn0=k/[`3?gIl0dnRS0;cHS@33kiX0]N2@0<_UYP3?jJP0e>f[0<[SW`3?
iZ000P3o0000L`3:jI/0d?2T0;SLU03BlJd0h_Ve0<CIUP2@Yf<0dnZV0<[SW`3BjjL0`mbH0=?ZYP3B
jJD0Rj1M0<SMVP33ei80dnZT08NRF`3Yok`0d]jL0:>UIP31^gl0kNV/0=_MWP3Ci:00c^RQ0;_IT@2k
eHh0NHE305=L6`3Gh9l0fNFS0=;YX`2nfI80a^JM0<KXWP3@kZ@0/[mi09fZI03Dhih0fNZT0<oVWP2m
fi<0PUh/0;F=G03;fiX0bn2M0<oTX@2Q]Fh0Y;U^0<GNR`3=jID0b^JI0<o`Z`1HQUl0MJR70;SP_P1Y
OfX0b=Rd096/M`3:n:d0LZU`03MV>P39i;L0_mRN0>3c/@3ChYl0QIE>0?7o^@3HljH0^]J90<OSV@3@
ij<0eNFV0=STY03DjIh0hON_0<gRW@39gih0fo:^08bWFP29Y5D0`=^>0=;/X`3<ij@0e^j`0<oTX@3<
j9h0bNVN0<CXX036iZD0mooH0?3odP3:fj@0dnRW0<c/U`3=kiT0a>2C0<[VV`3?jIl0dN^Q0::lLP33
gI<0`]bB0<KRU`3Ckj@0e_:W0<OUV`36hj<0b^JY0=?//P3Cj[H0io[<0;o?ZP3Rl<d00P3kon`07@3n
oo40oooZ09bPK@2VZg40eN:M0=k_Z03MlZL0c>RN0<_YX`3:jZ/0c>ja0<ga/`3:jK00a]V/0>3/_P1a
IcH0[ZEn0<_B`00?4@H00@800>koo`36ool0X=Bn0>Woj03bom@0cn^Q0=7VX`3<g:d0n?Wn0080ooco
07@0ooof0?ool`3oo_l0ooko0?omo`3oo_l0oooo0?ooo@3nood0ooom0?ono`3nn_/0lN_]0>CIg`1_
HfD0ooWb0?olmP3onoP0ookk0?_mnP3nool0n_km0?WnnP3lo_/0oOki0?kmn`3mm?D0`K:_0?omk@3o
onX0gNc=0<_F^02^WhP0f/J^0<o<X`3Xm<80mooJ0>ggg`3konP0_LZN0=7OZP3>iIL0e>ZR05U^;@3@
gZT0l?g?0?cog`38dZl0i_3=0;W4W03Ul<H0gnc10?Oog03Eil40b=Vg0<cJ`@39e/80jOKR0?Wok@3i
onX0lOgG0>Odb03>fZP0TYmW0=;N[03Cgk40g>Nm0>3/a03Kj;d0enNf0=?S/P3@hKD0WJf60;k?XP3K
lJH0a_>^0;STY`2jeJ00n?oD0:F/P02MSX/0g^W]04M?DP3alNl0V:VI0=3ooP0mQ780^>Nk0<cc^P3C
hJ`0oooL0=bn_025JVl0kNgS0?CniP3Hi<00bNR_0;oTX@3Am:@0c>fX0<7M[035hJh0_=^G0>Wob`3T
o]L0dN_40>;ob@3Gk;40bMbT0=CQ]P3jon00lO3K0?ook@3ooo40oo[`0?G]jP80oo[o01l0o_So0?om
o`3oo_l0ookj0?oomP3ooo@0oooh0?oon`3oo_l0oo[o0?oko`3jnol0nOod0>gff`3lool0o?co0?[m
o`3SkLX0l?c<0>[adP3emoH0o_o_0?ooc`31]H<0Qg]E0>WN`03oo^l0oogd0?kgl@3ooOX0oook0080
o_oh01L0oooa0?oolP3jm_D0oo[o0?olo`3bjo80l^c`0?omo@3ooOl0oo_o0?ogo`3fl?`0oOOo0?ok
o`3kl?P0ooSl0?_cl@3oo_P0lNgQ0?ool@2TVhX0nnkN0?oonP0@0?ooo`002P3oool05`36k9D0a^fB
0<G^TP35kI@0aNbK09FjM`1HO3l0`N:[0<k]/@2ifIH0eoBa0=?Y^039j<P0>FA909:n/@3Ylo@0UhR=
0?onnP3doo<0o?c`0??/i0051P00VYRI00<0ooko00d0ooom0?oomP3cm^D0o_oS0=[R^@2naiP0h^ng
0=;RX`3?jJ80cN^S0<W[X@38j9l0an6J0080eNZU02P0a^2I0<OYW`37iih0NI9>0<cSW`3<ij@0_mfM
05ak@034hK<0cNRo0<kP]P3Chk@0_lV=07Uo@`3Sf:X0f<:I06Y<:03=ZXX0]9Qa0=[LW@3Bi9X0`nJB
0<OZUP30g980//V10=WZY03PmK00f>n[0=CYZ038fi/0g^R/0<3:SP3Mk:/0c^>N0<;WVP37kJ00d_6]
0<[XXP31gI<0dN^R103o0000U`3DkZD0cn^P0=;^X`3:iIh0dnfV0<3JT`2_bH80SZQQ08NQFP2T_WL0
_MN@0<;LU@36h9T0b^6K0=?RW`1iSTT0d_:Y0<3NUP3Hi:80hnFV06MN8`3KeIT0hnRX0<[XX03:k:80
^]F>09J[IP3FhIl0bmJD0=;SW`3DjjD0b^ZQ0<WYX034hYX0b]nJ0=KWX@3<ei80VJAO0=o^Z@3Kk:H0
_mV@0<SXW`1kEbD0]8aK06Qg=P2GYfH0dn>T09^YKP2GYfP0dNNN0<OOT`3Ckj@0boZL03eW>@003`00
_]k70::i[`29XXD0W;b:0;WTU@2kk;D0YMBZ04ekBP32kkH0bnj^0<[TX`1eQ440U:5K0>;dZ025W4h0
`MfB0<_WW@3:i9d0e^fW0=W`Z03Lljl0cnFT0<[PXP3/ol80fO2X0<?KS`34fXl0Mhe40=;WXP3Ikjh0
c>JM0<KXU034jY<0a_2J0<S]W@35gY`0d^RX0=?XY`3Ek:@0a^RA0<gaV@3<kid0a^JJ0=?bYP3?jIl0
UZiT08ZPE`2EZf80d^RO0=oe[03IlJL0b>:H0=3aX031hY40`nBC0<k]W@2ngHl0a^:H0<?NU`3Dk:h0
f>fb0<cPZ`3CiJ/0hNBM0=[PV02b_gX0g>b[0=W]/P3;iKH0an:e0=3a^P3>lJd0aNfE0<ceV@3aol40
mOo:0?oog037aZP0IfE>0>7N_`2QXg`0_mVd0=;oj01e/Z<0]>[J0?3oi03>k:`0d^bU0<kP[P3ko_l0
o_go0?omo`3ooo40ooo_0?omo`3oo?l00P3oo_l20?ooo`0=0?ooo@3no_`0oo_h0?onn`3ooO/0[Z:R
0?oknP3oo?H0ooch0?_cl@3imO80mOGc0?koo`020?coo@1O0?con`3nooX0oOoi0?oomP2VVX`0g]Zg
0=;I[@34gjP0dNRb0?7/`P3IcJ<0hnJa0=7UZ03=iJT0iO?20;W7U03JjZ`0U:AS0:g3P`2ndYD0f^bb
0=cX]P2<UFH0_LJG0=SR/03Ji;00f^N_0<GCV03@hJX0dN:h0<cN[03@i:T0eNV/0=[/^P3YnMD0nOoj
0?3im03donL0j?O<0<3DS@27We<0f_6[0=?YZ03AiZ/0f^nd0<cPX`3Jkj`0enZX0<gOX`37f:40Ff`h
0<GIW02iikP0aoK80;cNXP3Cl9@0g>jH065L?01[P6d0=THl03Dk=`0i?cl0jooo0:[EcP1WXhL0[=^k
0>GcfP3konh0o_oh0?okn@2FOgT0_:bM0>[_d@3IlM40i_oI0=Sa^P3Jl<80f>_;0=7V_`2fd940m?oC
0=7/`@3?jk/0b>RY0<kXX@3Cj:L0ho;70?Soi03koO80o_oi0?knmP3moOD0oOkf0?WkmP3inoP00P3o
ool08@3gn_40o?oc0?_ok03Njm40hnoI0?7ijP3looX0o_go0?omo`3kooX0mOoV0<oO/P3Rj]/0o?oo
0?comP3CgZ@0en:M0=oU]@3BclH0XZ:609NCI02g/880k^S60=?=/`3ooo@0oooh0?ooo@3nool0nool
0?[onP3iooX0n_ob0?komP020?koo`050?cmo`3enOX0o?om0?OnmP3kooX00P3kool0303iool0noom
0>odl03oood0noKc0?GZj03onoX0C44k0;J]YP3oooH0j^kP0?oooA00oooo000:0?ooo`1A0<K[W@36
k9D0b>bD0<S/TP38jiL0`n:O06F3A`3;j;00b>N[0<WYYP2ogiH0b>:U0=GU`@1ZQ6T0EHEg0>koo`3o
oOl0MW1`0?SomP3dm>`0ookj0000002OWJ00ooco0?omo`3noO/0oook0?cokP3non`0o?oM02/g1`1K
J380b]ZK0=GXYP3?jZ<0bn^R0<KZX038jZ00c^FO0<kSWP3<h9/0cnJP0<CTV`3;jJ<0BE`L0=OZZP33
fIP0cnn/05Mj>P36i[@0a^>e0=OV^`3FgZl0NGI109VFG`3kmlX0lN:k05e6902hVGX0VX9L0=oSYP3A
hY/0fOZY0=KgYP2BZF<0N8e80<gSVP32fI40f>nY0=?XY@3;fi`0f>2U0>gb^027Te<0c^6O0<OYW`38
k:80`N:K0<c/X`3ElJL0b^BK00@0o`0000/0bMjI0=7WW033fhl0d>jT0;WER`34h9H0c>RN0<o[X@30
g980c^ZP0>3l/P020<o[X@260=7XX03Pk:X0TZMR0=CdZ`34i9/0dN2M0>o_/@1GCQ<0f]JI0>O][@30
hYP0anfR0=SbZ`32ei80hNbZ0>Ka[`3<hI`0c>ZR0<3TVP3=lJL0d>jV0>3_[03CgYX0c=bE0=?SW036
fY<0e>ZR0<[XWP36jZ00JDTF0:V5D`3;gY`0UJYW0<OIV`2FX6h0VjQb0=G/Z038hi`0cO6Y0;c]T@2>
/G/0d>_8000:000O=bX0k_o_09nnU02gfId0^^6/0;gY]P0HCaH0NK5d0;gYZP3=l;00^/^70;K1O03A
gi@0Sj5E0<cXV`3:jId0a^BJ0<;MUP31gI<0aMjL0<WRX@3;hjL0bMnQ0<7FT@3Fk:<0cnBI049F3P3F
jZD0d^NV0=3ZX`37jYP0`n^C0<C_U@38kYT0b^JL0<oVXP3:gi`0e>^S0<W[U@38kYL0_N:B0=7fZ02m
gI40i?jd0;G=P`1=HAT0FFdU0<SLU03EjJ40gO6Y0<OOT`36jID0cO6J0<W]UP3>l9T0d?>I0<c]UP3?
ki`0c>^O0<KTVP3;j:D0enjX0=KNT`3CgY80PY990<OKUP34fIh0m?oQ0?3ohP3bon40jOo=0<cXW@39
jY<0^n200=?`W03Ii[40hnBh04Ln4`3QfZh0e]RY0<3J[@2mg[<0=7AJ0;OdhP3^on`0bnZ^0=;^Y03B
i[40n_go0?kmo`3ooOl20?ook@050?olo`3onol0ooko0?ono`3oool00`3oood0103oo_X0oo[g0:jU
X03om_020?olmP220?oel@3ooO/0ookk0?ooo`3koO`0nOkj0?coo@3loo/0o?oj0?[mm03ooo40[ZJA
0>3Q]@3BgjT0`n:O0;gGUP3@d9`0em6M0=?IW@3>iJ40cnZW0<gJY03PkkH0dn>U07b<C@3Ci[T0go34
0<GDZ@3;eZ`0b=6V09BKK`2KXg80e]j[0=;OY`1EHbP0d=nV0=[W^`3@gJL0dMnQ0<cJW03>g:L0i?3:
0?WomP3koo/0n?oY0=[W_039gID0`=^:0<g/WP37iI/0b>>P0=?/ZP3@ij<0`MV?0<kTV`3KkZ`0`=:D
03543@0_B0l0]N2c09_5U@2/bXX0bo2@0<3LQ@1GF3H000h00=3Ob01/M6D0Jg=e0?Coo`3Im_80DXQh
08RgY`3`oo`0mOok0?Gom`3oooP0`:NP0;fWVP3oonX0lOc/0?Sol@3`omP0nOoV0<gF`@3JiLL0go6e
0>_naP35fjd0c>Bb0=7^Z`38hYT0e>ZZ0??of`3konl0o?om0?koo`3ko_L0n?kb0?col@3jon`0noo/
0?Wll`3nooX0n_o_0?Wok03`om/0dN6l0=?R``3Wlm/0nOoc0?gno`3nool0n?oc0?CohP39fjL0dMnl
0?;ii`3lonH0gn^]0=[SX032aY<0>SPO05MH<03cmlD0jNbm0=KJ]`3Wj/l0o_oe0?Wjm080oooo00X0
oOko0?goo03noo/0o_oh0?konP3inoX0n?co0?WmoP3koo/0nOod0P3ionl03P3hooH0m_oh0?Sol`3h
onl0nooa0?kol@3ooo<0hm7=0?oel@31[jl0oo_j0?konP3iood0o_oo403oool000X0oooo0580b>N/
0<[XXP3<j9/0d>RB0=7WU@3Qm;80cMnS0<3EW@3<jJT0c^nX0;_NSP3=jIl0eMbb0:BZT01MOWL0CH9l
0>koo`3oo_l0gLcB0?koo`3bo?d01@8=0?C^n03km_d0oogo0?ooo@3jno<0e]_409ZTPP3Gj;80enV[
0=_`Z`3Dk:00c>JM0<OYW`35jIl0aN^P0<W[X@3BjJ<0cN6L092QG@36fYD0cN^S0=3VY@3:ciT0fn>X
0<cLV`3CljX0_>:I0<S/[`3El[`0bm:X0=?>Y01OAQd0]JAi0<_F[03ooml0OGAE0;FOQ`1YESH0fmjY
0=;PXP3Jm:/0gOB^0=3LWP3?fi/0aN2?0<kYVP36h9L0gO:]0:>cLP3Yk;<0f=VP08J;D@3Ag:00g?Nd
0<KUW`38jZ00e_J[0=3/X@2ldh/0b]nL0P3o0000VP3=fih0b]VF08fNCP39ghd0`^:F0;kNTP38ii/0
`N2D0=SgZ`3?kZ80/<n30<_ZWP34hiL0_mnC0=K`Y`1oRTP0eNZU0<g_Y@33iI/0c=^H0=OGV@2MTeP0
e]BG0=[VY034kZ80ao>V0>Ci]02nch/0d=^I0=kZZ03BkJH0^n6F0<[dZ039kj@0`=^D0<;7Q`3^lk40
f>jU0<[RV039hiX0d_2V0<C]W`2ljid0U7e70;RMJ03>jJ@0f_F`0<;MUP3@j9X0e>fJ0<3NQ038iX`0
c>nE0;g^W`39h9P0e>6[03Y0<P2R]J40X[nY000>00001P00d^Ve0;KIU@2/l:L0@Ha90;Ga/@2dhZ80
g_6_0<oHU@3LiYd0c]b?0<CQT@3>kj00d_NY0=Sn/@3;kJ<0foRf05Mc=P067@00a=VP0<cQWP3=hIX0
d>:H0>Of/@1=G1T0b=RJ0<CLWP39kZ40a_2N0;gZS`31jI00c^ZM0=G/Y03<hJ00d>NS0<WYW@3>ljD0
boBU0;OPT@3=lZ@0`mnD0=3XWP3@hIX0cMfF0=KVW`3MjZ@0g>bU07jDC02ifY<0a^RN0<c^X@3DmjD0
an^D0<?YTP33jI@0b^nO0<kcY@36k:<0a>FP0<;HV03OmZh0`]j90=?aV`39iYH0aMbV0<WK/`3VkmX0
oOo`0?Sji03QjlH0c^jU0=_i[`3Kkk@0h^F/06M?4`3onn<0MFaS0=?NeP3;dJl0KJbA07>gZ03]ooP0
c^nj0=7_Y@3AjJl0m__n0?cno`3nool0oooX0?oojP3oo?l0oo_o0?oon`3oood20?kon`2>0?oonP3k
n_D0ooWa0:^RV@1GBT40nNSN0?okl`3oo?H0ooSc09fET`3dl>d0kno_0?koo`3lood0nool0?;ilP3j
ooT0o?of0?KfgP2YY8@0embR0=;SW@33jYL0b>VH0>;YY@2n_gd0fnNO0=WeZ02if8`0d=jQ0>3`/P3:
fJ80d=jY0?Gon03boNl0nooc0?goj`3_lmP0e=Rg0<O<X`3Gg[80o_oF0?coe03CgZ@0Ifd]0:R/K`1>
DAX0jN_30;bmV`2o`:00kO3C0?cohP3`m]80];ZD0=3OZ038jIP0anfF0<kdX@3>l:@0bNNM0<STV@3>
iiH0h_VY08BHD01AHQh0b=jP0;oVY@2ggJ@0bNN[0=GTW`38mZ/0_^^b00TE2@1?HdL0d]^T0=kX]P3^
ooP0_<W207J2PP3Km_l0TKW307V[/P3Qool0noom0?oomP3mm^H0QGU[0>cJd03on_l0oo_o0?ool`3o
oOP06A0;06IOC`1HFbH0injh0?3lc03LkKL0^<j50=G^ZP3>iJd0n?o/0?SonP3iool0l_Wo0?7kl03b
onL0j?[D0<cTZ03?jZL0e^710?7ih@3ion<0jO[>0=?Z/P3?j:h0cNB`0>?eb`3honH0nOob0?conP3h
onl0m?oS0=7UZP3Ik:X0d=nJ0<[FU03MijX0EETV05=E9038ahl0i>BT0<cQZ03Ro/d0jooK0?;ojP3h
ooX0m?[f0?coo`3ooOl0ooco0?oko`80oocm01H0o?[m0?ono`3oo_l0oOol0?Gnj`3Njld0bMZ^0=7S
/`39gk00dNNi0=W^]P3Dijl0f>Ja0>OX`03Cb:P0Sg=W0?ofl@3omO/0ooOo0?kno`3_nOl0o?oo403o
ool000X0oooo0>P0b>N[0<[XXP3<j9/0d>RD0=7WU@3?hih0b=bM0=kc^00/B@T0CVlZ0<?UV`3?jZD0
hNVj0:Z`SP38h]L0CX=k0>;oo`3[n?h0jLkE0?Gin03gool0100;0>CNj03oo_l0oook0?col@3ionT0
n?oM0:FbQ03DiZX0b=fJ0<_SV@36hi<0bnVO0<[/XP39kZ40anbO0<WYWP39giL0g>fW08JGD`2S]W@0
b>6M0=3RYP3WiK`0>CX>09JPK033gJ00i?o70?3ofP3_omX0oooM0?ghdP1[EB`0h=6V0?Koe`3oomd0
8A/008McF01lK4/0f=fW0=WYZP3=jIl0an6J0=GSY@3IijT0e^fU0<ONUP2P]G80TJAR08VGF@3cn;h0
cM2G0;FmP@1hQTP0_]VD0<_]X`3Lok@0_mnC09>YH03BiYl0cMjJ0<gOX@3Jk[40c^>R0=__ZP2@XE<0
fnbN0<_RVP3JlJT0c>JL0=[dZP37hiP0c>^O0=;aY@3;ii`0b>BJ0<[VW02:XET0go>/0<SRV@39jil0
b^bP0=SYX`3Qj:D0MG<f0:BYJ@35eY80`NZN0<7[W`33fY80[[mi0>7]Z`2kbXL0bNBO0<[^YP3Do;D0
fonj0=ki]P29TEH0];Yn0=GYXP3Ek:@0cNbP08^ZGP33j9/0_nVM07]W<P2SS5P0^MV@0<_[XP39jId0
b>VB0<SYT03Ali@0c?2@0<S[S@35lJ@0b>2D0=SXZ@3Hi/d0NiEj0<CWd`3YooT0FFaV0<OO[`3<k:T0
^_2U0;[b/@0CB@d0`?2f0<SQY`3FiZP0eN6I0=?TU030hHX0d?>O0<7VUP30hYP0bnZT000?0020V5`0
XKIn02e0203>hJ40f>VU0<kRVP36fY<0dnNR09JYJ@2hc8d0cNNP0=3/X@36iY40bNVF0=O_X`2kdHT0
T:=S0;;5P`3>iIl0bnNM0;oVU@35kid0`nRH0<_WW03<iY`0d>BM0=SYX`3<fiH0eNBO0=?RW@1AIAh0
c>fV0=;c[02mgiD0dO>Y0;kPU03<lJ@0a^^N0<W^X@37jId0`^JL0<o`Z`3BjZ`0bNFK0=cmY02hfgl0
eoVR0<[WY@3>iK40h>gA0?[oj`3dmND0emc50<CMY039hj@0cNJT0<cGU@3ZfiX0oo3K0?ojn`0100T0
`kZ[0=gonP1PW900^nOJ0;_V^`3<kjl0an:]0?Soo@3iool0nooo0P3lond00`3oo_l0oogo0?oon`03
0?oon`2;0?oonP3oooP0ooof0=K?a@1nM6X0oo?Y0?okl@2ER800MfaV0552?`3onoX0oook0?Smm`3k
ooP0kOSZ0=_Ze`3^mn80o?o/0:BZR02?T6P0f>:U0=7UW@35kIL0`^FC09:IEP1kNcd0S9EF09nhM03B
l:X0/L630;2oQ03IikH0mOoG0>ggn03iool0kOC]0?oom03dmND0ooo]0?ooj03oon@0o?oL0>gkbP3F
i:T0d=ND0=SJZ03If[80ookU0?ooiP2d]ID0_/>J0=gR^@2_]XX0KGE60=_]/@3:k9l0bO2M0<?ZV`2k
h9<0b^ZO0<g[X@3CkZ40a]jB09>WG`14E@l0d>ZS0;o[X039jJX0cN>U0<[IU02aj:@0HYaZ0008001[
Of@0eNB[0>CmaP3Kool0hooo05IbL`3gool0j_oo04^5R@2mmOH0l_oo0?;dk`3ooo<0`Kj_05i>@@3o
l_/0oo_o0?ojm03on?P02`0003`d9`2WZWl0ATLK0<gGY@3;gJ40h?RZ0<kTX`38g:L0m?oU0>_hi03Z
mNd0kOW_0?Ook@3gon@0iO_<0<CQWP3Bl:P0c^6c0=o_b03]om00h_No0<cQYP39gJ80dMn/0>G`aP3n
on<0ooka0?oomP3oonl0n?oN0=;MX@3MjZ80]lEj09bYI01IHRT0`/VC0=SPY`3Vk:`0eM^M0<oX[`3:
j;@0k_oP0=O[c`3aoO40nook0?_ooP020?omo`0I0?oko`3oo?d0ooco0?omo`3oo_l0ooom0?Wll@3k
onH0kokC0<SMXP3Jlk80a^6N0<[TX`3:hil0c^>P0=g][P3Lfj/0PGMC0;NJRP3okNL0ooGj0?o_mP3n
o_l0lO_o0?coo`0@0?ooo`002P3oool20<WZV@80bN^G03X0bNZI0<?SU`37ii`0c>^W0=Wg^`2YaX`0
2R@009N^PP3LkKH0QIAK0?7oh`2Ta[P0K;F^0=_oo`3^eM00n?c[0?7lkP0F21L0_[S20??nl03gonX0
c>F[0<[SX@3:gYL0YKI_0=kbZP3GlZD0bNRH0;cST035jY`0`^:F0<GTV03@jih0e>bP0=c]YP35eY00
cmnN0>Sh^@2caHT0h>Vn01L@002XWiH0oog/0?Gnh@3ionP0j?SM0?SojP3Egkd02Q400>[/^P3MiJ`0
f^f]0=?HXP1_J3X0Xi1X0:>AJ@3Hh:@0d>JN0P35k9T04@38jYd0c>NT0>[fb03;ejT0o_oF0=CNZP2`
^H@0KW`o08NGF02dcXD0_M^A0<CYV@2khY40f?Z]0<?MT`1GHQd0i_2[0080o`000340b>ZM0<;YVP32
hYH0e>RP0;S3O`2BSED0fMRO0=7LVP38fI<0d>^N0=3/W`38i9T0d^RP0:RhM`2f`8@0aMFD0=Go[@3;
lZ40a^NH0<;NT@3Dk:80a]bC0<[RV01VOS@0b>:I0<cXWP33hYH0fOZ[0<cXW@2:VEH0f^VX0=[Z[037
g:40h_o50=ci`@3Jml40iO_:0>3a_@37ci<0eNZU0<k]W@2^bGP0d>2I0;_BSP2<MdP0Vh]H0;OPTP39
jY/0b>NG0080c_>U06L0/mR80;kST`3=lj00co6M0<KYU`33j9/0]^:W0560E01IT7d0<6QK000c9P1f
W7L0JhaG0=7NV@3OfZ0000d0000E0013MDl0S[670<oTX@3?iYH0a>V:0<K]U03<kil0c^:W06]nAP2K
[7D0dn:[0>3Y/P3Cg:<0dM^O0=KTYP3EkZX0bnVQ0<?UV@3AkjD0e]nN09ZFF@2VX680a<210;fmO@3T
kj/0dN2M0=KRXP3[m;D0P7i50=kSX`3<iI@0bnfG0<g_V`3>kJ40c^ZP0=C]Z@2cbXH0_=2;08^OFP3<
gIL0dNNN0<c]WP2jfXl0cNfT0<SUY@2idYP001L00=cc^`36fj80fNjc0=3UY03AiZ<0e>ZR0<CLTP3C
mJ40aN^D0;[RRP32k9H0a^nP0<_[ZP3Ek[D0looH0?_oh`3oon@0n?oF0<?VU03:k9H0bn:D09:5H`3B
]j`06@0700l01@31`l80k?on02IgI00bNfL0b_oY0:WI_`3Jo>@0i_o^0?7on03gooP0mOo`0?ool@3o
oo@0o?cl0080oocm0280ookk0?SglP3io?D0o_oh0?oomP3fknL0ZIJ@0:ZCR`3gi=D0oo;U08QNG`3=
YJD0m?KX0>ooj@3gonH0j?oC0<W`]`3<gZ80fNBX0<cPX@3Lj:X0dN:N0<kXW`30jI/0c^fW0=[JZ03R
fK80m_3F0=cUbP3boml0eNj]0<[OYP3Bh;`0o?o/0P3nool0J03inO/0noWl0?Wfo@3ak_D0oOco0?ko
o`3kond0m_oQ0<gM[03Ih[<0oooc0?Kfn03ooo/0n_oV0>Wba`2`_HD0YkF40<OHXP3Ai:80a^290<WZ
X`36jjD0a>ZO0<GZW@37jId0a^RN0=7[ZP39hZ40f>bT09FXF@3>iXh0aNjB0<OGV03Ag:00dnRS0:k`
Z02[l[P0BG1M03i<<`3=jL00[NW501Z>SP0NR8P0J[Fj03LfAP3ilol0boGa0460M`3Iool0goco0?Kh
m`3_lN@0k_?L09FHP`1QFTX0L4Y7089DE00C1000OX1e0?Ckj@1>BC<0g^Fa0<kRV`36k9D0bN:P0<kP
YP3Rmk`0e>bb0=7Z/03AkK00jOo60=gf_03IlKD0k_o80=3U[037iIl0Y/Ik0;?=Q036fiH0g>BY0=kN
ZP1aHd00[YUn08ebG`3om?40ZX220?oVg@2BNV00k>2T05YB4`3;bY`0embd0=OO]P36fiP0cnJN0>Cm
a03Ollh0aMf]0=S_^@3Ijl40dn6n0?Wmk03noo@0oooh0`3ooo/0603noo/0oo_o0?ojo`3oo_T0oooa
0?coiP3=h:P0d^^Y0<c[V`3;jiP0cNjG0<k_V03Im:L0a]bD0=7QX01jMdX0[J=o0?o]fP3onNl0oo[h
0?olnP3nood0nooo0?kooa00oooo000:0?ooo`030<WZV`39jYT0bNZI0080bNZI04P0dO6U0<KVV`3=
k:H0`n6S0=Kd^02E/7/000`009>RJ@1ZNCh0jooJ0=3ah00iOgL0bOcg0>cGdP3noo<0noof00X01`2f
/;`0mOcd0?Coj@34g:P0`m^M0<SMVP35fI@0]/Z50=7[XP37iYX0`^VH0;cQT`3BlZH0d>nS0<cVW03C
jZ80d^>O0=;RX@2<W5d0J7Pj0=W[[`0j@a@0GUU30>?Lb@1SHTH0hNW20>SebP3]o=D0i_;<0=kU_01J
GC00e=>M0=CHW@36fIT0e=VS03`h2@1TDRX0`;680=SPY03@iYh0aNbI0<?]V@38jYd0c>NR0?Kod@2M
ZgP0ZKJ108JCG@2NZG40e^BW0<cOW`3=iih0eo>Y0<oaY03@l:@20?l00003051V7P3o0000o`000080
o`000680dnZR0<kUW@3Aj:00d^>O0=KGW@1:D1@0e>>P0=;VW`2mfHh0cNVN0<_WW02CZF40UjYX0=OQ
Y@3Qkk40^=R<0;oNTP3Mmjd0bN6G0<WMUP3IkJH0b=jE07jFC036h9H0`mnD0<GTV030hYD0d^jS0<gN
VP26UE@0amVK0<oUY`3Bk[<0c>V_0<cX[P3gomP0nOoB0>G[[`3EjJ@0anBD08>LB`3RkjT0k?nn06E=
7`2SSed0b>ZN0<WTU`3?iIX0a^:H0<?MU03Mmjh0f?:X0<WSV@3BlJ40d>nO0;gOTP3Ank`09eDT0:OM
a@2ZhLh0a?OT049X@`0bDR40d^6N0>OX[0017000F7mB021@:P04:080dn^_0<oVWP3:jIT0cNfR0<gZ
Z03<h:d0;3h:0>Gc_P3>fjD0dmZT0<gEW02OZFd0h>b^0<7HU03BkJH0c>bS0<?QV@3Dhj80c]:E0>7S
Y03Ff9T0inf]0<?DT03Bij80d>BO0<CCT01UIRX0e=fL0<cSV`80b^VM0<<0bNFK0<OSV@32g9<0iObd
096WGP3Bj9l0_]>80>Kn]036i9`0aN>K0=CbZ03Ckj@0f_BZ0=3WX`3EjZT0f^^e061`@@3EhK/0i?38
08>DG@17Fah0c^bT0<7SU`3Io[00`>NH0<GZW@36i:@0b^6Y0=KW^P3IiKl0dmbm0=;Y]@35k9/0bNnH
0=[eYP2LUg40NfIC0?SKh036/kL05adC0:>mY02Jfk<0?hEY05VVWP1d_kX0SlRe0<Kbd@3^on@0h^W7
0>SZe@3eloh0o?_o0?koo`3oo_l0oOOi0?omo@3jnO@0oooj0?kon03oooH0oo_c0<:`[02jYYl0oo__
0?ojk@1gEE<0on;O0?ool03`onH0hOK?0=Oa`@3@lkT0bM^M0=o^[@35gI<0gNfT0<kRVP3>j9h0`NVP
0<?QX@3/j/40l^C70?G^f`3Rj]D0mooV0=Kc/@35gZ@0d>:j0?WojP3ooo/0oOkh0?oonP3oo_d0oogo
0?ono`3kn_l0o_oo0?_om03eonP0bMR_0>K^a`3oooP0oOco0?koo@3jonP0j_;;0=;OZP3>fjl0d>2c
0=SY/P3@j9X0c>bQ0<O/WP36k9T0a>ZE0<S[V@3:k9l0dNbW0=?/Z03:gYH0S9m@0=_aW03>l9T0h>VX
0>?WZP3Fhi/0]n^P0;G]/00X@2P0<2`?0=;J/@1eV7P0H;Vo0<Soo`1KV9d0Zko609FLXP3KmOH0boSe
0;_gm`3Hool0o_oo0?_jm@3ioo40o_o_0?oll03om?40oo[c01090@1lN6l0ooo_05IB>@3Wgjh0gNBQ
0;kYT03@lJX0c>BV0=C/[P3<iZT0bnFX0<KNX038gZ00dnF[0?Gob@3HhjT0K7Dn0<oTW`3BjJ40Kh<l
0;;1OP3Cei`0emJP0?SY`P3njLX0onWC0?oPe`2JLfh0ooWV0:B@K`3Jd9<0gmVK0>OX`03=d;40i>_<
0=7Q/03Kl;P0mOoQ0?;ok03Cj<40i_c=0>Wie03Njld0n_k`0?oon03ooo/00`3oood0603noo/0oo[o
0?oko`3oo_T0oood0?[ojP3=g[80cn>`0<WQX`3:i:<0cnZW0<oXYP37g9T0g>b]0<cGW@21OUD0d/VX
0<BaXP3on_40oo[j0?oln`3nool0nooo0?kooa00oooo000:0?ooo`030<WYW@39jY/0bNZI0080bNZI
03T0bn^O0<;RU`3Al:X0_MbI0<?QX@3Ak;D0b=j_069a>02@WV<0a]Rb0<;Ob`0gMVd0eooo0;2QW03k
oo00i>cO00X01@1oMhH0noom0?Ool03Dk;X0cNF[0<kSXP3NlK40F6/Y0>Ko^`2ng9@0e?V[0=3eY`3>
kZ80a>>G0<cSW@3>hj00fn^/05=S9@2@Wf@0g^j`0=SZ[03fol`0oooT0=kK_03YjL<0BU@O0=CQZ`3E
hZd0dmn]0=?FY`3BdZ00G5LM0>CVY`3:gih0j>ni05=?801XERh0Q7M=0=OQY03?iYh00P33kIT03038
jYd0b^RR0<GHX01?H2T0_ljE0=SW[P3KjZl0e^JW0<oRX03;iIh0cNVO0<CTV0P0o`0009`0c=FB0=o/
Y`3;hYX0bn2K0>K[/@1DGR40fNfX0<;HT03Kmj`0d^jS0<CPU@22Ue80g>b[0>K`]03>fY`0f^nZ0=7V
X@3@hId0b]^G0=7PV`3?gYT0d>BM08VOEP32fY00b^JK0<o^XP3BmjT0]=>70<WMV03Hij@0enZZ0=W_
[`30g9l0a^:U0<OPYP3Gj[<0e^>]0>?Y[@3@i9l0e?6Q08^RDP3>fI@0dN6P09QkC`3TbIX0anFK0=CY
WP3Hj9l0eNVT0=OZZ039fYH0a]NC0=;QW02nfH`0cNZJ0=GdYP35k:T0T;^307BZR032n=h001400;KL
]`1]SEh0g_6a0<cHV023WV/0EGU=04]gE00/E2l0^mZQ0=Sb/`39hYh0d^Z/0<[S[0003@00PiES0<WF
X@3=ej<0DeXV05UN:00R:P00Uj5U0=S[Z@3>ij<0bNNO0<[XXP3HkJX0g^Z/0<oIVP31bh`0i?>b0<oV
X03Ak:D0foF^0<oSWP1]MSD0fN>T0=K[ZP3>ijD0c>FQ0<cVW@3>j9l0an:E0<?NT@2kdhD0g_JX0<gU
U`33gI<0bnJQ0=3[Y03>jYl0a]n>0<oXU@3;hIP0bmjL096MK`3QjlH0o?o]0?kok@3Likd0c=V[0=3X
[P34hJ40^MRD0<SYXP3<kJH0b^BW0<SOZ@3<g:l0bmNa0=CQa@3EkKd0ao2Q0;oVT`3:jI/0gMb`0>3B
^01;=S40j]gE00H?00004@00^NO00:cTb@0ZLfX004Y20465KP27_i`0Y<nT0<kR_`3Dh//0mooo0??m
o`3kool0o_oo0?SbmP3lm_P20?oon`290?_nm`3oooP0ookh0?oelP3onOD0l^7G0?okl@2>MG00ooWc
0?cnj@3Zmm/0`mf`0=?`^P38iZX0i_Vg0;g>Q`31gHP0f>jK0<oTU`3@k:40a^^X0<KSZ`3dkll0jmc5
0?onk`3ioNh0mooZ0=?b[P34hZ@0c^>h0?Ooj03no_@0nOW]0?oom03mn_D0mO7`0?omo`3lnOl0ooko
0?con03eond0d^2o0?Woh@3ooo/0oOko0?cnn`3lon/0k?KA0=KS]@3Pk<@0amJ_0<[J[@3=i:00bNVN
0<S[U`37kYD0a^fD0<O[U03<kid0an:K0<GNW02I[FP0E6DN0=3VU03<k9L0ooo60?oo`03KiYX0_>RK
0<;`/03Rkm40/JB20>GP^01]P680K:ng0=Koo`2mk_<0VKRj00031`3hool0kOoo04B2P@2>`L@0mooo
0>gbkP3iooH0noW/0?oklP3ol^h0n?7W00020027QGT0oog]05a@=P3Vf:T0h>FS0;[XT034j:00aMnN
0<[TX`32g9d0d>RZ0=?YZ@3=gIl0gNR^0=;JW`3Zjk80H5lY0=STXP38fI<0Uj9N04M@3`3Lg:00knZc
0<bmTP3nj/D0oo_M0<b]V@3;ZY/0ong@0=?4V`2e[g<0d]2E0?ooh@3oon`0m?WU0?;og@3doml0n?o_
0?Soo@3`on<0m?oP0?;oh@3eonL0oooh0?oon`3oood00P3oo_l06@3oood0o_ok0?oko`3onol0oOch
0?gom`3ioo00fNK80=;R_P3Ai;L0d^Fg0=7S/`3=gjl0c=VT0>;[]P2LXW80ViMd0=kD^@3eiMP0oo_c
0?okn`3oo?d0o_oo0?coo`3nool0403oool000X0oooo0P39jIh30<WYW@170<SXW03Gmj/0`^:G0=3`
Y`3<jjD0e?6a0<kR[@1cP4P0e=nU0>?ba`2ec[40a?S[03iYH02UY:80jo?X0?_nm@0>00<0ZIj/0?Oi
n03ioo<0kOoE0<cSZ`39gIh0f>Z/0=?UY`2F[6/0Z<=n0<[/X039jY/0d_6U0<SSW02`a8L0PI9K0=;P
[`3Fi;40;C`509naM`3Ai:@0noo?0?3hb@2k`Xh0QHmB09^YG03@gY40gNVQ0=3IUP3UiZX0emFJ0=3:
S01ADa80_MJD0=WT[00`;`00VHaR08EiC`3FhZ@0cNNN0<?]V@32kYT0a^^M0<WYX039i:40e>nZ0<WP
W03FkJT0c^>P0=GZY@3JkjX0d>NQ0<ONUP3=iih0103o0000o`3Dn:h0o`000?l0002k^G`0ZJ1U04U7
2P3>hYd0e^^X0>;`/`1mSDh0NHa:08NLE`3GkJD0e>VT0=W]Z037eYD0eMnR0;VnQ03Hfj80[:]e07Ed
?P1fMch0X:5W0=SNX03Yl[<0Q9=>07:6?`3Ejj80c^RN0<SXW031jY`0doFY0=?XX`3LkJT0F6`W096X
HP3@jjH0_]VD0<7HU03EiJH0e^:T0=o[[@30fY<0`=n?0=C]W032c8L0UJAS07MF:`29JS`0QYaD08fI
D@3XlZ/0/[in08jHF@2PYVX0e=RM07Ad>03<g9/0b]jF0=7XVP3<kIh0R[9[0;3R[`2=`9L0_>k;08>Y
PP3@klD0a=bR0;WGU`3Ck[/001D00;;E]@1KRF@0a?2m0;OJY02[]hD0_/ZL0=GT^`3Nmll0kOg>0>_c
`02DVfP0i^Zg0=oR[@3/lKT0Z;1g01l]002FZFT0f>f/0<KQWP3<k:T0d>j^0<_UY02@ZFP0H7Xi0;KG
TP3Ook/0bnfQ0=?_Y03>giP0g>^X0=KU[P3GiZl0eNN[0=3VWP3=hiP0`]j:09:^FP33hi00dO2R0<GS
V@3Imjd0a^:E0=3/W`3?jYd0h_Z`0>Cj/P3Wm[/0f>F`0?7ie03nonP0cm730?ool`3ooN`0o_oZ0=7K
^03Wm//0hO?30=W`^03NmKd0go?20=o`a03Wlll0iO3B0?Ool`3^on<0b>n/0<O]Y03?kZP0kOC10?C`
bP1QEc`0bLFX0>_jc`3HjLL08R/Z0007001CId@0e>k90;;N``2dj]X0M[BY03Z0MP0UJUL0BhaR0;3V
`P3bool0lOcn0?ono`3ooOl0ooco0?Sfm`3nood0oook0?chm@3omOD0ooWg0?olmP3Tc<P0oooc0?[i
i`3hn=`0l?SC0=7b^@2ifIP0h?2_08bNDP2V_f/0cO:;0=3[SP3>iYX0c>NT0<KX]@3=i[l0ook_0?WU
g03on?00oood0<GE^036jZ80bn^Z0<_R]03gon@0ook/0>k]f@3Bck`0j^KK0?Sck`3onO/0o?Wo0?om
o`3lood0nOof0?Wok@3gonX0m_Se0?coo`3kooP0o?o]0?7mf@3homX0m_oP0?Wok03iond0enRn0=7/
Z@36iY40bnjD0<g`U036jY<0bnbM0<cVY`3;hZX0`=6M0;?0R`3Eijd0bNVX0=[ZZ`3Ii:80cmnD0<?/
X030jZP0o?oL0<>hR`0i;`/0<CTR04EaO01DNh80i_oo09^c/`3iool09R<^0?Soo`2nm_L0GZ:Q06fI
VP3Rnol0koOj0?oem@3onoH0n?_d0?Cfl@013P@0QI200?ohh`00:@1aC380gMJO0<oSV`30jY@0`^:G
0<7LU`3=iZ80c^FQ0=?VY038eiH0e=fN0=;CU`3bl;D0^:ee0?;S[02MW5`0c]>@0>KYYP3Ti:@0<Bl0
0>KTY`2LUEl0W9EQ0=gCXP3]h;@0h]>Z06eW=@2KVV80QXM=0>CV]03fn^<0o_of0?_oo03go?H0nOkh
0?coo`3noOl0nooh0?_ol@3looH0o_oj0080ooko00D0oogo0?ono`3oo_l0o_ok0?konP020?ooo`07
0?cno@3lool0o?om0?_on`3eo?@0mo[a0?Skl0020?ool`07089lI02GT7@0h=S10?onk@3klnH0kNKN
0?onnP020?onoa<0oooo000:0?ooo`80bNVP02l0bNVN0<WYW@39jId0_=b@0=CdZ03<k:00b^ZO0;kN
T`2lfIH0aMZR05MR:P3PjK00UJ9d0=O/b`3Rool0C7A/0?7jn@3^n?00m_Oa00/0002OTid0loG`0?Wo
k`3comL0c^R[0<kSXP3KkZh0fNbZ08ZOG02<YUl0dO6U0<SYV03Ckj@0a=jG0<3CV`2Q/Wh0f>>h065]
?`0gAA00VZab0=?XY`2Y^gd0Y[Ao09>QI02M[VP0i?NU0<;DPP020?l0000;0<G6RP3YjJd0/:a]07=h
=P3=j:D0d]nW06Y/>`2RUV`0THQM0=CRY03=iih00P33kIT01`38jYd0bNVN0<SVW03?kJ<0cn^Q0=[d
Z`33fY800P3o0000103=hi/0h?F`0<gTWP38fID20?l0002Q0=Cb[02ngIL0d^fX0;NmO`21Od@0f<nF
05YH7@2X/W<0bmZI0;c:S03Tl[@0e^JU0=[ZZ@3Dhj00hNf]0;k8R@3LhZ@0dmNL05aM8`2MVV<0ZYi^
09fCHP2ITel0I64Z0>3TY`3?eIL0D5lJ07:6?`3>i9/0b^FH0=[j[P32k:00^=bB0<gSV`2kchP0Ig/d
0:VoM`3Hm:X0cn^Q0=gd[037eY40f^JT0=3SX`2lg9<0gOn`0<WYUP3PkJL0cN2N06i?8`2[Sf00N8m7
04QE3@2>VU80[l1l0<cKV03Fh:40i^b^05]L8P3?gJ80f>NR0<_MT@39iY80Gh@f0;[Z/01o/H00^>S0
08>WP@31gK@0c>N`0<O^[`2nf:P05bd60=;ad@1YUg80]^Jd0;[OZ`3AfJP0f>2a0=gZ_P3[omL0l_o?
0>?/]`2b^HD0aLVF0=SKYP2X[GD0jo>j05YU:@1_Od40Ffh^09bgM01FNCL0CVh_05Aa<@1BJR`0DV`]
096bK@39kJD0b^bP0;kJS`3KkJ<0amJA0=7NYP3>fj<0c=bM0=7UW@3Ek9h0Z/Ib08:MC032hID0cnfU
0<[XZ02mg9H0co2I0=;bW`3?jj00a]jR0>Ch``3gomh0nOoQ0?;lf@3kon80_LBR0<oD]P3onN/0ooo/
0?ooi03lon40nooM0?Goe`3hom`0nOoQ0?WoiP3kon`0n_o`0?Oon03aonX0bnbe0<OWZ03<jJT0jo?0
0;nmU02ARfT0inO10<_GY`2kbj@0[[Vc0001000B2`00ZjJC0=k^h@3Al^L0`_KY042>N01J[X`09Ga7
05>JKP3]ool0l_oo0?koo`3oo_l00P3ooOl0Q`3nool0o?cj0?ooo@3oo?d0oogk0?olmP3Oal<0oooa
0?_ok@3blm<0k??:0;cPX030hI`0gnZV09NZF`3Gli`0bo2@0<_WT03@ij<0b>6W0=7`a`3/on80oocc
0?cUg`3omNX0oooa0<oN_@38ij<0cNZZ0<gP/P3ion<0oo__0<c9^P2b[9`0`kfa0<_4_P3CcLd0kngb
0?ono`3looP0nOoa0?WojP3honX0h^SN0>kek@3donh0nooX0>gle@3QlL@0j_WB0??oi`3fonh0iOCE
0>7h`038i9T0b^VI0<c^VP37ii/0bnZT0=3X]03?iKL0fnO30<OA[P3BhKP0b>Rg0<KMY@36fYd0cNBP
0<7^Z`2kjJ/0k?oC0?3ca028RFT0HG9P00Te@00O@4D0YKfo0>[hn@3Ulo@000H;0?7oo`3Wool0[]gS
06jQY02QbL/0l_oo0?olo@3ooOX0moom0?koo`085@/0EfAC0?ocf@1fDcD0g]nS0<[RV038jIP0e^fU
0=GZY@3Cij80bMfH0=SWY03Dh9h0jo6a0=_MWP32`8<0YYeR0>3DVP2^[F`0f]fJ0=cOW03Mh9d0D58A
0<?5Q031`h@0IFHZ0;BeN`2LVf<0_Kb6092AF01BEQ/0];b30=[R/@3nond0mO__0?_oo03cmoH0n?[i
0?koo`3ooOl0nogh0?con03ooo/0o_kn0?kko`020?omo`80ooko00@0o_oj0?kon03nool0o?go0P3j
o_l0403iood0o?oo0?coo@3ooo/0oooj0?onmP3bjN80JE]>0<k0/`3oo>l0oogd0?S_j03[j><0ooom
0?ono`3oool20?onoa40oooo000:0?ooo`D0bNVN0P39jId20<WZV`0M0<WZV@3:j:00d>>[075kAP3E
gZL0UZ9`0<KGZ`3Qo^`0Y<O00>Woo`2[^K`0bLW900d0001`IF40kO3K0?Cog03Fl:l0c^ZP0<CLT03C
j9d0b]jF08^QF02`b7`0bnRH0<cYV@39hiX0f>n[03e>601LJST00P3o00000`3ChJh0/lB=08BHF@02
0?l000030<[TY@3<iJ40bN6C00@0o`000180DePP0:^^M@38dYD0b>>P0=c[/P2CUfD0RGeC04Hm4P3C
gj40c^RO0<;YUP2hgh`0a>BH0<g/X03;jY`0c>^M0<?OTP36hYD40?l000060=[^Z@3;g9P0e^NS0=_^
[03:fIP0g>JW0P3o0000X@1AH1l0RIQG0=oYZP3IgJ00AC`30=oIW`3:di@0eMfQ0=gQYP3Wj:h0a/B;
05aG801MEQl0W9=L06QO:03UfZ80aKR30:^HK@1LBad0hmNU0>OPZP2KWf@0f>6R0=?TX03@iYh0cnNM
0<cXV`39jId0b_JY0<W]X`39h9P0i?Ra0=kbZ`3;hIP0b>:H0<[UV03NmZX0Nh]20=CTW@39iZ<0a>jR
0;_[U@32k9H0amnE0=7/Y`1oIcT0/Ya[0<OUV`3@iIX0fNjQ0<OZV039jY/0an6J0=C[Y`2__h00eMn]
0;S2P`1IIa`0eNfE0<;SS02iiil0_^jb05B0C`24Ygd0aN6h04aX=`0QCa40an6a000A0033fkL0_^Nk
0;SY/@37kk40eN6S0=GNW`3Dhj80c^fW0=?UY`3Wl[X0i^nf0?Soa`3Vk[D0`<R=096KG`2mb8`0hNna
0=KVY`3?iJD0bn^Z0<_WZP3?ij/0dN>Y0<oQY`2R^W`0_]RG0<ORV`2^aW`0UjEJ09BPEP2AWUP0UZIO
09NWG02I[Ul0[/=d0;;:P032fiL0e>fd0<?M[@3@jL80an:e0<[[YP34i:<0`]nU0<cW^P3>ikl0bMni
0=;X`@3Ikkh0a=^S0=[a[@3;gJ40Z:F60::RP03Qi[d0i>^o0<O@X`3BgK<0jOG?0?[oj`3koo80o_ok
0?[ln@3goOT0nOof0?Coh@3gomd0looE0=kT]03HfZ/0Hf0e07mnDP3oom40h>Vl0>koj@3cooT0NXB>
00003P2b/;<0oo_b0?ook03Ej[l0g?oB0:;O/`2Sh;h0W/O30>[oo`3iool0lO3f0?olo`3ooOl0oooo
0080o_oo07`0ooom0?onn`3on>l0k=G?0?3ohP3bon@0b]>V0=;LZ032iYh0b>RL0>3ZX@3JkI`0bNVF
0<kbZP2oeiT0kokC0=SYa`3[on/0m?oa0?oilP3omnh0ooOS0?ooi03Bg[H0d^>]0=OU]03`m]80oOgQ
0=?9d@3hko00oogj0?ojlP3on?00ookh0<;2^03noo@0d^2o0??of03QmL80mooQ0<gM^@3Jj/D0f^[3
0>OhcP3LkL00cn6_0=SZ^03Gil<0kogS0??ok`3bon<0enRl0<?GY03DkK@0b>F]0<[V]@3_onL0mooc
0?conP3lo_T0mOSa0;[7_@3=f;P0c=N_0=ST_03:iL@0`n;30>goh@3;fk@0mooc0<;Kf01YRYd0<Sa5
06]ZK`3Pjnd0V[jj02ELEP0C?C/0o?Go0?ojo`3Zool0=65V07JX[`3Zool0j?Se0?Cmo`3`ool0=cLe
08b6NP3EeZh0VjI^0>3YYP3EgiP0b]^D0;[1O@2MX5d0G6<O06mi=02LZF<0U:5K09JSG@2Z]G00b=>>
0=GOVP2f_GT0NH8o0<oJUP2NZfH0SiaG09ZYI02/_GL0dNFN0=3VWP3@j9h0cnNM0<gWW@3?gj00enFZ
0=GR]03iomd0k_SM0?_ok@3joo00o_oh0P3oooX0103oooP0ooom0?ooo`3ooOl20?olo`0B0?omo`3o
o_l0n__f0?CgkP3fon`0l_kV0?Kon03iool0nOom0?SonP3iooP0o_of0?_ml03ooo40ooc/0<RkZ`1`
H540ooSg0P3onO/0203ono/0oocm0;^i^P3no?d0n?Sj0?ooo`3mo?l0oogo4@3oool000X0oooo1@39
jIh30<WYW@80bNZI01/0b^RN0=W^]@1UKc/0f>6/082:EP3Jj[/0lOod08BUWP2E`/L0lOoo0?ooo`0;
00002P0009bOPP3=fZh0d>^T0=;^X@3EkYd0fO2P04mQ5`2ldHH0`m^?0<_XV03>jI`0dNRR0=K[ZP1_
OTL0103o00000`1lSEL0o`000?l000020?l000030<SRX@39gYT0o`0000<0o`000180UIUW0>3U[@3S
kk40b^FR0=cY/@21Pe80UHQN07EY?`3Ojjd0c>>K0<W_W03>m:40^mZ>0<kZW`3Hm:L0]]:50=OcYP39
iIP40?l000050<?DT03@gi`0e>FQ0=G/Z03=gI`0103o0000X038hId0cnBQ0=CNW`1SEQl0imbT0>S^
/03Wjk00BTT@08^6CP1LDQd0TXEA0?c_^`2/W6P0YiYU0:bOJ03ReJ00IE@V0;Z/O@2UWVX0i>6Z05AJ
703GhJ80dNFN0=3VWP3=iid0c>RK0<WYW@32k:00`^JL0=7WW`3BiYl0d>BM0=gcZP3@k:40b^JI07nG
B`3Wmjh0d^>L0<7RW@2ghiH0^nfF0<?_V03EkjD0bnVS0:nIJP3E`Hl0^m^@0=gcZ032fH/0c?>P0=?j
Z@36iYd0d>fZ0<;HVP1lR5X0L7`n0>3]Y@3Dk9@0c>ZB0<_f[P34l[80]^:]0<OX_@3<ik`000h009c:
S031gJX031d00=kcbP2`e:@0DGi30;[RX`38fID0d=fG0=[ZW`31gI00d>FR0>Kd]`2nc8l0mOo40=KQ
Y@3Ag:00[;Qj0=cZ[03Di:D0eNRX0<oUY033h9h0b>2R0=ga]P3>fjD0Y[=m0<gOY@3Fk:h0cnJP0<?G
T030c880_/Yn0=KTU`3Ai9D0dNBC0<_PT@3Aii`0f>j]0=3UZP3>i;H0j_kI0>GigP3Gkll0f_S60>3l
b`3QoLd0an:e0<gX^`2AZg`0c^Vf0=;^/@39iZ@0c>ZP0=3WX`3/kl@0/[R:08J>F`3>eZ<0f^B`0=_W
^@3Cg[H0mooX0?_ol`3dm_D0o_oo0?[on03koo@0l_oO0>Whc`3VllL0c]JU0>7U/`3[j[`0]KB60<C6
U@3oomX0looX0?Com`3bool0`m7J00000P1cJV40ookZ0=[K/`37e:T0`nZm0;CS_`14MFl0g_oo0?Oo
o`3gn?d0oo_o0?olo`3oool20?koo`1o0?koo@3ooo/0oo;Y07]WG03fonD0jooK0=SV/@3FiJX0a^RL
0<SWV@1=E`h0amf;0=;aX`34hZ`0hO;50?_oj03^o>D0j?[Z0??nl03oknP0lmO<0?omi03oon40bmJ/
0=GN/@3Pikh0oooV0?ook03bioD0oo_o0?olo`3oo_H0oo_c0?GaiP3Gf/T0l_[R0=;S]P3Gk;<0eo2_
0?7oe03>h[40en^h0<gQ/03Gj;/0d>:b0<gOZ`3Ej;00d^>g0>;ad03iooH0nooc0=KSa@3:f[D0c>:d
0<cV]`3]omd0loo^0?Oon03lool0oooo0?oko`3oo_l0ooo/0=C@/`3hn=`0mOob0?Com`3gonX0nooV
0>gik@3bool0d^Wk0>ccn`3=cLl09cTk039IEP2LdL/0RK:^07MdO`2n//00ioGo0=Kho`0MDUP0f?on
0>_oo`3do_l0lOoo00<0001kLFL0i^jo0<k]ZP1[Nc80S9I?09^VH@1AE140P7ln0=CGU03OiZ80fnRR
0=3PV@3:fi@0a]ZB0<gQV@3LkJH0eNJO0<cMU`3MkZP0a]ZE0=O[YP36fiH0dNRR0<_WW@38iY`0anNK
0<SYVP38jiT0d>FT0=?T[@3BhKP0looM0=?Q_P3Hi/<0enC60?Kmk@3oooH0oood0?olk@020?ono`0O
0?omo`3oo?l0ooco0?ono`3ooOh0o_of0?;kj03VmMH0h?7=0>okk`3foo/0nOoh0?3kk@3Wl^40j?3I
0>;Vc@3bk]D0n?3I08AeH03on>@0oo[j0?oam`3on?h0oo_m0?[`l@3[inP0ooko0?_io03oool0no[o
0?ono`0A0?ooo`002P3oool00`39jYT0bNZK0<WYW@040<WYWP050<WYW@39jY/0bNZI0<[XWP3DjK00
0P3o00005`3?fJ@0cmfX0?Cok`3Oo_T0JZbh0>_oo`3`l?X02`0001`A002GVG40fnRb0<CQT@3=kYL0
e?2L0;78N03>giT0f>bU0<SLU@3@ij40bN2L0=KYZ@3BiJD0[;am00@0o`0000<0cn2Z0?l0003o0000
0P3o00000`3<gZX0WJIg05mT?0020?l0000@0<W6Y@3oom`0loS00=gYZ`3:hj40dmjV03Lf1P1QDRT0
I5L]0=?KW`3NlZ/0^mb;0=CeY03BjZ00bn6I0=W]YP80o`0000X0c>>K0<GLU03o0000o`000=7RWP2f
`X00Qi9@0:JeLP10FQ<0IgPd103o0000602jgY@0`>2G0=GYY01_IR/0knJ[07b2A01IFR00/jig0>?I
YP2kZgX0OF/m0>?AX@2RTUl0HUDP05mD703@ahh0Y:9Y0;VgOP2j`880Xje^0<CET@3@iJ00cNNN0<cX
WP80c>RM08<0bNVM0<cbY`3:jZ40b]jI0=k_Z`3EjJ80`]VA0<SVW03;jIl0Y/1g0:o3O03Dj:<0c>VV
0<?]X@30l9X0`nfG0<_SV@3>jJ@0Mf4b095mB`3;jj00bn6F0=3WV@30iiH0`^NJ0=Ge]P3Ak[H0m?oM
0:jnU`3FiJ`0amRD0=G^VP32hXl0bO6[0:kHV@3Ao<H0NYYY07VCH`2D[G<0cOBc0=Kd]P3Sn;l0I7E1
08VPK0004000HXI9086PG02U_gD0_]F50=K/VP2Z`7L0/lZ40<GLUP37gYP0cnBO0<OLU`3AiZ40QiiH
09>ZIP26WEL0QIaH07jGD`2@Xf<0_/V=03Tm2P3;cid0e^2/0=c[]031e9@0a]JE0>?_Y`3EhiH0b^:<
0<OPS03=iYD0cNBP0<[NX@3Ij[d0looK0?_ok03_n><0l?SY0?_omP3coo@0ioKQ0?OojP34fjL0bN6S
05Ue:P38iiT0a>BH0<OWWP3:jjH0a^>Q0=c_[@3<h9/0_Lj80:BeK`27V5@0SIaQ0;K3SP3Ihl00hNWA
0?_nl`3Zl>80j?GG0>Kdd`3Um</0c]ja0<oP[03Ijjl0f>Z/0=GSYP3Ki:/0`lND0;2]Q01_Ge00Y9N6
0?Scg@3oon`0^l6c08:9PP001000l?OW0?goi@3Sj;80_m>R01]IC03Mool0kOoo0?coo`020?olo`22
0?ono`3nood0noom0?Woo@3oooP0]:>?0:6GO03JkKl0a^>[0=;_[03Fl:T0^=2608NMDP3DiIh0j?nh
0<_UYP38el80o_oc0?oom`3[k^L0nOok0:f^Z@3/d<d0]IB?0=6oZ`3=cK40XJR90<g<]`3Ie/<0gMG:
0?oil03on_l0ooco0?omo`3ooo<0o?_Y0<;4[P3lon@0amJ]0=C][035hIH0b>RE0<?PW@37hY/0bnNM
0<gUZ@3EjkX0h_S:0?OoeP3`olD0fNfb0<[K[P3ioo@0oOol0?comP3gon/0mooT0>kof@3BkL00a=Vj
0=o^f@3nooP0oooj0?oemP3olo`0onoJ0=:mXP3_fL/0nNG`0?oio`3oonX0moCE0?Gaj03ooOl0nOco
0>Wgm`3[ooh001@C0313BP3bnOl0mOoo04i^H`1?IU`0j>_`0>G/mP3]ool0=UQI06V=S@3Alod0k_oo
00000P1hNF/0eNV^0<?UV034kYP0e_FU0<gJU@3Kh9h0f=fJ0=;MV03LjJ<0f>jU0<[RV038ii/0bnZN
0<c/X038j9`0anNK0<COV03?jZD0c>NT0<GPW@39j:D0cNbX0<[[Y038k:80anfP0<C[VP33jYL0bN:Q
0=GW]@3[o=P0mooV0=GY]P3Cj;00dnFa0?_oj`3noo@0ooof0?ook`80ooko0P3ooOl07@3oo_l0oook
0?com03honT0h?;<0<WRZ`38i:T0h_GI0??ok`3fonL0hO7:0<kO/P3>gJH0g^Rc0=cN[`3Rg[P0Zib5
0?oii`3on_/0oogo0?olo`3onol0oo_m0;R/[03jk_00oo_l0?omoP3in?d0o_oo0140oooo000:0?oo
o`0;0<W[U`39jYT0bNZK0<WYW@39jIh0bNVP0<WYWP39jId0bNZK0<WZV@3:j9h0103o00005`3:fJ80
mOk[0>[oo`0QKG/0jOoo0?cno`1]HT`02P0008N9H@3Gi:`0b>FE0<k^V@2nfHP0a=Z?0=c/Z`3JjZ/0
d>>S0;;6Q`1hS4l0QYQJ07F5AP3FiJ80f>BR0080o`0000<0nooA0??ocP3eomH00P3o00005@3komX0
o_oJ0:BQOP3ck=00oo[[0?obh`3oo^@0i=ni0<K7S@3Fgih0dNZX0<gHX00Q8000X8iV06EF;@2LXVH0
JW/e07nNCP38iiL0d^RO0=WZY0040?l0000:0=od[`35fYD0dnRS0=g^ZP1BGQ`0TiaK0;K2P03<h9T0
a=F?0<gLU`80o`0001P0b^ZO0<7SU`31gI<0en^T09BIE`29Rd`0b]BE0>K//02^Zg@0MVlk0;>RM024
LdL0H4lQ0:^OJ`1NEb00k>Z_06m_<`1aMcL0g>:R0=cXYP3<gIT0hOR`0<gWWP3<j9h20<[YW@0g0<cX
W@3:jId0c?2V0<[XX03<h9/0h>n/0=O[YP3=i9h0d>jV0<[XX03=j:40c^>N08^NG03Jl:l0co>Y0;cV
TP39k9P0e>RP0=7XY028KD00bK610<cXWP3Ijj40dN>I0=Wd[`3Pn[T0enjj0=cba03fonD0_mB]0=7T
[@3DjJP0eo:Q0<o^X02niJ80c_Nk082XL`2WaiD0dnjg07bBDP2lfiD0`=jH0<3IU`1/Nd@0Kg]90;K<
W@1SPDl0X/R;08>SH02`bX<0SimF0;79O`2lf8h0jonm0<cXWP020=;^Y01;0<KRV02ofi40cnVR0=cf
[@3Mmk00fO>/0<?CU02LYVX08B<00=?EY03DgZX0cMbU0=?WZ03@iJ@0c=bE0=?UV@3BkYT0c^jK0=7]
XP3;hjL0c^:_0>Kdd03^nM/0o?o[0?kok`3lonh0l?;T0?komP3nonl0n_oV0<gKZ03?hJD0KXHl0<[U
UP3ClZH0`n6G0=;a[@32hId0c>JM0<cVW03>iYX0dnZL0<cSU@2I[FH0UJEV0:nmS03Likl0locQ0=_V
b03CjKX0cN>b0=KZ]@3=hZT0amnQ0>3k]03BkZ@0amjH0<oRX03IhZ/0fM^Y0>[H]03oo=d0N5a70=Fn
[P3ooo<0jOGY0>Gjj`006P40J7eN0=kS^P3IkLP07F5B0=_oo`3/ool0nooo0080oo_o01/0ooko0?ko
o@3kood0n?ok0?oom02@O6<0j^K30=GX/@3>j:T0d?BZ0<;RUP1GJAl0Z;Ub0=3WW`2ofY<0c>F/0>;]
g`3oooP0no?a0>STh@3=d/`0m_;_0?ofn03_bld0oo7X0?ook`3cn>@00P3ooo@0I@3oo?T0oock0?Wc
o`3lmo/0lo3[0?ook`2`/Y`0kO7F0?_oh@39fZd0cnZW0<_/W@3:kYL0b^RP0<g/WP37iYP0b^BW0<_R
]P3Nm<h0i_c;0=CZ[03BiZL0b]bZ0?_ol`3ko?L0nooa0?Cni@3hon40hok70;cIX@3?i[X0fN[60>O]
d`3YjmD0ooka0?obk`3ml<h0ooO@0?ogh03on?l0ooWo0:fVR@2l^Y<0UHil0<c3^P3gm>l0m?oo0>Wo
o`1ANgT0b^?Z08Z4T03em?T0gOc/0:72[`0^>3L0k?7g0?Woo`2ndMP0P9nT05f?UP3Mn_l000D508:>
NP3QlK<0f_6S0<3cU`3>oZP0c^>N0=_XX`3HjJ<0b=jF0<GLU03:j9h0bn^P0<W[W`37jId0a^RL0<[/
X03=kJ80aN>M0=3]ZP34hIl0anBR0=3^[P32h:00a^JS0<SYY038k:@0a^^M0<CYV@3IlK<0io_80?Go
i03YoMP0amnS0<oUY@3AiJX0n?oY0?konP3ooOh0ooce00<0ooko01l0oooo0?oon`3nooH0nOo_0>;b
c@3=hk@0a>>P0<_/Y@3Rn=40kooT0?7of@3QmL00dnNZ0=WZYP35dHl0gn>`09FCJP3Ca[D0ooC]0?[f
m`3oool0ooko0?olo@3ono/0XY2@0>cIf`3on_`0oo[m0?[ko@3lool0o_oo0100oooo000:0?ooo`05
0<W[U039jiD0bN^G0<WYW@39jIh00P39jJ001039jIh0bNZK0<WZV@3:j9h40?l0000c0=k`]P3noo40
j_oo001HJ`3Sool0nOko00P1000h;1H0];F=0=3JY@37hiP0cnjN09RbJ@2I[Vd0J7I105m]?00iBAP0
Q9IT0;S9U@21T5L0aMFF0>_k/P36e8L0`m6406Mg;P39fid0d>6[0<OJ[@38ej`0a<bK0:n/P@1aJD@0
oo;M0?KId@3Va<D0]9:A0<:YU@2`WWP0WIED0:JZH03@iJ@0g^F_061L;@2;N500QgA<0>7RZ03PkJP0
`Mb=09B_H03HjJ80dMfK00@0o`000280enZX0=;UX`36fIL0P8m<0:JcKP3EgY/0e=VG0>;WY03?h9T0
^=n@0<CaX02njIT0cNfQ0=;/XP3Bhi`0b=VB0<gWW@35hIL0d>>Q0<kLWP30`h`0f]RU06YR<`3IcZ00
knNh07]jA02HVf80bmNG0<cKUP3EjYl0/lUn0;WER03?kZ00doFX0P38jYd0Y@39jId0b^RN0<cXWP3:
j9h0a>BI0<GQU`3Hij@0cMbI0<cLV`38gi/0`n:L0<WXY03Al:`0d^^Z0<gOX@1nQTX0UjaW0=7^WP3?
iYH0dmZF04eI6@2IMT`0JDPK09Z^I`2laWl0eMZH07f4D@1fO500oooV0?cnj@3oooP0lOoT0>7ia@39
hJ<0c>RN0;WIT031ijX0bO2i08ZbOP3Bl;X0an>V0<7FR`2Y`6h0_]n80<[ZU`37eIL0]kJ604A::033
e[H09UD[0;_U]`2mfJT0fn:/0<KPU`3=l:00a^VG0<cbW`2lhI40_N2@0<W/W03;jil0cnnS0<7PU03:
jId0d^jS08jOF`2a_Gl0LWA204iB800W=@80?U4J00hX000iDa80f_6[0<_WW@35j9P0a>RP0<OZZ03B
k;l0i?SE0?Gnj@3Be/D0fMS409:@N@2h/iD0eLn]0:NON02i/H`0hmjh07ekE@0n@1T0[[N80<;?VP2X
_G`0cNBL0<ORT@3?kYh0_>2F0<GWVP3CmJ40b^^D0<gYTP36gXP0hoVV0;72N`2EYF@0bmRP0=?WZP32
k9X0anbN0<SZW@3;kYh0bO2M0<[iV`3;nYX0^^F;0<3ST@3@iJ80am^D0>7eX033d8P0j^^o09RAM02X
U8d0ono/0?o_kP2?R800:2XM07:5K`2gglD0AY=o08[7^03`ool0nOoo0?ojoP3onol0ooom0?kon`3i
oo/0mOoj0?ool@2BNeT0VIm_0=GSYP3FjjH0b?FP0<W`W@3Rk:D0b]FA0=Ke[`3ClK40_M>R0>;Sg@38
_[`0m>KU0?oknP3ooo/0oocm0?o^n@3ldn40ooOo0?omo`3kool0o_oo0?ooo`020?ono`1T0?ooo@3n
o_80ooo_0=WN`02HWW`0d]bg0?Cof@3?iK@0anJS0<CYW038l9X0anVM0<k`W033iI40g?Rn0<cR_P3Q
mM`0g?7:0<oTZ@3Bij@0hOBl0?_ok`3oooP0n_cW0=SR_`3?hJd0b^JL0=OfZP3El:T0c>:Q0<[EV`2M
XV`0TIAU096QNP36hYP0c>JL0>KhaP3alnh0oooj0>3Z]P2kbh`0c]FY0?7_b@3Zf/00^JZW0?_oo`1P
[:80L]3200<]:@21QHH0on?S0?oikP1=HU<001P?08BAU`3]mOl0k_oo06fY/`18SI@001LB07B1K`3?
diP0e>^I0<?[TP38m9l0c?J/0<SaY@32jid0_^VJ0<?^W`35lJ80a>nP0<O]X03;l:<0d?:V0=3/XP3<
iYd0b>>P0>?m_03CkJh0d>Z]0<WRZ03]ol`0g?Ji0=K^/03?j:L0bnFN0<cVW@3Mlk<0f^ji0>7bd03?
i;d0bnBP0=;/X`3Pm[D0nooc0?coo`3onol0ooco0?ono`80o_oo01l0o_om0?kom03konl0mooV0<_S
[`3<jJT0`^RE0<WdV`39i:d0cNFe0<kYYP3<iiX0bnB@0<cSR@35ehD0DUTS0=[J]P3om_H0ooOo0?_o
o`3eooX0noom0?olnP3om_<0g/K40=[0`@3on_X0ooOg0?cmo`3jool0o_oo0100oooo000:0?ooo`0<
0<W[U@39jiL0bNZI0<WYW@39jIh0bNVP0<SZWP39jIh0b>^K0<S[V@39jIh0bN>T0P3o0000=@27UU/0
cmjW0?Con03;lO80<GR:0>[oo`3ko_l040h0044f803;c:@0fnFa0<kXW`3;iiX0Q9]E08VNG@3=gZP0
:S`:096ULP3=i:h0bmjW0;_:S`3Mjjd0aMF<0>3^X`3Jj9/0DUlG0=[XZP3?gZD0d>2a0=[V]P3Sik@0
_;R8081iC@2dYHP0/9^607mYF`1YDdD0G4l_05aD9P1FEa40DUP@0;W5Q`3Jej80OFa008]aC02JQ5/0
f=bO0=KSWP3BiiX0RYaB0=?PV`3LiZL0T9UP0080o`0002<0d^FU0<kNW`3LiJH0d]^J04UJ5037fi@0
eMbH0>?VX`3@fYD0fNfV0<;XV`39mZD0_^VJ0<OUV`3@iYd0c]jG0>Ch/@38j9d0bn^P0<ONV03=h9h0
JgDi09JNI@1:BQ@0i^Jb0<_;U@2c^h00g>RZ0=CUX@3Dj:40e>^M0=3VV`3NnZd0a>>E0<_/W@020<WY
W@2S0<[YW@3:j9h0c>RN0<[XWP3?kJ<0c>JM0<gNVP3Gj:@0cn:P0=C[Y`33hI/0eoJb0;oLV@3Fkjh0
cN6R08^GF@2BYf80d>RJ0<KIRP3Ji9d0V:AR081K;`2CLD<0QYaD0;;2N@3LjJ<0];^80:neQ`3SilH0
n_gR0?ool03domT0c^>Z0<[NW`3@ij<0cnRW0=Se_`3Rolh0e_C20<CMY03Bj:X0^<Z00=C/V03=kYL0
b>VH0=c/[@3IgJX0EU`h0=_/bP009@00Kief0;SN]`3;g[00d_:Y0<S_W032jIP0bo2R0=OgZ`3DljD0
a^FG0<kcX`2igY00b^bO0<[VW03EkjD0Df@P0=OSX`3Rj[40MGi70:2_N027VEl0MHi=09JaKP3=j:40
c>bQ0<S^X@36jJL0bnZa0=cabP3]o=d0k_SO09BMPP3Igkd0hNO10>GX^`3?dJ00RhiE0;6dO`3CejD0
dmR_07ImE03:djP0]l>C0761@P3AiIh0`=N50=C`W03>lZP0co6U0<GUTP3;j9@0d>bG0<gWT03EkYX0
e>^M0:_1N02Z_G/0fNjY0;cRS@37jYP0`nBE0<7TTP38l9X0b?NI0;[YR`3:mI`0dONT0<[SW`3DkZ@0
_^210=WjX`35eid0fn:h08afJ02mWYT0ooGd0?oimP25OWH000X0051jHP1TYHd0A8=^0>?ooP3]ool0
lOoo0?_oo`3ooo/0oooj0?conP3aooX0nOoa0:NDJP2HWfT0d^6P0=S^YP36lYd0b>nL0>C][03Hh:D0
a=VP0=3P/`3Eg;/0j^OR0<Vo_@3onoT0oogj0?onnP3oo?d0ooGo0?gLi`3okoX0oogo0?coo`020?ko
o`140?_ko@3oool0nok]0?goj03nonD0g^K109jVO`3>fK40nOoO0<SI[`3?ik<0c>R^0<OSYP3?j;40
e^j`0<cTYP3Wo=40d>350>;afP3Nk/T0dnJ_0<kPY03Ql[h0n_o/0?gok`3nonH0d]nc0=3TY`3<iiX0
`n2@0<[TVP2I/6P0WJa[09:NGP3BgjL0d^Nl0=;`/02lfYX0cNBf0?WonP3kooH0f^Zi0<cPX`3Dh:h0
dmVY0>SN^`2o[:H0o_Wo0:3OeP0^QWH0CGmf0<gIf@2mU9`0j];@04AHC@1XPg`05bDV0?;fo`3_nol0
gOoo01iMHP0030L0M7a]0=cJZ@3Gij00cNRG0<o`W`2njIT20<;^W`110<C`X`32kZ40`>ZN0<7/W@36
jid0anVM0<GUVP37hY/0c^NS0=KT/`3komd0d>6e0=7T]`3=hk80kooB0?3oc`3TnKh0e^b^0<gPWP3@
i9l0fNRW0<gKX03CgkL0cMZ_0=3OY03@h:80nooD0?komP3oo_l0oo_o0?ojo`3oo_l0o_oo0?koo@3n
oo/0o?od0?col@3iond0dnRo0=ge``36iIl0bo2P0<WWZ@39iJ/0cNJT0=;XX03Bii`0cMfF0;O3P`26
SF<0hnK;0?olo`3omOl0o_oo0?[oo03kood0oogj0?okn03F_;/0gKg00?ojnP3on?H0oOgm0?_oo`3n
ool0403oool000X0oooo0`39jIh20<SZWP0X0<CVVP34jI`0bN^N0<[_W`3<lYl0e?FT0<cSU@0D6000
f=fe0=KWX@3AgJd0d_oo06RSY`3lool0ooco0?omo`001000j^WD09fRN@3nom@0d>FP0=S^YP2O/fh0
OY5A0<gSY@2ofIP0b>VT0=3d[037gYP0dn:O0=3OW01hQd@0cm^I0=WUX`2f`Gl0g>NU0=ORX031bXT0
h>VX05YP8080o`0000h0e^NS0=S]Z03?jZ<0bNNO0=3`Y`3EmJ`0`>2G0=_e[P3YhZ/0JdhR07]C;`1e
DBd0IeP]0<gMWP80o`0001h0S8a@08nDG02IXVd0bmbX0=7R[03Cjk40bmnT0>;Z/@1/F2D0g/nF0<7K
TP38kj00f>:K0<gDT03HmZh0d>^T0=Wc[02F[FL0CF@N09FZI@36gIL0b>:K0<KPV@38iYh0a=nH0<cQ
W039gYT0c^>N0=;WXP31eY420<gRW@080<[OVP3MlZd0Y[]f06Ij<`2M[VL0U:EN0=CUWP37fi<20=cb
Z@3o0<gUV`3<i9X0cNNM0<kZW`3;ii`0`MfB0=SdZ@3=iih0d>ZQ0<kXW`37gYP0`=NA0<WPVP3?iZ80
cN:O0<[SW`37j:40cnfS0<CKR@3AiiD0fo:R0=OcZ01P?Ph0[heM0<_]X033kIT0f?n^0=3ZX`3>ij<0
a]fI0<oUY03<hJ00f>6B0<C<P`3YlZl0b]>L0<oGYP23RV00`/VM0=gU]00@6000W:AX0<[GTP3GlZD0
eoN/0<[YX`3Ajj`0a]^P0<[MY@2H[GD0coK906ZNN014QFD0W>>k0;oaZP36lj80b?BW0;WHU@3Gjj`0
e^:R0=?TWP38ji/0`nfK0<?/W@3:j:00cn2L06Ed<@33ei80b=fH0<WMV036dHd0i_6]04IE402BYUl0
e?BX0<?XV`2khi`0g__30?Oog03non<0dmVe0=;P[@3EjZl0d_2V0<;RUP3Pok40_=f>0;gTT`39l:40
aNZM0<_ZYP1^Rd/0f?2b0=KZ[@3@h9l0d>6K082=A@1FJb00^mf@0<KRU`3KkjL0dNFM0=?WW`3;jYh0
`nFH0<S]W`38jYd0a>2E0=3VW@3KijD0PXm:0=?YX033gI<0dNfP0<SXW037jI`0anNN0<SUXP3:i:<0
b>JP0;WQR`2oi9@0/lb;0=WV/@2JSg40RW=Q0?oej03ono@0ookh069bJ0002P00a=nn0;;YbP1IPh80
4TQ:08g[g@3Dood0mo?`0?omn03oo_P0gOO/0?3ol`2SXFh0UY]Q0=S]Z03JmZ/0_>6C0<_]X`2eaI@0
c=:`0?onk@2>Lg`0k=3N0?oko03oo_/0o?ki0?_onP3ooo/0oogk0?okn`3omoH0ooWg0?onn`3oo_d0
oogo0?ono`3nooX0n_of0?Cod03Kk;H0mOo@0;G1T@3?fjd0b]:Y0=WL`@3oond0ookh0?omo@3oo?l0
ooko0?_ko@3inO/0m_Oa0?kolP3oon`0kO?=0=ON]03Ni;h0koGC0?Woh`3goml0f?2f0<oXY`3<hi/0
AEX?09>WG`35fIX0f>ba0;_CV@37h:H0f>jm0>_gg`3go_H0n?og0?Onm`3kooX0nooh0?Cmj03konX0
enBh0=CR[`3Cg[<0n__]0?onn`3fnO80nooj0?7oo`3Tool0LYNM035DFP0fBe00Mh:60?coo`2KTIX0
A3U70?kno`3gnol000<40088101BESl0cm>^0<WEU`35eH`0hONU0=OhY`3=l:00anVO0<SYXP38j9d0
c>bP0;KFP`3:iiL0eO6V0<;LW@3Il[T0oogm0?oeo`3ooOl0oook0?CniP3honH0bMf/0=W[]`3Gjk00
dNBR000:0<7AT01oP3X0I64J06AO9`1XHS80J5m206EJAP2bZ9`0ooch0?olnP80m^c[0240ooco0?om
o`3in_D0n_gd0?SklP3loo/0nOgn0?Gkn`3iooX0m?oQ0?Coe`32hYl0]m^E0?coeP3ooml0oooV06QI
DP2_YJ<0n_[h0?coo@3Nj>00nOoj0?ohoP3on_l0nooo0?ono@3oo?/0k]GH0?K4c`3on_X0nO[e0?on
o`3ooOl04@3oool000X0oooo0`39jId30<WYWP0O0<[/X03<k:00`nFH0<3ST`35i9@0g_FW06]aB`2a
^8l0d>6M0=OS/`3Eool0:FAX0?gmo`3nm_l0gMSO0004002TXHh0UIM`0<WCX@3DjjL0amjF0<gRW@1P
Lc<0fnnb0<gVY@38iJ80b>RO0<cSW@3Gj:@0b]^G08jOF`020?l000050<cHUP3=fIL0cMVG0=GPWP3D
gid0103o00000`2oeY00an:K0=Wg[`020?l000070<KTW02ng9H0a]BG0=[BX@19<PT0GdTT07MdB@04
0?l0000T08N>F`2i`i40jOK80>;d`P36f:@0k?K20>cZ^@1KDAh0j>J]0<oRX03?jJ80b=NB0:FfL01n
WUD0Pj5I0;7<Q@2B[6D0an6J0;S?R@2leXl0f?>/0=3[Y037iih0dNbU0=KRX03Lj:H0e>2N0=;NW02Z
]W@0]<1n0=STXP2a_G/0SIUG0:jjN02ea7l0^/j60P2S]fl0c@27WE@0SZIL08ZRF02I/FL0TZaR08bV
G02Y`gT0_=R=08n^HP2lfhl0c>RN0<WUV`2je8/0eNbV0=3UX01nTdh0W[=`0<;ET`3JlJd0`^2J0<OQ
V02G[Uh0cnFC0<[RU035iIX0J4PG0<2NKP30gY@0c?6Q0:oDQ03:iY`0b^FN0=?]YP3>ij<0fO2/0<oM
TP3NjjD0bmZG0<cKXP3QkkX0cmf/0;S6T`2CXF`0h>jc0=OUY`3MkZP0_MN=0=GcZ`2ieY<0dn^]06n3
B03AhjT0XKAm0=7ea`3Jon80VMFc04b@J`2cjj`0_^RN0<S^X`2kgiD0`nNQ0<cVZ@3@i:T0e>>R0=3V
W@39jiL0`^nD0=W_YP31dXh0RimJ09J]I`21UU40OHY504UF4@3@giX0TjUQ0<KVV`33j9/0`^ZQ0=kj
_`3^oll0mogG09ZNN@3Fi:l0b]jQ0<g[X@39j9`0c^ZO0<GQU037hiH0cn^P0<oZX`2of9L0GWHh0<?H
W@3@iZP0d>FT0;kCSP3Fjj00c>BH07fMD@1ZQS/0dnNO0<cPV03@i9`0anJJ0<W[WP2nhiD0anVL0=Oa
Y`3?iI`0ko^i0:>`J`3>i9/0dN^Q0<CPT`3<k:00bNVM0<KVW@39iZ<0c>JU0<SUX`3=jj/0eNjd0=SS
^02LWGd0EdLh0=:n]`3omoH0ooWn0?olo`2j`/D092lY05e`E03BmMl0lo_o0?7oo`3;ool0f_oo0?Wg
n03oo?/0oocj0?ooo`3=dlL0Vj5e08fGI@2le9P0_MZH0<[^YP3>kjX0eNVf0<[E[@2>SWH0oo[j0?oi
o03oo?d0ookm0?_oo03lood0o_gk0?ojn`3on_d0ooOg0?oin03ooOd0oo[n0?ojo`3oo?l0o?om0?So
l`33e9d0/l6<0<;@W@3gomD0mooF0=gS_`3jo>H0oooa0?onnP3om_L0oogo0?ono`3De=@0no_i0<;3
^`3Kg/d0XjN>0<_AZ`3=e:X0oooQ0?GjfP2b^i`0f>Vo08ZOIP3:gYl0Uj]V0=KWX@3IjJP0eN>^0>Kc
a@3Znll0l?oF0=W[a@3doN`00P3loo/0H03lood0n_oi0?conP3go^h0o?o]0=KP^`36dJH0kOOB0?Kj
k03nood0koW^0?Con03Monl0cOW/04=hL016N7D0NYjL000G501;GUP0o_Gf0<Vj_`13>3h0ZjFY02Tc
<P0I;B@0F7]M041U?03Flk/0enf_0=KUY02ogHL0_N240<W[U@3<kYX0b>RE0<WYU03<jY80c^bF0<_X
V03?j:L0b^6Y0?;on03_oo`0n?oj0?SklP3oond0oooV0=_Q]@2?VfT0I7Tn09BjL@2A_Fh0g^jW0=cN
W@3Ogj/0gMb`0?[ff`3ooNX0oooa0?K_j@3ooOX0fm?@0?omnP3onol0oogo0?konP3nooH0l_S/0?co
n03fnoD0mooh0?Sol`3fomd0jog90=Ke/P2nfiT0oooH0?Scd`3ooNP0[9VB0?okn03oo_/0oook0?oo
nP3oooP0ooOm0?ojo`3eo_/0oogl0?oln`3gg^40/7j90?okn`3ooo/0noOh0?kioA40oooo000:0?oo
o`<0bNVM0P39jIh20<WWW@0M0<[YW@3;jYh0c>^O0=3/W`36gY00KWI?07f5G030e8l0fNNf0<Koo00a
K700o_ko0?oko`0;10`0JW1T0?3[f02SYH00gn^k0=7ZZ03JmJh0FG0/00DJ0035ei/0go>d0<cRX@3F
lJX0c^FO0<_PV`3<hI`0103o0000103Nkj/0dN2M0=g/Z@2FXV040?l000030=?ZY036hIX0o`0000<0
o`0000H0g?Zd0?l0003o0000Mf]106AF<`1VJCh40?l000140:6WN@2BVFd0Xjj30?Oog03Lj;P0oooF
0?omc`1>DA`0en2W0<KDUP33ci40T:MS0<SSWP3=j:40dnfV0<_RW03Nljh0d>FP08fQG02@YF00b^6K
0<gTWP3Hlj`0bN2J0=gXYP3Dgid0WJQV09RSH@26TDl0TiiL09JQG`29U580WZUW0=gXYP3Kj:<0d^ZP
0=C/XP2X`7H0V;1V08bTFP3?iid0dnfS0;[DRP2J]6X0V;9X0:_5N`2ogY80d>nS0<gYW`3?jj40e>jU
0=[aZ`28WEP0^/n:0;_@S@2L[fd0ZKal0=;XY`37gYP0Mh`o0=K]W@37hiP0anVO08UY>P2NO4h0d>bR
0<7RT`3GnZX20<WUV`260=3[Y038hY/0cnVR0>;f[`3>hYd0f>^Y0=oc]P37fj00f>^c0<SKX`3<h:D0
g>j`0;kAT@3KlZ`0f?:Y0<SVX03Km[<0aMfQ065c>@3Njk<0NXUB0<?P/038lLL0goo_03IgE@2Ig:T0
_>JW0;gNV@3=k9h0c?>T0<GYZ@39iZ`0e>:W0=?TWP3=jID0aNn=0<gTUP3Pm:l0^m2;0=C^Y`34fiD0
cMbG0=c[YP1cQ3h0/<Mo0<CVVP39kj80`nVN0<gWZ037fZ<0h^W008jCJP3GiZl0dnNX0<CSU`3=k:00
aMnE0=cdZP3Dj:00d>BM0<?GTP3Dj:/0J7a10<gRY`3<hJH0f_>a0=?]YP3Jm:X0a>2E0<g]X@2lf8d0
K80h0=7UW@3<hYT0e_FY0<KXV`3=kj80dO6U0<SPUP3>hYX0bmNE0=;QW02/`WT0bnFK0>3k[P3<jil0
anNK0<[ZX@3ElZl0h_bk0>7k_03=hk80lOoD09RDM`1oM600oo3Y0?ofm03on_d0n_?j0?omo`3emOd0
KW9a03<o9`2oe/@0o?7o0?klo`2Cb<`0iooo0?ono`3kl?@0nN[]0?K[l@3ThM`0QY9/09VXO`3Dk;X0
c^^c0=gm_033hJ40dnZf0<[I/03nonP0ookh0?cdlP3oo_d0no_i0?[oo03kood0o_kl0?ogn03kk?40
l=oU0?oko`3onod20?oko`270?omo`3looP0i_;L0=_Z[`2@WfP0_LVG0?Cld`3`m]@0j>_>0?cjj`3o
oo@0no?`0?ohmP2g/K40h^7O0=SHeP3fmo80ooof0>g`g`38c;<0TiUc0:J]Q03EfkT0d=Fg0=OM``3R
lLP0cMjW0=CVZP3Qkk40f>BV0<_FWP3EgK@0j_CB0?_ojP3conH0nOo]0?Sol`3loo/0o?om0?[on`3h
oOT0nOkh0??ik@3loo40g>G60<OA[P3Yl=40oooh0?cjn`3_mn`0jOcY0>;olP29^Z@0/nkL07ngZP23
Zj80RZRP0:Nk/P2FShT0ooC`0<Jd]01:?3`000P403I@A@17NE`0ChMR086[N`23XFl0UjUg0=K[WP3F
kYX0eNfO0=7YW@3>iYP0c^VH0=3/V03Bkid0aN6F0<_UZ037gj/0k?o`0?3on`3doo@0i>[N0=?@_@2I
UG`0[;690<_GY`3Vnl80/]bB0<[k[038fi/0d=RO0=GKZ`3@eJd0o_kV0?ook`3ooO00oooh0?Wfl@3P
fmD0mo;/0?kio`3ooOl0oooj0?kom03loo40moo_0?WolP3bon/0mOoX0=W`_037gj40bN>R0<oWZ@3o
omX0oooQ0?oii@3TcLL0ooSg0?[_k@3nm?80oogh0?_bj`3on?d0oo[o0?CmnP3onoX0ooSg0??Jg@3o
d=X0n^k^0?gnn@3oo_l0o_co0140oooo000:0?ooo`0T0<SZW@39jId0bNVM0<[YW@3<j9d0d>ZQ0=3W
W`3>iId0d^NR0=?XX`3?iId0c^VL079nEP3Fh[X0f>nY0<_K[02mn_<0LZfa0?ono`2i[kP02P440?co
l@3]i=<0Zjb:0=GQ/`2F/g40GWlj09^eM032f9P0D5/O0>[d]`3GhZ00e^NP0=3ZX@36i9`0aN>K103o
00001@3FkJL0`]VC0=gd[P24VE@0S9eI0080o`0000<0d>NQ0;kHT@1jUDh0203o00000`1XF3L0J6U1
0<[NZ@020?l0000Y0?ondP3dk<P0m?7>0<3;X03hom`0oooJ0<_2V@24OE40an2W0=ch_@3Ae9d0FE<O
0<3SW`2miil0dnBP0<cKV03Cgid0aM2>0?3i^03Gh9l0^<6009>OG@26UE80^LZ60:JgL`2=XUd0TZMR
0<SMV03PmK00cN:M0=S]Z03:giX0c>6L0=3UX03?i9l0enjV0<OWV`33hiL0c>^O0<_WW03?jj000P3?
jIl0c03Ajj40dnfS0=7YW`3<iY`0`N>F0<[ZWP3GmJ/0eO>Y0<WUV`3=i9h0hoNb0;G9Q03>gYd0_<^:
0<kLWP3GhZH0d^6P09BXH03>iY`0bNVP0=Oo^@25IC`0QV4g08BHD`3Ciil0bn>G0<k]X@3?kZ80bNNM
0<o]X`38iY`0a>2V0=;/[`3:i:D0gONf0<;MVP3EkZX0^MB?0=7/Y`3FlJh0a^6N0<COW03BjjL0c^NV
09^cM@0_@PX0X:mf0<S@U@3Nj:`0TZE^0<ST/`34jKd0YN;3042EP02jl<h0do?10=ORT`3EjI80_?2M
0;OaY@2lkJ/0b>VT0=?UV`3MhXh0c=Z?0<[TV`36hYP0eoF[0<gYW`3;giX0k_nk0;;7PP3DkZL0_^BI
0<oeZ038kY/0a=jG0=CWY`2RZGH0e]fZ0=7QX`3Cj:D0aN6F0<_UV`3@iJ00i?Fa0<oHU`2ka8D0V:9U
086>EP0L:`00:Sd609R]M035gih0a>6N0<OWWP3:jYl0aNFI0;[FR`36g9<0d>JM0;_AR02K^Vh0[]23
0<CVV@3;jYh0en^S0<oPV@3HjJD0c=fG08bRF@2I/FL0bNBG0<cXW@39j9`0c^bT0=Kc/03Ro;/0ho^m
0?Ooe@3oom`0RG5G0?oZe@3nlN00ook/0?Sol03Lkm`0j_OV0?oom03klnP0:blN02Ti;P3onol0eM[]
09G:d03Sool0o_ko0?oko`3gm_`0l_cm09JVW00780803bH:0;S</03Kl<l0mOoO0<_N/03Hjkd0d^Bj
0>gngP3gooH0n?ok0?knoP3lool0n?oo0?Gnn`3oo_l0ooco0?oio`3on?l0oo_o0?olo`3mn?`0nocd
0?gol03ioml0b=ZV0=gWZP3VkkX0T9QY0?ooiP3innH0oO__0?ojm`2;PX<0mng/0<:h]`3ooOX0m_Ga
0?oon`3clo40oooj0?Khj`3gn^L0g^?30=WN_P3oon`0ooo_0?;diP3Ujm40eMbc0>C[_`3CfJ/0oooJ
0?oogP3ooo40oooh0?ShnP3oool0nO_j0?coo@3koo`0nOgl0?WmoP80o?oo03L0o?om0?conP3koo<0
o?oa0?cmk`3on_h0oo[o0?7ciP3hond0AVm708FhS`2dkLX0P;FI0>?ol03booL0o?oh05A;>P2bYI80
oo;U0?ohl00210005R<L09c0/P38mn<0Bh9U09[A/@2cjLD0/l6@09FEH@1KGbd0M7]809jYL@2FY6L0
e>NW0>Gk^`3:hZH0j?oC0>kohP3hnN/0ookf0>;Of03Kfm<0o?of0?7jj@3DhLL0b=>c0<kJ]03ao/T0
k?K10=7N/`3GiL40n_oW0?Soj@3loo<0nOca0080oooh0280h=gF0?Oej@3ooo@0ooko0?omo`3ooo@0
ooo_0?Soi03Bh;d0`=2[0>Omc`3Bjk@0c^jU0<GVU`3HlK00d>6[0?kleP2gZHl0Ie910?ogm03omoH0
l]gL0;6LV@2WT8X0JTm80>oFg03on_l0nOoo0?ooo@3oo?/0mmkQ0:1aN`3ono/0loG`0P3oo_lA0?oo
o`002P3oool09@38jYh0bNVM0<WYW@3:jId0c>RK0<_SV@3@iYh0dnVQ0=7QX03@h9l0e^ZU09B_HP1X
Mdh0d=nf0<?LV03Jjkh0eOoo07Ja]@3oo_l0OgAj00h51P011000MFaK02PY2@3Dgk@0bnVY0<GXY02l
fIL0hONi0>7[[`0i@P<0FF0M0=OTW03EkjH0f_Za0<3PU`30gYH00P3o0000301FLBX0b^BM0<WSW039
hi`0f?:[0=O/Y`2ebXD0^<n90<OQVP3To[L0cNNP0<[TW@80o`0000<0cn>N0?l0003o00000P3o0000
7P1J@1l0THEO0=SR[P3Ag:@0Z:9`0?obaP3oom`0j>Bo0>3/_034cIh0fM:V09B<GP1CDb40bNNY0<7O
W`3TiJ`0IF0Y0<W^Z038mZ/0`M^D0=[aZ`37g9L0i_Ze0<_LV03Kk:P0aMJB05aa;01>IAl0an6J0<7L
U@80bNVP0;00aNFL0<SXW`3<k:<0bn^R0<c/X`3>kZD0anNN0<CTV`3;kJ40bN^N0<oaY034i9P0c^fQ
0<SWV`34h9D0dN^Q0=3ZX03<i9X0cNFK0=3ZX03>ljD0a^RK0;kNT`2ogI<0bNFK0=gd[P11EA00go>^
0>Cd/`3Dhj80f^JX0=[RY`3GhJ@0bMfF0<KMU@36jZ80]n2L0:23F`1aBb@0TJ1O09n_J03;h9D0cNjO
0<c]WP35iIT0b>RL0<?SU`3:iK80_MJO0<?LXP016P0000l00<WPV03Ajj80f?:[0;oJU@3;iZ<0cNRU
0=[a[@036@0001400;c?U`3Wm[d0h^Z^0=oUZ@34dIT0b=nY0<GR/P2kkM00Ej2I07BbV`2mk<00eNRI
0=SWTP33kYD0^?:M0;?cY@2okJ@0d>FP0>KLU`3VlZX0_]Z@0=Og[037ii`0aN>I0=[_ZP39gIP0LhQ3
0>Go^031iih0a^bO0;kTS`3>j9h0PYIA0>ke_`3?f:40c]jO0>;g/P3Dl:<0^M>904IJ5@18FAD0RYEC
0;_5QP3Hi:H0h>fe07N5D03Ei[80YkZ30<OMW`3AjZT0eO2Y0<KTVP3RokD0`=bA0=cbZ@38gYD0aM^B
0<?SU`2;[F00aNFI0>?o]02od8T0fn^T0<gQW03QmJh0g_J/08^SF@3CkZ40c^ZO0<gYWP3<ij00bnJS
0<WSXP3:hj80c=ZO0?ood@1_ERh0PfI40?oog@3hom`0iooF0<CX^P36gkD0o_kL0?ooi00>50H0Mhn2
0=gbm`2J^l@0b_oo0=Koo`3lo_l0oO_o0>kmo`003P8084/g01hi600C;0l0?U0j0?Sok`3doml0l_kH
0<_J/@3OklX0m?oY0?3om`3[n_D0o_oo0?_oo`3hool0mOkk0?ono`3on_l0ooWo0?ocn`80oo_o02T0
n_Kg0?gol@3mon/0n?oJ0<gSY@3FgZ80e]fZ04mD:`3oon/0oooc0?oln029P8D0[JBY0?S^k`3oo?/0
oogj0?gln03clo<0oooo0?gmn`3oooP0j^cN0>KZd@3Lh<L0oOoa0?oomP3ooo/0oooc0?ooj03gn=T0
no_I04a9:P1OFd80OWMa0?C[kP3oo?l0oo[o0?Who@3mooh0nogl0?_loP030?cmo`1M0?koo`3koO`0
o?ki0?kon03nooX0o_oo0?KkoP3WoNP0Sjj<08JoS02]l;X0X^Zl07NeT03Hnn<0k_oc0?_omP2i]:40
ViEo0?olk@3oooH0G5IF038^;`000@80d^7L04moJ@15Q6L0Z_KB0<[b[03>iYP0cNBL0=[`Z02hcXD0
V:aT0;g>Q`3[nkX0dN2U0=3K/`3=e[T0ookf0<c1_`3Ba/H0oo_m0?ofm`3oo?d0mo3X0?ool03oon`0
oooN0?oog`3fon<0lOkT0?_ol@3koo<0o_oh0?[mm03nooT0noSa05aGD@3ooo@0ookd0?cfmP3oo?/0
n?S/0?ook@3:e;80f^W00::cQP3@jK00a>6Q0<kaX@37jYH0a=jO0<_MZ`3oon40/:B>06ABA03ojnL0
ooSf08A_K01_FUD0SW=Z0=o1]`34Zjl0oO;h0?Soo`3oo_`0oock0?[Qi01[?4H0oo_k0?kon`3oo_l0
o?[m0140oooo000:0?ooo`0N0<SWX@3;jJ40bNNM0<[VV`3>jI`0dnVN0<CJT@3Smk00UZET096OH@1E
IB@0c>RM06QhD@3@h;T0_mRF0<gN/P006aH0IZ6U0?ooo`22N7T01P000?Sni03oo^D0^;fE0?Soe`3`
oll0`^FQ0;oLW03DjZ`0dmfQ0P3o00005`2OZf40an6H0;gOU@2kgI<0c>jT0<WYX02ngYD0c>bS0<o]
Y@3ClJT0c>NP0=?]YP3@ij40fo:/0<WPVP38hi`0e_6Z0<GOV03Bk:D0b]nJ0=W]Z03LjjP0a]NA0080
o`000300JdlP09MgD02MSf80h>j`0<7ET03Gh9l0eMVN09VSKP38fJ80d>:T0=WDW@2NUEh0TiMJ0=ke
/@3GlZ/0a]ZC09VNF`3EhY`0`>FG0<7^W@2diiP0bOb]0;c[W@3;mjX0/]jA0<K`Y033kj80_>^M0<?d
Y@2ciYL0_NbN0<cZXP3>k:@0bnVQ0<CRVP3;jJ40dNnW0<GSV`36i9`0eoF]0=_i/@2ogi@0^Mj@0<g_
XP39jId0anNK0;GDR03:iY/20<gWW@2E0<oWW@3:hYP0an6G0=7cYP39jId0b>JL0=7_Y@3GljT0dnZT
0=;VX@2>XUd0b]ZI0=g][03Xm;H0hnR^0=KNXP3GjjH0Q9iG0<CYYP37kk00j<ZV0>6kU`3Dh:00WJYU
0=3RV03>kZ80^m^?0<g]X@33hiL0aNJG08^QL`1WNDT0cn:[0<kNX03BhJ00fNJQ0<SHT@3EiYl0Rj1K
04]P7@34fYT0enZX0<;FU`3Jl;80fNjc0<WKX@3Jhj@0o?o009JQG`3IjJ/0cN:Y0<?R^03Cm=l0_?SL
03^2FP2Tik40^nZd0=;Z/034gI`0b>bR0<W[X@37iI/0b=RA0<oWV`39jId0b>ZM0<K[W@39jIh0d>NQ
0=3UX02>Xf00a^6L0=Ci/`34jYd0`NF>0<gUU`2:WUL0dM^N0=cVZ@1;GaP0SZIJ0=3/W`3;iI/0e^VW
0<kQW`31g9D0e>f[0<WRX@39g:@0HgHo06Ab?`3>fjH0Uj9X06Ud>03HhZ<0f>VS0<GTV033gI<0c>:I
0<kTV`3AjIl0cNfQ0;gOTP3GmZX0Rj=I0>3[YP3FhI`0e^fW0<WPV03=iI/0c>BJ05E]8@38h9H0e>jT
0=Wc[031g9T0gONf0<COW03@iYh0g^>Q0>gIY01TD1d0embR0=7^[P2ojZ<0a?R]0;kXX03JiZH0gnJc
082>P@002P00i_oo0<Gfl`0kRXD0=Wal0?;oo`3Ym_h0hooo03b5I`2Yk<<0dN^k049F<@2@U8H020P0
0?onl`3oon`0m_CM0?ook@3hno000P3hool0903jo?T0mO[f0>CZiP3lood0o??d0?ojo@3onO/0jmSJ
0?oln`3elNh0ooko0?kmo`3_loH0m_o[0<cQ^03WjkT0m_SA0?ooi02k]j`0/jj[0?ojoP3onol0k>;[
0?olo`3lm?80ookj0?ono`3fmOd0lo;j0?;am`3emOD0oook0?oom03noo<0oook0?ooo`80ooco00/0
oo[j0=[Cc@3oo_<0oo__0?omm03Hc/l0gM;J0?oko`3on_l0oogo0?ooo`030?koo`<0o_ko0`3nool0
<@3oool0ooco0?olo`3Yj]P0g>G60;C>W`3Cl<00iOoK0?Ook03olNH0c:n[06a0@@3ono<0ooof0?Ol
m@3gnOH0N6]b07AOJ03Vb]H0ooWo0<;FbP2ojM<0MkNE02N9O02=m^l0Q^?H06S1[@0aNE<0Okn=0;WX
Y036jjD0d>^V0<gKWP3Lhjl0oo[f0?oho`3onOl0o_ko0?Coo`3bool0l?oo0>_fo03kool0no;e0?oj
o@3ooo/0o_oj0?kon`3oood00P3oo_d09@3mm?D0oocj05I;A`2=P7P0RW]d0?olnP3/in@0o_c_0?oo
k03Hh[d0d]na0=;S[032fiL0bnVO0<OYW032iiT0b^Jc0=3U_03nonT0ooo_0?omlP3on_L0oo_j0?oe
k`3omN`0oo;T06Q;?@3;/[D0k>7W0?Soo`3mo?X0oogk0?oem`3/_/P0oock0?Gjm03oo_l04P3oool0
00X0oooo01d0b^VU0<cZY03:j:00bnNL0<gXV`3Fk:40a=Z?0<WMU@3JjZT0cmfO0<OJV03Ckj@0EFDn
09>SO03Gl:h0g^o303IdK`3:ool0o_kn08MoO0060000locM0?Gde@3Oj;/0g>nh0<?SX03;kjT0eo6`
0=KZ[@040?l0002;0=3/XP3Bm:X0co6W0<[ZX@30h9L0[<Z20=GcZ`2mfi<0a^6J0=Sc[02nf940cNBN
0=;YX`3KlZ`0aN2I0<[UWP3GlJX0b>:K0>Ci]02db8<0e^FR0=SYX`3Di9d0h=NL069;6@2nYWP0M6di
0<7HTP3Lnjl0/LMn0:NkM037i:@0c^b/0=oc[P3KdYL0CDL90=ORWP3Gmj`0a=ZA0>Wf[P2CWE@0e^fO
0<SYV03<lJ40b?VZ0;c[W@3>n:`0`>ZN0<;[W`2ki9P0aNjR0;gYW032kZ40_NjO0<OaY@3@iJ00bmnJ
0=?WXP3Gk:L0d^NR0=3TW`2ndhh0d^NR0;oCSP24V5<0g?>[0<g_XP37jI`0_mnC0<g/X03Mo;00cn^P
0<gWW@3<iY`0d>RN0=O_Y@3HlZP0Zl]o08BTF033hIL0eO6W0<WSVP31f980c^>N0<CHT`2V^GL0e>NU
0>?a/`38d9D0e=jO0=oc[P2bbHD0b>^Y0;WQX`2oXGd0e[2<0>Of]@2lc8D0VJiS0=;bYP3?kZ80d?2T
0=;bYP3?l:40X;6409n_OP3DhZd0fNBX0=cVZ@3Jhj00h>^W0=o/Y`3Gj:80c^:M0=S]ZP33ei80dNFV
0=W_/@3;hjL0b=bO0=cWY@3WlJ`0V:5N0=7PW`3CiJL0l_oH0=_eb036n]<0L[B>05fWQP2Gck80jooR
0?Sog`32e9H0f?:Y0<CSU@3Moj`0b^VI0<WYW@020<K[W@1D0<SZWP3?iZ00c>6L0;G:Q`3Fkj/0an^U
0;oUVP37ji@0bn>E09FYH@2=VE/0XZi^09Z`I`2mf8T0cnjN0<SSUP3DijD0c^>P0<7SV@3<jjD0a>6N
0=G]/@25VV80WZai0>Ca_030b8l0QhmD09BJFP2a_7P0eoJZ0<kXWP39giH0cnNM0<kXWP3:jYh0c>jQ
0;kJS`3Fk:<0Y:iY08B?BP2oeY00d^VQ0<cTVP3IlJL0/l]o0=C/XP34g980^mF>0=ce/`2nf9L0bnFT
0<cRX@3Vk[80I5@S07EU=03Oi[00bN>V0<;[Y`31mJX0]n:J0=W/ZP3Wm;l0[;V_0008003LmO80g?km
06:WY01TZZP0h?Ko0?7oo`1iYi`0booZ0;7/_P33g:80i?G;06IVG01;@d40_JjY0=K8^`3oon`0oooa
0?oonP3in_l0lO;o0P3oood0;`3noo/0oook0?olnP3omOD0o^WX0?ojmP3djn@0ooof0?gmn`3no?l0
n?_o0?Som03Yn]X0g=jg0?oohP3alMT0oo_e0?ggm`3on?l0oo_o0?olo`3fkO00oogm0>cWi03gmOP0
=cHn00@23@0510X0Bd]=0?oon`3hn^d0n_ca0?ooo@3mo?l0oo_o0??/oP3>all0ooco0?kel03ooO@0
o?7[0>SNg`3onOl0ooSo0?ojoP3onoX0oooo00@0o_oo0`3no_l20?koo`0^0?ono`3mmo/0ooKg0>7N
b`36aZX0h^o40<_L/P3konH0ooo[0?ogl@3db<L0QdmB0?obl@3noo/0oooo0?omo`12=Ch0Lf9/0=S3
bP2VUiX000T005ieH`38j]40HKZd01V1P00ZRH<036AF06NaT00YJSl0QKEg0<_b/@2kf9P0h_2k0=7J
[@3ol_80ooSo0?_oo`3^ool0XL_908o0_@3Pool0iooo0>?goP3oo?l0n^Wk0?omo`<0ooko02P0oogo
0?olo`3oo?d0ooKf0>WKfP3ol>/0ooKb0?olnP3ooOX0n_S/0?ook`3Fg[T0f^Jh09BVK03HlZ/0e?2V
0<k]Y`3>kjX0cNRk0=7Va@3ion`0oooc0?onm@3ooO/0oocj0?ommP3ooO<0/if?09=hI`3ojnh0oo[o
0?Soo`3lo?X0oogk0?cXj@3W^L<0oock0?con`3emOD0o?cn4@3oool000X0oooo01d0b>BZ0<KRY@37
i:80c^VR0<kXWP38h980d^ZL0=G]X@3@iYh0b]nJ0<WNV@3Mmjd0Df4m071nFP3?j:L0dnFk07Jg/@3B
ool0loSb08^8O`030P00f>Vo08RDIP3Hj[00an2N0<SXW@2ogI<0TZMV07j>D0040?l0000>0<_YW`3?
kJD0`mjG0<WTW@22WEH0c>JO0=SbZ`39h9X0eNbV0<oVX030ei40[L9m08nTG`2cbX@20?l0000N0<?M
UP3Fl:T0]lj805M/9`3=gYX0c>>M0;[HSP2UZfl03@<009b@H029SU@0coJW0;KRS@30iY40^^2=0;;S
U031l:80c>6F09RIE`2/]W40e^bQ0=SiZP3ChIH0UimF0=;WVP38jYH0d^VI08jND`1[MS@0>4400P3C
f9P0503PhZ<0fmfN0=oQXP3MhZ80g^BT0=7LVP3PjJP0j>RZ0>3PXP3FeYP0a/J806MW:@1CDaD0GelQ
0;RhNP3IfI/0TY9D0=ONV`34h9D0/ln40P39hiT0]P3@jZ00LH]109RbJ02abh40a=jD0=;ZX03?jIl0
d>ZP0<SRV02@ZV40g_R_0<WSVP3;hY`0e^fW0<cVW`2E[6P0bn:N0<_PW@3Lkjd0gO6/0<_OVP2?Y640
eO6d0<KX[036YH80eK:<0=7XXP3JmJH0a>6A0;SDRP33gIH0^=B:0>So_02feHT0amRQ041?60075000
bm:L0=cOZP2][WD0QHU>09^QH`2@WeX0PI9<0<[NUP3;g9D0h?F`0<SQW`2I]WH0VkEd09BUG`2M[F@0
cmfB0=c]YP3LlZX0e_FY0;gVQP3:jZL0bnNo0=Cgo@1EPi80OZZe0;_Og`3Pl<`0dnN/0=KbY@35mi@0
b>bE0<WZV`38ji/0a^^M0<WYWP3>hih0^lb80=OZZ032eiH0anJS0<OXX@3<kid0c>RK0>Gl]03GjZX0
g_6_0<gYW036iiH0aNRF0<WXVP3AiZ<0dNRT0<CZW@34j9h0anRQ0<KSX`1dSU40UZUa0=c[/P3Afil0
hNZ[0;BiM`2Z]G00c>RM0<cVW03MljX0d^ZP0<;LTP3CljL0eONZ0<_WW038g9@0d=FB0>?]Z03VokX0
a^:H0<_SV@3Hl:H0a=Z?08NME02CZF00enjX0=gf]03>j:L0bNFZ0=_`a`3IiKl0GUTk0:JMP03^kLh0
iNo<0>_me@3DlL40g_c:0>Woc@3PmL`0<3Td02hZ:@2QS940oo[o0>Soo`1?SHP0j_oo092VX`0ZEd00
d?370<_V/@3Fk:/0i_K90?oonP3=a<T0onob0:6@R03ooNX0oog/0?oek`3ol_l0n^go0?oln`3onoT0
k>OQ08IoM`2QThX0IE580<fgZP3]f//0dlnf0?;efP3ho>D0oooh0?Cgk03Sk=L0h^oE0?Cbh`3gmNT0
ooof0?_gm03oo_l0m_Cg0?ono`3hloT0o_[k0?ono`0a<2h0OWin0P3oo_l04`3oool0nO[e0?Wkl03n
onh0ooo_0?kom@3jnoH0ooko0<k<f@3ooOl0o_Sh0?kjl@2>R7`0fmC:0?omnP3on?T0oo_m0?ono@3n
ooX0103oool60?ono`0^0?ooo`3fn?<0ooof0>;Qc03oonH0nokO0?ooiP3[k]/0lo7T0?oim03`dll0
]hn=0<Vo`03ln_d0oo[o0?o`nP0Y92X0KG5b0>[kl`3doo/0[:VP0:FDS0128ah0LgaA0>Cma036hJX0
a^6/0=Ke_02deYX0DgQ206F9F`27ZhL0eOK]0>Woo`3hool0j??[0<[ag02Ed;8097aD03nNM00IL500
R]:l0:gUfP3`ool0nOko0?olo`<0oogo0P3oo?l09P3on_/0oo_m0>kRi03on_`0oNo_0?omnP3hl>d0
ookj0?omm03`m=T0f^:k0>gia`3>h:80d>BW0<SLZ`3Fjl80loo^0?7ok`3looP0oook0?omoP3oo_l0
lo?c0??`j@3Neld0d;f/0?o_g03om?H0ooSm0?KooP3oood0oogj0?oinP3^`l`0oogk0?Kkm@3kno/0
o_oo4@3oool000X0oooo01h0fO6m0<cU[03;iJP0cnZS0<kXWP39i9D0g?NX07NB@`3QnJl0aMbD0=7X
XP32g980LX1L08jLN037gj40d^Bj03aoN02nool0nOoi07IfJP021@00c>:c0:FhP@3Ll[40`MbE0;_J
S03Zok/0[Kel0=;PXP3AhJ820?l0000>0=7dX039iid0cNRQ0;oITP2?ZF80bnFN0<gTWP3Aj:80e>VT
0=ca[02`aH00X[Ia09>WHP3Hk:L40?l0000g0<7LU@2]a7h0`MJA0=S/Y`3?iZ00a>6N05=H8P1UF2/0
XY5V0820C03ClJL0_^6A0<gXU`3;hiD0bN^O0<oaY`37f940F6<O0<gQVP3MmJ/0b>2F0=?OU`1]NC40
e^jR0<CSU@2K[F40d=ZC0>7OXP2]ZF`0iMbQ0=gDV@3XgZ<0f]2E0>cRY`3FcI80V99F06=Q902ATE<0
PH=406EW:01nP440]kUj0>OYZP3alk@0dmFF0>g_/03Qhj@0ZJ]/0=7JU`3KljT0j?nf0=_cZ@3To;80
RZ9H0<kVW0020<_UV`2E0<cVW03?jIl0d>ZP0=3XWP3JlZP0RJ1H0;oFSP3RnK40b>:K0=[d[@3:iIh0
_=FA09JaK021W5L0amjH0;oFSP3JkZL0dnRS0=cf]`3`om@0WWaG0;FBK02lf8h0cNnK0<?UT@1iTd`0
LHQ40<gWX03=jIl0eo>Y0<KJV`3;gJ40TZ5V071g@`2UYgH0/;:00>7V/03Pj:d0dN:N0=W]Y@3Xok40
fN^O0=3WW`38hih0_]jM0<GTX@3>iId0dNJK0=_^W`39gY<0cNFK0;WKSP2nl8d0c>JO0<[EZP3hool0
i_oo02eQK`1QUY`0iood0<k^_`35iJ80dOFK0<[ZU`39jYT0b>^I0<SZW@3:j9h0en^V06Yi=P3Vm[L0
iONi0<?PWP3<kJH0c>nO0<?RUP3Bk:D0e>VX0<KMV@3<kIh0`nVF0<_aW03>kj00b^6M0<gTX039jih0
a^JK0<_[XP2leYL0I7a00766B`3Kkk@0a]JG0<cMV@3;f980a=F>09NcJ025WeD0YK]b0=G]X`3@jZ00
_MfA0<OYW03Ro;80bmbE0>W/Z@29T4`0c>ZR0<OSV@32fY00ennU0<gSV03Dj:00bn6H0:g4OP3:hj40
aMnN0=C`]P3Um]@0nooV0=GC^P1nMUl0ookW0?oih@3mo>00nooQ0?Oog`3Woll0m?oT079hMP3gkN`0
QF]^0?oin`35g]/0;6QP0=gem@2@Xid0C7MK0=7^_P3:hZP0cnRW0=[[_`3emO<0k>K`0?O[k`2aY9/0
ookT0?oegP3om>L00P3on?l04P3on?L0oO;`07M/IP36^K40oo__0?7Kc@3mim80oocT0>SUa03GgKL0
o_oQ0?ooi03lon80cMRj0=?Pa03mo?P0oook0>WXi080ooom01`0n?Sh0?Gem@3oo_l0m?;c03`l?03o
ood0oook0>_/i`3in_D0lO;/0?oom03oonl0loOL0?7ff03^lM`0`lFg0<o?c@3gmoT0oook0?oomP3o
onh0h=g:0<c9^P3jmO40oo_k0?ono`3oool0oOgk2P3oool0;P3oo_d0oo_h0?3Ne033[9h0onoN0?og
i`3ol>80oo_d0?ojn03QaL@0QF=R0<6IU`3gjNT0oogo0?g`m`3on_l02@T;06E`K03`ood0jOoc0?on
n03ok^X0cjf/03Pe5P2S/8D0_<jT08VSMP2fgZX0bO[20:SY/@1f_hX0>8EK07g@_P1ic<@0Nk>J08jm
V`00=@/03dTI0;3_^P2gml<0X]nf03mhF00VFT@0c_Sf0=koo`3iool30?ono`80oogo0P3onO/0903o
o?h0oogo0?olo`3oo_/0m_7]0?oln@3lnO@0X::<0<77Y@3_n</0bMRQ0>Sf``3Ulm00i?;I0?SomP3i
ooP0ooom0?omo`3oo?l0oogo0?kmo`3oo_T0[ZFL0?ojk03on>H0ooCf0?oioP3gool0o_kl0?[elP3o
nOX0TfQa0?ojn03koo/0oOgm0?[koA40oooo000:0?ooo`0M0?Gog@3Gk[X0cNB/0=3YY@3>jZ00cNZJ
08JVD`2jehD0dnnR0<o^XP3FlZP0bn>I061ZA`1<ES<0j?k00?Soh@30oo`0=gUh0?Son01jOVl000H0
0<COZ020WE/0bnZN0<_ZVP37hY40A5/=0<_GU@3PjZd00P3o00003`35k9d0`nnH0;gKT@1mTTd0[L9m
0=;WXP3BiZ40b=bG0>Gf/P2]_WX0WZeZ0<gLV@3Mk:T0e^FR0=CUX@040?l000290=Sc[02;YEh0amjH
0=C[Y@3:h9l0Z[>408QhEP1hE3X0]HM`08QWB03Jd9/0l^b`081]<P1^F1h0JU/T05]B6`2;TeL0doNa
0=?g[`3AiZ<0f]^O082<C02L/fl0fORb0=ca[P1lQTL0f>NV0<SVWP3Im:d0]Lb60<ONV03JkjX0c^>N
0<cQW035g9H0d>ZS0<CRVP35hi/0c>bS0<SXW`36iYd0bn^R0=Kf[@3>kZD0e?B[0<GUW02ngYD0c>bS
0:2lLP1fQd00`]><0:2aJP3Hk:@0cN>J0<SNU@3@j9h0eNfS0=C^Y03>jYl0c>JL0;gAR@3@hIX0I7Pa
0=;XX03;hYX0cNNP0<SSW03?kJD0b^RR0<7PVP38jJ80_=jB0=;aY@32f8l0gO6Z0;c@T`3HlKL0Pelk
09]hCP2ig8`0c?NN0;KNR037g9/0d>FT08bSG`2abh@0cnVR0<[YV`3@jZ<0dnNX0=KR/02T[7d0Ri5U
07EmCP3Ihjh0fo2[0<3JT03Ln:@0d>JD0<CLT03<jZ00b>fW0<;VX038ii/0cNRI0<oXU`37hY<0b>BG
0<?PW@33e9d0f^bb0=GW[@3Znll0i?OK0>Coo`2mk_80D8n709gG`@3<nMP0h?Rn0<gWWP3:jIT0b>^I
0<WZV`3<j9h0a]NC0;o>R`3fol@0iOFg0=3ZZ`3<jjL0a^ZP0<WXXP37hYl0c>FT0<KQWP37k9`00P30
jY@0A037jYP0c^NS0=?XY@3:gi@0c^:J0=[`Z03Nm;<0/LV;09bfM`3@kJd0`N2J0<_[X03@lJ80aNJG
0<kZW`3Snk40QYaC0=;ZX03?jj00^mf@0;oQU03GlJL0eNFN0::SH@2IX5`0a^JM0<g[X@3HlZP0`m^A
0=7VV`3BiYh0eNVQ08fTGP3?iJ@0^]BC0>Cm``3kon40o?oQ0?cog`3oon40^J>;0:b>MP2>KUD0YYId
0<K3VP2fciP0hocB07UkNP3oo_/0=ST^06QdJ03Wool0D92007V3PP3Vk>80]nBm0;G]YP2nkZ@0]m>I
0=_ac@3PjO00noko0>OVj`2<RW/0]:n70=SAY`3ooml0oo[c0P3on?X03`3C_kh0dL2h0?o`i03on^P0
Id`g0?olg@3omm<0/[B50=GOZ`3BgZh0k_;G0?coj@3MhM80o?of0?Cbo`020?ono`0L0?ooo`3lo?X0
n_cg0?[mmP3fn?<0J6YY0;k2`@3nood0oooc0??fi@3ooo40ooo/0<_@/P2i_i/0b<nS0=_S]03Cf[40
nOoM0?;gh03anN@0o?oZ0=SO`03;dJl0_/6R0?ooj03Fe/h0ooko0?gno`80o?oo00<0o_oo0?ooo`3o
ool00P3oood30?oon`80ooom0340ookj0;^WWP1QACT0onkR0=J^Y03CZjT0]YBE07YWK@1cJ6h0bLC1
0?oomP3ooo40nO3W0?onmP3ZkN@0m_ge06YaJP1aMW80oogn0?omo`3fl_<0no_k0?OknP3Gc/L04@@0
08IoK@3oonX0Yk>50<KGX02lfY@0bNfU0<[a[P2oj[D0e?oB0;SX]031lkP0_^VT0<WbYP3:kI/0b>VH
0<?SX035iZl0doC902A6=@33j>00n?oo0?koo@3noo/0o_om0080o?om0P3lool04@3amoL0n?go0?co
o`3oo_d0oo[g0?oloP3oo_l0KfeP0>c^eP3WjlP0m_gC0?Sof`3nooH0o_oo0?_kn`3no?d0oo[o00@0
ooWo00d0oogk0?ohlP2]ThH0HT4`0?ognP3oo?l0look0?koo@3oo_/0ooWi0>:g`03ooO/0n_oj0080
o_oo4@3oool000X0oooo00`0mooV0=GW_@3:gZd0d>VW0=;/X`37i980TZmK0<_XU039j9P0cnjR0<ST
VP3BjZ020?l0000>0=K/[03Bi[D0]N_M097=a@32h=@0k_c_0006003BjK<0bnJS0<[VV`34h9<0a=n@
0=?YWP3JjJH40?l0000?0<G/V@3OnK00FFhY0=K[YP3DjJ@0c^:M0=g^ZP34di00VZUV0<CES`3Ll:T0
b=jF0=;VW`37fi@0go>^0080o`000?h0d>NQ0=C[Y@34fiD0hoZd0=3WX@3AjZP0en>a065E;`0I0000
M4H_06Q39P2[VfX0GE8J06EG6P3ZfYh0hMJN0>CMYP3Pk[00`^bT0;[RV`3DkJT0g>:V0>Ge]P0jEA00
^]VC0<gRX@2KYfT0cnBQ0;kWV@38lJD0eOV_0;KKSP3GnJl0_n6G0=?eZ@30iIP0`nNM0<O]XP32jid0
`NbM0<K_X`37l:@0`^RK0<?YW036k:40a>ZM0<W_XP39kj@0ao2T0<O/W`3Rn:d0b]nD0<cMUP3@hIX0
d>6K0=KWX@3>i9`0c>:I0<_SV@3>jYl0d^bR0>7bZ`3Gj:80W;1Y0<cRVP3CjZ80dnfV0=KaZP3:j:00
_mfG0<[YX`3=kjD0b>RM0<KUV@3KljL0cnFL0>Gk^P38iJD0ME8Z06m<8P3>kJ40cO>L0<O]V03=hJ80
enb[0<cSW`2DZfL0dN^T0<KRU`32g9D0f>n[0=3RYP3AgZT000L009>LK@3Cgjd0c>6P0=?]Y03:jYL0
dNVM0<[VV`3;jj00aNVO0<CXWP39j9`0b^JI0=;]WP3Ckj80a^FG0<gXY@3Fi;40hoo40?7oc`37fj00
go;40>[onP3Rool0?Wmg0878^03Iood0gng<0<gUZ@3:j:00bNVP0<[XX03=iZ80enNV0=k][039eiT0
e^VY0;[ETP3BlJ/0a>VL0<7QV03>k:H0eo2^0<kYY03>kZ80b^fM0<SYVP3>jYl0dNBT0<oOWP3AhiT0
e>JL0=KZXP37g9/0Y;Un08fTK03:i:L0c^jS0<[/W`3DnJT0b>ZM0;oKT037hIL0SJ=J0=G]X`37hIL0
d>nS0=CcY`3Cjj40dn>L0;o4P@1GHA`0e_BZ0;gISP3>j9h0d^ZP0=?[W`3;hiT0cnJN0<cSW@35g9P0
mOo<0=[b]03Di[@0bMVX0<oHZ@3NhK@0mnW40?odd@3ooMP0HU<Z05EA8P3HiJd0d^2_06m`HP3:c[l0
00@000@B1@3TooX0>WYZ08>=Q03HflP0^=nc04^:@`2bkZH0c^o20>Wji`3gool0kOgo0?3oo`2ga[<0
FE4]06=C;`1ZEcT0Gd]005m:A`1XD500FdU70?okm03on_<0onoO06a@>P3IbjH0mNc10<C4T03AiJP0
mOoF0?ook@3oonl0oOoe0?konP3lo_l0moOo0?ono`3imoP0oooo0?ooo@3lood000800?Ckm03kooP0
o?oc0?Sli@3Sil`0c]>e08F=IP2ob9/0eN6_0=;OY`3Fhj/0f^Jf0>3X_`3lonH0o?oX0??mf03Ni[d0
d]^^0=[P^P3Ffkd0oooh0?[jo0<0o?oo00@0o_oo0?ooo@3nood0ooom103ooo/20?ooo@1H0?onnP3o
n_<0HDHk0?o_i03omNd0oo?a0?ofmP3on_l0nO?e0?coo@3kooX0koOZ0?oomP3oo_P0o?oh0?Som`1W
KVH0MWQc0?cbl`3onol0ooko0?_oo`3cood0oocm0?ofm@0=0`00ooWZ0;FbS`3>dJ@0e=bQ0=WSYP3G
hZH0eN>b0<_H[03>j;/0c^^k0<OPY`3AjJ/0cnBO0=7VX@2ldY@0goO30;[EZP1=KU<0eOST0?3oo`3d
ool0nooo0?_on03ioo@0nooh0?_ko@3nool0nooo0?KonP3nool0oOSe0;Vd/03ooO`0oOWf0:jaWP3o
onH0o_oM0?cof03lom`0o?o]0?comP3moo@0ooof0?oonP3oo_/0oogm0?kjn@3oood0n_G_0?oll`3V
c/@0KTi30?o^k`3ooOl0nOoo0?oon`3oo_X0ooKd0=6]/@3oo?X0o_ok0?_kn`<0oooo0P3oo_l=0?oo
o`002P3oool02`3koo<0c=Vk0<gL]@36fYd0W[A/05Ub7`2lf8<0g?RS0<o/W03>jYl0dNbU00@0o`00
00d0dNZY0<KXa`2_g/X0DI>906N4O`074`D0g^Rf0=?SY03=hi/0f_2X09J]I@3Aj:00cNBN00@0o`00
03<0bnFK0<;FS`3;giP0fo6Y0=W`ZP3<hIh0/L1o09^WI@3JjJ@0dNNN0<7PTP3=kYl0b>NK0;kHSP3B
jJ40cn>L0=SYY@3FiZD0e>BS09baKP3Cj:D0eNnX0<WWW`3:ijD0X:Ub05]C9@2>LDl0HDDP05E>601n
Pd<0]<Il0<KLT@3RnK<0cnRT0<_/Y@2ojIl0`^ZQ0<_]X`3DkjX0anFO09BdJ`2^c8@0`MZF0;K=R@3=
j:40`NRI0<[`X`33j9/0cNnR0<?UV@30h9D00P3=kJ408032hYL0bNVN0<O/WP31kYd0_NRI0<7WVP3@
mJL0b>ZM0<c/X@3>kZ80`N>F0<[_XP33jI`0`^VH0<c^VP3;jiP0b=jC0=SYX`3>fYP0g^ZX09^ZI`38
g9D0c>:I0<;QT`3?jj00b=bE0=W]Z02_`gh0cnBO0=C[Y@3Ajj@0b>>L0P3>k:@08038j9l0do6Y0<gW
X035g9@0eNfO0<_VU`3;jj00bo6X08IU>02JMDT0RImF0=C/WP3<iiP0c>:Q0<SNW@3>i:<0cnRV04iW
8`2Z_gh0cnVP0<gXV`3?ii/0^Lf806]e@@0a>P/0TY]^0=SY/P3=iZ@0bNVM0<[WY039j:80bNVP0P38
ji/20<[XWP2K0<cWX03<j9h0c>RM0<[XWP37i:40`_J[0<Sf[@3Jhj`0d>B_0=Sfe03Lo^D0Ah5b05^d
X03:ool0n_[h0>gof`36hJX0b^F^0<WQY`3BiJd0h?:f0>?e]`3HjjT0d^VS0<_WW034iIH0a^VI0=Ki
Z@2kfhl0a=jE0=[aZ@3@iYh0dnVQ0=7PW@3MjJT0dmRN0<kFV`3Hk:D0d^NJ0<WNS`39g9`0BEXV0:fn
TP3=hJ`0d>bQ0<WYUP33hiP0bn^R0<c[W`3<j9d0]Lf30;G;PP34f900e>RP0=W]Y@3<gIH0e>FN0=CT
W@3Ci9d0`]V;0=O_X@3@jih0an>F0<WXW036i9X0do6W08NQF02X_gT0n?o60=gd[P3@kj`0`n2M0=;Y
X`38g9L0j_Jh0?ooc`3lold0^k^907ekB022Nd@0h]VR00P:003Chkh0IE]I00X2003Voo40@gmc092P
QP2_]Hl0cNFe09OCU@1AUE`0K9R10?Soo`3[n?l0i_oo076cY@1fXh`0/Z:;0<NTT02eT800`Z^U0;RS
X02FO7/0c;jm0?oknP3onoP0oo_/07UJAP3Pi;80jo:l0>WT[02ohid0j?oC0?ook`3ooo40ooof0?gn
mP3Zm?h0nooo0?Ofn`3ooOl0noCk0?omo`2TZJl000H80?GolP3gonX0nooM0?oog`3AeZd0T9QY0=;R
Y03>hYd0d>JN0<GLU03@ij<0b]bX0>Shb`3ion40o_oQ0?[oe03Bg:P0g^Rc0<K?XP2Z/Hl0loK_0?gn
o`3lool0lOCi0?coo@3loo/0o_ok0?con`3noo/00`3nood0@P3oood0oooo0?ooo`3oo_/0oo_h0>;=
b022JF@0glK10?oel@3onOH0oocj0?kimP3lood0nOom0>cilP3gn?X0oooo0?koo@3noo/0@4<j06Y[
H`3oooX0ookk0?Wgn03oool0n__m0?ono`3mmoL0PGah0:^WWP3oonh0fmW40<k=/@3glmH0oooT0=SF
_@3KfL80h>7?0?KiiP3jo>H0m_KN0?Wlg`3go=h0m?oO0>Okf03=jL<0U;bG06jKM01_XY40h_oo0?So
o`3goo80m?oR0?OojP3on_l0ooWo0?ono`3<eL80/jbT0>3Gd03hlNT0jNKO0;o1]03Gh/@0hO370>?e
`@80h_Rg01L0h_No0>?ea@3[mll0jOG=0?Woh@3]nmL0h>k;0>GbeP3Vl=P0mo[Y0?ool`2JQh<0/YZH
0?oln`3oood0o_ok0?onn03ooOH0oo[f0>G=b`3olo00oogj0?omo0020?ono`030?ooo@3oo_d0ookm
0080ooom2`3oool000X0oooo00/0oOog0>3Xd`3Eh<00S9eV0<oTW`3Nmj@0eo2L0<KRS@3ElZ80d>nS
0<[XX0040?l0000>0<kYY03?hkh0foo[00AECP1GOWd000@00=WMZ`3NiZ/0^<B20=OVX`2K[fX0cN6L
0=K[YP3?iZ020?l0001G06]o>P3Hij80gNZU0<?DSP3CjJ40^m:>09N/J@3Dh:00en6R0<KET03Bj9l0
aNRH0<kaX@3<jZ00an6H0<KPV@3Sn;D0`MJC0=?VY03Ik:X0dnRS0=?ZY02neHl0_m^A0<WYX03IjJ/0
e]JR0;:OM`1PCB<0fMZQ0<oKV@2ohY80^Mj>0<SZWP3KnK40^<b70=CUX@3NkJX0fNRU0=WUX`3NjJL0
T9UH0<_AT@3^m;@0T9EE0=oZYP3Ckj@0a>2E0<3LT@3Onk00an6G0<?MT`3Bk:80dn^Q0=C/XP3GkJ@0
c>BJ0<WUVP3@jZ00fO6W0=[`Y`39giH0e^jT0=OaY`31h9@0a^RK0<G/W@37kYd0aNRD0<_ZVP3>i9/0
f^^U0=WUY@2HY6@0g>^X082DC@3?iYh0bNRJ0<;QT`3CjZ@0PiQC0=;YX`39h9X0e_2Y0<gWX03Ajj@0
c^VR0080b>>L0;T0dN^T0:6`K@1nSTL0cN2A0=S]WP38ii/0`nVP09AgB`1lFc00bNBM0:;2MP3Hmj/0
`MJC0=7VX`3HlJd0cNJR0=3YY@3GiJX0amfE0<[UUP30gHT0eo:U0<gOY@2LZWL03AH008JCGP1kRTl0
_mJ@0<[WY@38jZ00b>ZM0<S[U`39jiL0bNVM0<WYX03:j:80b^RP0<[YW@3:jI/0a^JK0<;^X@36k:40
e>2P0<gSX`3AkKX0aNJk0;kcf@0eP6`0G::J0?7oo`3`oo<0hoWE0=;V`@3Fikd0ioO:0?_oe03;gJ<0
ambI0<GLU03=j9/0b^NG0<;QT@3Mo:h0cn^N0=K`YP3NmJd0O8e907^:A`2IXf@0QHeA05iT:02>V5/0
HWLb0;78N03JlIl0eNRX0:^hRP1JJD80NXYK0<SPU034h8`0_M^C0<o^Z03;jil0b>NK0<[TVP3=iI/0
cn>K0=[[Y02@XEX0UZYR0;_AR03GkjD0dNNN0::bJ`26Ue40dNRP0;kHS`2jeHh0b>JN0<gXX@2ab880
Y[Ye0<CCT03NlZd0b^jV0<3PU`3;iYL0goNY0<SRV`3:i:<0c^JZ0=SU[`3@dih0ZIaW0>7HW`0fBPl0
MX]P09>@L@0d;a40R:260;3Se02Lb;L0Wl2S09:UN030jK40]nVh0>[on`3kool0h?[o04Z1Q003H4<0
RlnZ0?koh`3onmd0o?_V0>koo@3bo_h0oo_h0?oon`3oo_d0oocj0?olk03jflH0f^>^0=SRYP3McYL0
doB_0;CPX`3dn^`0n?kb0?conP3io_P0m?ko0?koo`3]jNX0ooGd0?oko`3oo?l0F5eQ0??oo@3YoN40
k?oG0=S/[@3Wl[X0WjY`0=[XZ`36fIL0ambG0=G/Y02fd8L0d^bS0=3WX`3Yo[d0dN>W0=OS/@3Mik80
fnV^0<[HV`3:e:80o_oQ0?kon03nool0ooko0?Oin0020?oonP<0oook0`3oood30?ooo`0E0?ono@3o
o?/0ooOc0?okmP2CPGd0oo_d0?o_j03ml^`0oo_h0?;dk`3bn?@0nOoo0?OkoP3in_h0oooo0?ooo@1M
GUP0@T<k07AeK`3ZjN@0dm7B00@0ooko00L0ooom0;nk^P2e/Zd0nOK_0?onmP3on_80oogf0080oogd
0P3ooOP0=03_i^40_[>_0?[ak03oo_D0o?oc0?Ool@3/onL0dOGA0<3Z`P1j^Z80Gi^C0>koo`3`ooL0
mooV0?klk`3okol0ooOo0>oUk@32aK80oogh0?olo@3omoP0o_gk0?oon`3`o>H0a=Fe0<gO]@3=hZX0
bn>Y0<gQ[03=hK00d>:`0<kR[@3Uo/D0fO:h0<[VZ`38gjL0jOg:0?kog`2j^i`0oog]0?oci`3oool0
nooo0?koo`3oo_d0ookk0?olnP3onoX0oock0?oinP3knO`20?onoa00oooo000:0?ooo`0<0?kon03g
o>P0o?oV09RYL`3BiJ<0c>FD0<;NRP37i900cnjN0<OWV`3:j:00a=jG0P3o00004P3;i:80_mZG0<oS
`03VooP076eV07BKVP002`80h^Jd0=gUZP2FXEl0f^JT0;k?R`2HZFD0bmnJ0=O/Y`3?hih0Wk1/0;_<
R080o`000?l0VZ]U0:k2N`2/`Gh0]lZ80>3/[039di@0gn^Y0=[^Y`33hiL0`>2D0<[TW@2X_g/0OiQD
0=C]Z@3<iJ40bnBP0=?]YP3?jJ80d^VS0=W_Y`3HlZT0dnfV0=7LX02GUf<0b;J>09j=HP3Uj:l0bMZF
0=?dY@3DmjL0^MF;0<SOV@3Tlk00i?2^09fXIP2Z]G<0Xja[08fCD`37cHd0jNj^0=KKV`2OXF80e]nL
0=3XWP3Dk:80c^JL0<GMT`2DZV40UZaS0:NmM03IkJD0am^C0:>dK@2T]Fh0eNFN0;W9PP2^^gD0/[mi
0=WYXP39gID0dNNN0<?OU03:jYh0a>^L0<7XU`3MoZd0a^:E0<KLU03Kk:P0T9aL0:jjNP3EiZ80TjMP
05=[8@2jfHT0goj`0<[TW@3=i9h0a]fG0<cSW@2hdX/0`mfF0<OQVP2T_WL0TJ]T09:/I@21V580bmNE
0<KCS@2AWe@0U:AI0=7[XP3Fmk80Q6Lm091cB@3<kJP0boBX0;CIS02L/6/0d^JQ0=S_Z@39hi`0an6J
0<oJX02db840e>bP0<CQS`36hYD0d>JX0<gNZ02=VFT0_/JC0:>/L`3Ci:00c>NR0<SZW@38jiT0b>bE
0<W[U`39jId0bNVP0<[XXP3:j:00b^VM0<cYV@39iid0b>RM0<SWV`3?hi/0c>JM0<GSY`39jkT0h_od
0:OPc@1LUHh0Z<_=0=[bi03]onD0f^[=0>Gcd03koml0n?oE0=[Y/P3HjjT0e^bT0=C/X03CkZ40aN2C
0<CNU03@jZ00_mN=09neK@3=hI`0f^^W0=o^[@3KjZT0bmNI0=OUY`3=ij00bnBC0=3WU@2ndI40d^:c
08jMMP3]oLh0HgT^0>Wo[`3GlZ/0cN^U0<GWVP34i9P0c^ZO0=C^Y03Hl:H0bmnG0<kRVP3<hYT0L8Pn
09>]H`3KljT0c=RF0:BcLP3<hIh0hOZf0=;[Y`3=j:<0bNBO0<oTX@32eY40SYYH08VIF02@/F`0b^RP
0<kVVP35gI40h_fh0=7[[03;iJP0c=fV09nVLP3:`HX0jnZa09>^M`2]`Y/0_/JC05aP;@0I9`h0]^7@
02APF02_h<d0XkbD0=;`_036ikX0mOof0?WgnP3PoOl0S/K308ON^`2RhkP0e>^o0=GW`@3[on`0fooo
0>[oo`3ooOT0loWe0?gmn`3lmo<0ooc/06a@>03Qj;@0f]nU0=:nR`2of9L0c_Bk0?Wom03kooP0o?ok
0?Smn@3iool0ooko0?onn`3onOP0nno_0:ROX02m`L00n?oj0=S^bP3IlKl0f>n[0<[JV@3Ij:L0c]jM
0;kCTP3^ol<00180`mZF0>3j/`3CjZ80R9iE08jSF02>WeT0T9mV05]Z<@2;Ved0`]:D0=7MZ`3_mm00
mo_]0?oon`3oo_l0no[h0?Shl03oooX30?onn`<0ooom0`3oool07@3oood0oo_h0?oln@3oo?P0k]oL
089`K03ono@0ooC^0?kel03oooX0oook0?[on`3nool0oOko0>k^kP3oood04A8=07IgL@3ooo/0LG1/
0>[Xj`1jN7d0N7El0?ono`3jn?/0ooko0?ono@12?S/0`[jk0080ookj00<0ooci0?C]i`3oo_P00P3o
o_P0=03ooOP0ooGa0?cbl03oo_P0o_od0?Wol`3conl0e??D0<_^c@2UhlX0<W1S0>Woo`3aool0o_oc
0?gfl03ol?l0ooKo0?oko`3]j]/0oocm0?olo`3onOd0oO_o0?kno`3eoo80f^SA0<oN_`3?h;@0cn2c
0<oO^03@g[/0enZl0<[Q[@3=jJl0`mnR0<7NWP3BjjX0j?g20?WodP3hn=80dlN_0?ogi@3oool0nOoo
0?coo`3oo_l0ookm0?olo@3onO/0oocm0?cfn03lnol70?koo`/0oooo000:0?ooo`0O0?kol`3nond0
nooU09:SK`3;gJ40d^bR0<gZVP3<ji/0`^FE0<S]W@36j9`0`n6I0=_c]@2R]g`0LHU;0<_SY@3<gl<0
iOol03J8Q00bFUX000h40=cS/03IhJD0TIaJ0<gIU`3DiJ40QiQD0<CIU03>hih0cn>N0=;SW`040?l0
00140=kbZ`3=hYl0cMfN0=;LW`2LY6P0^<:309>RG`31gI<0^MB=0=KXZP2DYV`0cN>U0<[YYP31iIl0
d_R]0<GYW`1kVDl0NiE<0:>dKP2CY5h0e^NS0=;GW@3LfJH0TH9I081eB03Dgj<0fo2[0<o^X03@jih0
UZ=N05UX9@1nVE80c>JO0=?]YP37hIX0b^BM0=7XXP2oeY00amjH0=?ZY02Z_gX0eN^S0<cRV@3EjJ40
e^ZR0<KJTP3>giP0e^NP0<?DS@2AXEX0T:1I0<WFT03<ei80g^6N0>ob[`2X[FX0WjAQ09bWHP2]^W@0
c=fF0=3XWP39hiT0anNK0<k^XP3?jJ00bn:J0;W=R028W5L20<kOV`3:0>?i/@2O]fd0aN2C0=3_W`31
h980b^FN0<kYXP2X`W/0SZQQ07VCC01NN340_mJ@0=7XXP3@ij40c>6L0<SMV03Hk:L0gNfV0=_WW@39
eH/0fnbX0=cd]P2OOEX0UGAA0;gTY@3=n[D0_^RN07B5?P3Gjj<0cN>J0=?]X`35hIH0f^BX0=GVX01A
Iah0^MJ60<?SU`2jeiD0g?Ji0=OZ/`0`<P00QX=>05MG6`3?iid0a^bE0<K]U038k9@0b>^G0<WYX039
j:80b^NT0<[XXP3:jId0c>VI0=7XXP3?hi/0cnJH0<_/T`3:kI<0/=F70=cl^@2jcJd0m?of0>Woo`14
Og/0WkRe0?_on`3kooP0o?o_0?coj03@fk00gn^i0=3PX@39fYH0d>BL0<OKT`3Hk:D0h_>_0<SLU@3N
lZ/0PYQ@0<oTW`3Ek:H0d>ZS0=?]YP32g9D0`mjG0=Oe[@2ngX/0d^nK0<cRX@2>X700M8=L0=WY^P1k
T4D0_=>10=C[Y@3CkZT0b>fO0<SZW@34i9P0bNRL0=7`Y03;ii`0bNFJ0<g/X02jfHd0c>^O0<WSVP3B
h:<0bMNJ0<kTX`3Mm[80f_F`0;oMU@3<ij00e^fW0=;VX@3>fYP0b]ZI0<GOWP36gi/0bn6H0:BlL03D
kjX0c>^X0<WWZ@3=iJ/0V:M^0<c>S`3:di@0c>Zh000>003ImZH0TJQH04a<=03Cl=X05FET05fYW`2d
g;T0]/RN0;>mV`3_g=H0on_X0??olP3Zoo<0HIIX09g7U@2gjKP0R/NN00129@1:QH/0DWZ60?3imP3d
ooh0l_cd0?oon01nK5P0NFI60=SQZ03Mh:L0b;:30=GTZ`32gZd0n_og0?conP3koOX0n_ci0?ooo@3o
o?X0ooKc0;FRV`1;?3D0R7id0?cok`3Gi/T0a^6/0<SUY@3>jYd0]<an09B/H02:XET0TJYV08bUI02V
_gh0_]>B092UHP3>giP0e>JL0<7BR`3DjJP0bn6Q0<_PW`3:gYl0fnVh0>cgc`3joNX0m_KZ0;fh/P3N
em40ooge0?omn0<0oock00@0oogm0?ono@3oood0ooko0P3oool20?koo`0@0??em03mnOH0ooSe0?7S
h01XFE@0kmkG0?okmP3on?<0oogg0?okm`3oo_l0oooo0?Gem@3oood0o?cj0?ooo@80oooo00/0n_[l
0?koo`3fmOX0oooo0?Sgm@23PX00M79c014?40040P<0ooko0?ObmP020?ono`0g0?cjo@3ooOP0n??]
0?S`k@3on_P0a[bk0?omn`3ooOP0o?ge0?comP3goo@0k?o[0;ofe`1TYX/0bOcm0>[oo`3fkoL0ooWo
0?ojo`3onoP0VHR00?okm03oo_l0nOKo0?[go`3ooOl0moOo0?coo`3foOH0nood0?_ok@3kon`0o?oc
0?comP3RnLd0cNZb0=3^[P3?kZP0eOFZ0>go^`3Rn:l0d]ZQ0=;DY@1nL5D0ooCP0?ooo`3iool0nooo
0?ono`3ooOl0oo_o0?ojoP3on_d0o?Kh0?_ko@070?koo`/0oooo000:0?ooo`0K0?cnl03mon/0o?oT
0<KGX`3Eij/0bN>J0<OSUP36iID0d?>S0<kcX`2oi9H0dO6V0=_c]@38h:@0CfL[0<;JX03Bi<`0i?on
03R:R01/U9H000H00=SP[@3Qjjh0X[5^0=;SW`3Bij80d>FP0080dNRR00<0g_F_0<;GTP3o00000`3o
0000o`3NlZ/0dnRU0=WYZP2EWF40dmVM0<_EUP2HYf@0eo6X0>3g/`3AgZH0b=NP0=?X[`2hfiL0a^jW
0;[TV033k:00d_:W0<kXW`2kc8H0WZeX09VUH`3>dIP0gMNU0>7DZP2_YgT0dn6T0<CKU@3Al:80UJeQ
08><B@3RkJ/0c>ZR0=G`Z@3>k:@0aN>K0<SVWP3>k:@0d>jV0<g[X`3:j:00bNBM0=3/XP3?iid0d>JM
0=?YX03Bj9l0h?B/0<GIT@3QmJd0gNjW0<;CS03JjZ<0e>BM0<WCSP3AfiH0bM>>0=oYY02Q[VP0bMVB
0=OXX@34fY40b^:H0=3ZX03=iih0d>FP0<kSWP2GZVP0a]VG0=O[YP3Hk:L0bn6I07nGC@3:iIP0`n:D
0<g/X03<jZ80d>jV0=[e[P2ie8d0cnVR0=K]Y`3Bij80bMjI0=3UX03MlJ`0cNBN0<KRV035gI<0fn^P
0<[FS03=g9T0_]BF09=/C@2>JTX0]MNK0<kg]@30iIl0VZaR0<cQUP3?iIX0f?>V0<SWV@3Ojjd0fnbV
0=3TW03Ln:d0a^JJ0=;c[P3DlJl0]lbA0=SHY03[hk80SXM@0=3VV`38k9@0b>bB0<S/U039jiL0b^RR
0<[WY@3:ijL0c>NT0<cWX03=j9/0d>NQ0<_UV`3<iiH0c>j@0<K^SP3CnjD0cNRQ0=kM_`3ioNh0j_ok
00U1?P2W_;l0o?oo0?Kkm`3ioNh0o_o/0>7Y`037dj40eNFW0<oPW03[o;D0c]nH0=7PW@27UUD0E6DQ
03mC3P3Cj:<0c^FM0<gWWP34hYP0bNNM0<KVV`3FmZ/0/M680>7o[`37ii80dNNV0;c>WP1YN540`m>T
0:BiKP3JlIl0c>6L0<_TX035jY`0bNjP0<[/W`37ii/0a>BH0<c[W`3:jId0bNVM0<g]X@3AlJD0bnVO
0>Cf^03:gId0bN:N0;oMU@30h9D0g?b`0<_[W`2mehh0c^FM0=o`ZP3Dj:<0enf/0=?XX`3<hIH0OYA9
0<KQVP2ogYX0aNFT0=;/[`2]`H80UiiK0>;XZ038fZP0IWI?0<W/W034hI4030l00>3hhP1c_;D0Kkb/
0<;fd031fkP0d=W40:N?S`2RQX80nOWM0?Woh@3AkK`0dN^l0<Cle@00@B00?I5j0:GDgP0O>DP0n?oo
0?Ooo`3WlNT0ooof06IA?03Fb:D0fnJ/0>GZ/03Nc9h0fnbf0<OQ/P3lo_<0oooh0?kmn03oo_X0o_Wf
0?g_k03on_H0H4a303d]802=Q7<0o?oV0<KF[`3GlkP0b^VU0<CST`3=jYX0dnjQ0=?]X`2mehh0Qj1L
059[9`003P2L/740aMNI0<cKX03ChJH0cmjS0<gSX`3=iZ@0fo6a0<cPX`3Eh[@0nooN0?ook@3IelX0
mo3X0P3ooO@04`3onoP0oo_k0?okn`3ono/0oocm0?omo@3oood0ooko0?ooo`3nool0o?oo0?_oo`3_
mOD0nOWg0?onn`3oo?P0o>gX0:JESP3[f]<00P3oo?H01`3omo80o?_i0?ooo@3oood0no_k0?koo`3j
o?/00`3nool09@3lool0oOko0>[[i@3oooX0k^oZ0?ooo@3jn_X0F5QJ0?3_m03ooOl0ooko0??bn03o
o_l0oook0?_hl@3oo_X0oogk0?3Vi`3Pe]L0oocl0?onn`3oooX0m?ca0?GolP2ijlP0P<:N07Nd[03O
ool0nO7n0?oio`3glO40lNGG04dl;03onO80oOgm0?koo`3mo?l00P3no_l00`3lool0nOkj0?comP02
0?cok`0H0?kom03nooP0f?;30<GTZ037j:<0`n>H0<;SU03:iIH0fNfU0=gT[P3Oh;H0H54l0?o]g`3o
ood0o?oo0?koo`3ooOl0oocm0?oko@3on_d0ooWk0?oko03nn_T0ooom1P3oo_l;0?ooo`002P3oool0
803KhLD0nOoP0?cog`3JjkD0c^:U0<gWX038iY`0a>>G0<OYW03AmZP0a^^M0<W[WP3AjjX0dNV]061e
?@1TNdD0jOSU0>Coo`0`PH806T=50009003>gJH0bn2O0<SOV@3CkJH0`^2H0<CTV`33iI/0d_BZ0<OW
WP3=kJ@0bNNO0P3o0000<`3Dj:00amfE06=h=@2_`X80g^J[0=SMX`2KXfL0YK5c0<gVXP3?hj@0emn^
0>Wc`@3doll0d_:a0<kf/030k:40boFY0<k`YP3HlZ/0dn:Q0=GTX`3<f9H0^;^205aF902HRf40C4DG
092NH@2dbhD0_m^>0<_QUP3>di40jN^/0>K[Z`3Gg9`0XZQX09NMG@2S[6/0X:UX07f8AP2;UU@0^/F3
0=CPWP3IjZ@0bn^O0<c[W`1oWU80dO2T0<WUVP3?jj00a>2E0=3ZX0030<cVW01N0<_ZWP3@kj<0g_Z_
0<OSV03=iid0QIeC096WGP2=XET0UJIO0=7QVP3AhY`0e^VW0:boO@3MlZd0aMbF0=_bZP36gID0e_2W
082JD@3KmJ`0`=N?0=G_YP32hYT0bnVQ0=_f[`33gYL0b>:K0<[QV`3EjZD0enbW0=7UX03Hk:L0`M^D
0<7`X038lJ80anBD0<oVV03BhZ40TZIY0;f>LP32T7L0nOoF0=ca^03<iJ@0d>FH0=GZW@3?jY/0a>6A
0<?TT`3Bhil0[Kij08nSGP30fY40b^ZO0<CZW`39kj@0a^FO0:Z_M`0k<`@0F4XI0=;TVP38jI80bN^D
0=CcY@35hi/0b^>/0=3X]P3bomT0iOc60<cTZ03Ck:P0cnRV0<7]WP3:m:00c>>90<CdT@2niXh0h^nZ
06a9<`22Ofh0GW9V01/k>P2NYJl0oogo0?ooo`3ooo40o_oZ0=;M/P1KIcD0eNFV0=SYY@3HjJ80/L9l
0=KRX080e>>R05L0dNFP0=3UX03@k:80a^BJ0<_]X@36jid0bo:S0<?YW038jZ00cNnK0<GUT03@jJL0
EVXi06QhD@3Di[H0cN>H0=O^W02N]Fl0fO:^0<c/X036iYX0b>RL0<7QU@31hiH0a^RK0<_]X034iYT0
`N>F0<SXW037iI/0a^6J0<WUV`3@lj<0`NRE0<3ZUP32kYL0a_2J0=3cX@3AlZ<0`]bB0=7XX039g9X0
f^^U0=[ZW`3;gI40XKeb0<c/X`32hih0dNj[0=O^Z037dHP0K6`V0>gM[01ZMTP0^mVU0=7`]@003@00
:cXS0<_cf01QVG@06V4e0:cLc033hn80mooo0?Cei`38aX/0iNFM0=WOX@3aomH0<hE^05RmZ`2Joo40
jooo0?Sho`3ZmO/0k_Ol0?GonP3fn>/0l]g20??`a@3FjZ/0k?Zm0=SAY@3@hkD0g_G;0?onk`3on^h0
0P3oo?<0C`2QV9<0]J>O0?ofl01iHeP0=2<A08j4J@3QkKd0fNjc0<OWWP2ohI@0aNRH0<g_X`38j9`0
bNRJ0<WVU03;iYD0d>RL0=c^/P3Tl/40jo?K0?Cjk03hon`0looB0=;/Z`3eom40i?S30=7P^@3Fh;h0
X::<0>3Oc@3lm>T0ooW`0>WLeP3Se=40gm7A0=k@d02m/K40oocm0?omo@3oo_d0ooko0?ooo`3nool0
o?oo0?Soo`3do_d0lOKb0?onnP3gk>P0oo_f0?ojm03ok>H0NFYU0:>FT03mkn`0oooj0?7`k0000000
^;Rh0?koo`3bloL0o?oo0?[no`3kood0m?_d0?Ckl`3hon`0o?o/0?_ol03ioo40o_ok0?coo`25RH`0
GEiS0;Nh_@3inOl0o_oo0?konP3loOL00P3oo_d0>@3hl_H0ooco0?olo`3hko80oogm0?;_jP3oooX0
eOS>0;W__@10PVH0foom0?gmo`3oo_d0noo`09bHM@1NCbh0oocZ0?Soj`3konl0o?oa0?con03hno@0
o_oh0?kom03nonl0f>740<cE^03lond0n_o_0=_h_P3<lZT0a^^N0<[ZWP38ii/0cnJR0=?UZ@3bm]40
ookU0:NIV03ei>`0ookf0?oml@3ooo<0oo_d0?oilP3on?@0oo3/0?odk`3ol>X0oocd0?[`i`3oo?H0
oo_e0?okm`3on_H0oocf0??XhP0;0?ooo`002P3oool02`3Bg[P0nooM0?_ofP3?hZX0b^2R0<ORW@3<
ij00d>jT0;WKSP37k9h0a^^M0080o`0000h0_mVJ08nTK0003@00mood0=_nnP0XNGX08D]:0008003O
lKL0cnFT0=?^Y`38iYh0eoV_0;SLTP80a^bQ0:l0a^ZP0<k`YP3o0000o`000<WOUP3?iI`0V[5Y06f4
@03Hjj/0f^BX0<gBV02a^Gh0en:V0<kWY@3?iJL0c]JW0?kof03kom@0a^BT0;kQW@2niYd0c?FY0<GT
WP34gIT0dn>U0=KVY`3Fij<0/KIl09bIIP2>PEL0HET[0=?NXP32ei80eO2S0=G[X03Ih9d0e]JH0=kL
W`2LVUd0G5`N07=e=P29Rd`0S95A07Ek>`2FWeh0`lb;0=ORX03IjZ@0c>jQ0;KHR`2;Zel0^m^?0<WY
W@3=k:00b>NK0<g/X03=jIh0an>H0<[YW@37kYl0a>^L0;KKS@35jY`0c^fQ0=KbY`3<iY`0S:1H06]l
=@3Kj:80gnjY0=7TXP2O/W00eNbV0<KPU`2lf8h0dN^R0<WSVP2@Yf40PYUC0=S[Z@3;h9d0_M^C0=7_
Y`2mf940eo:[0=cf[`3HkjT0bn2K0<gRW@2oe8l0d^JQ0=;]YP2hjIP0^nRG0<[[VP3:iiL0c^>N0<;H
VP3;VGh0f::80=kV/`3bolL0`MBD0<kUU`3?iYP0d>fM0<GTU038jIP0fNjY09N[IP3JjZT0gOB^0<7L
U@31jY`0`nbN0<k`YP1gP4L0;bT00963EP3>gYL0bNJB0<gZV03?jZ<0aMfO0=;W_03GjL<0kOoI0>Sk
cP3GjKL0bMnQ0<SRX`2kk9d0_NNE0=[/VP2nl940c_6Q0=SLW`1^B3<0aLZf020k:P0W=ST0/K6k0?oj
o`3ooo/0o_o]0?Klh038e:H0TJ1Y0=GUY03Bhil0a]N@09BUG`3Dhj00dn>R0=?TX03@iJ00cnJP0<gY
W`35iIX0b>ZN0<?XV`37kJ00`^RK0<7SV@39jiL0cNfH0<kYYP1/P4l0LH5J0=OY^@3>i9T0cNBB086H
DP2N]g<0dNfR0080dO2T0<40e?BX0<SXW035iIT0b>ZM0<g]X@3AlJD0d>nS0<OVVP3;iYl0anFK0<?X
V031j9D0_^ZC0;[VS@35lIX0^n6>0<CTV03AkJ<0e_2Y0<kNW`3GiZ<0a=690=W[W`2[aG/0bNNQ0<g^
Z@33h9d0dnZV0<_ES01ZIB40lmNX06AZ>P3Im</0anNf000M00003@00c^:o08F^PP1;TVH0=6aS09g:
d039l?D0e^gI0;NnN03IgX`0c]ND0<kU^@0KM600FL>e09?lkP3Ijnd0n_On0?;oo`3hool0m?ol0=7E
a`3bfk`0o_o@0>co`@3Rl;<0al:H0=o`a03gon@0ooc]0?olk`3olnT0kM_A06AKEP3onOH0oo[f01P2
000c8Q00F58b0<kKY@3AijH0bNZK0<c_W@3;kJ00a^ZR0<OYW@3:ji`0c>VG0<gXU`3@j9`0j?[00?_o
g@3cnnh0mo_j0?WonP3eomP0_MNH0>Wob03RmLL0ho7@0>K_dP2VZ980hn;>0?omlP3ooO@0nN_X0?oh
m`3mknl0b;bl0:nSX`3oo?d0oo_k0?ooo@3oo_l0oooo0?koo`3lool0nOoo0?3jn@3nood0oook0?ol
n03onoH0oo;/0?ojm01dIF00_:nY0?okn03ak^T0oooj03<c<`3oool0^;Vm0<?4b03ho_h0mogk0?_o
n03foo<0nOod0>Cbd@3WmM80h^oC0>O`f`3ioo@0o?ok0<75aP1FFUd0>3`o0<[;d03nool0ooom0?oo
n`3em?80ooko0?omo`3oo?l0fm;G0?olo`3kl_<0ookj0?3[i`3On]40]>2[05NEKP1LRgT0mooo0?[o
nP3Ymmd0YJIn06YP?03_hlT0m_oO0=g[b03bnm`0j_;K0?kol@3XkMT0o_o/0?koj03GhK`0dMfg0>gh
eP3/mmT0e_Bf0<S^X`38jYh0cNfR0<g[X`3Cj:d0d^>_0>O/cP3oonl0Z9jO0>OGhP3on^d0n?;L0?oo
k03oo>d0ooCY0080ooSa00@0`:NR0;jZX`37]Zh0oocc0P3ono<20?olm0030?ogk`3Hbl<0oooo00X0
oooo000:0?ooo`0:0<OLX@3Ejjd0e^b^0=O`[`39hZ00`=^D0<KQVP0eD`T0bNNM0<KVVP@0o`000100
cN:Z0<WO[P3AgLl0_^7M06Bf]0003PT000T00<oTX`3FkJT0c^VR0=[h/035iid0d?:X0<K/X@32j9d0
an^Q103o0000>02idhT0dNfS0<g[Y@3Fk:`0noo>0?ooc`2PZG00bmVN0=;/Z`3<i:P0g>Ff0>Wa`P3M
jKL0e>R[0<[SXP30gYP0e?:/0=?][03EkJl0n?oC0?;oc03GlZ/0e^JX0=kS[@2KSV@0UHYM0<O?U03?
h9`0bnJI059Z7P2KZ6<0eN2N0=kYY`3Dgid0f^VV0<GFTP3Vmk<0f^nZ0<[TW@34giP0aN>K0;cLT`2n
h9@0`>:E0=[l[`3@lZD0MiU<0;WIS@34i9P0cnnS0<SWV`3?kZ80cNVN0=3`Y03An:T0_^FF0P32jIX0
FP3:kj40]MN:0=?bYP3;hiT0eN^R0:RiLP3Jjj@0CfDM0=G/YP2cchD0d>nS0<WYW@2kfHl0dnbX0=K[
ZP3<g9h0C5DN0>?^]03=j:40an6J0=cf[`3:i9d0dnfV0<CNU`17GQP0Ni9<0=O^Z02hchT0T[1X0<kg
Z`37kYl0cO2N0<k_WP3?kj@0bn^X081E<`2VLe@0b/fF09^QI@19EA<0d^fP0<GQU03>kj00`^FE0<CY
V@37jI`0f>n[05AT9@3FhJD0eNRV0<GZVP3@o:L0]^2>0=?WZ022QU@0gMB[09^WI`39giL0cN:O0=7S
[`3Dhk`0nOoa0?WomP3koo@0noo_0?_oj03>g[40aMjT0<WVY03?hZ00dmRH0;[PU`3FhJT0[Ymh0?od
h02@]iX0?6UB09Z>TP3EcL/0o?W`0?ool@3Tk//0dn2d04mQ9@33f9L0d^JO0<kRV`34eHh0d^JN0=3V
W@80cnJN07`0cNNN0<cXWP3:j:00cN^S0<SZX03<kZ@0anRQ0<WZX`3@l:L0dO6N0;oORP3DkJ/0^LfL
06UiDP34f:L0b^FH0<cXU03:iIh0a]nK0<GFS`3Pm:`0d>RN0=G_Y@3@k:40_m^@0<STV@3ElJH0e>jT
0=7YW`3@iil0cnJR0<kWX`33hYH0`>>C0;kST`38kId0`NJH0;cKU`3Ajj`0f^nf0>cmb@3an//0oooD
05QR9P1mR4`0f>j`0<WRZ@3DkkP0cnR_0=c]]P3Xk[80gmJM099eB`3^jL40E6A00<o]^`38m:L0H6i=
06mTA03IhKX0bOSF0=ooo`19Oh/0:7mf0=GonP34k:H0bnZL0<7JV@2lfJd08FmG03JCP00nVhP0eN[Q
0?Soo`3Eo?l0kOoo0>gon`2CX8`0lMZh0=OUZP3Nlk00gNFZ09J6I03Mg;h0oooZ0;2NT01OCD40VHMm
0?o_j03oo_/0oo_k0?k^k`0>0000XiJ309FAKP3Lk:/0`Mb?0<kaW@33jIH0b^bP0<?WW@38jZ00anNL
0<oYX03BjJD0dNFV0>Wic03gon00nOof0?Soo@3Lj]d0c>B`0<_R[034eZ`0_lj_0?_ol`3dnn/0e=G5
06]YFP19@SX0H5ID0?ofm`3ooO/0ookk0P3on_L00`3cknh0ooom0?ooo@030?ooo`0V0?koo`3lood0
o_om0?oonP3hl>d0HEA>071QG03ol>/0oo_f0?oln03oo?X0nO7^06m/I@1QH5/0ooko0?CdmP1bLgP0
00440?_oo@3iooP0n?o]0?SojP3Gi/D0cNB/0<_UYP37gj/0d>Fj0?Goj@3ioo40nooh0?OlmP3lood0
o_om0?7ak`0<3P/0Gf5P06IXI`3emOL20?ono`0c0?oko03Rg]d0kn[W0?onn03km>`0nooQ0?Oog@3<
nlD0[^2j08J_W`3Gn>L0_mRh0?koh@3oon40ko?@0=OX/@3>h:@0QiIO0??oe03domL0oOoN0??nd`3b
o/h0dnFY0=?WZP3:hZH0bnB[0=[k]P3@lZP0anJS0<cXZ`3Aj[40d^>i0<kL^@3io^L0m?OT04a9@03o
ooP0al>V05iK>01<AbL0IeQ105M4<`1`F4`0I4U00?ock@3on_<0oocc0?oil03oo?@0oo[b0080oocd
00<0ooG]0?ohl03oool02P3oool000X0oooo00X0eNnX0<cUX@3<iJ40e>nZ0<?NV@3So[L0]<n80=cg
/03:iY`0cnfS103o00004039gZH0bmn^0006003Io?P0;7ij02UFC`002P00bn2M0<WMV030ei40eNnX
0;_IT@3<jZ80b^ZQ0<SXW`37iih40?l0000c0=KeZ@3=kJ80_]fG0<kWYP3ZnKh0hnjf0<[EV`3NkK80
`M^L0>_oa`3Tl<00i^jo0=gW/`39fI/0gnn`0=7VX`3=i:00amfO0=7Y[@3eomH0l_oC0;CFS03Kkk00
fN2Z0;2SN@1hJcl0k_6h0<[FU029Y5L0]m:50=;VW`39fYH0a]fG0<WPVP3KmZl0`MnG0=7_Y`39jj40
`^RM0<7ZWP30jYh0a_:U0<ojZ`3AlJD0bNVM0<[YW@2VaGT0D6lS0<STV@3FlZL0bNFJ0080d>ZP05l0
_mV?0=7]XP3Onk00`^:F0<g_XP34iYT0eoV/0<?SU`2ofi00^mF;0;S@QP17GaD0d^ZP0;cFS@3JnZh0
]mZ:0<OYW03AlJH0f_2_0;O9R`3Ii:`0EUXX0;c3S@3Ajj@0dNRR0<WPVP3Aj:80dnfV0;7;Q03Ilj`0
cNNP0<OQVP35giP0T:]T0<?NU`3BkZ<0d>nO0=7bX@2mhYD0/MVB09YgC`1^@Qd0F60T09NPG`3KjZD0
c^fQ0<?SU`3<kZ40`^NI0<?ZV`39lj40dNZV08fMG`3MiJX0aMBC0;_NS03<n:40_>ZB0=G_[P2FXfh0
aL6K08bGF`3Ai:@0dN>W0=?R]`3HhlD0mokf0?_oo`3go?P0n?kb0?Sok@3Dh;X0b=nW0=oT[03Yhjl0
i>B`0<SVZP2m^900NfI90?Soj02<bJL07ETm07=OH@38_kP0oOcX0?ooj03Ym<T0enRd07F:B@3Pmk40
eN^R0<kTV`2I[FH0a]bC0<gWW@030<[YW@1k0<[XWP36i9`0cN^S0<KUW`3BlJ/0aNBP0<WXY03:j:00
b^ZG0<cYU@3Ck:X0_M6P07>5G@3>h[40b>BG0<3PR`3?kjH0b^FP0:6^J02ochP0d^JN0=K/X`3@j9h0
fO>Y0=3ZX039hiT0d^ZP0<kTV`38g9L0eN>X0=o_/@3NmK40cNNP0<_VW`35hid0cnZW0<[OY`3Pl;l0
i>o50>?]b02BVGL0P8IP0<W?W`3Hh:l0enVg0<_Q/`3NmLT0i_W<0>cic@3NgJd0aKn?0:2BK@3Zg;l0
k?W;0<[XZP2ihiL0/;bH00d0003Vi<d0foON0>_oo`3Pool0<XUi08K6[P3Som/0cO6d0<cS[@39fk40
^ng@05fMP`00@2P0lOoo0>koo`1o^K/0EWj007nXUP22V840lM^f0=OWZ@3Ei:40hn2Y0>?5Z@3chL/0
hmK507]ZH02n[JD0oo_f0?ogm03fm_@0nO3c0?ocmP26MFh0Vi1n09jKN03Cij80bNBE0<W/V034jYL0
bnfQ0<K[W@38jYh0aNFL0=S`]03QmL00hoG50??og@3eon80l?kT0?Kok03AiL80`MRP0=3V]@3Ei/80
d^370?_on03ho_@0n_[^0?Cbi@3]i^00f=3>0?ofn`3on_L0nOGb0080ookk00<0moKd0?ooo@3oood0
0`3oool0G`3oood0oook0?oonP3el>X0jn;M0;2SW@2APW/0oo_f0?okn03onOH0oOSe0?ono@1ZJF@0
aLBo0?klo@3oool0NW^00001103foOH0nOof0?Soj03don00aMN]0<gZY`39jil0bNNW0<oZ/`3/oMT0
moo[0?_om03goO<0o_oh0?GfkP3oooL0iNOT0:VZ[01<CDl0824U0<g>d02SXjD0ooko0>?Og030_KP0
oood0?onlP3oon`0jNo=0<CW/@2`h;H0A7]T08fmY`3Cl]<0o?oX0?[oiP3YmM40eNNY0=CXX`37fYX0
b=JS0=gY^`3Rk/00dMf[0=c[/P3CjZH0bnFN0<_YX`36iJ40co2[0<[YY@3;ij`0g?C00>cod`3eon40
nOoX0?coj03nonP0/[JK05AI>`2MXWX0VYad0=GE/@3Zh<L0i]O40;n]X@3on_<0oo;^0?ojn03onOD0
oogh0?oim`3iknd0o_Cb0?ohmP3omO<0oocj00/0oooo000:0?ooo`0;0<KUU`38ii/0bNRL0<_WW@3;
iYl0]M290=Sc[03=j:40_=R>0=7]X`3<ji/00P3o0000403<jZ@0dNJ]0<oS/01JIUP0UKRd00mTG`0K
B44000/00=__ZP3EiZ80bmbH0=W]Z03NmJl0d>ZS0=3[Y039i9d40?l0000d0:g8N`3<k:00]]R<0=cm
]P35gih0d^BZ0=CQZ@3HiJd0fN^_0<SUY@3aolh0m?oA0=oW]P3IhJh0eMnS0=cXZP3FiJ@0Lh=40<OK
WP3fom<0`m^Y0<k]]03Ook`0`mbK0<SAVP2HRf40He@Y0;6`N02d_gd0h?^^0<GQU03VoKD0dnRS0>?h
/`2bah80NiE>0<_VW`3ClJT0aNNM0<G[X035kj<0^nFI0;KUU`2liiP0e?2U0;_GS03>j9h0d>ZP03iH
3P3=iI/0f_:X0<oWW@80cnFL05l0V:aT08:BB`34eHh0bN6G0;KBQ`31hID0bNVM0;?ER03Knjl0b>RL
0=_j[P3;ii`0`=Z@0>;n/`2oh940doRX0<K[W@36j9`0b^2O0=WX[@2JXfh0gMb^0>c`_P3CjZ@0enbW
0;oFT03_ol00W;I_0;G?R02nf940fOB]0;WDS@3<ij00b^BM0=7MV`3Ol:T0b>>B0<g]VP30jIX0`>jS
0;jSMP30WG<0bMRE0=CTW@3>hiP0a^RK0<?UV039kZ00aNbM0<O^W`31lId0aN2K0<;BU02NXf/0_<J9
0=?fXP2lj8l0`O:I0=3_Z`2odId02P`008bGG`3GiZ/0i_Bo0>Wcd03`n>40o_oo0?kno`3nool0o_kl
0?oon03Zlm@0f^jk0>GCY@37Zh<0Ti1S096UM01MAbl0Zi1m0=_lg`1Y^I80K[FE08iiN02eZil0oOgQ
0?goh@3Lj[L0cn6U08^RFP38h9H0bn>G0=S^Y@2_`g`0fO6W0<[YV`020<S[V`1n0<WYW@39jIh0bNNO
0=;`Z03<jZ@0h?fj0<gXY@3>jjP0`mjG0<;OS@3MnZH0_mRF09>WMP1[OED0bn6`0<OVV033iHl0bnfS
0<ORW@2S[FP0RIA?0;C4O@2P]6`0ZKmf0<SPUP3<i9X0dNNN0<_QV03Ci9d0h>n/0=[Q[P3Yl[d0k_c1
0=;TYP39gIh0fNf`0<;EW@3LjKd0k_KA0<33Z03Nh<P0ooo/0=7D^@3Lh;d0j>k80<_J/`3Ci<00k_oO
0??oh@3homl0cLVS079`B@3bm]D0Z9J005UT:03>kIl0bO:V0::]P`0E1`00W9><0>Wbh@3hool0g?On
00aE@P0fKEX0ioo_0=_mf03Gi[/0j^[40<cK^P24Xh@06D<[0??oo`2F[k<07VQW08k4a00UFD<07cdQ
0>OD[03:g9h0bM:A0>SLZ02VOFL0OEa=07=HC`3mk^L0oocf0?S/k03on_/0o_oo0?omo`0>0`T0n>WV
0>cTd@0j=a@0bMfF0=cgYP30hhl0`nRH0;kPU036k9L0b>VJ0<GSW@3Un<X0m?oO0?SoiP3ionX0mooV
0=_]``3GkK`0d>R^0=3XZP3>hK@0looS0?Wol`3jooT0o?ok0?oomP3lo?00ookh0?ohn@3oo?l0ooom
0?Wjm@3mo_T0o?gh0`3oood30?ooo`0P0?ooo@3ooo/0nOK_0?onmP1CB480oNkW0?okm03oo?H0o_?a
0?onn`3em?80oooo0?oonP3[j^D0ooko0?ooo`1RHfP0IFU/0?WonP3conh0eNK20=GX^`3>hZl0b^bO
0<K/U`3:jj@0cN^]0=[_aP3TmM<0nooa0?7hj03gnnd20?oom0030?ooo@3nool0m_Oi0080o_oo0340
aLK80000002g][40oooh0=??``3cl>40ooga0?oojP38hJX0_o3103n4J025_jL0gooX0?Wol@3koo40
gO7<0<KIU`3?i9T0c>2K0:flP`29UF<0_<RF0=CS[034eYP0d>ZP0<KRU@3>lJ40a>VL0<SWX`36hj<0
d>Rd0>Cjc03gon<0nOoX0>GbeP3Li/@0mOoJ0>Oc``3QkK/0g>Ff0<C=XP3/l</0oooV0?ogi03oo?<0
oo?_0?oin@3omoL0oo_i0080ookm00D0oogl0?omo@3ooOd0oogl0?oknP0;0?ooo`002P3oool06@3=
lIL0aNNA0<g^W@38iZ00e_6/0=?/Z034gYL0b^6I08>ID@3HkZH0eo6W0=?eWP3BlJD0b>>L0=oi^032
gZ40f^K>04eWG00iPGh0;EaF000?003Di:<0gn^Y09NVH`3FiJ800P3o00000`3EiJ@0d>2O0?l00003
0?l0001;0=7`XP34jIT0`nRJ0<[/XP3:j:80d^NV0<GEU`3Fj:X0gO6d0<cYZ@3>j:/0cn:[0=CQZ@2`
^gl0c]VG0:6ZJ@2kaHP0`<^A0?Sod@3=h:T0e^fe0<SVZ02ihYH0cnRW0=WT[01FBAl0JeX_0=cJX@3@
fIP0b^JI0<g/WP2ddXX0c>>M09BJFP3<eI@0d]jL09>OG@1aOC/0eN6O0=_ZY`3GjjH0aMnH0<OYW`3;
jj00cnFL0=W_YP39gID0dNFN0<SLU@31dX`0c]nI0=_/Y@3>hYX0c>2H05AQ6`3VhJ40e=ZL0=o`ZP33
eH/0b]nD0<_UW03<k:<0_^FF0<S[V`3<kZ@0bN^Q0=ok[P34hiD0c>nO0<7VUP34jI/0d_BX0=C][02M
/GH0m?o<0080oooH02`0nooA0<cLW@3GkJ@0AUhD0=7/Y@3:j:80c^jU0<GUVP37ii/0_]jC0<kXX@2Z
[W40bmBA0=C[V`37i900_nbI0<GjZP2/W6P0TW]90<k]X@39j9P0aNJE0;gVV039lZ@0`NZL0<?/WP30
jI/0boRW0=?aZ`3GjJ/0gnB/09^SI`3=jI`0aN^H0<oiY@32hZ40f_6k00H>002c_H/0cm^Y0?cof03V
l<h0mO[V0?ono`80ooco0280oogo0?ono`3konl0i?gC06m;<`31V8@0enS80?7ok@3om_40ooCX0:7P
]@0lWG00]ooR0:nNSP2:P6D0n?kB0>;/^03@ij<0dnfT0;gHR`3=j9/0f>jS0;kDR@3AjI/0d>fM0<S[
V@36ji/0b>ZM0<WYWP3:j:00aN2K0=7ZYP3:iJ80joo30P38iJ80C`3Dl:H0bnRF0<cYU`3ToKT0V:mg
06=iBP3:hj`0aNBF0=GfY@37jIl0bnJQ0=kYY`3Ghj40dN6J0=W[X@3Cj9d0aMZ?0:JhKP28V540Uj=Q
09JOH02AU5l0Mfa>096;J@36b:00d]V]0<cHZP2]^Xh0c=R`0?Ggh@3ooo40oocj0?ojn@3oooX0nogb
0?ool`3jo^d0lOc[0?WomP3doo40oood0?ool@3ml]h0W9b40>coj02:NV/0e^:J0<3NQP38iJ<0X:Qi
065HF@0:00L0@2hZ0?oan`3in_l0b>oL06n=P`3^ool0lOoo0;^kU`1eHSP0ooOE0?okh@3oonX0dmgO
08JYZ`0XPg40M[VX09oD]P0kFSP0KE/c05MO9P1RER@0JddW0?oIbP3omNd0ooOb0?onnP3oo_/00P3o
o_l0903kood0knkd00`53@3om_H0a;^Z09fJM`3JjZT0b^:H0<oaY@2kgiL0aNZL0<?[RP37jI<0`]nL
0>;ee@3con/0mOo_0>?de03@h[P0d>JU0=3XWP3?iid0dNNY0?Soi03honl0logd0?[no`3nool0oooj
0?Ogk`3oo_/0noOh0?omo`3oool0o_ok0?cnn@80o_om00<0o?kk0?koo@3nool00P3nool0F03oood0
ookk0?onnP3kl^d0Y9JC0?odk`3on_H0ooOd0?oim@10>cP0aLC20?ooo@3oo_X0mo;^0?[hn@3oool0
FV1P0004003ao^X0n?oX0<cR/@3HlKP0aN:R0<O_V@31k9<0b>jQ0<S/YP39i[00dN^k0>7ac03ion@0
hnc=0=cNaP3Hf/80oook0?Wjo03lool0nooo0?Slo`3lool0o_om0;>d[`13A3`0kN_N0<g;_03Mcl`0
`[6Y0?oof02ihZH0OlnX052HP03Foo40lO[g0?SonP2nfjl0dNRT0=7XV03CjIh0aMNM0>7__03=fjX0
joW40:k0Q03<i9P0b>FE0<G[V032jIP0bNVP0<kXZ`3Kkl`0k?cQ0?Ooj`3SlLd0f>O00=o]_03PkkP0
h_J_0<[PU`3GjKT0cM^g0>C_c@3nond0noc^0?omn`3onol0nO3e0?omo`3Zj^`40?coo`030?[no`3l
ool0lOGh00/0oooo000:0?ooo`0C0<;ZR@3;k9/0cN^S0=W`^038gJD0c^>R0=?WXP3?hIL0[<5f0=3T
W@3=h9h0dNVO0>;g]P3>i:<0d?NX0<SbWP3Bfjh0;3HN035RIP020?l000030<gEXP3KkjX0Zl9j00@0
o`000?l0b=JI0=K[YP3o0000o`000<k`VP2ni940_^FD0<;WU`3=kYl0aN6F0=_aZ01UNC80cnBO0=;W
Y03ToK/0cNJU0<oUY@32f900//Ml0<7FR@3Bhi`0f>N/0<[HX`3^n/P0bmRR0=KUX03<h9P0b>:I0<oM
W`2VZg<0Og=906aQ=03NgjD0bmJD0=G_Y@2S_g@0Z<J00<kYY038gIP0a=^E0<;MUP38hY/0WK5/0=WO
W`3KhJ40cmjK0<WSW030kj40a?2Q0=G]X`35fi<0fNfV0=_/Z039fYH0QYYE0;;6P@3Ek:@0b^BJ0<?R
U02?XEL0i=bN0<KNY034j9h0dn^M0>7XV`31e9@0c>VY0;WNT@3Cki/0b^BS0<?PX02ofi40aN>I0=?e
Z02hgHl0cO:U0<?WW@2hfI@0RJMW0?;od`3eomH0n?oL0?ooh@3Lijl0/<Me08VVDP34j:00a^^V0<[`
X`32jIP0^^2;0<c_W`39iid0CF@N0=cdZP3?k9P0a^RB0<KbW@36nZP0`K1l0;^VL@32iiL0a>jH0<_g
X02hiiL0_NbL0;kZV`2kiiP0`njO0<WUV`3>iIl0b=^I0<oNW@2`_gh0fNjY0<KPV@3Il[00d>F]0<[L
ZP0a?180^lBI0=[X]`3iomH0enRk0=CR_P3ooo<0oogh0?oio`3onol0ooko0?Oon03Yoo40Cda309bM
U@22]j<0bNS]0?okn`3on^D0[MnT025gAP2Wl/L0Yi]e07=YAP3FgJT0fnj/0<c_V`38jiL0Z<9h0=3T
W`3SlZl0bmnG0<SVSP3:kI<0b^fM0<SXW`3:iIh0c^>R0<kQX@3DiZP0dNFV0<cWXP3:jZ40a^fN0<C[
W03:kI/0a>NE0=;eX`37ii`0[LZ707bFE`36h9l0bnNM0<gWW@35giH0cnRT0<WSYP3<iJ@0cnNM0<oW
V@3@iiD0dnBD0=CRU@3OiZ<0]KQo0:FSL`2g[hX0hM300>7E_`3oon<0o?oQ0<kN]`3TnM80hOGB0?;k
jP3oooX0ooWo0?oko`3noo/0n_oi0>ojlP3goo/0mool0?Smn@3jnOL0oocj0?oil`3ono40ZJ2?0>ce
f00X9Pd0gN^j0<_PZ03>h:`0cMFV0;:]V@0d;2403PD00?K^o@3kool0_^G@049^E`3_ool0l_kj0=7O
XP2gaX40oo[S0?okl`3lk=l0h?O]082aWP1[_Hl0Nk><0=3Za@2BW7L0[9ah09N7H`3A[I<0dJ^F0?o_
h03ooo40m?o^0?oom03oooH0mOK`0?oon`3`nn/0i^OY00P53P3ono/0]Z^I0::LNP3Pik40c=VS0<oZ
/`34iZX001D0a?2K0;SVNP3>lYP0b>JP0=CZ``3Hk/P0g_O=0<[XZP38ij<0ambQ0<OHY03CgKX0f^S4
0?Wok`3iooH0nOom0?coo`3nool0o_om0?oon`3oood00P3oool0103no_h0ooom0?[jn03no_h20?ko
o`0X0?_ooP3lool0nooo0?KlnP3lool0no_k0?ono`3ooOd0]jf^0;JVYP3chN40`[2^08n0O@1]HUh0
oocf0?ommP3onoX0oO7a0?GcmP3lool0KgYb0006003gon<0mooJ0<GRX034j:00b_2U0<K_X`2hh9L0
anj[0<;YZ035jJ/0b>b/0=_i^@3ZolL0jOk50<oL[P3Oj/00o_od0?koo@@0o?oo0380o_oo0?ooo`2j
^[P0MgIa0>k^iP3oooH0iN7H0?omg@3;kIT0Q=6K01MMA@3Qool0o?oo0?Kmk@35hJ@0cNRU0<o`V@39
jI@0c^J/0<gN/P3MjLD0l_cG0<WEY@3EiJ@0d>JN0=GaYP3Mnk40bNZA0<cXW@3eooH0mooj0??ok03F
iJh0d^6X0<oQY@3Lk[80cN>U0<WPZ03Bh;l0f>C<0?3ii03kooP0o?ok0?omo`3ml_X0hMCK0?O/l03o
ooX0nooj0?_oo@D0o?om2`3oool000X0oooo0180bNb@0<SXW`39iJP0l?oJ0>gmf03komP0bmZQ0<KF
U`1=GQX0BUdK0<oTX`38gIX0k_bo0<OLV`2mjI80bnnE0=kW/01`MeP40?l000030=KZ[@2O]W00o`00
00<0o`000?l0f^ZY0=3WW`30fhh0eO:R0<[ZU`39jiL0dO2P0<KUU`3=iih0d>NQ0=od/`3?hZ80dNFX
0=3UZP3EkK40`M^L0<kWX`3ElJ@0d>fK0=KcX@3<j9d0iOg30?Gof028W6L0a=ZL0=3WV@26WDd0UjQR
0=?MX03MgJL0U8UL05E=7`3RiZ/0b=BB09NaI`2nfY00e_B^0=Ob[@3?iZ00_mZC0;GES03ClJT0amjH
04mH5`1WKBd0U:1N0=3WX@30kj40]^FE0<_/V`39j9X0b>:H0<KMU@3Mm:`0TZMR0<CJTP3>j9h0cNRK
0<k]W@35fX/0ZjMX0<STZP2lgY@0cNJC05IM3`2?Y6<0bnNZ0<;LTP3Vn:@0bnBS0<OOX`36cHX0VJ1M
092JE@3JiJ00fNJP0=gZY@3KjZT0S9YL0<oMXP3HiJd0e=f`0?_mi@2IXFh0eN^I0=O`W@3:j:P0b>N^
0;[NV03DnJ/0c_BQ0<_]X@3;jJ<0cm^M0:2/JP3Ch9P0fNVN0=?YX@39i9l0P5/a08YP=P38g9L0e>bP
0=S`Y03<gIL0d^>M0=?TWP3AiIh0`mN@0<cSV`3To;80]Lf30?Ooa@0iD@L0cnJN0=K]Y`3AijH0cN:W
0;kCVP034`00IVa60?kog03LjK/0cMja0<kM]P3ooo40ooce0?omo`3lnOl0mOGm0>?gm@0C?2h0joOe
0?ooo`0lA4H0kOoo0?;jo03fon`0^?:h06:hR`2=e:X0Xi5O05i?9P3JhZL0bMnG0;oWSP3;lid0c>:Q
0=KU[03Lijl0enNX0<o_VP3<l9P0b^fM0<CRVP3?jZD0l?o50?Kob`3Ll;40enf]0<_VW`38j9d0anbL
0<[]W@2oeHX0gO>X0<kTV`3FjZD0b]nJ0=od/@3JlJd0e>nX0<7QUP3?lJ@0aNZL0<[]V@3:k9P0bnVC
0<cXT`3>ii@0Cf0I0:nmO`2FW700nocJ0?ghi03oo_40ookc0?;_h03KiL`0cmk10?7oi03_onD0m?o]
0?Com03cnOD0oogo0?ggo`3lo?X0o?oo0?Ooo`3YmO<0nOoo0?Cfm@3nn_T0ooKc0?obkP2=O780lnOK
0<_@_03Skl/0cnRW0<SRV`3?hJL0j>o60=?<`P3oo?/0no;e00<0001IF5@0n?oh07ZZTP1VYI`0g?oo
0<gOX@3Cg9d0oo_[0?Wek03oon`0a^G508RmX@2Yo>X0?h=^0>3ok@2_g[00_>F]0<GMZ`3ooNP0lmOC
0?o_o`3clOl0nOoo0=?M`P3Fh<P0d]W90?comP3noo@0IV=Z0>CLj@3mlO40fLjl05iC<`3oomH0moOE
0?KohP3hon@00100mOoC0=S]Z03lold0o?oC0;_7U`3>gjP0c^NU0<K/U@32j940`]nO0>?fb03eonL0
nooX0?_ok`3kooH0nool0`3nool20?koo@80o_oo00@0ooko0?3^k`3ln_/0oooo0P3nool0:P3kooh0
mO_i0?_oo`3`m_@0nooo0?3dm@3nool0k>[]0?omo`3kko405@L70;2QWP3`hM`0ooC]0?olm03ci]h0
mNCM0?ojmP3mmO<0ookk06a^H@0Y;1L0gNBh0>C_]`3Il:`0]mF=0<GYW`33gjD0dn^g0?;of03HmKd0
`NBR0<KZY039jil0b^ZQ0<SUXP3=i;00hOC70?kom03ooo/0o_oo0?ooo`80o_oo0380n?Wn0?koo`3n
ool0ooom05iOFP3oo?d0ookj0?KlfP3@hkD0aO[203E_A`2CaL@0kOoo0?;ol`3Ci[T0cnJh0<gY[P3:
hjX0j?OH0?Ook`3noo<0ooo]0?ooh`29Ue`0VjmZ0=og[@3ElJH0dNjJ0<kYYP3good0n?oj0?Coj03B
iJD0c^2R0>Gh`@3/olP0f?:e0>?na`3hon40n_oS0?Woj03gonl0nooc0?omn`3ij>h0e;o60?oio`3o
oOX0oooj0?oon`D0ooom2`3oool000X0oooo00/0bNZC0<WVX`3;i:d0n?oV0?Woj03QkLD0l?g?0=GT
[@3Ol[80[lB30;G;RP020?l00005055T8P2^fX<0d>VE0>G_^P1`Ne/0103o00000`1RMCh0am^L0:Rk
N`020?l0003508BHD`2K[fP0N8i50=O_Y@3@j9h0fOBW0=7/V`3?jY/0dn^O0=gb[`3KkJl0Sj1Y0<CE
W`3;gjX0b=nW0<OPYP3>jZd0b>JP0<SWV@34hi<0c^fM0<KTVP3Sol@0i?o80<[S[02B[6d0bnRH09F`
G`37fi@0k?Ji0<S;U036^hh0R81B0=WMXP2HY680PI]A0=ok/@34hY`0_]NC0>?g/P3=i9h0cnfU0;[H
T03Mmk00f^JT0<kGUP2KYfD0f>fX0<kgZ`35l:40aN^F0;oRSP36iIL0c>RM0=C^Y@2DZf<0c^FM0<?M
T`3:iIP0do:R0<gRT`2QX600d>F/0<;NU03CjIL0d]n?08FNFP22Wel0cN:G0=gXV@3@jjP0d>Z[0:Z_
K@2BUeD0WZEQ0=oYY03RkJP0c]VD0=OSX@1dPd80UJ=V0=g[/03Ih[<0lOKH0:2ZMP3FjIX0b=f@0=7Y
[`3@j;@0`=fK0;?CRP3EmJT0d?6/0<_UYP3Vjk<0Vj5U0>;YY@35chX0b]VF096UIP1gBbH0UFE10=ST
Y03Fij40dN6J0=KFUP3DeYD0gnBR0=cSX03PjJH0c>JL06j9?02Q_G00PimB0<cWVP3:i9X0f?BZ0<kW
X`3@j:X0eNnb09JXM00^<Pd0[[F<0;o:W`35eZX0dMnk0?Slk@3oooX0no[o0?coo`3iool0N8b;0:?0
_03hool0mnk_0:RHV`0kDed0g>SX0?_om03>omH0LlFQ05NMN02QU5l0H54V0=gUZP3:h9P0_nN?0<?Z
U`3AijT0d^2[0=;LZP3?gZD0aNBF0<CWU@3:kId0a^JK0<_YX@3NnK@0h?^h0=G^[03Ak:T0bnJO0<[X
WP3;jYh0c^VL0>?`ZP3Kj:80cmbG0<kIU`1jQ4D0]/J50=?XY@3ClJT0bN^O0<?^WP2ojiH0b>bB0<S[
T@39jY<0c>VE0<kYVP32eID0e>>/0<cD[@3bmmT0ooo_0?GfiP3nond0iN[C0=7O_P3@hKd0mOoS0?Go
i03^omd0l_kZ0>oej@3clo<00P3oo_l0CP3oool0nOoo0?Woo`3fo?X0o_om0?oonP3ooO@0oo?Z07EU
EP18?c00m_oZ0>OhcP3FlZL0e?6O0<GIVP3_mm00nO7^0<6f^P3djnh00`0001LC203_l^/0d_WV052H
S02gn^P0`mnU0=WPZP3oo^l0mo?W0?[oi@2ce:T0/^2k03emK01OVH<0g?o_09cI[@2Oh:P0R;Z70?co
i`3Sel/0oo?i0?omo`3noo/0b]N[0=cX`03Eh<00o?o/0>OWg`11>D@0o_?o0?olnP3`iM40KFA30?oj
e03oonH0l_3Q0?ook`3iom/0f=fd09NHKP2c/HP0gN6^0>_g^@3;giL0a>N=0<W`U`3_ol/0lOoG0?Ko
i@3kon@0n?oX0?[ol@3looX0o_oo0?gno`3nood0o_ok0?koo@80o_oo02l0m?;e0?ono`3oo_l0oooo
0?3bl@3_lO00l_Ke0?coo`3kool0PhV707j4PP1QIFH0004208Z:S03imOH0oocm0?GYj@2JS8/0S7ik
0?olmP3mlnX0a;Za09b;P@2]VY<0`kRb0?onn023OG401`000<S5W03Hf:H0d^:T0=CZZP3BlJh0bMn`
0=KW_@3gomX0iok80=7^[039j:80b^ZQ0<cZY03=jZX0goG60>oof@3nooH0oook0?ooo@020?ono`0b
0?koo`3em_X0o_oo0>c^k@3dm_<0nogh0=oDg03omoH0nOoV0<7@^`3:l<40RkZ@06nUU`3=nnh0jOoh
0?3ni03eonX0k?oJ0>Kgd`3anNX0nooi0?oon03ooo40oOoT09j[L`2U^G@0f?>V0<kZW@3=jIl0d>N_
0?Gon@3bond0j?OF0=3SX`3LkKH0lOoF0?3od`3?k:`0eO>g0>Gga@3Rl/D0i?G;0>3]d@3^m^40oocg
0?oemP3:/k/0ooSo0?olo@3oo_d20?ooo@80ooko0P3oood;0?ooo`002P3oool02P3;iYD0cNFW0<gQ
/03hond0lok]0?Coj03Ag/00eNJl0<?HW@34gI/40?l000050;7HQ@1RHQX0dn6/0=3V`02J^;000P3o
0000<03Ak/l03al00<??W@1gQTl0cNBN0=C/X03=iYD0UJiM0=[^YP39fIP0d=jP0>3/[P2/^G40FFHQ
0<[FV03Fgk00emnf0<cF/`3bom`0jooC0?7oe`36iJT0b^ZW0<c/X`38ii/0c^fO0<?QU`3>jjP0c^^a
0<k[/`2kfYh0e_Nb0<7WU032iI40d^RP0<cHVP3Xjk@0VI5S069J;02HW640dMbJ0=7YW`35giH0`MbG
0::gM02@VeT0amJC0;K@R@80e>nX0>/0ambG0=O[YP3Fij<0j_ji0<oYXP39j9`0a^bE0<W_VP32iID0
d_:W0<CTV`2ogID0c^bT0<g]Y03@lZP0`NJI0<7MTP2SZVL0dMbP0<kKU@3KkYl0d^nK0;kSUP32hI/0
V9mI0;RjL@2ifY<0c?B]0<CNU@3Bk:<0WkU_0<cXV`36hYD0dnnR0=;bYP3AljL0bN^Q0<[[Y03<j:/0
Uj9g0<kLW`3HiY/0cMRC0=SP/@2e_Y<0nOo?08bSG`3:iY`0cN^]0<cX[P36di/0e^BW09>PF`2d`gh0
e>VV0<cVY@2lU700N4`Y086ADP2CZ6<0UJAO07A`<01fLS80VYeJ09BIEP2laX40`mnD0=ok/034h9D0
dnnR0;oKSP3=jIh0c>RM0=3/XP3=j:D0b>>P0<[MY@2PX7X0YjN109NNLP2mcJ00j_WB0?_ol@3hooD0
mooo0?Goo`3^ool0HG=e0?kno`3^l>d0oocf07UUGP1DQ7@0h_G_0?ono@3gool0Rl2h02QWC02BXEh0
HUl/0=OOX`3Fk:<0c_FR0;cRU@3Sml@0i?3:0>S_cP3Ji[h0_]ZO0<?TW`33hiL0c>nO0<[_W`31iiX0
`^RM0<;VW034iY`0cNRQ0=;YX@3Ci9h0dn2K0>?UYP2CUEH0TY9F0>WT[03ZiJd0BThC0=[TY`37hY/0
c>jR0;KXT`36mZ00bnfI0<c[V`3:j:00bNJS0<WSY03:hJ/0dnZf0<kQ/`3LkL00m?oH0>ooe@3So]D0
iOc@0<cP[`3:fZT0f>Jc0=;JZ@3Dfjl0e]Zg0?coh`3_l]d0^kb^09:7S@3VgN80ooko0?ooo@3io?<0
o_of0?_ol03oon`0oocV00d3002@Rfd0g_360<KOYP3Kok00b_2K0<3KUP3IjKP0ooo]0?K`i03Of<h0
oooa0;FfZ0063@H0JG1Y07BKV017Og80]O340<k]a03ooNd0l>_G0<_CZP1nV5T0cnRT0=WYZ030dI/0
b?7C08G0ZP1T_:`0W>oO0<Wcg@3Gkll0e^2Q0=CWV038gX/0h_V[0=;XW`3?hJD0cMjX00L0003mloh0
oo_o0??_h`3fmMH0/:j50=OB/P3onNd0_:V_0:bGWP1lIf80e;nn08MaH`1^FSl0hMJN0>OTX@3Mi9L0
eo2O0<o[X035hZ80c^J/0=7N/03JhKL0h>?60?Kii03ooo@0o?km0?koo`3noo/0o_oj0?koo@3nool0
ooko0080oooo02d0nOWi0?ooo`3lo_d0l_Cc0?koo`3Hf]T0NWim0>GYj03YkN`0n?cm0?[no`3/kNl0
oooo0?Kbl@3ooOd0ooOd0?ojm`2aZZ@0/:bS0=C=a@3ooNd0oog/0=O:`@1YFU<0Sg]b07IOD@2GOf<0
bKJE0>OX_P3IiKL0`=>U0?Ooj03lond0n?oN0=g[^P3Dj:T0cnBQ0=7VY@3@i:T0c^2^0>Cbd@3fonL0
oooh0?onn`3ooOd00P3ooOl0=03oo_l0oooo0?ooo`3nool0lOOc0?_on`3E`<T05PH60>WliP3iool0
aL^o0=Oac01KVVD0?He`06RZW03eool0o?oo0?[no`3lool0ooko0?omo`3oo?/0oood0?ooj@32ciX0
amVK0=KbY`3?kZ80eN^m0>3^e03goo<0gno;0<oQ[@3AijL0i?O:0?Cok03`on80c^fZ0<OXX@3=ijP0
bn>Y0<cU[P3@h[X0joKH0?ool`3ol>/0^9fT0?o]mP3on_l0oo_o0?omo`3oo_l20?omo`80ooko2`3o
ool000X0oooo00X0b^>B0<kTY03>h:h0nOo/0?_ol@3don`0nOo/0?;og@3EkK<0a=nL103o0000o`36
k9T0IU/K0=KW/`2O^I80T:bN07_4Z@0jRf/0`NC6000=001XLdP0dMn/0<oVWP3FlJ80bNF@0=KbWP36
fY80hNna0>G`]P2DVfL0_/N805mT:P3Df:D0n?cG0?ooi03bnmh0m_oQ0<_Q/P3>jK80b>VT0<CVW03<
jil0bN>I0=K`YP33g9X0goNi0=O`]`35gZD0c>ZZ0<;SWP3?mJ80a>NE0=3VWP3Lj:X0fMjV09bDIP1Y
HC<0ZZic0<[ET`3@j9h0dnfT0<KOV`2EZVL0g>FT061/:P33f9<0`]bE0<7LU@3BjJ<0cnJP0<GIU03<
h9/0d>BO0<oVWP39j9P0b>NI0;kLTP3@kjT0cnjZ0<CTX@3Am;00_NFO0;SQV`3FokX0`nVP0=COV`1<
E1P0eMnJ0<GGR`36k9L0aNjO0=GeZP2f^GH0Z:US0;3DS01@Nc<0dO>Y0;cNU038jYd0_=jA0;oRTP2g
fXX0_^>E0;OMT037kJ00[MJ:0<ka[@2O/7X0eNBQ0=OSU`3CgIP0RhiQ0<76W@3eolH0Sj=L0<?KT@3>
k:h0b^N]0<[WY`37i:40aN6F0<STV@2ohIL0bO6Z0:F:G`2VQUd0`n6K0<GUVP39iIX0cmZE0=ORW@3M
kJH0cMjG0<[PU`3<iJ40bnFN0;kHT@35giH0e>jT0<KPU`35giP0foF^0<WRX03Ck:/0fNRa0=oM]01H
FBd0Ti]Z0>3`_`3BhkH0lOkT0?;mk03good0l_oo0=K`i`0Z@3d0gn7]0?oonP3_imX0JV=A0<goi`3Y
ooL0n_[j0?olo`21YZ`07U<o08FOF01RHB/0f>6R0=K/X`3;lZ40_N>J0?Oog@3kon@0o_oZ0?Goh03?
j[D0d?2_0<GUVP39k9X0b>fM0<C]WP34kj00`^^M0<GYW`3<ij00dnNR0=ORX03Fgih0MW`n06EV:P3L
fj80clZC0=oHXP1FDa`0g>2U0<kSWP3;iid0a_2N0<C]WP39iZ<0c^RW0<o[/03>j[00cNRc0<KOZ03F
kkP0^mFF0=G`[@3?jj40c>R[0>7khP3bonl0O8U]0:2YS03:cK00/jnD05]E?`1cKEl0Sh^205YFD`2C
SHd0LfI]08f1Q@1aJFL0]k:^0>3Re@3@e<<0e=c508^@LP1]K4h0DDPW0;VfS@36gZ00b^NW0;SMU`3B
n[<0f_Vf0>7f^`3LhKP0fMRi0<O2[03kmn`0nOcc07Z7OP060000Y:na0;;Cc03Hoo<0gooZ0?_ol@3_
mM/0cmb^09:KFP38dXT0e_6T0<KRY`2Hc[h0>H>404J]`02Oool0O;Ne06jHPP31hIH0_^R60<kfT`00
9@2ne9H0dnR]0<WJ[@3OklP0SXF60?gfoP3ooOl0ooo]0=kU_03Vk[d0QhMU08EmLP29Lgl0bJnl0?oe
m03omO80M5m<0=k9ZP3Xg:80hmjN09fNG02faXL0dNFX0=W/]03EiZl0en2[0=SK[03PhL80no[U0?oo
l`3knoT0ooom0?kon`3nooX0o_om0?koo`3oo_l00`3oool01@3Zj^X0[:b/09RHV03nool0l?;a00<0
o_oo0280n?cm0?coo`3nool0oooo0?ooo@3oo_d0oo_g0?onnP3oo?P0oO[c0?onn03ooNd0ook]0?om
l`3gj^@0mmoK0=k3^P3Sb;D0]In70?3]cP3`mmH0j?WG0?Wom03koo@0io??0=CQ/`3MkJl0eNFT0>3]
]@3Zm<80jO780?Chh@3oonh0oogj0`3oo?d0=@3oo?l0oogo0?OemP3inOT0o_om0?CjmP3kood0ooCe
08IdL012CdH0n?Wo0?[ho@3Ijm40^oV`07G?Z@14TX@0k_oo0?kno`3in?l0o_go0?olo`3ooOl0ookj
0?ool@3oonP0Yk>10<_MX`2ogIL0`>2G0>Sif@3`nn/0nOoa0>7baP3@i:L0eN^[0>?dd03doo<0l?oX
0<k]ZP39jZ<0cNV_0<_V/`3<i[L0c>:n0>Gde`3kmn/0oocf0=>j`03omod0oo[m0?odn03oo_l0oooo
0080ooko3@3oool000X0oooo00/0dnbI0=K[YP3;gj80nOoQ0?Koh`3aoND0n?o/0?;ogP3;hjT0cnZU
0<g/W0020?l0001^0;oLS03Cm:<0GdH>0=[[]`33hk80@5/j08cAY@00Cb@0`^[?0=7TcP001`00YkN:
08RRF`33h8h0bNF>0<_WTP30dH/0ioFh08nGI03gnM40oooH069R?03QhKl0oooZ0?Khh`3Bf;h0b]Fc
0=G/]031g9T0^]j60<c_U@36ghh0QYMA09n_KP3]n/D0l?[80>3/^P3?gJP0c^BS0<kXX@39j9X0cNbL
0<gTW027UEL0WjM^08n8FP2DS5h0h>6W0=;MV`3Rn:l0^m::0=C[Y`2CYV@0e=fL0=7LVP2EYV80cn>N
0=3WX@3Ak:D0b>>L09:YH`20UE00c=RF0=[VY03UlK40dn6S0=GY[P2[`hT0GW]306jEGP28]Gh0]>Va
093:T037olP0/>JX0=3RY02JX680b]JD0=;/Y@2jkIh0_^ZK0=?cZ03Fg9`0f^BW0<gg[`2fi9`0_mNI
0<kTY036fIT0SimN092OFP3DhI`0amJA0=c]Y`3Ci:00b]fK0=GZY`2aaX40g_>T0>;`X@1GHQh0i^c0
0>O]`@3DhI`0T:=D092WE`37gj40cn^^0;SNT`35jY`20<W_V02o0<GaW031l:00Wh]H09Z3C`37jYX0
d_RS0<;XT`3:j9h0`=jD0<KTVP2mfi40bNNM0=7NZ@2jai80SY]U08JDF@1kRD`0Y[Ag05aZ;@0kB@h0
BULO061]=@0mAQ40?Cd;0;VnQ02BWUh0cnJP0<_QX03bomD0mooQ0>ooi`3`on`0joo/0;k[bP1aWH`0
ZJbI0:NKQ@3Gfl80_>2j0=Koj@3Goo80l_oo08RU]`28Yj40T9UJ09^EH@3HhJ80cnFL0<CZW@32ij80
lOoM0?_ok03nonl0n_oY0<kX^@37iZ/0c^bV0<KXV`34jI/0`njN0<7/W032jid0a>VL0=?ZXP3ChYl0
d]NG0;>lN`20Ue<0g>n_0<3>T03Tik00c/fG09NAG@1=BQ<0WZ9W0=GNW`3LjjP0c^:M0<?KW`3Ik[D0
m?oI0?Cog03^omL0kooG0?;oe037iId0bNZK0<OZT03?l:40c^Bn0=;R_@1nPUl0oo_H0;Z`S@2kZ8X0
_JV@0;6OR`2jZYX0XiV=07meK02?PH40F4Q80>kOf03;_k<0LWAL06ehF02@X7/0hO740<cEYP2ETF@0
J6La0=3UVP3@jZ<0i_o60>Wob`32hYl0c^VV0=;PY@3Ni[<0d=F/0:b^UP3Ad/00ookd0<Ff[`0B7@`0
1B0=06B3O@2[^k/0k_od0<k`c@2nh:h0XheD0<6^M02ei;00O:In04emK@1ESXL0O;g10935b`2X[:l0
FT]60?off03giKL0iN2X0?3oaP3MlkD0d^B`08^MJ`3moOD0m_Wb0?_omP3gon40dn^a0<oWZ@3Hi;`0
n?[/0?oeo`3on?h0oo[U0>3N]`1WIc<0Ti1K065F:02;PUT0lng;0;NgW`2SXh/0]kR@0:^YN03PfYh0
f]BT0>cUb03oonX0oooc0?oon`3oood0n?gg0?_on@3nood0oOko0?ono`3oool0iNGU03@d=0000000
oooo0?_kn`3oool0o?cl0?omoP3kno/00P3oool0103nool0nO_j0?_mo03nood30?ooo@0L0?gln03n
oOT0ookk0?knm03oooH0oogl0?Oal`3on?`0ooSj0?ofl@3omnl0ookd0?komP3]nNl0m?om0>ool`3M
klT0a]JU0>G`]02Y/GH0RHMP0:fVRP3ej=L0l]oI0>oLf03nl_80oocm0?oko@80oo_k03@0ooGd0?on
n`3hm?40o_oj0?Gkm`3iood0oo_W0;bcXP2n];d0KfYa0?_ko`3eoo40^N>G09S^[`2Zoml0dooo0?cn
o`3gmOX0o_oo0?oon03fm>D0oooX0?ooi03DeK<0dMZ_0<kK[@3Nm<<0`]fX0?SomP3koo/0nOoV0>oo
aP36g940e^^`0=g_e@3cooP0m?o_0<KSX`3Cl;00k?oR0?;ol@3_oo40m?od0?OomP3em>l0ooKd0=c9
b`3on?P0oo[g0?knmP3jo_d0n_ko103lool;0?ooo`002P3oool04P3?j9L0eNfS0<cQX03domD0n?oP
0?Soj`3ionX0lOoO0<KMY@39i:40an>F0<SSWP3;iYT0b>^G0<?RTP1bEb80c=fY0<;S[P80o`0007T0
XN^j05EmHP1LLUd000P005iaA03DkZL0cnZK0=?]UP3DkIT0amRB0<gKX02OZGL0loS@0?oog@2/[H/0
moSI0?oojP3oon`0fN310=OS_@2oeIL0gOV_0;oTQ`3CmIL0gOFQ0<cKUP3;eiT0YZan0?Gkc`3Sjk`0
am6L0=_^[034fY80bNBG0<KRU@17GQH0UZIW0=gU[024ODl0SXIH0>c`]@38di40aM^B0=ccZ`39h9`0
]<V60<SDTP3Pk:X0]lJ30=KWX`3>hYd0e>nX0;_IT@3:iIh0SZEO0>gl^@3>f9T0c]>I0=CLX`34eIl0
@EPR000A00004P0001@004f6D`1PW6P0FiaT0<7k`@3Fjk00iNnb0>3c/`34i:40^NnT0<C`X`3;jj00
g^b_0<KIX@2_fYD0c?Vd0=3Y/03>iZ`0jog10<_KW@1EGb00DE`J0>C_[@3Ghj40en>S0>?b/@1QLC00
c^JJ0<GLRP39g8d0Df8O0>C_a03lomX0e>FN0=CWUP27WD/0f>j^0<SPY03>kZ<0cnjP0;KGP03>kiH0
b>^G0;SQTP3@]X<0V7Y60=;_W`35iI00`nFA0<[XX03Jn;00e>nX0>Wo_03>iIl0DU/^0=;K[03Ihk40
4A/0008000X00:P0?dX@0;[5S@3Li[40am6L0=SQ[03]l;T0WZUW0=o_Z030fhh0h?Z`0<oW[@3@ik<0
a^2c0<SU^@39kKd0[n2a07NcT@3Df[h0Ddha0=CTa`3Hmld0?XE=08C8X`2fbnH0DVf00;kGd`2JWF@0
SHIB0<kGV03>i9`0aN^N0<O/Z@3=g[X0noo/0?kok`3konX0lOoK0<SW[037i:40cNfT0<[/X02oiIP0
`nZK0;oTU`3No[<0aM^C0>3/ZP1NHb<0EV4O0;cJU03EkZ`0dNJU0=COY@3ZkkT01`D00?3_^@1DDa/0
dM2G0>[[[`3<dY@0cnBS0<gQY03Dj;<0dNNf0=3V]`3?ikL0kOoA0<WVYP39iZ<0cnnS0;[HTP3Hj<@0
nooS08n<J`3RfKX0HU<f06E?=`1KABh0KUQ:05]7?01nL6L0a[Va0?olmP3ono@0FTXm0=[=_03_lm80
bmZa0=K/_@3?hjh0e>>/0<W6T`1]JS<0g^fX0=?YX@3@lZH0h_nk0<ocZ`3AkZ`0d^6Z0=GO[@3JhkH0
jo?<0?ooi02ZVXd0oog]08BGM`3BlM8000L706mgPP3`ooP0fo[J0<;S^03B_8X0jM^Z0:oZ_P1LSVT0
/=k109S=/@3Ioo@0i_og09nAQP1N?C@0`IJ60?cLa@3NcZd0mooH0=CX]@3Sm<P0HW=90?komP3iooH0
nOoc0>[od`3AkK00d>f[0=GU_P3co>/0oo_m0?olnP3oomd0cmZN08^HD`1GGB40Yj9j0?kgf`3oon`0
o?G[0?ool`3onML0gmNX0?;V[03]h;@0HEDk05UA?P2b[:00oOcj0?cnn`3loo/0n_oh0?[ln@3]k_00
oOco0?3`lP000000KVi^0?ooo`3inOT20?ooo`80ooko00@0o?[k0?ono`3oo_l0oooo0P3nool00`3i
noP0o_om0?gmn`020?ooo@040?oon`3nn_T0oook0?[kmP80ooko04l0MVU`00h00@3onOH0ooWd0?;Z
i`3oood0nOoo0?;oo@3`oo@0a]R`0=3Q[@3AfIh0HF@_0<:iW02UUHH0M65J06M?C`1WCDh0`kFe0?oe
mP3omOL0oO7a0?ojnP3oo?X0oO?b0?onn`3ooo/0o?om0?_oo@3oonT0in;>0?_Ym@3llOD0g^;S0?Oo
l@3JmkL0_?o008SK[@3Jool0h^_b0?Sjn@3koo/0o_o_0?ooj03CeK00fM^d09NILP3Vk/L0fN>n0?;o
g03don80jO?X0?_onP3Ah;L0c=nM0<oVUP38gJ@0h_7J0=cYg`3Di<X0fo>i0?7odP3eoo<0mOok0>cl
lP3eoo/0l?_c0?onn`3ono/0EdE50?ogm03mnO00ooof0?Oln03kool0o?oo0?3dm@3iood0nooo00/0
oooo000:0?ooo`0A0=3/XP3=jIl0b^BM0<WMXP3@h:l0j?KE0?WojP3eonP0h_?90>?ga03@iZH0d>BW
0<khY02bhhL0`MV;06IA703Ii[00103o0000j03;l]D0C6aD02M28@1CK480RZ1R03Y@203QljL0dnFI
092PG`2daXX0i?O00>_lc`3Ul/@0e^6f09fVN`3Tk<D0kOG<0;k:VP3AgZT0e^ZU0<7IS@3>k9@0PYm5
0<cTSP2jbhL0f>>[07AiD@3ooml0mOK:0=?HXP2e`Wd0PI5:0<;HS@38h9@0gON^0=;RX`3IhJP0^kN8
09F>H03Cei`0iNj]0=[^YP3SnK40]LZ70<CKU`3FlJX0cn>N07f8AP3:eI<0i?2^0=C[Y@3BkJH0d?2W
0=CbZP3?hih0fNRU096IG@2EWf<0e>N`0<kV/P2ddZ00?VPh0;SW^@2om<H0[NFf0;C_`@01=PP0b>Bc
05M[<01^U5L0;5lT0<3h^`36kjT0bnbU0<gc^P2Zf:L0G8Y<07FUI`2:`HX0P[Ao0<oh`032j:l0_MVN
08fWJP3IlK<0`MVK0=O_/@34gYl0e>j]0=3XWP3Im:L0VkEd0=;]]P3_on<0i_oE0<cWX03Ck9/0dNRH
09BSK03Gi:l0e^FR0=CQV`2Z]fP0/Ki_09JVG@2?YEd0YgQ>08mL<@3^mJl0dmjB0=;NU03KjJ/0d]fQ
07n9C@2NYVX0dMNK06A_A0002P00GFTg0=o/]P3IiZh0d^2S0<WGVP3?gJ00eN>V0=_Y[P3;fI`0bMFG
0=K[X032gH`0d?>I0<SZT`3<j9h0c>FQ0=7[[03=jj/0a>VT0<?^Z@2ih:/0MhUG05]a@`1EQ680]]nW
0;?kY`2]lK@000DJ06=oR`3Qo?L0Z[>406=O;`3Jhj@0eN^S0;gSV03>lk00dN>m0?_oj03nonX0l?cH
0<cX[@39jJP0b^RZ0<?OXP35hZ80c^VT0<cWX03=i9`0goF]0=_ZY@1:EQ@0i>f^0=;QWP3?lJL0_n6G
0;[IT`3:ijD0l?o:0=GT[@3Nik80];2005aD8`1GAAD0MV/e0;k=R03Dhj80dN2Y0<KDX`3Hj;/0]<BP
0<KE]P2JZXl0UjN<09^^TP1IIdd0K6]G03<`7@3onNP0Q7QZ08imL`3omNl0oo[f0?ocm`3olO`0ooWo
0?3Uj`3mo>L0oooZ05A6:`3:_il0hNVh0>_ob@3Clk@0bNRT0=O^ZP3UiJL0X9US0:NSL`3DfYX0anB8
0<?WQ`3=lZ@0e?:f0>Sje03Rl//0i_S80=7YW`3<f9H0b[VK0=G?Z`3Gm[<0ao2d07JJVP2/`m<30002
000c0=oW`P3Pml/024<E0:oN/P3;lkl0Z=2K05N3B02F]7h0lN_90??Rb02hZiX0d]?10?3kjP3bo?<0
en7H08jHT03koo/0noof0?Won03hoo<0b]nf0=3Y/P3FkkP0j?_M0?Gon03jooX0lOWT0>?f]P3DnI`0
dNjL0<CHV@3Vi/h0oood0?G`k03oooH0n_OX0=gG]@3NeJ`0_Zf10<FaT03Kb;L0Q7=Y0<Vk^03ooOl0
no_m0?Smn@3hoOL0o_om0?koo`3oo_l0n?Wk00<0oooo00@0ooko0?_inP3oo_l0ooko0P3imOH20?om
o`030?olo@3jn?T0oogn00<0o_oo00H0oooo0?cjn`3ono`0oocm0?ojo`3ooOl20?_oo`1?07=bN004
0080oo_f05Y9@P3onOP0oocm0?omo`3ao>h0nOo/0<3<WP3PjK80H60^0?oog03oo?<0ooGg0?oho`3o
loP0ooWj0?olo@3ooOl0b;jm09V=S@1KC4T0]jRU0?okn03ejnT0no?`0?Kfm03gnOP0nooa0:FVUP3o
lOL0oo?f06ebG00a>b80o?o_0<7YZP39olH0Zn7Q0>3onP3_oo`0k_og0?GoiP3]oM00i_2k0=3GX`2X
[X80e]Vl0?ook03hond0n_o`0?7hiP3lon`0bmVT0<CIS03Fk9T0n?oF0?Sok`2ma[<0T9]k0=cU^03n
onP0o?Od0?ofn`3oo?h0oogo0?olo@3onOX0ooCg0=k6aP3onOH0oo[a0?oom03jnO@0oook0?_jn03o
ood0o_gi08N6PP0;0?ooo`002P3oool04@3<jJT0a^>P0=C_ZP3=hJ@0dN:^0=_VaP3fonP0noo_0?Co
h`3`omT0d>:^0=7RZ`33lid0]Nf<0=G/W02/W6P0c=NO00@0o`000?l0`nK604AXC01LOU/0JHEL0:g2
Q`2M/700amB>0;o?R023UUH0dnN/0>Ck``3Nml00eNZa0=3TZ@1oTEL0g^ff0=;OZ@2EXVX0gN^`0<cO
W@3QmJh0[/Ij0;7:N@3Hm9l0dnRS0=KW/039cj/0k_;A0=gP/`3dnlD0NXY308VKD@3JlZH0dnfS0;oK
T@34eiL0j_>j0;fiRP2WX780em^P0=?LV`3Ciil0_=::0<KIU`3Om[80aNNM0<cVW`2V/Fl0^l610<cE
U031eY40e>nX0<3RV035iI`0d^bU0=?XX`2``Gd0/<>10<oY[03;jZl0^MZS06VAG`2iiK@0`O320;7O
/@2fiKT074LL086PM027XfP0TL>6049oAP2dkKH0aNb[0<WYYP2mk[H0M;:306VHH@2Zg:40>hA?00eB
702_j[80/NB/0<?//02=/gH0TkEh0:G7RP3Bm;L0]m^M0=Gh^03AjZP0`MbG08RWKP34iKP0bnc?0>Co
h`38j:D0dnnT0<_QV02CWfl0dMZ]0=[XZ`2b_Wh0/Kee0=7MU@3ChYl0BUlN07I47`1kAB40d]NG0>C[
Y`3LiZ40[[Ik09NOIP2V[WD0/KIl08F:D0003000LH=?0=[]]@3<h:<0dNFV0=;WY03HkJP0fo2[0<GJ
U@39gY/0fNbZ0=g`/02leX`0e_FU0<G/T@3=m9/0c>RK0<cVW@3@jJD0b^RR0<?UV`38j9l0S9MM0;G?
T01nYG00XM:d0;3RY@2_ki40^o>/01@[>@1]T9H0i_oo0>7ba@2KV6/0eMjO0<WOU`3?mJX0`>FP0=;T
_03_n]X0o_oV0?7nd`32gi`0cNjY0<KTZ03=jJl0cnR^0<cRXP3>hIl0f>NR0=WXX`2nbhH0BUHD0<GA
S`3HjJD0bnZN0=Og[02mgiD0d_Fa0>OoaP2of9h0fNbe0=CFY@2ITV@0/Ymd09B6F@3Ag:@0h>Zf0=kW
_03Ag;@0hN_807^5K01]MV40=T4a03U3>00b?3<000@001`J000`;PP0[:R3069N>`3lm]H0ooWR0?ok
iP3oo_40oo[c0?omnP3oooH0n?gO0?olg`1REC<0fM2W0=cW[`3Ekjh0_N6K0<__Y@3Aj:00g]fM0<6f
P01QDRL0UiEJ0=ccV`31h8<0aNNK0<[X[036gK<0`mR]0<_R[03@kI/0g_FW0=oL/@2IWF/0`=^<0<kc
[@17MG80C7J400@>3@0100002`D706MnI02E]I00T:B106M`D`3>e;X0WjV@07J9L`3ioo40oo[d0?ob
kP3olnd0blk30;o;_@35c[d0j_;S09bTU`3goO40n?gf0?_on`3kooP002D0dN2o0=WZ_P3NlL@0mOo_
0?Ooo`3fooT0i?;I0<o[X@38lID0fo^b0<CHX`3en>L0ooof0?clm03oond0k?7A0=cM]@3`kL@0o_3=
0?olh@2<MVP0[ibE0?;Th`3ooOl0n_Wn0>gbkP3loo/0l_Ca0?koo`3oo_l0o_oo0?GgmP3`l_40n_[j
0?ono`3`k^l0oOWj00<0oogo05l0o_Gh0?oko03oo?d0oocm0?klo@3nool0n?[i0?koo`3oool0ooko
0?ojoP3mmo/0oo_o0?olo`3bmOh0nooo08>7RP040`40ooO^05i=@`3ono@0oo_h0?ojo@3oonl0o_oR
0=CFY@3QhJ/0DDdN0?[ddP3omoH0ooWo0?ofo`3oo?l0oogg0?gimP3kmoP0oogk0>3De02`XIh0OVaX
0?ohm@3onoX0oocj0?ono@3moOd0o?oh0:VYX@3oloD0ooWk0<S7/P1eN6D0M7Ab0=K]``2hfJX0K9n>
0<7dh`3Wool0jooo0?7oj03aomT0dn2X0=WS[P2TZWh0emW10?kok@3oooH0lOCY0?_oj`3kon80enJ[
0=W^W`3Qmj@0h_;10;>oZ@3Pj=00bm6_0>?U_P3dl>@0ooWj0?ognP3omOL0ooKe0?oin03om_P0oo?f
0=^k_03igM`0oo_h0?onn03nm_<0]ZbZ09>9R03:`;l0PWQf00L0000;0?ooo`002P3oool04P3<jK40
a>:R0=kk^@3?iJD0c^6Z0=3K_@3bnnH0nood0?_ol@3ion`0i_G:0=kZ^02djI40`?bJ0=3UUP3bjK80
cmRO0=cf[`80o`000?l0KhE50<CS``2oj<P01B/4000C003?i:`0bm^M0:6/JP2c_WX0dnJV0<GJW`3X
olT0dO2d0<o]Y`3:i9/0M8]30<OKUP35eI@0ZkUk0;S6R03<g9d0gnn`0:o2PP3Djj<0cnnJ0=ki/P3>
hjX0cmVf0;[1X037cj00RI9K0=o`Z@3LlJH0`=Z@0;oKT03JmZ`0e^VY0<O@U`2OVf`0DDXL0=oSZ03Q
jZT0[L5i06]o>035f9H0b>6M0<K_X`39iil0b=6@0<76QP2SZ6P0enRT0;oITP3Qok/0^mnE0<k/Y03:
iY`0c^ZM0=;`YP32iJ40eOVi0;cRY@0?=`80Rk=o0;?JZ`3Go=00_^:f000P001JNU<0a^N^076^LP0_
M3h0YMf/0;kRY@3?kjh0NKAn01QQ=02chjl0eOo?05>QK`0VL3l0]O6n0;kd`0004`00@fT`0;oNY@2I
^7d09D@;0=Si`032hJH0_MFK0;OCUP20Y7@0_nG009k5/02Yd[@0c?2b0;OGSP3Pmk<0QHeT08VAJP2=
XFH0Z;Yn0<OHU03FjZD0amfL0<KPX@2>HD00ReXj09ZTJ027Te<0TYiN09JNI@2//gd0Qi1I05UR:@1f
PDL0RZ5Y0<3HW033fid0a]nK0=gg/032g980b>>F0<KQU03@jih0f?>V0<7KTP38gYd0c>bS0<;WU`30
j8l0b?2G0=7]X03Bk:80c^FO0<[VW039jId0e^jP0:6LG02mgYL0RKIk0;3=]`37mkT0__^D0<;gY`0Y
C500K9fJ0>3oo`3kon40]:n50=WQY@3:giX0coFZ0;gRW@3goml0nooT0>G/bP3Mj[`0bNNM0<OYW`3>
jk40m?oH0?;od`3BhJH0en:V0<cEU03Nij@0=T400:2/JP3ChYl0go2Z0<[RUP3=jIh0c^jU0<O_Z@3=
m;40d_Bh0;oJX`3Rj;P0emBY0?7N]P2<O5P0oooS0?_ng`3kon@0nOoU0?ook03^l^40/KFW0;c1^P3S
j>80mOWj0?oom03MfjX0W9][07MiBP3DeJT0m_S@0?ooh`3no^80ooo]0?ool@3clnT0k_7P0>ged03^
k/X0HUH^0=oGZ@3Bh:80`=jH0<_aYP3?mZL0`M^A0>?RX@3[gjD0bkJ908QmA@3?h980cnRG0<c/X`36
i:H0b^Fb0=;[]03DlK40_^2<0<_XV03Bg:L0a]RJ0:K0I@35iYL0Ym7=062AW`2og=P0l_ol05mOI`00
2@00;DX/0=WP]P3Sh;d0f]Fo0?Ghi@3Pk^40k_G]0?obm03oin/0ooOb0:6SUP3ioo<0g>GD0<39^01m
PgL0o?of0?Wkn03jo?/001h0o_ok0>G]eP3Ukld0joKF0?WonP3fool0m_oj0=obeP38j9`0d?RP0<7O
X@3<hKH0j>_P0?7bjP3ooo<0io7<0<WFZ03?f:T0loS?0?ooi02oZI80Z9260?oimP3on_d0oogo0?on
o`3lool0o?om0?koo@3`l_420?ooo`0B0?[ln`3nool0oooo0?Wgn03oo_l0n_Kg0?khnP3iloD0ooWk
0=O>d@3SfMX0nNo`0?omo`3oo?d0oooo0?gooP3lo_d0oooo0P3ooOl04P3oo?l0mnOa0?ojo`3ooOl0
noko075gM@000@00T8Mh07QXF03]e/h0ooSd0?ohn03Ca[<0WYEd0:BLJ`1mMT00KVDj0?G/c`80oo[o
0400o_Oo0?koo`3looH0kNkY0?ono`3jl_00oocj0?ojmP3chMd0I59>0=o@c@3on?H0oogm0?[hn@3U
jNP0oooo0=_;b`2_ViX0ooka0?oll`2a/;P0WJ6B0=GTa`1RSVd0F9R008jj^`3Rool0dO3A0<kY_039
fZ<0o?oD0?gofP2k^ZD0dLo20?knmP3hn?00jo;C0=OR]`2ibHX0Vk5O08:HA@3>g:/0j?7L0>7UbP3B
e:l0oooQ0?olnP3olO80g;Bb0<VSX03C/Zd0cZfX0?cFe@3okNl0kLK90?;@d@1`GUh0JEeM08inOP2=
NgT0Sgem08AbLP2BP7h0oo[h2`3oool000X0oooo0?l0aN>a0<gU/`3eomP0h^o30>Occ@3Vl=L0nOoa
0?Wol`3Pk=H0i?7G0>[fd03Pk[/0aO^S0:kYR`3Aj9X0cM6F096KGP2baWl0d>fC0=_XV@3@fIP0GG=<
02947`2H^940014009RYM@3EhZ`0hN^^0<kJW03AiJH0b>:S0=?c]03En[D0c_6O0<KWT02G]600bnBA
0>CiZP3Chi`0QIA?0:bjO@2^_H@0gN^f0<kTYP3<kil0a^ZP0<GSY@3?iKL0gO330>3e_039hZ00c^ZM
0<CPT`38ii/0an>I0=SYX`1bO3l0UiMQ0:ZOLP1nLdH0U9EK061[:@2[`gL0dnnT0<;MUP3:k:80`NfN
0<KXWP3FhZ80g^BV0>GY[03;f9<0OI590=C^Y03DkZD0dnJT0<gTWP37lYT0cO2N0<GUVP36jZ80`nbX
000C00004@0000h004EP:`003P00GGaC0<;W^`37m;T0FJA[000n3P2ekLP0_nJg0;[R[P1i_h/025LZ
0<Ob_@35kKT0KkF@06FUPP2nl;l0bOBo000B0013ERP0WZag04iL9`2BX6l0Q9EN092SJ`0V@Pl0Ih]K
0;o]d00MC3P0T[fc0>Con`2mikT0`nZc03iO:00T<``000T002E55P3:jK00c^j_0;?EV033j[/0T[^?
02@A000^5P00VZmg0=7/]@35h:/0UjUe06Ag@01VNd00a]jP0<k[Z@3AkZ`0cNZW0<GTWP3>kZ80c>^M
0<7PT03@lYh0anND0<[ZU`3CmJ40b>NI0<;MVP3FmJl0]mb?0<C^VP2cgHT0a>>G0=;/X`3Bj:00dnNP
0=S]XP36dXH0O7@/0=GhY02]d8`0d/fg0<GRZ02hjXT0a?n]04FDP@1XZXl0^nW<0>GR`@2dZh@0d]NM
0=KVY`34iIh0bNbX0<?KZ@3Ci;L0c]j_0=3QZP37hiH0b^ZQ0<?O[03XnLl0lOcA0=3>WP2c[G/0W9YQ
07am@@3KiJH0aM>E0>?e]`36f9X0dMnQ0?Woc@3coll0cNjg0<?X]03]omh0iooG0?Cnf@3ooml0IeXh
0:nSR@3bl_80oooo0?knoP3hn?P0mOGe0?Gfl@3oooX0nOcc0?comP3go^h0oooZ09VEI@1EDb80d=NS
0=OQ[@3Ji[@0h?750>7cc@3[nn00moo_0?;okP3Nk=D0f^Nk0=gT^01KFbT0De<M0=3LVP3:gYL0dN^Q
0<oWW@3EiYl0Ph=308^3A@2o/7T0f=6J0>;]]@35eid0d^b[0<_VX@3:iY/0b>BI0=;^X`35iIX0a>6N
0<CPX`30k9l0`^Ih0=O_S`3SlN00e_kn08S7_00hM6P003L0Q:fa0:O7`P0mGDD0010006^0A`3=fK40
mooV0=cig@3KmM`0ooc`0?ohk`3G_:/0ooKM0?ooj0000P00LGA]0?7al`3lnol0o?_f0>SWh`3`kn/0
oooc0?[hj@3ooo<0o?oo0?Cko`3eoo/0hOKG0<c[Y@3;k:D0amjb0?Koj`3looP0o_od0=kVcP3AhZ/0
b]jO0=_Y^03Nj<<0GEU=0<Zh[P3onOP0oNg`0?ojo`3oo?l0nOSn0?Sln`3lood0JFiW06AWH03lo_T0
oOoj0?3ek`3lo_/0ooom0080ooko06<0g=SI0=kHfP3Bc<`0lN_[0?olo03oo?d0i]_O0?gdm`3ooOl0
o?Si0?ono`3ooOh0ooko0?omo`3`inX0b;o20>?@eP3ok?D0ooco0?ono`1nPgd041<80?ook03ooNX0
Ie5308YbIP1PB3h0i=:n0?ohf`3KcYT0i]VR0=;5X`3om^H0oo_o0?omo`3ho?l0m?oj0?7ol`3iooX0
moWf0?[im`3on_L0oo;_0?ojmP3onO@0LEiJ075RG`3omoH0oogm0?ono`3_l?D0oooh0?oll`3kjn`0
lNK/0?[ko`35_L`0VY:@0<SV]02/k=80__?g04M`M03Io>@0a^Jo0=GV^@3lom`0o_oQ0?kdj03nlN/0
oo[j0?oal@1mOUH0YJaf0=[SY03GhIX0f^>P0=cN^@3hmN80ookT0?ooh@3<_JP0`jnh0:^3P`3;WiH0
f[:X0:1lL039Y9/0QeiH0:j0P01aAdT080000;^TZP3ij^l0^JNW0?GQh03ZeM@0TWel0<Ve]03KalH0
2`3oool000X0oooo00X0a^>Y0<kM]P3monL0n_K]0?Wfk`3koo40mooZ0?Coh`30eZD0eNNc0P3o0000
1P2jjYH0]^>@0=7[X@38fID0f^JV04]G5@80o`0007T0g^ZZ0=;P[@3o0000o`0005aY?P1aOd`0c]fV
0=?WZ03=hj80c>NT0<k[Z@33hYl0dO2/0=3^YP3=iih0dn^Q09R/I038g9@0d=nJ0=CSX03Hj:L0dnJV
0=3TY@3@jJP0`=nI0;gLV039j:@0anJS0=Kg/P2oj9X0b_FS0<?]V@30iID0`mnD0=O[X`2WYFP0i=ZU
0>_J[02JPeX0G4TO0=SIW@3KjZD0bnjL0<K`WP37mZD0^>NF0=CkZP2mgI80enf_0<GGV`3GiJL0dM^B
0>S`X`1PHQT0BDH30=W;VP3Oh:H0e?ZU0=CSX03Qhj80T9mL03]O7`0KDBd0QKJF0<?QZ`2H]g<0=FTi
0;kca@2gi:<0_oNf03j<F0009`00NKZL0:CM_@36o]T0]oK707fiQ@3;ijX0bNZc06joWP10Rfd0[nfZ
0<Kj[`005`00WKF10<[PW`3Fk:/0eNbf0=SdZP32hYH0OjQ^01Q@8`0gMV<0BX9g051_I`1>J5/0_NK8
086`S01GR5/0`nV`0<KR/@065`000Q00069h>P1@K3/0DG=S000=001IEc40EDhJ05mZ<P39g[D0cNO2
000<00036`00e^n]0<SRV@3BjY`0dNNV0<cRX@3?j:H0g_Nc0080bN2J0440cnVR0=G/YP3:hI/0bnFN
0=;YX@3AhY`0c>BJ0<KRU@3>lj<0a^fL0<c^X@2ng980f>VU0=WTXP3IgYh01PP009nYI03JkYT0d>ZC
0<KZY03;kK40`]nM0<_la00gTGL0Cgi@0;oFX03^mlX0[JUl0>7Q[@3FgjH0dNZY0=3_[02ogj00eO>g
0<OSYP2hd980b^>O0<WQX`3;iKP0oOoR0?Sdd@2KQEh0GdPO05mE903GeJ80gnjg0<KGX`3Okl80d=fa
0=o[``3ion40lOoO0<cKa03<flP0m_oc0?Cjk03oond0oooZ06eRAP2TWh40n?o_0?Cok`3iood0nooo
0?coo`020?_oo`1H0?Kom03eond0mOoS0?Sog03BciX0QHA>0=kWZ03Ghj<0e>BS0=O][@35gJ40c^Jf
0??oh03aonD0hoOD0=?N/`3DhK<0bMJP09bWK@13A0X0in:X0>ONY@3hkkP0gMJO065Q:`3oold0e^6Y
0<GCV03Ej:P0eNZW0<_RWP3@ij<0c>6N0=7TXP3@i9d0d^RM0<cRX@31fj`0`nBO0;kPL03@k7h0SImS
0<cSaP3Nool0Tl7105F8R@2`n^40X^G2000<00025@00d<jo0?oml03`oo40l?od0?onl`3ol^`0j<:i
0?oljP3Bd;T0OX5`0?Wik`3ooOl0ooSo07AjF03LhL<0dMFj0?kok@3bm^L0o?of0?Woo`3hool0l_o^
0>?ge032g9l0bnFT0<[P/@3fonD0lOc[0?_ol`3?fL40d=R_0=_R]P3hmmP0oooZ0?omn03oo_/0ooko
0?Sfn`80oogo06/0n?So0?coo`1/LF/0P8Ij0??lj`3koo40nOob0?Gml03looP0n_gf0?chm`3GdM40
mo7c0?ono@3mo?L0o_gh0?oonP3onOT0oocn0?ken03il?40oocm0?oln`3fk>/0^:j/05U?C@2cZjP0
oogj0=c>c@3onoX0ooOh0?ono`23Ph<000000?Wfk`3oooH0oooc04a6>03ooo40ooof0?cnj@3oolT0
h^BU0>7M`03dkND0mo7o0?ono`3]l^h0m_o`0?Gol@3iooP0nook0?_oo`3in_`0ooco0?oblP3okNP0
k]OA0::>Q`3oo?H0oocj0?_mnP3kooX0o_oh0?oomP3mn_<0f=OB0?_nm`3noo/0n_od06UmH@2gf<<0
h?oo03e[H03@m=P0`=nm0=_YaP3go=h0oo_U0?ohm03ok>h0oo3h0?oan03Yf[40kNJ_0<6gQP3QdjH0
IEH_09J1KP1:=2T0fL6g04La903Lb;d0`ZfZ0?oin`3ol_<0ooOf0?olmP3[hMP0ooWb0=Bk]P1QAD@0
G4A400P000040000i=kN0?omo@020?olo@030?ojnP3ooOd0oooo00X0oooo000:0?ooo`090;_KTP30
d:40`<FW0?Wbk03oo_P0m_oT0<_U]@38j:L0bnjN00@0o`0000@0gO>[0<WMU@3MkZL0dNFM203o0000
oP0^CRL0YLVU04QbCP1cXWP0]NNd0;?V[P30m;H0b?^h0;cYY033jjD0_>6L0=3^Z02O^W<0X;M_0<cR
VP3:h9L0bn6H0<GKTP2FZV<0VjU/096IGP30aXX0f^6N0=OQW03=giD0dnVN09J/H`1OKRT0dMFH0=ST
Y034jZ40`MjN0>;c_02EU6P0HE`b0=SHXP3?eIT0d=bJ0=CPWP3YlkL0b]fK0;_UT@35l:00[=^=0<;a
X`33lZ80cORV0;kUTP35j9P0bn^R0<;NX@3;i:<0]/1i0>[`/P3Chi`0aN6G0<Se/P0;A2<0Q[nO0=Cm
`@37j:40TZ:503959`3DlZ`0enZZ0>3^/`3=hJH0]=bP07JSJP1eX6/0c_?80<WbbP0fMDX0N<2K035o
LP0]MfP0X^Fb0;Wf^`2^gZh0B7=50=_oc@34l[@0QK9i0;7VU02hl:T0O;BY02MSH@05<SD000/60?_n
h@3HeK@000L0055`H@01;bD08Ei?019;>03?k/h0c^N^0;oBTP3GjkP083D^0=3Lf01ED2H0SHM=0<cE
X03Gl=0000d004I]@@1RR5D0`>FO0<7XV@3AmIh0bKZ108enA@2ZVf80O6dd08ioAP3Se9/0f<V@0:RI
H01MCQD0MVL^06MO8@1`NCH0a]ZB0=?[X@3GmJ/0gOfb0=3^YP33gYL0amNF08><C@25RD`0fMnQ0<_Q
V@3GiYD0cnN?0;_bU`32jJH0dNJ[0;3K[@0^S7@0d_O;0<gJY03;gZH0OHI70=CPV03Nl:H0`>6@0<S^
V@2oji@0b?JN0;OOR@35jiH0bNRH0<kTV`3]mkX0Ff0V0;NkP03EdI@0knNY061=4`2aXFH0EE4D0=[T
Y`3BlZl0g?_00=[Wb`3kond0nooa0?Cil`3nool0Ogf00?oko03ooOH0oo[^09R<MP3Gd;@0dMNa0=KI
^P3oonl0oood0?ghlP3oo_X0ooga0=cQ``3Cfk@0eNB]0=OUZP3BfYl0hn^_09JUI03Okjh0c^6O0=G[
Z`3Dk;00cNB`0?Oog03Hj/@0d>Jg0<7XU`2ojIL0bOFP0<K^V033f8/0NX4k071a;`1fM3T0_lB:0=?X
[@3<j:/0jOo;0=Sl]P3=lZ80dONR0<O/W03:k9l0`N>I0<CTV@33hiL0b^^D0<KUU`3AjKL0dN^^0>Gn
[@3@iY@0Uj=S09>OK`3/onh0jOoo0=goo`19VHh0M;R]0?_onP2_/:/0C3Hi0?WPi03nooP0lOof0:6T
T`2GRWX0<b4=079kG03;gkX0e^2m0>?Yc`3MgM<0hn;M0<kJVP3QkJl0g^Va0=cW_`3Ih/L0i^oN0P3i
ood0PP3ioo@0n?o/0>Whd@3Bg[H0nOoX0?_ol@3jooT0o?oh0?3di@3ko]l0/k>A0=O=/P3oo^P0m>ON
0?ojm03blNl0oO_n0?ono`3`koD0ooko0<G7`P2e^jl0mooV0=;M_@3Ljl80cn2f0=_[aP3?gKX0o?oZ
0>KXfP3oooH0oooj0?oon`3koOX0nool0?coo@3hn_L0ooom0<70_P3oo_d0o_Kd0?oln`3on_L0oogj
0?onnP3oooP0oooj0:bSVP2/XYP0oogh0?omn`2>R8`00`040?3^l`3ln_d0loC_0?oonP3bln/0bNG>
0<?X_`38jZ00bNFJ0?Soh`3kooP0o?oo0?con`3TjmT0fNS10;g=Z03Df/00ooo_0?clm03imO80ooOg
0?oal03olNX0ooS_0?ofj`2KRGl0oo7/0?cCf@3of^D0hJnj0<fIY@3]^<80gZVa0<bIX03[^/00omOJ
0=6YZP35WIh0BTI700H?302?UXH0`lRb0;6cW@3oon/0fMK70?olnP3omO@0oocj0?omn03Ugkd0g]N]
0?K[c@3olMX0ooc/0?oimP3on?X0ooOi0?oin`3nl>l0ooSe0?omo`3`k_<0oooo0<C6``3oooX0HU]C
0?SYi03D`Kd0m^CP0?omnP3ooo/0oooo0=?Cd`2<S8`0A4A40=gMg@3emOD;0?ooo`002P3oool02@2:
Z5h0JGU80;6fUP3ooo@0lo7U0?Soh`3=j;<0a>FP0<GXUP040?l000040=;QW03OkjP0c=fF0=S]XPP0
o`000?l04STJ0:[D_00jJED0:5a504^3GP21^Xd0O;R2066MG@27^gT0`_2_0;SUXP39kZT0`nBO096/
I@2H/VT0f_2W0=7WW02K/FH0ZKee0=?QX`2j_hD0WIiT0>g][`3GfIP0c]VE0=c[YP1VMC80V:9S0=WJ
X03Ojjd0`O6W0<_`[@3HlKP0SY=Z06QY?`3/k[d0b<fG0;JnP`2LY6/0][R70<cEWP39iIX0bNVM0:gH
R031l9l0bOVU0:gLR`3=o:/0boNZ0<3^Y@37nK80_nVQ0<SITP38fiT0anJH0<?YW02mjZD002d904n5
H`2eiJL0`>FP0=KNaP0@6P80bnRX0<_IW03Ti:P0g=fQ0=3UXP3>j:L0cnV/0;gHY@35jKT0Yn^h02Yf
B01?U7D0N[^I0;Oc_@30n[l0_o6l03m^@02IbIT0OJek02=C7`2fjjD0]>^a07BVY@00;SH0@5mR0007
003Vikd0hMn_020V30076@/01RTS00E0>P0050L0P[6=0<KY[`3Un;H0`/nJ01`R5P3AdLL0UhQM0:BG
H03;fJ@0bnc=000?0027Wg/0OIAX0<gSX`3@iYh0a]^>0:nSI`34^7`0XIMI0::HFP2/X6@0gM6E0>[P
XP3FbXh0ZIeQ0<RnP02QWEh0JG@b08^PF`3;hY`0aN2I0<SSW038hY/0Z/5k09b/J`1?Fa/0KgTj0=7M
V`3Ajj40dN6F0<oXU`2ll9d0`n^R0<cRX@2kik@0FKBR0<7W`P36eZL0gO:i0:2[I`3=fhh0d^FD0<g^
U`34ji80a>nC0<7/TP3HojH0b>ZD0=7/V`3DiYX0TIMA09^RGP3CgIH0jO2Z0<G4P@20KS00nnF[06QN
8@3Eg9T0b>jS0<__[`3Ag/80noo]0?Kmk@3noo/0kno_02`W:`3ooOl0ooSd0?oll`3^hM00nO;H0=3G
[@3Fg;H0oooX0?oojP3oon/0ooo/0?ooj03KhkX0c]ZX0<oRXP3AhJ00f>BV0=KRY02JZV`0amVM0=?U
Z`36fJ80dN>_0<[J[@3homh0cm^g0<gO[`33kY80_^f=0<7`TP35l9@0e^fK0:FaI`2LXEh0`<670=CL
X`3>iJd0bnR^0>Goa`3KokT0aNZJ0<7WU03:kj40`nRK0<7UW@3=lJL0e?JZ0<ocW033i9<0f?2f0=og
_@3Smk`0h_Bh0;c5SP2:TV40f>c90=_ih@3Rool0N[g305N>T`3dnOD0m?Cd00l0002jXJD0ooog0?3o
l@2j_JP0XIV400X0003Ej/<0a^>e0<WFZ03:e[00k?7K0?7ei03Bh9D0^/N10<[FU03?fjd0bmFc0>kf
g`3jooT003H0o?oo0?con03bnNL0fN;50=CJ`03noo@0oOoi0?koo`3ooo/0ooof0?ooj02RWh00oooS
0?oihP3ooNd0ooca0?omnP3ooOd0i^3R0?omo`3oo_l0n__e0?kol`3OjLL0c]^`0<OHY03:gJH0_m6M
0=_[_P2P[8@0mocU0?ook`3oooP0oOki0?[no`3lool0nooo0?coo@3fn?<0d=7<0<70_03oo_/0g=OD
0?onn`3oo_X0oooj0?glm`3em_40^K6V0:jTV03nlnl0no7`081gO00500D20?omo`1;0?ooo@3cm>l0
n__e0;SC/P2nhk00c>bP0<cVW03lon@0ooof0?olo`3oo?H0j>?@0=OJ[`3Hfjh0dm:c0?[hg`3onN/0
oogd0>?@c03okNT0mMS@0?ogj`3fg<l0GTY10=70^@3FZk@0i;2l0=FO[034SY`0i:bi0>6Y]03od]d0
`i2I0?oGg@3ohN@0g;:f02dN9@0_:Bd0k^[O0?gjj@3<bKH0ooc[0?oom03ooo/0moWf0?CnmP3hooX0
i>O:0>?R``3oonX0ook_0?omm03on_d0oo3e0?ojo`3ml_P0ooco0?oin@3ooOl0k>O[0?cjo@3Adm00
oooj0;jg/@3omNl0^JJR0>WGe@3ooOX0l_7]0?Win@3oool0jNWY03Xj>P1]KFd0R8R800/0oooo000:
0?ooo`0:0=?RY`3KhK/0nOWQ0>SQf`2PW9<0f>;00<OGZ03?iJL0aN6G0=3ZX@80o`0000H0`]:;0<cL
U@1AH1/0BU/E0=[^Y`2fbX<20?l0003o0=3[Y038hih0o`000?l0001YPEd00145000:2@3Tool0hooo
05b:O@1EQfh0/^K20:cR/@2cjKD0`_No000E0039l[X0a>N]0<3NX03:ijD0cNNP0=3ZX@3Ak9l0`]jA
0<WYX03?iZ80`M:>05mX9`1mR4H0dnBP0<WNV`38hIl0e>ZZ0>3b^03?gZ<0fNBZ0>OZ^`3ThKP0HU@i
0515:@3CeJh0iO3509NcP01TPE40Tk:80<GG[`1FBAd0THaE0=GUW02kdX80d^fL0<GOV02keI@0aN>S
0<W/Z02ijYP0^NnK0;cbY02egi<0dNRJ0<WOUP3?ij/0_M^g0=3^c01[R5800Ql0000<001GMEd0_MRS
0=Ka_03Fik<0c=>P04Tm3@1WFbL0Ad880<CIS037hhl0a^N<0<[[T03GnI/0bNb40=3bWP30hYH0`N:M
0<SW[P3<iLP0`mbo0>3ic`087`0000X0000;000?5@L0NWeb0<oI`0004@00:3d00=SI[@3Lfk`0XjN>
09NfU02HaZ4001@0000A002Z]G40B4`A00L2000=0000ARh006AC7@39fZd0`^W>000A002PRgX0IE4f
06aG:P1RC1X0Ie4H07FGBP33iIP0d_BW0<SZW@3AljH0`nFH0<;TU`37jI`0d?:U0<SZW@3;jj00dnj[
0<[PX03OmKD0a]VI0<gMWP35eIH0g_6_0<;GU03RnK<0b^BM0<OUV`39jYT0dNRT0<gZZP2jj:00`NRE
0=C]W02iiJX0WoK]0>KonP3eonX0f^bh0:BWKP3WijT0h>:Q0<WFSP3>h9H0c^>H0=S/Y03<fI@0j_2b
0=?BVP1RHBP0D5DC0=cSX03KhJ<0Zj]e09fJI`3RdjP0Z9U^0<_7V03FgJT0]]:E0=7/]@3Hh/X0o?oa
0?kol`3oooX0lNg/00H0003jl?40hm?C06=DC`3mk>80noKP0<_X/03=j[80an:]0<WT[@3=jJl0cnf_
0<o_[P34j9h0`^RK0<G_W@3:ji`0gNJW0=cTZ01GGb`0joC50?cog03eom`0o_oS0?Kkf`3oon<0f]Vj
0=SP/@3:ki80bnnE0<KXU03;j9P0d^6L0=cRYP3FeZ00oooG0?oog03fomd0h>c60<gJ[03Ii[40enJ[
0<oNX`3@hJX0loo@0;73T`2P/X00X;=l0<[NW`3AiZ40d>BM0=7RZ`3fon<0GfQ=0>CY`039cYH0f>>Y
0?;oe`3[onh0X/[S04I^R03^ool0jooo07YhO@080000oo[f0?kol`2JTWd0IUHm06eS@008600000l0
086CE@2HZG<0a]B`00/F003KjIX0fnVL000:0<3=Q`3Oik@0OXAN0??eg@3oood0oogo0?kjn`3lnO@0
n_O^0?gel`80oo_o02<0ooWo0?kgoP3ooOd0oooa0:fUTP1ICCD0He@m0;f/VP1<>b/0Gdi60>CEd01/
GUh0o_Gj0?omo`3ooo@0nOgV0>kjbP34dYL0g^nX0<GIT@3:gYT0TJ=U0<_JX`3<e:l0f]k30?kol`3n
ooT0o_oo0?kno`3joOl0nogj0?kon03fmo40oooj0:^VX`030?onn`110??cl@3gnOH0o_om0?W`i`3o
o?<0nNkX0>GJf01ZGV801`000?_bm@3on_L0n?S^0?oom03Jfld0bMZV0<CIUP3AgID0f=fM0<ZkYP2V
SX`0h/7<0>W7b01VA3P0g/6E06965035^X`0h]Zc0?omiP3on>X0oo?_0?ogl`1fFTl0KU=808eeJ@3o
n_<0oo[f0?ono@3moO/0ooom0?ckn@3kmoH0ooci0?[fl`3;b/H0oooj0?con03kooX0o_ko05ABG@3F
eM40o?cb0??ai03ooo@0n__c0?Gkn`3^n?L0m?oo0?;oo`3`o>h0lo_/0>_`jP3lo_d0oOko0?Sgo`3o
oOl00P3no_l04P3fnol0nooo0>SRiP3oo?l0ooko02d^:@051P40ookh0?oln03onoP0j]_H0?omnP3o
oo/0nOWi0?gmo@3Vi^H0n?Sh0?[jnP`0oooo000:0?ooo`3;0=OKZ@3Fd[D0ooo]0?okn`3onoT0ZJN>
09:GK`2GXFd0TZ9S09ZZK02BXFH0RY]G07N8@P29VU@0e>BS0=c/Z`3DhZD0d^2S0=COY`3AfjH0fnFa
09ZRL@3Ae:L0Z:b;020U3P00100000@5008E6`001`/0F7I/0<k]f`2oh<D0a>S20;cV_P2dgk@0[MJZ
03EF:@1YREX0f_K30<GPZ@3<iZL0dNbY0<GSV@3@l:D0_>2F0<[XX03RnK40TYmJ0:NcL@3TmkD0b=nK
0<OTX@3=ijH0e^^`0<WDW02eZ7/0W8QU0:F<KP1bEd@0IE0k07n0H01]O5<0H8AD06ZAHP12K4@0HgiK
09nAM02KVVh0U:QQ0=ghZ`3AkJ00fo6`0=[`/P3=hjD0`MnI0<CaUP37nYh0aNZT0=WRW`3ok:h0ZI=J
09J>G`20PfH0RXU]07MY@P3AaId0VjZE08ZHO`2aYVh0dmBJ09fRJ01kN4<0^jIi0:JDI01OF280c^:M
0=O_Y@31cH<0Mgdc0=cQT@3Nih`0e=fN0=OPZ`3KiZX0bM:K06Y]D01eM5D0Jf/e06QR<P26PU<0Nga@
00/0001nMFH0HFA906=m?P21V5@0<Bd00:RKN026Ne/00AP003mI:@001@00NgiC0;k7QP2CXf8032P0
08bRM01gM3d0Bd8;06YWA00a>RT000H007V6J02BWWX0am6L0<oIW@3IhZ40d?2U0<[ZW`3;jj00e?BY
0<GUVP3:jYl0d_:W0<c/X@2jfXl0b^ZO0<cZY036hj<0e>b`0<WMX03EiJL0gN^^0=cZ[030d940a=^G
0<_VW`3?kjH0d_NY0<OZUP3>j:L0b>F]0<7YZ`35jiH0d>VE0;gY[02IjnD0hooo0>Sni`3Tm<D0^K:8
08EfB`2AQUP0dm:L0>KV/03KgZL0g]jZ0>OP/P3om/h0RWIE089fD03Ihjh0bm:O0>WX_019>Q/0OFeC
0<FnY016A2/0o?oT0=OS_`3comL0j?C@0>O`g@3go^`0mOW[0?KckP3oo?d0Ac/m0?ojo@2STI40IUA@
0?ojl`3`jmL00P3;j[40D033hZH0a>BU0<KVY@31iId0`nVN0<3ZV02ojYP0`nnJ0<OXV@3He9L0kN^b
07IeA`3HfK40oooO0?ooiP3oonP0oooU0?_lg@3IfKL0dMf_0<?`W`33kj00`n^R0<W^Z03<iJ/0dnJ_
0=7Q/03fomh0n?oS0?Coj03<fkX0jnG30>[R_@2QWG00V9EX09nKM@2_[8/0inK80?ooh`3ooml0i^Vj
0<oHW`39fY<0iOBm0?Woj03^m]h0d=>X0??f_@3KhjL0k?S80>ooj@3<j?l0KY2[0;WWi03Mool0_]3@
00000P35]kH0m^oU0:bGQP3Zc[T09Pd004e>8P1XMd00ho>d0>Ke_P3Pk<H0JWEE0<kIU@3Ii:80f^BW
0;RnT02g^iX0ooo]0?ono`3oo?l0oo_o0?olo@3ooOX0oo_o0P3on_l20?oko`1:0?olo`3il>T0ooga
0?3Sd`37]jL0OFYK0<6[W@0_6a80@2dY0<Vf^03on?h0nO3c0?oom03MhLP0h>fh0=WYZP3Eiid0f^ZS
0=SWYP1WMCP0j?:m0=OM]`3TilX0oooc0?oon03oo_l0oO[o0?omo`3ooo/0nOW_0?olm@3mn?80oo_h
0?omnP3nm_@0o?Kf0?ono`3alO40oooo0?omn03nm>/0oo_h0?W[jP2=OX404PH60;>/YP3[im`0gn7;
0<S:/P37c:h0/<V809FdJ02<X5T0YkEj0?_fhP3om?00ooSo0?oin03okml0mN^h0?S`/P3Wi:l0fmNZ
0?omi039]:<0Wh9n0;2CS`3:/j/0oo7X0?o`iP3omO80ooGe0?Wmo03_n_H20?Woo`0F0?_oo`3kood0
noom0=KLf03ioo/0k__a0?Gon`3Rmo`0LXJ=061aJ`3fooT0jo7S0?komP3loOL0oogo0?ono`3nool0
mOWh0?_on`3ioo/0loWg0?[no`80o?oo00<0l_Co0?coo`3_l_/00P3kool0303ooOl0oo_l0?C^kP0>
3`X0JfaW0?_flP3nm?80i]KF0?oin03oo_/0k>_W0?gmo@80oooo00<0moOg0?ooo`3kno/02`3oool0
00X0oooo08d0fm2J0>?E/P3ooN@0oo__0?okk@3om]D0mnZn0>CHY03OfZ00f]RO0<g=U`3NgJ@0fmbR
0=;EWP2a^HH0_lRI08fGLP1^MeP09BdF00dA00000P00100000/0000=0000<2@H0=kLa`1SIDd0=3dP
00lJ001NK4/04R400008002/^Id0iO?J0?Sol@31c[X0e>3:0<gI``1BH4H0amZj0<OR]`3<jK/0^]fW
0=;a]P2idY00d=bJ0>7WY`3Iei`0gM^R0<oBV@3XkK<0eMjU0=;GW`1?CAX0Xj=a09VPM02o_i/0fM:f
04<^7@0T4@80RgmW0;2YS03?cjd0d]6c0=K@^03Od/8050000961LP20QUX0D5TT07Ai@@2/W6/0[9AT
0;:CG@2VS4l0X9Q50:6PD01XG2X0HSl907]=6`2XRE/0TY9/01D_2P0S<`h0>R8007eN@@1lLf80XYf:
08Y`E`1WABT0/I5R0<^aN02SUU00NF`V071Q7P2kW6d0`j=m06eE>`1lJU80PWEC081eB00K3PH07a4@
00h0000/6`L0HdE507ICC@1R?b40QeU205dm:00L8PH03`000:J7S@2`U900Yiig09b?H`2^RgD0Xh9c
0;FOTP1bT6X0A6Lo08Z9K@2MTfl0WY9P0:BNK00?5`000@H001L?000;0`00KgiE000D000QARL0H7AA
069dBP1UMcd0GFd_06Ug>@1^Mch0JW<j06Qa>01ZLcX00P1/MC`0P`1[M3/0JG8i06Ub>@1[M3/0K7Xo
05Q`=00^APX0HgPm06aj?`0c?P80LGdo05e[;@2D[fX0`N>I0<[`Y@2njIX0`NND0<ob/P0O?0h0i?kG
0<o`X@3BjI/0_nB^04>@R01IQ7/0014006QgC01SGSh02`0002@L000o?0l05aH0071_?`0f<`H07aD0
03d`401A?BD0LFM<065aBP1UKd`0Gei201h>000b91L04A<605AOC`1RMF40G6]F06Q[F01YJUP0KWAV
05mRE`1XJ5h0JV=M07M/JP0I1`D0ooGd0:JCS`1MB4D0oo[c0>[Mc@3]k/@0d=>T0=[OZ@3AeY`0e]bP
0=CMVP3Nj:<0dM^F0<kHT`3EgiX0VYUH0=ZlR03^dZ80P6Y305Q89P3Zg;l0j^C:0=oN`P3>d[40aL^W
0:jeR`2i_i40XJA_09JFHP2NV6P0WiQZ0:2HJP2g[X<0VY5V0:FLL`2`Ygh0ZZ5h09N;H`2WUV/0akJ:
0<k0S`3>`Y80o_;<0<[0W@3Ec:l0/JR90:VQO@2k]hP0WYiZ0:2YL02b_hT0QY=U0;2mS`2ma900d=>L
0>o^_P3bm<l0jNkH0=[Xj`3Ek_D0AWik011FCP2@^[H0MXZ901@41`3]g]/0`ZJJ09]jJ@2MOf<0VI5Z
09nRL`2?Tf40ZJ^30=?E_@1RHe40`/FZ0080d=>f05L0hn?;0<K3]03^j^40n>kf0>cPjP2bYJ`0g=3B
0?7Vh03Uf]@0lNKP0?G/i`3Xh=h0l^WZ0=37b03ej_00gm;I0=S8b`3/fM/0eL2m05Tn=`1XCdX0T7Qf
0=o=c@3oo?d0oOWf0?kol@3fon80d^2[0<_NWP37eY40f=nY0?OibP2PXGD0NgaD0>?R``3oonH0hM_;
0>[Tf03`i^@0k>;Q0>oSi@3onoL0l^GO0?odk`3Vem@0nNOW0?ojnP3di^H0oo3c0?cam@3VgN00gmWM
0>gTi@3[hN80n>c^0=K8b02k[JX02P000>3J`P3Cd:l0emj[0<oHW`3Skjl0f?:X0<3KU03GjKT0looN
0?konP3jn_`0o_ko0?coo`3hoo40h_C20<SQW@3;fid0oooD0?ogg02kZ9X0ooSh0?ogn@3ooOX0ookk
0?oon`3ooOl0ooco0?omo`3oo_l00P3ooOl30?oko`0<0<g4a@39`l<0ookm0?Sdl@3Sool0R;^n0<?/
i02I^jd0looh0?GomP3oool0oo[o0`3onOl05P3oo_l0oOon0?koo`3hnO/0noco0?coo`3in_h0o?go
0?gno`3nool0m_Se0?ohm`3om?80^[:_0?Cel03noo/0ookk0?omn`3ono/0f/k>0?onn`3ooo/A0?oo
o`002P3oool0302RVEP0DDLF0<k2W02j[980/Z:80;JUNP2@P4`0MVL/07M_<029PdL0I64/09:8E@80
o`000?l0RHiV03i68@075@0000L0034o<P2`_K@000@0020R8@0F3A00200001TA100l@1d0FV4g07B2
C@2>WfT0VZYi08NIJ@1IJSh000L000<7000F5`D0RXel09jPTP2DV8X0CEI503=0;00H;a80DVe:04EU
?02ddJ40LhM<08::CP2JWF@0HF0Z08B4D03<d9d0/kb7065X=02LWV`0K6@f00L5000?9@007RX400@7
000Q4@40;ah>0;ZXT03A`JL0_Zf?099mHP39ZYP0ilVn0;FUY@040000P95]08FHJ`2O[G`0GU8R07AL
;01UA@`0XXI70:JNC@2HU4X0]J]h0:jFFP2ZU5/0[JEf01X^2@1aWWD0Q:Um00@5001ZH3d0THmf024T
3`1kO6X0Y9R209R1F02cWfX0ZjMN09nIC`2SU4l0Me<S07eJ=02YUG`0Zj6809NFM`1FES00100002@N
8P2CRGd0HE=6048U:@2aTY00@Ql;03`@1`0f60d00Pl000/4000c6240=APJ03`[3@0d8P00>QL404l_
900@000000h0000L000;3000>S0<0;:SNP36_IH0<3<D018C000e;0D08AX004UP<P1EPeD07TlR051Y
@@1RN4X0MHU<0766A@1MKB`0JWDm06]f?P1[N400M85907Z5C@1eP4P0LWm707=nAP1bODD0LWm707>5
B`1bS4l0IGm208>IF`22TU@0H6ha08JDEP1jRT/0Wkeg0;gQU`36kj<0b?>T0<c_W`2igId001400>ko
i@3<ij00am^F0<g]_P0aNfh0G8Ym07JCO@1eQUX0RHeX06maB@24RU`0NhE@07J4B@1lQdd0KWTo08V=
F`2OWG@0Mg5?07AfD@1QL4D0PhmY08J=J`1[JE00OWiV05aTC@29UGd0MHE[069bF01RK5<0IFeH08B7
OP1jNg<0QHEm07mdL02ZViH0O6US0=O2_@27LVd0Ie=<0?7Me03ol^80lnk60>?O/P3bkk`0e=>M0<W8
T03Kfil0YZIX08F4A03AcI00/Zia061D6P1bCQ`0Hd<D08I]A@1UDBh0Z9Uh0;VdU02a/Y00Yjn60:6/
P@2CWfd0XZYg07Qa?@2NU640ZYYY0=K6U@3:_8/0YIUW069H9@33_XL0_[N109fDG@32^H80f=:H0=kH
W03AcHh0b<B70=KCX03Kf:/0hMnh0=;CZ@3DdjD0hNFZ0=KKX@3@eZH0en6_0<GFW`3AhjT0hnjf0=KJ
Z03Og;T0j^W=0?OhiP3hooX0kOon0=ooo`2Ad/`0WL_804iVIP1??T@0l^;R0?OQeP3H_Zl0mN760=WI
/`38cj<001L0emR`0>3M_P1iMVL0K6UP0?oon03Acl80blVl0?WgjP3oooH0o_Wf0?oko`3omOl0oO3g
0?oko@3ll^T0ooka0>oYf@3oonl0oooc0?oomP3mn?D0lNO_0?ojo`020?oio`120?o[k@3okn/0TGQc
0::=R03onoP0kn[T0>o_h`3Jh/X0aM2^0<CEWP2md900UJAS0:^^O`3Yil00d]2Z0?[ge03Nfk`0hmo2
0>SSc`3[i=@0k>;I0?7Vh03fj>D0l>7N0?okmP3olo40m^;Q0?ofm`3cgn00h<g?0>OGfP3cin/0mN[^
0?olo`3ek>l0ln[]0?oho03jk_00XYF?0147003Wh/@0inFn0>K`/`3Jij80c]jE0=W]Y@3<gil0j?;?
0?[nk@3oo_l0ooco0?kno`3kool0mooh0>3gb`38iJD0bn>U0?Woe03Cc[40N6QK0?o_lP3onO`0ooom
0?coo`3kool0o_oo0P3ooOl20?olo`80oo_o0P3on_l03@3jk_00Uh^=0?ogn03ooO/0fooo0=Woo`2G
`[/000`00>_llP3ioo/0oooo0?ojo`3onOl00P3on_l00`3oo_l0n_Si0?ono`020?ooo`0A0?Sin`3n
ool0oooo0?_kn@3al>`0oOch0?oknP3Te]D0@CLe0?_lm`3noo/0ookk0?oim`3omoL0e<S80?oln@3k
n_H04@3oool000X0oooo00/0XJ1@0:FUI@36ahh0gM^b0>7N/`3Oe9`0elb<0>CJT`2OVe@0f]VH09:?
G0040?l00004000600002@00GgQU09Rf[080o`0007/000/:00@:2P000`00KGEM09>UL@3Tn[X0Xkmd
0<OVVP3;jJ<0c^RY0<[SZP0b@AP03A0000H1000e<Ql0k^cO0?oomP2MX9D0?dLj00/N2`0<90h0HX1T
0<WU_`2?YG@0S9YU0;_8T`2DX700UZAc0;_AXP2meJD0?4hN034j3@2RWgH0NgiC07RCIP002P0010X0
00`1001TE4@0_jjD0<FbU030Z8H0VWeM0=BZU03I^ZP0g>cO05MgHP24^YH0S<BG08BdQ02CYVh0UYaP
09bIE03Ce8h0fNjO0=?[X@3@gj@0e^BI0<OJV035hJh08d/X0;?]a02ln<D07DT>04AT<P1mU6P094@O
05V?M`34k=40f>[40=[V]P3Kgj80kNb/0=;:R`2UUU/0YYUR0=oR[@3Mj[D0an:]08bWL0045P0000H0
079jH`0l?RP0200006YLD`0C0P007@@000d000002P0071h901P<3P08000030H000`3000G0P003P00
00T30019JSD0Gh1900H4000;0@00JV520:FTR01KJU<082hE055B<P1<C2H0f_;00;GPZ020/GT0WL>@
0<KY/@38jJ@0aNJO0<3PU`37iJT0aN>W0<CSY`37iZX0b^R/0<WWZ`37iZX00P36i:P02`36iJT0b^RZ
0<KTY03Bk:/0cnRW0<[MW@3<g9d0dnJV0<cQWP38iZ00an^Q0080`^^O07h0c>bQ0;[QWP1OOe00mooa
0<oTZ@3NjkH0c^S303UnJ`2;^ZH0c>cD0<cR]039gJ`0`]ZP0<gWZ02ngYD0aNFI0<_/W@3<jid0an:K
0=?YZ@39fZ<0cMjX0<gIY`3Rm<80g?>o0<cT/P3CjKP0h^g20?cof`3Vk/L0e^:l0<kW_`3DjLP0o_ok
0?oon`3flnh0ooG_0?okm03Yd/X0ooWa09N1MP1UCd@0o>SM0?omj03_lL80j^bm0>[/^P3FfjD0albD
0=_NY@3Zjk40[jed0>;MX`3Bc980GE0I07UG9`1ZBa`0GdXM06YK<03>aIX0f]^a0=SN/P3Bh:d0dN:/
0<SKX`3Ij:d0TYUF0>_][02KUeP0`[io0>;WY@21S4P0Xk=/0<GJS@3FjIX0eN:C0=OTU@3Dhi80d^6>
0=_ZU`3HjIT0f>NR0=;RX`3>gJ@0d>:V0=CTY@3AiYT0f>VU0=WM^P3=eZT0e^Z[0<kSXP3Ul[X0g>:f
0>CRb`3bkmh0ooob0?com03ioo/0j_oo0<Oin01GPGl0LHV;02`M901jJfh0mngS0<NkZ`38aj/0eN>o
0>?cc03Cck80j>;<03lh<P3ono/0ooco0=C>cP23OW/0ookh0?ojm`3hl_80oo_o0?oho`3llOL0oocm
0?oll@3oon`20?ooiP0W0?oojP3in^X0ooof0?olo`3bj?<0QWJ30;FT[P3onO/0ooWc095jLP2UU8X0
oocb0?Gfi03non`0nOoT0<oP]P3FjK40f>b]0=3PXP3Hfk00d=2/0<o?Z`3fm]80oooQ0?ooh`3oonH0
oooZ0?okjP3onNX0ooS`0?oelP3iinD0ooWj0?ohnP3okO00ooWk0?oem`3om?D0oo_m0080oocm00l0
oOOi0?K`m03omoX0ooOh0?;Wh@080000dm2a0=KG[@3JiZH0d^:I0=7VU`3Ii:00fn2Z0?oji`3oo?/0
0P3on_l0403oo?l0ooko0?coo`3Um]@0cnJ`0<cYZ@3`olh0]kJH05Y<?`3oko<0oo_o0?_oo`3gool0
mOoo0?_oo`3ooOl20?koo`80ooko0P3oo?l20?olo@0<089iNP3nn_L0ookk0>Ooo`3Pool0RZb[000?
203_o?<0noom0?ooo`3ooOl0ooco0`3oo_l0103ooOd0oock0?ooo@3moO/20?ooo@0?0?Cck`3ooo/0
oooj0?onnP2m[Z/0PgAa00h3003ooo/0ko7/0?ono03oo?`0ooWk0=O;c@3oo_/0o_gi0140oooo000:
0?ooo`0;0<o`X@2gfi/0eOc30<odb03:jKd0bmbX0>C_]`3PjK00ho6n05Y]?`002@00103o00000`3M
on`0goof07:MR@040?l0001c000<003Gm<@0b>J`0=3f[@2ggXl0a^jF0<O_U`2fg8T0`^BG0;gOU@3@
jZT0c=^R0=OO[P1AF2h000@00003003Uj=l0n_oh0?Woo@3eooX0hO7W05U^G@1?KE4000l001]38@32
lm<0Zn710:OT`P1o_9X0SKbJ0;7D]00lAR/0Bdld075/CP3Pe[d06P/005Y4=P1LBSH0oooK0=cKZ`3G
gj@0i>Z^0=OFWP2QWfh0cM:b0=3Tb@3Ooo/0?GEL000D0037iZd0e^fY0=3TW02jfIH0/>Jd0;[b`@2o
iZ<0_nN?0:g@T00M>aD001<70;CG_`2mi[h0^MnV0=kja`3OkK80a=VH0:CMT02alJD0>70c05f9EP3I
kLP0gO??0;CDZ`0lP4D0N<N50:C]Y031okh0]o>g0;C/^`2^gJl0[=JX0<3R[`3=kk80b^ZN0=3`Y@35
iJ80bnZa0<CQX@2meH/0_]bX0;_VbP2ok<l0PZan0<S/_037i[X0b^Zk0<7OZ`3?l:40/=N40=Go``33
hk@000d00006000N=SP000H700`?101BEd00`^JV0:kYU@2dmYl0`oBc0;c[Y@35lJ80`^fM0;gVU`02
0<GTX0050<CUX035iZ40anJR0<SWX`37j:<00P37iZ80FP36ij80b>NS0<o]Y`3=jj<0a^BL0<[UWP3H
lj`0`]fF0<KTW032hI/0a>>M0<WZX`3:jJ<0c^RW0<7YXP2jfZP0oo_l0?Sog`3oond0l?k]0;Cdd@13
ME00_^:l0=G[_@3:i[<0j_o?0=ko_P33kY`0boNP0;g/SP2njhh0a_2J0<S_WP38k:80kOo70>ooa`2o
g9`0`>FO0;o^W@35l9h0dnjO0=OYW`3LjjX0f>b_0<O[[P33h;@0m?Gg0?cjn`3hlo00ooG^0?ojl@3o
kMh0HdTh0?oeh@3onnH0oo[T0>cVa02jfiH0c^j[0<CTY@3Al;@0aN:X0=;[/P3Cj[80b=NN0=KQY@3R
jj`0c=2C0=3=UP3Thj/0c=:D0>Ob/03OkZ/0dNNO0=C[X`3;iid0d^bU0<WSW03Ejj<0PH@m0>GTX@3W
gj40in6U0=7JV`3GjZP0`MbG0<c`YP2mgiD0dNRP0<;JSP80co6M02X0bNZI0<GUV@3Bl;00a^>[0<WS
/`3;i[<0cNRa0<g[Y@3AiZd0n_SY0>CZcP3=hK00f_6k0<[M/03FhL40ooof0?onn`3oo_X0oOog0?oo
n`3WjoH0h?oo04j1O01SPX@03P@?00@0103ooo/0nO[b0?Slk@3eoo40`]Bj0?ook@3hm^X0oogo0?Ka
n03on_l0Z9nT0?olo@3oo_P0m_7]0?oln@3onOl20?olo`0T0?oko@3alND0o?oZ0<[F[P3@gk@0amJ]
0=3K^`3lond0m_Kd00D01P3onol0oo_k0?ofj`3oo>`0IE]20?okg@3`l/d0i_C30=3U[@3Fl;40cnVX
0<oXY038gi/0enZZ0<;?U`3?g:H0`<nF0=[Y/P3>gjP0aMJP0<KCY`3<ejl0eMZj0?3cf03JelH0[JBO
0P3ono/01@3Mcll0jmgM0?okn`3oo?/0oo_h0080oooj01h0oook0?KglP3ooo/0ookm0?olo@2YWid0
1`000?ook03oonH0o?oJ0?WoeP39gZD0a^>Q0<SU[@3eoo/0mooo0?Woo`3good0m_on0?Goo`3bool0
g__O0<c``02oij00c^j[0=[K^@2TUhH0oo[j0?oko@3hood20?Coo@060?coo`3ooOl0oogo0?ono`3o
oOl0oo_o0P3on_d04`3omoX0oo7b0<Fg]P3omO<0oocj0>goo`1CMH40g_Si07V<RP3koo/0ko7^0?oo
o`3oo_l0o_ko0?Woo`3gool0ooko0?oloP3ono`00P3oood04@3^lnl0moWf0?Ogm@3ooo/0ookm0?Sb
lP0T4Ph0d;fg00/0003em>l0nogh0?ooo`3oo?l0ooWm0=K<c@3oo_d0o_gi0140oooo000:0?ooo`0<
0;KWY@36o<P0[>Fh07F/S024]IL0c>[608NPN01LLDP000/0000<000RB3d0JhZ40P3o0000102DakH0
HiR405nEO@1?PFH40?l0001j07^GI03>kZd0_=nK0=7g[03:lJ80`NJF0<O/W034iIH0c^fQ0=kj[`3>
j9l0c>JM0<oTX`3Fik00g>S204I?<P000`00N7]d0?GjmP3lool0loWe0?Oon`3Km^L0d?GS0<G^g00I
CSX0IJ>>066WS`17Rg80YMK00>Som@3cnn`0lNkM075PAP3cgLP05000079HB@2aWhT0jnc00=;OY`3?
jJ00b>:I0=S_Y`3?fi/0GDlX0;FjW031imP0R;NW02]I?`3=k[D0eO2]0<?QV@3Tom40Qlf[0;Klf02e
h9/0f?nX06V8C@003P00744j0:cI`P2ghK/0aMVV0<S@X@3PgZ40iNRS0<KVVP3=mjd0X]:D07FPJP1[
RV40>E`d000B0023cY<0?Xm=06ZcK00`MRh0DY9E08>nT01`XVd0d_o80<C[]039l:l0aO:G0;KTS031
l:X0G91B0:?DT`3;l[40boo>08S:YP0;CRD0EHQ?04il?P0:>`@0GY1K0:CFX@32kJP0donf0;[h[`2/
fjL0CG5S07JMVP1FPhT0E7^20005001XM600c>^X0;gbV02glY@0a_>`0;kYXP3<mJH0b_6N0<[`W@3<
ij00c^VR0<cZX03>k:80dNbU0<oZX`3=jj420<oZX`3C0<cZX03>jZ00c>RN0<WXW03>kJ40cnnT0<k^
X`3>l:H0co6W0<_ZY03:jJ<0bnVS0<GPW@3<hJH0a>bS0;GCW`3omol0o_o[0?CajP3hoo/003`B00@h
2P3HoM40cMjd0=3U^P3bomX0gO[00<3TVP32iiT0c_BM0<;XT@31ii@0`N>G0<[YY@3boll0mOoD0<KT
YP39kZP0_n^F0;OSRP3Ali`0bNJB0<cVW@3;iJ@0do:i0<kW_`3noOl0ooko0?oko03ono@0oo[_0<fb
X@2ZSgX0ooSQ0?ogg`2bWXD0c<RR0<;XV`35jj00aNZW0<?WY`3:k;00kooC0=?Z]03?gZD0cmZN0:2V
IP1EFad0d^6V0=OZZP3Ek:@0e>nR0<?PT038j9<0b^bF0<CTT@3@kil0b^JK0=7YW`3eokX0Ce4@0<W4
S@3Wi[00c=ZU0<GPZ@39kk@0]>BX0<We^02ifZ40f?Jj0<GTX@39j:D0anBT0<gY[P3boml0k_oP0?Co
k03conP0m?oS0?GofP3gomd0oo_e0?ool@3^om`0l_oQ0>SnfP3`o^D0nokg0?omoP3ooOl0o_om0?oo
o`3iool0fOoo03aiL@3>n?H00`090?cgoP3hm_L0ookk0?oon03Df/h00``00??fi@3oooP0lo;h0?on
o`3onol0h=SF0?kgl@3on_00oood0?okm@3ooOl0noKm0?olo`3oo_l0o_of0?7ni03GjKl0dNBf0=;U
]`3Pl</0g>W=07j1NP35`l@0oogj0?ofk@3[h<`0RgmW0;nkV03Ui[h0jo?20<[OWP34giP0bn^O0<CT
V036hYP0bnFL0<?JU02W^gH0dNJQ0<gTWP3HkjT0eo2^0<SRX@3?hjh0f>Zj0<C@[03Zlm@0`LBa0?Wd
l03oo?d0o_Ce0?olo@3/h^40Q7aj0?onnP3dlnh0o?oj0>ogk03kooX0o?oh0>g`i`3ooo/0clW90?gc
lP060000ookc0?Sij@3konH0n?oS0<gR^@36j:/0a>N_0>konP3dool0n?oo0?Com`3eooL0mooo0?Go
o`3WoNH0foS<0<?[XP31hY/0g=bf09f>N@3om?00ooOf0?WonP020?ConP0_0?kon`3oo?l0ooko0?on
o`3oo_d0oocm0?oko@3ono/0ooGe0?ogmP2dZJL0n>k/0?olnP3Tool0Rk6l0<kZj`3[ood0XJRQ0?ko
n`3oo_l0oogo0?ono`3lool0nOoo0?ono`3hm?D0ooko0?ooo`3gnOH0noom0?_oo`3gnOP0oOgm040l
?@16@DD0h<g90<2]YP3Yg=@0nOSc0?kon`3gmoL0oo_o0?ojo@3Dblh0ookm0?gln03oood0403oool0
00X0oooo01<0IJ20045lJ01l^JX0SLK001mFD@0FAd4000l904YhM@2]gn00R[g003anO@0XOgH0EZJI
08?<^`2Kh<@0Zo;@0;?[a02nk<D0IgeF0080o`0007L0g^2^0=SZX03HlIh0b^:D0=G_Z03:hj40]<Z:
0:VmOP32eI<0fnbV096QFP39gXl0Z/ae0<S[V@36iYX0d>F/0=3Q]02^]Yh0N7a]00@5000_;Bh0IfEV
0?gmo`3lool0mooo0>Sjo03Zool0Qj^[0=ooo`3Rool0k_oo0?Soo`3onol0ooWg0?[Zd`34[i`04@00
08MgGP30]iH0e^>[0<OPWP2cgH/0doj^0<KaXP3>iY`0/IeX07UaC@3Onnl0TK^a06BGR02nj<00aNfi
07N]L`00>0T0Ikj[02j0JP2?aH/0cOF_0;?J[@2ml]@0/_c]03F9I@0BERL0AdlN0::AIP2]VEX0YIMJ
07mfE`1GBRX0o?W@0>;/^P37k:T0`^fV0<?^YP3<jJH0d^RW0=3YZ039j:@0X]B;0=3ob@1YUUl0/mjY
0;_S`00kICd0/N>V0;K//P1=Pf40]^o?00m;:@0[K4h002P:05VTO@2Xj;@0aN^P0<?TU@2_hZ00a?o:
07BiS00UID80CHQL0;gd/@2Zh:l0>GiY09KTeP1hdl@0L<2c000=100kE440e>R]0<[WT`32iH/0b^^T
0<c/X@3;j9H0eO:P0<SQT03=iY<0c>NF0<gXU`030<gZVP80cNZH05l0cNZF0<gYU03:ii<0cnbL0<g/
X02ogi<0_^2C0<GZW@39kJ<0aNVO0<c[Y`3<jJH0bN>R0=7YZ`3>hjP0fOnk0?7og03onOl0oooe0?Ok
oP3`oo/0_?K403ifB@35llh0n?oa0?Wmk`3oond0gNO50=SY/`39gIh0d^NR0<gRW@3=hJ@0c]nX0=;T
]03aomT0j_oG0<k]]037hjP0dnfV0<GTUP31kY<0^>V>0<7]XP38jZh0nOoV0?_okP3mn_l0o?[o0?on
o`3nlNT0oo_/06I><P2ZUW<0H5@Z0::IKP2UW7D0NGM70=7VU`3Bii`0e^BW0<oIY03IhK80emVa07Uj
D03AdId0j>V_0>;UX03Jij40`_6Y0;o^X033lIL0aO:E0<WeU035kH`0anb=0;gQQ`3BmYl0b>^I0<OV
VP3Mj[80CEhZ0?3oh`3Pon40gOod0=WomP06@RP0Ulji06^RS@3:ooL0fOol0?_om03koo<0noof0?So
m`020?coo`0M0?Sjo`3lo_l0o?oo0?gooP3oood0oocl0?kon`3eoo@0koo^0?Sol`3eoo80nOoo0?_o
o`3lool0oO[o0?cio`3`ool0d?oj05JLT@3Fool000@;069UKP3ol_`0o^Wb0>78cP2jYJX0ooSf0?_o
mP3jooT00P3lool0E03oo_P0o??Z0>CLd@2PUX`0X9R=0=oHcP3ooo/0lo?a0>KUjP2j^;d00@4002`h
900Y?1`0JGeJ02Tj601YNUX0L81S0>_gg`3Rj]80k?7A0<_?ZP2HVg00dMBW0=cU[P3Jj:X0`]R@0=Ce
WP33iXX0`^N:0=7eV`35hY80an6G072:@@2VaW40a^V?0<KZTP3>lYX0`NND0=3eZ036i:H0bnJa0>Gf
dP34dkH0o?oc0?koo@3knod0ooom0>g/jP3oooX0ooof08R<O@3Sj]P0dMo60?Ook@3Fi//0g>O90>oe
f`2f]ZX0oooj0>;KhP0?20l0oo_o0?Shn03jooX0n?oj0=[Wg@3Ml/T0fng70?Woo@3no_l0oogm0?on
n03omNl0oo_m0?oko`3ooOH0oooZ0=oc^03Wnk`0n_C@0:fMQP3on_<0oo[d0?comP80n?of00L0oooh
0?olnP3lood0n?oo0?Woo@3koo/0o_oj00<0oooj01h0/kB^0?kon03dmnh0e?oh09KBbP3Sool0l?oo
0:^m/@3cooL0o_oo0?oko`3on_l0oo_o0?omo@3oo_l0nOOj0?gno`3fn_/0nooo07AmNP0c?3/0;C4b
0?Kjn`3fmOX0oogo0:nMV@3on_<0oo[d0?[kmP3nood20?ono`040?oho03LbLd0ooom0?onnP@0ooko
3@3oool000X0oooo0180d??M06n5N@1`OgP000D0000?0@13MfX085mF04R>S010QW/0FYV409;I/@1X
bJH0]nkG0=kni`2ccjL0bO?30;gS/P2L^H/50?l0003I0=O[X`3<h9T0[l=n07R;B@39g9X0g_6_0;S<
Q`1aQT40fNnW0=S^YP2cbH40goF/0=3VWP3EiJH0fnRc0>gde@3oonl0`/>n08B2P`0b<3<000000002
001iP7T0Y[2X0?OooP3fool0looo0?Goo`3dn_X0o_oo0?oloP3oo_X0i^[A0=CD^P0D4@00Q85H0;Jh
Q`3Di:H0cnFT0;OGU03=k;00a^6/0<cT/03AhZh0IFm<0:W@_P0cJeh0>Wic0563NP19MfX0<ViB04F<
JP2^jL/0[^K;04N8JP2=aZD0AG=I04ikIP1IRWL0I91_06nBJ03Ehjh0fN6X0;g4OP3Oj:D0gnFi09ND
J@1TEb/0GeDT09BLH03KkZ`0a^BL0<ohZ@2miYL0cOJW0<7VV03:jZ40a>R[07RWN`2omM<01D<^062P
R01:REh04dlL000F002hij<0]^>P08>bN`2nlKP0/^:V0<_e]@36i9X0bnNJ0<GZW@3>n:`0^NNN07f[
H`1VU5<0Gi=U049hEP0lNEP0/O7<0;3Z^030lL@000/0059_F@0KCA`0QlIo0<7o[@31jiT0b>nN0<S^
V`2ni940a^NF0<cTT032gXX0c>VG0<?TU@3BlZH0b>^K0<KYU`3;kIL0b^^@0=GdUP37j8d0b^^L0<[[
Y03>l:H0`N>I0<SZX031hYd0cnjZ0<CQX@3>jZl0bnN/0<oY[03KmJh0g_k<0?Goj03omNh0oooj0>go
o@3Woo@0/^Vo05ZKQ`1j]K40kOoo0?Ooo`3honh0iO[C0<3TW032jIP0bNnJ0<OZVP3=k:T0bnN]0<OS
/`3>k;H0a>FN0<SXW`3:jJD0b^VV0<OYW`36k9D0`^V@0<KTWP3:hJd0mog_0?oon`3oo_l0nOgn0?Om
n`3ooo@0oogZ0<ZmT02TXVL0`mF;0=cbZP3>ej00^/:902dg002DVEL0Z:5c09b@JP1kK4d0I5Hi0<_2
X@3GgZX0d>2Q0<_ZVP35kIL0_?:N0;g^U@37k8`0b^f90<oZR@34g8@0bn>?0<?TU@2oiYL0^NRH0:_;
P01VER<0f]^a0=?oh@3BooL0>H]d000^6P25^J`0lOoo0=Wen02Gi^<0cOoo0?WhoP3no_l0lo?k0?co
o`020?Woo`80mooo0P3eool0K`3iool0m_;c0?WonP3eoo40nOoa0?kgk@3oo_X0mooo0?Coo`3gool0
oo[o0?oko`3fooh0m?oo06B@S`23^kP0010>00052@0=0080600500h00P070000100008B5P01aLVd0
oooo0?gmo@3nooH0oocj0?oio03omOh0ooWo0;2TY03gnN`0NWi`06]ZJ02m][d0ooWo0?ool`3joo@0
m?Wc0?_oo`3ioo/0nOoc0<WJ[P33eYl0Zkn008>GF03>hZD0cN:Q0=G/Y03@k9l0b>RE0<KZTP3:kY@0
b>bD0=;bW`3@iil0bMjK0=;WY03>kJ40aNRH0<c_W`37jYX0bNVN0<OUW`3=hJ`0cMba0?[oj02d]JL0
nOGb0?ono`3knod0ooom0?oonP3ooo<0ooo^07MjG@2SZHL0e=nd0=WV^03Chk80f^6]0<g@X@2<RgH0
noSa0?olo`0100L0oO_l0?ooo@3ooo/0o_om0?gno`3looH0o?od0?koo`3oool0ooko0?ooo@3oo_d0
oogo0?gho03oo_l0o__f0?ooiP3oo]l0j=W4081`H@3oo?H0oocj0?oon`020?con`80ooom01d0no[o
0?koo`3^knX0oooj0?oon03oo_P0ookk0?ono@2e/K00oOkh0?oomP2^iK/0L[B@0<SXm`3knol0IX5b
0>Kom`2__Kd0ACa103/_<`1lLWX0NWYh0?OemP3oo_l0oooo0>KXi`000@00/;Fa0>KZj@020?ooo@0=
0?oln`3on_/0c;Zf0?ofl@3oo_X0o_oo0?ooo`3on_d0ookm0?oan03O_<80nOkj0?ooo`060?ono`/0
oooo000:0?ooo`0B06V4H`1fQ540HV/b0=GHX`3Dg;D0^]nn0:gO^P2mnlP0[>^U0<?l]@2_j[80=iI/
0<;Zd03Kj<h0WjQm061kA0005@00PYAP1P3o00006`3ChYl0/L9n0=3QW@3:gYT0bmnJ0<CKU@3CjZ@0
c>JO0<CKU@3<hIh0bmnH0;34O037f9@0e>:W0=cT_`3`mMh0oooj0?Ofm03[inP0ooko0?oon`0M7QT0
00400000002YZ:d0n_Wn0?ono`020?ooo`3e0?ono`3fm_H0hnOX0=_JeP040000DD/e03hj7`1KHch0
0a80000:00003`0000H000<7003ZdZH0k<FT06AC>@2<Rfl0_LN/0>cQc@3Ba:X0f]b[0:^gN@3=`g`0
h=VE05n0B@1FLT40enO20:B_S`0b=Qd0`;f/0:fZV`0400000`40000200001000FfE<075aE`3Ib:h0
lmk1065H;@3>did0koo10=7eZ`3AnZ`0aNbM0<g`WP3Alil0d_R[09S<RP2:a8T0MK>00;7__P30l[l0
`>^e0<;UZ`3:gih0amVK0=;V]@37fjX0amVY0=7S/@37fZ<0`=>K0<gWZP3Bl;00bn^Z0;SMV03<m:h0
b?:`0<;dZ`2MdX@0^>^P0<GTZ@3QmlT02QP106^0K`2okmT0@H1S086jS`3Ejj00dnVN0=C/XP3<i9X0
b^BK0<G[XP31jJ/0/=RT0>Cok@1AOF@0HXmh0<CbeP2di;h0a_Jj0<7c[02_hI`0/N6g0>;ok@3SonP0
l?oO0>koeP3Ck:/0bNFK0<;TSP31j8l0^^F90<ofW@36g9@0gN[<0=CFb03onOP0ooWo0?oonP3noo<0
l_oa0<SekP0`IfX0e_ko0?Goo`3ooo40oooW0>[]_P3Sj;80eMnR0>7_/@3=h:00fNj]0?;oa03DkZD0
bn^H0<SYV037j9T0b>ZN0<W[WP3;k9/0c>^M0<gPZ03hom`0n_gb0?glnP3on_h0n?kn0?Ooo`3`m^X0
j>7>0<o9U`3SjZL0b^jG0;kUTP3Gl:l0d^:T0=SQX03Nhj/0dl^V0?olh03om]l0ooSR0?ooiP3?g;00
cNB/0;cUV@39kJ<0dN2W0=CR[`3Ah;D0d=nd0<kP/03?hJL0a]FJ0>cd``3Vj/L0/JnS0=CIa@3BkkL0
JX=I08ZdWP2JcK`0g?oo0?7oo`3jnol0no?o0>?io`13YJH09Xn;04V2O00gL6X0AX=n03YhL`29c<D0
bOoo0<_oo`1`^k@0;WUd00YGD@1i];80o_oo0?Wmo03oooH0o_[_0?oimP3onod0n?oo0?Goo`3hool0
oocm0?oln`3koo/0ooco0=KenP1>PH80AX=n000;303ok?@0onke0?[`k`3oo_l0l_3a0?kmn`3in?H0
ooom07EdLP000`00:B<U079RK00>00D0?Rdc07Q^K03Qjm80n?oX0?_ol@3oooH0m>o/0?cok@3coO80
m_on0?Slo`3Zk^l0i^cN0<gGX`36dHl0GFTQ09BOF`3?fYh0dNRR0<OWW038j9d00P3:k9l09`38jYd0
bNVN0<WTW@3Cj:D0e^VY0=;UX`3;iiX0bNZI0<c]WP3:jYl0bnFT0<oW[@3ion40o?oX0?oom03fk^/0
h=OJ0<_:b03ooo/0m_O_0?oom03fn>80i>O:09JMM02:TfH0nooA0??ob@3hold0fN:O0=kRY@1nOf00
moGX0?cjo`060`X0oOcj0?oon`3oood0ooko0?omo`040?ooo`80ooko00`0n?Ce0?ono`3oo_l0ooko
0?_gn03ono<0E40e0<bk/@3oo?@0oogj0?onn`3oool30?koo`0L0?koo@3ooOl0lNke0?onn`3oooH0
ookf0=SAb`3IdLl0n_Ch0:NSY03oooX0o?ka0;CW[P2Xk;/0S[c<0?kno`001`00Mi>50>ojoP3ooOh0
ooco0?kgo`3noo/0>3Le06IRH`0k>c/0oooo0?koo`80o_om0100o?_g0?oon`3oo_/0ooSf0=;3`03o
n?@0ooom0?_oo`3jnOh0oo_o0?onn`3ok?@0WG1g0?_oo@3dl_D0oogo1@3oo_l;0?ooo`002P3oool0
4`37iK40a=VD0>?cZ03Pij@0b=6J0=Ka_P33iZ`0_^bS0;KXT`2jiiH0^o2h05^cR`3CnN80a]:j00L@
00003P00`MVO0<cOY`23U5h01@3o0000iP21T4d0bmbH0=_/Z03FjZD0e>VT0>Ko^@3?jJ80fO>/0=?]
YP3:hI/0`=R>09J/H`3NlZd0dn>U0>Oac01BF3h0oooj0?Kel`3oo_l0n_Ke0?WhmP3oo_l0i^KV0000
10081`d0d<oE0?ono`3fmoT0oOgo0001001^L6l010<800T51P0I4@h07A4100L1000@5P00c]Zf0=SY
a`36e[T000L000<3000H0000>a<00>;9ZP1REC<0CTXW06E>;P1eFcP0?S<0065Q6`1>?000LF0H0>;[
/P1ZLCd0G5Xc05A?;`1FC3<02P00075TG00A2@H00`0005iNG0093PP000@000T9000>0000O6MD06EK
>03PhKD0b]BP0<_XYP2mg9P0do6Y0<3NU02lhI40_NJH0<Sh[P2mlJT0__:`0<Kf^02deil0c^^e0<cP
[@3>eZD0LWQ<065[B002300000L00>;/a`3Lj<00dn:g0<kT]@2ofJT0_]bZ0<?V/02lh:<0]]^=0<?`
U@31li80boVQ0<KNZP3@g[X0FF5<000<002ih<h0Nk2P04emH`2ndHl0ambI0<WOWP3@jJL0`^6N0;GS
X`2fi[@0aoOA0=ComP1AQ7d05DU507ng[P2VgLX0^oC90:KQZ`2bk[P0M[FJ04MlJP3Roo/0l?o]0?;o
h`3Bh[40cN2X0=CdZ`32ji`0_>jI0;K/V035k:T0/lj]0<gRc`3jn?/0oo_o0?ojn@3ono80k?SZ0>Wo
o`1GRHP0fOoo0>_oo03ko>h0ooo]0?7ZcP3Sg[h0c=>W0=SV/@37gI`0e>^U0?;o^@3HlIh0bnRH0<SY
V037j9L0anZJ0<S[V`35hiT0c>NT0<gM[P3lon@0oOob0?oonP3oo?l0m_cl0?Ooo`3ennl0kNKC0=7>
V`3Igil0`nVD0<K`WP3<ij@0ambK0>7_/@33cY@0gn6j0?ooh`3oonH0oooZ0?ooj03Ah;D0dnZf0<KV
X`3;j:H0fN:]0=WS/@3>gk<0b^2b0<WQ/@3Il;P0dnR`0?One03oonH0XIB>0=oVeP1c/7D001400;oP
c@3Poo@0lOoo0?oko`3omol0oo_o0>Coo`0TPhD0D;:a0<GonP3Eool0d_oo0=3oo`0aNFh0?8Ej02]h
KP0TM6T0L/:g08SId01j^kL0nOoo0??ho03oo_/0oocj0?ohn03oo?l0o?oo0P3kool03@3oo_/0oooj
0?Onm`3ooOl0j_oo08Bg^02mn_D000P90?o`m`2ZSiH0oogk0?Sdm@3oo_l0103oood0@P3fno@0mo7c
0?oko`1TEE`0o?3`0?oom03honH0lOoO0?Soj03do^H0oooa0?SojP3eoo40n?ok0?Smo`3jooT0o_oa
0=oS/@3OhjH0B4T70:FSIP3Yk;<0cnBQ0<c[Y@3>kJL0cNjY0<KWXP33i9l0b>FR0<kYYP3?i:<0cn:P
0=CXX@3<jIL0aNNC0<CUU039jIh0bN>V0<kU[`3_oMX0n_oZ0?oon03nnOH0o_Sh0;jm^@3al^X0oood
0?ool@3]l=D0embl09^TN@2AWFd0nOoA0<KLW03@iZD0f^FP0<[@T03LgK/0m_OU0?_inP010080oOcj
0?oon`3oood0ooko0?omo`@0oooo0P3oo_l00`3hl_80mNo_0?omn`020?omn`070;JUWP2aX9H0oocd
0?CYh`3oo_/0m_Gc0?ooo`030?koo`0_0?koo@3knOh0noWn0?Scl03lmNd0KFIN0<o8`P2_YjD0b<;6
0?ono`3/kND0o_od0<Of_`2cmLD0S<CA07n8T@1aOG<0jo_a0?Wno`3oo_l0o?Kh0?oko`3emo80nOSf
0?ono`3hn?P0no_k0?;dl`3moo`0l?;_0?oon`3lnoL0ookk0?ojn03<_KX0m>_V0?_kn@3kool0o_oo
0?odn03oo_/0onO_0;F8S`3kood0o?[m0?ono`3oool00P3oo_l=0?ooo`002P3oool05@3:j900hO^d
0=CZZP1BH280RiM?09VRB@3DgH80f>B>0<oUVP3<jZ00^N^`00M>;P2ngLd07RXD06YgB`3<iJ`0`mFI
0=[XZ`2fc8`0a^FO0=[h/0020?l0000C0:bgM@2NZVP0cMjJ0=O[YP38giT0bN>L0<kYXP3CkZL0c>NP
0<7OU`38iY`0]MB40<WVUP3CjZ80d>BU0>7]a`3ionD0clo70>o[j0020?Wdl@030?oio03ooOl0ooco
0080oogo01@0k>_`0>g^l01JGe/0LWUb0?Cll@3hoo<0ooo_0?Kdg@0>2000ZZ1l0=WEZ03JhZT0eN>V
0<KLWP3Jkk@0`]>M0=?U/@3@j[d0fNS1004A008000/00?l000L004A9:@1[OEL0Uk:906YlE01RJTD0
CSlX04`m:00A0P00404006iRC03oonH0oooT0<K@Z`3Ij/00bN>d0?;oj03]m?X0o_oo0?ofm03lkNH0
:1d700L2000<3P00?dPI09BPKP3>f:@0cMjZ0<c]^03;k;<0`n6S0<7NW03?i:<0DF4S00<60019AR<0
20400>[Ic`3omnh0oo_X0>[UdP3dlMh0dm2m06U[EP0d=b8000T0000700002000QIb00<OM^@33eY@0
d^jG0<3VP`32i8h0hO370>oaf@1iN5X000H009fhV@22Z9<07TH^08V]O`1VSEh0GHUH04MiAP1k]X00
;fLj039/A0005P002DT_07BcX013QWD0LKJT00U>>`1X[Y80D9Yi07K3X`22e;d0EIb:05B>O`3<jn<0
goC_0?Soo`3gool0jOoo0>Koo`2Sd<T0Bhad00AD8@1;U5l003PA0;[akP3Zool0ookm0?omo`3_ool0
j?om0=Goo@0bOgT0T[^]0?WonP3koOP0oook0?conP3Ko=l0eooI0<Ce]032jZ40d>>B0=3RUP3<iJ@0
anJP0<OWV`38j9D0anJJ0=W`_03Sll`0hn[J0?oom03moO40ooof0?ooo@3hoo/0m?oi0?cok`3/j<d0
VYMT0=KOX030jYH0`>fH0<g_X`3:iIh0bnJO0<[UXP3Aj;80_mFV0=;W_03DjL80kOoK0?Gog@3]om80
hOVo0<[WY`33jY/0`NVA0<?`R@36lh`0a_:@0=Gn/03=lZl0d>jl07nKJP2of:40Ojme02ElC`34k=40
bMG90=gYg`3oooX0ooKj0?oan@3kool0S[Zi0;cho`3Cool0logo0?Soo`3]n?X0mOoo0?;oo`3_ool0
k_oo0>Woo`3]ool0h?co06n>T`1NPY00hO?o0?K^n@3oo?l0oooo0?koo`3oo?l0oo_o0?omo`3kooP0
n?of0?con`3nnOd0j_oo0=Goo`1k^;<0aN7R0?o[lP3ojNl0ookk0?ono`3alO40ooom0?glnP3kn_P0
Y:>Q0<k@b`3/jnT0o?Sg0?oomP3^lMh0nooX0<cW]037i:`0c^^a0<KQZP3JkKl0cN>d0=3Q`@3honl0
kO?U0?ool@3oonP0hmf]0=kEWP3RdiX0XI1L0>CJY`3BhZ40b>NT0<GSX`35hjL0goc40>god`3YolT0
cnN[0=7VX@3IkJD0ZKm]0<?PQ03;jI40`^:?0<k/Y03=iK40fo370?Sok`3koo@0ooom0?ono`2_ZjX0
oooc0?OliP3@e[`0X:N80;S0V`1/Mdd0W:ak0=3S[03Ekk0000X0c>VW0<[YY@3<g9<0e^6L0;>iS@3i
o=d0ooof0040003mo?X0ooom0P3oo_l04P3ooOl0o_oo0?koo`3nool0ooko0?ono@3oo_/0oO?a0?oj
mP30/jd0/:6L085bK@37^[@0ooch0?ojm`3oo_/0m_Kf0?Gfn0<0o_oo01d0o_om0?ooo@3jmOT0dlkB
0?Kak@3oo_H0oo_f0?ohmP3oo?d0oogo0?ono`3loo@0nOg^0=_ia`18PE@0X>od000F6P3jnO@0o?Se
0?ogo`3no?d0m_Ce0?olo`3bm>l0ooom0?omoP3oool0j>SX0??em0020?koo@0@0?_jmP3ooo/0h]gJ
0=?9a`3oo?P0ookh0?Kkm`3gool0moco0?ojo@3ooo/0k;g50>Vl``3hoOT0oogo0?ooo`D0o_oo2`3o
ool000X0oooo01T0amn70=3X[P2mdjD0_/jM0<[ET`2QYT`0jNbC0>GXV@3@i:D0b>F[0;S/^`11PFH0
_]W:00TE002GYgP0b>6W0=o]/02Z]WP0an2L0<[_XP36jIT0gnfR0:NbKP2FXEl0/[il0080o`000=<0
e_2Y0<gXX@3GmJd0a^BL0<[XX03HmZ`0cnnS0=WjZ@3ClZ80eo6X0=S/[@3Xm<h0o_oZ0<W9`@3Dd<d0
oo[h0?omn`3onol0ooOk0?olo`3gl_H0ooko0?ooo@3noo/0noof0?Wom03eonh0m_oZ0?ooh`3fmmD0
1P@006eY>@2<ReD0h>fX0=7UW@3HljH0an6G0=[aZ@3>jJH0_NFc0>OofP0gDRT0FG=<02@l6P001`00
0`/00006000A:b8000P5000=2P0300000`4008>2L01jNF@0j^g@0?;md`3aom40eOBa0<3TVP2hiI80
c?>d0?Woo`3_lo@0ookh0?onl`0c:a@0K6M:06MT@`031@00;S080;FgT03EgKP0a]jn0=;Xa02JZX<0
IW=8065W>`041@00=RlB07=XDP22MFD0V8J20:jOV02^[9D0Ph5Z09VGP02ASgX0CD`g07EgHP1`MEl0
>D4Z00hG0P0e@B/0FF=:06agC02I[G00d?2T0=7^Z`3aom/0oooX08Z7IP011P00VkF50;WL/P2C_ID0
=F8k01A26`0FBb405e0U05NFJ@0kL4H0XMVZ00i85P006`00KZmg000f000nQ58001d0072fTP0aN5P0
Z^cA03UaF02:`:H0:61708c6[P2BbkP0S;nf0:WGe03Jo?l0j_oo08fS^P27WjT0AgAE0:34U00B=A@0
fOoo0?7oo`3hn?X0nOoo0>?oo`3Pool0aOoe00MGEP1iUY80oo_o0?ofo@3kjoD0oogo0>Wok`3UonT0
c_?00<gT[P3UfjH0h=ZX0=OW^039iJP0a^BN0<WUVP3>ij<0kOgH0?3liP3hn_L0ooom0?oomP3ooo@0
o_of0?;ok`3]onX0nOoT0>;O_02SX6/0eMjM0;WSS`36lih0bNjN0<?TU@34iIH0cNnR0=;e/@36j:/0
`^>Z0<c]^03KnLD0ioo90=of_P3OlkP0b>JP0;K_SP2gkHd0a_6H0<W_V036j9@0`^:F0:S:P02jhZ<0
V<F:0<Kka@1PX6h0]okN0=GYg@3io?<0j?CX0?Kom@3omo40ooWj0>cooP2NdL`0c>_m0?Coo`3onol0
o?Om0080ooko0600o?oo0?Gho`3iool0mOco0?Gno`3gool0WKJm04=mR@3Wool0o_ko0?ono`3bo?d0
n?oo0?olo`3on_l0oo_o0?WomP3gooH0loG`0?olo`3Zool0dOoo07:]Z@15HF80ooSo0>cCf@3km_<0
ooko0?ooo`3_jnP0ookk0?7]jP3?blP0ooom0?7bk@3ko?H0o?oa0?Soi`3Fj<80_mbR0<;RX@39jZD0
cnjZ0<OOX@3Qlkl0a]B`0?_oj03innH0oooZ0>k[c03Yhk<0f]6J0?7RZ`3@_h/0hmbV0=;VX@38iJ80
b>FU0<kZ[`3/om@0m?oJ0>gocP3AjJd0e>ZR0=CYW01kTSX0[<MZ0=7]UP38iID0d>^V0<gS]03Tn=<0
n?oc0?WomP3lo?`0ooko0=?BcP2Z[iT0]KjO0;[4XP2OZHH0hnk40=7N/03:g:P0g?6h0<_XZ03<k:T0
_n>M0<cQUP3Ok:H0Y:ak0<W?Z`3ooo000@400?oknP3oood20?ono`0B0?kno`3nool0o?oo0?koo`3o
o_l0ookm0?onn`3ooOP0]:NQ07m`J@2iZ:00a[F]0?oln03onOH0oogm0?GdlP3oool0o_oo0P3lool0
803nool0ooom0?oon`3ooOl0[:JX0?onn03hknP0oo[e0?olnP3oo?d0oogo0>_YjP3nooH0l?CS0?Co
g01UV6d0/Ooo00092`3oo_X0oo[i0?oio`3oo_l0oooo0?olo`3cmO00no[h0?kjn`3clo<0oooo0?ko
o`3dm_<0n?[g0P3ooo/03P3FdLh0gM?A0?oim03oo?H0mO_g0?Ooo`3hoOl0ooKi0?oon`3L[KD0_i:I
0?coo@3ooOl0oooo103lood00`3nood0oooo0?ooo`090?ooo`002P3oool04@38dIP0[Kn504II8@2o
dJ40f>Fg09NMG`3LiYd0f>ND0<kdZ`2bhj/0Ql>Z03e`H@0U>2D0;c`P0<OKYP3CjJ/0fn6Q0080o`00
00D0`o2M0<GaVP3HjIT0/[eh0=gYY`040?l0000T0=7_Y`2lfY80e>nX0<;MUP3FlZP0bn^O0;gLS038
iiL0b>:K0<oSYP3[mM<0oOo/0?CajP3Dcl/0o?;`0?omn03om?80oocj0>gSh@3jm^d0ooga0?ook`3l
on`0nOoT0?Kog`3Ej;X0cn:e0<oJ^03TjlT00@D0059E:P2KXG40cn>V0<_UY038kZ<0bNfS0P37jId0
Z`33k:00a^ZP0<oVXP3Chj@0en6U0?ooe`3nomh0noo/0?Sol`3cooh0l?oe0=_j`@3<jJl0bNFZ0<gY
[03:j:P0b>VT0<S/Y030jYh0_NVJ0<WhZ03FoK`0nOo_0?Wok03lonH0iNc:0=oQ^P2SXG/0DDdX0?7/
c034_j40RhM/06UWD0010P001PD007idJ02=P7L0n>OM0?olk`2QUX80NgAJ08>0H@2l`IT0fn:f0<kO
Z`3?gJX0m_oB0?[oe02c^Y00KgA<0:NTP@3YiL80h=^k0>WP`@34_J40LGAQ04UE?`1EKU00d>_80<cN
^03JhL00RXYb00440031fJD0c_>^0<3YY@35i[L0bNZk0<[__02gg:T0_>:_0<K//`31j:T0bO:/0<Gb
W`30kIP0^nbJ0<Sk[P2olJ`0bO[;0:[L]P1n]IP0N;NH0:g_b`1MVg@0`_O=0;?R]P2ojK/0bO310;;H
Y`1jXVh0QZij0<cka@2ekK00`^FU05QhB@30lNd0iooo0>3oo`3Oool0?GN505AgN`2M^/00gooo0>ko
o`3Ed]/0o>km0?oeo`3olo`0nooa0?Sol@3/o^H0nooc0?k_lP3oo?/0m_kc0>;fd`3=h;<0cn6]0>7`
a@3looH0n__o0?omo`3ln_l0oooh0?ook`3domh0eNc00<CP[`3;fZ<0i>B^0<o;SP3Mi:40`nZI0<Od
W`3<l9T0a>J?0<C[SP34kHl0`NnE0;k_UP2nkYP0_^^J0<SaXP33hiX0eo6Z0=kb[@39giH0co6J0=_f
Y`3>fYX0]kn409:EG02d_840f^R[0<KU[02oik<044LM0;7Xb03^ool0ooWo0?olnP3kooH0joof0?;n
lP3eoo/0f?oo08O;`03no?l0ongo0?ooo@020?ooo`040?koo`3lool0o?oo0?_oo`80nOoo01P0n?oo
0>Koo`0aS940d?oo0>_oo`3Vnoh0jOoo0>goo`3ooOl0ooOo0?k_mP3eno40mOoc0?konP3oo?l0go[o
08>e]P1n^KD000P90?oio`3:/kT0oOWf0?ooo`3nood20?oln0140<S3_`3Sg]X0oook0?kom03doNP0
hoG?0=O]_`3Jlk`0b>:Q0<gXX`39iIP0cnbJ0=?YWP3Ffj40k>^o0?oog03Gdk00[JV307YgC02ZZ7D0
[Jad092?EP26QD`0M7dn0<_SU`3@kj<0b>JN0=oi^P3/old0mooF0<OJXP3>hZD0dnRM0<WOS@2DZe<0
UJeI0<kTV@3DjjD0d>JX0>7fb`3Jk//0n?oc0?7lkP3looX0o_ok0?kom03co]`0l?oC0=CT]@3<g:d0
ioS40??ocP3Cjk40a^2S0=;`/037jZP0`NBR0<KMU`3RmZl0bmRP09RQM03_lMT00`400?ono@3el?@0
ooko0?gmo`3oool20?coo`0?0?koo`3oo_l0ookk0?onnP3_i=h0KV5K06eNE`3Ib<00ooS^0?olnP3o
n_P0n?Cc0?klo@3in_h0o_oo00<0o?oo01X0ooom0?oon`3lm_H0oocm0<c3_P3ooOH0ooWd0?_al03o
o?l0oogo0?ooo`3loo@0mOgX0=SU]`2oiKh0=hZ>05MkN`3looX0oogj0?oho`3oo?d0no_k0?kko`3o
oo/0ooom0?ono`80oooo01P0o_oo0?koo@3nood0n?Oc0?[im@3Hdm00oocj0?okm`3oo_P0noom0?;n
oP3hoOl0oogo0?konP3ofn80fk2g0?Won`3oo_l0n_ck0?_oo@3lood0m__g0?[on`3lo_/;0?ooo`00
2P3oool0403VkKL0FfT[0>Wl_03LkkP0ho?40;70Q`3@i9l0d^jJ0;c/X02lm[T0?G]T08B_WP001`00
G6Y90<WQY`39gih40?l000040<7bV@3DiID0gNZT0=SWY0@0o`0006/0QZAL08^YH@2?ZV<0e_2Y0<SR
V@2mfHh0i_nc0::nL@2[`Wh0aMNM0?KmgP3]l=d0oooj0>oWi@33^KL0oogh0?oln02j[j/0/ZVR0<>o
/`3Og/`0oooZ0>G_c@37ejX0c^2^0<kSZP39gZH0amFa0=KP^`001P00N7iB0;BlS@3=hZT0anFU0<;Z
X@33k:00aNbM0<S]W`35k9d0`nfK0<gXV@3Di9T0f>:K0=KRX03DhZD0e>2b0=CN^@3<hL80b>Fi0<_b
X@33j9P0anZJ0<_^WP3:k9l0a^RL0<W[W`36jZ80`nNQ0<W^Z@3Al;D0m_oQ0??og@3Jjkh0d^:c0=OQ
[`3?dZ<0iNBh06QT?`2HTgD0_;^O0>7Pa02JUGP0SHE^0;Z/W`2cXYX0UhAm089aI`2ET7<0[k280<kF
X`3Dj:<0eN^S0<kWY@3AijL0eNVZ0=W[[`3<eil0/KZ50:BSL`1kMdP0_[N;0?[/a@3?aJ40gn7908jG
QP002P007CXN0=CX``3Gh/80Rh]o0002002EZX<0]MNJ0<_`ZP35i:P0b^V]0=;`/P020<_YZ`1S0<?P
X037i:40c>ZT0<k/XP3=kJ80`>6J0<ob/03:k;00f_kB0=3dcP36lmH0R<N/05ZKO@3?onL0/=Zb0<W]
_`2nfj40d>j^0<gcYP30jiT0`O6K0;C[U`2fkZD0b^RX0<CR/01CPWP0OjZQ0=Soo`2lool0>XNA062@
U03Jnol0PjBe04mcL`3>h>80V9^T0?cXm03on?l0oooc0?ook`3foo80m_ol0>oeo`3iool0mooo0>om
iP3VlmD0lOgG0>[ceP3noo/0ooko0?omo`3oo_l0o_of0?kok03OlKl0cNZb0<SXZ@3?gih0gMfQ0;6[
K`3Gg9`0`^NJ0;kWV03;kIT0b^ZE0<O^T@38lI<0a?6D0<7`TP31l9@0_n^B0<C^V032hI<0e_2V0=W]
YP3Cij00a]ZC0:FfLP2LYVT0T9QM0=oV/03Tl;h0bm^/0=Odb01cUV`0GheX0=Coh`3hool0ooKo0?oj
nP3nooH0k_oh0?GonP3aood0C8Ym029ZGP3ooOl0ooOo0080ooom0P3oool0103nool0o?oo0?_oo`3k
ool20?Woo`1M0>Ooo`0POh<0bOoo0>Koo`3Yool0i?oo0>3oo`3amOh0ooco0?ofoP3looX0nOoh0?oo
n`3on?d0jooo0932``33o_X000P90?oio`3liN/0ookk0?koo`3alo00ookj0?ghm03Sg]X0j>?O0?oo
m`3cnnH0j_OI0=C/_03Ck;D0d>V_0<[PW`3Nlk00dnRM0=3UUP2/_Fl0Nga203<]002GTf@0NgQ=05QG
:@3Pgjl0hNJ^0>C//03IhjH0f>BV0=GVXP3AkY`0cnjN0<CRV03>jJH0cN:Y0=GZ/P3Hjk<0cMnS0=[^
YP3Cj9/0YK]Y08ZOE03Bij@0dnNX0=7T[03fomh0k_oM0=GUb`3?g<P0noof0>W_i@3loo40nOoO0>Gi
a03>h:`0cn:[0=7R[03Ej;00mOoA0>Ooa031gj40`n>T0<7TY03AjZP0a]^H0=[Y/01UKSl0f=_002HT
5@3ooOd0oogo0?ono`3hn?P0n_ci0080o?oo00l0o_oo0?ono`3oo_d0ookk0?W`j`3ol^`0mNKO0:fL
U028Mfl0[jBP0?omnP3ooOd0ooom0?ooo`3ko?l00P3lool05P3nool0ooom0?oon`3oo_/0oogk0?3W
h03kl^T0kNCO0?omn`3onoh0oO_n0?gmn`3an>P0i>kF0<cHZP3Pom/003a40<_]kP3dooX0mokg0?k`
o@3oo?l20?ono`030?oon`3oo_d0ooko0080oooo00<0o_oo0?koo@3lo_/00P3ooo/03`3@blP0o?;`
0?ogl`3oo_P0moch0?Ooo`3jool0oogo0?_lm`3og><0g[Fk0??nn03oool0o?km0?_oo@020?coo@80
o_om2`3oool000X0oooo0100eMnJ0:VdK`3Ah9/0e>JX08JJG`3El[00^mfC0;oZVP2XhYP0[>f]04j:
IP1mX8X04Ah40<KE[P38hZ<0c>>M103o00001@2mkiP0o`000?l0003<gIT0h?B_0080o`000=<0bn^R
0<;RV@3;iYl0O9I?0=S_Z@3BjJ40cnVO0;OBQ@2@Z5`0QiYJ0;c:U@3ion<0n_g/0?onn`3oo?d0a[bj
0?kel03oo?H0[jBN0?oll`3im^D0f]W40?[og`3Ym<`0dnB^0=7UZP3CjZH0e^b/0=CT]@3Hi;@000P0
05eT<@2HXF`0cNJU0<WXXP30ji/0`>bG0<O_U`37kY/0`NfR0;c_X036ji/0cNRG0=?VU@3<j9@0bNVD
0<kVW03?i9l0aNVS0<;[W@36jh`0a^V;0<[[T03<kI@0cN^E0<WTU@3=iid0dNNV0<kTY03<hJP0cn6]
0?_og03eomL0`MZP0<WSYP3DiZP0f>>Y0=SMY`3Lfjl0emNa02/_3P1_LD`0FU@T06MN=@1PDSP0F4Tf
0=oB`P3on><0j_320=kY[@3Jkj@0a>N30<?WQ@3=kYl0c^fQ0<7MTP35giH0en^V0>?b[`3Gfj00WIaS
0:BOJ03YgJT0iM^X0>[/a03=f;X0FW=M000I001MLdl0e^?90=SEg01/JWD000H00=7]a033ijX0cO:R
0<CYV@2kgXh0a>FD0<g/W03DjZ80eNRX0<kPY03;fjX0bmR]0<OE/@3aomd0n?oV0?Goj03Mlll0eO?G
04inL035mn/0h?om0<cad02kfk80e?2e0<k[Z032iI40cOBI0;_TQ02njHd0an^S0=k]]P39f:d0fOod
000@102Nk^<0Y_om01Z1OP1^^kD0UM?>01A<B`19RGT0EHAj09jl^P3Zinh0ooOi0?oik03fkm`0n?od
0?3oo`3Rool0i?oo0?Goo`3loo@0koKT0?gok03ooo40mOGc0?ooo`3gm_/0o_om0?Kmk@3konP0bn>U
0<KVX`38k:80dnBM0=cMV`2VWFH0fMRP0<SWY036jZ@0cn^P0<kYW037ji@0b^jF0<C/T`32jY40`^^?
0<O_UP36k9D0`n:D0<oYW`36fiH0d^BV08BBH@2BXf`0aMjJ0<WVX`38iZP0g_oD0>_ok02`d[X0848W
0<SZa@3Mnml0nooo0?ogo`3on_X0ooof0?OonP3amoD0l_oo04V;P@1PZYd0n?oo0?g`nP3ooO/0oocm
0080oogm00<0oogo0?ono`3oo_l00`3oo_l05`3^ool0;XR90<coo`3Jool0f_ol08:ZXP33iN@0j_Om
0?_oo`3oo_l0m__g0>[_j03ooo/0ooOm0>goo`2EaLL0S/W5000J6`3omO/0jM;H0?chm@3nool0o_om
00<0ookj04<0o_We0?onl@3Oj<d0f^[50;gHX@3=ijX0`m^M0<kNX03Afih0h>ZU0<[ER@1>EP/0RhU>
0?3X]`2g/Gl0IFDa092CGP3JhZT0dMfO0<oOX037gYX0bn:L0<cXW@3>l9X0cNfJ0<SWV`3:iIh0aM^M
0<kRY`36ej00hO2e0<OJV03Cij80EFTR09JXK03Ci:d0dNB]0=_]^`3gomd0mOoO0<[K^`3<fkh0nOo_
0?7ji`3kon`0kooB0=?[[`3>hjP0eNZa0<[MY@3?hZX0k?o80>Ooa@36hZL0cN^_0=3^/P3Ajj`0`m^M
0=;S[02BWV`0T9=f00<2003_jN/0n_Gk0?ono`3no_h0o_ok00<0o_oo00d0ooko0?ono@3oo_/0oocj
0?oln03omo40oo_f0?oim01MD4X0clC00?WakP3hlo00no_k00@0o_oo01X0o_om0?ooo@3ooO/0no7_
0?ofk`3ooO@0g]G@0=S@cP3oo?l0o_co0?ooo@3Xkml0en780=7J[@3Pn=H02Sm=09Rf^03Monh0l?ok
0?oko`3oloL0oocm0?coo`3ooo/0ookm0?ono`80oooo01D0o_oo0?koo@3moo`0oook0?gln03Ie=40
oocj0?oelP3oo_P0ko7^0?Soo`3dnO`0oo_m0?kon`3oi^d0kLK;0?Ooo@3nool0o_om0?[on@3koOP0
0P3noo/00`3ooo/0oooo0?ooo`090?ooo`002P3oool04@3HkI80f^FP0=_SY`1`O3h0[<=k0;k/Y03P
omP0f_oU0569HP1fZgl0Ukb8000=0039dJX0eNJb0<KTVP3Bj9d0JV8Q0080o`0000<0/^bH0?l0003o
00000P3o0000EP22W5D0f_Za0;GGS@3Hn[00d?2W0=C^Y`36fiH0P95=0<WHU@3AhY`0iOJ`0<GFT03K
iZh0WZMj0?ook@3oooH0oogo0?olo`2k/k40oogk0?omnP3on?80oo_c0?Wgj03Jg<L0j_3>0=WR]`3>
gJ@0enZX0=S]XP3DjIh0cMRF0<gBTP0:3000JfT^09ZLG@3@hI/0c^VL0<O[U035k940c?2@0<WZT`3<
i;00`nV^0<[WY`3Ai:@0en6R0<KWV033jI@0cNBB0=GPT@39ii40aNVB0=3ZX03Ak9l0c>NF0<gVU@3?
j9D0c^FC0<oVUP3AiYT0d^>L0=CSWP3GhZH0oOoN0?SofP3BmKD0bo2Z0<OWV`33fhl0d^BJ0=KQW`3K
jJ`0cnB[0<kPXP3Siid0f]fJ0?Kia03CeZT0k_G<0?7ld@3/ol@0eNnV0<k^V@33k8@0a>Z50P3;j9H0
7`3@l9d0cnnL0<OVUP3Bkil0enfR0=[[Y03Chi`0e=jI0<?8Q@1HE1L0c]JM0=?Z_03aon<0jO_S0002
00060100>Re709fPZ@001@00FW5D0<SbYP36l:@0a>fQ0<C]W`38lJ<0f>Z/0=;N[P3SjlH0oood0?ol
n`3oo?l00P3ooOl0DP3oooP0o_oa0?Com03Iool0M9jL0>[oo`3nood0ookh0?olk`3cj=@0e=jl0<OP
^02lh;80bNnl0:NdQP0b=aL0>T0V06M_HP3dool0iooo0=Wko`3[ool0ioom0>oonP2[]9l0Pj5o000C
002M_k40jogo0?Gio02EPGP0ZHeo0?oliP3oond0j_oj0>_on`3kooX0oooj0?okn03fl?00n??`0:>Q
U03/k]T0o_oV0?_oi03Hj<@0bmja0<OWWP37lIl0a>jH0=7TU@3/jj/0_jf50>?I]P3Nkl/0looR0=7Q
/P3Ehk80bn:^0<[QZ@38gZ00cN>S0<oUY038gi/0f>j]0=7Y[@22VF<0SJEe0;?BYP2HaZT0RKVQ0:CJ
c@2<a;/0@W]b05N=P01LSX80hOoo0>Ooo`3aool0mOoo0?coo`3oo_l20?oon00;0?olo`3lnOl0mOoo
07Va/03=ool0m?oo0?gmn`3lood0o_om0?coo@3kood00`3kool30?Woo`1N0?Coo`2bgN@0UKk20:?8
`@3In_<0jooo0>[oo`1YRhd0h_oo0=kfnP3do?l0o_oo0?okn03onol0i_oo0=goo`18Pgl000h?0?oa
m`3F`LH0oook0?[no@3lood0ookh0=39``3oo_P0kNKP0?oojP3?g;40cn>^0<c[Y@3dolX0m_o:0>cZ
^@1^HCD0fLNG0>KGX03KeYH0fMRO0=[PY03PjJX0eN:M0=SYX`3EjJ@0b^BM0<SSW038jYh0a^^M0<;Y
UP3:kI/0b^VM0=?_Y@3:i9d0e>RY0<kPYP2d`Xl0ZKN60<cK/03Ah;L0jOOC0>gff@3Pjld0joWF0?So
h@3QmL80dNF`0<?JYP3Fj[T0lOoJ0?Woi032dZ/0b>6W0<cYYP3>j:L0e>f/0=__/P3BiZ/0c=fV0=W/
]@3WnlH0j?o90?GoeP3bomP0jooA0<OIY@2<VVT0];NJ00h=003nn?`0o_Ko0?ono`3oood0mOS_0?ko
o@<0oooo0P3oo_l20?omo@0:0?gel`3ooO/0oogk0?ohl@3bhML0YiZB0?olmP3oo?T0ooom0?ooo`<0
o_oo01T0o_om0=kFd`2m/Zh0YYbC0=gCbP2j/:h0n>o`0?olo`3knO`0o_ok0>?/e`3DhLD0g>Fh0>_f
f0001Al0a=?J000I002]kM<0]kk40?oho`3onol0n?oo0?oon`3ooOd0ooko0080oooo01@0o_oo0?ko
o@3nood0o_gi0?oon`3RgMX0e<[80?g[j@3onoP0ooom0?Woo`3jo_l0oogo0?_onP3ojNh0o=WM0?7o
o03hool0o?om0?kon`80oook00<0oOch0?onn`3oool02P3oool000X0oooo01@0d>VF0=OSX@32bXh0
aLnC0=;VY`2jjk@0X=^_08_:[@1hZI<0VlBV02Pk3P001P00h^Vm0:>dO@2ce8D0OY=40:^RG`3Ed900
`^bP0;;]W@@0o`000=@0RZEN0<_]X`33iid0]]R>0<GUW037hIX0bmnJ04eL6@3NjZP0hNjY0=CQW03M
jJL0h^^f0<;9W`3ooo40noSa0?oio@3oo?l0^k:c0?omn`3oo?d0oogk0?onnP3elnL0[JjL0?ooi03b
n]40eN:Z0<kNW@3<hIH0eNFL0>CX[@3XiZd02PD006UR;P2XYG00eN2T0=GXYP38ii/0b>NG0=3^V03=
iYD0cnB[0<?ZZ@3:ijL0dN>U0=KRY038kZ40aO2P0=;ZW03KiYX0cnbH0<_^W03=iZ@0cNJR0<WUVP3:
iYT0c>VI0<cYU`3;j9H0bnJG0<cWVP3AjIl0eNNY0?coh@3homl0fOo10<[c[@33j9P0cnnL0=C]W02l
cX80eNVQ0=;`ZP38i9X0eN:C0<C@R02e`hP0amJO0<_M[@3Vn/T0g_Nm0<7NW02ngY<0b^jG0<c^V03>
iYP0dNVK0<_XV036iID0c_6Q0<KWV02lfhd0b>BG0=kh[P3Rn:l0c=VC05E;3P3Vj:T0cN:Y0?Cog@3`
o>h0S8b>00P03P0H2Ah0:2L_00`B4P001P00gO_50<g[]@2mg:<0_=^R0<CSZ03Pl/00g>_40?coj03o
ooP0oogn0?ojo`3jl_d0oOKn0?ooo@3mo_H0mooj0;[Mf@2D];<0j_on0>?QhP2l/;00l]oK08enM`1[
KEl0GVeJ05eeG`1GLE@0<CHF008;000[=2<01`L00=kVj03hool0nO_o0?C[k03moo`0o_of0;ZhTP2:
TfP04RlA07^PSP3@n_P0h?oo0>g^h035^J<0n>720?o`d@3Zl]X0noo_0?Sii`3onoD0oOCe0>;IgP3l
l_<0dLnj0?7ee03Wll<0i?C30<gP/P36gJT0anVM0<OcWP36l9X0cn6E0>SVZ@2jYHH0l^;;0>oki@3e
ond0hN_90??jf@3FiL@0e>:o0=GR]`3Lj;X0fNFc0=KT[`3DhZl0_M2R07:9G`36h;/0fooL056DL@1?
T7P003Tc04=kNP0MD540PjjW0<S`i`3Xool0lOoo0?Ono`3amOl0o_oo0?_oo@3kooP0o_oj0?oko`3f
mOl0m?oo07f`/`31lo00n?ok0?oonP<0noom00D0nOom0?Woo`3iool0nOoo0?Soo`020?Woo`1N0?So
o`3`o_l0kOoo0>_oo`3WooT0hoWf0>goo`0C?C`0X<c=0>Koo`3[m?/0noco0?Sdl@3onol0f_?j0=_o
o`0jMG4000P90<Je^`3[e]/0oook0?coo`3bmo<0ookh0?gfl03oo_P0j>7K0?oohP3Fi;<0cnN[0<c/
X@3/ol00l_o10=K;WP1RC2L0oo;:0>?8V@3ZgZ@0emZQ0<;@TP37f9@0d>FJ0<7IS@3DkZ@0anFM0<OW
WP3=kj80bNjN0<O^V`38kIl0bNNO0=;]YP36gi/0g>jb0<[IXP1lR5X0fnNo0<OD]P31c[80m?oZ0?Wo
l@3foN/0noo/0?Woh`3>hZd0d^N^0<WQY@3Ik[D0n?oJ0?Sog`3@hkD0bnRX0<c[Y@39iZ<0gORe0>co
``3EjJh0bMZT0=SY]@35ejD0e>Jd0?3od03[omD0l_oL0>;d`P2V]8<0PXEX00@1003om_h0oo_o0?cj
o`3inoP0oOog0?oon`<0oooo0`3oo_l02`3mnOX0ooko0?kjn`3oo_l0oo_c0;:NT`3<^k40o_7Y0?om
nP3ckn`0oooo00<0o_oo01T0o_om0<>k^02ZWiT0WiF<0=oEc03Fc<X0oo[k0?olo`3no?l0o_ok0>ch
hP3Ul]H0hNZk0?3df@0b;Tl0kOKo00UP?@2Gj<P0`M3C0?CJh`3on_l0m?oo0?_jmP3ooOd0ooko0080
oooo01@0o_oo0?koo@3nood0o_gi0?oon`3flNh0h=KD0>C@c`3jjnP0ookm0?Olo`3lool0oo[l0?co
n`3ok?00onGX0?3oo@3gool0n_ok0?kon`80oook00<0ookk0?omnP3oool02P3oool000X0oooo01D0
b^Nk09:RH`2<UU40bLjF0=CT`02;^;<07UIE0;OelP2jh]L0amg@00T1002/YHT0Ui]Y0;G5Q`2deX80
f_2N0>_PWP3^jJT0`NbT0;CaX`2onJ`00P3o0000>`39i9d0[/j50<KZX03CnJh0`N>I0<WYX03NmJl0
_/n;0:2/JP3CfIT0U9eL0>7ZZ@3Jhj@0e]fZ0??ecP3UhMD0oo_h0?olo`3on_l0gMCG0?okoP3FcmH0
oogo0>cXj@3oooP0][JZ0?ooj03/m<l0Wjaf08^IG02JZf@0[k]k07ebE02WUgh03`0005M2;`2_WX`0
oooX0?koiP3Gj;h0cN2b0=;S[`3<gZ00c>Z@0;cbTP32kYD0b>^I0<gXV`2il9l0]?:O0<CZW`3@i9l0
a>ZM0<7[W`3:jJH0bNVV0<W]Y@34kIl0`NZL0080`>fJ04<0_njN0<3^X`2mjj<0`^>Z0?ookP3fonT0
_>>^0;_ZYP36lYd0an^D0<[XT035gHD0eo>L0<?YTP2SbG@0QiiH08^THP2Y`hH0cnbb0<SV/P3Jn/T0
goc@0<CQ]@33g[<0b^>i0<GKZP3BgY`0c]fH0=G_YP3@kZ@0a>ZM0<7ZW03=nJX0_^ZK0;ORT`35kZ00
d^VU06mJ:`3KeYH0eNBQ0?Sof03lool0oo_o0?oanP3oknd0QWme06i]J@000000<bTW00H000040000
=34Z06i^I01CJTh0HWAJ07N5K0001@0000<003`i<0081@000`0000H41`0000@00P470040100<30`0
00<00080JWIZ05<0NHIe086<O02k_[<0XJ6I0=?>b03fkNH0m^[J0=cak03^ool0^;Z/00483P3onOl0
onWk0?ohk03honl0lOoX0=KZXP2UWf<0Eg=:05fHN00]UXD0<ij<0<colP3Bo=@0XZ9/09bFG02n_8<0
lo6n0=3<Z@3Tf]40oo_m0?_^n03ll?80k>W:0:BXMP3;fi80kOnk0<gUY`3<jJT0bNnR0;_WTP2lj940
c]nH0>;MYP2cVHP0ooWb0>cak@3iood0oOga0?_kk`3kood0o_oj0?ool@3oon`0m_GI0<k?/02Z[i40
j?KL0?Col@3^ooP0CG]Q0:Cob`2ZolP0__K50<WbaP3Vo]h0oood0?kdlP3ll?00o_?a0?ojk03ooo<0
oogo0?ConP3^ooP0l_ok0?cno`3eool0ZlCH0:KAfP3Yool0oogg0?omm0020?ooo@80ooko0P3oool4
0?ono`1O0?oko`3okol0ooco0?Ooo@3eoo/0m_oo0?;oo`3Kool0VMCB03IYJP3cool0nOco0?onn`3o
moh0kOoo0=goo`14PG`06cLh00/0001QC540oook0??gmP3joo/0ookh0?okm@3onO<0ookh0<C1WP3?
gZL0bnBR0<_/W@3;hiT0en>S05a88`1`CS<0MTX_07599P1E@a40JgHl0;kLUP3EljT0e?BQ0;oQS@3<
kI`0b>RM0<SZX039jih0aNRF0<cbW@3:jj@0b>FS0<kXY`34gI`0l_o:0<[HX`3gom`0o?oV0?_om03h
ooT0nOoo0?koo`3noo/0m?g/0?Goh03@hj`0cN>S0=?]YP38hIl0d>F]0=3T/@38gj/0c>^W0<K[WP3:
j:00b^FR0<_OXP3AhjT0Y[Ao0:VgQP3Ii[P0cmb^0=3P/`36gkD0`=^`0=GY^03eom80kNgA00X7003@
a/h0ooSo0<W6c@3fn?D0o_of0?oon`3oood01@3oool0303mo?l0ooko0?Sgo03oo_l0Wh^20=Fn[P3o
nnl0oo_a0?omn03gl^h0ooom0?ooo`<0o_oo01P0ookh0=W>b03ooO@0ooG/0?olnP3oo?d0ooSm0?on
o`3koOP0nOo_0?Woj03lomP0moGL08I]U@3ooOl09I1V02:6H03@j>P0o^3Z0?o_m@3bool0ookk0?om
o@3oo_l20?ooo`030?koo`3nood0nO_h0080oook0100ookk0?okn@3`fmX0aK6`0?_em@3fn_d0o_oo
0?omo`3loo/0onCX0?oXjP3^ood0m?oo0?_mn03oooX0ooki0P3oooX00`3AbLH0oooo0?ooo`090?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {574.813, 0}} -> {-0.0750158, -0.100559, \
0.010963, 0.010963}, {{10.25, 147.063}, {561, 424.188}} -> {-14.9102, \
-19.0921, 2.18184, 2.18184}, {{147.063, 283.875}, {561, 424.188}} -> \
{-213.912, -19.0921, 2.18184, 2.18184}, {{283.875, 420.688}, {561, 424.188}} -> \
{-412.914, -19.0921, 2.18184, 2.18184}, {{10.25, 147.063}, {424.188, \
287.375}} -> {-14.9102, -218.094, 2.18184, 2.18184}, {{147.063, 283.875}, \
{424.188, 287.375}} -> {-213.912, -218.094, 2.18184, 2.18184}, {{283.875, \
420.688}, {424.188, 287.375}} -> {-412.914, -218.094, 2.18184, 2.18184}, \
{{10.25, 147.063}, {287.375, 150.563}} -> {-14.9102, -417.096, 2.18184, \
2.18184}, {{147.063, 283.875}, {287.375, 150.563}} -> {-213.912, -417.096, \
2.18184, 2.18184}, {{283.875, 420.688}, {287.375, 150.563}} -> {-412.914, \
-417.096, 2.18184, 2.18184}, {{10.25, 147.063}, {150.563, 13.75}} -> \
{-14.9102, -616.098, 2.18184, 2.18184}, {{147.063, 283.875}, {150.563, \
13.75}} -> {-213.912, -616.098, 2.18184, 2.18184}, {{283.875, 420.688}, \
{150.563, 13.75}} -> {-412.914, -616.098, 2.18184, 2.18184}}],

Cell[BoxData[
    InterpretationBox[\("Total distance "\[InvisibleSpace]"45.8371 km"\),
      SequenceForm[ "Total distance ", "45.8371 km"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="],

Cell[BoxData[
    InterpretationBox[\("Net elevation change "\[InvisibleSpace]"-15. m"\),
      SequenceForm[ "Net elevation change ", "-15. m"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="],

Cell[BoxData[
    InterpretationBox[\("Total climb "\[InvisibleSpace]"1299. m"\),
      SequenceForm[ "Total climb ", "1299. m"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="],

Cell[BoxData[
    InterpretationBox[\("Total descent "\[InvisibleSpace]"-1314. m"\),
      SequenceForm[ "Total descent ", "-1314. m"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0207775 -1.29225 0.000781678 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23158 -0.0125 -6 -9 ]
[.23158 -0.0125 6 0 ]
[.43936 -0.0125 -6 -9 ]
[.43936 -0.0125 6 0 ]
[.64713 -0.0125 -6 -9 ]
[.64713 -0.0125 6 0 ]
[.85491 -0.0125 -6 -9 ]
[.85491 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -41 -21.5625 ]
[.5 -0.0125 41 -9 ]
[-0.0125 .0366 -24 -4.5 ]
[-0.0125 .0366 0 4.5 ]
[-0.0125 .11477 -24 -4.5 ]
[-0.0125 .11477 0 4.5 ]
[-0.0125 .19294 -24 -4.5 ]
[-0.0125 .19294 0 4.5 ]
[-0.0125 .27111 -24 -4.5 ]
[-0.0125 .27111 0 4.5 ]
[-0.0125 .34927 -24 -4.5 ]
[-0.0125 .34927 0 4.5 ]
[-0.0125 .42744 -24 -4.5 ]
[-0.0125 .42744 0 4.5 ]
[-0.0125 .50561 -24 -4.5 ]
[-0.0125 .50561 0 4.5 ]
[-0.0125 .58378 -24 -4.5 ]
[-0.0125 .58378 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -26 ]
[-0.01875 .30902 -24 26 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12.5625 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23158 0 m
.23158 .00625 L
s
[(10)] .23158 -0.0125 0 1 Mshowa
.43936 0 m
.43936 .00625 L
s
[(20)] .43936 -0.0125 0 1 Mshowa
.64713 0 m
.64713 .00625 L
s
[(30)] .64713 -0.0125 0 1 Mshowa
.85491 0 m
.85491 .00625 L
s
[(40)] .85491 -0.0125 0 1 Mshowa
.125 Mabswid
.06536 0 m
.06536 .00375 L
s
.10692 0 m
.10692 .00375 L
s
.14847 0 m
.14847 .00375 L
s
.19003 0 m
.19003 .00375 L
s
.27314 0 m
.27314 .00375 L
s
.31469 0 m
.31469 .00375 L
s
.35625 0 m
.35625 .00375 L
s
.3978 0 m
.3978 .00375 L
s
.48091 0 m
.48091 .00375 L
s
.52247 0 m
.52247 .00375 L
s
.56402 0 m
.56402 .00375 L
s
.60558 0 m
.60558 .00375 L
s
.68869 0 m
.68869 .00375 L
s
.73024 0 m
.73024 .00375 L
s
.7718 0 m
.7718 .00375 L
s
.81335 0 m
.81335 .00375 L
s
.89646 0 m
.89646 .00375 L
s
.93802 0 m
.93802 .00375 L
s
.97957 0 m
.97957 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -102 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(distance) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 12.813 moveto
(H) show
123.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(km) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 12.813 moveto
(L) show
141.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0366 m
.00625 .0366 L
s
[(1700)] -0.0125 .0366 1 0 Mshowa
0 .11477 m
.00625 .11477 L
s
[(1800)] -0.0125 .11477 1 0 Mshowa
0 .19294 m
.00625 .19294 L
s
[(1900)] -0.0125 .19294 1 0 Mshowa
0 .27111 m
.00625 .27111 L
s
[(2000)] -0.0125 .27111 1 0 Mshowa
0 .34927 m
.00625 .34927 L
s
[(2100)] -0.0125 .34927 1 0 Mshowa
0 .42744 m
.00625 .42744 L
s
[(2200)] -0.0125 .42744 1 0 Mshowa
0 .50561 m
.00625 .50561 L
s
[(2300)] -0.0125 .50561 1 0 Mshowa
0 .58378 m
.00625 .58378 L
s
[(2400)] -0.0125 .58378 1 0 Mshowa
.125 Mabswid
0 .05224 m
.00375 .05224 L
s
0 .06787 m
.00375 .06787 L
s
0 .0835 m
.00375 .0835 L
s
0 .09914 m
.00375 .09914 L
s
0 .1304 m
.00375 .1304 L
s
0 .14604 m
.00375 .14604 L
s
0 .16167 m
.00375 .16167 L
s
0 .1773 m
.00375 .1773 L
s
0 .20857 m
.00375 .20857 L
s
0 .2242 m
.00375 .2242 L
s
0 .23984 m
.00375 .23984 L
s
0 .25547 m
.00375 .25547 L
s
0 .28674 m
.00375 .28674 L
s
0 .30237 m
.00375 .30237 L
s
0 .31801 m
.00375 .31801 L
s
0 .33364 m
.00375 .33364 L
s
0 .36491 m
.00375 .36491 L
s
0 .38054 m
.00375 .38054 L
s
0 .39617 m
.00375 .39617 L
s
0 .41181 m
.00375 .41181 L
s
0 .44307 m
.00375 .44307 L
s
0 .45871 m
.00375 .45871 L
s
0 .47434 m
.00375 .47434 L
s
0 .48998 m
.00375 .48998 L
s
0 .52124 m
.00375 .52124 L
s
0 .53688 m
.00375 .53688 L
s
0 .55251 m
.00375 .55251 L
s
0 .56814 m
.00375 .56814 L
s
0 .02097 m
.00375 .02097 L
s
0 .00533 m
.00375 .00533 L
s
0 .59941 m
.00375 .59941 L
s
0 .61504 m
.00375 .61504 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -117.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
87 10.2813 translate
90 rotate
-87 -10.2813 translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(elev) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 12.813 moveto
(H) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(L) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.23158 .61178 m
.23158 .61803 L
s
.43936 .61178 m
.43936 .61803 L
s
.64713 .61178 m
.64713 .61803 L
s
.85491 .61178 m
.85491 .61803 L
s
.125 Mabswid
.06536 .61428 m
.06536 .61803 L
s
.10692 .61428 m
.10692 .61803 L
s
.14847 .61428 m
.14847 .61803 L
s
.19003 .61428 m
.19003 .61803 L
s
.27314 .61428 m
.27314 .61803 L
s
.31469 .61428 m
.31469 .61803 L
s
.35625 .61428 m
.35625 .61803 L
s
.3978 .61428 m
.3978 .61803 L
s
.48091 .61428 m
.48091 .61803 L
s
.52247 .61428 m
.52247 .61803 L
s
.56402 .61428 m
.56402 .61803 L
s
.60558 .61428 m
.60558 .61803 L
s
.68869 .61428 m
.68869 .61803 L
s
.73024 .61428 m
.73024 .61803 L
s
.7718 .61428 m
.7718 .61803 L
s
.81335 .61428 m
.81335 .61803 L
s
.89646 .61428 m
.89646 .61803 L
s
.93802 .61428 m
.93802 .61803 L
s
.97957 .61428 m
.97957 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Elevation) show
123.000 12.813 moveto
(Profile) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .0366 m
1 .0366 L
s
.99375 .11477 m
1 .11477 L
s
.99375 .19294 m
1 .19294 L
s
.99375 .27111 m
1 .27111 L
s
.99375 .34927 m
1 .34927 L
s
.99375 .42744 m
1 .42744 L
s
.99375 .50561 m
1 .50561 L
s
.99375 .58378 m
1 .58378 L
s
.125 Mabswid
.99625 .05224 m
1 .05224 L
s
.99625 .06787 m
1 .06787 L
s
.99625 .0835 m
1 .0835 L
s
.99625 .09914 m
1 .09914 L
s
.99625 .1304 m
1 .1304 L
s
.99625 .14604 m
1 .14604 L
s
.99625 .16167 m
1 .16167 L
s
.99625 .1773 m
1 .1773 L
s
.99625 .20857 m
1 .20857 L
s
.99625 .2242 m
1 .2242 L
s
.99625 .23984 m
1 .23984 L
s
.99625 .25547 m
1 .25547 L
s
.99625 .28674 m
1 .28674 L
s
.99625 .30237 m
1 .30237 L
s
.99625 .31801 m
1 .31801 L
s
.99625 .33364 m
1 .33364 L
s
.99625 .36491 m
1 .36491 L
s
.99625 .38054 m
1 .38054 L
s
.99625 .39617 m
1 .39617 L
s
.99625 .41181 m
1 .41181 L
s
.99625 .44307 m
1 .44307 L
s
.99625 .45871 m
1 .45871 L
s
.99625 .47434 m
1 .47434 L
s
.99625 .48998 m
1 .48998 L
s
.99625 .52124 m
1 .52124 L
s
.99625 .53688 m
1 .53688 L
s
.99625 .55251 m
1 .55251 L
s
.99625 .56814 m
1 .56814 L
s
.99625 .02097 m
1 .02097 L
s
.99625 .00533 m
1 .00533 L
s
.99625 .59941 m
1 .59941 L
s
.99625 .61504 m
1 .61504 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .02644 Mdot
.02478 .02644 Mdot
.02948 .01862 Mdot
.03267 .02722 Mdot
.03558 .03426 Mdot
.03791 .03817 Mdot
.04073 .04364 Mdot
.04354 .05067 Mdot
.04881 .06162 Mdot
.05269 .06083 Mdot
.05542 .06162 Mdot
.05978 .07021 Mdot
.06221 .07021 Mdot
.06379 .08897 Mdot
.06514 .09288 Mdot
.06728 .09757 Mdot
.06855 .11086 Mdot
.07001 .11399 Mdot
.07123 .1265 Mdot
.07252 .14213 Mdot
.07446 .14995 Mdot
.07626 .14995 Mdot
.07736 .17809 Mdot
.07969 .19059 Mdot
.08162 .19997 Mdot
.08296 .19997 Mdot
.08471 .19997 Mdot
.08611 .19997 Mdot
.08796 .2117 Mdot
.08932 .2117 Mdot
.09126 .22733 Mdot
.09296 .23202 Mdot
.09476 .24609 Mdot
.0962 .25313 Mdot
.09792 .25782 Mdot
.09975 .25938 Mdot
.10106 .25704 Mdot
.10317 .25156 Mdot
.10496 .24531 Mdot
.10696 .24766 Mdot
.10935 .25547 Mdot
.11086 .27189 Mdot
.11245 .29221 Mdot
.11383 .30237 Mdot
.11639 .31801 Mdot
.11835 .33129 Mdot
.11986 .33208 Mdot
.12185 .33989 Mdot
.12305 .34537 Mdot
.12591 .35318 Mdot
.12794 .35396 Mdot
.13017 .36022 Mdot
.13221 .37116 Mdot
.13389 .37351 Mdot
.13538 .37038 Mdot
.13693 .37351 Mdot
.13907 .37898 Mdot
.14218 .37116 Mdot
.14444 .37194 Mdot
.14708 .37507 Mdot
.14967 .37351 Mdot
.15132 .37741 Mdot
.15353 .38836 Mdot
.15524 .39383 Mdot
.15771 .39696 Mdot
.15926 .39539 Mdot
.16185 .40712 Mdot
.1636 .41572 Mdot
.16643 .429 Mdot
.16851 .43604 Mdot
.17028 .44386 Mdot
.17275 .45011 Mdot
.17554 .45949 Mdot
.17758 .45949 Mdot
.17934 .46496 Mdot
.18154 .46653 Mdot
.18313 .49857 Mdot
.18495 .50326 Mdot
.18682 .5189 Mdot
.18913 .52515 Mdot
.19079 .52828 Mdot
.19222 .53375 Mdot
.19437 .54235 Mdot
.19792 .54313 Mdot
.20017 .54391 Mdot
.20289 .54 Mdot
.205 .54469 Mdot
.20854 .54547 Mdot
.21156 .54782 Mdot
.2165 .53922 Mdot
.22062 .5314 Mdot
.22362 .52437 Mdot
.22618 .51655 Mdot
.22854 .50795 Mdot
.23121 .50326 Mdot
.23444 .50717 Mdot
.23757 .51108 Mdot
.24116 .50483 Mdot
.24375 .50561 Mdot
.24567 .50952 Mdot
.24809 .51264 Mdot
.25012 .52124 Mdot
.25224 .52281 Mdot
.25501 .52906 Mdot
.25836 .53219 Mdot
.26045 .55095 Mdot
.26284 .5658 Mdot
.2647 .57127 Mdot
.26883 .56814 Mdot
.27069 .56658 Mdot
.2723 .56658 Mdot
.27413 .56345 Mdot
.27581 .56658 Mdot
.27727 .56658 Mdot
.27907 .58612 Mdot
.28272 .583 Mdot
.28634 .58143 Mdot
.28974 .57752 Mdot
.29477 .57831 Mdot
.29826 .56971 Mdot
.30154 .5658 Mdot
.30429 .56345 Mdot
.30616 .5572 Mdot
.30951 .54938 Mdot
.31293 .54391 Mdot
.31662 .54391 Mdot
.31956 .54313 Mdot
.32127 .54782 Mdot
.32429 .54704 Mdot
.32845 .54078 Mdot
.33148 .53219 Mdot
.33391 .53219 Mdot
.33564 .53531 Mdot
.33799 .53844 Mdot
.3405 .54547 Mdot
.34255 .54782 Mdot
.34664 .54938 Mdot
.34923 .54704 Mdot
.35465 .54547 Mdot
.35678 .5314 Mdot
.35881 .53609 Mdot
.36189 .53844 Mdot
.36416 .54157 Mdot
.36793 .53766 Mdot
.37249 .53297 Mdot
.37414 .53609 Mdot
.37662 .54547 Mdot
.37898 .55251 Mdot
.38059 .55564 Mdot
.38323 .55954 Mdot
.388 .56736 Mdot
.3893 .55954 Mdot
.39147 .56111 Mdot
.39437 .56423 Mdot
.40116 .59394 Mdot
.41315 .60176 Mdot
.41798 .60332 Mdot
.42165 .60332 Mdot
.43252 .60332 Mdot
.43644 .60332 Mdot
.44001 .60332 Mdot
.44426 .60332 Mdot
.44964 .60332 Mdot
.45225 .60332 Mdot
.45386 .60332 Mdot
.45541 .49623 Mdot
.45667 .49857 Mdot
.46058 .49857 Mdot
.46384 .46418 Mdot
.46798 .46965 Mdot
.47045 .46731 Mdot
.47264 .472 Mdot
.47524 .47512 Mdot
.47882 .47591 Mdot
.48283 .47825 Mdot
.48452 .46105 Mdot
.48691 .47747 Mdot
.49165 .48138 Mdot
.49292 .45871 Mdot
.49868 .46809 Mdot
.50287 .46262 Mdot
.50663 .46105 Mdot
.50919 .46105 Mdot
.51133 .44855 Mdot
.51328 .44307 Mdot
.51519 .4376 Mdot
.51878 .43838 Mdot
.52066 .44776 Mdot
.5226 .44776 Mdot
.52966 .43917 Mdot
.53368 .44073 Mdot
.53731 .44229 Mdot
.54129 .41806 Mdot
.54453 .40946 Mdot
.5463 .40868 Mdot
.54954 .40086 Mdot
.5516 .39617 Mdot
.55479 .39227 Mdot
.55738 .39148 Mdot
.56031 .38523 Mdot
.56287 .38445 Mdot
.56572 .37741 Mdot
.56784 .38132 Mdot
.56939 .38132 Mdot
.57119 .38289 Mdot
.57464 .38132 Mdot
.57808 .38054 Mdot
.58036 .38132 Mdot
.58454 .38132 Mdot
.58748 .38132 Mdot
.58999 .37663 Mdot
.59316 .37585 Mdot
.59473 .37976 Mdot
.59611 .38367 Mdot
.59949 .38601 Mdot
.60151 .38445 Mdot
.60323 .38523 Mdot
.60466 .39305 Mdot
.6061 .40008 Mdot
.60785 .40086 Mdot
.61041 .40477 Mdot
.61353 .4165 Mdot
.61543 .42275 Mdot
.61929 .42275 Mdot
.62238 .43526 Mdot
.62415 .44073 Mdot
.62643 .44698 Mdot
.62751 .44698 Mdot
.63126 .46731 Mdot
.63399 .4634 Mdot
.63871 .4634 Mdot
.64225 .46105 Mdot
.64416 .45636 Mdot
.64645 .43917 Mdot
.65005 .429 Mdot
.65329 .42666 Mdot
.6554 .41728 Mdot
.65838 .39696 Mdot
.66076 .38523 Mdot
.66408 .3782 Mdot
.66618 .37585 Mdot
.66865 .36413 Mdot
.67123 .35553 Mdot
.67446 .34693 Mdot
.6768 .34537 Mdot
.68039 .34693 Mdot
.68309 .33911 Mdot
.6852 .33129 Mdot
.68882 .31253 Mdot
.69221 .30941 Mdot
.69614 .30159 Mdot
.69898 .26329 Mdot
.70149 .25625 Mdot
.70481 .24297 Mdot
.70858 .23124 Mdot
.71049 .23515 Mdot
.71296 .22889 Mdot
.71474 .22655 Mdot
.71622 .21795 Mdot
.7186 .20232 Mdot
.72155 .19294 Mdot
.72422 .18825 Mdot
.72668 .17887 Mdot
.72854 .1648 Mdot
.73222 .14916 Mdot
.73382 .12884 Mdot
.73511 .10773 Mdot
.73776 .10226 Mdot
.74004 .09835 Mdot
.74228 .09914 Mdot
.74793 .10383 Mdot
.75096 .10852 Mdot
.75526 .11164 Mdot
.75861 .1179 Mdot
.76205 .12181 Mdot
.76883 .13119 Mdot
.78157 .14838 Mdot
.7848 .15307 Mdot
.79116 .16558 Mdot
.7969 .17496 Mdot
.80058 .17574 Mdot
.81344 .16089 Mdot
.82163 .15385 Mdot
.82843 .14213 Mdot
.83672 .12884 Mdot
.85794 .12962 Mdot
.86551 .11633 Mdot
.89669 .06865 Mdot
.90382 .06005 Mdot
.91081 .06083 Mdot
.92469 .04755 Mdot
.9375 .03817 Mdot
.94377 .03582 Mdot
.94834 .03191 Mdot
.95975 .02722 Mdot
.97442 .01472 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00]P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05P0
oooo002e0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E`3oool007h0oooo1000
00020?ooo`<000000P3oool3000000@0oooo0P0000030?ooo`L000000P3oool200000080oooo0`00
00030?ooo`<000002@3oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`80
000000@0oooo0000003oool000000`3oool00`000000oooo0?ooo`1F0?ooo`00O@3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0400000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1F0?ooo`00O@3o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`<000000`3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool4
000000T0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo05H0oooo001n0?ooo`<000000`3oool2000000<0oooo10000000
0`3oool0000000000003000000<0oooo0`0000000`3oool0000000000002000000@0oooo0`000003
0?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`050000003oool000000000003oool00`00
00000`3oool000000?ooo`030?ooo`030000003oool0oooo05H0oooo00200?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0
00000?ooo`3oool0E`3oool007l0oooo0P0000040?ooo`030000003oool0oooo02h0oooo00@00000
0?ooo`00000000002`3oool00`000000oooo0?ooo`1H0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00>@3oool2000002P0oooo1@0000020?ooo`8000009@3oool4000000<0oooo
0P00000V0?ooo`800000103oool2000002L0oooo0`0000020?ooo`800000:P3oool003P0oooo00@0
00000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool09`3oool003P0oooo00@000000?ooo`3oool00000:@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000002H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0280oooo1@0000001@3oool000000?ooo`3oool0000002T0oooo000h0?ooo`040000003oool0
oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02D0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000:@3oool003P0oooo00@000000?ooo`3oool00000:@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000002@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000U0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000:@3oool003T0oooo0P00
000Y0?ooo`800000103oool2000002H0oooo0P0000040?ooo`8000009P3oool2000000@0oooo0P00
000W0?ooo`8000000`3oool2000002X0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo000d0?oooml000003@3oool003@0oooo0P0000040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000d0oooo000d0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool02`3oool003@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3?0?ooo`800000103oool00`000000
oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo00/0oooo
000d0?ooo`8000000`3oool00`000000oooo0000003=0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02`3oool001X0oooo1@0000030?ooo`030000003oool0oooo0080oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000000D0oooo
00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0:0?ooo`8000003@3oool001`0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool02`3oool001`0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool2000000<0oooo100000030?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00/0oooo000d0?ooo`80
0000g03oool00`000000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`080?ooo`800000
_03oool2000001<0oooo00<000000?ooo`3oool02`3oool003@0oooo00<000000?ooo`3oool0f`3o
ool00`000000oooo0?ooo`0;0?ooo`00=03oool2000000/0oooo0P00002h0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool02`3oool003@0oooo00<000000?ooo`3oool0f`3oool00`00
0000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo00/0
oooo000d0?ooo`800000g03oool00`000000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool02`3oool003@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00/0oooo000d0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0TP3oool2000003P0oooo00<000000?oo
o`3oool02`3oool003@0oooo0P00002R0?ooo`030000003oool0000003L0oooo00<000000?ooo`3o
ool02`3oool001X0oooo1@0000020?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo0:00oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;
0?ooo`00703oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00000<0?ooo`030000
003oool0oooo09H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`800000
3@3oool001`0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`2P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool01@00
0000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool02`3oool003@0oooo0P00003L0?oo
o`030000003oool0oooo00/0oooo000d0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3o
ool02`3oool003@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool003@0oooo0P00002Q0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0;0?ooo`00=03oool0
0`000000oooo0?ooo`0=0?ooo`800000W03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool02`3oool003@0oooo00<000000?ooo`3oool0f`3oool00`00
0000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02`3oool003@0oooo0P00002P0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?oo
o`3K0?ooo`030000003oool0oooo00/0oooo000d0?ooo`030000003oool0oooo0:h0oooo0P00000[
0?ooo`030000003oool0oooo00/0oooo000d0?ooo`8000003`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool02`3oool003@0oooo00<000000?ooo`3o
ool0f`3oool00`000000oooo0?ooo`0;0?ooo`006P3oool5000000040?ooo`0000000000000000@0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool300000=X0oooo0P00000=
0?ooo`00703oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool2000008/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0;0?ooo`00703o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0f`3oool00`00
0000oooo0?ooo`0;0?ooo`006`3oool2000000@0oooo0`0000030?ooo`800000103oool2000000D0
oooo0P00000A0?ooo`800000b@3oool00`000000oooo0?ooo`0;0?ooo`004@3oool200000240oooo
00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0;0?ooo`00403oool2000000030?ooo`00
0000oooo01l0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00/0oooo000@0?ooo`80000000<0oooo0000003oool07`3oool00`000000oooo0?ooo`3K
0?ooo`030000003oool0oooo00/0oooo000A0?ooo`030000003oool000000200oooo0P00000B0?oo
o`030000003oool0oooo08L0oooo0P00000n0?ooo`030000003oool0oooo00/0oooo000d0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0Q@3oool2000003l0oooo00<000000?ooo`3o
ool02`3oool003@0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0;0?ooo`003P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo0P00002J0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool02`3oool000h0oooo1P00000P0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`0000000000a@3oool00`000000oooo0?ooo`0;0?ooo`004`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo00<000000?ooo`000000aP3oool0
0`000000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`0C0?ooo`030000003oool00000
08<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0;0?ooo`00=03oool2000001@0
oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0;0?ooo`006P3oool4000000<0oooo
0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0V03oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00/0oooo000A0?ooo`8000001`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool02`3oool00100
oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`00
000F0?ooo`030000003oool0oooo0<40oooo0P00000=0?ooo`00403oool2000000030?ooo`000000
oooo00L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=/0
oooo00<000000?ooo`3oool02`3oool00140oooo00<000000?ooo`0000001P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool02`3o
ool001/0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0=/0oooo00<000000?ooo`3oool02`3oool00100oooo00<000000?ooo`3oool08@3oool20000
01L0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0;0?ooo`00403oool200000280
oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0;0?ooo`004P3oool200000200oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool02`3oool00180oooo0P00000P0?ooo`800000g03oool00`000000oooo0?oo
o`0;0?ooo`00403oool200000280oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo00/0oooo000@0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00/0oooo000d0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0;0?ooo`00
=03oool200000=`0oooo00<000000?ooo`3oool02`3oool003@0oooo00<000000?ooo`3oool0f`3o
ool00`000000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`0G0?ooo`800000O03oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00/0oooo000d0?ooo`800000g03oool00`00
0000oooo0?ooo`0;0?ooo`006P3oool400000080oooo1@0000020?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool02`3oool001X0oooo00<000000?ooo`3oool01@3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0N03oool2000004H0oooo00<000000?oo
o`3oool02`3oool001/0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<00000fP3oool2
000000d0oooo000@0?ooo`@00000203oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool02`3oool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool02`3oool000h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
2`3oool003@0oooo0P00003L0?ooo`030000003oool0oooo00/0oooo000@0?ooo`040000003oool0
oooo00000200oooo00<000000?ooo`3oool06P3oool500000;`0oooo00<000000?ooo`3oool02`3o
ool00100oooo1000000P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`000000G03oool0
0`000000oooo0?ooo`020?ooo`8000003P3oool2000004T0oooo00<000000?ooo`3oool02`3oool0
0100oooo00<000000?ooo`3oool08@3oool2000007`0oooo1@0000000`3oool000000?ooo`1H0?oo
o`030000003oool0oooo00/0oooo000A0?ooo`<00000803oool00`000000oooo0?ooo`1i0?ooo`80
00001`3oool2000000`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0;0?ooo`00
403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
EP3oool200000640oooo00<000000?ooo`3oool02`3oool00140oooo0`00000P0?ooo`030000003o
ool0oooo01l0oooo0P00001F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00/0oooo000d0?ooo`800000N03oool0
0`000000oooo0?ooo`090?ooo`800000EP3oool00`000000oooo0?ooo`0;0?ooo`003P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo00/0oooo000?0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0;0?ooo`00403oool400000200oooo
0P00003L0?ooo`030000003oool0oooo00/0oooo000d0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0;0?ooo`006P3oool400000080oooo10000003
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00/0oooo000J0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00/0oooo000K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo0`00000R0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool0BP3oool2000000d0oooo000L0?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00/0oooo000J0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0L03oool010000000oooo0?oo
o`00000D0?ooo`050000003oool0oooo0?ooo`000000CP3oool00`000000oooo0?ooo`0;0?ooo`00
6`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo0P00000T0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00/0oooo000d0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B03o
ool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
2`3oool003@0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0;0?ooo`00=03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00/0oooo000d0?ooo`800000I@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo0P00000K0?ooo`<00000CP3oool00`000000oooo0?ooo`0;
0?ooo`00=03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool02`3oool003@0oooo00<000000?ooo`3oool0I@3oool2000007@0oooo00<000000?ooo`3o
ool02`3oool003@0oooo0P00001W0?ooo`@00000L@3oool00`000000oooo0?ooo`0;0?ooo`00=03o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool02`3o
ool003@0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0;0?ooo`00=03oool00`00
0000oooo0?ooo`3K0?ooo`030000003oool0oooo00/0oooo000d0?ooo`800000H`3oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo00/0oooo000J0?ooo`@000000`3oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03T0oooo
0P00001g0?ooo`030000003oool0oooo00/0oooo000J0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
0:P0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`<00000<03oool2000000030?ooo`000000oooo0:D0oooo0P00000=0?ooo`00703oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0380oooo00<000000?ooo`000000YP3o
ool00`000000oooo0?ooo`0;0?ooo`006P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0;0?oo
o`006`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0;0?ooo`800000Y@3oool00`000000oooo0?ooo`0;0?ooo`00
=03oool2000002P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2Y0?ooo`030000
003oool0oooo00/0oooo000d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00/0oooo000d0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000008X0oooo00<000000?ooo`3oool02`3oool003@0oooo0P00000[0?ooo`040000003oool0
oooo000001P0oooo00<000000?ooo`000000103oool00`000000oooo0000002;0?ooo`030000003o
ool0oooo00/0oooo000d0?ooo`030000003oool0oooo02P0oooo1000000F0?ooo`<00000103oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01<0oooo00@0
00000?ooo`00000000000`3oool200000900oooo00<000000?ooo`3oool02`3oool003@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool02`3oool003@0oooo0P0000120?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool3000008H0oooo00<000000?oo
o`3oool02`3oool003@0oooo00<000000?ooo`3oool0=`3oool010000000oooo0000000000050?oo
o`030000003oool0oooo0100oooo0P0000260?ooo`030000003oool0oooo00/0oooo000d0?ooo`80
0000>@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool02`3oool003@0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0;0?ooo`006P3o
ool4000000@0oooo0`0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0?03o
ool3000009`0oooo00<000000?ooo`3oool02`3oool001X0oooo00<000000?ooo`3oool01P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0k0?ooo`800000WP3oool00`000000oooo0?ooo`0;0?ooo`006`3o
ool00`000000oooo0?ooo`020?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`040000
003oool0oooo000000@0oooo0`00003J0?ooo`8000003@3oool001`0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`0;0?ooo`006P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0=/0oooo00<000000?ooo`3oool02`3oool001/0oooo0P0000050?ooo`8000000`3o
ool2000000@0oooo0P0000050?ooo`800000FP3oool3000000030?ooo`000000000000@00000N03o
ool00`000000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`3K0?ooo`030000003oool0
oooo00/0oooo000d0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool02`3oool003@0
oooo0P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000d0oooo000d0?oooml000003@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00700oooo1@0000020?ooo`<00000103oool3000000<0oooo0P0000030?ooo`D000000P3oool2
000000@0oooo0`0000030?ooo`8000000P3oool200000080oooo0P0000060?ooo`<00000103oool4
000000<0oooo0P0000030?ooo`@000000`3oool300000080oooo0`0000040?ooo`<00000B`3oool0
0740oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo0P0000030?ooo`@000000P3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0C03oool00740oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`@000000P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01P3oool3000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`@00000B`3oool00740oooo0P0000050?ooo`030000003oool0oooo00<0oooo
0P0000020?ooo`8000000P3oool200000080oooo0`0000000`3oool0000000000003000000<0oooo
0P0000040?ooo`8000000P3oool4000000T0oooo00@000000?ooo`3oool000000P3oool4000000<0
oooo0P0000030?ooo`@000000`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000004`0
oooo001a0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0K0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1A0?ooo`00L03oool500000080oooo0P00000N0?ooo`030000003oool0oooo0180
oooo1000000A0?ooo`800000103oool010000000oooo0?ooo`3oool2000005<0oooo003o0?ooob40
oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.5785, 1512.97, 0.216709, \
5.76025}}],

Cell[BoxData[
    InterpretationBox[\("Total elapsed time "\[InvisibleSpace]"4:33:50"\),
      SequenceForm[ "Total elapsed time ", "4:33:50"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="],

Cell[BoxData[
    InterpretationBox[\("Average speed "\[InvisibleSpace]"10.0432 km/h"\),
      SequenceForm[ "Average speed ", "10.0432 km/h"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="],

Cell[BoxData[
    InterpretationBox[\("Estimated moving time "\[InvisibleSpace]"3:34:24"\),
      SequenceForm[ "Estimated moving time ", "3:34:24"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="],

Cell[BoxData[
    InterpretationBox[\("Estimated average moving speed \
"\[InvisibleSpace]"12.8272 km/h"\),
      SequenceForm[ "Estimated average moving speed ", "12.8272 km/h"],
      Editable->False]], "Print",
  CellLabel->"From In[20]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Deployment",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Here is the Ptolemaic view of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as the center of your computing universe..."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@0000302000`400?l00000o`00003ooooooooo
ooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooo
ooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooooooooooo
ool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4oooo
o`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooo
ooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooo
ooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooooooo
ooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4
ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00
ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooo
ooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooo
ooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooooooooooo
ool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4oooo
o`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooo
ooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooo
ooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooooooo
ooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4
ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00
ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooo
ooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooo
ooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooooooooooo
ool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4oooo
o`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooo
ooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooo
ooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooooooo
ooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4
ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00
ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooo
ooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooo
ooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooooooooooooooo
ool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4oooo
o`00ooooooooooooooooooooooooool4ooooo`00oooooooooooood?ooooo00Go];Bdoh:2P_mcLg?o
WYjNonc/k00Eooooo`03olC4a?n3Ph?ooooo0?ooooooXoooool00?oooooooooooom2ooooo`07og]k
Nol30`?o;bl_oc<c<olO7aoo>3PholK6aP0Dooooo`03ogmoOol0003ooooo0?ooooooXoooool00?oo
oooooooooom1ooooo`09okjn__l0003oSHf=omOGeooPh>3o^[Zjoc8b<_m0@43oinOW01?ooooo00?o
R8R8o`L71oooool0oooooonSooooo`00oooooooooooood7ooooo00?o@410od51@Oooool00oooool0
0onQXJ7o4a<CokNg]`0Cooooo`03ohR8R?l71`Oooooo0?ooooooXoooool00?oooooooooooom1oooo
o`03oj2PX?o=cLgooooo00?ooooo00?odm?Cob8R8_n=SHd04oooool00on8R8So1`L7ooooo`3ooooo
oj?ooooo003ooooool7ooooo00Sokno_ohf=SOlQ8B7o4A4Aof1PH?o@d=3oXJ6Qofa/K0?ooooo00Ko
lo?cohZ:R_lV9RKo410@oclo?onYZJT4ooooo`07ookno_n@T93o;2`/oa0@4?lc<c?oX:2Poo;blP02
ooooo`06oo_knomkNg_o4Q8Boa<C4omHF5Sof=SH0oooool00on2PX;o@d=3on?Sh`02ooooo`07obXZ
:_n:RX[oooooooooooobl_;oJf][odm?C`03ooooo`06onSXj?mbLW;o6ATIoa0@4?mJFU[oc<c<0_oo
ool00oo`l?3oIVIVoeQHF003ooooo`03olS8b?lP823od=3@00;ooooo00[o6a/KoinOWooooooooooo
onCTi?mQHF7o4A4AoalO7onEUIGonOWi2?ooool03?ono_koW9bLob4Q8Ol@413oBd];ong]kOmmOGgo
SHf=ooWinOooooooShn?obXZ:P?ooooo00?og]kNochn?_nCTi<00oooool02?oRh^;oEeMGoa8B4_lV
9RKoTI6AonWYjOmJFU[ocLg=1oooool2ooWin@07ogmoOolH61So5QHFogMgMoo@d=3o;bl_ogemO@02
ooooo`03od51@OmbLW;on?Sh00Gooooo017oX:2Pob@T9?l@413oB4Q8onKVi_n4Q8CoRHV9ooCdm?oo
ooooR8R8o`P82?ooooooL71`oahN7_lD51CoGemOomOGe`03ooooo`03ok6a/OlK6a_olo?c00;ooooo
00?ogmoOoa/K6oo1`L400_ooool00omiNGWoCTi>onKViP03ooooo`06ok>c/om0@43o4A4AoalO7on;
Rh_oi^KV0_ooool01Onm_Kgo>c/koa<C4om]KFgonOWi0?ooooooO_ooool00?oooooo`?ooool02OoK
fm_o>CTio`000?mGEeOoP820od92@_l30`?o=cLgob0P8002ooooo`08omKFe_lb<S;o0000oeMGEon<
S8co<c<co`410Om[Jf/2ooooo`08ooWinOmADE7o0000oeEEEOn3Ph?o@D51oaTI6Oo0`<02ooooo`07
oda<C?l92@WoJf][ogUiNOlO7aoo8b<SomSHf002ooooo`03og=cLol/;2coh>3P00;ooooo00Oo410@
ogalO?oooooooooooo7alOmJFU[o>SXj00;ooooo00cog]kNoc/k>ol0003oIVIVohR8R?lW9bOo1`L7
ojZZZ_ooooook^k^oeADE?m3@d<3ooooo`03ol;2`_l51@Gob/[:00;ooooo00[o0000oiBDU?oooooo
g]kNob0P8?lD51CoNg]kodm?Col20P;oWYjN1oooool03Oo`l?3oJVYZo`410Om0@43oQXJ6od51@Old
=3Co1@D5ofMWIoogmoOooooooh:2P_l@41000oooool00ooJf][o9RHVohJ6QP02ooooo`09olG5aOlI
6AWo4a<Cof][JomiNGWo6ATIobl_;olK6a_o`/;200Sooooo00So>3Pho`410OmHF5SoNGUiobh^;_lB
4Q;o30`<oh>3P`;ooooo00?o:RXZof5QHOogmoL00oooool05?odm?CoMGEeo`820_lk>c_oQHF5odA4
A?l`<33o1@D5of5QHOoalO7oooooohR8R?l0003o>CTioaXJ6_mmOGgoJVYZoa@D5?lB4Q;o`/;20_oo
ool00onXZ:So0000oo;blP02ooooo`03om_Kfol0003o^[Zj00;ooooo00?oJFUYocPh>?oShn<00_oo
ool03on4Q8Co0`<3od10@?n0P83oG5aLoaLG5on8R8Soooooojb/[?l61PKo@410ogemOOl820SoM7Ad
oo[jnP3ooooooggooooo003ooooookoooooo00Coo_knofMWIol51@Go`/;20oooool02?nOWioo0000
ob8R8_oooooom?CdofEUIOl>3PkoalO70oooool01on?Shoo0000ok6a/Oono_koPh>3o`H61_ng]kL0
0oooool01_n_[jooclo?ooooooo=cLgo1@D5ojf][@;ooooo00?ok>c/oa8B4_n4Q8@00_ooool00omc
Lg?o;Bd]on3Ph002ooooo`0<oa4A4OmlO7cooooooooooooalO7oFUYJoc/k>oooooooo_knofe]KOl?
3`oo_[jn0oooool01_ln?Sko1`L7ooooooo`l?3oE5ADodA4A0?ooooo00?o`/;2o`H61_o:b/X00_oo
ool01_l0003oU9BDoooooooBd];oH61PokRh^0;ooooo00?oFEUIoclo?ooUiND01_ooool00onf][Ko
0000oginOP03ooooo`07oiFEUOl10@7oIFEUooOgmoooooooPX:2oa4A4@03ooooo`08om[Jf_lW9bOo
QXJ6ooooooono_ko=3@doahN7_oTi>@2ooooo`04oo?clolc<c?o5ADEol;2`POooooo00?oX:2Po`00
0?n`/;000_ooool01?o^k^koFe]Ko`000?n8R8P2ooooo`03ob/[:omQHF7omoOg00?ooooo00?oaLG5
o`000?mhN7P00oooool02?nQXJ7o0@41oemOGooalO7oooooohR8R?l0003oE5AD0oooool02?oLg=co
;Rh^odA4A?oVi^KoooooojRXZ?l0003ol_;b0_ooool00ooKfm_o0000okZj^P02ooooo`07ofUYJOli
>CWohn?Soooooon`/;3o0@41ohR8R003ooooo`0:om;Bd_nWYjOoooooojNWYomXJ6Sof][Joooooon>
SXko51@DooCdm?ooooooOOooool00?oooooo_oooool01?oQhN7o:RXZofm_KooinOT4ooooo`06obXZ
:_lM7Agoooooolc<c?lL71coQhN71Oooool01Olo?cooADE5ooooooln?SkoBd];00Oooooo00?o[jn_
o`000?o_knl00_ooool00ooclo?oDe=Coclo?`02ooooo`03og=cLol];Bgoh>3P00;ooooo00co4A4A
ogalO?oooooooooooo7alOmJFU[o>c/koooooooNg]ko8b<SogemOOooool3oo_kn`06onKVi_oYjNWo
o_knonk^k_mDE5CoA4A40oooool00oo2`/;o1PH6ol[:bP02ooooo`03o`000?nDU9Cooooo00?ooooo
00Gono_kon_[joln?SkoB4Q8onSXj005ooooo`04ooGemOm^KVko92@Too3`l0Cooooo00Ko9RHVof9R
H_ogmoOooooooh:2P_lA4A43ooooo`08om[Jf_lW9bOoQXJ6oooooooAdM7o2@T9ojJVY_omoOd3oooo
o`03okBd]?l51@Go`/;200Oooooo00?oADE5od10@?ooool00oooool00oo1`L7o0P82oh>3P`02oooo
o`03ob/[:omQHF7omoOg00;ooooo00ComoOgog]kNolI6AWokno_1?ooool01ol/;2coFe]Koo7alOoo
ooooR8R8o`@41?oOgml01?ooool01onGUiOo3`l?ol30`?ooooooZ:RXo`000?obl_800_ooool00ooK
fm_o0000okZj^P02ooooo`06ofUYJOli>CWohn?SoooooomWIfOo7alO2_ooool01?odm?CoLW9bo`X:
2_oclo?ooooooggooooo003ooooookoooooo00?oc/k>oa@D5?nOWil01Oooool01_mmOGgo5QHFoooo
oonb/[;o4a<Col;2`PGooooo00GoUIFEo`X:2_ono_ko10@4oj2PX007ooooo`03ok6a/Ol0003ojn_[
00;ooooo00?om?Cdoe]KFolb<S800_ooool00omcLg?o;Rh^on3Ph002ooooo`0<oa4A4OmmOGgooooo
oooooooalO7oFUYJoc/k>oooooooe]KFob@T9?mFEUKoXj>S0onHV9P01_nMWIgoXJ6Qono_kooalO7o
E5ADodA4A0?ooooo00?o`/;2o`H61_o:b/X00_ooool02_l0003oU9BDooooooooooooo_knon?ShonN
WYko;Bd]o``<3?nTY:@6ooooo`03oo7alOmADE7o?Shn00Gooooo00Ko;Rh^of5QHOogmoOooooooh:2
P_lA4A43ooooo`07om[Jf_lW9bOoQXJ6oooooong]kOo0000on7Qh@04ooooo`03olk>c_l410Co`/;2
00Oooooo00?o51@DohJ6Q_ooool00oooool00ooJf][o820PogemO@02ooooo`03ob/[:omRHV;omoOg
00;ooooo00?om?CdoeiNG_l];Bd01Oooool01_lf=SKoFUYJoo7alOooooooR8R8o`L71`Gooooo00Oo
c<c<oaLG5onXZ:SoooooojRXZ?l0003ol_;b00;ooooo00?ofm_Ko`000?nj^[X00_ooool01omYJFWo
>CTion?Shooooooo8B4Qofi^K_olo?`01oooool01_ogmoOoa<C4odU9BOl10@7oQHF5oo[jn_oooooo
OOooool00?oooooo_oooool00ooDe=Co6QXJoi6AT@05ooooo`06ofQXJ?lH61Sooooookjn__lN7Qko
/;2`1Oooool01OmiNGWo:2PXookno_lD51CoQXJ600Oooooo00?o/K6ao`000?o[jn/00_ooool00ood
m?CoFUYJoc<c<`02ooooo`03ogAdM?lU9BGogMgM00;ooooo00co4A4AogMgMooooooooooooo7alOmI
FEWo?CdmoooooooJf][o=3@doa@D5?lX:2P2obHV9P07obLW9ol<30co0000omCDe?oemOGoE5ADodA4
A003ooooo`03ol71`Ol410CobLW900;ooooo00Wo0000oiBDU?oooooono_kolK6a_lY:BWo2PX:odE5
AOnk^k/01oooool00oobl_;oFEUIocPh>005ooooo`06ocPh>?mTI6ComoOgoooooon2PX;o4A4A0ooo
ool01ooIfMWo9BDUohF5QOoooooo_knoo`410OoEeMD01?ooool00oo:b/[o410@ol30`007ooooo`03
ob4Q8OmmOGgooooo00?ooooo00?ofMWIoalO7omnOWh00_ooool00ol/;2coF5QHooOgm`02ooooo`03
ooGemOmVIVKo:2PX00Gooooo00Oo?clooeiNG_oalO7oooooohR8R?l61PKon_[j00Cooooo00OoalO7
oa`L7?n^[ZkoooooojRXZ?l0003ol_;b00;ooooo00?ogMgMo`000?nj^[X00_ooool01_mYJFWo>CTi
on?Shooooooo=CDeoeEEE@Oooooo00GomoOgohf=SOl30`?o8R8RoiFEU@3oooooogoooooo003ooooo
okoooooo00Cok^k^ochn?_m1@D7okNg]0oooool02?oYjNWo6ATIoalO7ooooooogMgMoc4a<OmBDU;o
moOg0oooool01ooShn?o5aLGofm_KoooooooIFEUob4Q8OoWinL00oooool01_oZj^[okno_oooooona
/K7o0000on_[j`;ooooo00?om?CdoeYJF_lc<c<00_ooool00omjNW[o0`<3olS8b002ooooo`0;oa<C
4om1@D7ooooooooooooclo?o@410oeQHF?oooooolO7aod10@?mNGUh01?ooool01om]KFgo4A4AooWi
nOo`l?3oEEEEoc<c<oofm_H00_ooool00onYZJWo1PH6olk>cP02ooooo`07o`000?nHV9Soooooong]
kOm;Bd_o4A4Aolg=c@09ooooo`04ooWinOn8R8So51@DomKFeP?ooooo00Sohn?SoaHF5_mSHf?omoOg
oooooon2PX;o2`/;onc/k0;ooooo00Soc/k>oaPH6?nBTY;oooooonGUiOlB4Q;oNg]koogmo@?ooooo
00?oQ8B4o`T92Oo2`/801oooool00omYJFWo6a/Kono_k`03ooooo`03oibLW?l0003oQXJ600;ooooo
00?o<c<coalO7ooemOD00_ooool01?ojn_[oV9RHo`/;2ooBd]83ooooo`08onSXj?lJ6Q[oG5aLoo7a
lOooooooR8R8o`820_nZZZX3ooooo`08oogmoOmbLW;o8B4Qolo?coooooooZ:RXo`000?o7alL2oooo
o`03olo?col0003o^k^k00;ooooo00OoJFUYocTi>OoShn?ooooooi>CTol51@God];B00?ooooo00Oo
n?Shon7QhOoooooodM7AoaLG5omADE7on_[j0?ooooooP?ooool00?oooooo`?ooool08OnEUIGo0000
of][Joo<c<cogmoOokjn__m:BT[o1`L7ob8R8_oooooooOgmoiFEUOl20P;oKFe]olc<c?oTi>Co^[Zj
od51@OlC4a?ofMWIooooooo=cLgo1`L7odU9BOo4a<CohN7Qol30`?mMGEgo^[Zjoooooona/K7o0000
on_[j`02ooooo`03ooCdm?mJFU[o<c<c00;ooooo00coNg]ko`000?m^KVkof=SHojb/[?l71`Oo3@d=
oijNW_oNg]koZj^[o`T92OnDU9@2ooooo`0NoibLW?l0003oI6ATomCDe?oKfm_oTI6Ao`000?moOgoo
ooooong]kOmHF5So0P82oh:2P_oIfMWodM7AodI6A_l/;2coh^;RoooooooShn?o0000oginO_oRh^;o
jNWYoeMGEol/;2cofm_KojZZZ_n0P83ohN7Q1oooool04ooBd];o5ADEocPh>?o2`/;ohN7Qokno_omE
EEGo0000ofATI?ogmoOooooooh61POl0003oHV9Rom?CdooGemOoLW9boa@D5?o0`<000_ooool02OmX
J6So0000oi:BT_oFe]Kof][Joi^KVolE5AGo6ATIol;2`P07ooooo`09olk>c_l51@GoG5aLolg=cOoK
fm_oXZ:RobDU9Ol10@7oQhN700;ooooo02Co>3Pho`000?nMWIgog=cLomWIfOoooooog]kNoa/K6olc
<c?o`<30on7QhOo0`<3oGUiNo`000?mNGUkolO7aoooooon8R8So0000obTY:OnZZZ[ogMgMom;Bd_n6
QXKo30`<ogEeMOodm?CoooooojRXZ?l71`Oo?3`lolg=cOoHf=SoH61PoaLG5ooMgMd2ooooo`0DofUY
JOli>CWohn?Sooooooo^k^ko9RHVob4Q8Ong]kOogmoOolg=cOmmOGgoOgmooooooooIfMWo6QXJogal
O?oBd];oKFe]olk>c_ono_kooooooggooooo003ooooool3ooooo00Wolo?coh:2P_lH61So5QHFobTY
:OlZ:R[o@T92oeQHF?lJ6QX00_ooool02?odm?CoQXJ6oaHF5_lI6AWo<C4ao`h>3_l];Bgo[jn_0ooo
ool02onLW9co:2PXoaPH6?l/;2co5aLGocLg=ooAdM7oooooojZZZ_l0003ojNWY00;ooooo00?olo?c
oda<C?lQ8B400_ooool03?n2PX;o92@Tochn?_l_;boo0000odi>C_n<S8co820PobPX:?l>3PkoATI6
on3Ph0;ooooo01kom?Cdoh20P?l<30co7AdMobPX:?lD51CoJ6QXooCdm?ooooook^k^oeaLG?lT92Co
F5QHocHf=_lD51Co1PH6oi>CToogmoOooooooc`l??l0003o4a<CocXj>_oNg]ko^k^koadM7OlC4a?o
3`l?obh^;_oAdM47ooooo`0Coo_knonXZ:So8B4Qo`P82?l];Bgo7QhNog=cLolR8R;oIVIVooOgmooo
ooooPX:2oa@D5?mKFe_o>SXjoahN7_l30`?oKfm_ong]k@02ooooo`09onSXj?mKFe_o1`L7oa`L7?l`
<33o:RXZog5aLOl@413o`/;200Sooooo00SoTi>CoadM7OlB4Q;o:2PXobXZ:_mCDe?o2@T9ogEeM@;o
oooo01[o820PobTY:Om0@43o9RHVoe5ADOooooooo?clok:b/_lS8b?o1PH6ob`/;?lN7QkoK6a/obHV
9_mPH63olO7aoooooomnOWko0000ohV9ROlP823o;bl_oaPH6?l410CoIFEUon[ZjP;ooooo00OoZ:RX
o`L71omEEEGo;2`/ob<S8ol51@GoPh>300?ooooo00?oG5aLobPX:?oQhN400_ooool03oo2`/;o@D51
oaHF5_lZ:R[o8B4QobHV9_nYZJWooooooo[jn_n5QHGo7AdMoa0@4?lG5aOo^[Zjoogmo@3ooooooggo
oooo003ooooool;ooooo00Oob/[:ohR8R?mlO7co[Jf]oo3`l?mmOGgo5QHF00Cooooo00Gob<S8ohZ:
R_mkNg_oVYZJom[JfP05ooooo`0:omKFe_nEUIGoO7aloiVIVOoCdm?ono_koooooooKfm_oR8R8ooKf
mP;ooooo00?on_[jok:b/_nPX:000_ooool02ooBd];o`/;2omOGeon<S8coR8R8onCTi?oooooo_[jn
ogalO?nCTi?ogMgM00Cooooo00Gono_kokZj^_n2PX;oP820okFe]@03ooooo`08ooShn?o2`/;oaLG5
onKVi_n?ShooOgmoojj^[_okno/2ooooo`0:ohJ6Q_l0003oBDU9ohJ6Q_o_knoooooool;2`_moOgoo
TY:BomgMg@[ooooo013obl_;ohZ:R_mlO7coX:2Pookno_o1`L7oaLG5ooclo?ooooooclo?ok>c/ood
m?CoVi^KoginO_nQXJ7ok^k^1?ooool02?oalO7oZJVYoginO_n9RHWobl_;omSHf?l10@7o`/;22Ooo
ool01oo;bl_oPX:2oh20P?nk^k_ol_;boj2PX?o2`/800_ooool01OnKVi_oaLG5ol[:b_mmOGgoYJFU
00?ooooo017oc/k>ohb<S?mlO7coWinOoo[jn_o5aLGo`l?3oo[jn_oooooob<S8ohb<S?oooooo`L71
ohB4Q?n0P83o[jn_ooShn003ooooo`07ojRXZ?l0003okno_oiVIVOmmOGgoYJFUoo?cl`03ooooo`03
okbl_?nVYZKol_;b00?ooooo00Koj>SXojFUYOmlO7coShn?olK6a_ofm_H2ooooo`04ooKfm_n][Jgo
PH61olW9bOooooooOoooool00?ooooooaoooool00omeMGGo5aLGooooo`10ooooo`03o`000?nOWioo
oooo02Wooooo00?ob/[:o`820_o2`/80;_ooool00onXZ:So0000ooGem@3ooooooiSooooo003ooooo
olOooooo00?oMGEeoaLG5oooool0@?ooool00ol0003oS8b<ooooo`0Yooooo`03ol[:b_l20P;o`/;2
02kooooo00?oZ:RXo`000?obl_801_ooool01?ojn_[oNWYjoc/k>oo@d=3oooooohkooooo003ooooo
olOooooo00?oMGEeoaLG5oooool0@?ooool00on9RHWoc<c<ooooo`0Yooooo`03ol[:b_l20P;o`/;2
02kooooo00?oZ:RXo`000?obl_801_ooool01?omoOgoGemOo`000?o5aLGoooooohkooooo003ooooo
olOooooo00?oMGEeoaLG5oooool0@?ooool00oohn?Soo?clooooo`0Yooooo`03ol[:b_l20P;o`/;2
02kooooo00?oZ:RXo`000?obl_801oooool00ooZj^[og=cLooShn03oooooohkooooo003oooooolOo
oooo00?oMGEeoaLG5oooool0K?ooool00oo:b/[o0P82ol;2`P0^ooooo`03ojRXZ?l0003ol_;b0?oo
ooooV?ooool00?ooooooaoooool00ombLW;o4Q8Booooo`1/ooooo`03olW9bOl0003o`L7102kooooo
00?oYZJVo`000?obl_80oooooonHooooo`00ooooooooooooooooooooooooool4ooooo`00oooooool
ooooo`03oo?clooUiNGooooo06?ooooo00?ol_;bonSXj?okno/08_ooool01?omoOgokNg]onSXj?on
o_koooooogOooooo003ooooooocooooo00?oQ8B4o`000?ooool0Hoooool00omkNg_o30`<omOGe`0R
ooooo`04oo;bl_mLG5co0`<3omWIfOooooooMoooool00?ooooooo?ooool00on>SXko0`<3ooooo`1S
ooooo`03ohJ6Q_lQ8B7of][J02?ooooo00Coe=CDo``<3?m`L73ooOgmoooooomfooooo`00oooooool
ooooo`03ohj>S_l30`?ooooo06?ooooo00?oQXJ6ob4Q8OoJf]X08oooool01?ogmoOoLg=coa@D5?oM
gMgoooooogKooooo003ooooooocooooo00?oSXj>o`<30oooool0Hoooool00on6QXKo8B4Qom[JfP0T
ooooo`03olG5aOl20P;oRh^;0?ooooooM_ooool00?ooooooa?ooool01_oBd];oX:2PogemOOmnOWko
Vi^Kolo?c`?ooooo00?oj>SXoi6ATOoEeMD01Oooool01OoOgmooUIFEog]kNon:RX[od=3@00Gooooo
00Ooh>3Poi2@T?mmOGgoXJ6Qon_[joo=cLgo_[jn00;ooooo00?ojNWYoi>CTooEeMD00oooool01_o[
jn_oXZ:RogalO?n3Ph?oaLG5ooknoPSooooo00SoSXj>o`<30ooooooo^[ZjohF5QOmnOWko[Jf]oo;b
lPCooooo00Gol?3`ojRXZ?mmOGgoPH61ol;2`P03ooooo`08olK6a_nMWIgok^k^olk>c_n8R8SoOGem
ojb/[?o[jn/3ooooo`07on;Rh_n;Rh_ohn?SoooooooXj>SoTI6AomWIf@04ooooo`05okbl_?n2PX;o
P820ojb/[?oZj^X01?ooool01onk^k_oPX:2oh20P?ne]KGoooooojb/[?oIfMT00_ooool00oo@d=3o
Ti>ConWYj@02ooooo`03oj2PX?nf][Kon_[j00?ooooo00Gofm_KoiZJV_mkNg_oRXZ:olS8b004oooo
o`03oiJFU_no_kooo_kn00;ooooo00?oj^[ZohR8R?oQhN402Oooool02?o?clooS8b<ogalO?nQXJ7o
m?Cdoi6ATOlP823of][J0_ooool01Oobl_;oZZZZoginO_moOgoo_kno00Gooooo00Oom?Cdoj>SXomm
OGgoS8b<omkNg_oMgMgo[Jf]00;ooooo00?oj^[ZohV9ROoQhN400_ooool00one]KGoXj>Soo?cl`02
ooooo`03ohb<S?o8b<Sooooo00;ooooo00ColO7aodi>C_lW9bOoi^KVoooooomeooooo`00ooooooo2
ooooo`06onOWiom_Kfoo6a/Kob<S8ol];Bgo;2`/0_lF5QH01_m_KfooinOWooooooo9bLWo0000oifM
W@Cooooo00Soc/k>oc8b<_l61PKo=SHfob@T9?lL71coR8R8ooKfmP;ooooo00So/;2`oc8b<_lB4Q;o
;Bd]oc0`<?li>CWoB4Q8odA4A0;ooooo00?oc<c<o`<30onMWId00_ooool02?oPh>3oADE5o`@41?la
<C7o:BTYoaPH6?mcLg?olO7a1oooool02On>SXko0@41oh:2P_lF5QKo=CDeob8R8_l<30coCTi>on3P
h002ooooo`07on[Zj_mFEUKo3Ph>obd];OlO7aoo5QHFoiZJVP02ooooo`09oh20P?l30`?oDE5Aobl_
;ol];Bgo:b/[o`P82?m0@43og]kN00;ooooo00Oo^k^ko`000?nm_KgoooooolW9bOl0003oYjNW00;o
oooo01;oo?clofMWIolA4A7o;2`/obXZ:_lB4Q;oFe]KooGemOooooool_;bogemOOl=3@go61PHocHf
=_lI6AWoOWino`l?3onLW9`2ooooo`03oi:BT_l30`?oc<c<00;ooooo00?o8b<SoeADE?oclo<00_oo
ool02?nTY:Co:RXZo`l?3olg=cOo7QhNoa8B4_mlO7colO7a0_ooool00ol;2`_oJVYZooclo002oooo
o`03olk>c_l0003o^KVi00Sooooo017oQhN7oahN7_lC4a?o<C4aobl_;omGEeOoB4Q8obd];OoJf][o
ooooonk^k_mKFe_o3`l?ob`/;?lP823o51@Doi2@T003ooooo`08omOGeom9BDWo3`l?obPX:?l`<33o
;bl_oeeMGOl=3@d2ooooo`03olk>c_l0003o^KVi00;ooooo00?oDU9BobTY:OoTi>@00_ooool00ol0
003oOWinooooo`03ooooo`03ojb/[?l0003oTY:B0?ooooooMOooool00?oooooo`Oooool03ooEeMGo
?cloo`P82?meMGGo`<30omgMgOoLg=co_KfmoginO_m0@43o];Bdooooooo=cLgo4Q8BojBTY004oooo
o`0BocPh>?lK6a_o^;Rhon?Shoo@d=3oFEUIo`000?n>SXkoooooonGUiOlU9BGo;2`/ok^k^ooMgMgo
a<C4oc`l??l51@Go?Shn0_ooool00oo@d=3o5QHFojBTY002ooooo`08oeEEEOl;2`_oXZ:Ron3Ph?oG
emOoNWYjo`000?mYJFT7ooooo`0Mohj>S_l0003o9RHVojZZZ_oLg=coe]KFohn?Sol:2P[oK6a/oo;b
l_ooooooWIfMo`000?nUYJGogMgMom7AdOmMGEgo6a/KonKVi_ooooooT92@o`000?lK6a_oTY:BomKF
e_oLg=coZJVYo`d=3Om4A4@00_ooool01oo0`<3o1PH6ol;2`_oooooocLg=oa8B4_n^[Zh00_ooool0
4_mbLW;o2@T9oibLW?oJf][ofMWIoifMWOmLG5cofm_KoooooonEUIGo0000of][Joo>c/koh>3Pojn_
[ol];Bgo0000oifMW@;ooooo00?oVYZJoaHF5_o@d=000_ooool04_lc<c?oHF5QooCdm?oooooofMWI
o`l?3oll?3co^[ZjonCTi?o=cLgoKFe]o`820_n?ShoooOgmoooooolM7AgoMGEeooclo0;ooooo00?o
d];Bo`000?nn_[h01oooool07Oo>c/ko0P82od];Boo5aLGoh>3PolO7aomVIVKo0000ocLg=ooJf][o
ooooojNWYol0003oWYjNomcLg?oCdm?oHV9Roa4A4OoTi>Cooooooo;bl_mPH63o1PH6oiVIVOoJf][o
eMGEofATI?l92@Wo000000;ooooo00?od];Bo`820_nn_[h00_ooool00omOGeoo>CTionKViP02oooo
o`03o`L71on8R8Sooooo00;ooooo00GooOgmoiBDU?l0003oC4a<ono_k`3oooooogCooooo003ooooo
ol3ooooo00Golo?cod];BolA4A7o]KFeoo_kn`04ooooo`07ookno_oEeMGoeMGEooooooo=cLgo4Q8B
ojBTY003ooooo`03okJf]_l0003oc<c<00?ooooo00Oojn_[oj2PX?o?cloooooooiBDU?l@413oalO7
00?ooooo00?oeMGEo`d=3Oln?Sh00_ooool01oo@d=3o5QHFojBTY?ooooooclo?o`<30on_[jl00ooo
ool00oojn_[oXj>Sokno_`07ooooo`03ohj>S_l10@7oZJVY00?ooooo00GooOgmogMgMolG5aOob/[:
ooooo`02odI6AP0:oo_knoooooooooooomSHf?l0003o_;bloooooon@T93o0000ohN7Q`Cooooo00oo
WinOo`000?o?cloooooool30`?l61PKo`/;2ooooooo=cLgo4Q8Bojj^[_oooooof][Jo`L71on<S8`0
1?ooool01_oXj>SomOGeonk^k_lm?CgoA4A4on_[j`?ooooo00?o^;Rho`410OnNWYh00_ooool00onJ
VY[o5QHFom3@d002ooooo`07oc<c<omQHF7om?Cdoooooom^KVko5QHFonCTi003ooooo`08ooOgmomN
GUko;2`/omcLg?oooooo7AdMogEeMOolo?`2ooooo`03om;Bd_l0003o_[jn00Oooooo00?oIfMWo`h>
3_oZj^X00oooool02?o_knooD51@obPX:?oJf][ooooooeADE?m2@T;omoOg0_ooool02?oPh>3o0000
okNg]ooooooobLW9oa`L7?n0P83oo_kn0_ooool00ooclo?o>SXjo`000002ooooo`03om;Bd_l20P;o
_[jn00;ooooo00?oGemOocTi>OoVi^H00_ooool00ol71`OoR8R8ooooo`02ooooo`05on?Shol^;Rko
30`<oaXJ6_n/[:`0oooooomdooooo`00ooooooo0ooooo`03oiFEUOl?3`oo/;2`00Sooooo00Goo?cl
ooooooo=cLgo4Q8BojBTY003ooooo`03ohn?Sol20P;oiNGU00Cofm_K00Koe]KFonWYjOooooooDe=C
oclo?oo_knl3ooooo`03ooGemOm?Cdoo=3@d00;ooooo00Ood=3@oaHF5_nTY:Coooooojj^[_l0003o
cLg=00Cofm_K00?oemOGonCTi?omoOd01_ooool00on>SXko0`<3oo[jnP04ooooo`07ol71`OlE5AGo
YjNWoooooolU9BGoIfMWooOgm`02ooooo`07onGUiOl0003o]KFeoooooon:RX[o4Q8BolO7a`04oooo
o`0?ooShn?l0003oWYjNooooooo0`<3o1PH6ol;2`_oooooocLg=oa8B4_n^[Zkoooooojf][Ol0003o
l?3`00Kooooo00?oemOGoaTI6OnBTY801?ooool00oolo?co0000oijNWP02ooooo`03oiZJV_lF5QKo
d=3@00;ooooo00Ko<c<cof5QHOodm?CooooooaHF5_mhN7P5ooooo`07okRh^?lD51Co^;RhoooooolM
7AgoMGEeooclo002ooooo`03om;Bd_l0003o_[jn00Oooooo00?o8B4QofIVI_ooool01?ooool01on4
Q8Co820Pom[Jf_oooooo=3@dof5QHOodm?@00_ooool01oo]kNgo0000ok2`/?ooooooYjNWoaXJ6_o3
`l<01?ooool01on>SXko0000ooooooooooood];Bo`820_nn_[h00_ooool00omOGeoo>CTionKViP02
ooooo`0;o`L71on8R8Sooooooooooookno_oUYJFoa0@4?nHV9So@d=3ode=COoZj^X0oooooomcoooo
o`00oooooonoooooo`04oogmoOm<C4coAdM7ong]k@[ooooo00?ocLg=oa8B4_nTY:@00oooool00on;
Rh_o0000o`H61P03o`<30`07o`L71olE5AGoK6a/oooooom8B4SoG5aLoo;blP03ooooo`03ooGemOmO
Geoo<S8b00;ooooo00Ood=3@oaHF5_nTY:CoooooojZZZ_l<30co1PH600?o0`<300Co1@D5oa<C4omA
DE7ok>c/1_ooool00on>SXko0`<3ooooo`04ooooo`07omKFe_lR8R;oWinOoooooolT92CoJ6QXooOg
m`02ooooo`07on?Shol0003o][Jfoooooon6QXKo8b<Som[JfP05ooooo`0=o`000?nFUYKooooool30
`?l61PKo`/;2ooooooo=cLgo4Q8Bojj^[_ooooooYJFUo`000007ooooo`03om;Bd_lD51CoWYjN00Go
oooo00Oo30`<oifMWOoooooooooooiZJV_lF5QKod=3@00;ooooo00Ko<c<cof5QHOodm?CooooooaPH
6?n?Shl5ooooo`07olG5aOlQ8B7o]kNgoooooolM7AgoNGUiooclo002ooooo`03om;Bd_l0003o_[jn
00Oooooo00?o4a<Coi2@T?ooool01?ooool01onATI7o:RXZomWIfOoooooo<c<cof5QHOodm?@00_oo
ool01oo[jn_o0000ok6a/OooooooWinOobHV9_oFe]H01?ooool01onNWYko0000ooooooooooood];B
o`820_nn_[h00_ooool00omOGeoo>CTionKViP02ooooo`0;o`L71on8R8SooooooooooooVi^Ko9RHV
odU9BOohn?SoSXj>o`D51Oo3`l<0oooooomcooooo`00oooooonoooooo`04om;Bd_lH61SoUiNGookn
oP[ooooo00?ocLg=oa8B4_nWYjL00oooool00on/[:co0@41onOWi`03oo;blP07ol_;bolN7QkoI6AT
oooooomiNGWo7alOonSXj003ooooo`03oo?clol`<33o>3Ph00;ooooo00Sod=3@oaHF5_nTY:Cooooo
olS8b?l0003oc<c<oo?cl`;ol_;b00CogmoOocTi>Oll?3coo_kn1_ooool00on>SXko0@41omSHf004
ooooo`07ojJVY_lH61So^[ZjoooooolT92CoJ6QXooOgm`02ooooo`07on?Shol0003o][Jfoooooon<
S8co0P82ok:b/P04ooooo`0?olk>c_l0003o][Jfooooooo0`<3o1PH6ol;2`_oooooocLg=oa8B4_n^
[ZkoooooolC4a?l0003o_[jn00Kooooo00Coi>CTobTY:OmiNGWooOgm0oooool00ooTi>Co0@41oijN
WP02ooooo`03oiZJV_lF5QKod=3@00;ooooo00Ko<c<cof5QHOodm?CoooooodU9BOlf=SH5ooooo`07
ohb<S?lK6a_ocLg=oooooolR8R;oB4Q8ooclo002ooooo`03omGEeOl0003o_Kfm00Oooooo00?oBDU9
obTY:Oooool01?ooool01omfMWKo92@Tom[Jf_oooooo<c<cof5QHOodm?@00_ooool01oo[jn_o0000
ok6a/Ooooooo^[ZjoaLG5onVYZH01?ooool01om]KFgo0000ooooooooooood];Bo`820_nn_[h00_oo
ool00omOGeoo>CTionKViP02ooooo`0<o`L71on8R8Sooooooo[jn_nDU9Co20P8okZj^_ooooooe]KF
oalO7omKFe_okno_oooooombooooo`00oooooonoooooo`03om3@d?lF5QKoVYZJ00_ooooo00CocLg=
oa/K6omQHF7ol_;b0_ooool00ooclo?o3@d=od=3@`02ooooo`0>oo[jn_miNGWo1PH6ojf][Ooooooo
b<S8o`l?3omjNW[on?Shooooooojn_[oPX:2o`000?m2@T82ooooo`03om3@d?lF5QKoY:BT00;ooooo
00So9BDUobTY:Oo^k^kooooooo_knonQXJ7o0P82ohf=S@Oooooo00?oSXj>o`000?m:BTX00oooool0
2?oJf][o<30`od92@_oTi>Coooooob@T9?mXJ6SomoOg0_ooool02?oShn?o0000okJf]_ooooooTI6A
o`000?m1@D7oh>3P0_ooool03?omoOgo?Shnoa4A4Oolo?cooooool30`?l61PKo`/;2ooooooo=cLgo
4Q8Bojj^[P;ooooo00?o<S8bobh^;_oclo<00_ooool01ooWinOoUIFEom_KfoooooooJf][o`@41?ng
]kL00oooool00omEEEGo0`<3oijNWP02ooooo`03oiZJV_lF5QKod=3@00;ooooo00Oo<c<cof5QHOod
m?CooooookFe]Ol0003oPh>300?ooooo00go`L71o`l?3omRHV;omOGeoooooolX:2So0@41onSXj?oo
oooon_[joi>CTol;2`_obl_;00Oooooo00?oY:BTo`000?nDU9@00oooool02?n/[:co0000oc@d=?oJ
f][ooooooc<c<omQHF7om?Cd0_ooool01Oo[jn_o0000ok6a/Oooooooi>CT00;o>SXj00Koi>CToooo
oooooooo/k>co`/;2ol00002ooooo`03om;Bd_l20P;o_[jn00;ooooo00?oGemOocTi>OoVi^H00_oo
ool01_l71`OoR8R8oooooooWinOo8B4QodA4A0?ooooo00?oKFe]o`000?o>c/h0oooooombooooo`00
oooooonoooooo`04om;Bd_lH61SoUiNGooknoP[ooooo00oocLg=obXZ:_l10@7oK6a/ocHf=_oFe]Ko
oooooijNW_l51@Go;2`/ohJ6Q_m=CDgo0P82ofi^K_okno/00_ooool05ombLW;o0P82od51@OmlO7co
EUIFo`@41?l];Bgo?clooooooooYjNWoNGUio`@41?m:BT[oY:BTooclo?ni^KWo3@d=oaXJ6_n1PH7o
GUiNo`820_m@D53on?Sh00Oooooo00WoSXj>o`000?lk>c_o61PHogemOOmUIFGo2@T9oa`L7?o5aLD0
0_ooool00olS8b?oJ6QXooOgm`02ooooo`0=on?Shol0003o][Jfoooooon<S8co20P8oaTI6OlP823o
L71`ogYjN_lE5AGo1PH6ojBTY002ooooo`07ol30`?l61PKo`/;2ooooooo=cLgo4A4Aojj^[P02oooo
o`0LonCTi?lN7Qko3@d=ogEeMOmdM7Co820Poc<c<oo/k>coooooom_Kfolg=cOo0`<3oeYJF_n4Q8Co
8R8Roc/k>ol71`OoWYjNoooooooShn?o?Shno`T92OmJFU[o][Jfoooooole=CGoHF5QooCdm0;ooooo
00SoLG5ao`820_lc<c?oS8b<oeYJF_l0003o>CTiomWIf@;ooooo00Oo:RXZoa@D5?lL71coOgmooemO
Gol0003oC4a<00Wooooo00goHF5Qo`000?lh>3SoQ8B4oeEEEOlT92Co71`LocDe=OoJf][ooooooc8b
<_mQHF7om?Cd00;ooooo00?ojn_[o`000?na/K400_ooool02?n^[Zko1`L7obDU9OmeMGGoKfm_o`X:
2_lh>3So0`<30_ooool00ooBd];o0P82okjn_P02ooooo`0;oemOGolh>3Soi^KVoooooonHV9So10@4
ocdm?On0P83oNGUio`P82?nn_[h00oooool01?o<c<co51@DogalO?ogmoOoooooog7ooooo003ooooo
okoooooo00CooOgmoda<C?m7AdOokNg]2_ooool03OoDe=Co>SXjoh^;Rom;Bd_o7AdMojb/[?omoOgo
oooookJf]_lk>c_o5QHFoclo?onf][H01Oooool05?nZZZ[o=3@doaLG5omCDe?of][JoiRHV?n3Ph?o
ooooom_Kfom7AdOo0`<3o`l?3omWIfOokNg]ooooooo<c<coD51@oaHF5_ld=3CoX:2P2Oooool02?nM
WIgo9BDUoooooon9RHWo92@ToaXJ6_mRHV;ogmoO0oooool00om1@D7oO7alooShn002ooooo`0<onOW
iolR8R;o`<30oooooon5QHGo:BTYolg=cOnLW9co:BTYoaLG5omQHF7oc<c<0oooool01oo0`<3o1PH6
ol;2`_ooooooe=CDoc8b<_ni^KT00oooool01_oemOGoOGemob0P8?lL71coHV9Rolg=c@?ooooo01;o
j^[ZogAdM?lN7Qko7AdMog9bL_ooooooGemOokJf]_oooooo`/;2o`l?3ol20P;o4a<CogMgMooooooo
DU9BogIfM_oemOD3ooooo`06ok6a/Om5ADGo5ADEob/[:on?Shoolo?c0oooool01omeMGGo[:b/ojBT
Y?ld=3Co6QXJof][Joo[jn/02_ooool03?nJVY[o;bl_oaHF5_mCDe?of=SHol71`Om^KVkoh^;Roooo
oom>CTkoMWIfooGem@;ooooo00?ok^k^ob8R8_nk^k/00oooool01oo@d=3oC4a<oaLG5ol`<33oaLG5
okNg]omQHF400_ooool00ooBd];o0P82okjn_P02ooooo`0:ogEeMOmDE5CojNWYoooooole=CGo0@41
o``<3?lF5QKo5aLGodU9B@Gooooo00?oHV9Robl_;ooTi>@0oooooomaooooo`00ooooooo0ooooo`03
oiFEUOl?3`oo[jn_00Sooooo00?oo?clooooooooool06_ooool00ooOgmoo61PHokBd]00Uooooo`03
ohJ6Q_lP823of][J00Sooooo00?o`<30o`H61_o2`/806_ooool00onYZJWo61PHonGUi@0oooooo`03
om;Bd_l20P;o_[jn00Oooooo00?o20P8oiJFU_ooool0oooooomkooooo`00ooooooo0ooooo`05oo?c
lom?Cdoo4a<CokBd]?okno/01?ooool00oono_koeMGEomGEe@0Looooo`03olo?col?3`ooXJ6Q02Go
oooo00?oQXJ6ob4Q8OoGemL02?ooool02?o0`<3o1PH6ol;2`_oooooofm_KoiNGUoo@d=3oo_kn5Ooo
ool02?nGUiOo3`l?olo?cooooooono_kojFUYOnWYjOon?Sh>_ooool02?oBd];o0P82okjn__oooooo
oOgmokBd]?nOWiookNg]0_ooool00ol0003oQ8B4ooooo`3oooooog_ooooo003ooooool7ooooo00_o
gmoOod92@_l>3PkoMGEeol30`?oMgMgog=cLokfm_OmnOWko?cloojn_[`0Looooo`03om_Kfom?Cdoo
^k^k02Gooooo00?oQXJ6ob4Q8OoGemL02?ooool02?o0`<3o1PH6ol;2`_ooooooQHF5o`000?n6QXKo
o?cl5Oooool02?nc/k?oCdm?om_Kfooooooom_KfoadM7Ol0003oinOW>_ooool02?oBd];o0P82okjn
__oooooono_kodA4A?l0003o`l?30_ooool00om4A4CoY:BTooooo`3oooooog_ooooo003ooooool;o
oooo00[oiNGUogYjN_lK6a_o8b<Sobd];Ol/;2co5aLGoa@D5?mTI6Cog]kN7?ooool00oojn_[okNg]
ooShn00Uooooo`03ohJ6Q_lQ8B7oemOG00Sooooo00Oo`<30o`H61_o2`/;oooooom7AdOmkNg_oeMGE
01Kooooo00?omoOgong]kOojn_X00_ooool00onOWiooTi>CooKfmP0jooooo`03om;Bd_l20P;o_[jn
00;ooooo00?o/k>cohF5QOoYjNT00_ooool00oo/k>com?Cdooooo`3oooooog_ooooo003oooooolCo
oooo00Ooclo?oiVIVOmcLg?oM7AdoiBDU?o9bLWooOgm04Gooooo00?oQXJ6ob4Q8OoGemL02?ooool0
0oo0`<3o1PH6ol;2`P1Looooo`03om;Bd_l20P;o_[jn0?ooooooQOooool00?oooooooooooolAoooo
o`03ogUiNOl92@Wodm?C00Sooooo00?o^KVio`000?nk^k/0G?ooool00oo=cLgo0000okNg]`3ooooo
ohGooooo003ooooooooooooo4Oooool00ooHf=So]kNgoo;blP08ooooo`03on[Zj_n^[Zkojn_[05co
oooo00?ol?3`ojb/[?oZj^X0oooooon5ooooo`00ooooooooooooooooooooooooool4ooooo`00oooo
ooooooooooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00oooooooooooo
ooooooooooooool4ooooo`00ooooooooooooooooooooooooool4ooooo`00ooooooo0ooooo`05ooCi
noo[loSok?Cion_cn?omo_h02_ooool01ookoOkoloSkonkenOo/m?WokOGioo;gnoohnod01Oooool0
0ooenOcojo?honcdn@04oncdn@03oo;gnoohnogooooo00;ooooo00?omo[lon_cn?o/m?T01Oo/m?T0
1_oamo[oo_ooon_cn?o/m?Wojo?hoo?hn`?ooooo00OonognooCio?o^mO[ok?CiongenOocn?_oo?gn
00?ooooo00Gon?_mon_cn?o/m?Wojo?hooWlo@04ooooo`0=ooknooo[loSok?Cion_cnOobmo_ooooo
ooKio?o[loSok?Cion_cn?okoOkoooooongdn@02oncdn@03onoen_oooooooooo00Cooooo00?oo?gn
onoen_o/m?T00_o/m?T5ooooo`07ooSkoOobmo_ok_Gion_cnOo]mOWoloSkoo[lo@3oooooom3ooooo
003ooooool3ooooo00GoIZC=o`1EX_l0H:Oo04nOon?_mP09ooooo`09onccnOnQan7oAI33o`Y^[ol0
H:Oo0VR/ocB7_Omj/=Coh>ge00Cooooo00?oKjW@o`1EX_l0H:L01?l0H:L00olgR;koO[?EonC`m`02
ooooo`03oh^kfOl0DIoo062W00Co062W01;o05jVocZ:_oofn_co05>Po`1PYol0F:?oDiW7oooooool
o_koj?7hoio6h?mCVLOo3Fn`o`1PYol1J:_oAI32ojk?iOodn?/2ooooo`05oiG0g?l0Cioo062Wo`1>
WOn`d>D01?ooool04?obmo_o05BQo`1PYol0FJCoBYC3oooooomi/=Co05>Po`1PYol0CYgobn3^oooo
ool0Ijco062Wo`1OYolFMK<6ooooo`05ok?Biol>L;3o05jVo`1PYol0G:D00oooool02_oinogod^C`
ogbbe?lgRKgo0fV]o`1LYOl2JJco?Hc0ohnmf_oSkoKooooooloooooo003ooooool3ooooo00GoLZ_A
o`1RZOl7K:ko05fVonG`m`08ooooo`04om_Ylom1Sl7o066Xo`1VZ`?o0VV/00Co06R/o`1SZOlFMK?o
aMg/0oooool03_mj/=Co06:Yo`M/[_l7KJko06R/o`1WZol2JJco06R/o`1SZ_l`Q;_oio7goooooonD
`=co05jV0_l7K:h03ol2JJco06R/o`5X[?l0IZ_oA932ooOjo?l0H:Oo1fb^o`1UZ_mPXL_oooooon[c
n?lnSKoo05fUo`1UZP02o`1X[00;o`9Y[Ol0Ij_o06F[ogB]d_odn?_ooooooig5gol0GJKo1fb^o`1L
YOnfe>L01?ooool04?ocn?_o066Xo`M/[_l0IZ_oF9c8oooooon3]]Oo062Wo`M/[_l0G:Gocn;_oooo
oolCLk;o1fb^o`I[[_lXP;T5ooooo`03omWYlolQO;Oo06N[00;o1fb^00oo0VV/ooooooooooool?Kj
ohZifOl7K:ko05nWo`1VZol0Ij_o0FR/o`1X[?l0IZ_o05jWobQo^Oo5g>`0ooooooo>ooooo`00oooo
ooo0ooooo`05og:[dOl0HZWo1fb^o`1MY_oUl?L01oooool03OoenOcoGIo:o`1OYol6Jjko0FR/oaMf
/olXOkWo7GZeo`1X[?l7K:ko06R[obQo^?oYlOL00_ooool0;?mj/=Co06:Yo`M/[_l5Ij_oAY72oe2G
a_lXOkWo1V^]o`I[[_l9KZooN:oCoooooonD`=co05jVo`M/[_l5JJco;8:joc^;_oliR[ko=XRmoffY
d?oenO_o062Wo`M/[_l0IJ[oH:7;ooooooocn?_oHj?<o`1VZol9KJoo:82ioc^;_olHM[Co1fb^o`A[
[Ol;KZooZLcSoooooonMaMoo05fVo`M/[_l0G:Go]]CW1?ooool04?ocn?_o066Xo`M/[_l0IZ_oF9c8
oooooon3]]Oo062Wo`M/[_l0G:Gocn;_oooooolCLk;o1fb^o`I[[_lXP;T4ooooo`03onC_m_m2Sl7o
06JZ00?o1fb^013o0VV/oooooookoOkoMJkCo`1LY_l1JJco0fZ]oaEd/oldQkgo?8^ooc64^ol=L;3o
1fb^o`1VZolFMK?og>[dooooooo=ooooo`00ooooooo0ooooo`05og:[dOl0HZWo1fb^o`1LYOodnO`0
1oooool03Oo9gngo9gnio`5WZol5JZgo67FcoiC0g?o3fn_o[LoTobf3^_l4JZgo1F^]oaEd/onJ`ml0
0_ooool06_mj/=Co06:Yo`M/[_l0FZCom_Wlooooooo:gnko0FN[o`M/[_l0IZ_o>h^ooooooonD`=co
05jVo`M/[_l0GJKo[/oUongdnOoYl_Ooj?;honkenOo]m?Wo062Wo`M/[_l0IJ[oH:7;0_ooool04?oB
iO3o@Ho1og6[dOo5g>cokOCiojC:hOl4JZco1Vb^o`Q/[_mLWl[ooooooig5gol0GJKo1fb^o`1LYOnf
e>L4ooooo`0@oo?hnol0HJSo1fb^o`1VZomHW<Sooooooh>feol0H:Oo1fb^o`1LYOo?h^oooooooa=c
/_l7K:ko1V^^obR0^@?ooooo00ColOOkof:Rc?l0Ij_o1Fb]0ol7K:h01?l2JJcoooooolONkOl0HZP2
o`E[[@0;oc>6_?nK`moogncdoo[loOoXlOOoVL?NoaIe/ol7K:ko0VV/od:@`Oohnod0ooooooo<oooo
o`00ooooooo0ooooo`05og:[dOl0HZWo1fb^o`=TZ_mn/mD00_n<^mT00on/cNCognceooooo`02oooo
o`05ojc>i?l:Kk3o0fZ/o`1QZ?mi/=@00oooool01OnednOo06J[o`M[[_l7K:koJJK>00;ooooo017o
N[3Do`1RZOl7K:ko05^Too7fn_ooooooj_;ho`1VZol7K:ko0fV]oe>IaoooooooU<3Lo`1NY_l7K:ko
05bUolCLk004ooooo`05oncdnOl0H:Oo1fb^o`1UZ_mPXL/00oooool00ooDiO7oooooooooo`02oooo
o`0:o`9Y[?l7K:ko06R[ocN8_OooooooWLGOo`1MY_l7K:ko05^TolGMk0Gooooo00oo062Wo`M/[_l0
IZ_oF9c8oooooon3]]Oo062Wo`M/[_l0G:Gocn;_oooooolCLk;o1fb^o`I[[_lXP;T00_ooool00ooi
nogoQ[SHo`Y][P02o`=Y[@0:o`I[[Ol7K:ko1fb^o`9Y[?ooooooHZ;<o`1TZOl3JZgo87ZfokSDi`;o
oooo00So^mOYoi6mf_nOa^3o6WNdo`I[[_l7K:ko1F^]olCMk?ooooooc?ooool00?oooooo`?ooool0
1OmbZm7o06:Yo`M/[_l8KJoo062X00;o05nW00?o4W:aodRB`on_d>D00_ooool01_nJa=ko06>Yo`I/
[_l0GJKo^MKYookoo`;ooooo00GolOKjo`1TZOl7K:ko06JZod^Da002ooooo`0AogZ`e?l0HZWo1fb^
o`AUZ_m[YlooN[3DodB@`_l4JZgo06JZo`U][onUb^;ooooooiC0g?l0GZKo1fb^o`1LYOnofNX01?oo
ool01Oo/m?Wo062Wo`M/[_l0IJ[oH:7;00Gooooo00gol?Kjol7Kj_mSXlgo1F^^o`M/[_l3JZcoAY;3
oooooonMaMoo05fVo`M/[_l4IJ[oF9c800CoN[3D013oMJgBo`AWZol7K:ko06J[oeRLb?ooooooPkKG
o`1PYol7K:ko05bUoloRkooooooo4g>bo`M/[_l6Jjko:82i0_ooool01_n^cnCo4fn_o`5WZol2JJgo
5GBco`a_/0;o1fb^00Oo0VV/oooooolXPKWo0VV/o`1XZom8Tl?on?_l00;ooooo00CoDYW6o`1HXol0
GjOo16Z]0_l7K:h00ol<KjooPkKGooooo`3ooooool_ooooo003ooooool3ooooo017oLZ_Ao`1RZOl7
K:ko26f_o`1RZ?l0H:So06N[o`=Z[Ol0IZ[o;X>jomcZm?ooooooTkoLo`1NYol7K:ko05bUol[PkP03
ooooo`05oo_lo_l0I:Wo1fb^o`1WZom@UlH00_ooool04Omj/=Co06:Yo`M/[_l8KJoo06>Yo`1QZ?l0
IZ[o2Vj_odF@`_n<^mWomOWloooooonD`=co05jVo`M/[_l0G:Go_mWZ00Cooooo00Gok?Cio`1PYol7
K:ko06FZof2Qb`03ooooo`0?onOamon7]mOoBiG4obV1^Ol0I:[o1fb^o`E[[_l7K:koRk[IoooooonM
aMoo05fVo`M/[_l8KJoo06BZ00Co066X023o06:Xo`Q][_l7K:ko06J[oeRLb?ooooooPkKGo`1PYol7
K:ko05bUoloRkooooooo4g>bo`M/[_l6Jjko:H2iooooooo6g^go9Wjgo`1TZ_l5Jjgo06N[oiS2g_lc
Q[co16Z]o`M/[_l2JJcoo_ooo`=UZ_l6K:ko06N[oeVMb0?ooooo00?oCiO5o`1DXOl0G:D00ol0G:D0
0ol0GZKoDiW7ooooo`3ooooool_ooooo003ooooool3ooooo017oLZ_Ao`1RZOl7K:ko0VFZogB]dOn5
]mKo<HFlo`AZ[Ol5Jjko4G:boiS2g_ooooooU<3Lo`1OYol7K:ko05bUolONk@03ooooo`05ooWkoOl0
I:Wo1fb^o`1WZom@UlH00_ooool01?mj/=Co06:Yo`M/[_l8KZl2o`1NYP03o`E[[Ol:KZooHj;<00?o
oooo00GoU<3Lo`1NY_l7K:ko05bUokoIjP04ooooo`05oncdnOl0H:Oo1fb^o`1UZ_mPXL/00_ooool0
4?oOk?GoEi_8o`EZ[Ol0IZ_o0FV/o`E[[_l0IJ[o06>YoenPb_o]m?Wooooooig5gol0GJKo1fb^o`Q^
[ol0H:P5o`1LY@0Po`Q][ol7K:ko06J[oeRLb?ooooooPkKGo`1PYol7K:ko05bUoloRkooooooo4g>b
o`M/[_l6Jjko:h6jooSkoOlhR[ko06FZo`M/[ol0HZSoEY_8oo[lo_m4T<;o0VV/o`M/[_l2JJcooooo
o`Q[[_l5Jjko06R/odjFaOonool2ooooo`08om7Tl?ndd^Ko]]CWok[Fj?nge>Oo]]CWokOEj?o@ho3o
ooooolcooooo003ooooool3ooooo017oLZ_Ao`1RZOl7K:ko05jVomg[m?ohnococ^;_o`1UZ_l7K:ko
0fZ]oeZMbOooooooU<3Lo`1OYol7K:ko05bUolONk@03ooooo`05ooWkoOl0I:Wo1fb^o`1WZom@UlH0
0_ooool02_mj/=Co06:Yo`M/[_l2H:Oo/M7VojW<hol?LK3o1fb^oaii]_ncd^H2ooooo`05oiC0g?l0
GZKo1fb^o`1LYOnofNX01?ooool01Oo/m?Wo062Wo`M/[_l0IJ[oH:7;00;ooooo00WoTKkKo`U^/?l3
JJgo26f^o`1TZ_l0IZ[oAi;2oi_4g_oYl_P00_ooool01OnMaMoo05fVo`M/[_l2H:OoS[cJ00Coamk]
00go_]SZo`9SZOl7K:ko06J[oeRLb?ooooooPkKGo`1PYol7K:ko05bUoloRkooooooo4g>b00;o1fb^
01;o6GNdogN^dol0Ij_o1fb^o`1QZ?lfR;goe>KaooooooloSL3o0VV/o`M/[_l2JJcoooooocJ8_Ol1
J:co0FV/ocB7_OoIjO?oooooomKooooo003ooooool3ooooo00GoLZ_Ao`1RZOl7K:ko05fVonKam`02
ooooo`0:o`1TZOl7K:ko06R/odnGa_ooooooU<3Lo`1OYol7K:ko05bUolONk@?ooooo00GonO_mo`1T
ZOl7K:ko06N[oe2GaP02ooooo`0:ogZ`e?l0HZWo1fb^o`1LYOoRkOGoo_kood>?`_l4JZgo1fb^oe6H
a@;ooooo00GoU<3Lo`1NY_l7K:ko05bUokoIjP04ooooo`05oncdnOl0H:Oo1fb^o`1UZ_mPXL/00_oo
ool02?m[Yloo06BYo`M/[_l1Ij_oGZ3:olgQkoo]m?Woo?gn0oooool01OnMaMoo05fVo`M/[_l0G:Go
^MKX00Cooooo00gomo[lo`1QZ?l7K:ko06J[oeRLb?ooooooPkKGo`1PYol7K:ko05bUoloRkooooooo
4g>b00;o1fb^01;o26f^o`m`/?l6Jjko06J[obQn^Oo2fn_oo_koooooooloSL3o0VV/o`M/[_l2JJco
ooooofNUcOl0IZ[o1F^^o`Y^/?nA_]/5ooooo`03ocJ8__mg[m;om?Sk0?ooooooc_ooool00?oooooo
`?ooool04OmbZm7o06:Yo`M/[_l0GJKoj?;hooooooohnogo06BZo`M/[_l0IjcoCIG5oooooonD`=co
05nWo`M/[_l0G:Goamk]00?ooooo00GonO_mo`1TZOl7K:ko06N[oe2GaP02ooooo`07ogZ`e?l0HZWo
1fb^o`1LYOoNjoCoooooodbEa@02o`AZ[@08ocR9__oooooooooooiC0g?l0GZKo1fb^o`1LYOnofNX4
ooooo`05oncdnOl0H:Oo1fb^o`1UZ_mPXL/00_ooool01OmWYLgo06:Yo`M/[_l0GZKoiO3g00;ooooo
00Woo?cnoooooooooooooooooig5gol0GJKo1fb^o`1LYOnfe>L01?ooool03Oocn?_o066Xo`M/[_l0
IZ_oF9c8oooooon3]]Oo062Wo`M/[_l0G:Gocn;_oooooolCLk801?l7K:h01?l2JJco6GJcojc>i?om
o_h2ooooo`0;ocn=`?l2JJco1fb^o`9Y[?ooooooc>7_o`1LYOl7K:ko0FV/ob^2^_o8gnd00oooool0
1OmbZm3o2fj_o`a_/?lGM[?oSKcJ0?oooooocOooool00?oooooo`?ooool04OmbZm7o06:Yo`M/[_l0
HJSo[m3UolSNk?mOX<_o0VV/o`I[[_l>LK7oPkGGoooooonD`=co05nWo`M/[_l0G:Goamk]00?ooooo
00GonO_mo`1TZOl7K:ko06N[oe2GaP02ooooo`0:ogZ`e?l0HZWo1fb^o`1LYOoXl_SodnG`oaYg]?l6
K:ko16Z]ocF8_@;ooooo00GoU<3Lo`1NY_l7K:ko05bUokoIjP04ooooo`05oncdnOl0H:Oo1fb^o`1U
Z_mPXL/00_ooool02On;^]So2fj_o`E[[Ol0Ij_oGj3;ol;Kjon=^m[o=HRmomWYlP02ooooo`05oig5
gol0GJKo1fb^o`1LYOnfe>L01?ooool03Oocn?_o066Xo`M/[_l0IZ_oF9c8oooooon3]]Oo062Wo`M/
[_l0G:Gocn;_oooooolCLk800ol7K:h01?l5Jjgo2fj_ogZ_doomo_h3ooooo`0Cocn=`?l2JJco1fb^
o`9Y[?oooooolOOkoeNKb?l0IJ[o1fb^o`I[[OlBLk7oJJK>oj;7hOm?U/Ko3Fn`o`I/[_l7K:ko1F^]
ojC9hP3oooooolgooooo003ooooool3ooooo017oLZ_Ao`1RZOl7K:ko1fb^o`1X[?l0Ijco16Z]o`M/
[_l5Jjgo9WjiolkRl?ooooooU<3Lo`1OYol7K:ko05bUolONk@03ooooo`05ooWkoOl0I:Wo1fb^o`1W
Zom@UlH00_ooool01?mj/=Co06:Yo`M/[_l7KJh2o`1WZ`04o`I/[_l7K:ko3W2`ohVif0;ooooo00Go
U<3Lo`1NY_l7K:ko05bUokoIjP04ooooo`05oncdnOl0H:Oo1fb^o`1UZ_mPXL/00_ooool04?oHj??o
>HVno`=Y[?l7K:ko16Z]o`1X[?l2JJco2Vj_ofBScOomo_kooooooig5gol0GJKo1fb^o`1LYOnfe>L4
ooooo`0=oo?hnol0HJSo1fb^o`1VZomHW<Sooooooh>feol0H:Oo1fb^o`1LYOo?h^oooooooa=c/P03
o`M/[P03o`I[[_mMW/[ooooo00Cooooo00Co?hg0o`9Y[?l7K:ko0VV/0_ooool03?oWl?Oo8gbgo`A[
[Ol6Jjko1Vb^o`=Z[Ol1J:co16Z]o`M/[_l6Jjko1V^]ofFScOooooooc_ooool00?oooooo`?ooool0
0omaZ]7o062Xo`AZ[@04o`AZ[@03o`e`/?lQNkOoU/7M00;ooooo00GoTkoLo`1MY_l4JZgo05ZTolKN
k@03ooooo`05ooWkoOl0HZSo16Z]o`1UZ_m>U/D00_ooool00omi[mCo062Xo`AZ[@03o`AZ[@04o`I/
[_l?LK3o;8:jonK`mP;ooooo00GoTkoLo`1LYOl4JZgo05ZTokkIjP04ooooo`05oncdnOl0GZKo16Z]
o`1SZOmNX<X00oooool03onhe>So:X6jo`Y^[ol5Jjgo16Z]o`]^[olAL[7o<HFkon3]m?ooooooW<CO
o`1KYOl4JZgo05ZTokGDi`04ooooo`0=oo?hnol0GjOo16Z]o`1TZ_mFVlOooooooh:eeol0GZKo16Z]
o`1JY?o?h^oooooooa5b/@03o`AZ[@03odBA`_oooooooooo00Cooooo00Co?Hboo`1WZol4JZgo06N[
0oooool02ooXl_SoGZ3:o`m^[ol?LK7o1fb^o`AZ[Ol8K:ko3W2`oa5a/?mb[=3on_cn0?ooooooc_oo
ool00?oooooo`?ooool00on9^MWo:Wbgoc24^`04oc24^`03ogJ^d_o<hNoooooo00;ooooo00GoY/[R
obYi]Ol`Q;_o:WNdom3Sl003ooooo`05oo[loOlZOKOo<8BkobZ0^Om]Z<l00_ooool00on@_M_o:Wbg
oc24^`02oc24^`04obn3^oloSL3oPkGFonC_mP?ooooo00GoY/[RobYh]Ol`Q;_o:WNdolWOk@04oooo
o`05onofn_lZN[Go<8BkobYn^?mj/=@01?ooool01ooGio;oL:W@oc>6_?l_Pk_oHJ7;ojS<h_odn?/0
0_ooool01On]c^Co:WReoc24^olZMkCo`]_[00Cooooo017omOWlobYk]_l`Q;_o:Wniog>/dOoooooo
Ul;NobYj]Ol`Q;_o:WNdomOWl_oooooo>XZooc24^ol_Pk_o@Hk1omWYl`06ooooo`04oejPb_l[P[[o
<8Bkob^2^PGooooo00Oo_]WZohFgeom6TL?o:Gjhod^DaOmm/]Cob^7^0?ooooood?ooool00?oooooo
oooooooooooooooooooo1?ooool00?oooooooooooooooooooooooooo1?ooool00?oooooooooooooo
oooooooooooo1?ooool00?oooooooooooooooooooooooooo1?ooool00?oooooooooooooooooooooo
oooo1?ooool00?oooooooooooooooooooooooooo1?ooool00?oooooooooooooooooooooooooo1?oo
ool00?oooooooooooooooooooooooooo1?ooool00?oooooooooooooooooooooooooo1?ooool00?oo
oooooooooooooooooooooooo1?ooool00?oooooooooooooooooooooooooo1?ooool00?ooooooiooo
ool2oocmo_oooooooooooolJooooo`00oooooooWooooo`03okcGjOnXbn?oo?gn0?oooooooooooolI
ooooo`00oooooooVooooo`04oocmo_n0/mKo9GjiomSXl_oooooooooooolIooooo`00oooooooVoooo
o`04on3/mOllS;oo06>YojG9hOoooooooooooolIooooo`00oooooooVooooo`05okKDiol8JJco05nV
oejQbooamoX0oooooooooooooaSooooo003oooooonGooooo00Kom_WlogR_dol0GZOo0VZ]oa1`/?o0
f^_ooooooooooooo6?ooool00?ooooooiOooool01ooIj??o8Gbgo`9W[?l7K:ko062WohZjfOojo?d0
oooooooooooooaOooooo003oooooonCooooo00SooOkoojW;hol0H:Oo1Vb^o`M/[_l1IZ_o;XBlon3/
mOoooooooooooolGooooo`00oooooooTooooo`03ongenOmGWLWo06>Y00;o1fb^00Co1F^^o`1RZ?nW
b^;ooOknoooooooooooooaKooooo003oooooonCooooo00?od>?`o`aVZol5Jjd00ol7K:h00ol0HjWo
DY[8oncdn@3ooooooooooooo5_ooool00?oooooohoooool00oojnogoS[gKo`1PY`04o`M/[P03o`I[
[_l8HjWoc^?`0?oooooooooooolFooooo`00oooooooSooooo`03onofn_lSOKOo0FR[00Go1fb^00?o
06:YofjXcooenO`0oooooooooooooaGooooo003oooooon;ooooo00?ooOknok_GjOl1H:L01_l7K:h0
0ol4JZgo2fn`on_cn@3ooooooooooooo5Oooool00?ooooooh_ooool00oohnogoFYg9o`1VZP07o`M/
[P03o`1RZ?nF`Mgoo?gn0?oooooooooooolDooooo`00oooooooRooooo`03ongenOl0Ij_o1F^]00Oo
1fb^00?o0FR[ocJ8_?oenO/0oooooooooooooaCooooo003oooooon;ooooo00?oT;kKo`1UZ_l7K:h0
1ol7K:h00ol8K:ko062Wol7Kj`3ooooooooooooo5?ooool00?oooooohOooool00ookoOko;hBjo`9Z
[@09o`M/[P03o`5X[?m8T/?ooooo0?oooooooooooolCooooo`00oooooooQooooo`03ol_Pk_l0HZWo
26b^00[o1fb^00?o06N/onWbn?ooool0oooooooooooooa;ooooo003oooooon7ooooo00?oHJ7;o`=Z
[Ol7K:h02_l7K:h00ol1J:coL:[Aooooo`3ooooooooooooo4_ooool00?ooooooh?ooool00ooamo_o
36n`o`M/[P0;o`M/[P03o`I/[_lEM;;onOcm0?oooooooooooolBooooo`00oooooooPooooo`03oj;8
hOl4JZgo1fb^00co1fb^00?o0fZ]oj_=i?ooool0oooooooooooooa7ooooo003oooooon3ooooo00?o
?hg1o`M/[_l7K:h03Ol7K:h00olnSL7oooooooooo`3ooooooooooooo4?ooool00?oooooogoooool0
0ooJj_?o5GFco`M/[P0>o`M/[P03oaEd/_o@ho3ooooo0?ooooooooooool@ooooo`00oooooooOoooo
o`03ofjYd?l;K[3o1fb^00ko1fb^00?o2Fj^oefPb_ooool0oooooooooooooa3ooooo003oooooomoo
oooo00?o:X6io`I[[_l7K:h03_l7K:h00ol6Jjko97fhonccn@3ooooooooooooo4?ooool00?oooooo
g_ooool00onYcN?o5GBco`I/[P0@o`M/[P03oa5b/On9^MSooooo0?ooooooooooool?ooooo`00oooo
oooNooooo`03oefOb_l8K:ko1fb^013o1fb^00?o16Z]oc:6_Oooool0ooooooooooooo`oooooo002h
ooooo`03oo_knooclo?oo?cl01[ooooo00Koo?clooGemOobl_;olo?cooShn?ono_koooooo`;ooooo
00?oe^ObobQo^Ol4JZd04Ol7K:h00ol5Jjgo6WNdojk?i03ooooooooooooo3oooool00;Sooooo00?o
/[:bo`000?o5aLD06Oooool02?ohn?SoXj>SobTY:Ol0003o0P82odi>C_o4a<Cono_kooooool1oooo
o`03oh>fe_l>LK7o1V^^01;o1fb^00?o1F^]oefOb_okoOh0ooooooooooooo`kooooo002hooooo`03
okNg]ol=3@gobLW901Sooooo00[oo?cloiRHV?l10@7oE5ADojJVY_nBTY;o8b<So`000?o7alOoo_kn
o_ooool00oohnogo?hk0o`1VZP0Co`M/[P03o`9X[OlSO;Ooamk]0?ooooooooooool>ooooo`00^?oo
ool00ong]kOo3@d=olW9b@0Hooooo`03om[Jf_lX:2SoG5aL00?ooooo00CoinOWoadM7OmFEUKon?Sh
o_ooool00on`cnGo7GVeo`=Z[@0Ao`M/[P05o`E[[Ol0J:co2fj_od>?`_ngeNP0ooooooooooooo`ko
oooo002hooooo`03okNg]ol=3@gob/[:01Sooooo00?oclo?oe1@D?o@d=001?ooool00omgMgOo7alO
ooGem@3nooooo`03of>Rc?l0Ij_o1fb^00oo1fb^00Ko1V^^o`1WZol8KJoo?hg0oh>feoo`m_[ooooo
oooooooo3oooool004cooooo00?ol_;bojZZZ_o<c<`00_ooool03?n[Zj_o`L71ooclo?oooooooOgm
oiZJV_oQhN7oj^[ZojVYZOn@T93oY:BTomgMg@?ooooo00?ofm_KoiZJV_ooool01Oooool02ooMgMgo
YJFUoi2@T?nYZJWoj>SXonKVi_nh^;Sono_kookno_o8b<SoXj>S00Gooooo00?o_;blokJf]_ofm_H0
0oooool01OoHf=SoWYjNoi6ATOn][Jgoh^;R00Cooooo00Coa/K6oi:BT_nLW9coiNGU2Oooool02?on
o_kod];BoiRHV?n@T93o^KVioo;bl_oJf][o`<300_ooool00ooCdm?oYJFUonk^kP02ooooo`03on3P
h?nJVY[omoOg00?ooooo00Soj>SXojn_[on@T93oWYjNomgMgOo_knoo_[jnonc/k0Oooooo00So]kNg
oa0@4?o<c<cog=cLoijNW_n@T93o/K6aonSXj0;ooooo00?oo_knolS8b?nVYZH01_ooool01OoMgMgo
Zj^[oi6ATOnOWiooalO700?ooooo00konOWionc/k?oLg=coYJFUoi2@T?nYZJWojNWYojj^[_l10@7o
l_;booooooogmoOoVYZJomoOg`Gooooo00colO7aok:b/_nATI7oW9bLolg=cOoooooo^;Rhon7QhOoo
oooom?Cdojj^[_o4a<@2ooooo`03onCTi?nJVY[olO7a00;ooooo00?on_[joiZJV_oOgml00_ooool0
1Oodm?Co/[:boi2@T?nNWYkogmoO0=Oooooo00?oh^kfocN9__l0IZ/03_l7K:h01_l6Jjko06JZo`1X
[?lmS<3oQ[OHonSamooooooooooooolAooooo`00C?ooool00ooJf][o4a<Cog5aL@02ooooo`08oaLG
5omBDU;om_Kfooooooohn?So0000of1PH?m2@T82obHV9P07o`d=3Ol`<33o[jn_oogmoOooooooVYZJ
o`000004ooooo`04oo[jn_nXZ:So<30`o``<30;o9RHV00Oo?cloofIVI_l>3Pkolo?cooclo?mXJ6So
0@4100Gooooo00?oATI6ocDe=OoWinL00_ooool01onIVIWo:2PXoaLG5olR8R;o61PHocLg=oo4a<@0
0_ooool01_nSXj?o5aLGoaXJ6_l<30coAdM7ooKfmPOooooo00Wolo?coh>3PolL71co4a<Cob<S8olZ
:R[oBTY:oeYJF_lZ:RX00_ooool00on6QXKo1`L7om3@d002ooooo`03ojZZZ_l0003ojNWY00;ooooo
00WobLW9od=3@ol:2P[o8b<SobDU9Oli>CWoHV9RoaDE5Onn_[h01oooool03Oni^KWo2@T9ofEUIOli
>CWo9BDUob<S8ol92@Wo@d=3olW9bOooooooo?clofQXJ?l820P01Oooool00onZZZ[o;Rh^oa`L7002
ob8R8P08oaPH6?mlO7coooooooooooolo?co/[:boc@d=?l<30`2obHV9P08od51@OmZJV[o0000oo;b
l_oooooojNWYo`000?nUYJD4ooooo`04omCDe?mBDU;o3Ph>oa`L70;o:RXZ00OoSXj>oa8B4_nVYZKo
ooooon3Ph?lP823oFe]K00;ooooo00?o];Bdo`000?oHf=P00_ooool02ooalO7o0000ojFUYOoooooo
hn?SoeUIFOl@413o8b<So`D51Olk>c_ofm_K0=Kooooo00?oW<COo`]][ol4Jjd03?l7K:h01_l5Jjgo
06BYo`1SZOloS/7oS[cKomo/mOoooooooooooolCooooo`00C?ooool00ooMgMgo9bLWogemO@02oooo
o`0Aob/[:omQHF7omoOgoooooooinOWo0000oa4A4OmCDe?o`<30om_Kfonc/k?o=SHfoaXJ6_o>c/ko
oooooj>SXol000001?ooool03Oo?cloo51@DocHf=_na/K7ofm_Kol30`?mQHF7o410@o`000?obl_;o
o?clogEeMOlG5aL01Oooool05?mFEUKoATI6onWYjOoooooof=SHo`D51Om7AdOo`L71omOGeon^[Zko
<C4aoaHF5_oFe]Kon?ShobTY:Om@D53od=3@ok^k^ol0003oZZZZ1oooool02OnEUIGo0000oeaLG?o4
a<CofMWIok6a/Olj>S[o2PX:oa`L7002ooooo`03oi2@T?lL71coe=CD00;ooooo00ko/K6ao`000?o[
jn_ooooooo?clol`<33o5ADEojBTY?oIfMWobl_;ogQhN?lH61So0000ok^k^`Oooooo00go_Kfmo`00
0?lC4a?oMGEeol_;booIfMWoXZ:RoaDE5Ol`<33on?Shooclo?meMGGo7AdM00Cooooo01So`<30o`/;
2om9BDWo]KFeomOGeoo7alOoP820o`000?n3Ph?oooooom3@d?lG5aOo<S8bok6a/OoKfm_o`<30oeMG
EolA4A7o0000oo;bl_oooooojn_[o`000?n][Jd3ooooo`0>ono_kom@D53o3`l?oiBDU?oCdm?odM7A
oi:BT_l?3`oo0`<3ojNWYooooooohn?Soc<c<omYJFT2ooooo`03okZj^_l0003ofm_K00;ooooo00co
l_;bo`000?n][JgooooookJf]_lJ6Q[oO7alomWIfOne]KGo3`l?ogYjN_ohn?SDooooo`03oo?ho?mS
X/co06BZ00co1fb^00Go16^]o`I[[_m5TL;oT[oLom[Yl`3ooooooooooooo5Oooool004cooooo00?o
gMgMobLW9ommOGd00_ooool02?l[:b_oHF5QooOgmooooooonOWio`000?l/;2cok^k^0oooool01_o>
c/ko4Q8BogemOOooooooYJFUo`0000?ooooo00Con?ShohF5QOlC4a?oc/k>0oooool01oofm_Ko=cLg
o`000?obl_;oo?clogEeMOlG5aL01Oooool01omFEUKoATI6onWYjOooooooM7AdoaDE5Oo^k^h00ooo
ool01_o=cLgoPX:2onWYjOojn_[o^KVionSXj0;ooooo00?o1`L7ogUiNOooool01Oooool01?o`l?3o
>CTioclo?oo/k>`3ooooo`03omkNg_l92@Wo820P00;ooooo00?oT92@oa`L7?oDe=@00_ooool01ona
/K7o0000on_[jooooooo^KVio`000?nYZJT01?ooool00om]KFgo0000okbl_007ooooo`04okbl_?l0
003oHV9Rooclo0?ooooo00KoZJVYo`000?no_kooo_knogEeMOlM7Ad3ooooo`04oo7alOm?Cdoo=CDe
on7Qh@Cooooo00KoLG5ao`d=3OoGemOoP820oa4A4Oo:b/X3ooooo`08oo3`l?lb<S;o0000oo;bl_oo
oooojn_[o`000?n][Jd3ooooo`03okFe]Ol92@WoSHf=00Cooooo00OoUYJFo`<30onXZ:Soooooon?S
holc<c?oJFUY00;ooooo00?o^[Zjo`000?oKfm/00_ooool01oobl_;o0000ojf][OooooooinOWol[:
b_ofm_H00_ooool00ol_;booCDe=oo;blP3Dooooo`03olCLk?lTO[So0FR/00co1fb^00?o06BYoeZM
b_oIj?80oooooooooooooaOooooo001<ooooo`03omgMgOlW9bOoOGem00;ooooo00Oo:b/[of5QHOog
moOoooooooWinOl0003oQ8B400Cooooo00Koo_knodI6A_m;Bd_on_[jojFUYOl00003ooooo`04ong]
kOmBDU;oATI6ooknoPCooooo00KoUYJFo`000?obl_;oo?clogEeMOlG5aL5ooooo`07oeIFE_m6ATKo
jNWYoooooolJ6Q[oHF5QonOWi`03on7Qh@03omoOgooIfMWolO7a00?ooooo00CogmoOofa/K?l0003o
`l?31_ooool00ooDe=Co5ADEoiZJVP05ooooo`07of5QHOlI6AWooooooooooon@T93o71`LomCDe002
ooooo`07ok6a/Ol0003ojn_[oooooon2PX;o3`l?oo[jnP04ooooo`03okjn__l:2P[o^;Rh00Oooooo
00?o^KVio`@41?nb/[801?ooool01_ojn_[o3`l?ohR8R?ooooooMGEeoadM7@?ooooo00?of=SHoalO
7onATI401Oooool01_oWinOo0000oijNW_mKFe_o?ShnooknoPCooooo00OoRXZ:o`000?obl_;ooooo
on_[jol0003o[Jf]00?ooooo00?oOWinob<S8ooDe=@01?ooool01oogmoOo0000ojRXZ?oooooohn?S
oc<c<omYJFT00_ooool00onj^[[o0000om_Kf`02ooooo`03oo;bl_l0003o[Jf]00Cooooo00GogMgM
ofQXJ?l0003oTI6Aoo_kn`3Dooooo`03ohZjfOl3I:[o1Vb^00co1fb^00?o066Xoh6ee_oloOd0oooo
oooooooooaOooooo001<ooooo`03omgMgOlW9bOoOGem00;ooooo00Oo:b/[of5QHOogmoOoooooooWi
nOl0003o[jn_00Gooooo00GoDE5Aod92@_ogmoOoYJFUo`000003ooooo`03on_[jom9BDWoDE5A00Go
oooo00Ko/K6ao`000?obl_;oo?clogEeMOlG5aL5ooooo`06oeIFE_m6ATKojNWYoooooolI6AWo410@
1?l92@T02_lA4A7o8R8RoiNGUoooooooo_knogYjN_lC4a?o0000ohN7Qookno/6ooooo`03olg=cOl?
3`ooZj^[00Cooooo00?oo?cloginO_lF5QH00_ooool00on@T93o7alOomOGe`02ooooo`06ok>c/ol0
003ojn_[oooooomhN7So4Q8B1Oooool00oo?cloo3`l?okNg]`07ooooo`03okNg]ol=3@goc/k>00Go
oooo00Go4Q8BogmoOoooooooMGEeoadM7@03ooooo`03om;Bd_lI6AWoXJ6Q00Gooooo00Goo?clo`00
0?nCTi?oEeMGodQ8B005ooooo`07okBd]?l0003ol_;booooooo[jn_o0000ok:b/P03ooooo`03ofm_
Kolo?coohn?S00Cooooo00OooOgmo`/;2onWYjOoooooon?Sholc<c?oJVYZ00;ooooo00?o^k^ko`00
0?oKfm/00_ooool00oobl_;o0000ojf][@02ooooo`06ong]kOmRHV;o4A4Ao`P82?mlO7cok>c/e?oo
ool00ooSk_KoCIG4o`1TZ@0=o`M/[P03o`1QZ?mm/]Gomo[l0?oooooooooooolGooooo`00C?ooool0
0ooMgMgo9bLWogemO@02ooooo`07ob/[:omQHF7omoOgoooooooinOWo0000ofYZJP04ooooo`06ooOg
mold=3CoFe]Kookno_nUYJGo00000oooool01?oalO7oHf=Soc@d=?ogmoL4ooooo`06ogQhN?l0003o
l_;booclo?meMGGo61PH1Oooool01omFEUKoATI6onWYjOooooooATI6ob/[:ooRh^800_oJf]X02_oL
g=coXj>So`@41?nLW9cooooooinOWol71`OoM7Adom_KfooinOT7ooooo`04omoOgolQ8B7oOGemoo_k
n`Cooooo00Oo?clooa/K6ooooooooooooi>CTol410Co_kno00;ooooo00OoYjNWoa@D5?o]kNgooooo
oiBDU?l92@WoinOW00Cooooo00?oZJVYo`820_ni^KT01oooool00onj^[[o0P82oj2PX004ooooo`06
onOWiol:2P[oRXZ:ookno_meMGGo7QhN0oooool01?oRh^;o:b/[ogEeMOomoOd4ooooo`06okBd]?l1
0@7o/k>cofe]KOl];Bgom_Kf1?ooool01omaLG7o0000oo;bl_oooooojn_[o`000?n9RHT00oooool0
0onDU9Co3Ph>olC4a004ooooo`07on[Zj_l10@7oZ:RXoooooooShn?o<c<cofEUI@02ooooo`03ok>c
/ol0003ohn?S00;ooooo00[on?Sho`000?n/[:coooooon_[jomKFe_o2@T9ohJ6Q_oQhN7on?SheOoo
ool00onfe>So26j_o`=Y[@0=o`M/[P03o`1QZ?mm/]Gomo[l0?oooooooooooolGooooo`00C?ooool0
0ooMgMgo9bLWogemO@02ooooo`08ob/[:omQHF7omoOgoooooooinOWo0000oaHF5_nl_;`3ooooo`07
oi6ATOl0003oY:BToooooonTY:Co0000okFe]@02ooooo`04ookno_n[Zj_o0000oi6AT@?ooooo00So
clo?oaXJ6_l0003ol_;booclo?mfMWKo2`/;omSHf0Cooooo00OoEUIFodI6A_oYjNWooooooj:RX_l0
003oZj^[00;ooooo00[ol?3`odm?ColP823oe]KFoooooom>CTko?Cdmonc/k?o[jn_omOGe1oooool0
1?ono_koG5aLo`T92Oo8b<P3ooooo`03oijNW_l0003o8R8R00;ooooo00?oVIVIo`000?n>SXh00_oo
ool01omVIVKo;2`/oo7alOoooooog]kNo`000?mNGUh00oooool01?oTi>Co@410o`000?nm_Kd7oooo
o`04okfm_Ol0003o=SHfomkNgP?ooooo00OoGUiNo`000?oShn?ooOgmogIfM_l>3Pkof=SH00;ooooo
00Coo_knoh20P?l20P;o[Zj^0oooool01oo/k>co820Poc0`<?olo?co[:b/o`000?n9RHT00oooool0
2?o1`L7o6QXJo`000?obl_;oooooon_[jol0003oDE5A0oooool01?oDe=Co820Podi>C_obl_82oooo
o`0Iooclo?lf=SKo1`L7ojRXZ?oooooohn?SocTi>Ole=CGoiNGUoooooomkNg_o0000ohF5QOono_ko
oooookRh^?l0003o^;RhoooooooOgmoo;2`/og9bL_ooooooh^;Ron_[j`3Dooooo`03oo?ho?m[Yloo
06:X00Co1fb^00?o1F^]o`=Z[Ol7K:h01ol7K:h00ol0HJSoOK;EooOjo03ooooooooooooo5oooool0
04cooooo00?ogMgMobLW9ommOGd00_ooool08ol[:b_oHF5QooOgmooooooonOWio`000?l^;Rko20P8
of=SHon@T93oAdM7o`000?mFEUKojNWYoooooonSXj?o2@T9oa4A4On9RHWoEEEEooooooo]kNgoEUIF
o`000?m4A4CoT92@of=SHol92@Wo;Rh^o`000?obl_;oo?clogMgMol0003o<30`00;oNGUi0_ooool0
0omFEUKoATI6onWYj@02ooooo`07ocTi>Ol10@7oHF5Qoh>3PolX:2So10@4oiFEU@02ooooo`05ojJV
Y_lE5AGoJFUYobh^;_lZ:RX02?ooool02OoBd];o:RXZo`000?mUIFGoS8b<odY:B_l0003o<C4aoahN
7P02ooooo`0CoiVIVOl0003o4A4AofYZJ_mbLW;o0`<3of][JoogmoOooooooo[jn_n2PX;o0000obd]
;On<S8coM7AdoaLG5olM7Ago0000ok^k^`07ooooo`13ok^k^ol0003o7AdMoaTI6OmdM7CoS8b<obTY
:Ol0003oTY:BoogmoOolo?coMgMgo`000?l`<33oNGUiogmoOooooooon?Shoe5ADOl0003oCdm?ohR8
R?m^KVko4a<CoaXJ6_oOgmoooooooo3`l?mXJ6So0000odA4A?n@T93oHf=So`T92Ol/;2co0000oo;b
l_oooooojn_[o`000?lK6a_oGUiNohR8R?nk^k_oooooohV9ROl0003o7AdMogemOOn0P83o92@Toc8b
<_l71`OoZ:RXoooooooShn?oA4A4o`000?m<C4coLG5aoa4A4Ol/;2co0000ofe]KOn8R8So2`/;obPX
:002ooooo`07ooCdm?mNGUko30`<og5aLOla<C7o410@omSHf03Cooooo`03omKWl_l^Pk_o06N[00?o
1fb^00?o0FR/ocV:__mVYLd02?l7K:h00ol0HJSoOK;EooOjo03ooooooooooooo5oooool004cooooo
00?ogMgMobLW9ommOGd00_ooool03Olk>c_oKFe]ooShn?oooooonOWio`000?nVYZKo_;bloc/k>ol;
2`_o;Rh^oj2PX?ogmoL00_ooool06onZZZ[o51@DojVYZOlF5QKo=CDeom[Jf_oooooomoOgoj2PX?l`
<33o2`/;ocTi>Oo6a/Ko^[Zjoe5ADOofm_Koo?cloh20P?lN7QkoV9RHo`d=3OmEEEGojn_[oooooomS
Hf?oE5ADon_[j`02ooooo`06oogmoOnDU9Co92@To``<3?m;Bd_ob/[:1?ooool01?nTY:Co5QHFochn
?_o@d=09ooooo`08onWYjOn7QhOo6ATIo`/;2omJFU[ogMgMoibLW?mVIVH2ooooo`07okJf]_m^KVko
Z:RXod10@?l>3PkoI6ATooOgm`04ooooo`08okJf]_m4A4Co2`/;obHV9_nTY:Co_[jnoa<C4ong]kL7
ooooo`08okbl_?lU9BGo`/;2oj2PX?lV9RKo2`/;odM7Aonf][H2ooooo`07ooclo?n0P83o8R8RoiRH
V?l=3@goFUYJon_[j`02ooooo`06oj2PX?lo?coo3@d=obPX:?mcLg?ol_;b0oooool04?ohn?SoXj>S
oc0`<?l;2`_o>c/kokZj^_n`/;3o51@Doo?cloooooookNg]oa@D5?nUYJGoG5aLo``<3?nQXJ42oooo
o`0EolC4a?m:BT[o30`<ob<S8onBTY;on?Shoe9BD_nh^;SoooooonOWiomdM7CoOWinofm_KolA4A7o
FUYJoooooonc/k?o=cLgo``<3?ll?3cobl_;00?ooooo00KoinOWofQXJ?l=3@go>SXjokZj^_ojn_[B
ooooo`0:ooknoonQb>3o05^Uo`I/[_l7K:ko2Vj_ocF7__n`dNGooooooiO1g@So1fb^00?o066Xogfb
eOogn_`0oooooooooooooaOooooo001<ooooo`03omgMgOlW9bOoOGem00Kooooo00?onOWio`000?nY
ZJT0E_ooool00oo;bl_o3@d=okNg]`3oooooobKooooo00Koio7god^Da?l0I:Wo476aocR9_on/c^@3
ooooo`03oiBofol7K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`0oooooooooooooaOooooo001<oooo
o`0<omgMgOlW9bOoOGemooooooolo?co[Jf]okJf]_okno_oooooooWinOl0003oZ:RX7oooool01?om
oOgo^k^kok2`/?obl_8cooooo`03olW9bOl=3@go]kNg0?oooooo9Oooool01Oono_ooa]g]o`ma/Oll
S;ooY<WQ00Gooooo00?oU;oKo`M/[_l7K:h01_l7K:h00ol0HJSoOK;EooOjo03ooooooooooooo5ooo
ool004cooooo00cogMgMobLW9ommOGgoooooooCdm?lG5aOo0000ong]kOoooooonOWio`000?nXZ:PO
ooooo`04ooWinOll?3co0000ol_;bc?ooooo00?obLW9o`d=3Ong]kL0oooooolUooooo`03oo_mo_nl
en[oSkgK00Oooooo00?oU;oKo`M/[_l7K:h01_l7K:h00ol0HJSoOK;EooOjo03ooooooooooooo5ooo
ool004cooooo00?ogMgMobLW9ommOGd00_ooool01on?ShooQHF5ooOgmooooooonOWio`000?nXZ:P0
8?ooool00onUYJGoNg]konWYj@0cooooo`03olW9bOl=3@go]kNg0?oooooo;oooool00onD_m_o1fb^
o`M/[P06o`M/[P03o`1QZ?mm/]Gomo[l0?oooooooooooolGooooo`00C?ooool00ooMgMgo9bLWogem
O@06ooooo`03ooWinOl0003oZ:RX05Kooooo00?obLW9o`d=3Ong]kL0ooooool_ooooo`03oiBofol7
K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`0oooooooooooooaOooooo001<ooooo`03om[Jf_lB4Q;o
L71`00Kooooo00?on?Sho`000?nOWil0E_ooool00oo4a<Co0000ok2`/03ooooooboooooo00?oU;oK
o`M/[_l7K:h01_l7K:h00ol0HJSoOK;EooOjo03ooooooooooooo5oooool004cooooo00?ol_;bojZZ
Z_o<c<`01_ooool00oomoOgoVYZJomgMg@1Fooooo`03on[Zj_nOWioohn?S0?oooooo;oooool00onD
_m_o1fb^o`M/[P06o`M/[P03o`1QZ?mm/]Gomo[l0?oooooooooooolGooooo`00oooooooPooooo`03
oiBofol7K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`0oooooooooooooaOooooo001aooooo`04ooSh
n?n0P83oDE5AooGemBWooooo00KooOgmoj>SXom3@d?o:RXZoe9BD_ne]KDhooooo`06omKFe_m`L73o
:b/[oc@d=?n8R8Sojn_[5oooool00on?Shoo?Shnom?Cd`3Sooooo`03oiBofol7K:ko1fb^00Ko1fb^
00?o066XogfbeOogn_`0oooooooooooooaOooooo001aooooo`04ookno_ng]kOo0000oiRHV2Sooooo
00WojNWYoeMGEol30`?oADE5ofm_Kolf=SKo20P8oiZJV_omoOd0=Oooool02?n/[:co5QHFoalO7omV
IVKoF5QHoa4A4Olm?Cgoi>CT5_ooool00oo<c<co0000oh:2PP0dooooo`03onSXj?nOWioooooo0:co
oooo00?oU;oKo`M/[_l7K:h01_l7K:h00ol0HJSoOK;EooOjo03ooooooooooooo5oooool007;ooooo
00CokNg]odI6A_l_;bookno_9oooool02_nPX:3o0`<3oijNW_o`l?3om_Kfong]kOm]KFgo2`/;omCD
e?ono_hdooooo`08oa`L7?m5ADGoj^[ZooGemOoclo?obLW9oaDE5OmEEEDFooooo`04ooOgmomMGEgo
7alOonc/k3?ooooo00?ofMWIo`/;2ooWinL0[?ooool00onD_m_o1fb^o`M/[P06o`M/[P03o`1QZ?mm
/]Gomo[l00Cooooo00?ohNSbooknooooool0oooooooooooooa3ooooo001cooooo`03ok2`/?l0003o
[:b/02Kooooo00CojNWYodI6A_m9BDWooOgm0oooool01?oZj^[o3@d=ohR8R?omoOdcooooo`03ojj^
[_l0003ogMgM00?ooooo00Con_[joh20P?lK6a_oe]KF5_ooool00ooBd];o0000oginOP0cooooo`03
oo7alOm4A4CoSXj>0:cooooo00?oU;oKo`M/[_l7K:h01_l7K:h02_l0HJSoOK;EooOjo?ooooool??i
om3Jjon^_mco[KoKok[8h_oaloWooooooooooooo4?ooool004cooooo00?oo_knoo[jn_oinOT01Ooi
nOT4ooooo`07oo_knooinOWonOWioo[jn_ono_koo?cloo_kn`03ooooo`04oo_knooinOWonOWioogm
o@?ooooo00Koo?cloo[jn_ono_kooooooogmoOoinOT4ooooo`04on;Rh_l_;boo?Shnoogmo@[ooooo
00Oono_koo[jn_ooooooooooookno_oinOWooOgm00?ooooo00Ooo?clooWinOoooooooooooogmoOoi
nOWoo_kn00?ooooo00_oo_knoo_knooinOWonOWioo_knoono_koooooooShn?o@d=3oeMGEooclo002
ooWin@08oo[jn_oooooo5aLGogEeMOolo?coooooooclo?ojn_X6ooooo`07oogmoOojn_[onOWioo[j
n_omoOgoo?cloo_kn`02ooooo`03oogmoOoinOWoo_kn00?ooooo00Koo_knoo[jn_oinOWonOWioo_k
noono_h8ooooo`03oogmoOoinOWooooo00?ooooo00Goo?clooWinOoinOWon_[jooclo002ooooo`04
onWYjOno_koono_koo[jnP;onOWi00Coo?clojn_[ol=3@gobLW90oooool02?ono_kono_kooWinOoi
nOWono_kooooooojn_[ooOgm0oooool01OomoOgon_[jooWinOojn_[oo?cl00?ooooo00ComOGeoemO
GolV9RKooOgm3?ooool01_omoOgon_[jooWinOoinOWono_kooknoP?ooooo00KooOgmoo[jn_oinOWo
nOWioo_knoono_h4ooooo`08ookno_okno_onOWiooWinOokno_ooooooo[jn_omoOd3ooooo`06ookn
o_okno_onOWiooWinOokno_oo_kn0_ooool01?ohn?SoO7aloahN7_omoOf[ooooo`03oiBofol7K:ko
1fb^00Ko1fb^00Ko0F6Xoh:ee_oSjoCo_/gSojbmf_n[_M/2ojbnf`04oj^nfona`]gog^Kaooknoooo
ooooooooool>ooooo`00C?ooool00ooKfm_o<C4ao`000005o`00000CooWinOooooooo_knomkNg_mE
EEGo0P82o`000?lg=cOo`l?3ofm_KomQHF7okNg]oooooooZj^[oEEEEo`L71olE5AGoRh^;oo[jnP02
ooooo`07of][JolW9bOog]kNoooooonSXj?o0000oo7al@04ooooo`03oifMWOl0003o[Jf]00Wooooo
00?okNg]od=3@oli>CT00_ooool00oo6a/Ko0000ok>c/`03ooooo`07oh61POl0003ooooooooooonc
/k?o0000olK6aP02ooooo`03ooclo?nm_Kgo>CTi00;o000000?oBTY:okBd]?ojn_X00_ooool03?oL
g=coGEeMo`<30ol0003o<c<com_KfolE5AGoMGEeooclo?oinOWoIfMWoa0@40Gooooo00Som_KfoifM
WOlK6a_o0000ob@T9?nGUiOoQhN7odQ8B0;ooooo00?oU9BDo`T92OoBd]800_ooool00ookno_o/[:b
oc<c<`02o`000003oe5ADOno_koono_k00Oooooo00?oWYjNo`000?oinOT00_ooool04_oZj^[oLW9b
o`X:2_l0003o5aLGogemOOoShn?oo_knooooooono_koXJ6QobDU9Ol0003o5ADEoh20P?nVYZKo4A4A
olW9b@;ooooo00Woo?clolS8b?lm?Cgo0000o`X:2_mKFe_of=SHoc4a<Ond];@00_ooool01oo`l?3o
T92@ob0P8?l0003o5QHFof9RH_o_knl00oooool00oo3`l?o0000oiJFUP0;ooooo`0AooKfm_nXZ:So
;Rh^o`000?l92@WoC4a<om?Cdoono_koooooooGemOnLW9co<S8bo`000?l20P;oCTi>ol30`?ojn_X0
0_ooool02Oolo?coc/k>od51@Ol0003o1@D5oeMGEooKfm_o<C4aok2`/002ooooo`08ooWinOn`/;3o
>c/ko`000?l:2P[o?3`lolg=cOono_h2ooooo`03om;Bd_l61PKo];Bd0:_ooooo00?oU;oKo`M/[_l7
K:h00_l7K:h02?l6K:ko26b^o`Y][_lHM;;o@X>johFUcOnW^]Wo[;gJ1_n/_]/00on[_M_ob=GXooOi
n`3ooooooooooooo3Oooool004cooooo00CogMgMobh^;_m=CDgo/K6a0onXZ:P05?nRXZ;ooOgmoooo
oooJf][o3@d=oaLG5on5QHGo[Zj^ofYZJ_lW9bOo0000odi>C_o/k>coooooodQ8B?l:2P[oW9bLoh:2
P_l71`OoWinO0_ooool01omcLg?o<c<con3Ph?ooooooZ:RXo`000?obl_800oooool01Oono_ko^k^k
o`000?mKFe_on_[j00Sooooo00?ok^k^ode=COm4A4@00_ooool00oo9bLWo3@d=okNg]`03ooooo`07
ohR8R?l71`Oooooooooooong]kOo3@d=olW9b@02ooooo`0FokBd]?l<30co:RXZoijNW_n/[:co>SXj
o`000?n?ShooooooomoOgolc<c?o2`/;oginO_ni^KWoGUiNobDU9Ol0003oMWIfooclo?oinOWoKfm_
oadM7@Cooooo00WonOWiofMWIol0003oG5aLojFUYOn:RX[o1`L7ob0P8?lJ6QX00_ooool00onJVY[o
5QHFomCDe002ooooo`03ojJVY_l410Co<S8b00;oYZJV00?o<S8bo`000?nOWil01oooool05onSXj?o
0000ooWinOooooool_;boeMGEol410CoJVYZokVi^OmhN7So1`L7ocTi>OoMgMgooooooi:BT_l0003o
@D51ojj^[_nHV9So;Bd]o`/;2olV9RKobLW900;ooooo01;o];Bdo`D51OlZ:R[oShn?ojVYZOlm?Cgo
7QhNo`X:2_n`/;3oooooong]kOm@D53o20P8og1`L?n`/;3oNGUio`h>3_nQXJ42ooooo`05ookno_oB
d];o1@D5oc4a<Oofm_H02Oooool09oohn?SoPH61o`000?mFEUKo[Zj^ohf=SOlG5aOoKfm_ooGemOok
no_oFEUIo`000?m6ATKo/;2`oiRHV?lU9BGo2@T9oinOWoono_kooooookVi^Ol<30co9RHVohf=SOn/
[:co@410ob4Q8Ol410Co[:b/ooooooolo?coTi>Co`000?m1@D7oXJ6Qoi^KVol^;Rko0000olO7a`02
ooooo`03oo3`l?miNGWo[Zj^0:_ooooo01;oU;oKo`M/[_l6K:ko1F^^o`a^[olCLK3o9GVdoeZ=`OmO
S/3oDXRmogjScOnY_=[o[KkKoj^mfon]_]_o/<7Mojo1g?n[_M/2ojbnf`04ojRkf_nibN;oj^ogoogm
o_ooooooooooool;ooooo`00C?ooool00ooMgMgo9RHVohB4Q006ooooo`04ooclo?mTI6Co3@d=omGE
e@?ooooo00Oo[:b/o`d=3Om>CTkokNg]oogmoOnATI7o/K6a00;ooooo00_oATI6od=3@ooooooooooo
og=cLolc<c?oh>3PoooooonXZ:So0000oo;blP03ooooo`05oo7alOmQHF7o0P82obPX:?o0`<002?oo
ool00oo^k^koCDe=odA4A002ooooo`03olW9bOl=3@go]kNg00?ooooo00coR8R8o`L71ooooooooooo
okNg]ol=3@gobLW9oooooooemOGo=cLgocPh>?oclo<3ooooo`06oe5ADOlj>S[oo?cloi>CTol20P;o
/;2`0oooool01on6QXKo0`<3ogIfM_olo?conOWiofm_KolM7Ad01?ooool00oo4a<Co4a<CogAdM003
ooooo`03ol30`?l51@Go8B4Q00;ooooo00SoVYZJoaHF5_oDe=CoooooooCdm?lS8b?oBDU9oo_kn`;o
oooo00?ooOgmod92@_m;Bd/01oooool01onSXj?o0000ooWinOono_ko_knoo`000?nRXZ800oooool0
1_n^[Zko:2PXok^k^ooalO7o3`l?odQ8B0?ooooo00Woi^KVob4Q8OlP823obLW9ooooooohn?So?3`l
obLW9oo/k>`00oooool01omSHf?o2@T9ok:b/_ooooooRh^;o`D51Onk^k/00oooool02Oo:b/[oa/K6
oooooooooooonOWiog5aLOl20P;o7alOojJVYP08ooooo`04ookno_o;bl_o0000oi6AT@?ooooo00Ko
hN7Qokbl_?ojn_[o`L71o`000?n=SHd3ooooo`08oogmoOm9BDWo8b<Son7QhOolo?coA4A4oa`L7?oW
inL3ooooo`08ofUYJOl51@Go[Jf]oooooooMgMgo;2`/oe5ADOomoOd3ooooo`03ocDe=OmbLW;ooooo
0:oooooo01WoU;oKo`A[[OlCLK7o6gBcocN0^_mVT<;oGXg0oeR;_omGRkooD8NmogjRcOnX^m[o[[oL
ok?3g_nnbn?obmGWolWDi_na`]ko[;kKoj^nfon/_]_oYk[Iojo0gOoJh^oonO_l0?ooooooooooool:
ooooo`00C?ooool00ooMgMgo9bLWogemO@06ooooo`03oo[jn_lL71coHV9R00Gooooo00?oBDU9odI6
A_o/k>`00oooool01?oalO7o/k>coadM7OmRHV82ooooo`07og=cLolc<c?oh>3PoooooonXZ:So0000
oo;blP02ooooo`07ookno_o0`<3o30`<ode=COlZ:R[oHF5QooOgm`07ooooo`03onk^k_m=CDgoA4A4
00;ooooo00?obLW9o`d=3Ong]kL00oooool03?n8R8So1`L7oooooooooooo]kNgo`d=3Oo9bLWooooo
ol[:b_l:2P[oZJVYoo[jnP;omOGe00Oom_Kfono_koohn?Sok>c/odY:B_m4A4CooOgm00Cooooo00Ko
4a<CogIfM_olo?conOWiofm_KolM7Ad4ooooo`03oh>3PolM7AgogMgM00Cooooo00coDU9BoaXJ6_oo
oooooooooiZJV_lF5QKoe=CDooooooo1`L7o0@41ol;2`_ohn?P2ooGem@04ooKfm_o_knoon?Shookn
oPKooooo00OoXj>So`000?oinOWonOWiog5aLOlG5aOooooo00?omOGe00Kol_;bonk^k_oooooo/K6a
o`000?oAdM44ooooo`07oijNW_l?3`oobLW9oooooooCdm?o4Q8Boj:RXP04ooooo`07on;Rh_l0003o
]KFeooShn?ln?SkoDe=CooknoP06ooooo`07ookno_oJf][o3Ph>odQ8B?m=CDgoBTY:ooGem@07oooo
o`04ooWinOmfMWKo5aLGooWin@Kooooo00?oEEEEoc4a<Oooool01?ooool01oo>c/ko5QHFoi^KVooW
inOo5QHFoi6ATOono_h00oooool02?oYjNWo0000ojf][Ooooooo][Jfoa4A4OnZZZ[on_[j0_oemOD0
0oogmoOofMWIooooo`2`ooooo`06oiVofolNMK?oBhRnof6?`OmLSL3oEX^o0_mGRkl04_mERKkoChJl
ohFWcongan3oa]7VomWPkOoMh^ooemo/omCLjoo>enWo^<KPojfnfon[_M[o[;kKojZlf_nX^m[obMGX
oo3dnBCooooo00Cono_konOWiooEeMGolO7ai?ooool03?oTi>Co^k^kojf][Oo0`<3ok^k^onc/k?o:
b/[oo_knooooooogmoOo];BdonSXj0;ooooo00?ol_;bok^k^ooQhN400oooool02?ohn?SodM7Aojj^
[_na/K7ofMWIooKfm_oIfMWogmoO2Oooool01_oRh^;o^[Zjojf][Onh^;SohN7Qoo_kn`?ooooo00Go
fm_Kok6a/On][JgoaLG5ooCdm003ooooo`05ooOgmoo7alOo[Jf]okJf]_oWinL00oooool00ond];Co
h>3Pooooo`02ooooo`06oo;bl_o7alOo/;2`ok:b/_o:b/[omOGe0oooool00oomoOgo];BdonCTi002
ooooo`03on7QhOnm_Kgol_;b00;ooooo00?oj>SXokBd]?oinOT01oooool00ooalO7o^k^kon7Qh@02
ooooo`03onCTi?nd];Cooooo00Gooooo00Kokno_olK6a_n`/;3o/k>colc<c?oinOT3ooooo`03ooWi
nOnd];Coj>SX00;ooooo00?ol_;bokfm_OoQhN400_ooool00ooTi>Co];Bdoogmo@08ooooo`06oocl
o?oAdM7o/K6aojf][Oo=cLgomOGe0_ooool00ooinOWobLW9ol_;b`03ooooo`03onc/k?nd];Col_;b
00?ooooo00SolO7aolS8b?n^[Zko]KFeon;Rh_odm?Cod];Bon_[j`;ooooo00GoiNGUokRh^?n^[Zko
b<S8ooShn01=ooooo`00C?ooool00ooMgMgo9bLWogemO@06ooooo`03ooWinOl30`?o[Zj^00Gooooo
00?oEUIFodQ8B?o/k>`00_ooool01Oo:b/[oFe]Ko`D51Om4A4CogmoO00;ooooo00OoLg=coc<c<ooP
h>3oooooojRXZ?l0003ol_;b00;ooooo00OomoOgoeEEEOlN7Qkohn?Sog]kNol@413obLW900Oooooo
00?ok^k^ode=COm4A4@00_ooool00oo9bLWo3@d=okRh^003ooooo`0<ohV9ROl71`Oooooooooooong
]kOo3@d=olW9bOoooooo`l?3oaTI6Om3@d?oFUYJ0omGEeL01OmVIVKoOGemom?Cdom7AdOoG5aL00Go
oooo00Ko61PHogEeMOolo?conOWiofm_KolM7Ad4ooooo`03ofEUIOlo?cooinOW00Cooooo00coQhN7
oaHF5_oooooooooooiZJV_lF5QKoe=CDoooooonk^k_o410@ode=COmIFET2oeMGE`04oeQHF?mWIfOo
QHF5onk^kPKooooo00OoXj>So`000?oinOWonOWiofa/K?l92@WoIVIV00?oEeMG00KoGUiNofUYJOo4
a<CoY:BTo`000?omoOd4ooooo`07okJf]_l<30cobLW9ooooooo2`/;o1@D5ol[:bP04ooooo`06oo;b
l_l61PKo]KFeonk^k_l^;RkoL71`2?ooool01_m_Kfoo3@d=omcLg?nNWYko20P8ok:b/POooooo00?o
m_Kfof9RH_lW9bL01oooool00olX:2SoMGEeooclo004ooooo`06omoOgolh>3SoO7alomSHf?l92@Wo
]kNg1?ooool02?oinOWo1@D5ojb/[?ooooooYZJVo`<30omBDU;oG5aL0omGEeL00om]KFgoIfMWoooo
o`2]ooooo`05oo7dnOoPio;oV;?Fof2>`OmJS;l00_mGRkl04OmFR[ooDhRmoeJ;_omRT/?oJIO5ojS0
fooPiNooiNSbomkSkooJh>gof=k]omGLj_oBfN[ocMKYokg:hOn^`=coZ[gJ00;o[;kK00?oXkOGokW8
hOoSjO<08Oooool01oodm?CogMgMol30`?nNWYkoQhN7om3@d?ono_h0hOooool03_okno_o][Jfochn
?_l92@Wo5ADEob8R8_mCDe?oLG5aoa4A4OoinOWoooooon3Ph?l0003oZJVY0_ooool00oo?cloo0000
ohn?S`02ooooo`09on_[jomdM7Co61PHo``<3?lE5AGo>SXjofYZJ_lo?cooLG5a00Sooooo00Oo_Kfm
ocLg=olA4A7o5ADEo`X:2_m3@d?oc<c<00;ooooo00oo^KViobh^;_l:2P[o4a<Coa0@4?m^KVkokno_
oooooooYjNWoLG5aoa@D5?lC4a?o0@41odY:B_oPh>000_ooool03?l0003oRHV9oooooooooooog]kN
oeeMGOlG5aOo51@DoaDE5OlG5aOoIFEUonOWi`;ooooo00?on?Sho`000?nIVIT00_ooool00on?Shoo
10@4olo?c`02ooooo`03ojVYZOl0003ojNWY00Oooooo00?obl_;o`000?n?Shl00_ooool00onIVIWo
0000ooooo`04ooooo`08omGEeOmGEeOo5aLGoa<C4olF5QKo61PHofi^K_o/k>`2ooooo`03onWYjOl0
003oZJVY00;ooooo00?oclo?o`@41?n?Shl00_ooool00onIVIWo0000ooShn007ooooo`0<ooKfm_nA
TI7o5QHFo`h>3_lF5QKo71`LofIVI_oYjNWoooooon[Zj_lb<S;o>SXj0oooool00ong]kOo0000olg=
c@02ooooo`0@omgMgOmMGEgo3Ph>oa8B4_lI6AWoA4A4og1`L?lS8b?oYJFUooooooo7alOo@T92o`l?
3olB4Q;o30`<ohN7Qdgooooo001<ooooo`03omgMgOlV9RKoPh>300Kooooo00?on_[joaHF5_moOgl0
1Oooool02OmDE5CoBTY:on_[jooooooofMWIobLW9olF5QKoQHF5onOWi`03ooooo`0Aog=cLolc<c?o
h>3PoooooonXZ:So0000oo;bl_ooooooo_knol_;bol410CoOWinooooooo2`/;o30`<ogYjN_ohn?P0
1_ooool00oo^k^koCDe=odA4A002ooooo`03olW9bOl=3@go^;Rh00?ooooo00coQXJ6o`410Ooooooo
oooookNg]ol=3@gobLW9ooooooo>c/ko7AdModI6A_mWIfL2ofATI006ofMWIolT92Co0000omKFe_mE
EEGoCdm?1Oooool01_lE5AGoMGEeooclo?oinOWoKfm_oahN7PCooooo00?oNGUiobd];OoRh^801?oo
ool03?m[Jf_o61PHooooooooooooVYZJoaHF5_oDe=CoooooolO7aolB4Q;oDE5AofIVIP;oI6AT00Co
IFEUoaXJ6_l?3`ook^k^1_ooool01onSXj?o0000ooWinOojn_[oNWYjo`T92Om_Kfl00_mTI6@01omU
IFGoCdm?o`000?n<S8co/[:bo`000?oWinL01?ooool01onUYJGo3Ph>olW9bOooooooc/k>o`d=3Onf
][H01?ooool01_oWinOo1`L7okBd]?oemOGo>CTioe]KF`Oooooo00SogmoOo``<3?m[Jf_oooooom_K
folG5aOoG5aLooKfmPKooooo00Con?Shog1`L?lL71cooOgm1_ooool00omADE7oA4A4ooooo`04oooo
o`06om?CdolS8b?oV9RHon;Rh_lA4A7oY:BT1?ooool02?o_knoo1PH6ojb/[?oooooo^;Rho`L71olo
?cooIVIV0_mTI6@00om[Jf_o30`<o`D51@2[ooooo`06ooclo_oUj_Cod]c/okk<honZ_=[oQ:G>0_mG
Rkl06_mERKkoDXNmoeZ<`?m/VLKoNZC<oh^_dOn@/]?o_]3Son;Wl?oSio7ogn?_om_QkOoHh>goeMg[
om7Jj_o>enWobmCWol7<i?na`]koZkgJojbnfon]_]_oYk[Iojk0g?oDg^goo?kn7Oooool02OoZj^[o
d=3@okBd]?nCTi?oSHf=oinOWonDU9Cob/[:ooclo03Qooooo`0>om3@d?lK6a_o:b/[oj6QXOoBd];o
[jn_odQ8B?lA4A7o0000ooWinOoooooohn?So`000?na/K42ooooo`03omCDe?lF5QKoVYZJ00;ooooo
00WoKfm_o`000?m`L73oaLG5olW9bOn0P83o61PHo`D51OmXJ6P01oooool0;?o@d=3o6QXJocLg=on]
[JgodM7AojVYZOm>CTkoZJVYooooooo^k^ko9bLWocLg=onj^[[oc/k>ohf=SOl0003oXj>Soooooong
]kOo4Q8BofMWIoo?clooYJFUo`P82?n2PX;on?Shooooool0003oU9BDooooooo`l?3oADE5oa4A4OnA
TI7ob<S8olK6a_n:RX[o1PH6oeIFE_ojn_[oooooooWinOl0003oXj>S0_ooool00onJVY[o71`LomCD
e002ooooo`03ok6a/Ol0003ojn_[00Oooooo00?od=3@oaHF5_nJVYX00_ooool00onSXj?o0000oooo
o`03ooooo`09onWYjOlf=SKo61PHoiBDU?o:b/[oaLG5ohF5QOl0003oHV9R00;ooooo00?ojn_[o`00
0?na/K400_ooool00ooDe=Co71`LoiZJVP02ooooo`03oj>SXol0003onOWi00Oooooo00coYJFUo`D5
1OmBDU;o`<30om?Cdon4Q8Co0000odM7AoooooookNg]odI6A_m=CDd3ooooo`03okjn__l0003od];B
00;ooooo017oBd];o`820_n7QhOocLg=ol71`Om/K6co51@Do`000?nQXJ7oooooof=SHolM7AgoZJVY
olg=cOmgMgOo0`<3omCDe01<ooooo`00C?ooool01?oMgMgo:b/[of5QHOoCdm<3olg=c@06olS8b?on
o_koo?cloeADE?lH61SoinOW0oooool02_o8b<So6QXJoda<C?o/k>cooooooiFEUOl0003oemOGoooo
ooofm_H3ooooo`0Aog=cLolc<c?oh>3PoooooonXZ:So0000oo;bl_oooooooOgmoe]KFolF5QKojNWY
ooooooodm?CoEEEEoaHF5_oHf=P01_ooool00oo^k^koCDe=odA4A002ooooo`03olW9bOlD51CoPH61
00?ooooo00_oEUIFobLW9ooooooooooool71`Ol>3Pkodm?Cooooooobl_;o;2`/oeUIF@04ooooo`06
ocXj>_la<C7ono_kohN7Qol@413obl_;0oooool02?nVYZKo1PH6ogIfM_olo?conOWiofm_KolF5QKo
moOg0oooool00ong]kOo3Ph>oiRHV003ooooo`03omSHf?lI6AWo7alO00;ooooo00OoXZ:RoaLG5ooO
gmoooooooo3`l?lI6AWoKfm_00?ooooo00?oo?clob/[:om3@d<01oooool01onSXj?o0000ooWinOom
oOgo];Bdo`000?o=cLd00oooool01_nQXJ7o0P82ok^k^ooZj^[o1PH6ofi^KP?ooooo00WolO7aoc`l
??lM7AgobLW9ooooooobl_;o<30`odM7Aoofm_H00oooool01on1PH7o1@D5ok:b/_ooooooN7Qhoa8B
4_o>c/h00oooool02ooOgmoof=SHoooooom_Kfoo0000on3Ph?oooooomoOgog=cLol>3Pkoa<C400Ko
oooo00CooOgmokRh^?l0003o[:b/0oooool01_o_knood];Boo_knon/[:co0000ok6a/@Cooooo00Oo
J6QXoaPH6?oDe=ConOWiocLg=olk>c_ol_;b00?ooooo00OoQhN7o`<30on][JgoooooomGEeOlU9BGo
MGEe00?ooooo00?on_[joa/K6omQHF40ZOooool09Oodmo[ogNCaolSDiona`]goY[[IojRkfOn``=co
QjO?oe>9__mAQkgoH973ogFPbOn5Zm3oU[OFoijkf?nI^MKoSk;Cokc>h_oSio3ohnSaon3Ul?oLhnko
f^3]omKNjooCfn_od=SZolcEj?o9e>Oo`/kUokG4gon/_m_oZkkKojbnfonZ_=[oZ;_JolSDiooam?T0
6_ooool02ooQhN7oa/K6ojNWYon<S8coTi>CokFe]OoFe]KobLW9oiJFU_o;bl_oo?cl0>3ooooo00Co
nOWioh>3Pol=3@gob/[:0oooool02?obl_;o<30`o`000?oinOWoooooon?Shol0003o/K6a0_ooool0
1ooDe=Co5QHFoiZJV_ooooooinOWo``<3?mVIVH01?ooool00onRXZ;o0000ofa/K007ooooo`03ofe]
KOl:2P[oh^;R00?ooooo00KojNWYon?Shooooooo`l?3o`410Oo0`<03ooooo`06ocdm?Om:BT[ooooo
on3Ph?nj^[[ol_;b0_ooool02_l`<33oC4a<ono_kooooooo0000oiBDU?ooooooY:BTo`000?na/K44
ooooo`07oj:RX_l0003o^[ZjoogmoOoinOWo0000oj>SX`02ooooo`03oiZJV_lL71coe=CD00;ooooo
00?o/K6ao`000?o[jn/01oooool00oo@d=3o5QHFoiZJVP02ooooo`03oj>SXol0003ooooo00;ooooo
00ConOWioiFEUOl92@Wo^[Zj1?ooool01onBTY;o0000olo?cooooooojn_[o`000?na/K400_ooool0
0ooDe=Co71`LoiZJVP02ooooo`03oj>SXol0003onOWi00Kooooo00Cok>c/oc/k>om;Bd_onOWi0ooo
ool01_nFUYKoMGEeooooooo/k>coATI6ode=C@?ooooo00Oo_[jno`000?oBd];oooooom7AdOl0003o
S8b<00Cooooo00KoNWYjo`000?nSXj?oooooolG5aOo:b/X2ooooo`03oo;bl_l0003oWinO04cooooo
001<ooooo`04omgMgOll?3co10@4oa4A4@?o3@d=01Co2PX:ooWinOono_koalO7o`000?lb<S;oVYZJ
olS8b?n=SHgo<30`o`000?m=CDgok>c/oooooonb/[;o0000ojFUYOn:RX[o@D51onWYj@;ooooo00_o
Lg=coc<c<ooPh>3oooooojRXZ?l0003ol_;bookno_o?cloo1PH6oh>3P`03ooooo`04ok2`/?l51@Go
VIVIoogmo@Gooooo00?ok^k^ode=COm4A4@00_ooool0@Oo8b<So7alOo`@41?n5QHGo`/;2oi:BT_l1
0@7oM7Adooooooofm_KoPX:2o`P82?nATI7ofm_KoooooonPX:3o0000od];Bonk^k_o]kNgod=3@ol0
003o][JfoooooooIfMWo9RHVoahN7_nHV9Sob/[:ohB4Q?lU9BGo0000ogIfM_olo?conOWiog5aLOl2
0P;oHV9RokBd]?nb/[;oooooooCdm?mBDU;o2PX:oh20P?o0`<3oZ:RXoa`L7?lA4A7o6QXJoooooood
m?CoJf][o`l?3onIVIWog]kNoooooon?Shoo0000oeEEEOo0`<3o/;2`ocXj>_l51@Go`l?300Oooooo
01OoXj>So`000?oinOWoooooonk^k_ll?3co30`<oi2@T?o;bl_oQ8B4o`H61_mCDe?ok^k^oooooon3
Ph?o0000ofUYJOnj^[[o][Jfod];Bol0003o9bLWolW9b@02ooooo`0EoijNW_l0003oC4a<ojf][Oo2
`/;oIVIVoaTI6Ol92@Wo/;2`oooooooPh>3o=SHfoalO7onCTi?ob<S8oi^KVolX:2SoXJ6Qon7QhOl;
2`_oBd];00?ooooo00CoaLG5o`l?3omVIVKolo?c1_ooool09oogmoOoHF5Qo`X:2_mmOGgoa/K6oj^[
Zolg=cOoLW9booGemOohn?SoC4a<o`L71omaLG7ob<S8okFe]Om<C4co0`<3ohJ6Q_omoOgoooooojBT
Y?l0003oB4Q8ojb/[?o4a<CoJVYZoadM7Ol:2P[o[Jf]oooooooinOWoOWino`000?mTI6Co_knooj:R
X_la<C7o1PH6omGEe@2Wooooo`0SonW^mOo>f>[o_<_Rojfog?nX^mWoZkgJojbnfon[_M_oZkgJoh>T
c_mZV<KoPJS=oi2cdonM^mSoX;kIoibkeonI^MOoV;OEohnbdonlcn?oi>Saon?XlOoPiO3og^?_om[Q
kOoHgngoe=c[om7Ij_o>enSobMCVolKAi_o1c>Co^LSQojk0g?n[_M/00_n/_]/00onW^]Wo^lWRomoV
l@0Fooooo`0>ooKfm_oDe=Co^[ZjoijNW_n=SHgoWYjNolK6a_oPh>3om_KfoooooooKfm_oUIFEol_;
boolo?cPooooo`03onk^k_m=CDgoA4A400Gooooo00OoT92@o`000?oinOWoooooon?Shol0003o/K6a
00;ooooo00Ooe=CDoaHF5_nJVY[ooooookFe]Ol0003og=cL00Cooooo00?ohn?SobTY:OmRHV801ooo
ool00olQ8B7oJf][ooooo`06ooooo`03okRh^?l0003oe]KF00;ooooo00?oo?clofi^K_lN7Qh01?oo
ool02ooTi>CoOWino`000?n8R8SonOWiooooool0003oU9BDooclo?mPH63o;2`/00Gooooo00?oo_kn
oaLG5omeMGD00_oinOT01ol0003oXj>SooooooooooooVYZJoa`L7?oDe=@00_ooool00ona/K7o0000
on_[j`07ooooo`03om3@d?lF5QKoVYZJ00;ooooo00?oXj>So`000?ooool00_ooool00oo^k^koDe=C
odA4A005ooooo`07oo_knol=3@goRHV9ooooooo[jn_o0000ok6a/@02ooooo`03omCDe?lL71coVYZJ
00;ooooo00?oXj>So`000?oinOT01_ooool01?oAdM7o61PHohV9ROobl_82onSXj007onWYjOoWinOo
k>c/oogmoOo/k>coATI6ode=C@03ooooo`07okjn__l0003od];BoooooonFUYKo0@41ooGem@04oooo
o`03olW9bOlB4Q;oW9bL00Cooooo00Coa/K6od92@_l0003og]kNC?ooool004cooooo00CogMgMobh^
;_mEEEGo[Jf]1?n^[Zh04oomoOgooooooogmoOnQXJ7o<30`o`000?l:2P[o;bl_oinOWom=CDgoE5AD
onc/k?ooooool_;bof5QHOl<30co2PX:og]kNooemOD00_ooool02omSHf?o71`LomgMgOooooooZ:RX
o`000?obl_;ono_koc/k>ol0003ok>c/00?ooooo00Com?Cdoc8b<_l?3`oofm_K1Oooool00oo/k>co
>CTiobl_;`02ooooo`0:olO7aol_;booLG5aoeMGEol=3@go0000od=3@ooShn?oooooom3@d0;o0000
02So0@41oeaLG?odm?Com_KfoiJFU_lK6a_o1@D5o``<3?lf=SKoZZZZoogmoOooooooo_knolK6a_m0
@43o0000o`T92OlP823o/;2`o`000?mVIVKoo?clooShn?mQHF7o0000oeUIFOl0003o@d=3oo3`l?oo
oooogmoOof9RH_l:2P[o10@4oalO7omeMGGoKFe]oc<c<ooooooo`<300_l000002_l10@7oKVi^ooKf
m_oclo?oRHV9oaHF5_l61PKo3Ph>ocdm?Onf][H8ooooo`0<oj>SXol0003onOWiooooooono_koe=CD
od];Bol0003o2PX:oaLG5om]KFgogmoO0_ooool02Oodm?CoQ8B4o`d=3Ol20P;o61PHoeUIFOmoOgoo
0000ol?3``02ooooo`09ooKfm_nBTY;o6a/Ko`000?lB4Q;o>SXjojj^[_lM7Ago[jn_00;ooooo00[o
emOGof9RH_lE5AGo20P8oa0@4?lj>S[oi^KVodm?Col0003od];B0oooool01?ofm_KoEUIFo`000?o7
alL7ooooo`0AonWYjOmgMgOo6ATIo`P82?l:2P[o9bLWokRh^?olo?coooooon?Shom^KVko61PHo`P8
2?l71`Oo:RXZoiJFU_oalO400_ooool02OogmoOoVYZJoahN7_l0003o3`l?ocHf=_n_[joo0`<3ojf]
[@02ooooo`07onc/k?n1PH7o8R8Ro`D51Ol20P;o<c<cok^k^`2Vooooo`0VomkUlOo2cnGo]LKOojZm
f_nY_=WoZkgKojbnfonZ_=[oY;SHojfnfoo9dnKo^lkSoiRhe_nQ_]WoXKoIoinmf?nL_=SoVk_GoiZj
eonI^=KoT;?Cokg@i?oUjO;oiNWaon;Vl?oOi>oog>;^om[PkOoEgNcod][[oloHjOo;eNSoam;Vol?>
i?o0cN?o_<[Rok71gOn[_MX2ojbnf`03ojZlf_na`]god=[[01?ooooo00Wok^k^olW9bOn^[ZkoVIVI
ohV9ROn[Zj_oclo?on[Zj_okno/00oooool01?oHf=SoUIFEol_;boolo?cPooooo`03on_[jom1@D7o
DU9B00Gooooo00Oo/k>co`000?oinOWoooooon?Shol0003o][Jf00;ooooo00OoeMGEoa@D5?nHV9So
ooooojRXZ?l0003om_Kf00Cooooo00?oj^[ZodU9BOmNGUh01oooool00ol30`?oUIFEooooo`06oooo
o`03okZj^_l0003od];B00;ooooo00?oo?clog1`L?lL71`00_ooool01_oemOGoN7QhoalO7ol30`?o
JVYZonOWi`;ooooo00Go0000oiBDU?ojn_[oEEEEocLg=`06ooooo`06ob0P8?mZJV[onOWiooWinOl0
003oZ:RX0_ooool00onJVY[o7QhNomKFeP02ooooo`03ok>c/ol0003ojn_[00Oooooo00?od=3@oaHF
5_nJVYX00_ooool00onSXj?o0000ooooo`02ooooo`03on_[jom8B4SoDU9B00Kooooo00Ko4a<Cogem
OOoooooojn_[o`000?nf][H2ooooo`03omGEeOlK6a_oV9RH00;ooooo00?oXj>So`000?oinOT01_oo
ool01?o=cLgo;2`/oa8B4_lJ6QX3oaLG5`06obPX:?m1@D7ofm_Koo7alOm6ATKoCTi>0oooool01_no
_koo0000om;Bd_ooooooRHV9o`<30`Gooooo00?ofm_Kob4Q8OnIVIT00_ooool01Oo?cloo@T92o`/;
2olM7AgoWinO04gooooo001<ooooo`03omgMgOlV9RKoPH6100Wooooo00Soh>3PolG5aOo1`L7oe]KF
oogmoOoVi^KogmoOoo_kn`;ooooo00CokNg]olW9bOo;bl_omOGe0oooool02_oRh^;oeMGEooShn?oo
ooooZ:RXo`000?obl_;oo_knolg=cOo;bl/5ooooo`03om_Kfoo5aLGomOGe00Gooooo00?ono_kom[J
f_oIfMT00_ooool01oodm?Cof=SHooCdm?oRh^;o`/;2olK6a_oTi>@00_ooool03?oclo?oRh^;o`X:
2_nHV9Soe]KFooclo?oooooon_[jomSHf?o2`/;oa<C4on7Qh@Gooooo00OoiNGUolG5aOo0`<3oe=CD
ooooooo;bl_oh>3P00;oo_kn00KogmoOolW9bOoVi^Ko`L71omGEeOojn_X2ooooo`0Dono_koo<c<co
`L71olg=cOofm_Koj^[Zom_Kfoooooookno_ogEeMOlA4A7oX:2Pom[Jf_olo?coooooooShn?oFe]Ko
`L71olK6a_oShn<9ooooo`03oj>SXol0003onOWi00?ooooo00Goj>SXolS8b?o0`<3od=3@oo?cl`04
ooooo`08ooShn?oAdM7o`L71olS8b?oZj^[ol_;bolS8b?oclo<3ooooo`08ooWinOoHf=So`/;2olC4
a?oPh>3oooooomGEeOo_knl3ooooo`08oo3`l?o=cLgo`<30ol[:b_oTi>Coooooom3@d?o7alL5oooo
o`03on?Shoo5aLGolO7a00Sooooo00Kom_Kfom?Cdoo0`<3oa/K6omgMgOokno/3ooooo`06oo?clooE
eMGo`<30ol?3`ooNg]kono_k1?ooool02?ojn_[ofMWIol?3`oo3`l?ogmoOooKfm_l0003o[Jf]0ooo
ool01Oohn?SoemOGol71`Oo5aLGohN7Q0:Cooooo00KolOCiom;Lk?nlb^;o/L;MojZlf_nZ_MX2ojbn
f`0RojVlf_nT^MSo]<CNomKMk?oYkOCom_KhomCOk?nS`=WoX;oIoj2nfOnN_MSoWKcHoibkeonK^mOo
VKWGoi2cdonmd>?oi^[aonKZl_oSio7oh>G`omkSkooKhNgoemk]omCKjooAfN[ocMKXolWDi_o4d>Ko
`<cToko<honnbn;o]LGOoj^nfP;o[;kK00CoZkgKojbng?o3d>Gol_Gj3oooool02OoShn?o^k^kojBT
Y?nEUIGoTY:BokBd]?oJf][ol_;boogmo@05ooooo`04omSHf?nEUIGobl_;ooclo>3ooooo00Col?3`
oeMGEolh>3Sono_k1?ooool01on0P83o0000ooWinOoooooohn?So`000?nEUID00_ooool01oo>c/ko
8b<SojBTY?oooooo`<30o`410Oo5aLD01?ooool00ooQhN7o5aLGofATI007ooooo`03ocHf=_m9BDWo
oooo00Kooooo00?o^[Zjo`000?oBd]800_ooool02_olo?coKfm_oadM7OooooookNg]ofe]KOl71`Oo
LG5aolc<c?odm?@3ooooo`06o`000?nDU9Coo_knofYZJ_lS8b?ono_k1?ooool01oo[jn_o3Ph>ogmo
Ooojn_[onOWio`000?n3Ph<00_ooool00onOWioo3Ph>ol[:bP02ooooo`03ojb/[?l30`?ojn_[00Oo
oooo00?od=3@oaHF5_nJVYX00_ooool00onSXj?o0000ooooo`02ooooo`04oo3`l?mLG5co>3Phoogm
o@Cooooo00Oohn?So`L71onCTi?oooooon_[jol0003oUIFE00;ooooo00?oc/k>obLW9onTY:@00_oo
ool00onSXj?o0000ooWin@06ooooo`04omgMgOlV9RKoJVYZolG5a@;o_kno00Oo`l?3of1PH?l0003o
kNg]oo3`l?m6ATKoC4a<00?ooooo00Oo^[Zjo`000?oAdM7ooooooj6QXOl0003oiNGU00Cooooo00Wo
`L71o`H61_nMWIgoooooom3@d?l/;2co7alOoinOWooNg]h0C_ooool004cooooo00?ogMgMobLW9omm
OGd06_ooool01ooclo?omOGeooooooooooooZ:RXo`000?obl_804Oooool00ookno_ok^k^ooooo`0;
ooooo`03okZj^_l=3@goc<c<02Oooooo00?oW9bLoaHF5_oGemL04Oooool00onSXj?o0000ooWin@1B
ooooo`03oo;bl_l0003o[Jf]0:[ooooo00Goj>geolGBi_ndaMko[/3Loj^mf`02ojbnf`0Qoj^mfonX
^m[oZK_Jol3=hooTjO7oloCgooKgn?ojn__oo?ckom;NjonR`=[oXKoIoj2nfOnO_]SoWKgHoibleonL
^mSoV[[Foi6de?nndNCoin[aonO[l_oTj?7oh^OaomoTkooLhNkof>3]omGLjooAf^[ocmOXol[Dioo6
d^Ko`LgT00;o_lcS00Co_/cSok[9hOn]_mcoZkkK0_n/_]/00on[_M_o]lOOon;Xl`0<ooooo`09onGU
iOnTY:CoWYjNoi6ATOnLW9co`<30ong]kOohn?Soo_kn00Oooooo00Cof=SHoiFEUOo;bl_oo?clh?oo
ool01?ono_koW9bLo`000?nTY:@3ooooo`08omSHf?lO7aoo0000ooWinOooooooi>CTo`000?m@D502
ooooo`07ojn_[olH61So^;RhoooooooinOWo6a/KocLg=`04ooooo`03ogalO?l0003oKVi^00Oooooo
00?oXj>So`000?nNWYh00oooool01_o1`L7o`<30oooooonj^[[o0000om;BdP;ooooo00[oo?clofm_
KolM7AgoooooomoOgol`<33oI6AToooooooalO7on?Sh0oooool01_l0003oVYZJooooooo7alOo0000
ogemO@Cooooo00OoJ6QXo`000?oKfm_oo_knooWinOl0003oBTY:00;ooooo00?oRHV9o`000?nOWil0
0_ooool00om_Kfoo9BDUoo3`l007ooooo`03omOGeolG5aOoX:2P00;ooooo00?oXj>So`000?o2`/80
0_ooool01?ono_ko][Jfo`000?n:RXX4ooooo`07oeMGEol10@7okno_ooooooo[jn_o0000oe1@D002
ooooo`03ojn_[olH61So^;Rh00;ooooo00?oZJVYo`000?ooool01_ooool01?olo?coFUYJoa<C4ooI
fMT2ooooo`08ono_kolP823o@410ookno_o/k>coBd];ob8R8_oMgMd2ooooo`07ohF5QOlL71cog]kN
oooooooZj^[o0000oeYJFP03ooooo`0:ooKfm_mIFEWo0000oj>SXooooooo[Zj^o`000?oUiNGooooo
onGUiDkooooo001<ooooo`03omgMgOlV9RKoPH6101Wooooo00Son_[jofIVI_l?3`oo_KfmoooooonX
Z:So0000oo;blQ3ooooo00Cog]kNo`h>3_m6ATKom_Kf2oooool00ond];Co0`<3olO7a`0Wooooo`03
oiJFU_l<30cod];B017ooooo00?oXj>So`000?oinOT0D_ooool00oobl_;o0000ojf][@2Wooooo`05
oocmo_oKh^oo^<SQojo0gOn]_m/00on/_]/08on[_]_oZKcJok70gOo@f>Woko;fooShn_oinO[on_Wj
ooWhnOohn?WooO_kom?OjonR`=[oX[oIoj2ofOnP_]WoW[gHoiflf?nL^mOoV[_Goi:ee?nod^Coin_b
onS[l_oUj?7oh^K`on3UkooMh^kof>3]omKMk?oCf^[ocmSXolcEj?o7dnKo`/oT00Co_lcS00?o_L[S
ok;2gOnZ_]/00on/_]/00on]`=cocMS[oocloP09ooooo`07oo[jn_o3`l?oS8b<ojBTY?oFe]KomoOg
oo_kn`0:ooooo`04omSHf?nEUIGobl_;ooclo>7ooooo01?ohn?SodI6A_l20P;oEeMGoj6QXOm_Kfoo
2`/;ob@T9?l0003onOWioooooooTi>Co0000o`h>3_mEEEGoUYJFobDU9Ol_;boofMWI00;ooooo00Wo
Y:BTo`000?lN7QkoSHf=oiBDU?lj>S[o10@4oa@D5?mYJFT01oooool03?ofm_KoADE5o`410OmLG5co
XZ:RofATI?lM7AgoZ:RXoooooonj^[[o0000om;BdP;ooooo02Soo?clofm_KolM7Agooooooo;bl_mJ
FU[o30`<oh>3Pom2@T;o5aLGomWIfOooooooY:BTo`000?mDE5CoZ:RXonOWion8R8So0000od92@_nC
Ti?oShn?ocXj>_l0003oV9RHoo_knooooooonOWio`000?lA4A7oFUYJohF5QOlB4Q;o4a<Cob<S8omd
M7CoPh>3o`D51OmOGeoom_Kf1_ooool09Oo_knooRXZ:o`L71omMGEgoUYJFomcLg?nPX:3o1PH6oa@D
5?nIVIWoIFEUooooooohn?SoLW9bo`000?m7AdOoUIFEohf=SOld=3Co0000ojBTY?ono_koooooon_[
jol0003o3Ph>oe5ADOnFUYKo9BDUob/[:ooIfMWoooooomcLg?mSHf?o0000oiFEUOo7alL01_ooool0
9?o;bl_o7alOoa4A4On8R8SoU9BDob0P8?l51@Goclo?ooooooo/k>coD51@o`000?li>CWoUIFEog]k
Nol71`OoCTi>onc/k?ooooooo_knoh>3Pol0003o<S8boiVIVOn9RHWo9bLWo`l?3ol10@7oXJ6Qoooo
oooIfMWo1`L7odY:B_n9RHWo61PHodm?Cdgooooo001<ooooo`04omgMgOl`<33o@410oiRHV0?oSXj>
00?oQhN7ooclo?ooool04oooool01omnOWko6QXJolW9bOooooooZ:RXo`000?obl_804?ooool00ooS
hn?o9bLWoeYJFP0<ooooo`03on[Zj_nh^;Sok^k^02Oooooo00?oh^;Rok^k^ooalO404Oooool00onS
Xj?o0000ooWin@1Booooo`03oo;bl_l0003o[Jf]0:Gooooo00?ol_Gjol[FjOn_`=d01On/_]/01_n[
_]_oZkgKokK5gooMhngomoSioo[inP?on_[j0_oinOX00ooin?WooO_kom?Pj`02oj;0fP0Foj6ofOnP
_]WoWkkHoifkf?nL^mOoVk_Hoi:ee?o0dNCoincbonW/l_oUjO;ohnOaon7Ul?oNhnoof^7]omONkOoD
fn_od=WZolcFj?o8e>Koa=3Vol3<i0Go_lcS00?o]LGOojbmfon/_]/00_n/_]/00onZ_=[o_/_Soo;e
nP09ooooo`04ooOgmoo/k>cono_kooknoPcooooo00Cof=SHoiFEUOo;bl_oo?clh_ooool04_oYjNWo
QXJ6oa/K6ol0003o:b/[ok>c/onWYjOo>CTioo[jn_ooooooj^[Zoc/k>onHV9SoCTi>o`000?l`<33o
b<S8ooknoP;ooooo00WooOgmol30`?m?Cdoo0000o`D51Om^KVko^[ZjodI6A_mOGel02?ooool02ooe
mOGoT92@obDU9Ol0003o8B4Qoh20P?oVi^KooooookRh^?l0003odM7A00;ooooo00?oo?clofa/K?lH
61P00_ooool02?oKfm_oEEEEo`000?lR8R;oYJFUooOgmooooooo2`/;0_l000002_lF5QKog=cLoogm
oOn][Jgo>SXjo`@41?l820So@410okNg]oojn_X2ooooo`0<oo[jn_lj>S[oV9RHoe=CDol0003oE5AD
onWYjOn_[joo6ATIo`000?m<C4cojn_[1oooool00ooJf][o=cLgo`000002o`0000;oVi^K00ko0000
oi>CTol92@Wo8b<SomWIfOoooooon?ShojJVY_lg=cOo0P82o`X:2_m4A4Co`/;2oo_kn`;ooooo00_o
l?3`oc/k>onHV9SoDE5Ao`000?l`<33oa<C4ookno_oooooo/;2`o`h>3P02o`000003oi>CTooooooo
oooo00Cooooo017oo_knom7AdOm>CTko0P82o`@41?mHF5SoemOGookno_ooooook^k^ofYZJ_m^KVko
ZJVYoaPH6?l0003o@T92on3Ph003ooooo`0@oo[jn_nZZZ[o>CTio`000?lA4A7oQHF5okBd]?lP823o
VYZJooooooono_koZj^[obPX:?l0003oF5QHomKFeTgooooo001<ooooo`03omoOgom7AdOo2PX:00Go
1`L700?onOWiooooooooool05_ooool00onXZ:So0000oo;blP1Mooooo`03oj>SXol0003onOWi05;o
oooo00?ol_;bo`000?n][Jd0XOooool01_omo_konO[lomoVlOnkbN7oY[WHoj^mfPCo[;kK0_n]_m/0
0oo;e>GojNgbooglo007oo[jnP0LooWin_oin?Woo?[jom?PjonS`M[oX/3Joj6ofOnP_]WoWkkHoijm
f?nM_=SoW;_Hoi>ee?o0d^Coj>cbon[/l_oWj_;ohnOaon7VlOoOhnoof^7]omSNkOoDg>[odMWYolgG
j?o:dnKoaM3Vol3=i0Ko_lcS00?o^LSQojfng?n/_]/00_n/_]/01?nY_M[o[;oLon3Wl_omoOhGoooo
o`04omSHf?nEUIGobl_;ooclo?cooooo00?oj>SXod10@?mOGel08_ooool00ol0003oVYZJooooo`0O
ooooo`03omKFe_lG5aOoX:2P01gooooo00?oZJVYo`000?ooool08Oooool00ooEeMGo71`LoiZJVP1D
ooooo`00KOooool00onWYjOo0000oo;blP1Mooooo`03oj:RX_l0003onOWi05;ooooo00?ol_;bo`00
0?n/[:`0Woooool01_oko?gol_GjomCNkOn``MgoY[[Hoj^mfP;o[;kK00SoZkgKojbnfon_`=go]lGP
om;HjOobloGooOcloo[inP;onOWj1_ojn_X2ooWinP0Joocjn_oCh>_oXl7Joj;0f_nR_mWoX;oIoj2n
fOnN_MSoWK_HoibkeonC]]Co`=?TonW/looZkOCoin[bonGXlOoQi_3ognC_omcRk_oIgngoe]g[om;J
j_o>enSobmCWolKAi_o1c^@4oko<h`05okk;honlb^;o]<CNojo0g?n[_]/00on/_]/01?nZ_M[oY[WI
omGMk_oloOhFooooo`04omSHf?nEUIGobl_;ooclo?cooooo00?oi^KVod10@?mOGel08_ooool00ol0
003oTi>Cooooo`0Oooooo`03om3@d?lF5QKoVYZJ01gooooo00?oXZ:Ro`000?oinOT08Oooool00ooD
e=Co71`LoiZJVP1Dooooo`00KOooool00oni^KWo<S8booGem@1Mooooo`03okFe]Olb<S;on_[j05;o
oooo00?omOGeoc8b<_nm_Kd0Woooool01?oPio7o[KoLojFif?n[_MX3ojbnf`06ojfofonc`mko`loT
omkSkoohnOWoo?ck0_oinOX00oohn?WonOSiooWinP07oo[jnP04ooWin_omn_[odn3[oj?1fP;oX/3J
01coXKoIoj2nfOnO_MSoWK_Hoi^keonD]]Go`M?TonW/loo[k_Coin_bonGYl_oSio7oh>G`omcRk_oI
h>goe]k/om?Kj_o?f>SobmGXolSBi_o4cnGo`LgSoko<honmb^;o^LOQok72g_nZ_M_oZkgK0_n/_]/0
1on[_M_oZ[gJojfog?nda=koa]?VomoVlOolo?d05_ooool01?oHf=SoUIFEol_;boolo?clooooo`03
onKVi_m0@43oGemO02;ooooo00?o8b<Soj:RX_ooool07oooool00oo@d=3o5QHFoiZJVP0Mooooo`03
ojn_[olR8R;on_[j027ooooo00?oe=CDoa`L7?nJVYX0E?ooool00?ooooooa_ooool04OoKho3o]LKO
ojVlf_n[_]_o[;kKoj^mfon^_mcodm_ZooWhn_ojn_[omoKhooOhnOohn?Won?WjooShnOoin?WonOWj
00Oon_[j00ConOWjoogjn_oCh>_oXl7J0_nR`=X06_nQ_mWoX;kIoinnf?nM_MOoW;cHoiBfeOo1e>Go
j^gcon_^looXjo;oiNWbon?WlOoQiO3ogN?_om[PkOoGg^coe=cZom3Ij_o>enSobMCVol?>iOnlb^;o
]lKPok31g_nZ_M[oZkgK0_n/_]/01_nZ_M[oZ[cJok72gOnmbn?ocm[[oo3dnAWooooo00Cof=SHoiFE
UOo;bl_oo?clo?ooool00ooVi^Ko@410oemOG`0Rooooo`03on7QhOo`l?3ooooo01oooooo00?oclo?
oaDE5OnOWil07Oooool00oobl_;ogmoOooknoP0Qooooo`03omCDe?lL71coVYZJ05Cooooo003ooooo
olOooooo013ok?3gokk<i?nZ_M[oZ[gJojbnfonZ_=[o/<3Mom;Jj_oaloOon?OiooOhnOohn?Won?Wj
ooWin_oin?WonOWj1oojn_X09_oinO[ooO[jom?PjonT`M[oXl7Joj;0f_nQ_mWoX;kIoinnf?nN_MSo
WKcHoiFfeOo2dnGoj^kcon_^looYjo;oi^[bon?WlOoQi_7og^?_om[PkOoHgngoe]g[om;Jj_o9e>Oo
`LkSokK6gon]_]coZ[gJoj^mfon/_]_oZkgKojVlf_nY^m[o]/OPolGBi_oNiO7oo?gn6oooool01?oH
f=SoUIFEol_;boolo?`Hooooo`07ooclo?ni^KWob/[:ookno_oUiNGo[Jf]om;BdP05ooooo`04om[J
f_n/[:co`l?3ooGem@;ooooo00Sod];Bojb/[?oVi^KoooooooShn?o3`l?o]kNgooGem@;ooooo00Co
c/k>oj^[Zone]KGobl_;0_ooool00oolo?co_[jnol?3``03ooooo`03omgMgOn/[:cokNg]00Cooooo
00Woo_knolO7aone]KGoo_knooooooohn?Soa<C4ojRXZ?oZj^X00_ooool01ooemOGo[Jf]om_Kfooo
ooooe]KFojb/[?oRh^801Oooool00oo4a<Co/K6aol_;b`02ooooo`09oogmoOo3`l?o/[:boo7alOoo
ooool?3`okJf]_o8b<Son_[j00;ooooo00Co^[Zjojb/[?nk^k_of=SH0_ooool00oo_knoo][JfomCD
e025ooooo`03onKVi_m0@43oGemO04Cooooo00KoeMGEoaTI6OmcLg?of][Jon[Zj_omoOdnooooo`03
omCDe?lL71coVYZJ05Cooooo003oooooolSooooo00Womo[lolgHjOn]_mcoZ;[IojbnfonZ_=[oYk[J
ol??i?oYjo<00oohn?T01?oinO[on?SiooWhnOoinOX6oo[jnP0KooWin_omn_[odn3[ojC1f_nS`M[o
X/3Joj:ofOnP_mWoWkkIoifmf?nM^mSoUKOEol;DiOoZk_?ok>kconW/looWj_;oiNSaon7Vl?oPiNoo
g^?_omSOk?o;eNOo`<gSokG5gon[_M_oZ[gJ00;o[;kK00KoZ[gJojNkfOn[_M_o`<kTom;Kk?o[l?LN
ooooo`04omSHf?nEUIGobl_;ooclo1Sooooo00SonOWiobLW9olP823omOGeoj:RX_l0003oM7Adok2`
/0Cooooo00koQ8B4o`000?mZJV[oZ:RXomCDe?ooooooYZJVo`000?m^KVkoooooooCdm?mZJV[o0000
ojj^[P;ooooo013oPh>3o`000?lD51CoV9RHol30`?oooooomoOgoc8b<_l>3PkoSXj>oo7alOoooooo
_knoo`000?n1PH7onOWi0oooool04oojn_[o3Ph>oeEEEOn_[jooooooomGEeOlL71co4A4Aohb<S?o]
kNgoooooong]kOl0003oEEEEoooooomYJFWo0000ohZ:R_o;bl/01?ooool03_lk>c_o0000oiFEUOnT
Y:Coi^KVoooooom^KVko0000oijNW_ooooooi>CTobh^;_lE5AGoemOG0_ooool02om:BT[o0000ocPh
>?na/K7obLW9ooooooo?cloo4a<CobTY:OnXZ:Son_[j08?ooooo00?oi>CToc4a<OmBDU80A?ooool0
1_obl_;oMWIfoa4A4OlQ8B7oX:2PooWinCkooooo00?odM7Ao`X:2_nBTY80E?ooool00?oooooobOoo
ool01?ono_oogNCaokS7h?nV^MP2ojbnf`08ojJjfOnib>3ogN;^oo[kn_ojnO[on?WjooWin_ohn?T2
ooWinPGon_[j013onOWjoogjn_oCh>_oY<7Joj?1f_nR`=[oX[oIoj2ofOnO_]WoWKgHoifkf?nE]mGo
`mCVon_]loo/koCoj^gc0_oWj_801ooVjO;ogN;^olcEj?nnbn;o/L;MojVlf_nZ_MX00_n/_]/01_nY
_=[oYKSHok72gOo5dNKog>C`ooCgnb3ooooo00Cof=SHoiFEUOo;bl_oo?cl6Oooool02?moOgoo0000
om;Bd_oIfMWoMWIfolo?comRHV;oe]KF0oooool03_n`/;3o20P8oiFEUOo3`l?oRh^;ol[:b_oooooo
7alOoaDE5OoinOWoooooom7AdOl:2P[oFEUI0_ooool04?oXj>So:2PXoaTI6OoShn?o/k>cojVYZOoo
ooooKVi^o`000?le=CGoVYZJooOgmoooooooLW9boaLG5ooAdM43ooooo`0Doo[jn_lH61Soj^[ZoiFE
UOo<c<co^k^ko`d=3On/[:coRHV9ok>c/oojn_[oooooodY:B_l?3`oon_[jol30`?mnOWko^;RhogIf
M_oTi>@3ooooo`09ogmoOol0003oe=CDojVYZOn@T93og=cLomgMgOl61PKoB4Q800;ooooo017oV9RH
o`000?nKVi_oo_knoooooooHf=So0@41oc@d=?omoOgoYZJVol71`Ooclo?o@T92o`T92Om0@43o^;Rh
ooclo022ooooo`03oo?clonPX:3o[jn_04Gooooo00GolO7aoibLW?mdM7Coc<c<oogmo@0nooooo`03
on[Zj_n>SXkocLg=05Cooooo003ooooool_ooooo00cok_;hol;@iOnW^]WoZ[cJojbnfonW^mWo/L7L
oloHjOoem?Oono[jooSin_oinOX2ooWhn@;onOWj02;on_[jooWin_oinO[onOWjoogjn_oCh>_oY<7J
oj?1f_nR`=[oX[oIoj2ofOnO_]WoW[gHoifkf?nE]mGo`mCVon_]loo/koCokO3donk`m?oMh^kobM;W
ok_8hOn_`=goZK_Joj^mfon/_]_oZkgKojNjfOnV^]Wo^<OQom3JjooUjoCon?Wl8_ooool01?oHf=So
UIFEol_;boolo?`Iooooo`03okZj^_l61PKoTi>C00?ooooo00?o_Kfmod=3@oooool00_ooool03ooK
fm_o9RHVoe1@D?okno_oe]KFolW9bOooooooMgMgo`000?n^[Zkooooooo;bl_mGEeOo4Q8Bolc<c002
ooooo`0@ohF5QOl0003oUYJFoooooonIVIWoe=CDol71`Ol0003oO7alojb/[?nYZJWoooooonCTi?lJ
6Q[oOWinoo_kn`;ooooo00oooOgmojRXZ?ooooooj>SXoifMWOmlO7co820Pon;Rh_oQhN7obl_;ooSh
n?ooooooTi>Co`000?o8b<P00_ooool00oolo?coR8R8ogEeM@03ooooo`0?ol71`Ol51@GoR8R8oooo
ooo8b<Soe=CDooCdm?m5ADGo3`l?om3@d?ooooooi>CTobDU9Ol[:b_okno_00;ooooo00coDU9Bo`00
0?o9bLWomOGeoiZJV_oWinOoPX:2o`h>3_nKVi_oTY:BolW9bOono_koooooofCooooo003oooooolco
oooo00comoWkom?MkOn/_]_oZ;_IojbnfonZ_M[oZkgKol7=hoo[kOCoo_glooSin_oinOX2ooWhn@Co
nOWj00?onOSioocjn_oCh>/00_nS`MX06?nR`=[oX[oIoj2ofOnO_]WoW[gHoifkf?nE]mGoa=GWoo3b
m_o`lOKof=o/ol??i?ngaMoo[;gKojVlf_n[_M_o[;kKojZmf_nT^MSoZKcIol3>i?oOi_;ol??iookn
obCooooo00Cof=SHoiFEUOo;bl_oo?cl6Oooool01?o`l?3o9RHVoc`l??ogmoL2ooooo`03onk^k_lb
<S;oclo?00;ooooo00[on?Shof5QHOlG5aOoe]KFooooooono_koooooom_Kfol0003o@T920_ooool0
5Ona/K7o0000odi>C_o[jn_oooooong]kOlR8R;o7AdMooKfm_oclo?oi^KVonk^k_lT92CoAdM7oooo
ooo5aLGoi^KVoooooonBTY;o4a<Com7Ad@03ooooo`0>ooclo?ooooooo?clol[:b_l/;2co?cloonWY
jOooooooo?clookno_ooooooiNGUo`000?m`L703ooooo`03okFe]Om:BT[ohN7Q00;ooooo00Golo?c
ob@T9?lo?coonOWiooooo`02ooclo003ojNWYol0003oNg]k00;ooooo017oN7Qho`000?mnOWkoo_kn
oooooooHf=So0000odM7AoooooookNg]oo3`l?o0`<3o1`L7ohb<S?oXj>Soa<C4oo?cl`3?ooooo`03
oe=CDong]kOooooo00Oooooo00?oc/k>oe=CDoo/k>`0Qoooool004cooooo00?o_MSZod:7_Om7T/<0
1?m7T/<01_m8Tl?o>HZnodRB`om6TL?oEI_7olKMk@Gooooo00[ogN_doebNb_m6TL;oAI72of>Rc?ol
o_ko@XVnodNB`om2S/7oRKWH1_ooool01OoFi_;oCIG5odNB`om7TL?oH:7;00Gooooo00Oo^=KXognc
eOm@UlKoA932oejPbonI`mgoi>of00Sooooo00OodnGaohbkf_mLW/WoAi;3oeJKaon4]]Ooamk]00?o
oooo00Kof>SbofBSc?m2Sl7o@X_0ohFheoocn?/4ooooo`06ooSjo?nKa=oo@XZoodFA`_m7TL?o^MKX
0oooool02?o_mOWoXlSQog>/dOm6TL;oBYC4offYd?nbdNGon_cm1Oooool00om[Z<ooA972odNB``03
odNB``03odBA`_mMWl[od^C`00;ooooo00Ooio7hoj;8hOmRX/_oAi;3oe2Ga_n:^]WoiNof0?oooooo
2_ooool01?oloOkoi>[dokC4gonW^mT2ojbnf`05ojZmfonha]oog>;]oogmnookn_X00_ohn?T5ooWh
n@03oocjn_oCh>_oXl7J00;oX/3J00coX[oIoj2ofOnO_]WoW[gHoinmfOnL_MSo`=;ToloIj?nnbn;o
/l?Noj^mfonZ_MX2ojbnf`06ojVlf_nU^MSo[l3Mom3Jjoo[koOomOOk9oooool01?oHf=SoUIFEol_;
boolo?`Jooooo`08oeQHF?l410Co`l?3ookno_oooooom_Kfof9RH_mTI6@3ooooo`03ojNWYol0003o
/k>c00Cooooo00go@410o`X:2_nk^k_oooooomoOgolg=cOo0`<3og=cLooalO7oooooogalO?l0003o
X:2P00;ooooo00_olO7aoeYJF_lD51Cof][JoogmoOofm_Kooooooo?clolQ8B7oIVIVoo[jnP05oooo
o`03on;Rh_lb<S;oFEUI00Kooooo00?o8R8RoaLG5oo[jn/00_ooool00ooGemOo@d=3oifMW@03oooo
o`03ogEeMOl820Sokno_00?ooooo00kog=cLoahN7_lY:BWof=SHooooooo1`L7o6QXJo`T92OnJVY[o
o_knoooooom<C4co1PH6olW9b@;ooooo00Kof][Job`/;?m1@D7okNg]ooKfm_okno_?ooooo`03o`00
0?n?Shoooooo00Oooooo00?o/k>co`000?oRh^80Qoooool004cooooo00?oY<WQo`1HY?l0J:`01?l0
J:`01_l0I:[oJZO>o`1TZ_l0J:co0VV/of2Qb`Gooooo00[oXlSQoa5b/_l0Ijco06BZoffXcooho?go
05bUo`1X[?l0HZWoG9k:1Oooool01_onoooo>8Voo`5Y[?l0J:co06N/ob9l]`?ooooo00[o_]WZod:>
`OlIMk?o3g6`o`9Y[?l0Ijco1V^^oaEe/ol[PK[oUL7L1_ooool02On1]=Ko8Wbgoa9c/_l5Jjgo06R/
o`AZ[Ol@LK7o8GbgofNTc@02ooooo`06onofn_mAV<Ko05nWo`1UZ_l:JjgoiO3g1?ooool01_o]mOWo
@i72o`1QZ?l0HjWo9WjholGMk0;ooooo00[oV<7Noc>6_?lHM[Co36n`o`1X[?l1J:co2Vj_oaQg]?m0
S/7o_]SZ1?ooool00olaQ[co06J[o`1X[003o`1X[00=o`1VZolNNKKoaMc/oocmo_n1]=Go9WnhoaMe
]?l7K:ko06R/o`9Y[?lBL[;o;8:jojo@i03oooooo`_ooooo00?oloGjol?@iOnY_=X00_n/_]/01on[
_M[o//?MoloIjOoinOWooO_looSin_ohn?T00_oin?T2ooShn@03oogknooCh>_oXl7J00;oX/3J00[o
XKoIoj2ofOnS`=[oX/7Ioi:ce?m^W<OoRZ_Aojbofon/_M_oZkgK0_n/_]/01_nX^mWoY[WIokW8hOoM
iO7ol_Gjoo_loBWooooo00Cof=SHoiFEUOo;bl_oo?cl6_ooool00onTY:Co2PX:oc<c<`02ooooo`04
oo[jn_n;Rh_o7QhNong]k@;ooooo00Coclo?oaTI6OmZJV[ol_;b0oooool03On_[joo0000oeQHF?o]
kNgono_kohZ:R_l<30coBDU9okBd]?oooooojn_[o`/;2olZ:RX00_ooool01?omoOgoZj^[o`000?nC
Ti<4ooooo`04oiVIVOl51@Gobl_;ooknoPCooooo00CoiNGUod=3@olQ8B7oemOG1Oooool00omhN7So
0000ofATI002ooooo`04ono_komBDU;oEEEEooKfmP;ooooo00?o[jn_o`820_nRXZ800oooool01?oh
n?SoNWYjo`000?n0P802ooShn008odQ8B?lV9RKoDE5AomCDe?oooooo`/;2o`000?mOGel2ooooo`04
oo[jn_mXJ6So1`L7olC4a=7ooooo00?o0000oiBDU?ooool01oooool00onf][Ko0000on?Sh`27oooo
o`00C?ooool01OnVb^;o05fVo`M/[_l8KJko06N[00;o06BZ00Oo05nXohFff?lKN;Go1V^]o`=Z[Ol^
Pk_ok?Ci00Cooooo00[oG9k:o`5Y[?l7K:ko06>YomCUlOodnO_o062Wo`M/[_l0IZ_oH:7;1Oooool0
5?mAVLKo26b^o`M/[_l7K:ko1V^^obR0^Oooooooo_oooig6gol?L;3o1V^^o`AZ[Ol0Ij_o06FZo`1T
Z_l0IZ_o0fZ]o`E[[OlCM;;oM:cA1?ooool02omo/mGo1fb^o`A[[Ol7K:ko0FR/o`1VZol0J:co1fb^
o`E[[Ol9KJkoH:7;00;ooooo00GoS[cJo`1XZol5Jjgo062Woi_3g`04ooooo`0<onoenOl5GjOo1Vb^
o`1RZOmOX<_onognoooooomSXlco3W2`o`I[[_l4JZgo06J[0_l0I:X01Ol0Ij_o16Z]o`AZ[OlKN;Go
/m;V00?ooooo00Co=hVno`=Z[Ol7K:ko1fb^0_l0I:X03_l0HZWo6GJdolGLk?omo_koCYK5o`1RZOl4
JZgo06J[o`1TZ_l0J:co1V^^o`E[[OlNNKKoamk]ooooool;ooooo`03oo[koOoIh>ooZkgK00?o[;kK
00Go[[oLoko<hooZkOCoo_kmooWinP03ooShn@0FooWin_omno_odn3[oj?1f_nR`=[oXl7JojC1f_nR
`=[oRJkAofNFa?mJSL3oDHRmognScOnY_=[o[KkKojbnfonY_=[oY[[IolSDj?o/lOOonO[mooknoR_o
oooo00Cof=SHoiFEUOo;bl_oo?cl6_ooool01?oYjNWo5QHFoc@d=?n;Rh/2ooooo`03omCDe?l20P;o
`/;200;ooooo01Gono_kodU9BOlb<S;ohn?SoooooomdM7CoooooooGemOl?3`ooDe=Cof5QHOoooooo
c<c<oa@D5?n5QHGoMgMgoj^[ZoooooooLg=co`410Oni^KT00_ooool00ooLg=co6a/Kode=C@04oooo
o`0JooWinOlb<S;o@D51ooclo?oooooono_kolo?coobl_;oe]KFocXj>_mRHV;o]kNgonk^k_oooooo
aLG5ooGemOoooooobLW9o`000?m@D53o[:b/ooooooono_koRXZ:obLW9ooLg=`2ooooo`0EooShn?l@
413oI6ATooooooohn?SoNWYjoooooonl_;co61PHod51@OnGUiOoooooojBTY?l30`?o_knood];BooF
e]KooOgmodA4A?lG5aOofMWI00;ooooo00?o[Zj^o`000?n>SXh0dOooool00ol0003oU9BDooooo`07
ooooo`03okJf]_l0003ohn?S08Oooooo001<ooooo`0>ojK:h_l0GJKo1fb^o`1QZ?n0/mGo]mGWok7A
iOn_d>CofNWbogjbe?l0IZ_o1fb^o`U][olAL[44oa=c/P0:o`Y^[ol7K:ko0FV/oc>6_Oono_ooloSk
o`1PYol7K:ko06J[of2Qb`Cooooo00?oN:kBo`e_/?l6K:h00_l7K:h04Ol6Jjko:82iooooooo9gngo
2Vn_o`=Z[Ol4JZgo2Fj_oenPb_nYc>?o]mCWohZif?lQO;Oo1Vb^o`I[[_lHM[?oY<WQ00;ooooo01?o
c>3^oc:5_?l0Ij_o1fb^o`1TZ_m@V<KoP;?EoenPb_l0Ij_o1fb^o`AZ[OlQO;Oo_=SZooooooo<hNko
;hBko`1WZol7Jjko3G2`00Co4g>b01Co4W:ao`M[[Ol4JZgo4G6aoio6h?ooooooP[GFo`U][ol6Jjko
0fV]oaMf/omm/MCo/m;Vojg>i?m/Yloo3W2ao`=Z[Ol0J:co<XJlolgRk`;ooooo01Co=hVno`=Z[Ol7
K:ko1fb^okSEionadNGo/=3Uok[Fj?o[l_Sooooook;Bi_lEMK?o77ReogfaeOnge>OoH:3:o`U][ol7
K:ko2fj_og>/d_oooooo3?ooool01?ono_kok?7gojo0g_n[_M/2ojbnf`05oj^mfond`mkogN7^oock
noojnOX00_oinOX02OohnO[oo?ckom?OjonS`=[oY<7KoibkeomiXl_oGHk1oeR;`002oeN;_`07oe27
_OmoXlgoZ;_JojZlf_n_`=coe=g]ooSio00_ooooo`04omSHf?nEUIGobl_;ooclo1[ooooo00Woo_kn
od51@OlJ6Q[oT92@oj2PX?ooooooh^;Ro`000?n5QHD00oooool05?nFUYKo0P82om3@d?ooooooTY:B
oinOWoono_koJ6QXoaDE5OnJVY[oO7aloooooomKFe_o=cLgon;Rh_mRHV;o/[:bomoOgol71`OoG5aL
0_ooool01?o^k^koFUYJoa/K6oo>c/h4ooooo`0Iokno_ol10@7o^;Rhoooooookno_o_knookNg]onk
^k_o1`L7okBd]?n/[:co]KFeoooooolf=SKog]kNooooooomoOgo5ADEoc4a<OnPX:3o^KVioooooonI
VIWo0@41okJf]P03ooooo`0Dof5QHOl=3@gooooooooooon2PX;o^KVionk^k_lk>c_oA4A4og=cLonf
][Koooooob4Q8Om]KFgojNWYodA4A?oEeMGo^[Zjo`410On;Rh/2ooooo`04om[Jf_l/;2coATI6onKV
i]3ooooo00?o0000oiBDU?ooool01oooool00onf][Ko0000on?Sh`27ooooo`00C?ooool01OnVb^;o
05fVo`M/[_l0G:Go]]CW00Cooooo00?of>Obo`1SZOl7K:h02?l7K:h02?l0IJ[oRk[Iooooooocn?_o
062Wo`M/[_l0IZ_oH:7;0oooool00onVb^;o6WRdo`E[[@03o`M/[P08o`I[[_lZPKWoooooofFTcOl0
HZWo0fV]oa1a/OnXbn<4ooooo`0=oo?ho?l2JJco1fb^o`=Y[OlhRKkoloWkoooooonZcNCo5GBco`=Y
[Ol0I:WoIZC=oo;gn`02ooooo`05oh2ceOl0IJ[o1F^]oa1a/OnB_]`00_ooool00omIWLWo06FZo`M/
[P07o`M/[P09o`1X[?lkR[oohNgfon7]m_lfR;ko06R/o`9Y[?lSO;Oognce00Cooooo00Wo/=3Vo`1M
Y_l7K:ko066Xog>/dOojo?koooooocN9__l3JZd00_l7K:h6ooooo`03ooKio?nMa=ooe>Ka00?ooooo
00Co3G2`o`M/[_l6Jjko<8Bkooooool>ooooo`03oo_lo_nocN?oZkgJ00?o[;kK00_o[;gKolgFj?of
m_SonO[kooSin_ohn?Woo?[jom?NjonD]]GoKic8oeF:_P05oeN;_`09oe27_OmlX<co_L_Son?Zloon
o_oolOGiol_FjOna`]kodmg]02gooooo00Cof=SHoiFEUOo;bl_oo?cl6oooool02on9RHWo0000olC4
a?nGUiOoHV9RodM7Aol0003oPX:2oooooonUYJGo1PH600Co0000017o7QhNobl_;oobl_;o`l?3o`00
0?nJVY[o[jn_ohZ:R_mRHV;o0000ok>c/oooooooSXj>ogmoOol61PKo0000ooWin@02ooooo`03ojb/
[?l0003oT92@00Gooooo01_oFUYJoaXJ6_ooooooooooonWYjOlm?Cgo6ATIob@T9?o>c/koooooohN7
QomcLg?o1@D5ok^k^oono_kooooooeYJF_l?3`oof=SHohN7QomPH63o;Bd]o`T92Ond];Coooooofe]
KOl410@00ol000004Ol20P;o92@ToeYJF_ooooooQ8B4oaDE5Onf][KoRh^;ojj^[_lZ:R[o10@4onWY
jOoalO7oM7Adofi^K_l0003o=CDe00?ooooo00?oJ6QXo`000?o6a/H0Ioooool00ooShn?oBTY:o`00
0002o`000004oa/K6om/K6cog]kNooknoP;ooooo00OooOgmolG5aOlc<c?o0000o`/;2omXJ6Soi>CT
00?ooooo00Oo5aLGogEeMOooooooooooon?Shol0003o][Jf00?ooooo00Oo_;bloc@d=?l0003o7alO
oinOWonNWYkoAdM700Wooooo00KolO7aoh61POlH61So0000ocHf=_nKVi/2ooooo`07ojBTY?lB4Q;o
cLg=ooooooo2`/;o0P82ol[:bP03ooooo`06onWYjOmbLW;o410@o`820_le=CGoYZJV0oooool00olc
<c?oHF5QooCdm002ooooo`07on_[jol0003o/K6aoooooooMgMgo9bLWogemO@08ooooo`09ookno_oG
emOoEeMGo`000?l=3@goOGemok2`/?m5ADGof=SH00;ooooo00So0000oi2@T?nc/k?o>SXjo`000?lH
61SoQ8B4onOWi`;ooooo00Wo][Jfo`000?oLg=coO7aloalO7ol0003o=3@dojVYZOono_h00_ooool0
0omYJFWo>CTion?Sh`02ooooo`03o``<3?n2PX;ooooo00;ooooo00OojNWYofm_KolD51Co0000obHV
9_nDU9Col_;b00;ooooo00Solo?cohR8R?l92@Wo10@4oe1@D?nf][KoK6a/ohb<S0;ooooo00?oA4A4
oeADE?o^k^h00_ooool00ol0003oVIVIooooo`02ooooo`07onGUiOmhN7So5aLGo`000?lU9BGoS8b<
ooGem@02ooooo`03ooWinOm_Kfoo92@T00?ooooo00[oLg=cobd];OoPh>3ooooooogmoOn;Rh_o5QHF
o`000?m0@43oclo??oooool004cooooo00GoY/[Ro`1MY_l7K:ko05bUokKDi`04ooooo`09oogmooln
S<3o0FN/o`M/[_l8KJoo4g>boaYg]?lGMK?o2fj_00;o1Vb^00So1FBZon7^m_ooooooloSko`1PYol7
K:ko06J[of2Qb`;ooooo00Go^mOYob5k]ol0J:co1Vb^o`]^[`02o`M/[P08o`I[[_l[PK[om_WlobV0
^Ol0J:_o06:YoejPb_o_m_X2ooooo`03obAm]ol0HZWo06BY00;o1fb^00[o16Z]ob9l]onieNSooooo
oh6ee_l0GjKo1fb^o`1NY_nhe>Ooooko0_ooool01OoIj?;o066Xo`M/[_l0IJ_oGIo:00;ooooo023o
X<OQoaEd/ol4JZgo1Vb^o`a_/?lIMkCo6WNdoa5b/Ol6Jjko1fb^o`9VZomXYLkooooooj_=holGMK?o
0fZ]o`1QZ?nJa=ooo?gnooooooobn?_o05RSo`1TZOl0IZ_o1ff^o`M/[_l0IJ[o@Hk1om_Ylooooooo
=hVno`=Z[@;o1fb^0oo/m?T00oo_m_[ooOknooooo`03ooooo`07oocmo_ofn_coc^C_o`a_/?l7K:ko
1V^^oc:5_03ooooooa3ooooo00?oeMk^ojbnfon/_]/00_n/_]/02OnV^]Wo^/SPon[/loogmoWolO?f
omoTk_nC/M?oDhVnoeJ:_P03oeN;_`0?oeR;_omGRkooDXVnodF1^_nK_=[omo[lonO/mOo0c^CoZKcI
ojZmf_n/_]_oZkgKol7?iOodmo[oo_ko02[ooooo00Cof=SHoiFEUOo;bl_oo?cl6oooool02?o@d=3o
20P8og9bL_oooooo^KVioclo?oln?Skog=cL1?ooool03_li>CWoATI6ooShn?oooooogMgModM7Aon4
Q8Co51@Doe9BD_ooooooa/K6obd];OlN7Qkoa/K60_ooool01?n[Zj_o:BTYocDe=OogmoL2ooooo`04
om_KfolJ6Q[oC4a<ooclo0Cooooo00?of][Jo`P82?n@T9000_ooool00ooCdm?o;bl_ogIfMP02oooo
o`04ooKfm_mXJ6So:b/[onSXj0;ooooo00SoZ:RXo`000?nQXJ7ooooooi^KVolX:2SoHV9Ronc/k0Co
oooo00ko2PX:ogQhN?oooooooooookFe]Om@D53oIfMWoa8B4_nATI7oooooojBTY?lL71co>3Phonk^
kP;ooooo00?oPh>3oaLG5omPH6000oooool01?nc/k?o0P82ohb<S?omoOeVooooo`0Con?Shom0@43o
>CTiojFUYOnNWYkoOGemoa/K6ol0003o`<30ookno_ooooooh>3Po`000?lc<c?oWYjNogemOOl92@Wo
AdM7onSXj002ooooo`0AoaLG5omeMGGooooooooooooShn?o0000okJf]_oooooooOgmoi6ATOl0003o
?Shnoi>CTon6QXKo2`/;obPX:?l10@402?ooool04?oUiNGo;2`/o``<3?mnOWkoVYZJoe1@D?l@413o
dm?CoooooonTY:Co4Q8Bolg=cOoooooo`/;2o`820_o:b/X2ooooo`0=ooShn?lJ6Q[o3@d=ogUiNOnJ
VY[oBTY:o`000?miNGWono_koooooolc<c?oHF5QooCdm002ooooo`07on_[jol0003o/K6aoooooooM
gMgo9bLWogemO@07ooooo`0:ookno_oEeMGo0000oa`L7?n6QXKoUIFEob`/;?lH61So0000ol_;b`;o
oooo01So0000obTY:Ol61PKoIfMWoj2PX?mRHV;o10@4oc8b<_oKfm_ooooookJf]_l@413o8b<SoaXJ
6_n9RHWoUIFEoclo?ol0003oLg=cooclo?ooooooJFUYocTi>OoShn<2ooooo`0Fo``<3?n2PX;ooooo
ookno_oNg]ko:RXZo`l?3omgMgOoWinOoe9BD_lP823oclo?ooooooojn_[o<30`o`820_m_KfooVYZJ
oeUIFOl20P;o3Ph>ofIVIP;ooooo00?oA4A4oeADE?o^k^h00_ooool04Ol0003oVIVIooooooono_ko
c/k>oadM7Ol71`OoK6a/oj^[ZomDE5Co0`<3od];Boo_knooooooooWinOm_Kfoo92@T00?ooooo00_o
Lg=cobd];OoPh>3oooooofMWIol10@7oKfm_oiVIVOlW9bOo7AdMoo;blP0nooooo`00C?ooool01OnV
b^;o05fVo`M/[_l0G:Go]]CW00Cooooo02?ooOknoiK1g_l0HZSo16Z]oaId/onYc>?oooooon;]m_lg
R;ko06R/o`1VZ_m@UlKom_[looooooocn?_o062Wo`M/[_l0IZ_oHJ7;oooooooNk?Co=XRmo`1TZ_l7
K:ko0VV/of:Rc?l;Kjoo1fb^o`I[[_l[P[[oj?7go`=X[?l4Jjgo062WohJgf003ooooo`03obf2^_l2
JJgo0fZ]00;o0fZ]00Wo0FV/o`mb/OnB_]cooooooh>feol0H:Oo1fb^o`1LYOoBi?000oooool01Oof
n_co062Wo`M/[_l0IZ_oH:7;00;ooooo00Gog^_docN8__l0Ijco06N[od6>`002ooooo`0;ohjlf_l0
IJ[o0fZ]oaah]OnadNGoooooohVifOl3JJco1F^]o`1MY_oFio800_ooool00oocn?_o05nWo`=Z[@03
o`=Z[@06o`1UZ_lMNKGoaMg/oooooolgRKko0fZ]0_l7K:h2o`1PY`03o`1LYOlRO;Koio7f00;ooooo
00Gon_cmonG`monXbn;oHJ;;o`1WZ`02o`M/[P03o`Q][_mKWlWooooo0?oooooo4?ooool02oo]l_So
]lKPojbnf_n[_M_o[;kKojVkfOnd`moo`/kSojo0g?n/_M[oQZK>00?oEh^o00[oFHbooeJ;_om=R;go
AXJloaef/ol5JZgoP:[Aok71g_nX^m[oZ[cJ1?n/_]/01?nZ_=[o]/KQonO]mOoloOhYooooo`04omSH
f?nEUIGobl_;ooclo1cooooo00?o8b<Soa/K6oooool02?ooool00on1PH7o7alOomkNgP0Cooooo`04
ono_komKFe_o61PHolK6aPGooooo00?oNWYjoaDE5Oo`l?003?ooool00oojn_[o1`L7od];B`09oooo
o`03oe9BD_lg=cOooooo01?ooooo00CohN7QobTY:Olk>c_oiNGUI_ooool00ooShn?o>3Phofi^KP04
ooooo`07ocHf=_m5ADGono_koogmoOn4Q8Co3`l?oo;blP02ooooo`03ojNWYolG5aOo_Kfm00;ooooo
00co5aLGogEeMOooooooooooon?Shol0003o][JfoooooooGemOo:BTYodi>C_oclo<2ooooo`03olS8
b?l<30co1PH600Oooooo00Cono_koda<C?lO7aooi>CT0oooool02_n^[Zkoclo?oooooonTY:Co4Q8B
olg=cOoooooo`/;2o`820_o:b/X2ooooo`03ohJ6Q_l51@GocLg=00?ooooo00OoP820ob<S8oo=cLgo
oooooc<c<omQHF7om?Cd00;ooooo00Oojn_[o`000?na/K7oooooomgMgOlW9bOoOGem00Oooooo00Co
m?Cdof9RH_lH61SoeMGE0_ooool01?oYjNWo?Cdmo`000?o=cLd2ooooo`03o`000?l61PKo_Kfm00?o
oooo00So]kNgo`<30on3Ph?ooooookJf]_l=3@go;Rh^ooknoP?ooooo00OoKFe]o`d=3Oo6a/Kooooo
ofUYJOli>CWohn?S00;ooooo00Oo30`<oh:2P_oooooom?Cdof=SHolB4Q;oe]KF00?ooooo00Ko]kNg
on;Rh_ooooooXZ:Ro`410OnSXj<3ooooo`03ogMgMol0003oKVi^00;ooooo00?oA4A4oeADE?o^k^h0
0_ooool01ol0003oVIVIooooooobl_;oIVIVoa<C4oo@d=000oooool01on^[Zko0000oiFEUOomoOgo
nOWiofm_KolT92@00oooool01_mcLg?o;Bd]on;Rh_ooooooT92@oiNGU`;ooooo00?oj>SXo`000?nV
YZH0?_ooool004cooooo00GoY/[Ro`1MY_l7K:ko05bUokKDi`05ooooo`0Ron;^m_l=J:co1V^^o`1S
ZOmEV/Soo_oooic4g_lBLK7o16^]o`1QZ?nVbn?oo?gnooooooocn?_o062Wo`M/[_l0IZ_oIZC=ooGi
o?m@UlKo06BZo`M/[_l0Ij[o?8^ooooooolDM;;o1fb^o`I[[_l/P[[ohNgeo`1MYOl7K:ko05nWohRi
f0?ooooo00koF9c8ocJ8__lgRKko>8VnocN9__lgR;ko?Xc0oj78hOooooooPkKGo`1PYol7K:ko05bU
oloRk`?ooooo00GoloSko`1PYol7K:ko06J[of2Qb`03ooooo`0Aof>Sc?l4JJco1fb^o`1NYooEi_;o
nOcnocF7_Ol1JJgo0FV/ocb;_oo[loSoooooog^ae?l0HjWo1fb^o`1LYOoHj?800_ooool00ooenOco
<X2iocN9_P02ocR9_P07ocN9__lcQ[coAI72olgRkooooooo=hVno`=Z[@02o`M/[P;o0VV/00ko06JZ
obn4^ooYl_OoooooooOjo?nTbN7o6WJdo`1QZ?l0IJ[o1V^^o`AZ[Ol2JJgo8WfgolCLjooooooo4_oo
ool08?oin_coa];VojbofonZ_=[o[;kKoj^mf_nY_=[oZkgKok30g?n6YlooF8^ooeV<_omBRKkoAXFk
ocj2^_lDL[;o87JcoeB;_omKRkooOj;<ojNkfOn]_]_o[;kKoj^mfon/_]_o[KoKoj^nfon/_]_oZ;cI
ojbng?oEg^gon?[l:?ooool01?oHf=SoUIFEol_;boolo?`Looooo`03oh61POl0003oi>CT00Sooooo
00?oinOWojRXZ?o_knl05?ooool00onSXj?o0000ohn?S`05ooooo`03oo[jn_l?3`ooMgMg00cooooo
00Con?Shodi>C_lE5AGomOGe2?ooool00ooIfMWoZ:RXooooo`0Dooooo`03of5QHOl0003ob/[:06Ko
oooo00?ohn?SocTi>OmYJFT01?ooool01_nHV9So3@d=oo[jn_olo?coK6a/oalO7`?ooooo00?od=3@
oaPH6?nNWYh00_ooool02olG5aOoMGEeoooooooooooohn?So`000?nf][KoooooojFUYOlF5QKo_kno
00Cooooo00?oIFEUo`D51Oooool01_ooool01?oFe]Ko3Ph>oiZJV_ono_h6ooooo`07ojBTY?lB4Q;o
cLg=ooooooo2`/;o0P82ol[:bP02ooooo`03obh^;_m?Cdoooooo00?omoOg00OoinOWonWYjOoooooo
oooooc<c<omQHF7om?Cd00;ooooo00Oojn_[o`000?na/K7oooooomgMgOlW9bOoOGem00Oooooo00?o
j^[ZoadM7OmkNg/01?ooool00onRXZ;o0000ol_;b`02ooooo`03o`000?m2@T;ooooo00?ooooo00Oo
o?cloeMGEom4A4ComoOgokZj^_l0003o^k^k00Cooooo00Oog=cLoa8B4_n3Ph?oooooofUYJOli>CWo
hn?S00;ooooo00Ko30`<oh:2P_oooooojn_[obTY:Om]KFd7ooooo`03od];Bolk>c_ooooo00?ooooo
00?ofm_Koa4A4OmUIFD00_ooool00om4A4CoE5ADonk^kP02ooooo`06o`000?nIVIWoooooom?CdolK
6a_oS8b<1Oooool01_mBDU;o<30`oo[jn_oinOWoKfm_ob@T90?ooooo00?oLg=cobd];OoPh>001?oo
ool01?o/k>coTI6Ao`000?nl_;`nooooo`00C?ooool01OnVb^;o05fVo`M/[_l0G:Go]]CW00Gooooo
00_omOWlof:Sc?l0I:[o06N[ocZ:_ooKj_?oHZ;<o`1RZ?l4JZco4W:`oncdn@02ooooo`0Foo?hnol0
H:Oo1fb^o`5W[?mFVlSoTkoKo`1WZol5Jjko06FZoaei]Oo@i?3ooooooa=c/_l7K:ko1V^^ob^2^_o^
mOWo4GBbo`9Y[?l0HjWoGj3;oo?gn`_ooooo00GoPkKGo`1PYol7K:ko05bUoloRk`03ooooo`05oo?h
nol0H:Oo1fb^o`1VZomPXL/00oooool02_nlenWo8Gbfo`A[[Ol0IZ_oRk_IomSXlol0GjOo1fb^o`U/
[_mc[=42ooooo`06oiW3g_l;Kjoo16^]o`1QZ?nKaMoonocm2oooool04olgRKko0fZ]o`M/[_l7K:ko
>h^oocV:__leQkgoG9k9onkenOoooooo]mGXoaEe/ol0I:Wo1fb^o`5Y[?l0Ij_o6gReocb;_on]cn@0
oooooolEooooo`0OomSPkOna`]koZKcJoj^mfon/_]_oZ[cJojfnfon=Zm7oAhJloc^0^OlePKWo4W2a
obmm]omVTL;oGXk0oeR;_om@QkgoOj?=ojRkf_nZ_=[o[/3LokG4gonnb^;o_L_Rojjog?nZ_M[o[;kK
ojZmfonV^MSo`]3Uongbm`0Wooooo`04omSHf?nEUIGobl_;ooclo1cooooo00?obLW9o`000?n5QHD0
7oooool01?oDe=Co6a/Kodi>C_ofm_H5ooooo`03oinOWol410Coh>3P00_ooooo00Cono_koiVIVOl3
0`?o/;2`7oooool01?na/K7o1PH6oh^;Rookno]Uooooo`03on?Sholi>CWoJFUY00Cooooo00KoTI6A
o`d=3OoinOWoo?clofm_KolM7Ad3ooooo`03omGEeOlF5QKoVIVI00;ooooo00_o5aLGogEeMOoooooo
ooooon?Shol0003o][Jfoooooon;Rh_o9RHVom[JfP04ooooo`03oijNW_l30`?ooooo00Kooooo00?o
`/;2o`<30oo:b/X01oooool01onTY:Co4Q8Bolg=cOoooooo`/;2o`820_o:b/X00_ooool00ol0003o
D51@ogIfMP03og1`L007ogUiNOmlO7cocLg=oooooolc<c?oHf=SooCdm002ooooo`07on_[jol0003o
/K6aoooooooMgMgo9bLWogemO@07ooooo`03onCTi?l51@Go];Bd00Cooooo00?ob/[:o`820_o:b/X0
0_ooool00ol0003oUYJFooooo`04ooooo`06ogYjN_l_;boojn_[ok^k^ol0003ok^k^1?ooool01ooY
jNWoBTY:oeaLG?ooooooJFUYocTi>OoShn<00_ooool01_l<30coPX:2oooooooTi>Co0@41ok:b/POo
oooo00?o7alOogalO?ooool00oooool00ooVi^Ko@D51oeiNGP02ooooo`03odA4A?mDE5Cok^k^00;o
oooo00Ko0000oiVIVOoooooo`l?3o`l?3oo2`/85ooooo`06oinOWol61PKonOWiooWinOm_Kfoo92@T
0oooool00omcLg?o;Bd]on3Ph002ooooo`05on[Zj_nKVi_oB4Q8o`410OmFEUH0?oooool004cooooo
00GoY/[Ro`1MY_l7K:ko05bUokKDi`05ooooo`0;oo_mo_n/c^Co05nVo`9Z[OlJMkCoOK;DodVCa?l0
Ij_o06:Yof2QbooamoX00_ooool02_ocn?_o062Wo`M/[_l5Jjko5gJdoaei]Ol1J:co0VN[oaE_/?n/
cN@2ooooo`0:oa=c/_l7K:ko1V^^ob^1^_okoOko?Hboo`1VZ_l1Ij_o9gnholoRk`Gooooo00?oS;_I
omSXl_ooool00oooool01On3]]Oo062Wo`M/[_l0G:Gocn;_00?ooooo00GoloSko`1PYol7K:ko06J[
of2Qb`03ooooo`0:oncdnOliR[ko0VZ]o`9Y[Om0SL7oTKkKo`1WZol4JZko7GVfokWEj0;ooooo00Ko
^]KYob5k]_l2JJgo0FJ[odVC`oomo_h4ooooo`03omg[m?nC_m_oio7g00Cooooo01;o=hVno`=Z[Ol7
K:ko1fb^onkenOoYl_OojO7hongdnOono_oooooooh6de_l0I:[o1Vb^o`AZ[?lSOKSoG9k:ojS<h_o/
m?SooooooaOooooo00goj>kfokk<honY^m[oYk[IokO8hOoAfn_oV[cJobin^?lLM;;o@HFkof>?`_mM
SL3oEX^o00;oEh^o00_oCXJlogbPc?n_`=co^lWPolKBi_oDfn_ofMo/omCLj_o2c^Co/<7MojZlfP02
ojbnf`04ojBgf?nda=koh>KaooknoRGooooo00Cof=SHoiFEUOo;bl_oo?cl7Oooool00olP823o?3`l
ooooo`0Nooooo`04oo[jn_mQHF7o5ADEolg=c@Gooooo00?oo?clobPX:?m<C4`03?ooool00ooUiNGo
20P8ofm_K`0Oooooo`04oo7alOlZ:R[o>SXjong]kFGooooo00?ohn?SocPh>?m`L7000_ooool01?ok
no_oc<c<oaHF5_mUIFD2ooclo003ofm_KolM7Agooooo00;ooooo00?oe=CDoaHF5_nJVYX00_ooool0
2olG5aOoMGEeoooooooooooohn?So`000?nf][KooooooiRHV?lS8b?odM7A00Cooooo00?oR8R8o`<3
0oooool01_ooool00oo<c<co20P8ok6a/@07ooooo`07ojBTY?lB4Q;ocLg=ooooooo2`/;o0P82ol[:
bP02ooooo`03ob0P8?l=3@goC4a<00;oAdM700SoBTY:ob/[:ol0003oX:2Poooooole=CGoDe=Coo?c
l`;ooooo00Ookno_o`000?n`/;3oooooomgMgOlW9bOoOGem00Oooooo00?oinOWoa<C4onOWil01?oo
ool00onk^k_o0@41ol[:bP02ooooo`03o`000?mkNg_ooooo00Cooooo00KoJFUYoc@d=?o_knoo^k^k
o`000?oDe=@4ooooo`07onSXj?lk>c_oKVi^oooooomYJFWo>CTion?Sh`02ooooo`06o``<3?n2PX;o
ooooonOWiolD51CoSXj>1oooool00ole=CGoI6ATooooo`03ooooo`03onCTi?l];BgoHF5Q00;ooooo
00?oA4A4oeADE?o^k^h00_ooool01_l0003oVIVIooooooo>c/ko7AdMojFUY@Gooooo00KoMGEeobHV
9_ojn_[onOWiofm_KolT92@3ooooo`09ogIfM_l/;2coh>3PoooooooXj>SoGUiNo`000?ln?SkoW9bL
043ooooo001<ooooo`05ojK:h_l0GJKo1fb^o`1LYOnfe>L01_ooool02_oYl_So7WReo`=X[?l4JZgo
8gfgob1k]_l2JZgo06:Yojc>i?okoOh2ooooo`0:oo?hnol0H:Oo1fb^o`M/[_l3JZgo0VV/o`AY[Ol<
K:goT;kKoogmoP;ooooo00_o4g>bo`M/[_l6Jjko:H6ioooooomk/MCo05bUo`I/[_l0I:[oN:oBookn
o`03ooooo`05oik5gol0GZKo?8^oohnmf_oHj?800_ooool01On3]]Oo062Wo`M/[_l0G:Gocn;_00?o
oooo00GoloSko`1PYol7K:ko06J[of2Qb`04ooooo`09ogV`d_l<Kjoo1f^^o`I[[_lhR[ko16^]o`E[
[OlkRkook_Gi00;ooooo00Koi_3gocb<_ol0IJ[o1Vb^o`1X[?nednL3ooooo`06ooWkoOmMWl[o05jV
oe6Ha_nSb>7oj_;h0_ooool01?lgRKko0fZ]o`M/[_l7K:h6ooooo`05ogF]d_l0GjOo1fb^o`1OY_n_
d>D0oooooolKooooo`09ooGgnooBfncoe=k]ongbmoohnOcoT;WHoeJ;_omOS/7oFXc000;oEh^o01Go
EXZooe>8_OmFR[ooFhk1oiNceOo@f>WohNK_on3TkooKhNkoe]k[omCLjooBfN[oa]7Wok?3gon/_]_o
ZkgKojfnfonW^mWo[;kKom;Kjoohn_`09?ooool01?oHf=SoUIFEol_;boolo?`Kooooo`05ooShn?n/
[:co61PHo`000?oTi>@07Oooool01Oofm_Ko_Kfmocdm?Ol0003oXZ:R00Kooooo00?oZZZZo`000?nm
_Kd02_ooool01OoYjNWoSXj>o`000?lZ:R[ol_;b01gooooo00Gok^k^ok:b/_lD51Co0000omoOg`1U
ooooo`0=on?Shom1@D7o>3PhohF5QOn7QhOoKfm_ob4Q8OlU9BGobLW9ookno_olo?coKfm_oadM7@03
ooooo`03omCDe?lF5QKoVYZJ00;ooooo00_o5aLGogEeMOooooooooooon?Shol0003o][Jfooooooo6
a/Ko6ATIoh:2PP03ooooo`03on[Zj_lb<S;o1@D500Oooooo00Cokno_obh^;_m:BT[om_Kf0oooool0
2_oLg=coinOWoooooonTY:Co4Q8Bolg=cOoooooo`/;2o`820_o:b/X2ooooo`03ofIVI_lV9RKooooo
00?ooooo00OoQ8B4oaLG5oo:b/[oooooocdm?OlG5aOol_;b00;ooooo00Oofm_Ko`000?nb/[;ooooo
on?SholY:BWoPX:200Oooooo00Col?3`odA4A?lk>c_on?Sh0_ooool01?okno_oJf][o`000?o<c<`2
ooooo`03o`000?lJ6Q[oi>CT00?ooooo00OofMWIoalO7omPH63onOWiokRh^?l820SoHF5Q00Cooooo
00OoX:2Po`T92On^[ZkoooooofUYJOli>CWohn?S00;ooooo00Oo30`<oh:2P_oooooom?CdoeiNG_lT
92CoiNGU00?ooooo00Kof][Jonk^k_ooooooPX:2o`/;2ooPh>03ooooo`03ojNWYol51@GoJVYZ00;o
oooo00?oAdM7oeMGEoohn?P00_ooool01ol0003oVIVIoooooooWinOo@d=3oc/k>oo_knl00oooool0
2?oLg=co4A4Aofi^K_olo?conOWiofm_KolG5aOojn_[0_ooool01omWIfOo;Rh^on7QhOooooooZj^[
o`000?nXZ:P0@_ooool004cooooo00GoY/[Ro`1MY_l7K:ko05bUokKDi`06ooooo`09ooGjo?ml/MGo
062Wo`M/[_l1JJco0fV]o`9W[?lUO[Soi_3g00?ooooo00?oloSko`1PYol7K:h00_l7K:h01?l5Jjko
06BZoffYd?ofn_`3ooooo`0Coa=c/_l7K:ko1V^^obR0^OoooooobMo]oaQa/Ol2Ij_o16V]o`ia/?m/
ZLoo`M[ZomGVlOnB_mco4g:bo`M/[_l0I:[o06N[ojc>i002ooooo`05oh>feol0H:Oo1fb^o`1LYOo?
h^l00oooool01Oocn?_o062Wo`M/[_l0IZ_oH:7;00Cooooo00SoeNKaoaei]Ol5Jjgo1V^^o`1WZol7
K:ko3G2`oh2dePCooooo00koR;WIo`Y/[_l4Jjgo0VV/oamj]_n;^mWodNC`olSNkOm/Z<oo0FR/o`A[
[Ol0G:Go8gbhom7Tl0;ooooo01?o=hVno`=Z[Ol7K:ko1fb^oo;gn_o^mOWok_CionofnOojo?gooooo
ohFfeol2IZ_o1V^^o`1PZ?nPan3ok_Giom3Sl?n6^=Sok_Gi0?oooooo6Oooool01OoYkoKodmg/okg;
h_n8Z<ooF8^o00;oEh^o01SoEHZnoe:8_OmJS<3oKI[6og^Uc?n2Z/oo^lkSonCXlOoRio3ogn?_om[P
kOoHgngoe=g[om;Jj_o?en[obM?WokW8hOn]_]coZkgJojbnfonZ_M[oYk[Iol7?i?oXk?DSooooo`04
omSHf?nEUIGobl_;ooclo1_ooooo00GomoOgoj>SXomkNg_oJ6QXon;RhP0Mooooo`05ooKfm_ne]KGo
OWinofm_Koo5aLD01_ooool00oohn?SoTY:BokZj^P0:ooooo`05onOWion?ShooMgMgoh61POoalO40
7Oooool01Oo/k>coYZJVogUiNOm^KVkojn_[06Gooooo00Sohn?SodM7Aol<30co<30`ob0P8?l0003o
71`LolS8b0;ooooo00?oo?clofm_KolM7Ad00oooool00ooDe=Co5QHFoiZJVP02ooooo`0AoaLG5ome
MGGooooooooooooShn?o0000okJf]_oooooomOGeofIVI_l61PKoQ8B4olW9bOnn_[ko?Cdmo`d=3Ol6
1PH02?ooool04?nb/[;o30`<oe9BD_nj^[[ocLg=oiVIVOle=CGob<S8oooooonTY:Co4Q8Bolg=cOoo
oooo`/;2o`820_o:b/X2ooooo`0HomOGeol0003oADE5okRh^?o7alOoLG5ao`000?m^KVkomOGeoooo
ooll?3co0000of=SHoo6a/Ko_knoodQ8B?l:2P[ohn?Soo[jn_ni^KWo6QXJof5QHOoKfm_omoOg1Ooo
ool02_olo?co/;2`o`000?mOGeoo`L71ol[:b_mYJFWo3`l?o`000?o;bl/2ooooo`0Ho`000?l?3`oo
=CDeojVYZOoAdM7oZ:RXocHf=_lB4Q;oa/K6oooooonf][Ko4Q8Bo`/;2omWIfOo`L71ol[:b_mmOGgo
4Q8Bodi>C_o`l?3oooooofUYJOli>CWohn?S0_ooool0>ol<30coPX:2ooooooono_koalO7o`D51Olg
=cOo[Jf]om7AdOnLW9co?cloolc<c?oooooohn?So`d=3Olb<S;o/K6aolg=cOnFUYKo51@Do`410OmX
J6Soooooon[Zj_lc<c?o@D51okVi^Oo/k>coooooo`000?nIVIWooooooogmoOnb/[;o1`L7od=3@on_
[joof=SHoijNW_l];Bgo71`LomWIfOono_konOWiofi^K_l0003oEEEEolK6a_n/[:co5ADEof1PH?od
m?Cooooool71`Ol0003oXZ:RolG5aOmHF5SoSHf=03oooooo001<ooooo`05ojK:h_l0GJKo1fb^o`1L
YOnfe>L01oooool00onmf>[o066Xo`E[[P02o`M/[P03o`1OYomb[=7omOWl00?ooooo00?oloSko`1P
Yol7K:h00_l7K:h00ol0HZSo@ho1onG`m`04ooooo`0Coa=c/_l7K:ko1V^^obR0^Ooooooom_[lohVj
fOl0H:Oo06R/o`=Z[Ol0Ij_o:H2iocR9__l9KZoo0fZ]o`M/[_l0Ij_oBYC3on_cn@02ooooo`05oh>f
eol0H:Oo1fb^o`1LYOo?h^l00oooool01Oocn?_o062Wo`M/[_l0IZ_oH:7;00Cooooo00?oo_koocF8
_Ol5K:d00_l7K:h00ol6Jjko6GJcomCVl@04ooooo`0>onWcn?m:U<Co06>Yo`E/[_l0J:co0fZ]ocB7
_Ol^Pk_o0FR/o`A[[Ol1J:co0VR/oh>eeoodnO/2ooooo`0CocN9__l3JZgo1fb^o`M/[_m=U/GoBYC4
odNB`omOX<_odnC`oooooonnf>[o7GVfo`1VZol5Jjgo6gRdodRC`oldQkgo1fb^oh^jf@3ooooooaKo
oooo01kom_SkomWQkoo6d^Ko//?NojNkfOn]_]_oQjO?oeN;_omCR;koDHNmof2@`_meX<WoRJgAoi>e
e?nJ^MOoT;CDokc>h_oQio3ohnK`omoSkooLh^gof^3]omKNjooCfn_od=SYolcEj?o8dnKo_L[Rojo0
g?n[_MX2ojbnf`03ojJif?ndaMoof^;_02;ooooo00Cof=SHoiFEUOo;bl_oo?cl7_ooool00oojn_[o
ooooooooo`0gooooo`03oo_knooooooooooo08Kooooo00gohn?Soc/k>omGEeOohN7QomGEeOmkNg_o
7alOol;2`_ono_koooooooclo?mPH63o1@D500?ooooo00?oclo?o`000?n?Shl00_ooool01ol0003o
IVIVoooooooooooohn?So`000?nf][H00_ooool02?oPh>3oGEeMo`/;2ol?3`oo7alOoeUIFOm^KVko
10@42Oooool03onZZZ[o<c<coaHF5_lB4Q;o5aLGodm?Coo`l?3oooooojBTY?lB4Q;ocLg=oooooonk
^k_o0000olC4a003ooooo`07oifMWOl[:b_o3Ph>o`h>3_lC4a?oLG5aonGUi@02ooooo`0>odY:B_m9
BDWoBDU9ob`/;?l820So2`/;ohf=SOooooooiNGUodm?Col0003o1PH6oe=CDooShn<6ooooo`09oo[j
n_mnOWko4a<Co`T92OlH61SoAdM7og=cLolE5AGoclo?00;ooooo01?o0000of9RH_mJFU[o9BDUoaDE
5Ol92@Wo=cLgojb/[?omoOgoooooojj^[_l0003oU9BDoclo?olQ8B7o3`l?o`L71omNGUkog=cL00;o
oooo00?oJFUYocTi>OoShn<00_ooool03?l0003oMGEeooooooooooooo?clojRXZ?lf=SKo4A4AoaDE
5OlB4Q;oDE5Aon?Sh`;ooooo017o/;2`obh^;_l51@Go51@Doc<c<om/K6co>SXjog5aLOooooooMgMg
o`820_l410Co30`<ojRXZ?oooooo0000ohj>SP02ooooo`08ooWinOnQXJ7o;Bd]o`d=3OlJ6Q[o30`<
ochn?_nn_[h2ooooo`08ooWinOmaLG7o92@TofYZJ_lI6AWo0000ob@T9?o5aLD2ooooo`06ooCdm?mV
IVKo3@d=o`X:2_lR8R;oUYJF?oooool004cooooo00GoY/[Ro`1MY_l7K:ko05bUokKDi`07ooooo`07
on7]m_lcQ[go0FN[o`M/[_l5Jjko06:Xok7AiP04ooooo`07oo?hnol0H:Oo1fb^o`Q/[_l0HZWo;H:k
omGWl@05ooooo`04oa=c/_l7K:ko1V^^obR0^@;ooooo00Gol?Kjoh6de_l@LK7o05nWo`1VZ`02o`1W
Z`05o`1X[?l0IZ_o066XodbEa?oIj?<00oooool01On3]]Oo062Wo`M/[_l0G:Gocn;_00?ooooo00Go
loSko`1PYol7K:ko06J[of2Qb`05ooooo`07ohJheol?L;3o1fb^o`M/[_l6K:ko<HFloognoP05oooo
o`06omSXl_mVY<go06FZo`1TZ_l0IZ_o06R/0_l0Ij/01?l0HZWo0FV/og:[dOo]m?T3ooooo`0DocN9
__l3JZgo1fb^o`M/[_l0IJ[o06J[o`1TZ_lKMkGo`=[Zooooooofn_coPkKGo`9Y[?l0IZ_o0VV/o`1V
Zol0I:[o06>Yoa1a/OoQkOGooooooa?ooooo027oinceolkHj_nlb^;o[[oLojRkfOnZ_M[o[;kKojno
g?n1Y<goDXNnofZHa_n4Z/ooT;;CoiVie_nN_]SoV[[GoiNgeOn>/]?o_<oSon?XlOoTj?7oh>G`omkS
kooKhNgof=o]omCLjooAfN[ocMGXolWCi_o5dNKo_L[Sok;3g_n[_]/00_n/_]/01?nY_=[o[l3Lol[F
jOoloOhPooooo`04omSHf?nEUIGobl_;ooclo>7ooooo00?ohn?SocTi>Om/K6`00_ooool02?ohn?So
7QhNofa/K?ohn?Soooooookno_o@d=3o]KFe0oooool00ooalO7o/k>comkNgP02ooooo`07okVi^OoD
e=CooooooooooooShn?o0000okJf]P03ooooo`07ono_konj^[[oY:BTok6a/Oo_knooVIVIo`<30`0:
ooooo`05omgMgOn_[jooY:BTokfm_OoWinL00_ooool01onTY:Co4Q8Bolg=cOooooook>c/ok:b/_o_
knl01?ooool01OoGemOo[:b/ojFUYOo4a<Con?Sh00?ooooo00kodM7Aon3Ph?oRh^;o];BdojFUYOo4
a<ConOWioooooooemOGoZJVYoaXJ6_mADE7o_KfmooGem@Oooooo00Soo?clolO7aonUYJGoZ:RXomkN
g_oalO7oa/K6oo?cl`;ooooo00Oo[:b/on3Ph?o`l?3o_KfmojBTY?n`/;3ogmoO00?ooooo00SoinOW
oj^[ZoomoOgohN7Qok6a/OnTY:Co_[jnonk^kP?ooooo00?oJFUYocTi>OoShn<00_ooool00one]KGo
f=SHooooo`03ooooo`06omkNg_nb/[;oY:BTokZj^_oShn?ooOgm0oooool04?oJf][oZZZZojFUYOo8
b<SomoOgom?CdooLg=coooooolO7aol/;2co=SHfoiZJV_oNg]kooooook:b/_oOgml4ooooo`05om[J
f_n_[jooXj>SokJf]_oRh^800oooool02?omoOgofMWIolk>c_o_knooZZZZojJVY_oAdM7oo?cl0ooo
ool01Oo]kNgo^;RhojFUYOoAdM7oo?cl03oooooo001<ooooo`05oig4gol0C9go05bUo`1;W?n^cn@0
1oooool01ookoOkoOK7Do`1>WOl0G:Go05FRobb2^_oKj_<01?ooool01_obmo_o04nNo`1LYOl0FJCo
57>bokSDj0Kooooo00Co06BZo`1LYOl0FjGo4G>b0oooool02_ogn_go^MKXofVVcOlhR;ko06BYo`1I
Y?lCL[;o@Ho1oi2mf_oVl?L4ooooo`05ogJ^dol0Ciko05bUo`1;W?o:gnd00oooool01Oobmo_o04nN
o`1LYOl0EZ;oCiO600Gooooo00Koj?7go`AZ[Ol0G:Go05bUo`1RZ?n8^MP7ooooo`0:onoen_nMaMoo
FYg9obV1^_l0FjGo05nWob9l]omHW<So[loToo3fnPCooooo00?o8Wfgo`1JY?l0G:D00ol0G:D00ol0
FZCo3FnaokgGj@02ooooo`09oo7gn_nLaMoo;H:jo`1OYol0FjGo5WBcoeFKb?nSbN7omOWl0?oooooo
4?ooool09oomoOoog>C`ol7?i?nc`mkoZkkKojVlf_n[_]_o[;kKojZmf_nV^MSo/<3LojFlf_n=/=;o
V;WFoj2nf?nP_]WoW;cGoi^kf?nJ^]KoV;WFohncdonlcn?oi>WaonGYlOoRio7ognC_omcRk_oIh>go
eMg[om;Kj_o>f>Sob]CWolOBi_o2c^Co_/cSokO6h?n]_]coZkkKojbnf`02oj^mf`03okk<hoo/l?Oo
oooo01kooooo00Cof=SHoiFEUOo;bl_oo?clhOooool00ooShn?o>CTiofUYJ@03ooooo`03obl_;omL
G5comoOg00cooooo00Oom_Kfooooooooooooooooon?Shol0003o][Jf00Sooooo00?oU9BDo`<30ooo
ool04?ooool00onTY:Co4Q8Bolg=c@02ooooo`03ooWinOoooooooooo01Cooooo00?oh^;RobPX:?n1
PH40:?ooool00omYJFWo>CTion?Sh`02ooooo`03ooKfm_oooooooooo01Gooooo00?oATI6oeMGEoof
m_H00_ooool00oofm_Koooooooooo`1Jooooo`00C?ooool01Oo`m_[oeNC`omKWl_oEi?3oloSk00So
oooo00KokoGjomGUl?oFio;oeNGaonC_m_okoOh4ooooo`06oogno_oEiO7oe^ObomGVlOoOk?Gonocn
1_ooool01?oHj?;oe^ObomKWl_oLj_@4ooooo`08ooknoooamo[oi_3gomWXl_oEi_7og^cdonSamooi
nod5ooooo`05on_cn?oEiO7oe^ObomGTl?ogn_`00oooool01Oomo_koeNGaomKWl_oEi_7oiO3f00Ko
oooo00Gof^WcomKWl_oFio;of>Sboo;hn`08ooooo`08oo[lo_o]m?WohnofomKWl_oGio;oh^keonge
nOomo_h5ooooo`03omk/m?oFio;oe^Ob00Coe^Ob00?ofn[cooGio?ooool00_ooool01ooio?goi>of
omSWl_oFio;ognceoncdnOolo_h0ooooool?ooooo`06ooCgnooAf^[o]LKOok31gOn[_M_oZkgJ0_n/
_]/01_nZ_=[oY[[IokK4g_oFg^_oko7folgKj@;oXKoI01WoX;kIoijmf?nM_=SoW;_GoiZkeonI^MOo
T;?Cokg@i?oUj_;oi^[aon;WlOoPiO3ogN?^om[PkOoFgncodm_[om7HjOo<e^Sob=?VolC?iOo0cNCo
_/cSok_:h_n_`=goZkgK00;o[;kK00?oZkgKokK6gooJh^l07_ooool01?oHf=SoUIFEol_;boolo?cQ
ooooo`03on?Sholh>3SoKVi^00;ooooo00Cokno_oaDE5OmeMGGonOWi2oooool00oo[jn_o<S8bobl_
;`02ooooo`03on?Shol0003o][Jf00Sooooo00?oU9BDo`<30oooool04?ooool02?nTY:Co4Q8Bolg=
cOooooooQhN7oalO7onXZ:Sono_k5?ooool00ooKfm_o61PHogAdM00Xooooo`07ofUYJOli>CWohn?S
oooooooVi^Ko:2PXocTi>@0Fooooo`07ocLg=om9BDWokNg]oooooooFe]Ko7AdModm?C`1Kooooo`00
oooooooAooooo`05onW^m_o2cnKo//?Nojk0g?n[_M/00on/_]/07onX_=[oZ;_Joko;h_oSj?3ol_?g
ooOhnOolno[od]k[oj:ofOnQ_mWoX;kIoinnf?nM_=SoW;_Goi^kf?nJ^]OoTKCCokoAi?oVj_7oin[b
on?WlOoQiO3ogn?_om_QkOoHgngoe=g[om;Jj_o=e^Sob]?VolGAi_o0cN@00_noc><00onnbn?o/l?N
oj^mf`03ojbnf`03ojk0g?o9e>Won__m01cooooo00Cof=SHoiFEUOo;bl_oo?clhOooool02?oShn?o
@410oc/k>on_[jooQXJ6oadM7Ol?3`ooe]KF3?ooool00oomoOgo9BDUoc4a<@02ooooo`03on?Shol0
003o][Jf00Sooooo00?oU9BDo`<30oooool04?ooool01onTY:Co4Q8Bolg=cOooooooS8b<o`000?nj
^[X05Oooool00oobl_;o[jn_om3@d00Xooooo`07ofUYJOli>CWohn?Sooooooolo?co6a/Koc`l?00F
ooooo`07ok^k^ono_koon?Shooooooo^k^ko2PX:oe=CD`1Kooooo`00ooooooo>ooooo`04oo_loOoK
ho3o]<COojbng0Go[;kK027oZ[cKok72gOoDg>[ol?;eoo[jn_oinO[onOSiooShnOolno_odmo[oj;0
f_nQ_mWoX;oIoinnf?nN_MSoWKcHoibkeonJ^]OoT[CDokoAi?oWjo;oj>_bonGXlOoQi_3ognC_omcR
k_oIh>goe]g/om;Jj_o>enSobmCWolKBi_o1c^@00onoc><00oo0c>?o]lKPojfng003ojbnf`03ojZl
f_nian7ojnog01_ooooo00Cof=SHoiFEUOo;bl_oo?clhOooool02?oRh^;oATI6o`000?l0003o7alO
ofIVI_oBd];ooOgm3Oooool01oojn_[ono_koooooooooooohn?So`000?nf][H02?ooool00onDU9Co
0`<3ooooo`0@ooooo`07ojBTY?lB4Q;ocLg=ooooooomoOgonOWiooknoP0Fooooo`;oo_kn:?ooool0
0omYJFWo>CTion?Sh`02ooooo`03oo[jn_okno_ooooo01Gooooo0_ono_h3ooooo`03oo[jn_okno_o
oooo05[ooooo003ooooool_ooooo00GooOknonobn?o9e^So[L3LojZlf`05ojbnf`05ojjog?nlbN;o
g^;^ooSgnOolo?/00_ojn_X02ooinO[onOSiooShnOomno_odn3[oj;0f_nR_mWoXKoIoj2nfOnN_MSo
WKcH00;oVk_G013oT[GDokoAi?oXk?;oj>cbonGYl_oSio7oh>G`omgSk_oIh>goe]k/om?Kj_o@f>So
c=KXolSBi_o4cnGo`<cT1?noc><00onkb^;o[[oLojbnf`02ojbnf`04oj^mf_n]_m_of^;_ooknoaWo
oooo00Cof=SHoiFEUOo;bl_oo?clGoooool00ombLW;oe=CDooknoP2Hooooo`03on?Shol0003o][Jf
00Sooooo00?oU9BDo`<30oooool04?ooool00onTY:Co4Q8Bolg=c@14ooooo`03ofUYJOli>CWohn?S
07cooooo003oooooolSooooo00Koo?gnooWjoOoSj??o^<OQojRkf_nZ_MX4ojbnf`06ojjog?na`]go
aM3Ton[/m?ooo_coo?_k1Oojn_X01?oinO[onOSioocjn_oCh>/2oj;0fP0Foj6ofOnP_]WoWkkHoifm
f?nL_=OoW;_Hoi>ee?o0d^Coj>cbonW/l_oVjO;ohnOaon7Ul?oNhnoofn7]omSNkOoDg>_od=WZolcF
j?o9dnKoa=3Vol3=i0Ko_lcS00?o/l?Ooj^mfon/_]/00_n/_]/01?nW^][oa]?Woo?fn_ono_lGoooo
o`04omSHf?nEUIGobl_;ooclo5oooooo00?ono_kod];BooIfMT0V?ooool00ooUiNGo51@Dokbl_008
ooooo`03oibLW?lF5QKooooo013ooooo00?oZj^[ob@T9?oAdM40A?ooool00omdM7CoB4Q8onGUi@1l
ooooo`00ooooooo5ooooo`07ooknoooin_col??ioloIj_na`MgoY;SHojZmfP02ojbnf`09oj^mf_n/
_]_o/L;MokW8h?oBfNWom_Kiooklnookno_onOWj00Kon_[j01conOWjooWhnOoln_[odn3[oj?1f_nR
`=[oX[oIoj2ofOnP_]WoW[gHoifkf?nL^mOoTkKDol3Ci?oYk?;oj^gconOZl_oTj?7oh^OaomoTkooK
h^kof=o]omGLjooBf^[oc]OXol[Dioo6dNKo`LgT1Onoc><01?nmbn;o^l[Qok31gOn[_M/3ojbnf`04
ojJif?nc`mooi^cdooknoQKooooo00Cof=SHoiFEUOo;bl_oo?clH?ooool00ooShn?oB4Q8ooooo`3o
ooooogcooooo003oooooolGooooo00GolO?iolKBionV^MWoYk[Ioj^mfP03ojbnf`08ojjog?nda=ko
a<oTomkSk_olno[ooOckoo[jn_ohn?T2ooWinPKon_[j0_oinOX08Oomn_[odn3[oj?1f_nR`=[oX[oI
oj6ofOnO_]WoW[gHoifkf?nL^mOoTkKEol3Ci?oYkO?oj^gdonOZl_oUjO7oh^Oaon3UkooLh^kofMo]
omKMk?oCf^[ocmSXolcEj?o7d^Ko`/oToko<hoo0c>?o_lcSokg:h_njb>7o/L7Moj^mf`03ojbnf`06
oj^mfonY_=[o[[oLok;2gOo8e>Son__l5_ooool01?oHf=SoUIFEol_;boolo?`Iooooo`03om7AdOo;
bl_ono_k00;ooooo00?odM7AolK6a_oKfm/01?ooool01?oZj^[of=SHom3@d?oXj>P3ooooo`04ookn
o_o<c<cobl_;on7Qh@Cooooo00Coj>SXolC4a?o9bLWol_;b0_ooool01_ono_koh>3PolC4a?o:b/[o
hN7Qooclo0Gooooo00ColO7aomGEeOoGemOoh>3P1?ooool01OoinOWogMgMomCDe?oGemOon_[j00?o
oooo00?ojn_[olK6a_oalO400_ooool00ooclo?obLW9omkNgP02ooooo`04ooOgmooQhN7o0000oo;b
l_ooooooO?ooool004cooooo00GoiO3gokC@iOnfe>Oo]<oUon[bn007ooooo`05onoen_ndcnGo]]CW
okC@iOoPkOD00_ooool01_oTkoKo^]OYokKDionfe>Oo^MGXooGjo0Cooooo00Oom?SkomKWl_o1f^_o
]]CWok[Fj?o:gnkohNge00Wooooo00SomOWlomg[m?o<h>ko^=GXokKDioo8g^gogN_doo_lo@Cooooo
00Goe^KbokCAi_nfe>Oo]=3UooGio002ooooo`0;omGVlOndd^Ko]mCWokCBi_o=hNkohNgeokODione
e>Oo]=7VomOWl_oloOh01?ooool01_ojo?gobn3^okCBi_nddnOoamk]olWOk@;o]]CW00So]<oUooKj
o?oooooooooooogno_oFi_7o^mKYoo?hn`?ooooo00SoenObokCAi_nednOo`][[olGLk?nge>So]]CW
ok[Fj@?ooooo00Como[lolSNkOo7g^gomo[l0oooool04?nnf>[o]]CWokKDionieNSoooooonoen_nd
cnGo]]CWokC@iOoMjoCoooooolcQk_nddnKo]]CWokCBi_omo_h5ooooo`05om[YlonddNGo]]CWokC?
iOo/m?T01Oooool01oo`m_[odnGaol7Jjondd^Oo^]KXolcQkooYl_P0g_ooool01?oYkoKo_/gTojbn
fonZ_MX3ojbnf`05ojfnfoo4cnGojNccoo[jn_ojnOX00_ohn?T01?oinO[on?SiooWhnOoinOX7oo[j
nP04ooWin_omn_[odn3[oj?1fP;oX/3J01_oXKoIoj2nfOnO_MSoWKcGoibkf?nE]]Go`M?UonW/looZ
k_?oj>_bonGYl_oSio7ohNG`omcSkooJh>goemk/om?Kj_o@f>[oc=KXolWDi_o5d>Ko_l_Sok[9hOnf
aMoo/<7MojZmf_n[_M/00_n/_]/01_nZ_M[oZKcJok32gOnlbn;odMc/onocnASooooo00Cof=SHoiFE
UOo;bl_oo?cl6Oooool00olh>3So0000om;BdP02ooooo`04ocLg=ol0003oN7Qholg=c@;ooooo00Ko
lo?cogalO?m_KfooJ6QXoeADE?oBd]82ooooo`0Eoo[jn_l820So0`<3oiZJV_o;bl_ol?3`ooooooo]
kNgoFe]Ko`000?lf=SKoSHf=omkNg_oooooomoOgodE5AOl0003oEEEEoi6ATOne]KGokno_00Cooooo
00GoMgMgofIVI_n1PH7oCDe=ol_;b`03ooooo`06okRh^?mHF5SoNGUiodm?ConDU9ConOWi0_ooool0
3_nc/k?o0000oj6QXOoooooon_[joiBDU?l0003oFUYJom7AdOooooooShn?obLW9ol0003oeMGEoooo
oomlooooo`00C?ooool01OnLa=oo04bLo`1LYOl0BY_o[/oT00Oooooo00Go`M[[o`1:Vol0G:Go04jN
ohVif002ooooo`06oenQbol0H:So05bUo`1IY?l`QK_ojoCi0_ooool02ooloOko/M3UofNSc?l]Pk_o
0VV/o`1LYOl0H:Oo57BcodFA`on9^MSofn[c00Kooooo00[odNC`og:[dOlkRkko6GJdo`1NY_l0FjGo
4G:aoc^;_on2]MGognce0oooool04_mSX/co056Po`1LYOl0C9cof^WcoooooooenOco:7nho`1IXol0
FjGo05jVogV`donbdNGo1V^]o`1IY?l0Dj3oBIC4onkenPCooooo00[ojo?hoaYh]Ol0EZ;o05FQocn=
`OmJWLWo05nWo`1KYOl0Bicof>Ob0_ooool01?omoOko=XRmo`1QZ?nSb>42ooooo`0:ooWkoOmEV/So
05:Po`1IXolIM[Co<hFlo`1NY_l0G:Go06>Yoo3fnP;ooooo00CodN?`oaEe/_l<Kjoob]o^0oooool0
4?l9KJko05bUo`1MYOlJMkCooooool7Jjol0BY_o05bUo`1>W_n0]=Goooooocf<`?l0Ej;o05bUo`1C
X?ohnod4ooooo`06omg/m?lcQ;_o05FQo`1LYOl0BY_o^=GX1?ooool02_nbdNKoH:7;obMo^Ol2J:co
05VTo`1PYolIMkCoDYS6ojC9hOoinogMooooo`0Aoocmo_oAfn_o/l?MojNjfOn/_]_oZkgKojfog?o5
dNGoj>cbooOgnOogmoSom_SiooShnOohnO[on?SiooWhnOoinOX01oojn_X00ooinO[ooO[jom?Pj`02
oj?1fP0Roj;0f_nQ_mWoX;kIoinnf?nM_MOoW;cHoiFfeOo2dnGoj^kconc^looYjo;oinWbon?WlOoQ
i_3ogN?_om[PkOoHg^coe=cZom?Kjoo>e^SoaM3Uokg:h_nca=ko[;kLojZmf_n[_M_o[;kKoj^mfonX
^mWoZK_IokO7h?o8e>SognKaoogmoQ[ooooo00Cof=SHoiFEUOo;bl_oo?cl6Oooool0:OnGUiOo0`<3
ogemOOojn_[ooooook2`/?l0003o_[jnoj2PX?o5aLGoooooojn_[om9BDWoemOGoooooom6ATKo=CDe
ong]kOoooooono_kod92@_lN7Qkon_[joiNGUonMWIgol?3`ojf][Ol20P;oKVi^onCTi?nDU9CoLg=c
oo3`l?ogmoOo:b/[obLW9oooooool_;bohF5QOn=SHgokNg]00;ooooo01Soi>CTo`000?o[jn_ooooo
ogalO?lF5QKog=cLoooooooemOGoD51@ofi^K_oooooo_knooa4A4OnNWYkoo_knooooooo^k^ko1PH6
oeYJF_ooooooe]KFob4Q8Olf=SH2ojb/[004oooooom4A4Co0@41oeUIFOooooooOOooool004cooooo
00GoY/[Ro`1MY_l7K:ko05bUokKDi`07ooooo`0<olONkOl0G:Go1fb^o`1OYonC_mcoooooolKNkOlF
MK?o16Z]o`E[[OlGM[Cod^Ga0_ooool01OoinogoQ[SHo`a_[ol0GZKo06N[00?o0FV/00Go0FR/o`1U
Z_l0H:SoAY72olSNk@04ooooo`04ok_GjOl`QKco06>Yo`1TZ@?o06>Y00Go06:Yo`1TZ_l0IJ[oCiK6
om?Ul@02ooooo`0Bog:[dOl0HZWo1fb^o`1MY_oMjoCooooooi2nfol0HjWo1fb^o`AZ[Om6TL?okOCi
ooOjo?mIWLWo06:Xo`AZ[OlEKZooio7g1?ooool04?oHj??o06>Yo`E[[Ol0I:WoPkKGok[GjOlKN;Co
0fZ/o`1OYonie^SooOkooooooooBiO7o0fR/o`AZ[OmAV<H2ooooo`0:oo3gn_m?U/Ko06FZo`1VZomE
V/SoNk3Co`e_[ol7K:ko3g6aolcQkP;ooooo01OoXLOQo`9UZOl0HZWoRk[Ioo[loOooooookoGioaai
]Ol7K:ko26f^ofFTcOooooooamk]o`1LYOl7K:ko05nWohbkfOooooooD9O6o`1WZol7K:ko06BYooWk
o@03ooooo`07ooSko?m[Yloo05jVo`I/[ol7K:ko05bUokoIjP02ooooo`06oo_mo_n0/mGo3g6bo`1P
Yol0I:[o06:Y0_l0HjT01Ol0I:[o062Wo`I[[_mg[]?oo_ko0=kooooo00WohnWcok_9h_nV^MWoZkkK
ojbnfonW^]Wo]/GOomWPkOoem_P00_ohn?T00oohnO[onOWjooShn@02ooWinPKon_[j01ConOWjoogj
n_oCh>_oY<7Joj?1f_nR`=[oXKoIoj2ofOnO_]SoW[gHoifkf?nE]mGo`]CUon[^loo/k_?ojNcconOZ
l_oUj?7oh^OaomoSk`;og>;^00Koe]k[olWCionnb^;o/lCNoj^mfon[_MX2ojbnf`06ojZmf_nW^]Wo
Z[cKoko>i?oDgNcoj^of7Oooool01?oHf=SoUIFEol_;boolo?`Iooooo`0Mon?SholQ8B7o6a/KonCT
i?oooooono_koaTI6Om/K6cooooooinOWoooooooPH61obl_;ooKfm_oooooon;Rh_l0003oUIFEookn
o_omoOgoVIVIo`L71oo:b/[oo?clokBd]?oZj^[oW9bLo`000?no_kl00_ooool01Onf][Koh>3PooWi
nOmCDe?o8b<S00;ooooo013omOGeogAdM?n=SHgomoOgoooooonYZJWo0000ooShn?oooooom_KfoalO
7omGEeOoooooomoOgolU9BGoP8200_ooool04OmVIVKo6ATIonSXj?oooooon?Shod51@OlM7Agolo?c
ojFUYOl0003oVYZJooooooojn_[oooooom;Bd_nMWIgol?3`0?ooooooOOooool004cooooo00GoY/[R
o`1MY_l7K:ko05bUokKDi`07ooooo`0;olONkOl0G:Go1fb^o`1OYonJ`mkomo_lodnFa_l6K:ko1fb_
o`1SZOn[cN@00_ooool03oohnogoSkkKo`=WZol0Ij_o1Vb^o`1QZ?l4JJgo6WNdoaAd/_l0HZWo0FR/
o`M/[_l0Ijco=HNmomOXlP02ooooo`0Jol3JjolRO;Ko06BZo`9Y[Ol0Ij_o>HVoofJTcOmYY/goA932
o`1SZOl5Jjko06JZodbEaOoSk_Koooooog:[dOl0HZWo1fb^o`1MY_oSk_KofNScoaUf]?l6Jjko16Z]
oamj]_o?ho02ooooo`05oi_4gol=K:ko1F^]o`1RZOmGW<P00ombZm40=_m`Z]3oBYG4o`=VZ_l2JZgo
6gVeokkIj_oDi_7o:7nho`5X[?l0HZWoRk[IooWloOooooooO[?Do`1UZ_l4JZgo9GjholgRkooooooo
g^cdod6>`Ol0IZ_o06BYofnZd?n/c^Co3g6ao`M/[_l>LK7o]M?Wooooooo_m_[oGj7<o`1QZ?l0I:[o
?Xk1on3]mOooooood>?_oaQf/ol7K:ko2Vj_ohJgeoooooooamk]o`1LYOl7K:ko05nWohbkfOoooooo
D9O6o`1WZol7K:ko06BYooWko@;ooooo00CooOkooiS2g_l9JJco16Z]0_l7K:h04_l0G:Go_mWZoooo
ooooooooNk7Do`1WZol2JJco0FV/oa9b/_mHVlSoKZW?oenPbolRO;Oo0VZ/o`1Y[?l0I:[oTKkKoogm
o]kooooo00gol_GjolSDj?nV^]WoZKcJojbnfonX^m[o[koKolSCioo^l?Gon_[jooShnOohnO[onOWj
00;onOSi00?onOWjoo[jn_ojn_X00_ojn_X2ooWinP0Ioogjn_oCh>_oY<7Joj?1f_nR`=[oX[oIoj2o
fOnO_]WoWKgHoifkf?nE]mGo`]CUon[]loo/koCojNcconOZl_oUjO7oi>Saon?WlOoJh>gob=;Vok_9
hOna`MgoZ[gKojZmfP02ojbnf`06ojVlf_nS^=Oo/L7MolODiooPio;om?Ok7oooool01?oHf=SoUIFE
ol_;boolo?`Jooooo`0=oe1@D?l0003oPH61ookno_omoOgoLG5aoaLG5oo/k>cokno_oooooomiNGWo
6QXJomGEe@02ooooo`07oda<C?lK6a_omOGeoooooooMgMgo0000ogEeM@03ooooo`03ojJVY_l0003o
_Kfm00?ooooo00GonOWiooclo?nFUYKo2PX:olO7a`02ooooo`0?omgMgOlj>S[oYZJVoooooonRXZ;o
0000onKVi_oooooono_kohR8R?l61PKof=SHonGUiOlT92CoMWIf00;ooooo00_odm?Co`000?nATI7o
oOgmoo_knonGUiOo0P82ohJ6Q_m=CDgo7QhNomKFeP3ooooooh?ooooo001<ooooo`05ojK:h_l0GJKo
1fb^o`1JY?o9gnd01oooool02_o7g^go05bUo`M/[_l0GjOoYl[SojW<i?l@LK7o1F^^o`1QZ?mMWlX3
ooooo`0ZolcPk_lCKJko0VN/o`E[[_l1J:_oDIS6ojg?iOo2fn_o_]WZoh:fe_lHM[Co0fV]o`I/[_l3
JZgoFik9ooooooo_mOWoFYk9o`1QYol4Jjgo0fZ]oh:de_oEi_;ol_OkooooooognogoV<;Mo`5SZ_l4
JZgo1fZ]ogbbeOooooooLjcAo`1RZOl7K:ko05fVongdnOmLWl[o0fV]o`M/[_l8K:ooVL;N0oooool0
1Oo=h^oo;8:jo`1WZol8KJoo06BZ00Co06:Y03Go06FZo`Q][ol0IZ[oBI?4ooGio?oWlOOo?8^oo`1W
Zol0HjWoNJoCooSkoOoooooo7WReo`A[[Ol6K:ko2Ff^ogR_doooooooe>KaocR9__l0Ij_o06:YohNh
f?o3g>_o3g6ao`M/[_l<KjooTkoKoooooooFi_7o576ao`=Y[?l4Jjgo2VN[ojk?i?oooooo]M?VoaEd
/_l7K:ko2fj_ojG:h_ooooooamk]o`1LYOl7K:ko05nWohbkfOooooooD9O6o`1WZol7K:ko06BYooWk
o@02ooooo`03oloSl?lIL;3o0VN[00?o1fb^00[o05bUokoIj_ooooooe>Gaoa5b/Ol6Jjko26f^obj3
^_nmf>WojO;h0_ooool01ooRk_KoCIG5o`5VZol3JJco4Vj_om3Tl?ooo_l0g_ooool02_oin_goen7^
ojo0g?nW^]Wo[;kKojZmf_nZ_=_o_<_RonGYlOomo?/2ooSinP04ooShnOoin?WonOWjooWinP?on_[j
0_oinOX05oomn_[odn3[ojC1f_nS`M[oX/3Joj:ofOnP_mWoWkkIoifmf?nM^mSoUKOEol?Di_o[kO?o
k>odon[/l_oZkO?ojngdom[PkOo5d>Ko^<OOojjog?nY_=[oZkgK00;o[;kK00KoYk_IojFhf?nhan3o
e]o]on[^mOohnO`Qooooo`04omSHf?nEUIGobl_;ooclo1[ooooo00SoXZ:Ro`X:2_l/;2cokNg]ookn
o_oBd];o0000ok2`/0;ooooo00?oV9RHo`/;2onf][H00_ooool01onQXJ7o0000olc<c?ooooool?3`
oc4a<Olc<c<00oooool01?nl_;co410@of5QHOnj^[X4ooooo`03omSHf?l0003oF5QH00?ooooo01[o
KVi^od];Boo^k^koaLG5o`@41?nYZJWoooooookno_oBd];o0@41oiFEUOoinOWo?Shnod];Boo`l?3o
oooooogmoOlW9bOoATI6oo_knooooooof=SHo`000?m3@d?o>SXjocdm?HKooooo00God>?`oebGaOmP
XL_oG9O6ol3Jj`05ooooo`05oo_lo_mLV/OoH:7;oebNbOnD`=`00_ooool01_oCi?3oKj[@oefOb_mP
XL_oDIS5olgRk`Cooooo00Oof^WbojC9hOmaZ]3oFig9og:[d?nTbN7of^Wb00Gooooo00Goj_;hoebG
aOmPXL_oG9_8oj[<h`05ooooo`05oo7fn_mSXlcoH:7;oejPbomk/=@01?ooool01OnUbN;oG9_8of2Q
bomLUlKoj_;h00Wooooo00?oWlKPoebKb?mPXL/01?mPXL/02?mSX/coW/GPooooooo@ho3oG9O5of2Q
bomLUlKo`=[[1Oooool01OoOk?CoFi_8of2QbomLWLWoU<3L00;ooooo00?oYLWRoebKb?mPXL/00_mP
XL/01?mPX<_oNK3Coj;8hOoNjo@6ooooo`07onWbn?n^cnGoMJgBof2Qbom/Z<koX/OPoo3fnP24oooo
o`00C?ooool02OnVb^;o05fVo`M/[_l5Ij_o>XZooe2Ga_m;ULGoLJ_@okSEj003ooooo`0:olONkOl0
G:Go1fb^o`1SZOml/]CoE9[7o`1X[?l2Ijco;X:jon3]m@;ooooo00Oomo[moh2ceOl0GjKo1Vb^o`1W
ZomQXL_oi_3g00?ooooo00gon_cmolCLk?l>L;3o1Vb^o`AZ[OlTOKOog>[com3RkolKNKGo0VN/o`1S
ZOmLWlWokoKj00;ooooo01;oEic8oeFKb?m8T/?o1FR/o`M/[_l0IJ[o>HZnonofn_mi/=?o06:Yo`M/
[_l0HJSo[<kToaAd/_l7K:ko26f^oejPb_ogn_d3ooooo`06ooKjo?mIW<So06J[o`M/[_l8KJko06FZ
0_l0G:D02?l0Ij_o26f^o`I/[Ol5JZcoNK3CoooooooloOkoCIG50_l0IZX01?m@UlKon?_molCKk?l0
I:X2o`M/[P0@o`1WZom0SL3olOOjok_Gj_lON[Ko0VR/o`1OYonYc>?ol_Sko`m`/?l7K:ko2fj_og:/
dOooooooU<3Lo`1OY`;o1fb^02Co062WofbWcooko?ko/M7UoaEc/_l7K:ko2fn_okoIjOooooooamk]
o`1LYOl7K:ko05nWohbkfOooooooD9O6o`1WZol7K:ko06BYooWkoOoooooolOKkodRB`ol0HjWo1F^^
o`=Z[Ol8K:ko1fb^o`1LYOnofN[oooooohFgf?l:KZoo1fb^oa1a/OnRb>02ooooo`09ol?Kjom?Sl7o
F9c8obIn^?l5JJgo1fb^o`1QZ?n:^]WooOgn0=oooooo00Coo_koonO[m?nhan7oYKWI0_n/_]/02?nY
_=[o]<GNomONjooknoWonO[kooWin_ohn?WonOSi1OoinOX00ooin?WooO[jom?Pj`02oj?1fP0Ioj;0
f_nR_mWoX;oIoinnfOnN_MSoWK_HoiFgeOo3e>Kok>ocoo7bm_o[koCoemo/ol;>i?neaMko[KkKojZl
f_n[_]_o[;kKoj^mf_nV^MSoYk[Jol;?iOoOi_;ol??iookoo`0Sooooo`04omSHf?nEUIGobl_;oocl
o1Sooooo00[ooOgmooooooobl_;o3Ph>ofMWIomnOWkoooooooKfm_lg=cOoB4Q80_ooool00onm_Kgo
2`/;ohf=S@02ooooo`08onOWiol61PKoSXj>ooooooohn?SoO7alo`h>3_oGemL2ooooo`06oo3`l?l^
;RkoDU9Boj2PX?mYJFWo[:b/0_ooool01?o/k>co<S8bo`X:2_nd];@2ooooo`06ol[:b_lL71co];Bd
ooOgmol30`?oL71`0_ooool01oo[jn_o9bLWoe5ADOooooooI6AToa`L7?oKfm/00_ooool02om]KFgo
3@d=oo[jn_ooooookno_ob`/;?lc<c?of][Joj>SXon9RHWobl_;08Cooooo00Go/];Vo`1DX?l0IJ[o
05FRoiS2g@05ooooo`0=ooWkoOl0FJCo06FZo`1OYom@UlGooooooogno_m^ZM3o06>Yo`1TZ_l0FJCo
DIS6onC_mP02ooooo`0;oocnoomg[];o;86ioaUg]?l2JJco06>Yo`9Y[?lIMkCo;86iog^`doolo_l0
0oooool01OoLj_?o05BPo`1UZ_l0FZGoLjcB00Gooooo00GoFYg9o`1VZ_l0IJ[o06:YobIn^004oooo
o`05of^Wcol0FZGo06FZo`1EX_oLj_<02Oooool00omQX/co05^Uo`1UZP04o`1UZP08o`1WZomOX<co
oooook;Bi_l0E:3o06FZo`1EX_nH`]d5ooooo`05oc^;_ol0HJWo06FZo`1NYom@UlD00_ooool00om[
Yloo05ZUo`1UZP02o`1UZP05o`1TZ_l6Jjko6GJdocV:__nUb^800oooool02_obn?_oR;WHocJ9_OlM
N[Ko16Z]o`1UZ_l0J:_o67Jdod>@`_o6g^f3ooooo`00C?ooool02_nVb^;o05fVo`M/[_l7K:ko0VV/
o`1X[?l0Ijco2Ff_oaah]OmVY<d2ooooo`09olONkOl0G:Go1fb^o`I[[OlGMK?o476ao`AZ[Ol2J:co
/];W00?ooooo00Koj_;hocR9_ol0Ij_o0FN/oc24^oo<hNl6ooooo`0:ogR_dol1J:_o1V^^oaAc/_nO
aN3o^mOYo`5PYol6K:ko05fUojk@i0?ooooo00?o1Vb^o`1X[?l2JJ`00_l7K:h02?l0Ij_o=8Nlon_c
nOmk/MCo06:Yo`M/[_l6Jjgo7GVe0_l7K:h00olQNkGoj?;hooooo`04ooooo`0<oio6h?lFMK?o16Z]
o`5VZ_mWYLkobn3^olcQkomBV<Ko0FR[o`=Y[?lPN[Ko^=GX0_ooool02?mIWLSo06BYo`1X[?lgRKko
oooooeFJaol4JZgo1fb^0_l4JZd03olCM;;o[<gTokoIjolFMKCo0fV]o`1JY?o9g^goooooobZ1^_l7
K:ko2Ff^oe:IaooloOgo@i72o`1UZP02o`E[[@0To`9Y[?lCM;?okOCiognceOl=L;3o1fb^o`e_/?od
nOcoooooolONkOl0G:Go1fb^o`1OYon<^mWooooooe2Ga_l0Ij_o1fb^o`1TZOoinogoooooohFgf?l2
Ij_o1F^]o`ma/OlJMk?o0fZ^o`M/[_l0G:Go_mWZoooooom<ULGo2Ff^o`M/[_lHMKComo[l0_ooool0
1?nTbN7o05RTo`1X[?l4Jjd2o`M/[P03o`1WZom>U/Gonogn0>7ooooo00comOOkolcGj_nZ_=WoZ[cK
ojbnfonZ_M[o/<7LolOCiooem_SooOclooSin_ohn?T2ooWhn@;onOWj0_oin?T04_oln_[odn3[oj?1
f_nS`M[oX/3Joj:ofOnP_mWoWkkIoijmf?nM^mSoUkSFolWIj?oYk??od][ZokW7h?na`]go[;kKoj^m
f`;o[;kK00KoZ[cJojBgeon]_mcod]_/oncamoognO`Vooooo`04omSHf?nEUIGobl_;ooclo1Sooooo
013o_[jnolc<c?ooooooFe]Kof9RH_m`L73ol_;booclo?nGUiOo3Ph>omWIfOoooooom_Kfod=3@olk
>c_ojNWY0_ooool01ol<30coOgmoooooooono_kob/[:o`000?nGUiL00oooool04om`L73o9BDUomSH
f?oHf=So<c<cohj>S_oooooomoOgogemOOl0003oKFe]olc<c?oooooono_kocDe=OmPH63ooooooemO
Gol@41000_ooool01oo`l?3oCTi>ocLg=ooooooo[Jf]o`<30onTY:@00_ooool03OnOWioo0000ooWi
nOoooooom_Kfog9bL_l71`OoU9BDoooooooDe=CoKVi^ohR8R?oinOT0P_ooool01Onfe>Oo05bUo`M/
[_l0GJKoWLGO00Gooooo00conO_mo`1QZ?l7K:ko06N[oeNLb?oooooo]mGWoa5b/Ol3JJco0FN[ob1j
]OoJj_<2ooooo`0=ooSko_m>ULGo1fb^o`5X[?l5Jjgo16Z]o`1XZol4JZgo1F^]o`5X[?l8KJooCYG5
ooSkoP02ooooo`05omk[m?l0G:Go1fb^o`1RZOmj/=@01?ooool01_nB_]co3Fn`o`M/[_l7K:ko16Z]
oc24^`Cooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[m009ooooo`05ofVVc_l0HjWo1fb^o`Q][ol0HZT0
0_l0HJP02?l0HjWoG9k:oooooonfe>Oo05bUo`M/[_l0GJKoWLGO1?ooool01_n5]]Oo0FR/o`M/[_l7
K:ko06J[oeRLb0;ooooo00_oLZ_Ao`1RZOl7K:ko26f_o`1SZOl0HZSo06JZo`E[[Ol3JZgo67NdohFg
f002ooooo`0;ongenOlnSL3o06:Yo`1X[?l0I:Wo066Xo`1WZol5Jjgo0VV]ocB7_OoEi_40P_ooool0
04cooooo00koY/[Ro`1MY_l7K:ko26f_o`1VZ_l0HZWo06N[o`I[[_l5Jjgo3W2`ok?Bi_ooooooamk]
o`1LY@;o1fb^0_l6Jjh2o`M/[P0:oaUd/_nF`MgooooooooooooQk_Go1FZ/o`A[[Ol0HjWoI:?<oo_m
oPKooooo00[ogN_eo`1TZ_l7K:ko1FZ]og2Zd?nnf>[o05fVo`M/[_l0G:Go^=GX0oooool00ol0I:Wo
062Wo`1PY`02o`1PY`05o`1LYOl<Kk3oc>3^oh2ceOl0HZT00_l7K:h01_l5Jjgo1fb^o`M/[_l;KZoo
=HNmolGLk0Cooooo00coenOaoc24_?l0J:co0FR/ocF8_OoloOkooooooaIe/_l5JZko06N[ocZ:_ooh
nod2ooooo`0RohZjf_l>L;3o0fZ]o`]_[ooXlOOo4G:bo`M/[_l9KJko5WJco`A[[Ol1IZ[oLjcAoig4
gol3JJco06R/oa9a/OoIj??oooooodbEaOl7K:ko1Vb^obn3^ooVl?Oo1V6Xo`E[[Ol?LK7o476ao`E/
[Ol0H:Oo[/oUoffXcol=Kk3o1fb^o`Q][P;ooooo01[oamk]o`1LYOl7K:ko05nWohbkfOooooooD9O6
o`1WZol7K:ko06BYoocmo_nheNSo2fb^o`I[[Ol2JJcoCYK5oh>feol0HZWo1fb^o`1LYOnofN[ooooo
ob9l]_l6K:ko1fb^oaYg]0?ooooo00?oWlKPo`1?Wol0H:L00ol0H:L00ol0FjGo9Wjhoo_loP3Roooo
o`04oo_loOoNiO7o[KoKojZlfP;o[;kK00Ko[KoLokO6gooWj_;oooomooWin_ohn?T4ooWhn@04ooSh
nOoln_[odn3[oj?1fP;oX/3J00[oXKoIoj2ofOnO_]WoX;oIoj>ofOn</=7oV;CFok72gOn_`=coZkgK
0on/_]/01_nY_=[oYk[IokS8hOoOi_7omOSkoocloRSooooo00Cof=SHoiFEUOo;bl_oo?cl6?ooool0
2ooemOGoWinOoo;bl_nOWioo2@T9om;Bd_m`L73oooooomOGeol10@7oVi^K00;ooooo00?oVYZJo`<3
0onf][H00_ooool01ol<30coRh^;oooooooooooon_[joc<c<om?Cdl00oooool0;?oWinOo3`l?oi^K
Voooooooc/k>o`/;2oo2`/;oo_knolK6a_l0003oLW9bol30`?oMgMgooooooda<C?lW9bOojn_[on?S
hol0003oYZJVoooooooalO7oGEeModi>C_oooooon?Shod92@_m8B4Sok>c/oooooonTY:Co4a<Coo[j
n_ooooooo_knolS8b?l0003oGUiNojJVY_ooooooiNGUocDe=On4Q8ComoOgPOooool01Onfe>Oo05bU
o`M/[_l0GJKoWLGO00Gooooo00conO_mo`1QZ?l7K:ko06N[oejOboomoOkoDiW7o`1UZol4Jjgo06J[
ok7Ai_ono_l2ooooo`09ofVVc_l3JJco1V^^o`I[[_l0HjWo3G2`ocb;`?l;K[3o06>Y00;o1V^^00Wo
0fV/ofVVc_ooooooooooomk[m?l0G:Go1fb^o`1RZOmj/=@00oooool00oo8g^go9Gfho`I/[P02o`M/
[P03o`AZ[Ol`Q;_ooooo00?ooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[m009ooooo`05ofVVc_l0HjWo
1fb^o`5TZ_n?_MX00_nOa]l02?nQb=oo`mc/oooooonfe>Oo05bUo`M/[_l0GJKoWLGO0oooool00onc
d^Ko4g>bo`I/[P02o`M/[P0Lo`1VZomHW<SooooooooooombZm7o06:Yo`M/[_l1HjWoS;_Joi>ofom@
V<Ko066Xo`M][_l4JZgo6GNdojO;hooooooooOknoic5gol9KZko5gFdog:[dOnTbN7oAI72o`I[[Ol7
K:ko3g6`ohNhf8;ooooo001<ooooo`0MojK:h_l0GJKo1fb^o`5QZOmk/MCo_=OXof:Qc?l<K[3o1fb^
o`Q][_mYY/ooooooolONkOl0G:Go1fb^o`M][_l0Ij_o06BYo`1WZol6Jjko1V^]o`Q[[_nheNSooooo
omk[m?l0G:Go1fb^o`1RZOmd[=801oooool02_omoOko06BYo`M/[_l0Ij_oFig:ol3Ijol0G:Go1fb^
o`1MY_n^cnD3ooooo`?ok?Ci013ok_GioncdnOo/m?Wok_Gioo_mo_mc[=7o06:Yo`M/[_l7KJko06FZ
o`1TZ_l1JJco1fb^o`AZ[Ol`QKcofn[d0oooool02oomo_koJZO>o`A[[Ol6K:ko0VFZom_Yloo1f^[o
06J[o`I[[_lAL[7oR[[I00?ooooo01?oW<CNoaId/ol4JZgo06J[ohNhf?l:KZoo1fb^oaMe/onRb>3o
05nWo`1X[?m3Sl;oE9[8o`1VZol0J:co87^gomcZm?ooooooT;kK00;o1fb^00[o67JdofnYd?l0IJ[o
06FZoebNbOmPXL_o06>Yo`1TZ_mXY/go87^f0_l6Jjh07_m9TlCoooooooooooo7g^go05bUo`M/[_l0
GjOoS;_Ioooooom@UlKo06N[o`M/[_l0I:[on?[moaUg]?l5JZgo16Z]oa]h]Oo3g>_oZ/cSo`1NY_l7
K:ko05bUokoIj_oooooo?8boo`Q][_l7K:ko5gFcon[cn@;ooooo00Son?_mon_cn?o/m?WokOGiongd
nOo/m?Wok??ionofnUcooooo00?oUIFEoa<C4oo7alL00_ooool01?odm?Co3`l?oc<c<onTY:@3oooo
o`05oiVIVOm^KVkoC4a<oj2PX?ono_h00_ooool01OoalO7o;Bd]ob`/;?nCTi?oo_kn00?ooooo00Co
S8b<oa@D5?lW9bOoY:BT0oooool01OoXj>So@D51o`l?3omDE5Codm?C00Gooooo00Co/;2`oeYJF_mY
JFWoQXJ61?ooool01OoKfm_oLW9bof1PH?mRHV;ohn?S00;ooooo00CooOgmojb/[?lF5QKob<S80_oo
ool02Onh^;So92@TohB4Q?oooooofMWIocLg=olB4Q;oQXJ6omcLg00nooooo`04oogno_o`loWo]LGP
ojZmfP?o[;kK00Go/l?MomKLjoomo?_on_[jooWinP03ooShn@04ooWin_omno_odn3[oj?1fP;oX/3J
00WoX[oIoj?1f_nQ_mWoRJc@ofJEa?mBRKgoP:C=ojVlf_n]_]/00_n/_]/01_nZ_=[oZ[gJolcGj_o[
l?Kon__mooknoR[ooooo00Cof=SHoiFEUOo;bl_oo?cl6Oooool02_nFUYKoYZJVoo3`l?l;2`_oVIVI
ojn_[omgMgOooOgmo`P82?m4A4@2ooooo`0WooWinOmFEUKoEeMGooCdm?oooooo0000om3@d?olo?co
A4A4o`<30ol0003o10@4o`X:2_l51@GoW9bLoooooon][Jgo>c/konc/k?oooooo0000oi:BT_oooooo
h^;RobXZ:_m<C4com?CdohZ:R_mfMWKo9BDUoaHF5_oRh^;ooooooh:2P_lE5AGooooooo?clom>CTko
R8R800;ooooo00Oo`<30oa@D5?n_[joooooooh20P?m?Cdoono_k00;ooooo00Wohn?Sob4Q8OmKFe_o
c<c<ohf=SOooooooE5ADoaHF5_oMgMd0POooool01Onfe>Oo05bUo`M/[_l0GJKoWLGO00Gooooo00_o
nO_mo`1QZ?l7K:ko06N[of:Rc?nof>[o16R/o`I[[_l0GZOoLJ_@ooChn`02ooooo`0EolKMk?l5Jjko
1Vb^o`E[[Ol?LK7oPKGFonken_obn?_ok_Gjoh6ee_l?LK7o1F^]o`I/[_l5Jjkobn3^oooooooNjoCo
05bUo`M/[_l0HZWoN[3D00;ooooo00?onognocj=`?l4JZd00ol7K:h00ol4JZgo<8Bkooooo`03oooo
o`05og:[dOl0HZWo1fb^o`1MY_oNjo@02Oooool01OmYY/ko06>Yo`M/[_l0GZKohNkf00?onogn00Oo
o?knoooooonfe>Oo05bUo`M/[_l0GJKoWLGO00;ooooo00?ok_Kjob1k]_l7K:h00ol7K:h07?l0IZ_o
F9c8ooooooooooooLZ_Ao`1RZOl7K:ko05fVom_Yloojo?gom?Wkojo@iOl0GjOo1fb^o`5WZom;U<Co
l?Kjooooooo_mOWoQkSHolkRkoogn_conognooKjo?l2JJco1fb^o`=Y[?m3Sl62ooooo`00C?ooool0
1OnVb^;o05fVo`M/[_l0G:Go]]CW00;ooooo01Oo6GJdo`M/[_l7K:ko8G^fooooooo7g^go05bUo`M/
[_l0GjOoV<;MoooooonE`=co5gJco`E[[_l3JZgoBI?4oooooooUl?Oo6gRdo`9Y[?l0IZ[oAi;3onG`
m`06ooooo`0;ojK;h_l0IZ_o1Vb^o`]^[on2]=Kof>SboaQf]?l1JJco06>YofFTcOo^mOT01?ooool0
0ookoOkoh>ceooooo`03ooooo`0;og:[dOl0HZWo1fb^o`1MY_oQkOGoiNofofZWc_l3JZgo1V^^o`ma
/Omo/mH01?ooool02_ncd^Ko7g^fo`E[[Ol0IZ[oU/3MogN_dol0J:co1F^]obEn^?o9gnh3ooooo`03
ol?KjolXOkWo0VV/00?o1fb^00go2Vj_of>Rc?odn?_o97fho`1WZol?LK3o4G:ao`I[[_l0HjWoG9k:
oncdnOooooooYl_S00Co1fb^00Ko1V^^o`E[[OnD`=coc>7^ob=m]ol1JJ`3o`M/[P0Oo`E[[OmPX<_o
ooooooooooo7g^go05bUo`M/[_l0GjOoS;_Ioooooom@UlKo06N[o`M/[_l3JZgoBI?4o`AZ[Ol6Jjko
4G:aohjlf_ooooooWLGOo`1NY_l7K:ko05bUokoIj_ooooooLJ_Ao`]^[ol7K:ko47:aojK:hP05oooo
o`03onOamoobmo_ooooo05kooooo023ob<S8oa4A4Om9BDWom?Cdooooooohn?SoB4Q8obPX:?oNg]ko
SXj>ooooooo7alOoFUYJom7AdOofm_Ko4Q8Boh20P?ojn_[ooooooo7alOlX:2So<S8bon[Zj_mlO7co
b/[:ooooooni^KWo4a<Coc<c<ona/K7oSXj>of=SH`;ooooo00KoeMGEo`000?mZJV[oo_knohV9ROnZ
ZZX4ooooo`05oa@D5?oMgMgon?Shoclo?omDE5@00oooool01_m[Jf_oNGUioooooon6QXKo92@TomWI
f@;ooooo00oof][Jo`000?n4Q8CoooooonCTi?m0@43o6a/KogMgMon/[:coLW9bo`000?ni^KWooooo
oe9BD_ni^KT0@?ooool00oo8e>Oo[;kKojbnf`03ojbnf`03olC@iOoem_Sono[k00ConOWj01;oo?ck
om?OjonR`=[oX/3Joj:ofOnH^=KoNZ?;oeb?`OmFR[koEh^ooe27_OmoXlgoZKcJojfnfon[_M_o]<GO
omGNkOohnO`^ooooo`04omSHf?nEUIGobl_;ooclo1[ooooo00WoWYjNof1PH?l20P;oBTY:oooooon:
RX[o4Q8Boa<C4on/[:`01?ooool01OmmOGgoKVi^oe=CDonNWYkooOgm00?ooooo00?oa/K6o`T92On/
[:`01?ooool03ooMgMgoTY:Bog]kNolR8R;oe]KFoooooooclo?oKVi^oahN7_oGemOooooooibLW?lI
6AWoFEUIonk^kP02ooooo`04oiFEUOmDE5CoMGEeoh:2PPCooooo00GoaLG5of1PH?m_KfooGEeMon?S
h`03ooooo`09oo;bl_mOGeoo8R8RonGUiOoOgmooD51@o`000?mFEUKok>c/087ooooo00Go]]CWo`1L
YOl7K:ko05fVoig5g`05ooooo`0:ooWkoOl0HJSo1fb^o`AZ[Ol]Pk[oCYK5o`1VZol0IJ[o@i32omk/
m0?ooooo00GoNk7Do`9Y[?l6K:ko3g6aognceP05ooooo`0;ognce_l>L;3o1Vb^o`9Y[?n1]=Kooooo
omk[m?l0G:Go1fb^o`1RZOmj/=@00_ooool00omUY<go26b^o`I/[P03o`M/[P03o`AZ[Ol`Q;_ooooo
00?ooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[m009ooooo`05ofVVc_l0HjWo1fb^o`1NY_oUl?L01Ooo
ool01Onfe>Oo05bUo`M/[_l0GJKoWLGO00;ooooo00?oEI[7o`Y^[ol7K:h00ol7K:h02Ol0IZ_oF9c8
ooooooooooooLZ_Ao`1RZOl7K:ko05fVomk[m002ooooo`06oo[loOm`Z]3o06BZo`9Y[?lXP;Wo`=[Z
1_ooool01OoCiO7o0fV]o`M/[_l2JJco?hg008;ooooo001<ooooo`05ojK:h_l0GJKo1fb^o`1LYOnf
e>L00_ooool02_lJMkCo1fb^o`M/[_lQNkKoooooolONkOl0G:Go1fb^o`1OYonD`=`2ooooo`0<ocR:
__l3JZgo1fb^o`AZ[Oooooook_GiodfFaOl0IJ_o16Z]o`]^[on=^m[onocn1?ooool03Oo]mO[o;H:j
o`AZ[Ol5Jjko6GNdoj_>i?o`m__oAY72o`1UZ_l0J:co7WVeom3Skoonool00_ooool03?omo_ooV/?N
o`1UZ_n5]mOok??ioocmo_ooooooLZ_Ao`1RZOl7K:ko05fVomk[m0;ooooo00Co06J[o`M/[_l0J:co
AI721?ooool02Oofnoco?8^oo`=Y[Ol1J:coDIS6ob5l]_l5Jjgo16Z]od2>`@04ooooo`03omk[mOld
Qkco0FV/00?o1fb^00Go3W2`okWEj?okoOkoLZ_Ao`1RZ@03o`M/[P05o`1SZOmNWl_okOCiooooooo<
h>h01?l7K:h01_l1JJco<XJlomGVl_ojo?goCYK5o`1VZ`?o1fb^00co16Z]oiBog?ooooooooooolON
kOl0G:Go1fb^o`1OYon<^mWooooooe2Ga_l0Ij/2o`M/[P04o`AZ[Ol7K:ko2Ff^oeBKb0;ooooo00co
WLGOo`1NY_l7K:ko05bUokoIj_ooooooZ<_Ro`e`/?l7K:ko26f^od2?`Oojo?d3ooooo`06oo[loOm5
T<;o9WnhokSEioodn?_oo_ooGOooool07?la<C7o0000omKFe_oooooono_koi6ATOl=3@gob/[:ol30
`?o3`l?oShn?od51@OoOgmoooooook:b/_l0003obLW9ooooooohn?SoL71`oaPH6?oVi^Koj>SXohV9
ROoRh^;oVi^Ko`000?nj^[X2ooooo`06omKFe_n9RHWoooooom_Kfol?3`ooQ8B40_ooool01_mbLW;o
WIfMoogmoOoooooo[jn_o`0000;ooooo00OoeMGEo`L71on=SHgoooooomkNg_lX:2SoT92@00;ooooo
00oo<S8bodI6A_ofm_Kooooooo7alOlO7aoo?ShnoogmoOn^[Zko0000oh:2P_ooooooj^[Zoo7alOoX
j>P00_ooool00omkNg_o:b/[ooooo`10ooooo`03on3Vl_n^`=co[;kK00;o[;kK00CoZK_JokO6gooV
j_?on_[j0oohnOX01oolno[od]k[oinnfOnC]=CoJYS6oeF9_omFR[l00omGRkl02_m@QkgoP:?=ojZm
f_nnbn?ohnScooknooocmO[od]_[oo3cnOono_l/ooooo`04omSHf?nEUIGobl_;ooclo2oooooo00?o
hN7Qoc<c<omVIVH02oooool00on`/;3o0000oj:RXP0Hooooo`03oj6QXOl0003oZ:RX08Kooooo00Go
]]CWo`1LYOl7K:ko1ff^o`5X[002o`1VZ`05o`1LYOnXbn;oo_koooWkoOl0HJP00_l7K:h01_l5Jjko
16Z]o`I[[_l0IZ[oT;cKooWko@?ooooo00Go8gfgo`I[[_l5Jjgo9gniomWXl`05ooooo`0EomWXlolR
O;Ko1F^]o`I[[_lYPKWoooooomk[m?l0G:Go1fb^o`1RZOmj/=Coo_ooojK;h_lHM[Co16Z]o`9Y[Om1
SL7o26f^o`M/[_l4JZgo<8Bk00Cooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[m009ooooo`05ofVVc_l0
HjWo1fb^o`M][_l0Ij/00_l0IZ/04_l6K:koX/SQoooooonfe>Oo05bUo`M/[_l0GJKoWLGOooknoonK
a=oo4G:ao`I/[_l6Jjko@Xk1o`=Z[Ol7K:ko06J[oeRLb0;ooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[
m002ooooo`06oogno_ncdnOo062Wo`AZ[OlAL[7oV/?O0_ooool01OoloOkomOWlokCCi_m/Z<ko0FR/
00;o1fb^00?o2Ff^of6Rc?ooool0POooool004cooooo00SoY/[Ro`1MY_l7K:ko05bUok?Bi_oloOko
lOOkoaQe]0;o1fb^03[o9gjhooooooo7g^go05bUo`M/[_l0GjOoU/7MoooooooenOco=8Nmo`=Z[Ol7
K:ko2Vj_ooooooojo?goXLOPo`MUZ_l6Jjko0fZ]o`I[[_n6]]Ooj?7hongdnOo/m?Woe>Gaoc24^ol3
JJgo1fb^o`EZ[OlkRkookOCioooooon3]MKo16BZo`M/[_l0I:Wo<XJlomCUlOodn?_oloSkom7Tl?lK
MkCo0VV]o`1SZOlMNKGoaMg/oooooombZm7o06:Yo`M/[_l0GJKohNgeooooooo`m_[o06J[o`M/[_l1
J:coBI?41Oooool02?mm/MGo3Fn`o`I/[_l1JJco1F^]o`I/[_lDM;?oX/SP1?ooool00oohnogo@8k1
o`1X[003o`M/[P06oaai]OooooooooooolgQkol5J:_o16Z]0_l7K:h01_l0H:SoSK_IooWkoOoooooo
o?gno`Q][P?o1fb^00Oo0FN[oeVLb?oooooooooooh^jf_l9KJoo1V^^00;o1fb^00co16Z]ojK:h_oo
ooooooooolONkOl0G:Go1fb^o`1OYon<^mWooooooe2Ga_l0Ij/4o`M/[P09obN0^OoWl?Oooooooooo
oonMaMoo05jVo`M/[_l0G:Go_mWZ00;ooooo00ko7GZfo`I/[_l6K:ko3G2`og^ae?o]m?Wom_[loo3f
n_mk/=Co1ff^o`5X[?l0G:GoDiS7oo7hnegooooo01KoRh^;o`820_mRHV;oo?cloooooooVi^Ko2`/;
ohf=SOobl_;ogmoOogQhN?l`<33ogmoOooooooono_ko6ATIodQ8B?ono_koooooolG5aOl0003oX:2P
0oooool00onHV9So0000ol;2`P03ooooo`0FooOgmoooooooj^[Zod51@Om=CDgoo?clooooooo<c<co
AdM7olK6a_ooooooXJ6Qo`000?olo?cooooooo?clomIFEWo7alOooWinOoJf][o820Pohj>SP;ooooo
00_oZ:RXo`000?o3`l?oooooooShn?meMGGo4A4Aol71`OmcLg?o51@Dol[:bP05ooooo`03oogmoOl]
;Bgo6QXJ04;ooooo013om?OjokW9hOn/_]_oZkkKojbnfonZ_=[oZkgKom?Lj_oem_Oon?SiooKfn?og
m_So/lSOof:Ca?mAR;goEHZn0omGRkl03OmHRkooEh^oodJ2^_n=[m?oj^ogoogno_oTj_?o`/oTojNj
fOnY_=[o//?Oon?Ym?oko?d0:oooool01?oHf=SoUIFEol_;boolo?`_ooooo`04ooWinOnm_Kgo[Zj^
ooKfmP[ooooo00Cofm_KoalO7omVIVKooOgm5oooool01?oAdM7o20P8of1PH?olo?b5ooooo`05okKD
iol0G:Go1fb^o`M/[_l6Jjh00_l5Jjd01Ol0HJSoZ/gSooknoooinogo066X00;o1fb^00Oo1V^^o`AZ
[Ol5Jjgo1fb^o`1LY_m?U/Goi_3g00;ooooo00Co16Z]o`M/[_l4JZgo>8Zn1oooool05?laQK_o16Z]
o`M/[_l:KZooooooomk[m?l0G:Go1fb^o`1RZOn4]]Koi>ofobb1^_l0Ijco16Z/o`ma/OoKjo?o36n`
o`M/[_l4JZgo<8Bk1?ooool01OmbZm7o06:Yo`M/[_l0GJKog^_d00Wooooo00CoJJK>o`1SZOl7K:ko
1fb^0ol5Jjd04_l>LK3oYL[Roooooonfe>Oo05bUo`M/[_l0GJKoZ<_SomCVlOlLN;Go0fZ]o`EZ[_lP
N[Kof^[co`1SZOl7K:ko06J[oeRLb0;ooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[m003ooooo`0@on;]
mOl0GJKo1fb^o`1QZ?m^ZM3ooooooo[loOnZc>Co7gZeo`1TZ_l0Ij_o1fb^o`I[[_l5Jjko9Wjhol7J
jh;ooooo001<ooooo`0GojK:h_l0GJKo1fb^o`5SZOmZY/koX/SPodnFa_l;KZoo1fb^o`I/[Ome[M?o
ooooolONkOl0G:Go1fb^o`5RZ?ml/MCocn;_ofnYd?lAL[7o1V^^o`=Z[?lhR[h00_ooool03oofn_co
Kj_@o`1TZ_l4JZgo1Vb^o`1PYol;KZoo:X6job=l]ol0HJSo0FR/o`M/[_l3JZgo8Wbgol;Kk002oooo
o`0Comk/m?m6T/?o06JZo`M/[_l0IZ[o3g6aof6QbomJW/Wo06JZo`=Y[Ol7K:ko0FV/odbEaOoXlOOo
ooooog:[dOl0HZWo1fb^o`5PZ002okODi`05odRC`ol4Jjgo1Vb^o`U][omaZm401Oooool00oo<h>oo
77Reo`I[[P02o`M/[P03o`I[[_lPN[Kognce00Gooooo00KoFIc9o`9X[?l7K:ko1fb^o`AZ[On:^]T2
ooooo`03onG`mom<U/Go06BZ00;o1fb^00?o05fUoj_=i?ooool00_ooool01_lRO;Ko1Vb^o`M/[_l5
Jjko4W:aoiS2g@;ooooo00?ofNWcoc>6_Ol1J:`00_l7K:h03?l3JZgocn;_ooooooooooooamk]o`1L
YOl7K:ko05nWohbkfOooooooD9O6o`1WZ`;o1fb^00?o1Vb^oaAd/_o1f^X00oooool01OnMaMoo05jV
o`M/[_l0G:Go_mWZ00;ooooo00koZLgSo`a_[ol4JZgo1F^^o`1VZ_lZPK[oMJgBod6?`Ol0J:_o1F^]
o`AZ[Ol6Ij_oTKkLooSkoEgooooo00goclo?oaLG5ol0003oaLG5ooooooodm?CoI6AToadM7OogmoOo
oooooginO_lE5AGocLg=00;ooooo00OoPH61o`000?oZj^[oooooonOWiol?3`ooDe=C00?ooooo00Go
/k>co`@41?n>SXkoj^[ZooknoP03ooooo`04ooGemOmeMGGo5QHFolo?c`;ooooo01_oHV9RofMWIook
no_o[Jf]o`000?o>c/kooooooogmoOn^[Zko0000ojn_[oo[jn_o:b/[ofe]KOokno_oooooooCdm?lD
51CoFEUIooooooomoOgo_;blo`000?m6ATKo:BTYodQ8B?oclo<01Oooool00ooCdm?o0000og5aL@14
ooooo`03ol_Fj?n^`=coZKcJ00;o[;kK00OoYKWHolKAiOoSio3od=SXojnogOn2Y<goEHZn00;oEh^o
00_oF8^ooeZ<_omERkooBHFlodB5_?l@KJkoOk?Eom7Lk?nda=ooYk[HojVlfP02ojbnf`04oj^mf_nY
_=Woc=KYooKhnb[ooooo00Cof=SHoiFEUOo;bl_oo?cl?Oooool01?o/k>coCdm?obHV9_oKfm/Goooo
o`04onSXj?m9BDWo92@TomgMgHGooooo01_o]]CWo`1LYOl7K:ko1VZ]oa]h]Ol[PK[o:H2iob9g]?nf
e>Ooo_koooWkoOl0HJSo1fb^o`I[[OlGM[?o=hVnobEn^?l<Kk3o1Vb^o`1JY?mj/=?om_Wlooooool8
KJko1fb^o`AZ[OlfR;d01oooool05?l_Pk_o16Z]o`M/[_l>LK3oooooomk[m?l0G:Go1fb^o`5UZ_m[
YlkoK:S>o`1TZOl5JZko1VN[oi[3g_oooooo3G2`o`M/[_l4JZgo<8Bk1?ooool01OmbZm7o06:Yo`M/
[_l0GJKog^_d00Wooooo00GoJJK>o`1SZOl7K:ko1VZ]obEn^002obV0^@0Boc25_?nbdNKooooookKD
iol0G:Go1fb^o`1PYonE`MgoBYC4o`1X[?l5Jjko2Vf_ojO;h_okoOko066Xo`M/[_l0IZ_oF9c80_oo
ool01OmbZm7o06:Yo`M/[_l0GJKog^_d00?ooooo00[oenObo`1MY_l6K:ko0fF[ogZ_e?oooooo]=?W
oaEd/ol0IZ_o1fb^0_l4JZd00olGMK?o<HFkojk?i023ooooo`00C?ooool05onVb^;o05fVo`M/[_l8
KJoo06BYo`1OYol0IJ[o16Z]o`1X[?lKMkCoc^7_ooooooo7g^go05bUo`M/[_l8KJoo06>Yo`1LYOl0
HjWo16Z]o`5Y[?l3JJgoXLSQ00?ooooo00KokOCioe6Haol9KJoo06FZo`AZ[Ol2JJ`2o`1X[005o`AZ
[Ol2JJco06N[obf2^_nG`]h01?ooool02?nhe>So;8:jo`1XZol1JJco0FR/o`1TZOl0I:[o0fZ]0_l2
JJ`02?loS/3obMo]ooooooooooooLZ_Ao`1RZOl7K:ko26j_0_l0GZH01Ol0IZ_o1F^]o`1XZolXOkSo
b=o]00Kooooo00Ko?Xc0o`M/[_l7K:ko1fb^o`U][_m<UL@6ooooo`06ogjbeOl=Kk3o1Vb^o`M/[_l3
JZgodN?`0_ooool01oonooooVlCOo`1OYol6K:ko1V^]o`AQZ?o6gN`00oooool01_mKW/[o0fZ]o`M/
[_l1JJco;hBkonC_m`?ooooo00KoGIo:o`=Z[Ol7K:ko1fb^o`1WZookoOl2ooooo`08olONkOl0G:Go
1fb^o`1OYon<^mWooooooe2Ga_l0Ij/2o`M/[P03o`=Y[Omd[=7ooooo00?ooooo00GoWLGOo`1NY_l7
K:ko05bUokoIjP03ooooo`0<offXcolHM[Co06J[o`9Y[?l0Ij_o06>Yo`1VZ_l3JZgo06N[o`M[[OmR
Xlcon?_mGoooool03?m1@D7o:BTYog=cLoobl_;ooooool30`?l10@7oZJVYoooooon`/;3o1PH6ojZZ
ZP;ooooo00Soa/K6o`410On^[Zkooooooo?clomKFe_o92@Too7al@;ooooo00KoemOGoa`L7?ln?Sko
Ti>CokZj^_oDe=@3ooooo`0;okNg]ol0003oN7QhoogmoOoooooo]kNgob0P8?o>c/koinOWo`000?n9
RHT00_ooool01ooMgMgo51@Dog]kNoooooooDe=CocDe=OoRh^800_ooool02om<C4co9RHVoooooooo
oooojNWYoa8B4_m0@43oSHf=ogalO?oFe]Kokno_00Cooooo00?oK6a/o`T92Oo=cLd0AOooool06?oL
i?3o]<CNojZmf_n[_M[o[;kKojRkfOnT^=SoYk[Iojnog?n7YlooEh^ooeV<_omJS<3oChRnod63^_ll
P[[o6gFcoamg]?m<QkgoPJ;=oj>heon[_=[o[;kKoj^nf`;oZkgK0_n/_]/01?nW^]Wo_<_Sonc`moon
o_lXooooo`04omSHf?nEUIGobl_;ooclo0_ooooo00GooOgmono_kooOgmool_;booknoP0^ooooo`03
oiVIVOl20P;o[:b/01Sooooo00?oUYJFo`P82?nh^;P0QOooool07?nfe>Oo05bUo`M/[_l0GjOoRk[I
on[bn?oRk_Gog^cdooGio?oooooonO_mo`1QZ?l7K:ko06J[of>Rc?ooooooe>Kaocb<`?l0IZ_o0FV/
ob1k]_oVlOOoooooobMo^?l6K:ko1F^]obEn^?oJjO<5ooooo`0Eom[YlolPNkKo1F^]o`I/[_l]P[[o
ooooomk[m?l0G:Go1fb^o`E[[_lBL[;o4G6ao`=[[Ol0IJ[oGJ3:ooSkoOoooooo3G2`o`M/[_l4JZgo
<8Bk00Cooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[m009ooooo`05ofVVc_l0HjWo1fb^o`1PZ?o;hNh0
0_oRk_D04_oSk_KoloOkoooooonfe>Oo05bUo`M/[_l2JZgo7GVfoa1a/_l5Jjgo06N[ogN_dooooooo
loSko`1QZ?l7K:ko06J[oeRLb0;ooooo00GoLZ_Ao`1RZOl7K:ko05fVomk[m002ooooo`0?ookno_nI
a=ko066Xo`=Z[OlIN;CoZ/cToooooomb[=7o06N[o`M[[_l5JZgo7WVfodjFaOnOa]ooj_?h08Cooooo
001<ooooo`03oj77h?l0E:7o06>Y00?o06>Y00Co06:Yo`i`/Ol_Q;_oWLGO0_ooool00oo4g>co05>P
o`1SZ@03o`1SZ@04o`1RZOl5JZgo8Gbgof^WcPGooooo00_oo_knohZifOlkR;ko6WNdo`U][ol0I:[o
0VV/o`ma/OlYP;WoEI[8olcQkP06ooooo`0:ol?Kk?mBV<Oo:h:ioa5b/Ol0I:[o06>Yo`e_/?lRO;Oo
DiW6omKWl@?ooooo00?oJZK>o`1IY?l0HjT01?l0HjT00ol>L;3o=XRmoi_4gP07ooooo`06oiK1gOl4
JZgo06>Yo`1SZOl3JZcoY/_Q1_ooool01OnE`=go2Ff_o`1RZOl0HZWo9Wng00Cooooo00Kobn7^oa5c
/_l0GjOo062Wo`Y_/?o?h^l3ooooo`05ognceOl0H:Oo06>Yo`1SZOmGVlP01?ooool01OnVb^;o36n`
o`1RZOl0HZWo36n`00?ooooo00_oa=c/o`1CX?l0HjWo05JRohFgeoooooooAY73o`1NY_l0HjWo062X
ocn>`005ooooo`05oiO2gOl0EJ7o06>Yo`1CX?nkenT01?ooool02_nUb^;o=8Flob1k]_l8KJoo066X
o`1W[?lDM;;o:h2iog^ae?obmo]Nooooo`0HomGEeOokno_oWYjNo`L71onb/[;oWIfMoooooooRh^;o
8B4QoeMGEooooooog=cLoa`L7?m/K6con?Shooooooolo?co1PH6ohN7Qoooooooo?cloj2PX?l20P;o
[Zj^0oooool04om<C4co>SXjol;2`_n1PH7oGemOojBTY?okno_oooooomgMgOlA4A7o:2PXon3Ph?oo
ooookNg]oaLG5on3Ph?oooooob@T9?lo?cl00_ooool01ooYjNWo?CdmodQ8B?ooooooQXJ6o``<3?o3
`l<00_ooool03?n@T93o0000ooooooooooool?3`odi>C_lM7Agoh>3PonOWion7QhOoRXZ:om3@d0;o
oooo00?omOGeoa0@4?m=CDd0Aoooool01?o`loSo`LoUojbmfonY_=X3ojbnf`0@ojjnfon6Y/koG8g0
odN6_?lgOkSo<7nioa]f/olaOKOoH8o1oen>`?mBQkgoOj?=ojVlf_n/_M_oZKcJojjog0;o]<CN00Oo
ZkgKojbnfon/_]_oY[[Iok30g?oMiO3ono_m02Oooooo00Cof=SHoiFEUOo;bl_oo?cl2Oooool01ooi
nOWoiNGUolc<c?nUYJGoQ8B4om7AdOomoOd0;?ooool01Oolo?coeMGEofUYJOl0003oLg=c01Kooooo
00Koo?clomSHf?mfMWKo0000ogIfM_omoOf4ooooo`05okKDiol0G:Go1fb^o`1LY_nTbN401Oooool0
1Ooinogo066Xo`M/[_l0Ij_oF9c800;ooooo00coM:cBo`1RZ?l7K:ko05fUomk[m?ooooooO[;Eo`1W
Zol7K:ko2fj_oenPb_oYl_P3ooooo`09onWbn?mOX<[o2fj_o`M/[_l0Ij_oQ;GGoooooooNjoCo05bU
00;o1fb^00Go16Z]o`A[[Ol0HjWo<8Blon?^mP02ooooo`04o`e`/?l7K:ko16Z]oc24^`Cooooo00Go
M:cBo`1RZOl7K:ko05fVon7]m@09ooooo`05ofVVc_l0HjWo1fb^o`1MYOo_m_X01Oooool03onfe>Oo
05bUo`M/[_l8K:ko0VV/o`E[[Ol0HjWo?Xg0ooSkoOooooooloSko`1QZ?l7K:ko06J[oeRLb002oooo
o`05og:[dOl0HZWo1fb^o`1MY_oQkOD00_ooool03?oamo_o>8Nmo`9X[?l0J:_o;hBkom7Tl?oooooo
I:?<o`1QZ?l7K:ko066Xojo@iHOooooo001<ooooo`03olcQk_m^XlcoLZ_A00?oLZ_A00?oKZS?oiO1
g_oDiO400oooool00ooOk?GoKZ;<og:[d@03og:[d@03ofjYcon7]mSo_mWZ00Sooooo00Ool?Kjojg>
i?n?_M_oM:gAoh:ee_nI`]koa]g/00Wooooo00SooOknolgRkonMa=ooM:gAog6[dOnE_mco_MSYooOj
o0Cooooo00?o[loUofjUc_mbZm401?mbZm400onG`Mgof>Sbooooo`07ooooo`06omk[mOmk/MCoLZ_A
og:[dOmj/=?okoKj1_ooool01OoNk?CoP[GFog2[d?m^ZLoo[m3U00Cooooo00Kol_Okoio6h?m]Ylko
KJW@ognce_oVl?L3ooooo`05okoIj_m_ZM3oLJ_AogZ`e?o6gN`01?ooool01OoYl_SoQKOGog2Zd?m^
ZLooVlCO00?ooooo00_ognceofjRc?mbZm7oKZC=okgHjOooooooVlCNofjXcombZm7oKJO?omcZm005
ooooo`05olONkOm^XlcoLZ_AofjRc?oKjO<01Oooool01ooTkoKo]]CWohfkf_m]YlooO[;Eoj;8h?oE
i_40H?ooool03on9RHWojNWYonGUiOl0003o/[:boi:BT_oBd];oo?clogAdM?lR8R;oj>SXoooooom/
K6co410@om3@d002ooooo`07o`L71on@T93oooooooooooo[jn_o5ADEog1`L003ooooo`0>olK6a_l7
1`Oo`<30ooooooo>c/ko2@T9ok2`/?ooooookNg]oe5ADOlP823oV9RHomgMgOooool2ocTi>@0@ooKf
m_n^[Zko0000omOGeoooooookNg]oeEEEOmCDe?oooooon7QhOlC4a?oLG5aooWinOooooooY:BTo`P8
20;ooooo00gono_koifMWOl0003oH61PomcLg?ooooooWIfMochn?_nm_Kgoooooolg=cOl0003ob/[:
00;ooooo00?ono_kooooooooool0@oooool01?ohn_codmc]ok31gOnX^mX2ojRkf@08okk:h_n=/]Go
;W^foc60^OlRM[Co@XFkof:?`OmLSL02oeN;_`0@oe27_OmlX/coY[[Iok?2gOnkb^7oam7Vom3IjOo>
enSo^<OQojbnfon[_M_o[;kKojVkf_nZ_=_obmKYoo;enBKooooo00Cof=SHoiFEUOo;bl_oo?cl1ooo
ool02?o`l?3of][Jok^k^onFUYKoRh^;oj6QXOnm_Kgokno_;Oooool01OoinOWo][JfofIVI_mOGeoo
WYjN01Kooooo00KonOWiokZj^_m`L73oFe]Koi6ATOolo?b4ooooo`06okKDiol0G:Go1fb^o`1NY_nE
`=com_[l0_oamoX08OocnO_oooooooWkoOl0HJSo1fb^o`1WZomPX<_oooooonWbn?m@UlKo06FZo`A[
[Ol=JJgohNgeoooooooTkoKo3G2`o`9Y[?l4JZgo1Vb]oe:HaonSb>7o_=OYoj;7hOmBV<Oo1Vb]o`E[
[Ol2JJco3G2`onOamooooooog^_do`1LY@03o`M/[P03o`9WZolFKk3o_mWZ00?ooooo00go3G2`o`M/
[_l4JZgo<8BkooooooohnogokoKjooWloOm/Yloo06>Yo`M/[_l0GZKod^C`00;olOOj00?oo?knoooo
ooooool01?ooool01OmYY/ko06>Yo`M/[_l0GjOofNWc00;olOOj00Gol_OjooKjo?oooooo]]CWo`1L
Y@03o`M/[P03o`9WZolPM[?od>?_00;ooooo00GoloSko`1QZ?l7K:ko06J[oeRLb002ooooo`0Gog:[
dOl0HZWo1fb^o`1NY_oBi?3oloSkolONkOmYYlko062Xo`M/[_l1J:coH:3;ooWkoOooooooLjcAo`9V
Zol6K:ko066Wok_GjOocn?_oe^Oboic5goofn_`0Poooool00?ooooooAoooool03oni^KWoTi>Coooo
oolf=SKoDU9Bono_komdM7Cohn?Sol71`Ol0003oZ:RXoooooooGemOo6QXJogalO002ooooo`0Ro`00
0?o0`<3on?Shoh^;RomJFU[o2@T9oadM7Om^KVkoJ6QXolS8b?ooooooS8b<odM7Aoobl_;oooooog1`
L?lT92Coooooooclo?n?Shoo7alOoj2PX?nLW9co]KFeob/[:olC4a?oi^KVooooooli>CWo@D51oooo
oooalO7oCdm?og]kN`;ooooo00KoQXJ6oaDE5Oo?cloooooooh^;Role=CD3ooooo`0;omCDe?l=3@go
H61PojZZZ_no_koooooooc<c<ole=CGol?3`onCTi?l000000_ooool00omjNW[oLW9booShn016oooo
o`0:on;Xl_nkb^;o`<gTom_Skoofm__oW/7MobQi]OmARKooGhk1oeZ<`0;oEh^o01?oEXZooe:8__m>
Q[coR:[@ol?@iOoBf^[og>;]omgRk_oGg^coe=c[olkHjOnnb^;o[[oLojZlf_n/_]_oZkgKojJjfOnk
b^;oi>[d02Gooooo00Cof=SHoiFEUOo;bl_oo?cl1Oooool02?oWinOobl_;ojn_[onATI7oSXj>ojf]
[Oo8b<Soi>CTC_ooool00oomoOgoooooooooo`23ooooo`0FokKDiol0G:Go1fb^o`AWZoljR[ooHJ7;
oebNbOmHW<SoO;;Eoocmoooinogo066Xo`M/[_l4JZgo<HFloh>feomBVLKo4G:bo`A[[Ol0HjWo@i32
ongdn@;ooooo00goU<3Mo`=Y[?l0IZ[o1Vb^o`1RZOl0J:co7WZfo`1W[?l0HZWo1Vb^o`1VZol3JJco
U<3M00;ooooo00Sog^_do`1LYOl7K:ko1fb^o`A[[Ol1IZ_oQ;OGoo[lo@?ooooo00go3G2`o`M/[_l4
JZgo<HFloooooonXbn;oEIO5ofFTc?l[PK[o16V/o`M/[_l4Ij_oDIS600;oG9k900?ofn[doooooooo
ool01?ooool01OmYY/ko06>Yo`M/[_l4IjcoDiW700;oG9k900GoGZ3:oi[4gooooooo]]CWo`1LY@02
o`M/[P03o`E[[Ol0HZWoX<OP00?ooooo00GoloSko`1QZ?l7K:ko06J[oeRLb002ooooo`0<og:[dOl0
HZWo1fb^o`AWZomAV<KoGZ3:ob^1^Ol0H:So1ff^o`1TZ_lRO;Ood>?`0_ooool02On_d>Go5GFco`1X
[?l4JZgo8gfgoe^NbOllRkoo2Vj_ojG9hP23ooooo`00oooooom7ooooo`0;oo_knon>SXkoU9BDoalO
7ol0003om?Cdokfm_OmVIVKo=cLgo``<3?nc/k<00_ooool03_nn_[koEEEEoiRHV?n4Q8CoDe=CooSh
n?oinOWoVi^KogmoOomPH63o0000oeYJF_mmOGgod=3@0_ooool01OnFUYKoXZ:Rok6a/Ol^;RkoD51@
00;ooooo00oo`L71o`d=3OnYZJWogMgMoh61POl0003o=SHfon_[joooooooemOGodM7Aon<S8coU9BD
of9RH_oIfMT00_ooool01_o`l?3oKfm_ofa/K?nPX:3oEEEEojn_[`?ooooo013oiNGUochn?_m4A4Co
i>CTojf][On3Ph?o10@4obHV9_oZj^[oooooohj>S_nWYjOoKfm_o`000?mJFU[onOWiAoooool01oof
n?cok_;honS]mOoGgngoTZoCoef>`?mHRkl00_mGRkl04OmER[koDXNmoeR<`?m/VLOoMJ3:ojk5gOoR
io7oi>SbomoSkooKhNgof=o]omGLjooAfN[oc]KYol7=honb`]goZ[gJ00;o[;kK00?oY[WHok;2g_oE
gN`09?ooool01?oHf=SoUIFEol_;boolo?`2ooooo`09oogmoOoMgMgo_[jnojFUYOn<S8coU9BDokRh
^?oHf=Sok^k^0=Kooooo00Go]]CWo`1LYOl7K:ko26f^o`1WZ`02o`1SZ@0?o`1OYol]Pk_onocnooWk
oOl0HJSo1fb^o`Q/[_l0J:co062Wo`1TZ_l1JJco06BYo`1PZ?nNa^3on_cn00?ooooo00CoT[kKob9l
]ol0FjGo06J[0ol1JJ`01?l0IZ_o05^UobEn^?nB_]/3ooooo`07omk[m?l0G:Go1fb^o`M/[_l0HZSo
D9S6on_cn@04ooooo`0=o`e`/?l7K:ko16Z]oc65_?ooooooLZ_@o`1GXol0HjWo0FR/o`Q][_l7K:ko
26f^o`1TZP02o`1SZ@03olGLk?oooooooooo00Cooooo00GoJJK>o`1SZOl7K:ko26f^o`1TZP02o`1S
Z@0:o`1UZ_mNX<_ooooookKDiol0G:Go1fb^o`I/[ol0H:OoGYo:ooGio0?ooooo00GoloSko`1QZ?l7
K:ko06J[oeRLb002ooooo`0;og:[dOl0HZWo1fb^o`Q][_l0I:[o06>Yo`1VZol0Ij_o06BZoc:6_Oni
e^P00oooool01Oobmo_oKZW@o`1WZol0J:_o06R/00?o06>Y00?o9gnionWbn?ooool0POooool00?oo
ooooB?ooool02_oalO7oa<C4ok2`/?nYZJWom_Kfooooooo3`l?oXJ6Qol?3`oodm?@3ooooo`04omGE
eOo9bLWo_[jnon[ZjPCooooo00?odm?Coa0@4?nATI401Oooool01?oEeMGod];Boj^[ZooWinL2oooo
o`08omSHf?lW9bOoF5QHooShn?oWinOo];Bdom3@d?okno/2ooooo`04on;Rh_nm_Kgobl_;om_Kf`Co
oooo00ComOGeolK6a_o9bLWobLW91?ooool02Oojn_[oOGemo`/;2ooAdM7on?ShokZj^_nXZ:SocLg=
oo_kn`02ooooo`04olo?cond];Co]KFeonWYjDOooooo02;omOOkomWRkoo3d>Go/l?Nojbmf_n6Y/ko
Eh^ooeJ;_omCRKkoDXNmof2@`_mgXL[oQjc@oi:ddon@/mCo_<oSon;Wl?oSio7oh>C_omcRk_oIh>go
e]k/om;Jj_o?enWobmGXolC@i_nfaMoo[;gKoj^nfon/_]_oZ[cJojbnfoo3d>Kom_Wk8_ooool03OoH
f=SoU9BDolk>c_oooooomOGeolc<c?nc/k?oW9bLohZ:R_nPX:3ob/[:onCTi?ogmoL0f?ooool00on^
cnCo04ZKo`1LY@04o`1LY@05o`1GXolSOKSonocnooSkoOl0Cih01?l0G:D01Ol0FJ?o16Z]ocR9__nL
aMoom?Sk00Gooooo00Wobn3^ogb`doldQkgo1F^^o`1FX_l7Jjko=8Nmogb`doo=hNl01?ooool01_oJ
jO?o04ZKo`1LYOl0EZ;o9gjhomCUl@Gooooo00Oo062Wo`1LYOl0FJCo6WNeoooooom[Ylko04jN00So
05bU00?o`][[ooooooooool01?ooool00omHW<Wo05:Oo`1LY@04o`1LY@09o`1NY_mFVlWoooooojk?
i?l0BY_o05bUo`1CXOl`Q;_og>_d00Cooooo00Gol_Oko`1?W_l0G:Go05FRodFA`P02ooooo`03of:R
c?l0DIoo05bU00?o05bU00Co06BYoc64_?mbZm7oe^Ob1Oooool02OoYl_SoQ;OGob5k]_l0GJKo05^U
oaEd/_m>U/GoV<;Moo?hn`22ooooo`00oooooomMooooo`04ong]kOmnOWkoSHf=ooShn0[ooooo00Co
n?ShofIVI_lK6a_odm?C5oooool00onh^;So0000oi2@T01@ooooo`0Uon[^m_o9eNOo^<OPojk0g?nZ
_=[oZkgJok30g?n6YlooDhRmoeB8__mZUlKoQJ_?oi6cdonH^=KoVkWGoiRhe_n?/]?o_<kRon?Wl?oS
j?7oh>G`omgSkooJh>gof=o]om?LjooAfN[oc=KXolSDi_o3cnGo^LOQojfog?n[_M_o[;kKoj^nfonY
_=[o^/WQonK[m00Qooooo`0;omSHf?nIVIWo^k^kol30`?n[Zj_oUYJFohZ:R_n^[ZkofMWIong]kOol
o?`0f_ooool00oo/m?Wo_MGXokoIjP04okoIjP05okgHjOo<hNkoo_kooogno_nme^P01?nofNX00onm
f>Wob=k]omg[m008ooooo`07ooSkoOoKj_?ob=o]okgGjOo9gnkofn[cooSko@05ooooo`05ooKjo?nm
eNSo_mWZokgGjOoGio801_ooool01oo0f^_o_mWZokkHj_o:gnkoooooomg[m?nme^P02?nofNX00ooa
m_[oooooooooo`04ooooo`03omSXl_nmenWo_mWZ00Co_mWZ00Wo`=WZomSXl_ooooook?CiokgEj?no
fN[o_MKYom_Zloonool01?ooool01OoloOko_MKXokoIj_nmenWoe>Ga00;ooooo00?of^WcokgFjOno
fNX00_nofNX01?nnfN[oa=c/om[Ylooamo/7ooooo`07ooKjo?oDiO7o`=[ZokkIj_o?h^ooiO3fooko
o`23ooooo`00oooooomMooooo`04ookno_obl_;okno_oogmo@_ooooo00?oYJFUo`000?nMWId05ooo
ool01?oGemOo8R8Rod];Boo^k^i<ooooo`0EooonoooLho3o_/gSok?4g_n/_]_oZ[cJoj^nfon/_]_o
Z[gJojZlf_n4YLkoM9o9ohjbdonG^=KoW[cHoifleonK^mOoV[[GoiRheOn?/]?o_<oS00;oi>Sa00go
hNKaomoSkooKhNgofN3]omGMjooAf^[ocmOXolWDioo6d^Ko`LgTok_:h_n``MkoZkgK00;o[;kK00?o
Z[cJok?4g_o@f^/08?ooool00ooFe]KoVi^KoibLW002oi>CT`03okbl_?oUiNGom?Cd01;ooooo00Oo
b/[:od=3@olY:BWo=3@dodA4A?nMWIgon?Sh00_ooooo00Co`<30ocTi>Ole=CGoUIFEooooooncoooo
o`00oooooom/ooooo`04olg=cOlI6AWoCTi>onWYjAKooooo00ComoOgof][JolL71cod=3@B_ooool0
1_o`loSocmWZok72gOn_`=co[;kKoj^nf`;o[;kK01koZ[gJojFif?nia]oogN7]olWHj?nN_MSoX;kI
oinnf?nN_MSoWKcHoibkeonJ^]OoVKWFoi2cdonmd>CoiNWbonKYlOoRi_3oh>G_omgRk_oJhNgoe]g/
om?Jjoo@f>Woc=GXolSCi_o3cnCo`<gSokk;honda=h4ojbnf`03ojjog?o1c^Gom_Sl01kooooo00Ko
eMGEoiZJV_nLW9cob<S8oo7alOojn_XDooooo`07ooShn?oWinOoA4A4oa@D5?o4a<Colo?cooknoP0;
ooooo`05ok2`/?lm?CgoZj^[ok:b/_m<C4`0oooooonbooooo`00oooooom/ooooo`04ooOgmom?Cdoo
4a<Col[:bQOooooo00?oY:BTo`410OnOWil0B?ooool01?oYk_Ko`<kUojo0g?n]_m`4ojbnf`0RojZl
f_n[_M_o`/cSon?Wl?odm_Sono[kom;NjonR_mWoX;oIoj2nfOnN_MSoW[cHoibkeonK^mOoVKWGoi2c
donmd>?oi^[aonKZl_oSio7ohNG`omkSkooKhNgoemo]omCLjooAfN[ocMKXolWDi_o5d>Ko`<gToko<
hoo0cN?o^<OQojfng0?o[;kK00?oZkgKokK6gooWk?D07Oooool01?oHf=SoUIFEolW9bOojn_XHoooo
o`03ohb<S?lH61Sobl_;00gooooo00Kono_kooOgmoolo?coo?cloalO7onVYZH4ooooo`03on;Rh_n>
SXkof=SH02Wooooo00?od];BohJ6Q_oemOD0:?ooool00oo8b<SoR8R8ooooo`3ooooooe?ooooo003o
ooooof_ooooo00GogMgMoeeMGOl@413o0000ojZZZP0Eooooo`06ooCdm?nDU9Co7QhNo`000?mXJ6So
n_[jA?ooool00oomoOkoemo^okG5h006ojbnf`0Coj^mfona`]gocmOYoo7bmookn_[onOSiooWin_ol
o?_od]k[oj;0f_nQ_mWoX;kIoinnf?nM_MSoW;cGoibkf?nJ^]KoTKCDokkAi002onO[lP0;onCXlOoR
io7ognC_omcQk_oHh>goeMc[om7Jj_o?enSob]CWolKBi_o1cN@00onoc><00onmbn?o[l3Mojbnf`02
ojbnf`04oj^nfon^`=cod=_[oocmoA_ooooo00Cof=SHoiFEUOo;bl_oo?cl6?ooool00oni^KWo10@4
ojVYZ@0Aooooo`03odm?ColU9BGooooo00Cooooo00?ok^k^ofYZJ_o>c/h0:Oooool00ooRh^;oEUIF
ooKfmP0Xooooo`03om?CdomEEEGooooo0?ooooooD_ooool00?ooooooKOooool00oojn_[olO7aoooo
o`0Hooooo`03onOWioo]kNgooooo043ooooo00Ooo_kooo_loOo[l?Kob=CXojbnfonY^m[oZkkK00?o
[;kK02Co[KoKok31gOnmb^7oh>G_oocjn_omoO_ono[jooWin_oin?Won?SioogknooCgn_oX/3Joj:o
fOnP_mWoX;kIoijmf?nM_=SoW;_GoiZkeonB]MCo_m;TonO[l_oXjo;oiNSaon;WlOoPiNoogN;^omWP
kOoFgNcodm[ZoloHj?o<eNSoam?Vol??i?o0c><3oko<h`03ol3=honeaN3o[;oK00?o[;kK00CoZK_J
ol3=i?o`m?Woo_kn6Oooool01?oHf=SoUIFEol_;boolo?`Hooooo`04on?SholT92CoJ6QXooGemA3o
oooo00?oR8R8o`D51Oo0`<001Oooool00oo9bLWoLG5aonCTi00Yooooo`03ok6a/OmfMWKooooo02So
oooo00?oX:2Poh:2P_ooool0oooooomAooooo`00ooooooo9ooooo`06oo_loOoemo_oh>Obok_:hOnU
^=SoZKcJ0_n/_]/02?n[_]_oZkgKojo0g?nda=kob]CWon_]looooogooOck0oojn_X2ooWinP03ooWh
nOomno_odn3[00;oX/3J01KoXKoIoj2nfOnO_]SoWK_HoibkeonK^mSoT[GDol3Ai?oWk?;ojNcbonGY
l_oSio7ohNG`omkSkooJhNgoemk]omCKjoo@fN[ocMKXolSDi_o4d>Ko`<cT1?noc><00oo0cN?o^LSQ
ojjng003ojbnf`04ojNkfOnb`mkoh^SboocloASooooo00Cof=SHoiFEUOo;bl_oo?cl6Oooool01_m8
B4So@T92omKFe_o]kNgohn?SooCdm0?ooooo00SooOgmonWYjOoOgmoomOGeooooooofm_Koh>3Poo7a
l@;ooooo00?o`/;2o`000?mlO7`01?ooool01?ojn_[oe]KFob8R8_o=cLd6ooooo`03oo[jn_oRh^;o
jNWY00;ooooo00ConOWion7QhOoPh>3oo?cl0_ooool02?oYjNWog]kNooShn?oooooon_[jon;Rh_oV
i^Koo?cl0_ooool01?oTi>CogMgMon?Shoo_knl2ooooo`03ooWinOoRh^;ojn_[00Cooooo00?on?Sh
ol;2`_lC4a<02?ooool01?o[jn_ogMgMonWYjOolo?`3ooooo`04ooShn?oNg]kog=cLonk^kP;ooooo
00Con?ShomoOgooPh>3on?Sh0_ooool00oodm?Cog=cLong]k@03ooooo`04oo;bl_oMgMgoinOWooWi
n@?ooooo00?omOGeojb/[?lM7Ad0oooooomBooooo`00ooooooo7ooooo`06ooOio?o]l_Sod=[Zok72
gOnS]mOoZ[cJ0_n/_]/02?n[_M[oZkgKok?3g_nkbN7odm_ZooGemoooo_cono_k1_ojn_X07?oinO[o
nOSioocjn_oCh>_oXl7Joj;0f_nQ_mWoX;kIoinnf?nN_MSoWKcHoibkf?nC]MCo`=;TonS/l_oZk?;o
in[bon?WlOoQi_7ognC_om[QkOoHgngoe=cZom7IjOo=enSob]CWolGAi_o1cN@5oko<h`04ol3<honk
b>;o[koLoj^nf`;o[;kK00GoZKcIojVlf_oAfn_oloKjookno`0Fooooo`04omSHf?nEUIGobl_;oocl
o1Wooooo00OoRHV9o`820_lo?cooTY:BoeADE?mgMgOolo?c00;ooooo00Wog]kNobl_;ol30`?oS8b<
onWYjOnb/[;o0@41of=SHooShn<00_ooool00ol410Co>c/kooooo`02ooooo`05ookno_n`/;3o=SHf
o`000?o>c/h01_ooool04oo:b/[o3`l?oeaLG?oQhN7ooooookZj^_l30`?o92@Tol30`?ooooooo?cl
ofQXJ?l0003oZZZZoooooooPh>3o:2PXoa`L7?oJf]X00_ooool04?lo?coo0000ob@T9?nIVIWoi^KV
oooooooCdm?o5QHFocTi>Oo@d=3ono_koooooookno_oTI6AobHV9_l410@8ooooo`0GoemOGol0003o
KFe]ol?3`oo_knoooooooogmoOnPX:3o0000o`h>3_mkNg_ogmoOoooooon][Jgo30`<obl_;onMWIgo
moOgoooooon7QhOo0000ogIfM_oZj^X00_ooool02_nGUiOo0000oe9BD_nm_Kgojn_[ooooooojn_[o
N7QhoaTI6OlH61QCooooo`06ooOjo?o?hnooc^;_olgQk_oNjoCon_cn1Oooool01_oSk_KocN;_olkR
kooDi_7ogncdolgQk`Gocn;_00Soc^;_omSXlooooooooOknolgPk_o?h^oocN7_omk/m0Cooooo00?o
fn[colkRkoo?h^l00oo?h^l02Oo>h^ooe>Gaoo;gnooooooojO;holgPk_o?h^oocMo]ooCin`02oooo
o`0:onK`moo>h^oocn;_olkRkooIj?;ok?CiolgPk_o?h^oocMo^onken@Kooooo00_oj_;holgPk_o?
h^oocN3^onOamoo`m_[ocn;_olkRkoo=h>koio7goognoP04ooooo`0;oo[loOoKjO?ocN7^olgQkooG
io;omOWloooooooJjO?oc^;_oloRkoo>h^l00oooool01Oocn?_ocMo]oloRkoo=h>koj_?h00Kooooo
00Coh^kfolgQkooAi?3oj?7h1_ooool00ooGio;oc^;_oloRk`03oloRk`03olkRkooEi_7om?Wk083o
oooo003oooooolGooooo00Kom?Kjon7Wl_o1cnCoZ;_JojJif?nZ_MX2ojbnf`08ojVlf_n]_]_o]lKP
ol??iOoRio3on_Wjooomo?ojnOX2ooWinPKon_[j0_oinOX06_oln_[odn3[oj?1f_nR`=[oX[oIoj2o
fOnP_]WoW[gHoifkf?nL^mOoTkKEol3Ci?oYk??oj^gdonOZl_oUj?7oh^K`omoTkooLh^kofMo]omKM
jooBf^[oc]OXol_Dioo7dNKo`/kT0_noc><01Oo0cN?o_lcSokc:h_nha^7o//;M00Co[;kK00GoZkgK
ojNkfOnW^MWobmOYoo_lo@0Fooooo`04omSHf?nEUIGobl_;ooclo1Wooooo00?o`L71o`T92OnATI40
0_ooool04_lj>S[oKFe]ookno_oooooo/K6ao`000?mOGeooMgMgohb<S?n[Zj_o5ADEocHf=_miNGWo
l_;boo_knol/;2co5QHFonc/k0;ooooo00Gon_[joeQHF?l10@7oADE5onKViP06ooooo`0>okJf]_lo
?coo`l?3ohf=SOogmoOoLG5aoahN7_o1`L7oGemOonKVi_ooooooh>3Po`L71om<C4`2ooooo`0EoiFE
UOl0003oW9bLookno_oooooobLW9o`P82?lk>c_ono_koiJFU_oFe]Kokno_odU9BOl0003o=cLgol?3
`oomoOgol_;bob/[:ol51@GoIFEU00Sooooo01OoSHf=o`410Oo8b<SoUYJFoiFEUOoVi^Kon_[job<S
8olM7Agod=3@ol71`On4Q8Coh>3Pog9bL_mZJV[oiNGUogEeMOng]kOoooooob`/;?m5ADGob/[:ogmo
O`02ooooo`0:okFe]Ol61PKoUiNGokFe]On;Rh_ogMgMonKVi_l?3`oo2`/;oh61PE?ooooo00Kof^Wc
o`Y][ol0Ej;o05BQobn3^ooIj?<5ooooo`06od6@`Ol0F:?o05ZToa5b/OmRX/co05:P1Ol0G:D02?l0
F:?o8gfhooooooobmo_o04nNo`1LYOl0EJ;oAI721?ooool00olcQ[co05RSo`1LY@03o`1LY@0Eo`1K
Y?l8K:ko]M?Woooooomo/mGo04fMo`1LYOl0BY_o`M[[ooooooogn_co@ho1o`1KY?l0FjGo05bUoeBJ
a_nOamoo04bMo`1LYOl0BicoW<CO00Gooooo00col_OkodbBa?l0E:7o05bUo`1AWomc[=7o_MSZo`1T
Z_l0FJ?o05:PoefOboodnO/4ooooo`0;om_ZlolHMk?o05JQo`1CXOl_Pk_ofNWcoooooolZP;Wo05VT
o`1LYOl0F:<00oooool01OnheNSo04ZKo`1LYOl0C9coR;WH00Kooooo00Co<HBko`1GXol0GjOoGj3<
1_ooool00olIM[?o05VTo`1LY@03o`1LY@03o`1HXol@LK7o`M[[083ooooo003ooooood;ooooo00Go
jn_[ojNWYonLW9co`l?3oogmo@1nooooo`04onK/mOn]_mcoY;OGoj^mf`?o[;kK00_o[KoKokc;hOoB
f^[oj>_coo_jn_olno_onOWiooWin_ohn?WonOSiooWinP07oo[jnP04ooWin_omn_[odn3[oj?1fP;o
X/3J01coXKoIoj2nfOnO_MSoWKcHoi^keonD]]Go`M?TonW/loo[k_Coin_bonGYl_oSio7oh>G`omcR
k_oIh>goe]k/om?Kj_o?f>Woc=GXolSCi_o4d>Go`/gTokk;honjb>7o]LGOojo0g?nZ_M_oZkgK0_n/
_]/01onZ_=[oYk[Iok31gOnocNCoeMg/on__m_omo_h05_ooool01?oHf=SoUIFEol_;boolo?`Ioooo
o`0Gon_[jolK6a_oRHV9ooWinOoooooog]kNo`000?ng]kOooooookNg]ol51@GoYZJVoooooooDe=Co
XZ:Ro`d=3On;Rh_o/k>coijNW_ono_koHV9Ro`H61_n/[:`00oooool01?o;bl_oT92@omKFe_ono_h6
ooooo`0DomgMgOnWYjOooooook^k^oo9bLWo>CTiode=COoooooo^;Rholg=cOoooooomoOgodA4A?lA
4A7oemOGoooooooLg=co9BDUoc/k>oo/k>`2ooooo`0?odY:B_l0003od=3@ooGemOn9RHWol?3`oh>3
Pol?3`ooR8R8oi2@T?oAdM7ooooookVi^OnDU9CojNWY00Sooooo00Wobl_;o`l?3omlO7cooooookJf
]_o3`l?onOWio`000?mMGEd00_ooool06?oOgmoo^KViojn_[onf][Koo_knoooooonEUIGohN7Qo`00
0?nGUiOooooooj6QXOoinOWoooooomkNg_lX:2SoD51@ooooooo5aLGo^KViooShn?n][JgoW9bLooCd
m5?ooooo00KomOWlogZ`dol0GZKo0fZ]oa5^[ongeNP4ooooo`0:oogno_l?LK7o1Vb]o`=Z[Om7T/?o
]mGWo`1MY_l7K:ko1ff^o`1WZ`;o06FZ00So06:Xoc24_?ooooooloSko`1QZ?l7K:ko06J[oeRLb0Co
oooo00CoAi;3o`9Y[?l7K:ko1fb^0_l0IJX05Ol0I:Wo5WFcokWEj?ooooooS;_Io`1OYol7K:ko05bU
olKNkOooooooW<CNo`1XZol7K:ko1V^^oc24_?oQkOGo^MKYo`1LYOl7K:ko05fVojK:hP05ooooo`0<
og^ae?l0G:Ko26f_o`M/[_l0HZWoMjoCooKjo?m3T<;o06BZo`=Y[?lPMkCol_Ok1?ooool01Oo4gNgo
06>Yo`A[[Ol0HZSoP;CE00;ooooo00Co?hg0o`=Z[Ol7K:ko0VV/0oooool01OnofN[o05bUo`M/[_l0
GZKoU<3L00Gooooo00Kocn;`o`1QZ?l8KJko06R/obf3^ooZloP5ooooo`09oc24^ol4JZgo1fb^o`M/
[_l0I:[o06FZo`1RZ?lNNKKoa=c/083ooooo003ooooood;ooooo00Ko^KVio`000?lV9RKoMWIfojFU
YOoemOEnooooo`0AonS]mOnnc>?oYk[Ioj^nfon/_]_oZkgKojfnfoo?fNWomoOhoo_jn_ogm_SomoSi
ooShnOohnO[on?SiooWhnOoinOX01oojn_X01?oinO[ooO[jom?PjonS`MX2oj;0fP0Loj6ofOnP_]Wo
WkkHoijmeonM_=SoU;KEol7DiOoZk_?ojnkconW[l_oUjO;ohnOaon7UlOoNhnoof^3]omONkOoDg>[o
dMWZoloHj?o:e>Oo`LgTok[7hOnc`mko[KoLojZmf_n[_M_o[;kKoj^mf`;oZ;_I00Co]/KPolSDiooO
i_7on__m6Oooool01?oHf=SoUIFEol_;boolo?`Jooooo`03ochn?_mXJ6Som?Cd00;ooooo00Ko=SHf
oc<c<oooooooemOGob8R8_mbLW82ooooo`09om[Jf_lC4a?o:b/[oooooonPX:3ooooooj2PX?l0003o
P82000gooooo00ooo_knooclo?oooooolo?cojVYZOl>3PkoKfm_ooCdm?oooooonOWiooooooolo?co
YJFUo`000?miNGT00_ooool02OmiNGWo0000ohj>S_omoOgoooooom3@d?l10@7oFUYJooooo`02on?S
h`06ol[:b_l71`OoUYJFomgMgOnf][KomOGe2oooool02Oo`l?3o=cLgocXj>_oYjNWooooooo_knooi
nOWo30`<of5QH@04ooooo`08ooOgmooinOWooOgmoooooooUiNGoQHF5o`000?nc/k<2ooooo`07ooKf
m_oooooom_KfoeaLG?lK6a_od=3@ooooo`02ooknoUOooooo00Go`]_[o`iZ[?l5Jjgo066Xoe2HaP04
oiC0g00DogN^dol2J:co1fb^o`ma/?n9^MWoa]g/o`1LYOl7K:ko16R/ocF8_OmDV/OoD9O6odbEa?mc
[=;ooooooo?hnol0HJSo1fb^o`1VZomHW<P4ooooo`0AodNB`ol2JJco1fb^o`AZ[OmBV<KoD9O6odjG
aOmRX/_ocn;_oooooon<^mWo05nWo`M/[_l0G:Gobn7^onken_lVO[P00_l7K:h02?l@LK7o]=;Woooo
oon]c^Go05bUo`M/[_l0GJKoY/[R1?ooool00onRb>7o06>Yo`M/[`02o`M/[P08o`1RZOmbZm7ooooo
ognceOl8JZko1Vb^o`1PYomj/=@3oiC0g006oi:ng?mFVlSo0V>Yo`=Z[?lHM[Co]mGW0_ooool01?lo
SL3o0fZ]o`M/[_l2JJ`3ooooo`05okoIj_l0G:Go1fb^o`1NY_nD`=`01Oooool01_mIWLWo16Z]o`M/
[_l6Jjko47:aoiC0g0Gooooo00Wo<8Bko`AZ[Ol7K:ko2Ff^oeJJaom@UlKoCIG4ofNUcOoGio80P?oo
ool00?oooooo@_ooool01ooRh^;oX:2PomkNg_oWinOoAdM7oiBDU?oinOT08Oooool00oofm_Ko`L71
om[JfP0Uooooo`03ooWinOo4a<Codm?C03;ooooo00_omOOkolgHj_nX^m[oZKcIojbnfon[_M[o[KkK
olG@iOoZk??onOSiooOhn@02ooShn@04ooWin_ohn?WonOSiooWinPKon_[j01gonOWjoogjn_oCh>_o
Y<7Joj?1f_nR`=[oX[oIoj2ofOnO_]WoW[gHoifkf?nE]mGo`]?Uon[^loo/k_?ojNcconOZl_oSj?7o
hNKaomkSkooKhNkof]o]omOOk?oCf^[oaM7Uok[8hOnb`mgo[;gKoj^mfP02ojbnf`06ojZmf_nV^]Wo
Z[gKol7>iOoIh^oojnog7?ooool01?oHf=SoUIFEol_;boolo?`Jooooo`0<ohZ:R_m3@d?okNg]oooo
ooomoOgoPX:2o`<30ooHf=Som_KfoeeMGOle=CGok^k^0_ooool00omRHV;o0000on;RhP02ooooo`03
om_Kfol0003oBTY:017ooooo00Co^[Zjo`D51OnIVIWoo_kn1?ooool03_oTi>Co5QHFobXZ:_oOgmoo
oooool;2`_lD51Co3`l?ojJVY_ono_koooooodE5AOl410CoeMGE0_ooool01_oNg]ko<30`od=3@ood
m?Col_;booOgm`cooooo00?oPH61o`H61_oHf=P00_ooool01Oojn_[o?Cdmob<S8oo9bLWol_;b00Oo
oooo00?oQXJ6o`000?oTi>@01Oooool00onTY:Co0000ojZZZP1Jooooo`05on7]mOm1T<;o06BZo`Q]
[ol0IJX01?l0GjL02ol0HJSo1fb^o`E[[OlNN[Koio7gokKCiol0G:Go1fb^o`1NY_nLa=oomOWl00;o
l?Kj00Ool_Skooooooocn?_o066Xo`M/[_l0IZ_oF9c800Cooooo00GoAi;3o`9Y[?l7K:ko06N[oo;g
nP02oo3fnP09oo7gn_ojo?goooooohbkfOl0GjOo1fb^o`1LYOoKj_CoN[3D00;o1fb^00Wo06N[ogZ`
e?ooooooooooojk?iOl0G:Go1fb^o`1MY_nVb^800oooool00onkenWo3W2`o`E[[@03o`M/[P08o`1R
ZOmbZm7ooooookoIj_lTOKSo0FV/o`Q][ol0HJP4o`1OY`05o`1TZ_l8KJoo06BYoe:Haoo`m_X00_oo
ool01?loSL3o0fZ]o`M/[_l2JJ`3ooooo`05okoIj_l0G:Go1fb^o`1NY_nD`=`01?ooool00ooZl_So
3W2`o`M/[P02o`M/[P03o`1WZom=ULGokoGj00Cooooo00Go<8Bko`AZ[Ol7K:ko372`ooKjo002oo3f
nP03oo;gnooko?kooooo07oooooo003oooooodKooooo00?oP820obLW9ooWinL08Oooool01?ohn?So
bLW9ohb<S?o9bLTTooooo`04oo[jn_o=cLgoShn?okZj^S;ooooo00oooOgnom_Sl?na`]goYKWHojbn
fon[_M[oZ[cJokW8hOoPi>oonOWiooSin_ohn?Won?WjooWin_oin?T00_oinOX5oo[jnP0IooWin_om
n_[odn3[ojC1f_nS`M[oX/3Joj:ofOnP_mWoWkkIoifmf?nM^mSoUKOEol;DiOoZk_?ok>kdonW/looW
j_;oiNSaon;Vl?oQi_3ognC_omKNk?o6dNGo^/SQok71g@02oj^mf`;o[;kK00KoZKcJojFhf?n^`=go
c=OYon7Xl_odmo/Nooooo`04omSHf?nEUIGobl_;ooclo1Sooooo00kom_KfoooooooKfm_o410@on_[
joooooooo_knokFe]Ol0003oZ:RXoooooonYZJWo3Ph>ok>c/`;ooooo00Wo[jn_o`@41?nJVY[oo_kn
ooooooo]kNgo6QXJobHV9_odm?@04?ooool01?o<c<co4A4Aof1PH?oinOT4ooooo`0>ooShn?maLG7o
0000oh>3Poolo?com?CdodQ8B?lE5AGoCDe=omcLg?oooooo_knoo`000?mQHF42ooooo`04ooOgmom]
KFgo30`<okno_`kooooo00co^k^ko`@41?nFUYKon_[jooooooolo?coJf][o`X:2_n^[ZkoSHf=oi2@
T?oemOD5ooooo`03oj6QXOl0003o]kNg00Gooooo00Coc/k>oaLG5omYJFWomOGeFOooool02Oohnogo
PkKGo`1QZ?l7K:ko26f_o`1WZol0GZKo05bUo`1UZP03o`M/[P07od:>`Ooooooo[loUo`1LYOl7K:ko
05fVojW<h`05ooooo`05oo?hnol0HJSo1fb^o`1VZomHW<P01?ooool01?m7T/?o0VV/o`M/[_l0IJ/6
ooooo`0:ohbkfOl0GjOo1fb^o`1PZ?nOa^3o97jgo`I/[_l4Jjgo?Xbooo7gn`;ooooo00Go[/oUo`1L
YOl7K:ko05fVojK:hP02ooooo`0GomSXl_l]Pk[o0fZ]o`M/[_l0J:co26b^o`M/[_l0HZWoLZ_Aoooo
oooamo_oB9;2o`1WZol7K:ko26f^o`1TZ_l0G:Go05fVo`1WZol8KJko1Vb^o`AXZon4]]L00oooool0
1?loSL3o0fZ]o`M/[_l2JJ`3ooooo`05okoIj_l0G:Go1fb^o`1NY_nD`=`01?ooool02?nLaMoo1F^]
o`M/[_l5Jjgo16Z]o`=Y[OlONkKo^=CX1?ooool01?l`Q;_o16Z]o`M/[_l>LK25ooooo`00oooooom6
ooooo`04ol_;bolA4A7oShn?ooShn2;ooooo00?o_KfmohJ6Q_oOgml09Oooool00oo7alOoOgmoom_K
f`0cooooo`0>on_`moo1cnGoXkSHoj^nfon/_]_oZKcJok72gOo@fNWomoKhoo[jn_ohn?WonOWjooSh
nOoin?T2ooWinP?on_[j0_oinOX05_omn_[odn3[ojC1f_nS`M[oX/3Joj:ofOnP_mWoWkkIoifmf?nM
^mSoUKOEol?Di_o[kO?ok>odon[]looWjo;oj>_conSZl_oHgncoa=3UokC4g_n^`=`2oj^mf`;o[;kK
00KoZ;_Ioj6feonga^3ofN7^onc`moojnodPooooo`04om[Jf_nGUiOobLW9ooclo1Sooooo01Wono_k
oinOWonf][Ko1PH6ok^k^oomoOgoooooonGUiOl0003oOgmooooooooalO7oBTY:oeADE?obl_;ooooo
ono_kolC4a?oEEEEoo_knoooooool_;boe=CDolB4Q;od=3@00gooooo01[olO7aomkNg_oooooo[Zj^
obl_;omYJFWob/[:oogmoOoooooodM7Aohn?Sooooooo_;blo``<3?m:BT[oXZ:RoooooonHV9So2PX:
ojBTY?mKFe_og]kNoooooold=3Co5ADEon7Qh@;ooooo00?o/K6ao`000?n9RHT03_ooool01?obl_;o
6a/KoeADE?obl_82ooooo`0Golo?col0003oZZZZomCDe?mfMWKoDe=ComgMgOoooooohn?SonOWiooo
ooooNWYjobd];On<S8coh>3Poooooooclo?olO7aooooooofm_KoAdM7obh^;_oShn<0F_ooool04_o2
fn_o6gRdo`9Y[?l2IZ[oB9?3ojW<honfe>OoHZ;<o`U][ol7K:ko476aohjlf_oooooo[/oUo`1LYOl7
K:ko05fVojK:hPGooooo00GoloSko`1QZ?l7K:ko06J[oeRLb004ooooo`04odNB`ol2JJco1fb^o`EZ
[@;oD9O600goCIK5of^Wcoo/m?WoooooohbkfOl0GjOo1fb^o`EZ[OlPNkKo2fn_o`I[[_lALK7odNC`
00?ooooo013o[/oUo`1LYOl7K:ko05fVojG:h_oooooon?_lodB@`_l4JZgo1fb^o`=Z[OlSO;Oo0VZ]
o`M/[_l0HZWoLZ_A0_ooool03?n>_=[o4G:ao`I[[Ol2IjcoIZC<okKDion_d>Go@i32o`5W[?l1JJco
8GbgokcGj@?ooooo00Co?hg0o`=Z[Ol7K:ko0VV/0oooool01OnofN[o05bUo`M/[_l0GZKoU<3L00Co
oooo00So:h:jo`M/[_l7K:ko36j_oa9c/Ol4Jjgo16N[ogJ]dPCooooo00Co<8Bko`AZ[Ol7K:ko2Ff_
0_m@UlH00om;U<CoLjcAoo7gnP20ooooo`00oooooom6ooooo`04ooWinOlk>c_o?cloonk^kR;ooooo
00?ono_kofATI?nOWil09Oooool00oono_koMgMgohn?S`0dooooo`0>ooOho?oCg>coZ[_JojVlfOn/
_]_oZ[gJojjog?nnbn;olO;eoo_kn_ohnO[onOWjooShnOoin?T6ooWinP0Eoogjn_oCh>_oY<7Joj?1
f_nR`=[oX[oIoj2ofOnO_]WoW[gHoifkf?nE]mGo`mCVon_^loo]l?Cok_3don_^m?oEg>_o_<[Qok;3
g_n]_mcoZ[gJ00;o[;kK00OoZkgKojJif?nV^MWo`/oTon?YloocmO[ooOkn02;ooooo00Coc<c<ohZ:
R_oHf=Soo_kn6Oooool02OoPh>3o/k>co``<3?mdM7Coo_knooooooo[jn_o0000ohR8R002ooooo`03
ol71`OlZ:R[oZJVY00;ooooo00?oBd];o`d=3Oooool00_ooool00onIVIWo0P82oiJFUP0=ooooo`0J
ong]kOn^[ZkokNg]ogalO?lP823oeMGEogAdM?o`l?3oooooobl_;omnOWkobLW9on_[jolh>3So>c/k
ogAdM?ni^KWon_[job@T9?miNGWobl_;oe1@D?oOgmoo][Jfo`410OnBTY82ooooo`04om[Jf_lU9BGo
AdM7onWYj@kooooo00?oLG5ao`d=3Oooool00_ooool04_oinOWoG5aLod10@?ooooook>c/odm?ComK
Fe_om_KfomkNg_nXZ:Soooooobl_;om9BDWoj>SXog5aLOooooooY:BToh61P@;ooooo00?oWIfMo`H6
1_oIfMT0F_ooool04_oUl?OoB9?3o`1SZOl1Ij_o:82ionC_m_ooooooA931o`Q/[_l7K:ko4W>aonOa
mooooooo[/oUo`1LYOl7K:ko05fVojK:hPGooooo00GoloSko`1QZ?l7K:ko06J[oeRLb004ooooo`04
odNB`ol2JJco1fb^o`M/[P;o06N[00Ko06FZobMo^OoSk_KoooooohbkfOl0GjL2o`M/[P06o`=Z[Ol6
K:ko1fb^o`Y^[olkRkooaMc/0_ooool01on^cnGo05bUo`M/[_l0GJKoZLcSoooooomTXl`00_l7K:h0
1ol5Jjgo:7niokgHj_l0H:Oo1fb^o`1RZOmbZm400_ooool03?o<hNoo9Gjho`=Z[Ol2JJcoBY?4oooo
ooonooko5WJco`AZ[?l0IJWo@ho1ooKjo0?ooooo00Co?hg0o`=Z[Ol7K:ko0VV/0oooool01OnofN[o
05bUo`M/[_l0GZKoU<3L00?ooooo00[od>?`o`a_[ol7K:ko2fj_oe^NbOmLWl[o0FJZo`1UZ_llS<3o
fnWc0oooool01?l`Q;_o16Z]o`M/[_l7K:h2o`1WZ`03o`1SZOlbQ[coj_?h083ooooo003oooooodOo
oooo00?oSHf=o`D51OoGemL00_ooool02?ogmoOoATI6oeADE?no_koooooooj>SXol];Bgoa/K61?oo
ool01?oXj>SoATI6ocHf=_nTY:@4ooooo`07ojVYZOl];BgoKVi^ooGemOoooooo?ShnofATI004oooo
o`04oo7alOn:RX[o2`/;ohV9R@Oooooo00Cog=cLod];BolW9bOo];Bd1oooool00onVYZKo;2`/oooo
o`08ooooo`03okjn__lZ:R[ok^k^00Cooooo00ComOGeohn?Sol@413oMgMg=Oooool01Oolo?koh^Sb
ok72gOnX^]Wo[;kK00;oZkkK00Go]<CNon7Ul?ono_con?WjooWinP02ooWhn@ConOWj00?onOSioocj
n_oCh>/00_nS`MX03onR`=[oX[oIoj2ofOnO_]WoW[gHoifkf?nE]mGoa=GWoo3bm_o[k_?ocmOYokK6
gona`Mgo[;kKoj^mf`02ojbnf`06ojZmf_nU^=So[/3Kom3Jjoo]lOSon?Wl9Oooool00oo8b<SoQhN7
on7Qh@0Kooooo`08ooKfm_mnOWko:2PXonCTi?ooooooPH61o`000?nUYJD2ooooo`0@oo_knona/K7o
GUiNon3Ph?ooooooJ6QXo`000?nh^;So[Zj^odI6A_lK6a_o0000o`h>3_lC4a?o61PHok6a/@[ooooo
01[ooOgmojn_[om8B4So4A4Aoc/k>ooXj>SoinOWofYZJ_nFUYKo0000okfm_Om4A4Coooooohj>S_lD
51Co[Zj^oh^;Ronj^[[o>c/ko`T92OoXj>SoemOGogUiNOmoOgoo0000oc0`<0;ooooo00Cono_kof9R
H_l71`Oo`l?33?ooool08OnATI7o5aLGo`000?l0003o7AdMoa8B4_m7AdOoo_knomcLg?mFEUKoXJ6Q
oooooon0P83o8B4QomgMgOokno_oMWIfoeADE?l10@7oL71`ooooooo4a<CoD51@oe9BD_m@D53odM7A
oaPH6?l30`?o0000oaTI6OlD51Co:b/[ooKfmP1Gooooo`0;oocno_n?_M[o06J[o`E[[Ol2H:Oo^mKX
onG`m_lGMK?o1fb^o`Q][omNX</00_ooool01On^cnGo05bUo`M/[_l0GJKoY/[R00Gooooo00GoloSk
o`1QZ?l7K:ko06J[oeRLb004ooooo`0NodNB`ol2JJco1fb^o`Q/[_l0HZSo06:Yo`1PYolPNkKoh^ke
oooooon<^mWo05nWo`M/[_l8KJoo066Xo`1OYol0IZ_o1fb^o`=Z[Ol]Pk[of^Wcoooooon^cnGo05bU
o`M/[_l0GJKo^=CXoiBogOlAL[7o1Fb^0_l7K:h01_nnf>WoiO3go`1MY_l7K:ko06:Yog:[d@;ooooo
00_on_cmoeBJaol6K:go1fb^o`IZ[Oo]m?Wo_MSYo`1SZOl4JZgo4G6aohnlfP04ooooo`04ocn=`?l3
JZgo1fb^o`9Y[0?ooooo00Go_mWZo`1LYOl7K:ko05jVoiC0g003ooooo`0:of^Vc_l:KZoo1fb^o`a_
/?o3g>_oZ/cSo`1KY?l6Jjko1VV/oic4gP?ooooo00Wo<8Bko`AZ[Ol7K:ko1fb^o`1QZ?l0HZWo05jV
obb2^_oZl_L0P?ooool009Sooooo00GoOk?Eoh>fe_nJ`]goe^Obon_cn@2Yooooo`0?om3@d?l;2`_o
Ph>3ooWinOooooool_;bo`000?lQ8B7oZZZZol;2`_ng]kOo0000oc4a<Ono_kooo_kn00;ooooo00Go
Kfm_o`000?m=CDgoJVYZofa/K003ooooo`0?ogIfM_l0003oMWIfohV9ROooooooGUiNo`@41?m^KVko
h>3Poooooookno_oR8R8o`<30ol71`Oo[Jf]00Kooooo00KonOWioeEEEOl>3PkoTY:BogQhN?nBTY86
ooooo`03oi>CTol10@7ooooo00Sooooo00?o/K6ao`000?o[jn/00oooool01Ookno_oUIFEo`<30ol5
1@GoX:2P03Kooooo00Coo_kooo?fn_nnc>CoZK_J0on/_]/01_n``=cocMKXoo_knOojn_[onOWjooSh
n@GonOSi00?oo?[jom?PjonS`MX00_nR`=X00onR_mWoX;oIoinnf@02oijmf005oiRheOngbn7o`/kT
ok;2g_n^_m`01?n/_]/01_nZ_M[oZKcJok_:h_oOi_7on?WloogmoROooooo00?ob<S8ohN7QooQhN40
7?ooool01onc/k?o2PX:oeUIFOle=CGo0000oe1@D?oinOT00oooool03oolo?cob<S8og=cLomgMgOo
Fe]Ko`000?miNGWon?Shono_kooGemOo<30`oc4a<OoTi>Coj^[ZooShn00;ooooo`0Ioo[jn_n=SHgo
0000oibLW?omoOgoooooom3@d?lc<c?o:2PXoo_knonWYjOoCDe=of9RH_l0003oP820ooOgmonLW9co
10@4o`d=3OoUiNGoooooooCdm?mdM7Co0000ocLg=`03ooooo`03oj^[Zol0003oS8b<00cooooo027o
mOGeon[Zj_oXj>So4a<CoeYJF_oWinOokno_ooooooono_kohn?Soi2@T?n6QXKo>CTiof9RH_oemOGo
ooooooGemOm@D53o2@T9on3Ph?oooooonOWioifMWOl61PKoNWYjoo_knooZj^[ojn_[ocPh>?lm?Cgo
e]KFonc/k?ono_h0F?ooool02_o6g^co:h6jo`1XZol0HJWoQKKGoiW2gOlALK7o1fb^o`]^[onXbn<2
ooooo`05ojk?iOl0G:Go1fb^o`1MY_nVb^801Oooool01Oocn?_o066Xo`M/[_l0IZ_oF9c800Cooooo
02KoAi;3o`9Y[?l7K:ko0FR/ojo?i?n[cN?oZ/gSokWEj?ofn_coooooohbkfOl0GjOo1fb^o`5MY_nk
enWoh>geofRUc_l9KJoo1fb^o`a_/?mg[]?oooooojk?iOl0G:Go1fb^o`1VZ_mAV<Ko9gnho`E[[Ol7
K:ko06BZoic5goomo_kog^_do`1MY_l7K:ko06:Yog:[d@?ooooo00[oXLSPoaEe/_l6Jjko06R/ojS;
homi/=?o06J[o`9Y[?l[PK[ob]o^1?ooool01?loSL3o0fZ]o`M/[_l2JJ`3ooooo`05okoIj_l0G:Go
1fb^o`1NY_nD`=`00_ooool03?obmo_o9Wjgo`I/[_l7K:ko;8:joocmo_oMjoCo;86io`1XZol0IJ[o
D9O6onOam`;ooooo00Wo<8Bko`AZ[Ol7K:ko2fn_okKCi_n[cN?oZLcRokcHjOoinod0P?ooool009So
oooo00coenOboa5a/_l9KJoo36n`o`]^/?lDM;;o=hRnof:Qc?n0/mGo/<oUom3Rl?oko?hbooooo`04
oooooOooe:SoolF:ooofk6cooooo01Ooo_knocHf=_lm?Cgolo?cooooooofm_Ko9BDUob/[:oono_ko
aLG5oi6ATOlh>3SoPh>3ojBTY?o@d=3oo_knooooool<30co=SHfoo_knoofm_Ko/;2`ojJVYP02oooo
o`0?oj2PX?l0003oYJFUooclo?nHV9SoWinOo`000?oOgmooRh^;oogmoOoooooo_[jnod92@_n4Q8Co
lO7a00Kooooo00Oom_KfobLW9olZ:R[ooOgmonk^k_nMWIgo_Kfm00Gooooo00?oU9BDo`<30oooool0
2?ooool00ona/K7o0000on_[j`04ooooo`04olO7aom4A4CoN7Qhono_kcSooooo00?oo_knom;Kjon^
_m/00on/_]/01_n]_]_o`<cSooCen?oln__onOWjooShn@;onOSi0_ohn?T00oomno_odn3[oj?1fP02
oj;0fP09oj6ofOnP_mWoXKoIoifmeon8[M7oH933oh2TcOnY_=[o[KkK00?o[;kK00KoZkgKojbofoo7
dnOoko7hoogno_onoolYooooo`03olS8b?n7QhOohN7Q01cooooo00KoiNGUo`H61_mhN7Son_[jooWi
nOokno/5ooooo`06ookno_olo?coo?cloo_knol>3Pko7alO0_ooool01?oemOGoLg=coa@D5?o8b<P>
ooooo`03oogmoOoinOWooOgm00;ooooo00Goo_knoo[jn_ojn_[ooooooogmo@02oo_kn`07ooWinOol
o?cooooooogmoOoinOWon_[jooknoP02ooooo`03ooclo?oinOWono_k00?ooooo00Cof=SHobTY:Om3
@d?oinOW3_ooool00om@D53o8B4Qoo[jnP04ooooo`;oo?cl00?on_[jooclo?ooool00_ooool00ook
no_onOWiooooo`02ooooo`03oogmoOoinOWoo?cl00?ooooo00?oNWYjoa<C4ooGemL0F_ooool02_oh
nogoGIo:o`1SZOl0Ij_oCiO6ocR:__l9KJoo1fb^o`]^[oomo_h2ooooo`05ojk?iOl0G:Go1fb^o`1M
Y_nVb^801Oooool01Oocn?_o066Xo`M/[_l0IZ_oF9c800Cooooo00CoAi;3o`9Y[?l7K:ko06J[1?on
o_l2ooooo`0>ohbkfOl0GjOo1fb^o`1LYOo7g^gooooooocmo_l=L;3o1fb^o`AZ[OlaQK_oooooojk?
iOl0G:D2o`M/[P0<o`Q][_l8K:ko1fb^o`1TZOmj/=?ooOknoooooooNjoCo05fVo`M/[_l0HZWoLZ_A
0oooool02_o^mOWo97jgo`E[[Ol4JZgoGYo:obEn^?l4JZgo06N[odNB`oono_l4ooooo`04ocn=`?l3
JZgo1fb^o`9Y[0?ooooo00Go_mWZo`1LYOl7K:ko05jVoiC0g002ooooo`0<oiG0g?lCLk;o1fb^o`M/
[_nB_mcoooooonofn_mXYLko06:Yo`9Y[?lIM[Co_]SZ0_ooool01?l`Q;_o16Z]o`M/[_l=L;02ookn
o`03oogno_ono_oooooo083ooooo002Iooooo`03ol3Jjol3J:_o1fb^00;o1fb^01;o1V^^o`E[[Ol4
Jjgo0fZ]o`=Y[Ol0Ij_o6GNdocV:__m/Z<ooPKCEol7JjooCi?7onOcmoo[loOokoOkoo?gnoogno_on
o_lSooooo`0:ooono_oonO?oolN@oon63OooN`3oogd0oon11?oo^gOoooS`ooonoF[ooooo01;oTI6A
o`000?oGemOoooooooWinOm]KFgo51@Don;Rh_oalO7o/k>cochn?_li>CWoh>3Poi^KVooYjNWooooo
ode=COn=SHd2ooooo`0>onWYjOnEUIGoeMGEooooooo?cloo6a/KogAdM?okno_ogMgMojFUYOl30`?o
RXZ:oogmoOn@T90;ooooo`03ooOgmoli>CWo:BTY00Gooooo00KooOgmooclo?olo?coo?cloi:BT_l3
0`<4ooclo0;oo_kn0oolo?`00on_[joo0000onSXj003ooclo003ookno_oooooooooo03cooooo00?o
i^_dok;2g_n/_]/00_n/_]/01On[_M_o/L;MomoTkooknoconOWj00;on?Si0_oinOX00oomno_odn3[
oj?1fP02oj;0fP0>oj2nfOnH^MKoMj7:oeb?`OmDRKkoD8NmognScOnY_=[o[KkKojbnfon]_mco/lCO
omOPk_oknoh]ooooo`03olS8b?n7QhOohN7Q02_ooooo00?oJVYZo`000?oQhN400_ooool00oo9bLWo
10@4oifMW@0Zooooo`03of=SHol0003ob/[:00kooooo00?oclo?ohV9ROolo?`05_ooool00ooLg=co
RXZ:onOWi`1Kooooo`08oig4gol=L;3o16^]o`E[[Ol6Jjko1fb^o`E[[Omd[=43ooooo`05ojk?iOl0
G:Go1fb^o`1MY_nVb^800oooool2ookno`0=oo;gnol0HJSo1fb^o`1VZomHW<Soo_kooogno_ono_oo
ooooodNB`ol2JJco1fb^o`1VZ`04ookno`;ooooo00koS;_Io`1OYol7K:ko05bUolONkOooooooo?gn
o`e`/?l7K:ko16Z]oc64^ooooooo[/oUo`1LY@Co1fb^00?o06J[oeFKb?okoOh00_ooool01OoNjoCo
05fVo`M/[_l0HZWoLZ_A00Cooooo00SoHJ7;o`Y^[ol7K:ko1F^]o`I/[_l5Jjko6GNdojC9h@;ooooo
00Ooo_kooogno_ono_oo?hg0o`=Z[Ol7K:ko0VV/00?oo_ko00co_mWZo`1LYOl7K:ko05jVoiC0g?oo
ooooo_kood2=`?l6Jjko1fb^o`U][ooZl_P2ooooo`0;olONkOl1I:Wo1F^]o`1PYon3]MKoo_oooooo
ool`Q;_o16Z]o`M/[_l=L;001?ono_n1ooooo`00V_ooool00onF`Mco1VV/o`I[[P07o`M/[P0Bo`E[
[Ol3JZgo06N[o`1WZol0I:Wo06:Yo`1X[?lWOkWoB9?3ogJ]d_nD_m_o_=OYomk[m?oYl_Sojo?ioo?h
nooenOconocn7?ooool01Ooon?7oomRcoon>7OooMP3oogl000?ooh0000GoogX0oon00Ooo_Wkooo?X
oooln01Xooooo`03omKFe_l<30coNWYj00;ooooo00goeMGEo`@41?nKVi_oooooomSHf?mSHf?o3Ph>
ok2`/?ooooooo_knoooooon:RX[oHF5Q00?ooooo00goeMGEoiBDU?oooooooooooeaLG?la<C7ohN7Q
oooooonNWYkoEEEEoa/K6oomoOgomoOg00_ooooo00Con_[jog9bL_lI6AWon_[j1?ooool04_na/K7o
L71`ofm_KomcLg?o>c/ko`820_mfMWKoKfm_ofe]KOmmOGgofm_Kom7AdOm_KfooKVi^ogIfM_m:BT[o
0000ofIVIP;oKfm_00?oMGEeol?3`oooool0?_ooool02Ooko?go`<gTojk0g?n[_]_o[;kKoj^nfon[
_M[ocMKXooGfn003ooWinP0DooSin_olo?_oe=o[oj2ofOnM_=SoS[;BoffJaomAQkgoEHVnoeJ;_omG
RkooD8NmognScOn[_M_o/L;Mol3>i?oSj_?oooooooWkoOoko?d]ooooo`03olS8b?n7QhOohN7Q02_o
oooo00?oXj>So`000?nDU9@00_ooool01?oTi>Co>3Phoe=CDoolo?`2ooooo`03oo_knoomoOgooooo
02Cooooo00Co/;2`o`<30onATI7ooOgmQ?ooool00ooGio;o>HZno`1W[003o`M/[P03o`AZ[OnofN[o
oooo00;ooooo00Go[/oUo`1LYOl7K:ko05fVojK:hP02ooooo`0Too3gnon[cN?oYL[Qoig6gol1IJ_o
1fb^o`5XZoljR[oo^=GWoj36goo;h>koooooodRC`ol2JJco1fb^o`5Y[?nYc>;oYL[QojC:hOn^cnCo
iNofoooooon<^mWo05nWo`M/[_l1GZKo]]CWomWYlomSX/co2Ff_o`M/[_l9KJkoEic8oooooon^cnGo
05bU0ol7K:h00ol0J:_o;X>kon?^m`03ooooo`05omk[m?l0GJKo1fb^o`1RZOmbZm401?ooool00ong
eNOo5G>bo`M/[P02o`M/[P0Jo`AZ[Ol]Pk[ognceooooooojo?ko`]_[oj77h?nie^So:h6io`AZ[Ol7
K:ko0fZ]ojc>honTb^7o]MCVokCCiol0GJKo1fb^o`1NY_nD`=cooooook[FjOlLN;Go1F^]o`=Z[OmF
V/P3ooooo`0@on;^m_m1Sl7o06FZo`5WZolcQ[coeNOaooooool`Q;_o16Z]o`M/[_l:Kjoo/=3TojG:
hOnTbN7o/=7Uon[bn83ooooo002Kooooo`03ofNUc_l0IZ_o1Vb^00co1fb^01?o1V^^o`9Y[?l0Ij_o
06FZo`1SZOl0HJSo05bUoa5b/_lRO;OoGj3;og6[d?nPa^3o`=[ZomSXl_oPkOGoi_3gonoen_odnOco
o?kn01?ooooo00GooocjoooXd_ooYe3oogD0oomm0006oon00006oomo0?ooN03ooh85ooo4R_ookmko
oociIoooool03Olk>c_o=3@dookno_ooooool_;boeUIFOlo?coono_koooooon?Shoo0P82og5aLOof
m_H00_ooool00ooTi>Co<30`ooknoP02ooooo`0<omkNg_nKVi_ojn_[ooooooo0`<3o4a<Cok^k^oon
o_koooooobHV9_l10@7oclo?3?ooool01?ono_ko^KVio``<3?o9bLT4ooooo`07oiRHV?lV9RKo7AdM
oadM7OlA4A7o0000oa`L7002oadM7@09oc`l??oDe=Co`l?3ob/[:olM7Ago71`LoaDE5Ol0003o6a/K
00;o7AdM00?o:BTYok>c/oooool0@?ooool00oo@f^[o/<;Moj^mf`02ojbnf`0<ojJifOnmbn;ojnkd
ooSin_oin_[onOWiooSgnOo9enSoP:S=ofBCa?m?Q[coE8Vn0omGRkl02omIS;ooD8Jmoh>Wc_o9e^So
ko?hoo_loOoSj_?o`LkUojBhf?o5dNKom_Sk02cooooo00?ob<S8ohN7QooQhN40:oooool00oo/k>co
10@4odY:BP03ooooo`08ojVYZOl^;Rko`/;2ooooooodm?CoXZ:RolK6a_olo?`Tooooo`04on?Shol[
:b_o@D51onSXj8Gooooo00KoJ:K>o`=XZol7K:ko1fb^o`E[[_lPNkD4ooooo`05ojk?iOl0G:Go1fb^
o`1MY_nVb^800_ooool09?oBi?3o1F^]o`1RZOl0HZWo26f^o`M/[_l8K:ko0VV/o`1QZ?l0Ej;oI:?<
oooooom:U<Co0VV/o`M/[_l8K:ko06:Xo`1RZOl0HJOo4W:aokSDj?ooooooS;_Io`1OYol7K:ko26f_
o`1QZ?l0GjOo06J[o`I[[_l4JZgo6GJdok?Biooooooo[/oUo`1LY@;o1fb^00?o0VR[oaId/_o>hNh0
1?ooool01OoNjoCo05fVo`M/[_l0HZWoLZ_A00Gooooo00Ko:X6io`M/[_l7K:ko1fb^o`Q/[_mLW/T2
ooooo`05onoen_m:U<Co05VTo`1QZ?l3JZd00ol7K:h03_l0HZSo066WoaYg]?nPamoo062Wo`M/[_l0
GZKoUL3LoooooomQXLco1fb^o`I/[_l0IZ_o/M3V0oooool02OonooooS[gKo`1PYol5Jjko05nWojG:
h_oooooo<8Bko`AZ[@02o`M/[P05o`1QZ?l0HZWo05nVoaUf]?o3g>`0P?ooool009_ooooo00?ok_Gj
ocf<`?l0I:X04_l7K:h04ol8K:ko0fZ]o`5Y[?l0IJ[o06>Yo`1PYol0GZKo066Xoa]h]?lgR;goHZ7;
og^ae?nQb>3o_]WYom3Sl?oEi_7oiO3gon_cn?ohnod03?ooool01?oom>SoolRBoon00OooN00:oon0
0006oomn0?ooN03oohP@ooo6S_oojmOoooglH_ooool01_ogmoOok>c/oooooonIVIWo0000om_Kf`;o
oooo00Wo`l?3oaPH6?o5aLGoooooon?Sholc<c?o6ATIom?Cdoojn_X00_ooool01omMGEgob/[:oooo
ooooooooo_knokVi^OnZZZX00_ooool01om:BT[oG5aLoo;bl_oooooo`<30o`000?mPH6003Oooool0
0oo/k>co>3PhohZ:RP08ooooo`03ojBTY?l30`?ooooo00Sooooo00?oa<C4o`000?ooool0A_ooool0
3_oSjO?o^<OQojZmfon[_M[o[;kKojNjfOnc`]goh>G_oo7bm_oWjo;od][ZohVYcomBQkgoEHZn0_mG
Rkl04?mHRkooFhc0oeF;_om6QKco=7^foiBlf_o/l_SogNC`ok32gOnU^MSoZK_JojbnfonX^mWo]/KP
on__m_omoOhZooooo`03olS8b?n7QhOohN7Q02[ooooo00GomoOgomGEeOl0003o10@4oo?cl`03oooo
o`07oifMWOmaLG7ofm_KogYjN_l0003oH61Poo;blP0Sooooo`05ooOgmooKfm_o=CDeo`820_oEeMD0
QOooool01_nednOo5gFco`1TZ_l0Ij_o06>Yogfce0Cooooo00GoZlgTo`1FX_l0Ij_o05NSoj?8h@02
ooooo`03omCUlOl=Kjoo06N[00Ko06N[00Go05bUofVVcOooooooA932o`1TZ@04o`1WZ`06o`1VZ_lI
M[?o^]KXoooooon8^MSo05VT1?l0Ij/01?l0IZ_o2fj_ob=m]omk/=@2ooooo`06oj_=i?l0EZ;o06N[
o`1TZ_l>JJco]mGX1Oooool01OoMj_Co05NSo`1WZol0G:KoKJS?00Gooooo00KoQ[OHo`AZ[Ol0Ij_o
06N[o`ia/On]cn<2ooooo`03onofn_m@UlKo05nW00Ko06N[00go06JZob5l]onOa]oo05ZTo`1WZol0
F:?oV/?NongenOlSOKOo06>Yo`1VZ_l@L;3onocn00Cooooo00So`]_[o`a`/Ol0HjWo05nWod2>`Ook
o?go:h6jo`1UZPCo06N[00?o06BYob1k]oo5gN`0P?ooool009cooooo00CohnogobUm^?l0HjWo1ff^
5ol7K:h04?l6Jjko0FV/o`1VZol0HjWo066Xo`1NYol0FZCo1V^^oaIe/om7T/?oF9_8ognce_nI`mko
[m3UokkHj_oUl?L6ooooo`05oooln?oog[goojI<oomc0?ooOP003OooP0001OooO@3oogH0oon;6?oo
`hSoonG;047ooooo00?ono_kooooooooool07Oooool01_oXj>SoUiNGonSXj?oRh^;o10@4oginOP;o
oooo00gon?Shoh:2P_mOGeoono_koooooon4Q8Co0000oijNW_o>c/kog]kNoooooooQhN7oGEeM00?o
oooo00OoZ:RXoh:2P_ooooooooooom[Jf_le=CGoa/K600;ooooo00?o9bLWoaDE5Oo]kNd03?ooool0
1ooinOWoV9RHochn?_ojn_[oooooooWinOono_h01?ooool00onDU9Co0`<3ooooo`08ooooo`03ok6a
/Ol0003ojn_[04Oooooo00_om?OjolKCion]_m_oZK_IojbnfonY_=[o[KoKok[8h?nY_=WoZ[cJohJV
c`02oeN;_`0<oeV<_omMSL3oDhZnocN0^?lfP;Wo8GReoaUc/_moZ<ooZkgKojJifOnZ_M[o[;kK0_n[
_]/01On/_]_oZK_IojbnfooGh>kon?Wl02Wooooo00?ob<S8ohN7QooQhN40:_ooool01OoWinOoMgMg
odi>C_m0@43of][J00Cooooo00Kog=cLoiBDU?mGEeOoH61Polo?coomoOdSooooo`05onOWion6QXKo
C4a<od92@_oIfMT0QOooool01_oWlOOoMJgBoeBJaomHW<SoDiS6omSXlPCooooo00Gob=o]oe>A`_mH
W<SoDi;3ol?Kj`02ooooo`03on?^m_mQXL_oF9c800KoF9c800GoDiG4oig5goooooooQKOGoeFJa`04
oeRLb006oeNKb?mYY/kod^C`oooooonbdNGoDi?41?mHW<P00omFV/SoOK7Dol?Kj`03ooooo`06olSO
kOmCTL;oF9c8oe:Ea?nKaMooo?gn1Oooool01OoYl_SoDi;3oeRLb?mCULGoX<KP00Gooooo00Kod^?`
oefOb_mHW<SoEi_8ofVVc_obmoX2ooooo`03ooGio?n=_=[oDiO600KoF9c800coEi_8ofnYd?o0f^[o
DiC4oeRLb?mCTl?o`m_[ol[Pk_mQX/_oEY_8oe:Ha_nNaMl5ooooo`08ongdnOn:^MWoDiO5oe>JaomQ
XL_ol_OjogJ^domFVlP4oeRLb003oeFJaom^ZM3ofNWc083ooooo002Mooooo`04ol;Kk?lKL[7o06J[
o`Q/[Qco1fb^00[o26b^o`=Z[Ol1JJco06FZo`1SZOl0H:Oo05^Uo`1JYOmNWl[ocn?_1_ooool00ooo
bYGoog`0oomf000Aoon00006ooml0?ooMP3oohhNooo2Q_oogkoooogk??ooool01OoalO7oeMGEol?3
`ooDe=CokNg]01kooooo00GoaLG5ojNWYooclo?o;Bd]ob`/;003ooooo`0Aom[Jf_m;Bd_oX:2Poooo
ooo7alOo2`/;od92@_oBd];oIFEUomCDe?oNg]koJf][ol?3`oooooooh^;Roc`l??mYJFT00oooool0
1onATI7oCTi>onCTi?ooooooNg]ko`000?n@T9003Oooool01oo`l?3oKFe]okRh^?ojn_[oPX:2oiNG
UooalO400oooool00onDU9Co0`<3ooooo`08ooooo`03ok6a/Ol0003ojn_[04Sooooo023ooOgnomKO
k_nb`]koZ;_Jojbnfon[_M_oZKcJoj^mfon``=coQJK>oe^=`?mLSL3oAhJloc5m]olgP;[o7WJcoc1l
]omKSL3oFH^oognRcOnX^mWo[KkKoj^mf_nY_=[o[KoLojk0g?n[_M_o[;kKojZlf_nY_=Woa];Vonkb
n2Sooooo00?ob<S8ohN7QooQhN40;Oooool00oofm_Koooooooooo`3ooooook3ooooo002Mooooo`04
ookooonF`]go36b^o`9X[27o1fb^00Co06N[oa9b/_mi[m?oi>of1oooool01OoocIcoojaHoon73ooo
M`3oogh0017ooh0000Goog/0oomg0?ooS1WookAYoooM^P0iooooo`04onc/k?o=cLgo/;2`ohb<S0;o
SHf=00?oZJVYolo?coo]kNd07Oooool01Oo3`l?o/[:boclo?ol0003ojNWY00?ooooo013o_;blofm_
Kong]kOoRXZ:ocXj>_l0003ogMgMoe=CDolW9bOo9RHVoahN7_la<C7ooooook^k^ol0003oMgMg1?oo
ool01omkNg_oSHf=okjn__mHF5So9BDUoadM7OomoOd03Oooool01_oNg]koX:2PogalO?l0003oADE5
onOWi`?ooooo00?oRh^;o`000?ooool02?ooool00onZZZ[o0000onWYj@1:ooooo`03onG[m?nkb^;o
Z;_I00;oZkgK01[oZ;_Ioj^lf_nA[]?o=Wniob]j]_lcP;So97Neocj3^omTSl7oGHg0oeN;_om@Qkgo
Oj?=ojNjfOnY_=[o/L;Mokg:hOo5d>Go`loTok31gOnY_=[o[;kKoj^nfonV^MSo]lOPon7XlROooooo
00?ob<S8ohN7QooQhN40oooooooPooooo`00W_ooool01?odnO_oM:gBo`1VZol5JjdOo`M/[P03o`1P
YolkR[oo/m;V00[ooooo00KooocioooI]?oo/63ooh<6oome0?ooOP0Aoon00005ooml0?ooM`3ooh`I
oon_G_oof[D0=Oooool03Oo]kNgob/[:ojVYZOn<S8coUYJFol?3`ooHf=SoalO7oibLW?n=SHgoZ:RX
olW9bOo^k^h07?ooool01?oJf][oZZZZoi6ATOo[jn/4ooooo`0?on;Rh_nl_;co/;2`olS8b?nDU9Co
h>3Pom?Cdon:RX[oQXJ6ohV9ROnHV9Soooooon[Zj_nPX:3od];B00Gooooo0_o3`l<01?nZZZ[obLW9
oiJFU_omoOd>ooooo`05oo3`l?nQXJ7oShn?om7AdOono_h00oooool00ooAdM7oTi>Cooooo`08oooo
o`03omgMgOnATI7om_Kf04_ooooo01[olOGiolkIj_nY^mWoZ[cJol7?iOoSjO?oW/;MocR0^Ol_O;Ko
ChVnoen>`OmJS<3oEX^ooeN;_omFR[ooBhBkogbPc?neaMooaM7Uom3HjOoHgncof=k/omCLj_o7d^Ko
]/CNojZlf`;o[;kK00CoYk[Iojk0g?o@fN[oo?gm9Oooool00oo8b<SoQhN7on7Qh@3oooooon3ooooo
002Oooooo`04onWcn?m@V<Ko06FZo`I/[A_o1fb^00Go26f^o`5X[?l0GjKoLjcAomKWlP0=ooooo`06
ooohlOoofK?oojiPoomo0?ooM@3oogd04OooP0001OooO@3oogT0oon=7Ooo[Ugoomno037ooooo017o
j>SXol30`?nYZJWoSXj>oiVIVOo0`<3oh^;Roo_knooooooooOgmonKVi_o7alOoVYZJohn?SonXZ:So
alO7oo;blP2/ooooo`09oo_loOoTj_Cok?3goo;enOo]l?SoSk?Eoe^<`?mLSL3oF8^o00;oEh^o01Go
EHZnoe27_?mGRkooIIG4ojBmf_oGg^cohNK_omoTkooJh>goe]k/omCLjooBf^[ob]?Wok[8h_n/_]_o
Z[gKojbnfonZ_=[oZ[gJol7>iOo`m?T09?ooool00oo8b<SoQhN7on7Qh@3oooooon3ooooo002Poooo
o`03om_Zm?l`QKco06JZ01_o1fb^00Co066XoaIe/onLaMoomOWl4?ooool01_oom^goomZfoonbIOoo
Q@_oog@0oomn017ooh0000Googd0ooml0?ooT23oojeKoooTb@0]ooooo`08onSXj?no_kooY:BTohf=
SOnIVIWoalO7onSXj?ohn?P5ooooo`08ooclo?oYjNWoa/K6oiNGUonBTY;oZJVYolS8b?ogmoN[oooo
o`05ooWjoOoHhNoo`m3UokS7h?n7Y/l00omGRkl06?mDRKkoDHJmoeb?`OmgXL[oQZc?ohR^dOnlc^?o
h^O`on;VlOoOhnoofn7]omSPkOoEgN_odM[ZoloGjOo:e>Oo_/_Sok30g?nZ_=[o[;kKoj^nfonX^m[o
]lKPom_Sl2?ooooo00?ob<S8ohN7QooQhN40oooooooPooooo`00XOooool00oo5gNco7WVfo`1WZ`0G
o`M/[P05o`Q/[_l4Jjgo066XodNB`_o<hNh05?ooool01_oon?7oon[EoonmO?ooP@;oogH0oomo017o
oh0000Googh0oomo0?ooSQ_oojUDoooVc00Yooooo`08omoOgonc/k?oX:2Pohn?SonHV9Sob<S8onc/
k?okno/9ooooo`08oo_knoo_knoob<S8oiNGUonFUYKoZ:RXolS8b?oinOTGooooo`03onk^k_lW9bOo
CTi>08gooooo017oj^ogolKCionfaMoo[/3LojZmf_n__mcoQjO?oeJ:_omCR;koDXNnofZHa_n7Zm3o
T[CDoiNheOnH^=KoSk;Cokc>hP02on?Wl00;on3UkooMh^kof^3]omONk?oCfn_od=SYolcEj?o9dnKo
`<gSok?3gon[_MX00_n/_]/00onZ_=[o[l3LolSDi`0Rooooo`03olS8b?n7QhOohN7Q0?ooooooh?oo
ool00:7ooooo00CooOknoio6golCLk;o16^]5_l7K:h01?l3JJgo26b^ohbkf_o/m?TGooooo`05oooj
m_ook]gookUdoomn0?ooNP004_ooP0001OooO`3ooh42oon:5_ooZUCoon[F02Gooooo00SogMgMok6a
/OnLW9coTI6AoinOWooDe=Col_;boo_kn`gooooo00Sono_koo7alOo4a<CoUIFEoiRHV?nWYjOobl_;
oo_knaGooooo00?on?Sho`P82?m9BDT0R_ooool01_oloOkog>C`ok_:h_na`]go[;kKoj^mfP;o[;kK
01[o[koLoh:Tc_mIRl3oMJ3:oi2cdonI^=KoW;_GoibleonI^MOoUkOEohjbdonlcn?ohnSaonCXlOoQ
iO3og^?_om_QkOoIgngoe=c[om7Ij_o>e^SobM?VolGAi_o0c>Co]/COojfnf`;o[;kK00CoZkkKojfo
fonlb^?oloGj8?ooool00oo8b<SoQhN7on7Qh@3oooooon3ooooo002Rooooo`03oo[loOmd[M7o2Vj^
01Go1fb^00Co1V^^o`5Y[?mQX/col_Ok6_ooool00ooonoOooo7SoongL002oomm01;ooh0000Googl0
oon00oooQ`kooj11oooQ``0Qooooo`08omSHf?nUYJGoVi^Koi>CTonMWIgod];BooShn?omoOdAoooo
o`08ooclo?oalO7o_knooiFEUOnGUiOoYJFUolc<c?olo?`Dooooo`03onk^k_oclo?ooooo013ooooo
00?okno_olK6a_oWinL0M?ooool01?ogn?coc]SZok?3g_n^`=`4ojbnf`0Moj^mfonW^]Wo^<KOok35
g_nL^mOoW[cHoinnf?nN_MSoW;cGoibkf?nJ^]KoV;WFohncdonlcn?oi>WaonGYlOoRio7ognC_omcR
k_oJh>goe]g/om;Jj_o?f>SobmCWolOBi_o2cnCo_lgTok_9hOn__m`01?n/_]/00ondaMkoh>Oboooo
o`0Nooooo`03olS8b?n7QhOohN7Q0?ooooooh?ooool00:Cooooo00?oDIS6o`U][ol7K:h05Ol7K:h0
1?l4JZgo3G2`ogfbeOobn?/Kooooo`03oooek?oo]6Wooh0001Gooh0000Coog/0oonJ=Oooh/Koookm
7?ooool01_odm?CoXj>SoiRHV?nIVIWoZ:RXomoOgaSooooo00Oolo?cokfm_OnHV9SoUiNGoj2PX?o=
cLgon?Sh02?ooooo00Gol?3`okZj^_nGUiOoU9BDol_;b`1booooo`03on7Xloo0cN?oZkgJ00Ko[;kK
01ooZkkKol7=hooWjo;ono[jom;NjonQ_mWoX;oIoj2nfOnN_MSoWKcHoibkeonJ^mOoVKWGoi2cdonm
d>CoiN[bonKZlOoSio7oh>G`omgSkooJh>goe]o/om?KjooAf>Woc=KXolSCi_o4cnGo`<gToko<honn
c>Co/L;N00Co[;kK00?o[KoLolSDioojnod07Oooool00oo8b<SoQhN7on7Qh@3oooooon3ooooo002T
ooooo`03oocmo_l`QK_o1fb^01Oo1fb^00Go06N[o`Y^/?n4]]Ool_Sjoo_moP0Jooooo`05ooodj_oo
[Ucooh4:oon10oooO`004_ooP0001_ooO`3oogL0oonN?OoohlSooo_goooooQWooooo00Coclo?oi^K
VonYZJWog=cL7?ooool02?oalO7o_;bloibLW?nEUIGoWinOolo?coogmoOooOgm7Oooool02?omoOgo
l?3`okfm_OnEUIGoUiNGoj>SXoo?cloonOWiK_ooool01_omoOkomoSkomWRkonb`]koZ[cJoj^mf`Co
[;kK01oo[KoLokC3g_o>enSolo?foockn_ojn_[oo?_jom;NjonR`=[oXKoIoj2nfOnO_]SoWKcHoibk
eonK^mSoV[[Goi6ddonodNCoi^[aonOZl_oSio7ohNG`omoSkooKhNgof=o]omCMjooBf^[ocMKXol[C
i_o5dNKo`<gT00;o_lcS00?o`LgSokO6h?n]_]/00on/_]/01?nZ_M_o_<[Rongamoono_lKooooo`03
olS8b?n7QhOohN7Q0=3ooooo1?oloOh01_ojo?gonO_mooWloOoio?gomo[looKio0;om_[l013omOWl
oo?hnoocn?_oloSkon_cn?n_cnGo]M?WokODj?nYc>?oQ;GFogJ]dOmh[];oO[;Docb;_onTbN;ooOkn
loooool00:Gooooo00?ohNgfoaUg]?l5Jjh05ol7K:h01_l6Jjko06FZo`ma/On@_M_oj_;hoo[loA[o
oooo00Gooo3Qoon[F?ooQACooh<6oomo000Boon00005oomm0?ooMP3oojA:oooUcOoon?806Oooool0
0oo]kNgoooooooooo`0Nooooo`08ono_konk^k_oWinOoi>CTonOWioodM7AooGemOomoOdIooooo`08
oo_knooalO7o`L71oiFEUOnFUYKoXZ:Rol30`?ohn?Q]ooooo`07ooknoooinogojnogol[Ej?n[_M[o
Z;_Ioj^mf`02ojbnf`0Toj^nfon]_m_o//;Moko;h_oOi>oon_[jookno?ojn_[onOSiooShnOolno_o
dmo[oj;0f_nQ_mWoX;oIoj2nfOnN_MSoWKcHoibkeonJ^]OoT[CDokoAi?oWjo;oj>_bonGXlOoQi_3o
gnC_omgRk_oIh>goe]g/om;Jj_o>enSobmCWolKAi_o2cnCo_lgS0_noc><00oo0cN?o^lWRojnog@03
ojbnf`04ojVlfOn``Mgofn?aoo_loA[ooooo00?ob<S8ohN7QooQhN40_oooool01OoloOkon_cnoo[l
o_oko?komo[l00;oloSk00?om?Skoo7gn_o[loT00_o/m?T00ooZloSoi_3gonG`m`02onG`m`?oZLcS
00_oY<WQoh2de_mZY/koKJS?og>[dOm:U<Co;8:koc24_?lcQ[co5gJdo`1RZ002o`1QZ00;o`1RZ?l0
I:[o06BZo`1TZ_l0IJ[o06J[o`1WZol0IZ_o06>YoeJKaooko?d0m?ooool00:Kooooo00?o^]GXo`e`
/?l5Jjd06?l7K:h01_l4JZgo06:Yoa=c/onC_mcog>[coo[loA[ooooo00Kooo;ToonkMoooTBGooh86
oomm0?ooO`0Aoon00005oomk0?ooMP3oojM?oooRaOoomN`0>_ooool02?o_knoo_Kfmoj>SXonATI7o
WinOom7AdOoalO7ooOgm5Oooool02?ojn_[okNg]olC4a?nEUIGoU9BDojJVY_nn_[kolo?cKOooool0
1_ojo?gol_Gjon3VlOnjb^7oY[WIojNkf@;o[;kK01GoZkgKojZmf_n``Mgo]lOOol[Dioo`lOGoookm
ookmnookn_[on_[jooWin_oin?Won?SioogknooCh>_oX/3Joj:ofOnQ_mWoX;kIoijmf?nM_=P00_nK
^mL04?nB]MCo`=;TonO[lOoXk?;oiNWbon?WlOoPiO3ogN?_omWPkOoFg^codm_[om7HjOo<e^Sob=;V
olC?iOo0c>@3oko<h`04ol3<honnc>Co/l;Mojfof`;o[;kK00CoZ[cJojRlfOo;enWoloGj6Oooool0
0oo8b<SoQhN7on7Qh@2kooooo`06oocmo_oLj_Cobn3^oloRkonSb>;oU/3M0_nG`Md02omj/=CoGIk9
oejOb_mPX<_oBiG4oamj]_lUO[So:82ioaIe/ol0HJSo05bV00;o05fV1?l0HJP01_l0HjWo06FZo`1U
Z_l0I:[o06N[o`5Y[0;o0FR/00?o0fZ]o`M/[_l7K:h01ol7K:h01?l4JZgo1VZ]of>Sc?oloOkeoooo
o`00Yoooool00on:^MSo06R/o`I[[P08o`M/[P03o`=Z[Ol2JJco1Vb^00ko1fb^00Ko0fV/o`1QZ?lM
NKGoTkoLomKWl_onoolJooooo`06oooej_oo^WCooiD/oon20oooO@3oogl04OooP0001OooNP3oogT0
oon[FOoog[koooK/03[ooooo00Ook>c/okjn__nTY:CoSXj>oj>SXooDe=Cokno_01;ooooo00Sono_k
on[Zj_o7alOoUiNGoi2@T?nUYJGo_[jnono_kfgooooo00KomoWlonW_m_o?fN[o/L;Noj:geonY_=X2
ojbnf`08ojZlf_nZ_M[o/l;Mokg;h_oIgncoloCgooooo_olo?/5oo[jnP04ooWin_oin?Woo?[jom?P
j`;oX/3J01KoXKoIoj2nfOnO_]SoWKgHoibleonL^mSoTkGDol3Bi?oXk?;ojNcbonKYl_oSio7ohNK`
omkSkooKhNgof=k]omCLjooAfN[ocMKXolSCi_o5d>Ko`<gT1Onoc><00oo0cNCo]lGPojbng003ojbn
f`04ojJifOnibN7oi^_doognoQOooooo00?ob<S8ohN7QooQhN40^oooool01Oodn?coMjoCo`1RZOl0
Ej?o05nW00?o062W00Ko06:Xo`1TZ_l0I:[o06BZo`1UZ_l1JJ`2o`1X[003o`9Y[?l6K:ko1fb^01Oo
1fb^00Co16Z]o`EY[OmTY<gonO_mm_ooool00:Sooooo00?oGj3;o`1RZOl7K:h01_l7K:h01Ol0IJ[o
6WNdobMo^?l0Ijco06R/00oo1fb^00Go06N/o`1QZ?lVOkSoT[oLom7Tl00Kooooo`05oooah_oo^gSo
oiP`oomo0?ooO0004OooP0001_ooO`3oogL0ooml0?oo[UooomR`ooo`gc[ooooo00OoinOWokjn__nS
Xj?oSHf=ojJVY_oDe=Cok^k^00kooooo00SooOgmonOWioo6a/KoVIVIohf=SOnUYJGo_knoonWYjFco
oooo01;onocmoo3cn?oPi_;oa]?WojVlf_nU^MSoZ[gJojbnfon[_M_oZ;_Iojbnfonga^3ob=;VomoS
k_omno_oo_ckoo_knooinOX6oo[jnP0LooWin_oin?Woo?[jom?PjonS`M[oX/3Joj:ofOnP_mWoX;kI
oijmf?nM^mSoW;_Goi>fe?o0dnCojNcbon[]looWj_;oi>Saon;WlOoOi>oofn;^omSOkOoEg>_od][Z
olkGj?o;e>Ooa]7Vol7>i0?o_lcS00Ko`<gSoko<honlbN;o^LOQojo0gOn[_M/3ojbnf`04ojJif?nY
_=Wofn;`oogmoQKooooo00?ob<S8ohN7QooQhN40_Oooool01?nMa=oo7g^fo`1X[?l6JjhSo`M/[P04
o`AZ[Ol2JJcoGj3;ooGio?Oooooo002Xooooo`03ooWloOm5TL?o06BY00?o1fb^00[o26b^o`=Z[Ol0
HJSo>HVnojS<hoo2fn_oM:gBobf2^_l0HjWo06N[3ol7K:h01Ol0Ij_o062XobR0^On6]mSocN7_01_o
oooo00GoongLooo1P_ooVcKoogX0oomk000Aoon00006oomo0?ooMP3oogX0oonN@?oobiOoonoP>_oo
ool01ooVi^Ko`<30oj6QXOn<S8coZ:RXom3@d?o/k>`02oooool01ooShn?oa<C4oi^KVon:RX[oY:BT
ol?3`ooXj>P0K_ooool01OoZkoKo]LGPojFifOnW^]WoZkgK00;o[;kK00Wo[;gKok71gOnoc>;odm_Z
onW[loomo?_oo?ckoo[jn_ohn?T00_oinOX6oo[jnP;onOWj027ooO[jom?PjonS`M[oX/3Joj:ofOnQ
_mWoWkkIoijmf?nM^mSoW;_GoiBfeOo0dnCojNgcon[]m?oWj_;oiNWaon;WlOoQiNoog>;^om[OkOoF
g^coe=[ZoloIjOo<e^Soam?Vol??iOo0c>?o`<gTokk<honib>7o]LGPojo0g?nZ_=/00on/_]/01_nY
_=[oY[[Iojk0g?o1c^Coe]k]oo_loAKooooo00?ob<S8ohN7QooQhN40__ooool01?nmf>Wo>XZno`5X
[?l6JjhQo`M/[P04o`E[[Ol0I:[oCiS6on_cnOSooooo002Yooooo`09on3]mOl]P[[o06:Xo`Q][_l7
K:ko06FZo`A[[OmNX<_ofn[c00?ooooo00Goamg/ogB]dOlUO[So062Xo`1WZ`0?o`M/[P05o`1VZol0
HJSo;hBkognceOoAi?006oooool01OoojmOool22oonH<OooM`3oog/0017ooh0000Koogl0oomh0?oo
O@3ooim4ooo8TOoolnLjooooo`07onCTi?o3`l?oWIfMohb<S?nXZ:SocLg=onk^kP07ooooo`07on?S
hoo2`/;oWYjNohV9ROnQXJ7oalO7onKViP1`ooooo`04oo?en_o@f^_oZkgKojRkf@;o[;kK00KoZkgK
ojfng?o:e>OolO?foo_jn_oin?T2ooShn@04ooWin_ohn?WonOSiooWinPOon_[j00?onOWjoogjn_oC
h>/00_nS`MX07_nR`=[oXKoIoj2nfOnO_]SoWKcGoiblf?nE]]Go`]?Uon[]looZk_?ojN_bonGYl_oS
io7ohNG`omgSkooJh>gof=k/omCLj_oAfN[ocMKXol[Dioo5dNGo_L[RokO6h?nc`mko[KkKoj^mf_n[
_]_o[;kKoj^nf`;oYk[I00Co]lOPolgHj_oPi_;on__m6?ooool00oo8b<SoQhN7on7Qh@2oooooo`03
om;Tl?m;U<Co06FZ023o1fb^00Co1F^]o`1VZ_m4T<;ofNSbnOooool00:[ooooo00Oo]M?XoaIb/Ol0
IJ_o06>Yoaei]?n@_M_on?_m00Kooooo00Goa=_/ogR`dolNNKGo05nWo`1X[00?o`M/[P05o`1VZol0
I:Wo=8NmogbaeOoGio806oooool01Oooim3ool:4oonC:?ooM03oogX0017ooh0000Koogl0oomh0?oo
P03ooj14ooo8TOoomnh9ooooo`03on__mooSj_?ooOkn02kooooo00Ooi>CTolC4a?nJVY[oSHf=ojVY
ZOo:b/[ol?3`00?ooooo00OoiNGUokno_onQXJ7oRXZ:oj2PX?o9bLWoi^KV07Cooooo00oognKaokW8
h?nT^=Oo[;kKojbmfon]_mco_<[QomgRkoogmoWon?SiooKhn?ohn?Won?WjooWin_oin?T00_oinOX6
oo[jnP0NooWin_omn_[odn3[ojC1f_nS`M[oX/3Joj6ofOnP_mWoWkkIoifmf?nM_=SoUKOEol;DiOoZ
k_?ok>kconW/looWj_;ohnSaon;VlOoNhnoof^3^omSNk?oEgN[oe=c[oloGjOo3cnGo]lOOok71gOn/
_]_oZkgK0_n/_]/01_n[_M[oY[WIojNjfOo1c^GofN;_on_`ma_ooooo00?ob<S8ohN7QooQhN40`?oo
ool01?oKj_?oJJK>o`1QZ?l6JjhMo`M/[P04o`I[[_l0IZ_o?Xc0omWXl_[ooooo002Zooooo`05oo_m
o_nF`Mco06>YodjFa_o<hNh02Oooool01_ono_oobn3^oh:de_lIM[Co062Wo`5X[0ko1fb^00Ko1Vb^
o`1WZol1J:co<HJlogF]d_oPkODKooooo`05oooXd_oocikooidloome0?ooNP004OooP0001_ooO`3o
ogX0oon31_ooWC_oolJ?oookm`Gooooo00Gon__lomGNkOnc`mkob=GWoocmoP0_ooooo`0>oogmoOoX
j>Sob<S8oiVIVOn@T93oZ:RXolW9bOoMgMgo_KfmojBTY?n=SHgoW9bLolg=cOoYjNUgooooo`0:onoc
n?o8e>SoXkOGojZnfon/_]_oZKcJok30gOo9e>Kolo?fooWhn@;on?Si00ConOWjooShnOoin?WonOWj
1_ojn_X06_oinO[ooO[jom?PjonT`M[oXl7Joj;0f_nR_mWoX;oIoinnfOnM_MSoWK_HoiFgeOo2e>Go
j^kconc^m?oYk??oin[bonGXlOoRi_3ognC_omgSkooMhnkoe=cZol?>i?nfaMoo/<7M0_n[_]/2ojbn
f`06ojVlf_nU^=So[[oLolgHj_oVjoComOOk7Oooool00oo8b<SoQhN7on7Qh@31ooooo`04oo7gnon?
_=_o06BZo`AZ[A_o1fb^00Co1Vb^o`1X[?m0SL3ofnWcnoooool00:_ooooo00?ol?KjokcHjOoUl?L0
3?ooool01_oinogod>?`oh:ee_lCLk;o06:Xo`AZ[@ko1fb^00Ko1V^^o`1X[?l8K:ko<hJmog>/dOo[
loPKooooo`05ooo_gooodjKooiTcoome0?ooN`004OooP0001_ooO`3oog`0oon63?ooWC[oolR@ooon
o`;ooooo00Koi^cdol3>i?n]_]_oY[WHol[Fj?oloOhaooooo`0;oo_knoo[jn_ob<S8oiJFU_nDU9Co
XJ6QoiNGUonQXJ7oeMGEong]kOomoOd0NOooool04?ohn_coemo^ojZlf_nX^mWo[KkKojZmf_n[_M_o
_<[Ron[]lookno[on?SiooSin_oinO[on?SiooWhnOoinOX4oo[jnP;onOWj01WooO[jom?PjonT`M[o
Xl7Joj;0f_nR_mWoX;oIoinnfOnM_MSoWK_HoiFgeOo2e>Goj^gconc_m?oYk??oin[bonGYlOoUjO;o
i>SaomKMjonocN?o/l?Mojk0g?n[_M[oZkgK00;o[;kK00KoZ;_Ioj>geonhan3of>7_onkan?ojnodO
ooooo`03olS8b?n7QhOohN7Q0<?ooooo00?o[<kToaYg]?l4JZd06_l7K:h00ol1JJco=XRmomk/m03l
ooooo`00_?ooool01_ogn_cognceohBfeol>L;3o06BZo`E[[@ko1fb^00Ko1Vb^o`AZ[Ol:Kjoo9h2i
og2ZdOo^mOTKooooo`05oooci_oofK;ooiH]oomh0?ooO@004OooP0003?ooO`3oogh0oon52oooUbWo
k/:=ol?EjOnaa>Go[;kLoj^mf_nX^mWob]KXoocmoS?ooooo00Sono_koo7alOo8b<SoUiNGoiBDU?nL
W9coaLG5oo_kng_ooooo00CooOgnonS/mOnfa]ooYKWH0_n/_]/02?n[_M_o/<7MomSPk?olno_on?Si
ooSin_ohn?WonOSi0ooinOX2oo[jnP;onOWj01KooO[jom?PjonT`M[oXl7Joj;0f_nR_mWoX;oIoinn
fOnM_MSoWK_HoiFgeOo3e>Kojngconc_m?oYk?;oj^gconKZl_oBf^[o^/SQok71gOn]_m_oZkgK0_n/
_]/01on[_M_oYk[HojRlf_o3d>Koi>[cooKhnoomo_h08Oooool00oo8b<SoQhN7on7Qh@32ooooo`04
olCMk?mBVLOo26f^o`I/[QWo1fb^00?o0fV]ocF8_OoVl?L0oOooool00;kooooo00Komo[monKamon0
/mGo26f^o`1WZol6K:h>o`M/[P06o`I/[_l5Jjgo2Vj_oamj]_me[]?oloSk6_ooool01_ooo_goooK]
oooH/?ooTRCoogX0oomo013ooh0000_oogl0ooZ10?nkSdGo[YJ7oj^ITOnZYjko[;cHojc1h?nX^mWo
b]KXoocmoP0eooooo`08oo_knoobl_;o`l?3oiJFU_nHV9SoYJFUol[:b_okno]jooooo`0:ooknoood
m_[oa];WojRkfOn[_]_o[;kKoj^mfon]_m_ob=;VooSin0;onOWj00?on?SiooWhnOoinOX01?oinOX0
0ooin?WooO[jom?Pj`02oj?1fP0>oj;0f_nR_mWoX;oIoinnfOnN_MSoWK_HoiFgeOo3e>Kok>ocoo3a
m_oXk??ocMKXokC4gon_`=`4ojbnf`07oj^mf_nV^MSo[l3Lom3IjoobmO[on__mookno`0Sooooo`03
olS8b?n7QhOohN7Q0<3ooooo00GoU<3LocJ8__lGMK?o2Vj_o`I/[P0Io`M/[P03o`AZ[OlcQKgok_Gi
0?kooooo0030ooooo`05oo[loOoWlOOoLj_@o`I[[_l2JJd04Ol7K:h01?l8K:ko5WFbogfbeOofn_`J
ooooo`05ooonoOoon_GoomF[oon?7oooO@003_ooP0001?ooO`3of8PRojVBL?nZThP3ojZCQ`05ojZF
SOn[Yk3oYkWGol_Gk?oloOh0=oooool02?omoOgol_;bokfm_OnEUIGoUiNGoj>SXoo=cLgono_kN_oo
ool01?omoOkofN7^ojk0g?n[_M/2ojbnf`06ojfofonib>7ok>gdoo_lo?oinO[on?Si0_oin?T2ooWi
nP;onOSi013oo?[jom?PjonS`M[oXl7Joj;0f_nR_mWoX;oIoinnfOnN_MSoWK_HoiJheOo7f>Sog^?_
olG@i?n``Mgo[KoL1?n/_]/01_n[_M_oZKcJokS7hOoRj?;on__moognoRKooooo00?ob<S8ohN7QooQ
hN40_Oooool01OoLj_CoL:[Aoaii]Ol<K[3o26b^01_o1fb^00?o1F^]obb1^_obn?/0ooooool00<?o
oooo00?ojoCioffXcol<Kk004_l7K:h01Ol2JJco2fj_og^be?oamo[ooOkn01_ooooo00?oom:Uoon?
7_ooP@<02_ooP0001?onP07olH<<ojBBGOnYThd4ojZCQ`07oj^DQonZThOoZY:5ojNBR_nj/j;onoOd
ooono@0iooooo`08oo?clonn_[koVYZJoiJFU_nOWiooc/k>ooOgmoono_iiooooo`03ong`monga^3o
ZkgK00?o[;kK00Go[[oKom[Pk?oknoconOWjooShn@04ooWhn@04ooShnOomno_odn3[oj?1fP;oX/3J
00WoXKoIoj2ofOnO_]WoW[cHoi^je_mnYlgoRZ_@ojRkf_n]_]/01?n/_]/01?n]_m_o/<7MolSEj?oa
m?TZooooo`03olS8b?n7QhOohN7Q0;Wooooo00Koo?gnooGinonhe>Oo?8boo`5X[?l4JZdMo`M/[P03
o`I[[_lBLk7oiO3f0?oooooo0Oooool00<Gooooo00Goj?;hofZVc_lCM;;o2Vf_o`I[[P0?o`M/[P06
o`I/[_l0IZ_o2fn_ohNhf?o_mO[on_cm6oooool01OoocYkooiH]oon32oooP07oogl000Gooh0000Co
nH07olN<<onVTh7oZY>;0onZThL02onZTXOo_J6;om>aSongWHWoZ9:7ojZCSOnQT5Con8@<ooo3R?oo
mnkooogj03Wooooo00SolO7aok^k^onMWIgoU9BDoijNW_o?cloom_KfoogmoGSooooo00?ooOgnolKC
ion^`=`00on/_]/01On[_M_oam7UooOgn?ojn_[onOWj00?on?Si00ConOWjoogknooCh>_oXl7J0_nR
`=X02OnQ_mWoW[gHoiFeeOmfXL[oFhk1odb4^omnX/goZKcJojfnf`02ojbnf`04ojo1g?nibN;of=o^
oo_loBcooooo00?ob<S8ohN7QooQhN40]oooool01_ofnOcoh>keoh2deOlON[Ko066Xo`AZ[Ako1fb^
00?o16Z]oaAd/_oDiO40ooooool2ooooo`00aoooool01_oSk_KoIJC=oaai]Ol:KJoo16Z]o`I/[Pko
1fb^00Ko1F^]o`1TZ_l?LK7oTkoMonG`moojo?dKooooo`0LoooI]?ooWC_oohD@oon00?ooO`3ooh00
ooJ11_oYQAKoZI=[ojNDS_nZThSoZY>7ojVCQonZThOo/iV8om2_S_ogcIKoil2BokJLROnXTHOoZY>=
oj:CFoohP0?oogX0oon63?oobYCooo;UooolnSWooooo00Sol?3`ok^k^onPX:3oTY:BoinOWooBd];o
m?CdoogmoGSooooo00?oe]o]okC3g_n/_]/00_n/_]/01OnX^m[o]lKPon[]m?ohn_[on_[j00?onOWj
00Ooo?ckom?OjonS`M[oX;kIoi^jeon=/=;oK9[600;oDhRn00WoEXZooe27_OmoXlgoZ;_Iojo0g?nc
`mko`<gTon;Xl_oloOh0;_ooool00oo8b<SoQhN7on7Qh@2dooooo`08oo_lo_o/m?Woamo]of6Qbol0
J:co06>Yo`AZ[Ol8K:hNo`M/[P03o`9Y[?lEM;?odNCa0?oooooo0oooool00<Wooooo00KohNgeofZW
c_lYP;Wo1ff^o`9Y[?l6K:h>o`M/[P06o`AZ[Ol0HZWo5gJdoi6mfooHj?;oo?gn6oooool01ooof;3o
ojA6ooZ;6_o^PaCo/Hm9oj2ES?nYTh`00_nZThL04onXTXOo/IR8olBXS?o[aICoo=>GooS?U_oU_i;o
]Yb9ojRAQonZThgoXY=KooR11OooP03oogh0oomg0?ooRACoolR@ooo[f?oooOX0>Oooool02?o^k^ko
_[jnojBTY?n?ShooX:2Pom?Cdoo`l?3oo_knMoooool04oo^l_So_/cSojbnfon[_M[o[;kKojRlfOn_
_mcof=o/ooGfn?oin_[on?WjooWjn_omo?[oc]_ZoiFfeOmnY/goHY?3odj5_?mDRKh00omGRkl02_mB
R;goPjK?okK7h?oEg^gok_;hooWjo?oRjO;o`<cTonCZlooko?d/ooooo`03olS8b?n7QhOohN7Q0:3o
oooo00?ooOgnookoooooool03oooool01oofn_cod^GaoiO1gOlnSL3o05^To`1UZ_l6Jjd04ol7K:h0
0ol5Jjgo0VV/o`I/[P0:o`M/[P03o`1WZolON[Goc>7_0?oooooo1?ooool00<_ooooo00Kof>SbofjY
d?l]P[[o0fZ]o`5X[?l6K:h>o`M/[P05o`9Y[?l0HJSo87^goi:ofooBi?006oooool01?ogo_ood/J/
ojNPTonWUYD2ojZBQP0>ojRAQon[ThOo_J6:omjjT?oldYKon=2EooG=UOohciKoiL2BokJLROnXTHOo
ZY>=oj:CFoohP@D3oon00006oomm0?ooMP3oohlOooo4R_ooi<Soooch>Oooool01ooZj^[o_knoojBT
Y?n>SXkoY:BTom?Cdoo^k^h0Moooool04?oinocob]KXojo0g?nY^m[o[;kKojZlfonW^]WoaM3Uong`
mOohn?Sol?7eonGYlOnX`=_oFXc0oe27_OmERKh2oeN;_`0>oeR;_omLSL3oEh^oocEk]_n=/mKolO?i
oo;dnOoEgnko/L;NojFhf?nX^mWoZK_Iom?Lk?odmoX[ooooo`03olS8b?n7QhOohN7Q0:3ooooo00?o
kO7gon3Wl_ohnO`03Oooool01ooTkoKo_mWZoh6de_l@L[7o062Wo`1VZol8K:h04ol7K:h01_l1JJco
06J[oa9b/OlXP;Wo0VV/o`E[[@So1fb^00?o06JZobAl]oo8gnh0ooooool5ooooo`00cOooool01Oo?
h^ooKjW@obj3^ol0IZ[o06N/00oo1fb^00Go06N[o`1PYolVOkSoSkgKom3Sl00Hooooo`0<on__m_o6
dnWoZ/;Xoj^mh?n/[kooZYnRojJCRoneVXCod:j<ooC;UOoldYKomlfE0_ofcID01oohciKoi/2CokNL
R_nXTHOoZY>=oj:CFoohP@D01OooP0001_ooO03oog@0oon74?oo^gSoon73ooonoCWooooo00OoinOW
okjn__nRXZ;oSHf=ojNWYooCdm?okNg]07Oooooo00cofN7_okC4gonW^mWoZkkKojbnfonU^MSo_<[Q
omCLj_o0cN;o[KkKoh:TcOmER[h2oeN;_`0;oeV<_omNS/3oDXVnocIo^?lfP;Wo5W2aoh6_doo6d^Oo
[;kLojJif?nZ_=X00_n/_]/01?n[_]_oYk_Iol3>i?o/l?LZooooo`03olS8b?n7QhOohN7Q0:3ooooo
00CohNOaojjog?o6d^KojNge2_ooool01_oBiO7oX/SQodjFa_l4JZgo062Wo`9Y[1?o1fb^00[o1F^]
o`1VZol0I:[o7WZfoe6Ha_nB_mcoa=c/of:Rc?l5Jjko16Z]1_l7K:h00ol0IJ[o97bgolGMk@3ooooo
o`Kooooo003?ooooo`05olcQk_md[];o:h6jo`1RZ?l0Ij/03ol7K:h01Ol0Ij_o066Xob^1^_n0]=Ko
cN;_01Cooooo00goloGjom7Lk?na`]goYk[Iojbnfon/_mcoYkgOojjnfoo7aL_oj=6dookEVoohc93o
m/fD00?omljF00Oon]2GonO1TongW8[oZ967ojZCSOnRTe_on84500Oooh0000Goog`0oome0?ooRQKo
okE/oooN_00jooooo`07onGUiOo2`/;oWinOoh^;RonWYjOoc/k>ong]k@1fooooo`0Jon_`moo2d>Ko
Yk_JojZlf_n]_]_oZKcJojJifOnX^m[o[l3LohNWcomGRkooGHg0oef>`?m7QKco:WZfocN0^OlXN[Go
<gfgoe:9__n0X/coY;SHojbmf_n/_]_oZkgKojVlf_nZ_=X2ojbnf`04ojNjfOnb`mkogNC`oogmoRSo
oooo00?ob<S8ohN7QooQhN40X?ooool01_oTj_?o[l7MojBgeona`]gocmWZoo3dn@Gooooo00OomO[l
ok3@iOmg[]?o<8Blo`1UZ_l0HjWo16Z]01?o1fb^00Ko0fZ]o`1SZOl0Ij_o>X^oofnZd?ngeNP4oooo
o`03og^`e?l<Kk3o0FV/00Co1fb^00?o06BZobMn^?o2g>`0ooooool7ooooo`00dOooool01Oo5gNco
N;3Cob=m]ol0GjOo06N[00oo1fb^00Go06J[o`1SZOlaQKcoNk;Eom7Tl00@ooooo`0IooknoooKho3o
_L_SojJjfOnZ_=[o[;kKojVlf_nV^MWo_/_RomcSkoogn_ooo?[eooWZf?ohg;Kon=2JooO:SOogcICo
mljFoo[AUooW`9;o]Yb9ojRAQonZThgoXY=KooR11@09oon00005ooml0?ooMP3oohhNooncJ?oogkd0
>_ooool01ooTi>Co`l?3oifMWOn<S8coZJVYol_;boo^k^h0MOooool01?ohnOcod=[[ojjog?nW^mT2
ojbnf`0Joj^mfonZ_=[oQjK>oej=`?l_OKOo9GReoc9o^Ol[N[KoA8Bkof6?`OmLSL3oDHNmognScOnY
_=[oZkcJojNjfOna`Mco_L[Rok[9hOn[_M_oZkkKojbnfonX^mWo[;kKolkHjOofn?`Wooooo`03olW9
bOn7QhOohN7Q0:3ooooo00Ooi>[cok31gOn[_M[oZ[gJojFif?nkb^;og>?`00;ooooo00Oog>[doi[4
g_mEV/Oo5WFco`1PZ?l0IZ_o1F^]01?o1fb^00Ko06N[o`1RZOl<KjooDIO6oi[3g_oFio87ooooo`08
oi_4g_l>L;3o06J[o`Q][_l8K:ko06BZob=l]oo3g>coooooo`Sooooo003Cooooo`05olGLk?mk/MCo
7GVeo`1OYol0J:`03ol7K:h01Ol0IZ_o06F[oc>6_?mk/MCofn[d00gooooo01[oingeolOCj?n]_mco
Yk[Iojbnfon[_]_oY[[Iok;1gOoCfn_ol?;foogknoojnOWonOWkooWkoooim_;onNgLooSQ`?ogd9Wo
mlV<oo[@UOoV`9;o]Yb9ojRAQonZThgoXY=KooR11@_ooh0000Goog`0oomh0?ooTB;ook=XoooSaP0i
ooooo`08ookno_oUiNGoaLG5oiZJV_n>SXkoZJVYolW9bOoalO5dooooo`0>oogno_oPi_;o]LGPojFi
fOnU^=SoZKcJolcFj?nA^=So9GVeocEo^OlcOKSoC8Rmoen>`OmJS<02oeN;_`0@odn6_OmkX<coYKWI
okO5goo4d>Coc]KXomCLjoo?fNSo_/cSojfog?nZ_=[o[;kKojZmf_nZ_=[o_/cSonS]mRKooooo00?o
a<C4ohB4Q?oPh>00X?ooool03OoTj_?o/<7Moj^mf_n/_]_o[[oKojfnfonea=oo/lOPoj2nfolgRkoo
2Fj_o`1RZ?l2JJ`05?l7K:h01_l0IZ_o05jVobIn^?m^Z]7o/m;VonOam`[ooooo00Ko/=3Voaij]_l0
HZWo06R/o`i_/?nZcN?oooooo`Wooooo003Dooooo`06oo_mo_o?h^ooQ;KGoaQf]?l0H:So0VV]3_l7
K:h01_l6K:ko06R[o`AZ[OlbQKcoLJ_AonC_m`[ooooo00col?Ciok;3g_nY_=[oZkgKojbnfonX^mWo
Z[cJolWDi_oYk??onOWjoo_jn_oin?T2ooWinP0=oo[jn_ojn_con__noo[imooikn;on>71oo_BV?oV
_8Wo]Yb8ojRAQonZThgoXY=KooR11@0=oon00005oomm0?ooO03ooi4Roon_Goooi/d03?ooool00ooP
i_;ofn;_ooooo`0Zooooo`08ooclo?oZj^[obLW9oiRHV?nBTY;oYjNWolO7aooclo=dooooo`0:onob
n?o;e^WocmWZonkbn?omoOkoW;gKocn2^_mHRl3oFhg0oeR;_`;oEh^o00koEHZnoe67_Om@QkgoU;;D
olkHjOoIgngogN;^om_Rk_oGg^codm_[oloIjOo3cnCo/L;NojZlfP;o[;kK00?oZ;_Iok72gOoFgnd0
8oooool01OoMgMgo^[ZjoibLW?nEUIGoinOW0:3ooooo00goi>[cok31gOn]_]_o]L?NojZmg?n?[M;o
L9[8oej?`OmBR;ko=WjhoaYd/ol0J:co1Vb^013o1fb^00So26b^o`AZ[Ol0HjWo05jVocJ8_OnJ`mko
d^C`ooCio0gooooo00Goamk]ocV9__l0Ij_oXLSPoo_loP3oooooo`Wooooo003Fooooo`06ooSkoOoE
i_7oP[GFoa1b/Ol0HZWo16Z]3_l7K:h01_l6Jjko0VV/o`U][ol`Q;coLZcAon_cn0Sooooo00_ojNkf
ojRkfOn/_]_o[;kKojVlf_nia^3ohnSaooGgnOojn_[onOWiooWhn@02ooWinPCon_[j00[on_[koo[k
o?ojn?KooOCVonOC_?ngVhSoZ8j0ojZCS?nRTe_on8453oooP0001OooOP3oogl0oon@8Ooo[UooonO>
00Sooooo00Com?Ojol?Ai_nc`mkoc]WZ;Oooool02?okno_okNg]olS8b?nGUiOoUIFEojNWYoo8b<So
n?ShM?ooool01OoamO[oe]o^ol;?i?n;Zm7oFHbo00?oEh^o017oE8Vnoe:8__mNT<;oMZ7:oh2Xc_ne
bn3oh^O`on?VlOoOhnoofn7]omWOkOoEg>_odMWZolkFjOo5d>Go]/GOojZmfP02ojbnf`04ojZlf_n]
`=co`m7VooWjoAkooooo00Son?Shol_;bon/[:coWYjNohn?SonKVi_oemOGoo_knj3ooooo00koj^ke
okS6h?nS^MSoOj;=ofNDaOmMS/7oE8VnoeF:_omGRkooFHc0oe69__lfOkSo16b_o`1Y[0ko1fb^00Ko
0VV/o`1OYol9KJooFik:okcGjOoOk?@Aooooo`03om[Ylonfe>Son_cm0?oooooo2_ooool00=Sooooo
00Kom_[lomk[m?n1]=Go2Ff_o`1UZ_l6Jjh>o`M/[P06o`I[[_l3JZgo2fj`obR0^Omf[]?oloSk1_oo
ool02_oZkoKoZKcJojbnfon]_mcoaM3Uoo;cm_oinO[on_[jooShnOoin?T2ooWinPOon_[j00Son_[k
oogno?oYj^ko^;oBojVSZonZTX_oXI1DooR11A7ooh0000Googh0oon10_ooRQ[ooj94oooQ``05oooo
o`05omGNk?ndaMooZkkKojfng?oAfn/0;oooool02?okno_ol?3`olC4a?nEUIGoUiNGojRXZ?o:b/[o
n_[jL?ooool01_o]lOOoam?XokO6h?n_`=co[koKohNWc`;oEh^o0_mDRKh06?mXU/GoQ:_?oi:edonD
]=CoSk;Cok_>h_oRio3ohnSaon3TkooLh^kof^3]omONk?oCfn[ocmSYol_Ej?o5d^Ko^LOQojfofon[
_]_o[;kKoj^mfon/_]_o]lOQongama_ooooo00Wojn_[okbl_?nTY:CoV9RHoi2@T?nWYjOofMWIoo;b
l_omoOd0XOooool02?nodNKoLY[8of2@`_mHRkooGi73of2Ba?mGS;ooEX^o0_mGRkl01_mHRkooEX^o
odn8__l^O;Ko06Z]o`E[[P[o1fb^00Ko06N/o`1QZ?lLN;CoP[GFomCVlOo^mO[oooooob3ooooo003J
ooooo`05ooWkoOoWl_SoO;7Do`Q][ol0Ij`04?l7K:h01Ol6Jjko2Vj_oaYg]?mb[=;om?Wl00Cooooo
00[oj^ofojVlf_n/_]_o[[oLoloHjOonoOcon?WjooWin_ohn?WonOSi0_oinOX8oo[jnP08oogmnooY
k?;o^LOOojZlfOnZ]mKo[ZnEooYl0?ooO@0Boon00009oomo0?ooP@7ooh8<oonM>ooohlKoooooonK]
m_nkbN?o[/3L00;o[;kK00?o[[oLom7Kjoooool0<?ooool02?olo?colo?col?3`onEUIGoV9RHoj>S
Xoo;bl_ono_kJoooool01OoloOkof>3^ok[9hOn^`=co[KoK00;o[;kK01[o/<3LohJWcomDRKkoF8^o
ogFQb_nD]MCoV[[FoiVjeonI^=KoUkSFohnbdonlc^;ohnO`onCXlOoQiO3ogN?_om_QkOoHgngoe=c[
om7Ij_o=e^SobMCVolC?i_nnb^;o/<7Mojbmf`?o[;kK00?o[l3MomSOk_ooool05oooool00ooJf][o
[jn_oijNWP02oiNGU`04okjn__oZj^[onOWiooknoZ3ooooo00coo?knoi2mg?l^Q;co;gbgoej>`?mG
RkooEHZnof6B`omZV<OoJIO6oej?`OmFR[l3oeN;_`05oeR;_omHRl3o@HFkoa1a/Ol3JZ`01_l7K:h0
1ol6K:ko06N/o`1WZom0Sl7o_MSZonofn_oio?d0oooooolRooooo`00g?ooool01OoloOkojO?hofnY
col6Jjgo0fZ/017o1fb^00Co1V^^oa5b/_mk/=ComOWl0_ooool02_oZkoKoZKcJojbnfon^_mcocmSY
ookmnoohn?WonOWjooShnOoin?T2ooWinPSon_[j00[ooOgkonW/l_niamooZ[cJojRkfOo9e^Woo>oR
oon_G_ooO@3oogl04oooP0001OooO`3oj8D=okRPOon[]lgo[;oK00?o[;kK00?o[[oLom7Kjoooool0
<_ooool02?ono_kol_;bokno_onGUiOoV9RHoifMWOo9bLWono_kIoooool01?obm?[oc=OYojjog?n/
_m/5ojbnf`0<ojfng?n@[];oPZ[>oinnf?nM_=SoW[cHoibkeonK^mSoV[[GoiRheOn?/]?o_<oS0_oT
j?403?oQi_7ogn?_om_QkOoIh>goeMg[om7Jj_o?enSob]CWolKBi_o2c^Co_lcSok?3g`Co[;kK00?o
[KoKol?Ai_ohn_`04oooool02OoinOWod=3@oj6QXOnJVY[oV9RHoifMWOo?cloomOGeooknoP2Qoooo
o`0:omcZm?mPX<_o3g2ao`Q][_l1JZgo;7Zfoej>`?mGRkooEHZnof6B``?oJYS700?oI9C5oeR;`?mG
Rkl01?mGRkl01?mKS<3o;gfho`Q][ol6K:h2o`M/[P07o`I/[_l3JZgo3Fn`ogN_d_oHj?;onognookn
o`3oooooobCooooo003Oooooo`03onKamomYYLko2fj`01;o1fb^00go0VV/o`i`/?n4]mOomOWkonW^
m_nY_=[o[;kKojjog?o?enWoo_gkooShnOoinO[on?Si00;onOSi0_oinOX7oo[jnP0<oogmnooYk?;o
^LOOojZlf_nX^mWob]KXoocmo_oooooooo3RoonaHoooQ0Wooh023oooP0003?onP03ooH02olJ<>onU
U8?oZY>9ojZ@Pon[WYooZkK=ojbmf_n/_]_o[[oLom7KjcKooooo00Gojn_[ojRXZ?nFUYKoU9BDomOG
e`1Sooooo`06ooknooomo_koh^Obol3>honY^mWoZkgK1?n/_]/06on]_m_o[[oMol7=hooYjo;odMk/
oj:ofOnP_]WoWkkHoijmf?nM_=SoW;_GoiZjeonI^=KoT;?Cokg@i?oUjO;oi^Waon;Vl?oPiNoogN;^
om[PkOoFgNcodm[[om3HjOo<eNSob=?VolC?i002ol3=h`03okO6h?n]_mco[;kK00?o[;kK00?o]/OP
on[_m_ono_l03_ooool02?omoOgok^k^okbl_?nKVi_oUiNGoiVIVOnYZJWoemOGXOooool01_omo_ko
n_cmojo@iOm:ULCo06J/o`E[[@;o1fb^00Ko0FZ]obaj]_mNS/3oEh^ooeF:__mQT/<4ofZHa`03ofVG
aomMT<;oEh^o00CoEh^o00OoF8^oof:?`OlILk7o26f_o`Y][ol[P[[oUl3L02Oooooo00?oookmooom
noooo?T00_ooo?T00ooooO[ooogloooooP3iooooo`00hOooool01_oVl?OoJJG>oaQf/ol:KJoo1F^]
o`I/[Pko1fb^00[o1V^^o`1TZ_l9KJooWkkKojFjfOnZ_M[o[l3LoloGjOonoO_on?Si0_oinOX00ooh
n?WonOSiooWhn@02ooWinPKon_[j00OooOgkonS/l_nhamooZ[cJojRkfOo:e^Soo?gn00?ooooo00Go
ooSaooniL_ooRAGooh86oomo000;oon0000=ooV01_oHR2CoXY=aojNDSonZThSoZY>7ojVCQon[ThGo
[i>2oj^OX_n[]/co[[kIom7Kk00cooooo`08oo[jn_o/k>coaLG5oiJFU_nHV9SoWinOolK6a_oinOUQ
ooooo`06oo_loOofn?_of>7_ok72gOnX^mWoZ[gJ0_n/_]/01_n[_M_o[;kKojo0gOnda=ood][ZooCc
mP;ooOcl01cod]k[oj:ofOnP_mWoX;kIoijmf?nN_=SoW;_Goi^keonI^MOoT;?Cokg@hooVj_7oi^[b
on?WlOoQiO3og^?_om_QkOoGgngoe=c[om7Ij_o=e^SobMCVolG@i_o0cNCo_lcSol7<honlbn?o/<3N
0on/_]/01?nZ_=_o[;kKomGNk_ojnod;ooooo`08ookno_oWinOoYJFUoi6ATOnIVIWoWYjNokZj^_oZ
j^ZPooooo`07ookoooodn?_oi_7gohJgeolMNKGo06FZo`9Y[004o`M/[P06o`5Z[Ol/N[KoGXk0oeN;
_omER[koHI;31OmZV<L02om[VLOoIYK6oeb>`_mGS;ooEh^ooeJ;_omFR[ooF8c0of2>`OmfYLko^]GX
02Oooooo00coooWcooociooo`hOooiP_oomd0?ooM`3oogX0oon@8Ooo/VGoomjoooofkOooo_cgoooo
o`00hoooool01_oSk_KoIZC=ob5k]_l9KJoo16Z]o`I/[Pko1fb^00Wo0fZ/ob=h]?mMS/7oQJO>ojJk
fOo=e^SoookmooShnOohnOX00_oinOX00oohn?WonOSiooWhn@07ooWinP07ooclnooXjo;o^<OOojZl
f_nX^mWob]KXoocmoP05ooooo`05oooej_oo]FgoohdOoon11OooOP001oooP0001_olP@;oihDGokR?
D_nQU8goZY><ojZCQ`;oZI:700So[YJ8ol>URooN^Y7oZI24ojZ@P_n/XJCoc<c=ooofjc3ooooo00So
nOWion_[jonm_KgoTI6AoiFEUOnVYZKoa<C4ooWinF3ooooo02_oo_koooOio?oXkOGob]KXojRkf_nW
^]WoZkgKojbnfon[_]_oZkgJojfofonc`mgo`LoTon7Vkoojn_[oo_cloo[inOoinO[oo?ckom;NjonR
`=[oXKoIoj2nfOnO_]SoWKgHoibleonL^mSoV[[Foi6de?nndNCoin_bonS[l_oTj?7oh^OaomoTkooL
hNkof>3]omGLjooBf^[oc]OXol[Dioo6d^Ko`LgT00?o_lcS00?o`LgTokC3g_n]_m`00on/_]/01?nW
^]Wo`M3Uoo;en_ono_l9ooooo`06ooShn?o3`l?oV9RHojVYZOo:b/[onOWiS_ooool00oomo_kooooo
ooooo`0?ooooo`07oogno_oVl?Oo_]SZofNVcOl1JJco06>Yo`=Z[@06o`M/[P06o`5Z[Ol/N[KoGXk0
oeN;_omER[koHI;31omZV<L02omZVLOoH9;4oeV<`?mKS/7oHY73og^Qc?nR^MWo/;oLol7=hooYk_Ko
nocm02;ooooo00Oooogjoooci_ooiLWook1Poomn0?ooN@3oogd000?ooh0000Koogh0oomi0?ooM03o
oiD[oooEZooomN_fooooo`00iOooool01_oKj_?oJ:G>obQo^Ol7K:ko0VV/o`I/[Pco1fb^00Wo1F^]
obmo^?mHR[koDXNmof2@`_nY`]col_GgooOgnOokn_X00_ohnOX00ooinO[on?SiooShn@07ooWhn@07
oockn_oXj_;o^<KOojZlf_nX^mWob]KXoocmoP07ooooo`05ooobiOoo]F_ooi8Voon10oooO@001?oo
P0004oo/Q0ooe8Xdoi^FOonWU9?oZY>8ojZCQonWTHKo[9B8okVNRooO^Y7onLnFonO0TonYTXOoZY>7
ojV@OonkSTgoojU>oooG[oool^D0;?ooool02?oinOWoj^[Zol30`?nCTi?oU9BDojVYZOo3`l?omOGe
H?ooool01_ojo?gol?CiomkVl_nmbn?oYk[IojNkf@;o[;kK02KoZkgKojZlf_n``Mgo^/SPolgFj?o[
kO?oooomookmo?okno[onOWjooWhnOohn?WooO_kom?OjonR`=[oX[oIoj2ofOnP_]WoW[gHoiflf?nL
^mOoV[_Goi:ee?o0d^Coin_bonS[l_oUjO7oh^Oaon3UkooMh^kofN3]omKMk?oCf^[ocmSXolcEj?o7
dnKo`loTol3<h`?o_lcS00Co`<gTokS6h?n^`=coZkgK0_n/_]/01?nV^MWo/l?NonCYm?oloOh9oooo
o`03ooShn?oQhN7oo?cl08oooooo00?ooOgoom[Rkoofn?/03_ooool01oocn?_oe>Kaoj?9hOlfR;ko
062Wo`1SZOl5Jjd02?l7K:h01_l1JZgo;7Zfoej>`?mGRkooEHZnof6B``KoJYS700goJ9O6of^Haome
Wl_oPZO?oiBae?n_`=co/l;Mojjofon/_]_oZ[cJojVlf_o@fn_ol_Gi01oooooo00OoooWcoooYd_oo
bYKooiXeoomh0?ooN@3oogl000Sooh0000Coog/0oomb0?ooYDcoon;3mOooool00>Oooooo00?oeNKa
og2Zd?l`Q;/00_l0J:`;o`M/[P0;o`E[[Ol_OkSoFH^ooeN;_omFRkooLYo:ok79g_oAg^[oj^odooWh
nOoln_X00_ohnOX2ooWinPKon?Si00Oono_jonO[l_nhamooZ[cJojRkfOo:e^Soo?gn00Wooooo01co
onoPoonjM_ooUbooogh0ooml0?ogP@?oghLWojBCJ?nSU9CoZi>;ojZCQ_nXTXOoZ967okBKROoD/hoo
ll^EooS?U_ofcYGoi[nCojVBQonZThOoZI>4okf=BoooM@3oogT0oonQA?oodZGooo3Q:?ooool02?oi
nOWoiNGUol71`OnDU9CoT92@ojZZZ_o4a<Colo?cH?ooool04?oemo_oi^cdolcHjOn_`MgoYKSHojVk
f_n/_]_oZkkKojZlf_nY^m[o]<?Mol;?hooKhNgom?Chooooo_omo?/3oo[jnP;onOWj00?onOSioogk
nooCh>/00_nR`=X05_nQ_mWoX;kIoinnf?nM_=SoW;_Goi^kf?nB]MCo`=7TonO/l_oYk?;oiNWbon?W
lOoQiO3og^?_om[QkOoGg^goe=_[om3Ij_o=e^Sob=CVolG@i_o0c>@4oko<h`04ol3=honlb^;o//;N
ojfog0;o[;kK00CoZ;_Ioj^mf_oBg>comoWkV_ooool01Ooko?goX;CEoko=hooXkOGoo?gn00[ooooo
00Koh^kfokWEj?m]ZLoo5GFbo`1NY_l0IZ/;o`M/[P06o`5Z[Ol/N[KoGXk0oeN;_omER[koHY;30_m[
VLL04om/VLOoJYW7ofZIa_maW<WoPZS?oi>ae?naaMkobm?WolcEjOnnc>?o/l?Oojfnfon[_M_o[;kK
oj^nfonW^]Wo]<GOomgTl?ofn?/06oooool01oookM[oomVboondJoooQ@[oog@0oomk0?ooO`003?oo
P0001?ooM`3ooh01ooo;U_oom^gcooooo`00jOooool01Oo?h^ooL:_@obf2^_l0IJ[o06N/00Wo1fb^
00ko1F^]obmo^?mIRkooEh^ooeV<`?mhX/coXl7JoiZjeon]amgocmgZonW]loojn_[oo?_jooShn@?o
n?Wj1?oinOX01ooko?_oin_bokS6gonZ_=[oZ;_Iol[Fj?oloOh02oooool07?ook=OookihonVH?_o6
RTKoX9>5ojZCS_nZThOoZI>7ojF@Q_n_UXSob:V=on[4TookdIKomljEooG=UOofcYGoi/2CojVBQonZ
ThOoZI>4okf>COooOP3oogl0oomg0?ooNP3ooj97ooo@X?ool^@Tooooo`08ooKfm_oKfm_o_[jnoiFE
UOnATI7o[Zj^olK6a_o]kNePooooo`0@ongamooLi?3o`LoUoj^nfonU^=SoZ[gJojbnfon[_M_oYk_I
ojbmfonian3ob]GWon7Vkookn_Wooogloo_kn`Kon_[j01conOWjooWhnOoln_[odn3[oj?1f_nR`=[o
XKoIoj2nfOnO_]SoW[gHoiflf?nL^mSoTkGDol3Ci?oYjo;oj^gdonOZl_oUj?7ohNKaomoTkooLhNko
fMo]omKLjooAf^[ocMSXol[Dj?o6dNKo`LkT1?noc><01Oo0cN?o_lcTok_9hOn__mcoZkkK00;o[;kK
00GoZ[gJojJifOo2d>Goi^cdoogmoP2Hooooo`06oo_loOnV^MSoZ;_Iojjog?oAfn_ok_;h1oooool0
1_o@hnooW<COodfEaOl:KJoo05jWo`5Y[0go1fb^01_o0FZ]obaj]_mNS/3oEh^ooeF:__mTU<?oKY_8
offKaomZVLKoNj?<ohf^donS^m[o`/oTom3HjOo<e^SobM?WolWCi_o;eNOob=;Vokc:h_nb`]goZ[cJ
oj^nfon/_]_oZ[cJojNjfOo@f^/06?ooool01oooo_goon31ooo6S?ooWC_oog`0oome0?ooO@004?oo
P0001?ooO@3oogD0oon]G?ooi<[booooo`00joooool01Oo6gNcoLZcAobIn^?l0HJSo06N[00Oo1fb^
00oo1F^]obmo^?mIRkooEh^ooeV<`?mhX/coY/;Koinnf?nL_=SoVk_Gojo7gOo=g>Woj>gboockn_ok
n_X01_ohn?T01ookno[oin[bokS6gonZ_=[oZ;_Iol[Fj?oloOh02oooool05_okoooofnkook;4conV
Z;[oZibMojZAPonWSh;oZ966okfRRooM^Y7onLnFoo_AU_ogcIGom/fEooG=UOofcYGoj<:CojVBQonZ
ThOoZI>4okf>COooOP02oon00006oomo0?ooM`3oogh0oonSB_ooc9[oooG[8?ooool02?okno_ofMWI
okNg]onBTY;oSHf=ojf][Oo?clool_;bH?ooool01_o]lOOoc]WZokS8h?nU^=WoYk_Ioj^mf`;o[;kK
00SoZ;[Jojfnfoo2c^?oeMc[onW[l_omo?_oo_glooWin@;onOWj1_ojn_X2ooWinP0Qoogjn_oCh>_o
Xl7Joj;0f_nR_mWoX;oIoj2nfOnN_MSoWK_Hoi^keonC]]Go`=?TonW]looZkOCoin[bonGXlOoSi_3o
gnC_omcRk_oIgngoe]k[om;JjOo?f>Soc=GXolOAi_o2cnCo_lcSol3<hoo0cNCo_/_Sok[8hOnca=oo
[l3L00Co[;kK00GoZ[cJojBheonW^]WocMSZoo_ko@2Hooooo`08oo_loOnV^MSo[;kKojZlf_nW^]Wo
^<SPom_Skooinod2ooooo`08ooOjoOo0f^[oO[?Eoc>6_?l0HJSo06>Zo`=Z[Ol8K:h>o`M/[P0@o`5Z
[Ol/N[KoGXk0oeN;_omDRKkoHI;2og2Lb?n1YlkoVKGFok?6goo9dnOoe=[ZolkGjOo=e^Soc=KXolcE
j0;ocMKX00GocMOXoloHjOo7dNKo^/SPojjog002ojbnf`03ojVkf_o1cnGooooo01Gooooo00Oooo3P
oooBYooo]6coohdKoomd0?ooN@3oogl001;ooh0000Googl0oomi0?ooL03oojUBooono@3aooooo`00
kOooool01Oo6gNcoNk7Dob=m]ol0GjOo06N/00Go1fb^017o1F^]obmo^?mIRkooEh^ooeV<`?miX/_o
YL;Joijnf?nP_]SoX;kIoiflf?nL_=So[/SMolWIj?oXkO?oo_ckooWin@04ooOgn007ooWinOoVjO7o
^<OOojZlf_nX^mWob]KXoocmoP0:ooooo`0<onS]mOo7dnOoZkkLojZngon/`=ooZkO@ojJY]oneY9co
eK69oo36SookdYOomlnF1?ogcYH01oohciKoj<:CojVBQonZThOoZI>4okf>COooOP001?ooP0001_oo
O`3oogP0oon00OooXDKoolZEooohlAgooooo00Oon_[jol_;bon?ShooSHf=ojn_[ooDe=Col_;b06;o
oooo00?ok_;hokW8hOnR]]L00on/_]/03?n[_M_o[[oLolWDi_oPi>oolO;foo_jn_ojn_[on?SiooSi
n_ohn?WonOSiooWinPOon_[j00?onOWjoogjn_oCh>/00_nS`MX09_nR`=[oXKoIoj2nfOnO_]SoWKcG
oi^lf?nD]]Go`MCUon[]loo[k_?oin_bonKYl_oSio7ohNG`omcSkooJh>goe]k/omCLj_o@fNWoc=KX
olWCi_o5d>Go`/gTokc:h_nfaMoo//;Mojjog?nZ_M[oZkkKojbnfon[_M_oYk[IojFif?nfa^3od=WZ
onG[m?oemo_oo_koV?ooool00ooko?goY[WHojbnf`02ojbnf`0:ojVkfOn_`=coc=KYomSPk_nC_mco
Di[8ob=m]ol0HZWo06N[o`I/[Q7o1fb^00co0FZ]obaj]_mLSKooChJloeJ9_on0YLgoZKoLokc<h_oB
fN[od][Zom7HjOo@f>T2om3IjP03om7Ij_oAfNWodMWY00?odM[Z00Ood]_Zom7IjOo7dNGoZ[gJojbn
fonZ_=[oa=7V01Cooooo00Koon?7oonnOOooWSgooh@8oomg0?ooO@0Coon00007oomm0?ooM@3oogd0
oonTB?ooaHcoomfkooono@3aooooo`00koooool01Oo8gngoOK;Eoa]h]Ol0GjOo0FR/00?o1fb^01?o
1F^]obmo^?mIRkooEh^ooeV<`?mhXL[oXl3Ioijlf?nN_MSoWkgHoj2nf?nO_]SoWKcHoijmf?n`b=oo
amSWon[^m?ooo?_on?Si00;omOKh00Oon?SionGYlOngamooZ[cJojRkfOo:e^Soo?gn00Sooooo00ko
mOOkoloJjondaMkoZKcJoj^mfon/_]_oZ;cJojRmg?o=f>cok>WXooWYd_oifJWom/^>ooO<TPComljF
00Oon<nFonO1TonYTXOoZY>7ojVCQ?nmSTgoogh000Kooh0000Koogl0oomi0?ooQ0Sooj93ooo<V?oo
oO/Kooooo`05ooclo?oDe=Co/K6aomGEeOoalO40IOooool01?ocmO[oc=SYojBhf?nZ_MX3ojbnf`09
olC@i?oal_Gono[jooKfn?ogn?Won?SiooSin_oinO[onOSi00;onOWj1_ojn_X07ooinO[ooO[jom?P
jonT`M[oXl7Joj;0f_nQ_mWoX;kIoinnf?nN_MSoWKcHoiFfeOo2dnGoj^kcon_^looYjo;oi^[bonCX
lOoQi_7og^?_om[QkOoHgngoe=cZom7Jj_o?f>WobmGWol3<honea>3o/<7Mojbnfon[_M/00_n/_]/0
1onZ_M[oY[WIojRkfOo1c^Gog>C`ongan?ono_l0Voooool03Ooko?goY[WHojbnfon]_m_o//;Mok71
g?nI/mKoNZ3;ofjIa_m7QKco6W>ao`1VZol5Jjd04_l7K:h02Ol6Jjko06:Yoaaa/OmRTL?oNZ3;oi2/
dOngan7oe=[[omCLj`02om;JjP03om?Kj_oCfn_oe=cZ00;oe=cZ00?oeMcZomCLj_oDg>X00ooDg>X0
1_oEg>[oe]g[ojZlf_n/_]_oZ[cJolCAiQ7ooooo00Oooo[eooo@X_oo[egooi@Xooml0?ooN`3oogh0
01;ooh0000Ooogl0oomj0?ooM03oohPAoondJ_ooeJcooo3Q0?Cooooo003`ooooo`0?oo[loOo<hNoo
PKGFoa=c/_l0H:So0fZ]o`M/[_l5Jjgo;gnhoeV;_omGRkooFHc0ogNQb_nR_mWoWK_G00;oWKcH0_nN
_MP04?nO_MSoW[gHoibleonO_]So/<SNolSHioo/koCoo__kooKgn?ogmoSoi>SaokS6h?nZ_=[oZ;_I
ol[Fj?oloOh7ooooo`0AomkUlOnjbN;oZkkKojZlf_n/_]_oZkgKojBhf?nnb^7oh^K`ooCen?olo?go
nOWkooSck?ohjM?ommFUooK:S_ogcI800_ogcYH01oohciKoil:CojVBQonZThOoZI>4okf>COooOP00
2?ooP0001_ooO`3oog/0oon73oooXD?oolRCooogka[ooooo00?ono_kooCdm?ooool0Ioooool02ooj
o?gog>CaojbnfonX^]Wo[KkKoj^nfon[_M_o^LSPonCXlOoinOWomoSi00;on?Si00ConOWjooShnOoi
n?WonOWj1_ojn_X07OoinO[ooO[jom?PjonT`M[oXl7Joj;0f_nR_mWoX;oIoinnfOnM_MSoWK_HoiFg
eOo2e>Goj^kconc^looYk??oin[bonCXlOoQi_3og^C_om_Qk_oJh>gof=o/om3IjOo0cNCo]LGOok31
gOn/_]_oZkkK00;o[;kK00KoZ[cJojNjf?n_`Mgoc=OYonK[mOoemo^Nooooo`0>oo_loOnX^]Wo/l;M
ojfng?n>[=7oKiW7of:A`omGRkooDXRmoeV;_omAR[koAXBko`U^[ol0JJ`?o`M/[P0>o`AZ[Ol0HjWo
06BYocf>`On=]]OoYK[IojNkfOn/_]_o`loUom?KjooEg>_oe]g[omKMk?oFg^`2omONk0;of=k/2?oH
gn`01?nY_=[o[;kKojZlf_o4dNH?ooooo`07ooo]fooo^G?ooi`ioon94oooO03oogd0oomo000Boon0
0007oomn0?ooM`3oogP0oonK>?oobI?oonC8ooohlP3fooooo`00l_ooool03_ohnogof^WcohFgeol>
L;3o06>Yo`=Z[?l_OkSoFH^ooeN;_omIS<3oMZ7:oj6ofOnK^mSoW;_H0_nL^mL04OnL_=OoWKcHoifl
f?nM_=SoW[cHoifkeonP_MWoZlKLolGFi_o]lOGoo_gjonCXlOnga^3oZ[gJojRkfOo:e^Soo?gn00Go
oooo00CooOgnomOPkOn/_M_oZ[cJ0_n/_]/05_nX^mWo[;kLomOPk?oaloOonOWjooWinOoin?WonOWj
ooWjo?oinO[onOObooWZe_oge:Con<b?ooS>U?oid9Koil:CojVBQonZThOoZI>4okf>COooOP0:oon0
0006oomo0?ooOP3oohD<oonD:?oo^gSooo[e3oooool00ooUjoCoemo^ooWko@1aooooo`04ookoooo[
koKo^LSQoj>ge`;o[;kK00WoZ[gJojo1g?oDfn[omoOhooSin_ohn?Won?WjooWin_oin?T00_oinOX5
oo[jnP0JooWin_omn_[odn3[ojC1f_nS`M[oX/3Joj:ofOnP_mWoWkkIoifmf?nM^mSoUKOEol;DiOoZ
k_?ok>kdonW/looWj_;oiNSaon;Vl?oRio3oh>C`om?Kjonmb^?o/L7Mojjog?n[_]/3ojbnf`06ojVl
f_nU^=So^<OPomSPk_obmO[on__mXOooool01onK/]GoO:;<ofBCa?mRT/?oHiC5oeN;`?mERKh00_mG
Rkl01_mHRkooFXc0od^7_OleP;Wo06R[o`E[[@_o1fb^00go16Z]o`1RZ?l7K:koGIo:okoHj_oVl?Oo
h>SbokC3g_n/_M[oZ;_Jol?@iOoGgNgof=o]00;ofMo]00?ofN3]om[PkOoJh>d00_oJh>d8om_QkP04
ojVlf_n/_]_oZ[cJolCAiPgooooo00KoolnOoonUB_ooSB3ooh84oomm0?ooO`0Coon00007oomm0?oo
M`3ooh<5oonbI_oohL;ooo;Tooono@3hooooo`00m?ooool02oogn_cohNkfogjbeOl7K:ko9WZeoeV;
_omGRkooFHc0ogJPb_nO_]WoVk[G00;oVk_G0_nL^mP7oibke`09oifmf?nW`]_oa]KWomkTkonmb^;o
ZkgJojRkfOo:e^Soo?gn00Gooooo00?oo?gnolkJj_nU^MP00_n/_]/01OnW^]Wo`loTon__mOogn?Wo
nOWi00;onOSi0_oinOX2oo[jnP0<oo[ko?ojnOWon_SdooW[e_oge:7onLjAonS1T_nYTXOoZY>7ojVC
Q?nmSTgoogh03?ooP002oomo0004oon32?ooSaoookmnooomn`_ooooo00Gomo[lolWEj?n]_mcoa];V
ooWjo01cooooo`0>ooKhnoo?f^_oYk[IojZmfon/_]_oZkgJojfnfoo3c^Com??goo[in_ohn?WonOWj
ooShnOoin?T2ooWinP?on_[j0_oinOX05oomn_[odn3[ojC1f_nS`M[oX/3Joj:ofOnP_mWoWkkIoifm
f?nM^mSoUKOEol?Di_o[kO?ok>odon[]looWjo;oin_conGYl_o>enSo^/OPojo0g?n]_m_oZkgK00;o
[;kK00OoZkkKojRkfOnV^]Wo`/kUonW^m_ognOcoo?gn0:7ooooo00[o`=[[oe2Ga_mPSl7oFHc0oeF9
_omMSl;oK9[8ofNGaOmNT<;oEh^n0omGRkl01OmHRkooEH^oodR6_?lFMK;o06R/00Oo1fb^00Oo26b^
o`5X[?l0HjWo4g>boi:ofooLjoCol?Kj00;ooooo00OoiN[cok31gOn[_M[oZ;_JolK@iOoJh>cofn7^
00;og>;^00?og>;_omgSkooMhnl00_oNhnl7omkTk`05omkSkonY_=[o[;kKojZlf_o4dNH02_ooool0
1_oom^cookUcoon@8?ooQPkooh00oomn01Cooh0000Koog`0oomh0?ooU2SoolfKooo`h?oon?;koooo
o`00m_ooool02_ojo?goj_?hohfde_mERKooEXZooeV<`?meWl[oWKcHoiRhe_nI^MH2oiZje`03oi^j
eonK^mOoVk_G00OoVk_G00OoW[gHoi:ce?n7Z<ooYK[Hoj^lf_o:e^Soo?gn00Gooooo00?oo?gnoloJ
j_nV^MP00_n[_M/01_oMi>komoKhooSin_oinO[on?SiooWhn@;onOWj1_ojn_X02Oojn_Won_[joo_[
eOoXaigoZI64ojZCQ_nYThCo_Hi=oomn000@oon00004oon01?ooRA7ookimooolnPSooooo00KognKa
okG6gon[_][oYk[IolKBi_oin_adooooo`04oogno_oQj?;o/L;MojVmfP;o[;kK00So[KkKojo0g?oU
j_7onOWjooSin_oinO[on?SiooWhn@KonOWj00gooO[jom?PjonT`M[oXl7Joj;0f_nR_mWoX;oIoinn
fOnN_MSoWK_HoiFgeOo3e>Kojnkc00;ok>od00Coi>Sbol_Dionc`mgo[;oL1?n/_]/01_n[_]_oZ;_I
ojo0gOoAfn_omoWkoocmoZ7ooooo00kooOknoiC0g?lYP;Wo3g6ao`a_[omMSL3oEh^ooeJ:_omMSl;o
K9W8ofZHaom[VLOoIIG6oeV=`@GoEh^o00CoEHZnodJ4^ol3K:ko1FZ^1?l7K:h01_l3JJgo06:XodRC
`onadNKom?Wloo_moPCooooo00Koi>[cok31gOn[_M[oZ;_IolOBiOoMh^h2omoTk`07on3Ul?oQiO3o
hNG`on7Ul?oQi_7oh^Oaon7Vl005on;Vl0;ohNK`00CoZKcJojbnfonZ_=[oa=7V2?ooool01?ooejko
oj=7oon32_ooPP@Eoon00007oomo0?ooO03ooh01oonYE?ooi/gooo[fooono03mooooo`00n?ooool0
1ooZkoKoX[SHogZPbomHRl3oM9o:oibkeonG]mD00onH^=H3oiVieP;oVK[G1OnJ^]L01onL_=SoRZoB
of2B`_mHRl3oNYo:olKCiooloOh01Oooool01ooloOkocm[ZojJif?nZ_M[o/L7MonS[loojnOX00_oi
nOX01?ohn?WonOSiooWin_oinOX8oo[jnP07oo_knooYk??oZZk0ojZKV?nYTX?o_Hi=oomn000Boon0
0004oomn0?ooQPcool>6oooln0Cooooo00?ol??iokk<honX^mT00_n/_]/00onW^]Woa];VooWjo01f
ooooo`03oo3cn?nkb^;oZKcJ00?o[;kK00OoZkgKomCJj_ojn_[on?WjooWin_ohn?WonOSi00ConOWj
00?onOSioocjn_oCh>/00_nS`MX03?nR`=[oX[oIoj2ofOnO_]WoW[gHoifkf?nE]mGo`mCVonc`m?oR
io3o`/kTojfof`Oo[;kK00?o_<[Son7Xl_oloOh0X_ooool01?oIjO?oIjG=oa5b/Ol6Jjh2o`M/[P06
o`]^[omMSL3oEh^ooeJ:_omMSl;oK9W80omZV<L00omZVLSoHY;3oeR<_`04oeN;_`0:oeR;_omDRkoo
:g^go`5Y[Ol7K:ko16Z]o`ma/OmaZ]3ohNgeookoo`Oooooo00Woi>[cok31gOn[_M[oZ;_IolWCi_oP
i>ooh^Oaon;Vl?oRio400ooSio42onCXl@OoiNSa00Goi>SaojVlf_n/_]_oZ[cJolCAiP05ooooo`03
oooil_ooa8[ooh`I01Sooh0000Coogd0oon=6oooahkoooG[ooooool2ooooo`00n?ooool01ooZkoKo
ZKcJojjog?nV^]WoU;7CoibjeonF]]D00_nF]mD00onG]mGoUkSFoiRheP08oiRheP09oi^jeon:[]7o
HI;2oeF:__mDRKkoFhboohfjfOobn?[onogn00?ooooo00_oo?gnoloJj_nV^MSoZ[gJok71gOoXjo?o
n_WjooSin_oinO[on?SiooWhn@02ooWinPSon_[j00Sono_konW/l_n[_]co[;kMoj^a`_o2VfWooh07
oon00A?ooh0000Soog`0oon52ooobI?ooO[eooSinoo@fncoZ;_JojZmf`?o[;kK00?oYk[IolKBi_oi
n_`0Moooool00oonookocMSZojk0g003ojbnf`06ojZmf_o0c>?omOOhoo[jn_oinO[on?Si1Ooin?T0
0ooln_[odn3[oj?1fP02oj;0fP0:oj:ofOnP_mWoWkkIoijmf?nL^mOoT[CCojk4gOneaMooZkgJoj^m
f`Co[;kK00Co[[oLok72g_o6d^Ooko;hXOooool01_okoOkol?Kjojk?i?m1S/3o0fZ]o`5Y[0Co1fb^
00Ko2fj_oef=`?mGRkooEXZooef?`_m/VLP5ofZHa`03ofRHa_mNT<7oF8^o00CoEh^o00GoG8g1odB5
_?ljR[koT[oKooGio00:ooooo`0<onCZlon``MgoZkgJojRkfOo9e>Ooh^K`onCXlOoUj?7oiNWaonGY
l_oVjO;oi^[b2_oWj_802onY^m[o[;kKojZlf_o4dNKoooooooomo?oon_Goon73oonYEOooP07oog`0
01Kooh0000Cooh45oon52_ooXTGoomjkooooool5ooooo`00n?ooool03OoZkoKoZKcJojbnfon_`=co
cMGXonCYl_ncbN3oVk[HoiJfeOnC]MGoU;KEoiFfeOnF]]D01onF]mD05_nI^MKoQjg@of2B`omER[ko
Eh^ooej>`Ol0IZ_o2fn`ohZjf_oTkoKonO_mooooooomoOkocm[ZojJif?nZ_M[o/L7MonS[loojnO[o
n?WjooWin_ohn?T2ooWhn@;onOWj1oojn_X02ookno_ojNcboj^mfon/_]_o[/7Oom;LkOoogK?ooi`i
oon54?ooP03oogl0017ooh0000Soogl0ooAl0?oASc[o[;2hojNheOn/_MWo[;kLoj^nf`;o[;kK00?o
Yk[IolKBi_oin_`0N?ooool01?ono_kohNObokO6gon[_MX2ojbnf`06ojZmf_nb`]goi^WaooShn_oj
n__on?Si0_oin?T2ooShn@03oogknooCh>_oXl7J00;oX/3J013oX/3Ioj2ofOnK^]OoSk;CogNPb_mC
RKkoNYo<ojRkfOn]_]_o[;kKoj^mfon/_]_o/L;Mok[9hOoMi?7onocmRoooool00oomo_kooooooooo
o`0Cooooo`06onoen_oEio;oQ[SHoaij]_l0GZKo0FV/1_l7K:h01_l;KZooGHg0oeN;_omFR[ooGHo2
ofbIb0KoJYS700_oJiW7ofBDaOmISL7oEh^ooeV<`?mNSl;oLY_9oiZae?o5cnGoko3goo_lo@0:oooo
o`06onCZlon``MgoZkgJojNkfOo;eNOoiNSa0_oWj_83onS[lP03onW[l_oYk??ojNcc00?ojNcc0_oZ
kO<3onW/l`09ojRkf_n/_]coZ[cKolC=gOoolN7oolVEoon=6oooMP3oog`001Cooh0000Koogl0oon0
0OooQa7ooiDZooo0POoomN_oooooo`Oooooo003hooooo`0=on[_m_nY_=[o[;kKojjog?o7d^Kojngd
onc]m?oLh^go//SOoibjf?nC]MGoT[CDoi>fe@03oiBfe@CoUKKE01OoUkSFohN/d?mQT/?oEHZnoeN;
_omNS/7o3Fj_o`AZ[Ol0HZWo5WFcoi>og?oLj_Como[momCMk?nV^MSoZ[gJok71gOoXjo?on_WjooSh
nOohnO[onOWjooShn@02ooWhn@;onOWj1_ojn_X01_olno_oj>cboj^mfon/_]_o[[oLom7Lk0;ooooo
00?oomBXoonN?OooQa<00_ooOP0=oon0000?oomo0?ohPPCojHDIoj6CIOnUTY3oZI22ojZHS_nZZKGo
[;S?ok;1fon_`Mko[;kKojNjfOo6d^KonO[l07Kooooo0_ono_h2oogmo@0<oo7dn?o1c^?o[KkKojZl
f_n/_]_oZ[gJoj^mf_o@fNWom_Oioo[jn_ohnOWon?Si0_oinOX04_omno_odn3[ojC1f_nT`M_oXKoI
oiJheOn9[]7oKY[7oeB9_omBQkkoChJmognScOnX^m[oZkcJojk0g?nfa]ooaM;WonGZm8kooooo00?o
jo3gonW^mOoko?d04?ooool02?oloOkoh^kfokcHj_mDV/Oo06BZo`1QZ?l2JJco26f^1ol7K:h01_l;
KZooGHg0oeN;_omFR[ooGHo2ofbIb0CoJYS700ooJiS7ofZHaomYV<OoJYS7og2Lb_mbW<WoPjG>oj:h
eonfa=ko[l3LojVlf_nV^]Woam;Wonkamoomo_h02?ooool03_oTj_?o/<7Moj^mf_nW^]Woc=KXonK[
lOoYk??oj^ccon[]looYkO?ojngcon[^loo/kO?ok>gd0_o/k_@03Oo/koCojnkdon_^m?o/k_Cok>oe
onc^m_nX^]Wo[;WAojVcbOo3WhCooh<0oomd0?ooO@004oooP0001_ooO`3oogd0oon31_ooTB?oojM?
oooF[ooooooo2_ooool00?Sooooo00koj^ofojVlf_n/_]_o[KoLolG@i_oWj_?oh^OaonKYl_o/kO?o
emo/ok77h?nL^]SoT;?Cohnbd`;oTK?D1?nB/m@01onC]MGoQ:[@of2A`omER[koEh^ooej>`Ol=KZl0
0_l7K:h03?l2JJco066Xoaii]_nH`Mgo_]3UojRjfOn]_m_o/L7MonO[looinO[on?SiooSinP;onOWj
00?on?SiooWhnOoin?T01ooinOX01_ojn__oj>cboj^mfon/_]_o[[oLom7Kj`Cooooo00Goom:UoonQ
@oooR1;oogd0oomn0009oon00006oomo0?ooP03okH<Dol>=@?nSU8CoZY>=0_nZThL02OnXTHGo[I:0
olJZTOoJcL3o_<?BojZlfOnW_=coa];WooWjo01fooooo`03ookno_omoOgoo?cl00?ono_k01CocMOY
ok31g?nY_=[o[;kKoj^nfonX^m[o`LkSonc_m?oin_[on_[jooWin_ohnO[oo_gkomKQk?nL_=SoTkKE
oh>Yc_mOT<;oD8Jmoe>9_P;oEh^o00KoDHNmogjRc?n]_mco^lWQom?Lk?o_loV@ooooo`04om[Rkon_
`=cocmWZonocn0gooooo00OomOWlom7Sl?nK`mko=hRno`1SZ?l0I:[o1V^^00[o1fb^00So2fj_oef=
`?mGRkooEXZooef?`_m]V/SoJiW7ofbIa`;oK9[700[oJiW8ofjKb?mjXlcoQj[@oj>lf_o:dnSoa]3V
okG5gon]_]coZkgK0_n/_]/01?nV^MSo[KkLomSQk_odmo/7ooooo`07onCZlon``MgoZkgJojNjfOo>
enSoj>cbon_^l`02onc^m005onc_m?o]koCokNodonk_m?o^l?@00_o^l?D02oo^l?Cok_7eonkam_o^
l_WokNg^ongXh_nWZKSoZiZGojR@Poo3RUWoog`001;ooh0000Ooogl0oomm0?ooO03oohTBoonK=ooo
^WKoonoO0?oooooo3?ooool00?Sooooo013oj^ofojVlf_n/_]_o[KoLolC?iOoTj?;oh>K`on7Vl?oQ
iO3oiNSbon[[looDgN_o//SOoibjeon;/=;oS;3B1?n?/]<01onA]=CoPZS?of2A`_mER[koEh^ooej>
`Ol=KZl01?l7K:h02?l0Ij_o0fR/odj;_on8YlooVk?Eok?2g_oZk??on?Wi0oohn?T01?ohnO[onOWj
ooWin_ohn?T7ooWhn@06oo[in_oXk?;oZkgKojbnfon^_mcodM_[1_ooool01OoodZCoojQ@oon74?oo
N@3oogd000Kooh0001;oogl0onb32_oHR2coZY=aojFDT?nZThWoZY>7ojRBQonYThOo^j2:omVfT?oh
cICojl6;okZQT?nXYJooYk76olOCjOoioomfooooo`0HoogmoOolo?con_[jooWinOohn?SonOWioo_k
nooLi>oo^/WQojNkfOn[_]_o[;kKojNjfOnea=oogN;^ooKgn?olo?_ono[joo7amOnjcN?oLIk9oeZ=
`Om?Q[coEHZn0_mGRkl01_mHRkooG8g0odj6_?n6Zm7oe^3^oocmoY;ooooo00Kog^Gaojk0g?nR]]Oo
]LGOom[Rkoofn?/9ooooo`07onOamonddnOoLjcAoaUf]?l0GjOo06J[o`I[[P0<o`M/[P0@o`]^[omM
SL3oEh^ooeJ:_omNT<;oLYk9ofnLb?m^VlSoJiW6ogBPbon2Z=3oUkCEokO9hOo=enWoc]KXolWCiP;o
bM?W00Wo_/WRok;2gOn/_]_oZkgKojbnfon[_M[oXKKFolGAi_ono_l01_ooool02OoTj_?o/<7Moj^m
f_nW^]WocmSXon[^loo]l?Cok^odonk`m002onkam@0@onoamOo`lOGol?;eoo3bm_o`l_Ool?Ckoo3c
n_o`k>[oknCIonkG^?o]bI_oYX]nojZAQ?nXU8_o`hePoomn013ooh0000Ooogh0oomi0?ooO@3ooi@Z
oon/FOoodJ?ooogl0?oooooo3_ooool00?Sooooo01;oj^ofojVlf_n/_]_o[KoLol;>hooQiO3ogN;^
omkRkooNi>oognC`on3Tl?oTi_7oinWboloJjOn`b=ooV;SFohJ/d?n9[m42ohb`dP07ohjbdon0Z<ko
H972oeF:__mGRkooGXk1o`e^[`04o`M/[P0:o`I[[_lALK7o?X>koeB8__mQT<;oQjS?omKOk?okn_[o
n_WjooOhn@;on?Si0_ohnOX2ooWinPKon?Wj00KonO[konS/lon[_M[o[;kKojjog?oAfn/7ooooo`06
ooono?ood:7ook1Poon<6OooMP3oogd00_ooP0005?ooO`3onh40omn79?nbT5SoWiF;ojVCS_nZThOo
ZI>7ojF@Q_ndVHWock2>ong7U?oldiOomlnEonS2TonjWHOoYhenojRET_nf[ioom]o5MOooool05oon
o_koo?cloo[jn_ohn?Som_KfooGemOogmoOonOWioo_knooaloSoaM;VojRlf_nY_=[o[KkKojNkfOn]
_]_ocmSYonCXlOoHgnco`LgSoh>Uc_mBR;goEHZn00;oEh^o00OoFXbooen>`OmDRkoo?86iob9`/?n:
^MWonokn09?ooooo00Oog^Gaojo1g?n[_M_oZKcJojBhf?o3d>Goi^_d00Kooooo00Kocn?`oiS2gOmB
V<Ko16Z]o`1QZ?l1J:`?o`M/[P0@o`]^[omMSL3oEh^ooeJ:_omOTL;oLik9ofnLb?mlY<coT;3CojNo
g?o1c^Cod]WZom3HjOo=e^Soc=GXolgEj0;ocMKX00CocmOYol[Di_nlb^7o/<3M0_n/_]/00onZ_M[o
]lOPooknoP06ooooo`08onCZlon``MgoZkgJojNjfOo@f>[ok?3donk`m_o`lOH2oo3bmP0Aoo3am_oa
l_Kol?;foo7cnOobmOkol_;eoo7Yg_o`h<[ol=>]onk6Soo^aHkok/JBojJ@Q_nZThOoZ9B;ol>=H?oo
OP003_ooP0001_ooO03oogP0oon41oooX4CookimoooUbooooooo4Oooool00?Sooooo01_oj^ofojVl
f_n/_]_o[KoKol;>hooNhnoof^3]omcPk_oLh^gofn7^omgRk_oLh^kogN;^on7UkooRiO3obMKWojg4
g_nC]=CoPJW>ohJ/d?n;[];oOZK>oejA`_mFR[koEh^ooej>`Ol=KZl01?l7K:h03?l6Jjko4W6aod>6
_?mKS<3oDHRmoeJ;_onN^mSocMcYonK/l_olno[on_WjooOhn@?on?Si0_ohnOX5ooWinP06ooWjnooX
k??oZkgKojbnfon^_mcodM_[2_ooool06ooof[Cook1Toon84OooM03oogh0onZ44oo4SDSoYi=lojJD
T?nZThWoZY>7ojJ@Q_nYTHKoaJN<on>nTOojd9Kon<nEooG=UOogciGojL>CokZOR_nWTHKoZY:<oin<
E?oaU2gookQboooRa@1cooooo`0Eookno_olo?conOWiooKfm_oclo?ol_;booCdm?ogmoOonOWioocl
o?oko?kodmg/ojo1gOnV^]So[;kKojZmf_n[_M_o/l?NojVkf_n/_M_oQZO?00;oEh^o00WoFhc0oej>
`Om:Qkgo<Gfhob=g]Ol6KJko05fVog^aeOogn_`0Toooool00ooNiO7o[l7Loj^mf`02ojbnf`0<ojNj
fOna`Mgodmc/ooKgnoooooooloWkokCBi_mh/=Co<XFlo`1TZ_l0HZWo16Z]4Ol7K:h03?l;KZooGHg0
oeJ:_om@Q[goGY32ohZ]d_nO^MSo]/SPolgGj?oEfn[odm[Zom3IjP;od=SZ00?odMWZom7IjOoAf^X0
0_oAf^X02?oBfn[od][ZolOAiOna`Mko[;kKojZmf_njbN7oo_kn1_ooool01ooTj_?o/<7Moj^mf_nV
^]Wod][ZonoamOo`l_H00_oal_H02_obl_Kol_?foo;enoobm_gol^o]oo;Tdoobf[[ol<nPoo36S_o`
ahl3oo39U005ojJ@Q_nZThOoZ9B;ol>=H?ooOP002oooP0001oooO`3oogT0oomh0?ooT2;ook9Vooo@
X?oolnH0oooooolCooooo`00n?ooool02?oZkoKoZKcJojbnfon]_]_o_lcSom[QkOoGg^cofMo]0_oH
gn`2omWPk@;of^3]00gofn7^omkSkooLh^koamCWojk4g_n>/=?oOjO=ogRRbomNT<;oEXZooeN;_omN
S/7o3Fj_00Co1fb^00oo1V^^oa9a/Om3Q[coFhc0oeF:__mLS/;oSK7Boifmeon^amkob=SWonS]loon
o?_onOWiooKgn?ogn?P01_ohn?T01oogn?WonOWjonS[l_n[_M_o[;kKojjog?oAfn/02oooool03_oo
o_coomjioofkMoo<Sd7o/h]Poj:DRonYThcoZY>7ojVBQonSSXKo^Yn:om^hTOocbiGon]6F0oogcYH0
2oogd9KojL>DokZOR_nWTHKoZY>>oj6CH_oaO`?oogT0oonB9?oo]F_oonC:077ooooo00ooo_knoo_k
noohn?Som?Cdoo3`l?o^k^kol?3`ooCdm?ohn?Soo?clookno_ooooooi>[dokW8hOnU^=P00_n/_]/0
3onZ_M[o[;kKojnog?n4YLkoGhk1oej>`OlnQ;[o8gJdoaIc/_l1Jjgo0VZ]o`I/[_l0HJSoOK;EooOj
o02Cooooo`03omkUlOn_`McoZkgK00?o[;kK00Wo[[oLojnog?nda^7oYl?NoefMbOl@M;;o06BZo`1V
Zol6Jjh04ol7K:h02ol4JZgoEhVnoeF:_ombVlSoUk?EolKCi_oCf^[oe]g[om?KjooCfn[odm_[00Wo
e=cZ00Ooe]g[om?Jj_neaMooZkgKojZmf_njbN7oo_kn00Kooooo017oi>[cok31gOn[_M[oY[[Iom;K
joo_lOKol_;foo;cm_oam?Sol_Kmoo?goOocj]gol]k2oo;C[?obbiKolLN?oo;:T`02oo;;U@?ol/ZE
00GoYY26ojZCQonXU8_o`hePoomn0009oon00007oomm0?ooMP3oogd0oonRAooobI?oon?8ooonoP3o
oooooaGooooo003hooooo`0<on[_m_nY_=[o[;kKojfofonmb^;oemk[omCLj_oDg>_oeMc[omGMjooF
gNcoe]k/0_oGg^`2omKNk00;omSOk?oJh>goe]g/olKDi_n^a=goOJG=oeN;_omDRKkoEh^ooej>`Ol=
KZl01?l7K:h04Ol6Jjko4W6aod>6_?mKS<3oEHZnoef?`On?/]?oWkkIoibleonN_MSo/<SOolOHiooZ
k_CooockooShnOofm_Som_Oh00ComoOh00Oom_OhooOhnOoVj_;oZkgKojbnfon^_mcodM_[00cooooo
00col?Wool?Ah_nW]<;oZ:B_oj^CROnZSgooXhj4oj^DR?o>[hkojlBCoo[@UoohciH4ooO>UP0=ooW@
U_oZ`iCo^Yn:ojNAQ_nZThkoXI=Roo632oooP03oogd0ooml0?ooU2Wook9UoooM^P1_ooooo`0;ookn
o_okno_om_Kfoo;bl_o]kNgojn_[ong]kOoalO7om_Kfoo[jn_ono_h00_ooool03Ooam?Woc=KYojVk
fOnZ_=[oZkgJojJif?n]_]_oVkCFobUk]_lPM[Co3g2`o`5Y[Ol4Jjd00ol7K:h00ol0HJSoOK;EooOj
o02Cooooo`0>omkUlOn_`McoZkgKojfofona`=go/L7MoiRbeOmiWl[oII;4oeJ:_om0P;So9WRdo`5[
[Ol0JJ`Ao`M/[P0<o`I/[_l0Ij_o05fVob9k]_n0X/_oU[7Doj>if?nlb^7ofn7]omCMjooEgN_oe]g/
0_oFg^`01?oGg^cof=k/omSNk?oGgn`5omSOk007omWPk?oEg>_o]/KOoj^mfonZ_M[o^/WQooknoP06
ooooo`0?onCZlon``MgoZkgJojJjfOoBfn[oko;eoo;en_ocmoooloCdoo?Td?obf;?ol]2Poo?:U?ob
bI3ollZD00Ooll^E00GoYY26ojZCQonXU8_o`hePoomn0007oon00006oomk0?ooM@3oohPAooniLooo
f[Gooo3QoooooolHooooo`00n?ooool02ooZkoKoZKcJojbnfon]_m_o_<[Rom?Jj_oAf>WodM[Yom7J
j_oBf^[odm[Z00?odm_Z00goe=cZom?KjOoCfnWodmcZomCLj_oFgN[odmcZok_;h_n8Z=3oFHc0oe68
_OmMSL7o3Fj_00Co1fb^00Oo1V^^oa9a/Om3Q[coFhc0oeF:__mLS/7oS[7B00?oW[gH00OoW;cGoj2o
f?n^b=gob=SWonkamOooo?_omoOi00GomOKh00Kom_OionKYl_n[_M_o[;kKojjog?oAfn/:ooooo`0<
ookno_oBfn_o]/KPojZmg?n/_moo[;cHojVcb?nTWjKo`Z>8onBlS?oec9Gon<nF1_ogcYH01oojd9Oo
jL>CokVNR_nWTHKoZY>>oj6CH_oaP`/00oooP0001OooO@3oogh0oon<7OooZE;oon3106gooooo00_o
o_knoo[jn_ofm_Kol?3`on_[jooXj>SojNWYonk^k_oclo?onOWioogmo@03ooooo`0:oo[koOoLhnoo
Z[gJojjofoo;e^WokO3goiVog?l7K:ko16^]o`I[[PGo1fb^00?o066XogfbeOogn_`0Toooool04?oN
iO7o/L;Mok?2gOn/_]coUk?FogRPbomQTL?oEHZnoeB9__mFR[ooFXbooeF:_om9Q[co97Rdo`1Z[?l5
Jjh<o`M/[P0=o`Q/[_l5Jjgo06>Yo`1QZ?l_Q;_oXLSQom7Sl?nT^=Oo/<7Loj^nf_njbN7og>7_omSO
k002omWOk@03omWPkOoJh>gof^3]00;of^3]1_oKhNh01ooLh^kof=k/okO6gon[_M_oZ[gJok[9hOon
o_h01_ooool03OoTj_?o/<7Moj^mf_nV^]Wodmg^oo;hooock^Golmo3oo?DZ?occY_ollVAoo?:Tooc
biD02Oodc9D01OnVT8KoZY>7ojRDRoo3SF3oogh000Cooh0000Ooogl0oomh0?ooMP3ooiPbooo<V?oo
ilkooo[d0?oooooo6_ooool00?Sooooo00_oj^ofojVlf_n/_]_o[KkKok[8hOo?f>Soc=GWolgFioo=
enSoc]OXoloHj003oloHj@?od=SY0_o@fNT02Oo@f>Wodm[[ol[Dion_`McoXKOGoh:TcOmPSl7o0FR[
o`E[[@03o`M/[P09o`I[[_lBLK7o@hJloe^<`?mER[koG8k1ohjad_nM_=SoW;cG00;oWKcH00SoW[cH
oifmf?nP_]WoZ/GLolCFi_o_lOGoo?[jooGfn0;om?Gh00Oom?GgooGfmooUj?7oZkgKojbnfon^_mco
dM_[00Wooooo00CohNObok_:hon^_mcoZkgJ0_n/_]/02?nW^][o]LCOomoSk?oeknOonN6nooO=T_og
c97omljE1OogcYH01oojd9OojL>CokVNR_nWTHKoZY>>oj6CH_oaP`/01OooP0001OooOP3oogl0oon8
5_ooXdSoon?706_ooooo00coo_knoo[jn_oemOGokno_onSXj?oUiNGoi^KVon[Zj_oalO7omoOgoocl
o?ono_h3ooooo`06oogno_ocm_[om?Kjoo[koOooooooU;oK2?l7K:h00ol0HJSoOK;EooOjo02Coooo
o`04ong^m_nW_=[oNj3<of>B``;oJ9O600?oIIG6oeb=`OmER[l00omGRkl01OmJS<3oEXZoocN1^Ol9
KZoo0fZ]00Wo1fb^01;o26b^o`=Z[Ol0HJSo16Z]of>Rc?o0f^_oi?3gooknooooo_koY[WHojbnfonZ
_M[o^lWQomoTkooJhNkog>;^omcQk_oLh^l2omgSk`03omkRk_oNhnkog^?_00Gog^C_00OognC`om_P
kOnhamooZkgKojZmf_njbN7oo_kn00Kooooo00[oi>[cok32g_n[`>7oYK_Nom;>c?o`eJkollnOoo?<
UoocbY?om<bD0_odc9D2ooG<U@SomLfE00GoYY26ojZCQonXU8_o`hePoomn0002oon00007oomn0?oo
M@3ooh00oonbIOooh<3ooo?Vooono03ooooooacooooo003hooooo`07on[_m_nY_=[o[;kKojfnfonh
an3obMGWolWBiP02olWCi`03ol_Dioo;eNOobmCW00;oc=GW0_o;e>L03Oo<e>Ooc=GWolcEioo>e^So
b=;VokC4gon/_]_o[KkKojNjf?o4dNKoNZoCo`Q][_l0Ij/00_l7K:h02Ol6Jjko4W6aod>6_?mKS<3o
EHZnoeb>`On=/M;oW;cGoibkf003oibke`0@oibleonM_=SoWKcHoinmfOnV`]coaMKVonoamOoimoWo
m?Ggoo;dm_ocmOKoi>O`oj^mfon/_]_o[[oLom7Kj`Sooooo00?olOCiok72g_n/_]/00_n/_]/02onZ
_=[o[;kKom3HjOobloOon?Wjoo[in_oim_KonO?ZooSN^Oohd9Kon<fC00Con<nF00Oonm6Gon[4Toni
WX[oYi66ojZCS_nQTf;olH<;00Oooh0000Googl0oon10OooQ17ooj95oooXd01Yooooo`05ookno_oj
n_[om?Cdong]kOoVi^H00_oRh^801OoWinOok^k^ooGemOojn_[oo_kn00Sooooo00?oU;oKo`M/[_l7
K:h01_l7K:h00ol0HJSoOK;EooOjo02Booooo`06okkKj_m_XLcoGho1oeV<`?mER[koHY?40_mZV<L0
0omYUlOoHI?3oeJ:_P03oeN;_`06oeR;_omFRkooEhZoobAi]Ol3Jjko1Vb^1_l7K:h01ol2JJco05nW
oaai]On7^=SofnWcoo?hnoonool00_ooool02?oko?goY[WHojbnfonZ_=[o_<[Ron;WlOoNi>oognC_
0_oPiO02on7Ul004on7VlOoRio7oh^Oaon7Vl0Coh^K`00OohNO`omgSkonhan3oZkgJojZmf_njbN7o
o_kn00Kooooo00OoiO3ook6ne_nYYZooY9BBomBdToobbYGoll^D00;om<bE00?omLbEooG=UOoecID0
0_oecID7ooK=U@0<ooG=UOnVT8KoZY>7ojRDRoo3SF3oogh0ooml0?ooN03ooi0Pooo8T_ool>3oooWd
oooooolOooooo`00n?ooool01ooZkoKoZKcJojbnfon/_]_o]/GOolC@i_o4cnD00_o4d>D01Oo5dNGo
a]7UolKAiOo6dNGoa];V00?oam;V00Cob=;VolOBiOnkb>;o[KoL0on/_]/04?nX^mWobMGXooSjo?oW
lOOoLj_@o`AZ[Ol2JJgo1V^^oa9a/Om3Q[coFhc0oeF:__mLSL7oRk3Boi^kf?nK^]L2oi^ke`;oW;_H
1?nL^mL02onL^mSoXkoIolGFi_o^l?GomOCgoo?cmooRio3oZkgKojbnfon^_mcodM_[00Sooooo00_o
ko?hojfog?n/_]_o[;kKoj^mfonmbN;okNoeooWjn_oinO[on?SiooWhn@02ooWinP05oo[in?ojm_7o
nN;1ooS?UOohcY@00_ohciH01ookdIOoj/BCokZNR_nWTHKoZY>>oj6CH_oaP`/02_ooP0001?ooP@;o
oh09oonTB?ooj]AWooooo`05ookno_ojn_[om?Cdonc/k?oTi>@00_oOgml01OoShn?ojn_[oo?clooi
nOWooOgm00Sooooo00?oU;oKo`M/[_l7K:h01_l7K:h00ol0HJSoOK;EooOjo02?ooooo`09ooWloOnC
`=go;8:jo`Q[[_lgOkWoG8g0oeN;_omFR[koHi?400CoJYS700?oIiK6oeb?`_mGRkl00omGRkl01OmH
RkooEHZooeZ<`?l<KZoo1F^^00?o1fb^00Ko0VR]o`9Y[?m1Sl7o^mOXooGio?oko?h5ooooo`09oo_l
oOnV^MSo[;kKojZlf_nmbn;oinWbon;VlOoRi_3oh^Oa00?ohnOa0ooTj?45onGXl@07onOYl_oPiNoo
^<OPoj^mf_nZ_M[o^/WQooknoP05ooooo`09oooP^_oJYfcoYIB0ojZDR_nTSXKoe;:?oo;:UOodc9Go
mLbE00?omLfE0_ofcID2ooK>UPGomljF0_ofcYH02OnVT8KoZY>7ojRDRoo3RU[oogh0oonXDooohlKo
oo[eooomn`3oooooob7ooooo003hooooo`0;on[_m_nY_=[o[;kKojfnfonea=oo`<gToko<hoo0c>?o
`<cTol7>i?o2c^@00oo2c^D2ol?>i@04ol??iOnnc>Co[/3Loj^mf`?o[;kK00Co[;gJok30gOoUk?Go
o_ko0_ooool02OoYl_SoKJS?o`]_/?lBLK7o@hJloe^<`?mER[koG8k1ohZ^d@03oiVieP;oV[[G00?o
Vk[Goi^keonK^mL00onK^mL02_nL^mSoV[WHoijlf?o3eNKokO3eon7Ul?n[_M_o[;kKojjog?oAfn/8
ooooo`06onocn?n]_mco[;kKojfofoo5d>Gon__j0_oinOX01?ohnO[on?SiooWin_oinOX3oo[jnP0<
oo[jnoojmo?onN6oooSAV?ohciKonm6Gon[4TonjWX[oYi66ojZCS_nQTf;olH<;3?ooP0001OooO`3o
ogX0oonUB_ooj]Gooogk06Cooooo00coo_knooWinOoclo?ojn_[on?ShooMgMgog=cLon3Ph?oWinOo
kNKJooKdkOolo?`8ooooo`03oiBofol7K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`0Roooool03Oon
o_oon_cnoloRkomVY<co3W2`o`5X[?l6K:ko06V/ocEn^?mLSL3oEh^ooeJ:__mSTl@01_mZV<L00omS
U<GoFHc0oeJ;_`04oeN;_`07oeb=`?lcPKSo26f^o`Y^[olHMK?oM:gBomOXl`09ooooo`0<oo_loOnV
^MSo[;kKojZlf_nnbn;ojN_con?XlOoUj?7oiNWaonGYl_oVjO;oi^[b2?oWj_800ooYjo?oh^K`okW8
h002ojZmfP0>ok[9hOono_koooonooomnooomN_ookekoon>7?ooN@3oehL]oj>DP_nZThWoY8j6omBb
SoocbiD3ooG=U@;om/fE00?om/jFooO>U_ogcYH02?ogcYH01OnVT8KoZYB8ojRGToo4^;Kooo[[0?oo
oooo9Oooool00?Sooooo00Koj^ofojVlf_n/_]_o[KkKokG4goo1cN@8oko<h`04okk<honlbn;o/l?N
oj^lfPGo[;kK00?obMGXoocmo_ooool01Oooool02OoVlOOoKjS?odR8__mJRkooEHZnoe^>`On9[]7o
V;SEoiNheP03oiRheP?oVKWF0_nI^]L4oiZje`07oiJge_nN_=So^<_QojJkfOnZ_M[o[koLom7Kj`08
ooooo`0:onocn?n]_mco[;kKojfofoo9e>Koo_glooSin_oinO[on?WjooShn@;onOWj1?ojn_X02ooj
n__on_cnoo[glOoih;gon]BKon[4U?njWXWoYi66ojZCS_nQTf;olH<;00kooh0000Koogh0oomi0?oo
ZU?ooncIoooim?ooo_eQooooo`0=oogmoOoinOWolo?con[Zj_oQhN7ofm_KomWIfOoMgMgoi>CTon?B
]Oo`iL7ono_kooknoP07ooooo`03oiBofol7K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`0Loooool0
0oono_ooooooooooo`0Cooooo`07ooWloOo_m_[o/m7Vod^Ea?l0HJSo0FV/o`I/[P02o`M/[P06o`1Y
[?leO[SoG8g0oeN;_omFR[koHi?42?mZV<L02_mPTL?oF8booeN;_omGRkooEX^ooeR;_omMS/7oJIK6
oj75gooio?d;ooooo`06oo_loOnV^MSo[;kKojZlf_noc>?ojnkd0_oWj_801?oWjo;oj>_bonS[l_oY
jo88onW/l`0;on_]m?oTj?7o^/SQojZmf_nZ_M_o^LSOookglOooi<WoojQ@oomj0?ooN`000_ooO`00
1_oGR2koXiB2ojZCROnTSXKoe;:?oo?<U@;omLfE00?om/fEooK>U_ogcYH02OogcYH01_ogciSomm6L
ojJLX?n[/lSoZ[gMolCCjOoooooo9_ooool00?Sooooo00Koj^ofojVlf_n/_]_o[KkKokG4goo1cN@7
oko<h`04okk;h_nha^3o[;kLoj^mf`;o[;kK00CoZkgKojfofonlbN;oj^kf2_ooool01oo8eNSoL9W7
oeb>`OmLSl7oQjcAoiFgeOnE]]D00onF]mD00onG^=KoV;SFoiRheP08oiRheP05ohB[d?mJS<3oQZO?
ojRkf_o?f^X02?ooool02_o_loSo[KoLojbnfon]_m_obMCVookmnoohn?WonOWjooSin_ohn?T2ooWi
nPKon_[j00Won__koo[looolmnoojmBhokZRTOnWTXOoZY>=oj6CH_oaP`/04?ooP0001OooO03oogX0
oonVCOoogK[oooK]063ooooo00gooOgmooWinOoclo?oj^[Zon3Ph?oIfMWoemOGom[Jf_oQhN7ohLjX
onW>S?oinOWooOgm00Oooooo00?oU;oKo`M/[_l7K:h01_l7K:h00ol0HJSoOK;EooOjo01booooo`03
oo_loOoQjO;on__m01;ooooo00OolOOkomo]mOn:^]Wo67Ndo`1SZOl0J:co26b^00Co1fb^00Ko06V/
ocEn^?mLSL3oEh^ooeJ:__mSTl@8ofZHa`0;ofbJb?mWU/KoG8o2oeZ=`?mMSl7oLI[8oi>^donc`mgo
]LCOomcSkoohnO`02_ooool01_oko?goY[WHojbnfonY_=[o_lgSonk`m0;ojNcc00Goj^gconW]looZ
kO?oj^gcon_]l`02on_]m0Gojnkd00WokNoeonK[lonjbN7oZ[_Foj^jeOn_/kGooI@[oomf0?ooO000
0oooP0002_ooO`3oehP^oj>DP_nZThWoY8j6omBbSoocc9GomLfEooK=UOofcYH7ooO>UP0:ooO>UOog
cYKomm6KooOEY?ohh/;onOK_ojRngon/_mgoZ[cJolCAi_oooooo9_ooool00?Sooooo00Koj^ofojVl
f_n/_]_o[KkKokG4goo1cN@4oko<h`05ol3=honnbn?o^lWQok72gOn[_MX00_n/_]/01?n[_M[oZkkK
okW9hOoIhNl;ooooo`0:oocmo_oBfn_o[[kKoinfeommX/coTK?DoiBeeOnB]MCoU;GEoiFfe@;oU;KE
0_nE]]D7oiJge@08oiNheOn8[]7oEHVooe:7_OmNS/7oVKSHomKWl_oloOh6ooooo`0;onocn?n]_mco
[;kKojfofoo9dnKoo_gkooShnOohnO[onOWjooShnOoin?T00_oinOX7oo[jnP08oogmoOo/l_co^lGI
ojRRZOnZVI[oXI=Roo601_ooO`0Aoon00005oomj0?ooN@3ooj54oooJ/ooolnH0G_ooool03OomoOgo
nOWioo;bl_oYjNWogmoOomOGeooEeMGoemOGomgMgOoE_Yoogk5CooSgm?olo?`01oooool00onD_m_o
1fb^o`M/[P06o`M/[P03o`1QZ?mm/]Gomo[l07;ooooo00GoloGjoindeOo7d^Kol??ioognoP0>oooo
o`06omo/mOnieNSoGj3;o`Q/[_l0HZWo0fV]1ol7K:h01_l0JJco=Gjhoeb=`?mGRkooEXZnof>Ca0;o
JiW700?oK9W7ofbJaom]VlL00_m^VlP03_m/V/SoKI_8ogJPbon1YlkoRjcAojZmg?nc`]ko[l3Lojbn
fon[_M_oYk[Iok[9h_oUk?ConO_m2?ooool02_oko?goY[WHojbnfonY_=[o`<gSoo7bm_oYk_?ok>kd
on_^m?o/ko@2ong_m003onk_m?o^l?Cok_3d00;ok_3d00[ok_3eonkamOo^lOSoko3donSWionj_/co
ZJ:XojZBR_nSSf_ooGd01OooP0002OooO`3oehP^oj>DP_nZThWoY8j6omFcSoodc9Gom/fEooK>UP05
ooO>UP0=ooO>UOohcY?on=2HooSEY?oig[OonNcIoo[jnoojoOoonO[lojRkfOn/_]_oZ[cJolCAiP3o
ooooobKooooo003hooooo`06on[_m_nY_=[o[;kKojfnfonea=oo`LgT0onoc><02oo0cN?o_<[RokG5
gon/_M_oZkgKojbnfon[_M_oZKcJok;2gOo<enWom?Ok00cooooo00[oo?gnoloJj_nV^MSo[[oLokS6
h?o;enSo]<WQoijkf?n@/]?oT;?D0_nB]=D00onC]=GoTkKEoiBee@06oiBee@09oiFfeOn6[=3oEXZo
oeN;_omFR[ko>WfgoaMg]OnB_m_odnGa00Gooooo00[oko?hojfog?n/_]_o[KoKolWCi_onoO_on?Si
ooSin_oinO[on?Si0_oin?T2ooWinPKon_[j00[ooOckonc_m?nkb^?oZL3SojZfe?n^[ISom9Leoon1
0_ooO03oogl04?ooP0001_ooO`3oogP0oomj0?ooY4coomJ^ooobiEcooooo00kooOgmooWinOobl_;o
jNWYomgMgOoFe]Kodm?ComCDe?oJf][ockNIomJI<_odkMCono_kooknoPKooooo00?oU;oKo`M/[_l7
K:h01_l7K:h00ol0HJSoOK;EooOjo01booooo`06ooCfn_nT]mOoYk_Iok72g_oJh^oom?Kj2_ooool0
1oogn_coc>7_oi[3g_lgR;ko066Xo`1SZ?l4JZd02Ol7K:h01_l0JJco=Gjhoeb=`?mGRkooEHZnofFE
a0;oKic800koL9c8og6MbOmaWLWoKYc8og2MbOmmY<goS:kBoj[0g?o8d^Kod]WYolSBi_nian7o/<3L
oj^mfP;o[;kK00?oZ;_JojRkfOoIh^l02?ooool02Ooko?goY[WHojbnfonY_=[o`LkSoo?dmoo/koCo
k^odonk`m002onk`m@;oko7e0_o`l_D03?o`l_Kol?;ioo3cn_o`ko;oknWSoo3PbooYbjKo^Yb5ojR?
POnZThWoY9=coof00PGooh0000Soogl0omN8;_nSU8;oZY>9ojB>Q_oE/hoom<bEooK>UP?omljF00[o
mljEooO=ToogcI?on=>NooWI[Ooii<KonOG^oo[mooojo?oon__k0_ojn_X01?nW^mWo[;kKojZlf_o4
dNKoooooobKooooo003hooooo`0<on[_m_nY_=[o[;kKojfnfonea=oo`LgToko<hoo0cN?o_/_SokS8
hOn^`=coZkgJ0_n/_]/01?nZ_=[o[KoLol?AiOoSj?<>ooooo`0=oocmo_o?f^[oY[WHoj^mf_n``=go
f]o^on_]looBg>_o/lSOoi^jeon</=;oS[7Coi2ce003oi6ce0GoT[?D00_oT[CDohBZc_mFR[ooEh^o
oeR;_om5Q;_o06BZo`1PYolYP;WoSkgKom3Sl003ooooo`06onocn?n]_mco[;kKojfofoo9dnKooOgk
0_ohn?T00oohnO[onOWjooShn@02ooWhn@OonOWj00coo?_kon_^m?nkbN3oZKcJojNlg?o8f_Kon^SG
oonnOOooW3Soogd0oomk0?ooO`0@oon00006oomo0?ooM`3oog/0oonUC_ooe:WoooCXF_ooool03_om
oOgon?Shoo7alOoXj>SogMgMomCDe?oAdM7od];BomOGeooF_iGocH/_onkJWOojn_[ooOgm1_ooool0
0onD_m_o1fb^o`M/[P06o`M/[P03o`1QZ?mm/]Gomo[l07;ooooo00Som?KjojBgeon/_]_oZKcJojNj
fOnnc>?ohnWcoocmoPKooooo00Ooh>ceok?Bi_md[M;o77Reo`1MY_l0IJ_o1V^^00_o1fb^01Oo06V/
ocEn^?mLSL3oEh^ooeF:__mXU/GoM9k9ogBOb_mcW/WoLYk9ogNQbon9[=7oW;SGokW:hOo@enWodmWZ
olkFj?o=e^SocMOXolkHjOo4cnCo]/KOojfnf`02ojbnf`03ojNjf?o;e^Sooooo00Oooooo00Wonocm
ojJif?n/_]_oZKcJol7>hooemOOok_3eonoamOo`l_D00_o`lOH04?oal_Kol?;foo7cmooam?[ol_Cj
oo7]j?oaiMKol=Vlono:VOo_a8[oj/:?okZOROnXTXOoZY>:ojBCLoomP085oon0000Boomo0?oGR2ko
XiB2ojZCROnTSXKoeK>?ooC<UOofcYKomljFooO=U?ogc9;omljDooOFYoohgkconNcFoo[inOojo_oo
n__m1Oojn_X01?nW^mWo[;kKojZlf_o4dNKoooooobKooooo003hooooo`09on[_m_nY_=[o[;kKojfn
fonea=oo`/kToko<honian7o//;N00;oZkkK00Ko[;kKoj^mf_nV^MSo^LSQom[Rl?oko?d?ooooo`0>
oocmo_o?f^[oY[WHoj^mf_n``=coeM_/on7Ul?oTj?7oinWbolkJjOncb=ooV[WGohN]d?n;[m82ohjb
d`GoSk;C01GoSk?Coh6Yc_mFR[ooEh^ooeR;_om5Q;_o06V/o`M/[_l0IZ_o066Xob^1^_n2]]OocN;_
ooooooofmo[o[KoLojbnfon]_mcobM;Voocknoofn?T00_ohn?T01?ohnO[onOWjooSin_ohnOX3ooWh
n@Con?Si00_oo?[jon_]lonkbN7oZKcJojNjfOo6d^KonOkoooooooool>;ool>7oonK>@02oomj017o
oh0000Koogl0oomg0?ooOP3oojA=ooo>W?oom^eHooooo`06oogmoOohn?SolO7aonOWiooLg=coe=CD
0_o?cll01_oDe=CocK69olb8;_oXaVSon?Sgooclo0Kooooo00?oU;oKo`M/[_l7K:h01_l7K:h00ol0
HJSoOK;EooOjo01booooo`03ooCfn_nT]mOo[;kK00;o[;kK00CoY[[Iojfofoo<enWoj^of0oooool0
1_o>hNooTkoLod>?`_l6K:ko05jWo`5X[0ko1fb^013o06V/ocEn^?mLSL3oEh^ooeF9__mZV<KoMIo:
og:ObOn1Z<ooUkGFojo4gOo8dnKof=g/omCKjooBfN[od=SY0oo@f^X02?oAf^[od]_Zom3IjOo1c^?o
Z[cKojbnfonX^mWocMSY2?ooool01_oko?goY[WHojbnfonY_=[o`/kSooOgn@;ol?;f01?olO;foo;b
m_obl_KolOCioo;foOobl_Gol^SMoo;Na_oadj[ol<VCoo35S?o`b9;ol/VDonc4TonjWh[oZ9:7ojZC
R_nTTg?ooH0200Gooh00013oogl0omN8;_nSU8;oZY>9ojB>Q_oF]8oom<bEooK=Toogbhoomm2KooOJ
/_ohi/gonO;YooWlooojoOoon__l1oojn_X01?nW^mWo[;kKojZlf_o4dNKoooooobKooooo003hoooo
o`09on[_m_nY_=[o[;kKojfnfonfaMoo_/cSokC4gon]_]coZkgJ00;o[;kK00CoYk[Iojjog?o<enWo
k?3g4Oooool04OoloOkocm[ZojJif?n[_M_o[l3Mom;Kj_oNhnkogN;^omkSkooRio3oh^Kaol_Gj?n`
amkoU;GDohB[con9[m7oS;3A00CoRk3A00OoSK7Aoh2XcomFR[ooEh^ooeR;_om5Q;_o06V/00?o1fb^
00go06J[o`1SZOlaQKcoO;;EomKPk_nd`mko[l3Lojfog?o9d^Koo?_jooKfn?ogmoSomoSh00;on?Si
00?on?WjooWin_ohnOX00_ohnOX4ooWinP07oo[knoo[kOCo^lWPojVlf_nW^]Woa];VooWjo003oooo
o`05ooo[f?ooaH[ooiPcoomg0?ooNP004OooP0001_ooO`3oogL0oon10oooYdkoolnOooojmEKooooo
00ooo?clooShn?o`l?3oinOWom_KfooCdm?oc/k>olg=cOoBd];o`J1lolb7<?oR/Cgom>oMoo_knoon
o_h01Oooool00onD_m_o1fb^o`M/[P06o`M/[P03o`1QZ?mm/]Gomo[l07;ooooo00?om?KjojBgeon/
_]/00on/_]/02onZ_M[oZ;[Iokg:h_oFg^go_MGXofNWcolcQKco06N/o`1TZ_l4JZgo26b^00oo1fb^
00co06V/ocEn^?mLSL3oEXZooe27_OmVU/GoRjkBoj>lf_nkbn;oc]OYom[OkOoEg>/9omCLjP06omGL
j_oCg>[oZ;_JojbnfonX^mWocMSY2?ooool01_oko?goY[WHojbnfonY_=[o`loTooShn@;ol_;f00[o
lO?goo;enoobmokolo7]oo;ScooafKSollnPoo77SOoab97ol/ZD0_obbiD01oodbiGok/JDok^PR_nX
TXOoZY>:ojBCLoomP0801OooP0003_ooO`3oehP^oj>DP_nZThWoY8j5om>_R_ohc8kon=FTooSQ`Ooi
jm[on?C`ooWloooinokonOWj2Oojn_X01?nW^mWo[;kKojZlf_o4dNKoooooobKooooo003hooooo`06
on[_m_nY_=[o[;kKojbnfon``=go/L;M0on/_]/01OnY_=[oY;SHoko=hooTj_?oo?gn01;ooooo00So
o?gnoloJj_nV^MSoZkgKojo0g?o@fNWofn7]om[PkP;ofn7]00Sog>7^on3TkooMh^kob=GVok36g_n?
/M?oP:W>ohJ/d0?oR:g@00OoRJk@ogjVcOmFR[ooEh^ooeR;_om5Q;_o06V/00Co1fb^00Wo1Vb^o`1V
Zol0I:[oEIG4ognSc?nO]]Oo]lCNol_DiooknoX00_ofm_P00oofmoSomoOhooShn@09ooShn@07oo_j
n_o[kO?o^lWQojVlf_nW^]Woa];VooWjo005ooooo`05oooYdoooahkooiH_oomf0?ooN`004OooP000
1_ooOP3oogT0oon52oooYT_ool>8ooofkECooooo00ooo?clooOgmoo`l?3oi^KVom_KfooBd];oc<c<
ol_;boo?clooaJAdolMn;OoPZC?ok]fXooWinOomoOd01Oooool00onD_m_o1fb^o`M/[P06o`M/[P03
o`1QZ?mm/]Gomo[l07;ooooo00?om?KjojBgeon/_]/00_n/_]/02_n_`=co]<?NojFkfOn5Y/koLY[7
oebA`_l/MkGo06N[o`1Y[?l8K:hAo`M/[P0<o`1Y[?lbO;OoE8RmoeJ;_omZULGoXK[IolCBiOoFg>_o
f]o/omONk?oEg^coe]k/0_oGg^`00ooGgncof=o/omSOk005omSOk005omCLjonX^mWo[;kKojRkfOo=
f>T02?ooool03ooko?goY[WHojbnfonY_=[o`loTooWhnOobm?SoloOooo?go?ocj]ool]k2oo;F[Ooc
biOol/R?oo;9TP02oo?:U@?oll^E00OomLbEono7U?nkX8[oZ9:7ojZCR_nTTg?ooH0200Gooh0000_o
ogl0omN8;_nSTh3oZXn1ojRAQ_neYIkoe/c3oo[ahoolo?conO_oooSin`02ooWhn@03ooWin_oin_[o
n_[j00Kon_[j00GonOWjojRkfOn/_]_oZ[cJolCAiP3oooooobKooooo003hooooo`03on[_m_nY_=[o
[;kK00;o[;kK00OoZkgKojbnfon[_M_oY;OGok?3g_oJh_3omOOk01Cooooo00Koo?gnoloJj_nV^MSo
ZkgKojjog?o=e^P2omONk0?of=o/017ofN3]om[PkOoMhNkofN3]ol[Fion_a]ooRZkBogjWcOn4Z/oo
QJ_?ohJ/comlYLgoEXZooeN;_omHRkooAHBko`1Y[006o`M/[P08o`9Y[OlSNKGoEHZoofFCa?moXlco
_/cSooooo_ofmoT2ooGfn004ooKfn?ofmoSomoOhooOgn0?omoSi1?ohn?T01oojn_[oj^gcok_9hOnY
_=[oYk[IolKBi_oin_`01oooool01Oook=SoolfKoonD:OooM@3oog`0017ooh0000Koogh0oomk0?oo
PPCooi/foonoO_oonO@Aooooo`03oookn?oogkgoooon03Oooooo1oono_h04?olo?com_Kfono_kooU
iNGof][Jom7AdOo;bl_ob/[:olg=cOo2WV_oa7X/omZN<OoXbW;omoOgooclo?ono_h4ooooo`03oiBo
fol7K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`0L_ooool04?odm_[oY;OGojfofonb`Mgo^<KPojJl
f_mhWl[oII?4oeV=`?mCR;koEHVnoeb=`?m2Q;_o:W^go`1WZol5Jjd>o`M/[P0:o`I[[_l0IJ_o05fV
ocR0^On5YLkoU[7Doinfeoo:dnOofN3]omSPk@;ofMo]00CofN3]om[PkOoJh>gof^3]2?oKhNh01OoG
gNgoZ;_IojbnfonX^mWocMSY00Sooooo00gonocmojJif?n/_]_oZKcJol?AioojoOoolo?boo?Tc_oc
f;;olm2Poo?:U?ocbI;oll^D00Oom<bE00Oom/fEoo37U?nlX8[oZ9:7ojZCR_nTTg?ooH0200Cooh00
00koogl0oomi0?oDOQcoWY>5ojZV/_n//lGoZKOAok31h?o1cnKohnSaoooooOojn_[onOSjooShn@;o
nOSi2?oinOX01?nX^mWo[;kKojZlf_o4dNKoooooobKooooo003hooooo`03on[_m_nY_=[o[;kK00?o
[;kK00GoZ;_IojZmf_o<enSoko;hookno`0Eooooo`0<oocmo_o?f^[oY[WHoj^mfon__mcobmCWomCL
j_oCg>[oe=c[omGLjooEgN_oe]g/0_oFg^`03_oGg^cof=o/omGLjoo:e^Oo[L;MohBZd?mlYLcoPJW>
ogVRc?mFRkooEh^ooeR;_om5Q;_o06V/1_l7K:h02_l3JZgo:WfgoeJ;_omER[koFHg0oh6Wc_o:f^So
k_3eoogknoofm_T2ooGfn0Gom_Kh1?ogm_P01oohn?WojNccok_9hOnY_=[oYk[IolKBi_oin_`02Ooo
ool01OookM_oolnOoon?8?ooM`3oog`0017ooh0000Koogl0oomm0?ooP`SooiL`ooo0POooo?X>oooo
o`04oooYdoooXTGooh@LoooJ]CKooooo0_ono_h05_omoOgoo?clooclo?omoOgoo_knoogmoOokno_o
m_Kfonk^k_oTi>CofMWIom3@d?o:b/[ob<S8ol[:b_ngS5koaX0^olf<;_oU^4?olnoSooWinOomoOd4
ooooo`03oiBofol7K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`09?ooool5ooknoTWooooo00Won?Sk
ojVjfOn[_M_oRJW@ogJNbomeWl[oIIG4oeZ=`?mFR[h00omGRkl01OmJS;ooDhZoocj2^_l?LK7o06R/
00_o1fb^00Ko1V^^o`1SZOl0HjWo>XZooj?:h_nnd^H2ojjog004ojZlf_o9dnKofN3]om_QkP;og>7^
00Cog>;^omgRk_oMh^kog^;^2?oNhnl01OoJh>goYk[IojbnfonX^mWocMSY00Sooooo00[onocmojJi
fOn/`=ooZKkPol;7doojhKkol]:Voo?>V_ocbY?om<^C0_odc9D00ooec9GomLfEooG=U@05ooG=U@07
ooO?UOo`b9Co_:2:ojRBQonZTh[oY9=coof00P02oon0000@oomo0?ooN03oogT0oonN?_ofdZ_ob]?R
ojRieonY_=co[;oLoj^nfonZ_=[o]<CNolcFj?odmOSoookmooWinP;on?Si2?oin?T01?nX^mWo[;kK
ojZlf_o4dNKoooooobKooooo003hooooo`09on[_m_nY_=[o[;kKojbnfon[_]_oYk[IokO7h?oUjoCo
n__m01Oooooo00Soo?gnoloJj_nV^MSoZkgKojk0g?o8d^Kod=SYom7Ij@;odM[Y00?od][Yom?Jj_oC
fnX00_oCfnX03OoDg>Wodm_YomGMjooAfNWoamCVojS0fomoYlkoLYg9oeJ;_omGRkooF8^oodF4^ol0
JJ`01_l7K:h02ol3JZgo:WfgoeJ;_omGRkooF8boog6Mb?nS`M[oZ/CMolKEi_o`lOGoo?Wj00[omOKh
00OomoSionS/lonkbN7oZKcJojNjfOo6d^KonO[l00[ooooo00Koooklooo`h_oocI[ooiXeoomh0?oo
O@0Aoon00005oomo0?ooOP3ooh@:oonC9ooo`hL03?ooool01_oocI_ooi0Qoomo0?ooO03oohTFoooZ
eSGooooo00?oo_knooclo?okno/00_ojn_X05?okno_oo?clooclo?ojn_[omOGeonc/k?oRh^;oemOG
olo?coo9bLWoalO7olS8b?niS5KoaX4^olAn:ooQ[CGok=jbooKfm_okno_oo_kn0oooool00onD_m_o
1fb^o`M/[P06o`M/[P03o`1QZ?mm/]Gomo[l02;ooooo0_ono_h00oomoOgoo?clooclo002oogmo@03
ookno_oooooooooo04Kooooo00_oj?3gogFLbOmRTL?oFXg0oej@`_m[V<OoJYS7ofZHa_mRTlCoF8c0
oeJ:_`02oeN;_`;oF8^o00CoChVmocMo^?l0JZco0fZ]1ol7K:h04?l4JZgo06>Yo`1VZ_mSXl_o^mKY
onOamoomo_oohNObok31g?n[_M_oZ;_Jol_EiooLhnoog^?_omkTkooOi?03on3Ul0;ohNKa00?oh>K`
on7Vl?oQi_000ooQi_001_oPi_3og>?^ojNjfOn/_]_oZ;_IolgHj@Sooooo00[onoooojJifOn[[[oo
Yi^Kol:XTookdYSollZCooC;U?odc9GomLbE1OoecID5ooK=U@0BooO>UOoabICo_:2:ojRAQonZTh[o
Y9=coof00_ooO@3oogP0oon11?oo]fooonO?ooodj?ooo_con_coonS]mOnjbN;oZ;_I0_n/_]/01_n[
_M_o[KoLokS7h?oMh^gooogloo[knP;onOWj1_ohn?T01OoinO[oZ;_IojbnfonZ_=[oa=7V0?oooooo
9_ooool00?Sooooo00Soj^ofojVlf_n/_]_oZ[cJojk0g?oGgnoon__mooknoaSooooo00Ooo?gnoloJ
j_nV^MSoZkgKojjog?o4d>Goc=GW00;ocMGW00Coc=KXolgFj?o?enSocmOY0_o>enT00oo@enWocmSY
oloHj@02om3Ij@08olkFj?o9e>KoVkSHoeF9__mER[koF8^oodF4^ol0JJ`6o`M/[P0=o`=Z[OlZOKOo
EX^ooeN;_omHS;ooLYg9oj6ofOnL^mOoW[gHojG1foo5eNKoko7fooSgn@02ooCdm`?om?Gg0_odmOP0
2?odmOOom_OhonO[l_nkb>7oZKcJojNjfOo6d^KonO[l3?ooool01_oooO_oooWboooL^OooVC?oogX0
oomo01?ooh0000?ooh47oon<6?oo`hH02?ooool00ooom^goojeKoon22@03oon00003oomm0?ooUbko
oo_f03Cooooo00?ooOgmoo_knooinOT00_ogmoL05Oohn?Son_[joo[jn_ohn?Solo?con_[jooPh>3o
e]KFolk>c_o8b<Soa/K6olO7aonhRDgoah@_okie:?oKXS;oilajoo?clooinOWoo?clooknoP02oooo
o`03oiBofol7K:ko1fb^00Ko1fb^00?o066XogfbeOogn_`08Oooool01?ono_kooOgmooclo?okno/2
oo[jnP04oo_knoolo?cooOgmooknoTGooooo00So/];VodnGa_lKM[CoH8k1oeJ;_omFR[koGi72ofbI
b0?oJYS700?oJIS7of2@`_mFR[l00omGRkl01OmHRkooEh^oodj8__lPMkCo06V/00Co1fb^00Oo0fZ]
o`1VZolLNKGoT[kKonSbn?ofn_coo_ko00;ooooo00Wog^Gaojo1g?n[_M_oZ;_IolgFiooPiO3oh^Oa
on;Vl?oRio400ooSio42onCXl@OoiNSa00Goh>G_ojNjfOn/_]_oZ;_IolgHj@07ooooo`09oooah_ok
]6koY9JDojZER_nWTHKo`ZF;oo_AUoodc9GomLbE00?omLfE0_ofcID3ooK>UPComljF00_on<nFoo;:
UOnlX8[oZ967ojZCR_nSTW7ooGX0oonI<oooc9[oooK^oookm`05ooooo`04oo_loOoLi>oo[KoKojZm
fP?o[;kK00Co[l3Lol3=hoo^l?GooOgl0oohnOX00ooinO[on?WjooSinP02ooSinP04ojRkfOn/_]_o
Z[cJolCAi_oooooo9_ooool00?Sooooo00Koj^ofojVlf_n/_]_o`m7Uoo?fn_ono_lJooooo`07oocm
o_o?f^[oY[WHoj^nfon^_mco`<kTolOBiP02olSCi`04olWCioo:e>Oob]CWol[Ei`;obmGW00?ob]CW
ol_Dioo;e>L00_o;e>L02?o=eNOo`/oTojjog?nT^MWoNZ3:oeN:_om3Pk_o06V/1_l7K:h03ol3JZgo
:WfgoeJ;_omGRkooF8boog6MbOnP_mWoVk_Goibkf?nL^mOoW;_Foj6nf_o5eNOoko7eoo?emP03oo;d
mP?oloCg00Oom?KgonKZl_njb>7oZKcJojNjfOo6d^KonO[l00kooooo00Goooknooomnooof[Gooi@Y
oomk000Doon00003oomo0oooRQCoolRA00Gooooo00?oon73oon=6_ooOP801OooP0000oooOP7ooilo
ooooo`0booooo`0@ookno_olo?conOWiooOgmoodm?Colo?cooGemOogmoOon?ShooKfm_oalO7ojNWY
omkNg_oDe=CocLg=olS8b0;oaLG500Wo/Wa4olb;<?nkKRKoeYTaon>iC?o^k>Gom_Kfoo_knoomoOd0
0_ooool00onC_]_o16Z]o`AZ[@06o`AZ[@03o`1OYoml/MGomo[l023ooooo00Goo_knoogmoOolo?co
nOWiooShn002ooOgm`04ooWinOokno_oo?clooknoT;ooooo00_om?Wloig4g_laQ;co2fj_o`Q][_lB
L;3oGhk1oeN;_omFR[koGi72ofbIb005ofZHa`03ofNFaOmLS/7oEh^o00CoEh^o00[oFXc0ocj3^ol=
Kk3o16^^o`E[[Ol0IJ_o@i31ojO<hoojo?gooOkn1Oooool03?oNiO7o[l7Loj^mfonX^mWocMOXon;V
lOoTj?7oiNSaonGYlOoUjO;oi^WbonKZlPWoin[b00Goh^O`ojNjfOn/_]_oZ;_IolgHj@05ooooo`09
oooL^OooWd3ooh@6oo^22OnTU97oZY>7ojNAQ_o2YXcoo=:G00?omLfE00?om/fEooK>U_ofcYH02?og
cYH02OoiciKol/ZEokbPR_nXTHGoZI:8ojfTU_omj]Oooogkooono@08ooooo`04ooknooocmo[oa=7U
oj^mfP?o[;kK00GoZkgKok31gOoCfn[om_KhooWinP06ooShn@04ojRkfOn/_]_oZ[cJolCAi_oooooo
9_ooool00?Sooooo00?ojnofokG5h?oUj_@07Oooool02?oloOkocm[ZojJif?n[_]_o[KkKokg:hoo3
cnGoa<oU0_o4d>D01Oo5dNGoa]7UolKAiOo6dNGoa];V00?oam;V00Coa];VolG@iOnfa=oo[;gK0_n/
_]/01_n^_mcoZKcJogJScOl@L[7o26f^o`I/[PCo1fb^00[o0fZ]obYm]omFRkooEh^ooeR<_omaW<Wo
W[kIoiZjeonK^]OoVk_G0_nL^mP01OnI^MKoW[gIolCEi_o/k_Col?7f00Col_;f00Oom?CgonGXlOnj
b>3oZ[cJojNjfOo6d^KonO[l01;ooooo00CoomR`oonG;oooP0Oooh014oooP0002?ooO03oohL=ooo<
V?oonO?oooK]oonkMoooN03oogl01oooP0000oooOP3ookM`ooomo00aooooo`0Nookno_olo?con?Sh
ooGemOoalO7okno_oo7alOodm?ComOGeooCdm?o_knooi^KVomcLg?oBd];obl_;olO7aoo5aLGoaLG4
ojme>oo=SC;o^flVolb;;OoR[CKojN30oo;bl_ohn?Soo?clookno_ooooooc^;`2?n>_=X00on5]]Oo
a=c/oo_moP0Oooooo`05ookno_omoOgono_kooShn?ofm_H00_oclo<01Oodm?ComoOgooWinOolo?co
o_kn03kooooo00OooOknooKjo?oGio;oJjO>o`U][ol0J:co1V^^00;o1fb^00Ko4W2`oen>`OmGRkoo
EXZnoenA`_m/VLP6ofZHa`03of^HaomRTlCoF8c000CoEh^o00GoF8^oof:?`Ol/O;KoJjK>omk[m@09
ooooo`09omkUlOn_`McoZkgKojRkfOo?f>SoiNSbonKZl_oWj_;oin_b00;oj>_b00?ojN_bonW/looY
k?<00ooYk?<05ooZkO?ojNcconW/looYk??oi>SaojJjfOn/_]_oZ;_IolgHjOooookooo_gooo`hOoo
_G[oohXDooml0?ooO`3ooh00oo^11onTU97oZY>7ojNAQ_o2YXcooM>G00;omLfE00?om/fEooK>U_og
cYH02OogcYH01ooid9Ool/VFokbWVOnYZ;KoZ[cIok[:i?onool03Oooool00ooVjoGo/l?Oojfog003
ojbnf`04ojRkfOneaMooh>C^ooKfn0GomoSi00CoZ;_IojbnfonZ_=[oa=7VoooooolVooooo`00n?oo
ool00oogn?coooooooooo`0Mooooo`07oocmo_o?f^[oY[WHoj^nfon^_mco^lWQoko<h`02ol3<h`03
ol3=i?o1c^Co`LkT00?o`LkU0oo2c^D00onjan7o[;oKoj^mf`02ojbnf`0Coj^nfon_`Mco`<kUooOh
nooZloSoJJG>oaMe/ol:KJoo1F^]o`I/[_l7K:ko0fZ]obYm]omFRkooEh^ooeR<_omaW<SoWKcHoiRh
eP02oiVieP0BoiZjeonK^]OoVk_GoiZkeonG^=KoWKcIolSHj?oZk_?oko7eoo;cm_oal_KoloCgonGX
lOnjb>3oZ[cJojNjfOo6d^KonO[l5?ooool01OoodjSooiP`oon33?ooP03oogl0017ooh0000Googl0
oomj0?ooP03oohlPoomh000:oon00003oomo0?ood:3ooooo033ooooo00Soo_knoo_knoogmoOolo?c
onk^k_o/k>cokNg]oo3`l0;olO7a01;ok>c/onCTi?oJf][odM7Aol[:b_o6a/Koa<C4olG4`?nbMCOo
cHhbokea9oo1O2SohJXeonG>R_o]kNgomOGeoo[jn_omoOd[ooooo`06ookno_omoOgono_kooShn?od
m?ColO7a0_o_knl01Oobl_;omOGeooWinOolo?coo_kn03cooooo00Oon?_mon[cn?n`d>Go>h^oo`1U
Z_l0IZ_o1V^^00Co1fb^00Ko4W2`oen>`OmGRkooEXZnoenA`_m/VLP7ofZHa`0<of^IaomZV<OoGXo2
oeN:_omHRkooFXg0ofNEaOn3YLgo/<3MomgRkoohnOcoo_ko2?ooool02_oNiO7o[l7Loj^mfonX^mWo
dM[YonOZl_oYjo;ojNccon[]looYkO<2on[]l`03on_]loo[kOCojnkd00Kojnkd00[oi^WbojJjfOn/
_]coZ;[Iolg@g?ooh[goojE<ooml0?ooNP3oogl00oooP0002OokP@OoY9BAojZCQonWTHKo`ZJ<oogC
UooecIGom/fEooK>UP07ooO>UP0;ooO>UOogcYKomlnIooOBWOoig[KolncQokg>i_nZ_mkoZ[gJok[9
hOono_h03_ooool02oono_oodM_[ojk0g?n/_]_oZkgKojbnfon[_M_oY[WIol;?i?oZkO?omOGg00?o
m_Kh00CoZ;_IojbnfonZ_=[oa=7VoooooolVooooo`00oooooolIooooo`06oocmo_o?f^[oY[WHoj^n
fon^_mco^lWQ2Onoc><01?nnbn?o^/WQojo1gOn[_MX2ojbnf`04oj^mf_n/_]_o]lOOom_Sl0Cooooo
00koh>ceofJTcOlQNkKo2Ff_o`AZ[Ol2JZgo:WfgoeJ;_omGRkooF8boofnKb?nK^mOoUkOEoiJheP;o
V;SF0onI^MH03_nI^]OoV;WFoiFfeOnO_MWobmWXonO/loo]koGoloCgon?Wl?nian3oZ[cJojNjfOo6
d^KonO[l5_ooool00oood:3ooiXeoon63`02oomn017ooh0000?oogl0oomn0?ooP0002oooP0000ooo
Qa7oonG;ooooo`0_ooooo`08ookno_okno_om_Kfoo7alOo/k>coj>SXonWYjOo/k>`2ong]k@0ConWY
jOoQhN7oemOGolo?coo9bLWoa/K6olC4a?o4`K[o/G0bom2C<_nmLRWo^W0TomfT=?oQ^e[oj>OUoo7a
lOogmoOoo?clooknoP0Yooooo`0>ookno_omoOgono_kooOgmooclo?okno_onc/k?oZj^[ok>c/oo3`
l?oemOGonOWiooclo?ono_hjooooo`06onoen_oDi_7oRKWHoaUg/ol0GJGo06R/1ol7K:h01_lBL;3o
Ghk1oeN;_omFR[koGi72offJb0;oJiS700?oK9[7offKaom^VlP00_m^W<P03Om]VlSoKY_8og:Mb_mb
WLWoMYo;oiVce_na`Mgo/L7LojfnfonV^MSo//7MonCYlooin_`01oooool02?oNiO7o[l7Loj^mfonW
^mWod]WZonS/looZkO?ojngd0_o[k_@00oo/k_Cok>odong_m003ong_m0?okO3d00WokO3eonk`m_oX
k??oY[ODojbgcOnWZ[coc8iHoomf0?ooN`001_ooP0002?okP@OoY9BAojZCQonWTHKo`ZJ<oogCUoof
cIGom/jF1_ogcYH03OogcYGon<nFooSBWOohf:[onNG7ooWgl_olooooloGjokg;h_nZ_=[oZ[gJok[9
hOono_h04?ooool01?o_loSo`loTojo0g?nZ_MX2ojbnf`04ojNkfOn^_]_odm_Zonk`m@;omOKh00Co
Z;_IojbnfonZ_=[oa=7VoooooolVooooo`00oooooolIooooo`06oocmo_o?f^[oY[WHoj^nfon^_mco
^lWQ2?noc><02_nlbN;o/l?Ooj^mf_n[_M_o[;kKoj^mfonY_=[o/lCNol_GjOohnO`7ooooo`0<omk[
m?m/Yloo;8:jo`9Y[OlUN[GoEX^ooeN;_omHS;ooKi_8oiVieonD]]GoUKKE0_nF]mD00onF]mKoUkOF
oiNgeP03oiNheP0;oiJgeOnB]=?oWkcHolKEi_oSjO3oh>G^okc9hOnZ_=[oYk[IolKBi_oin_`06?oo
ool01Oood:7ooj94oon<6oooO03oogh001gooh0000?oogh0oon:5OookM`0;oooool01Oono_kono_k
ooKfm_o`l?3ojNWY00;oiNGU01OoinOWonWYjOoXj>SoiNGUomgMgOoEeMGocLg=olS8b?o5aLGoa<C4
ol6k/on_JbkoeYXcokae:_ncI27ofIhcon2[=ooTgLOok>c/ooCdm?oinOWooOgmooknoP0Wooooo`0>
ookno_omoOgono_kooOgmoobl_;okNg]onWYjOoVi^KoinOWon[Zj_o`l?3om_Kfoo[jn_omoOdioooo
o`07omk[m?n/c^CoFik:o`5X[?l0GjKo0VV/o`Q][P08o`M/[P06oa9`/?mOS/7oEh^ooeJ:__mQT/?o
LIk90_m_W<P03?maWLWoLIk9og6NbOm`WLWoKic8ogZRc?n8Z]3oW[WHol;?iOo?e^Wo_/[Rok31g@;o
ZkkK00Co[;kKojZmf_nR]]OocMSY1oooool02OoNiO7o[l7Loj^mfonW^]Wodm_Zon_^m?o]koCok^od
onk`m002onk`m@;oko7e00kol?7eoo3am_o`lOKol?7foo3bmoo`lo[ol?7eono[iooYh=CoYIbRojZB
QOnVT8Koc8Y@oomn00Oooh0000Oonh47ojBDTOnZThOoYi66ol:VS?omdiKom/jF00ComljF013omlfE
ooO=T_ohd9Son=JUooWO^Ooik]konOgooo[nooojnocoo?ckooCdmonnbn;oZ[cJojZmf_njbN7oo_kn
4_ooool03_oOi_7o^LSQojbnfonZ_=[o[;kKoj^mfonS]mSo_L[RomkTk_o`l?GoZ;_IojbnfonZ_=[o
a=7VoooooolVooooo`00oooooolIooooo`06oocmo_o?f^[oY[WHoj^nfon^_mco^lWQ1Onoc><01Oo0
cN?o_L_RokK5h?n^_mcoZ[cJ00;o[;kK00CoZ;_Iojg0g?o2cnGoi^cd2oooool03OoEi_7oK:W?odb@
`_mCRKooEHZnoeR<_om^VlOoUkOGoi:deOnE]MGoU;GEoi>feOnD]]D00_nE]]D4oiJge@06oiFgeOnC
]MCoSk?Boj6nf?nic>7oZ[oK0_n[_MX00oo6d^KonO[looooo`0Iooooo`05oooJ]OooZUGoohdJoomj
0?ooOP007?ooP0000oooOP3ooihnooobiP0^ooooo`08ookno_okno_om_Kfono_kooXj>Soh^;Ron7Q
hOoRh^82on?Sh`0Don3Ph?oJf][od];Bolc<c?o7alOoaLG5olC4a?o5_Zoo/f`ZomRM<_noNRgo[ehP
om6C;ooOYSCohLfDonKVi_o_knoom_Kfoo_knoomoOdVooooo`0?ookno_omoOgono_kooOgmoobl_;o
k>c/onKVi_oShn?oh^;RonGUiOoZj^[olO7aooOgmookno_oo_kn03Kooooo00SoloSkolWOkOnI`mko
?8boo`1PYol0HjWo16Z]o`Q/[P[o1fb^01Ko4W2`oen>`OmGRkooEHZnof>C`omeX<[oM9o:ogFOb_me
X<_oLYk:ogBOb_n3Z<koT[7Cojk3g_o=eNSoeM[[oloGj?o=e^SocmSYolOCi_nhan3o[/3L0_n/_]/0
0on[_M[o_<_Rooooo`06ooooo`09omkUlOn_`McoZkgKojNjfOoEg>_okNoeonk`mOo_lOGol?;e00;o
l?7f0_o`l_H2oo7bmP0<oo7cnOoam?_olO3`oo7Ygoo`h<Wok/jSonW0S?nTS83oZY>6ojJDS_o<Re;o
ogh01oooP0004_okP@OoY9BAojZCQonWTHKo`ZJ<oogCU_ofcYKomljFooO>UOogcI?omlbAooOAWOoh
fZoonNG8ooWcj_ojoooon_cooo[jn`;on_[j00Ooo?ckooCdmonnbn;oZ[cJojZmf_njbN7oo_kn01?o
oooo00gom_SkolgHj_nb`mkoZKcJoj^mfon/_]_oZ;cJojVlf_o:dnKoZ[gJojbnfonZ_=[oa=7V0?oo
oooo9_ooool00?oooooo6Oooool01_oloOkocm[ZojJif?n[_]_o[[oLok_9h@?o_lcS00co`<gSokk<
i?njb>7o/L;NojZmf_n[_]_o[;kKojZlf_nW^]Wo^<OPomSQk_ono_h>ooooo`09olcKk?mkXLcoHi;3
oe>9__m[V<KoUKKFoi2ce?nA/mCoT[?D00;oT[CE00?oTkCEoi>eeOnD]MD01_nD]MD01_nC]MCoPj[?
ofnJaon2Y<goUk7Dol_Ej1gooooo00GoomN`oon[E_ooRQGoogL0oomn000Joon00004oomo0?ooO`7o
okAXooojm2gooooo00Soo_knoo_knoofm_Kok^k^onKVi_oPh>3ogMgMomcLg0;ogMgM00Gofm_KomGE
eOo?cloob/[:olK6aP02olC4a00>olBkZOnfK2Soei/aokYo;OndIB7oaH4Zon6X=OoN^67oh>3PonWY
jOobl_;on?Shooclo?ono_hTooooo`0@ookno_omoOgono_kooOgmoobl_;ojn_[onGUiOoPh>3og]kN
on3Ph?oUiNGok>c/oo?clooinOWoo?clooknoSCooooo00Ooj?;gokGCiom]ZM3o7gZfo`1OY_l0IJ[o
1Vb^00go1fb^013o4W2`oen>`OmGRkooEHZnofFDaOmjXlcoMj7;og>Ob_mjY<goSJkCoj6kfOnlc>;o
e]c[omGLjooBf^[od=SY0oo@fNX01ooBfn[odMWYol?=i?n_`=co[;kKoj^mf_nocN<01oooool01_oN
iO7o[l7Loj^mfonW^]Woemg/onoamP;ol?;f01?olO;foo;bm_obl_KolO?foo7cmooamO_oloCjoo?]
jOoai=ColMZkoo3;VOo`aHcol<N@on_4TonTSXKoZY>7ojJDS_o<Re;oogh000Oooh0000oonh47ojBD
TOnZThOoYi66ol:VS?omdiKom/fEooK;T?ogcICommBTooSN^_oij]Gon_[ioo[nooojo?h01Oojn_X0
1oolo?_om?Cgokk;h_nZ_=[oZ[gJok[9hOono_h05Oooool01ooVk?GoaM;Vojbng?nY_=[o[;kKoj^m
fonW^]T00_n/_]/00onZ_=[oa=7Vooooo`3oooooobGooooo003ooooooaWooooo00Koo?gnoloJj_nV
^MSoZkkKojjog?nkbN42oko<h`0;ol7=i?nkbN7o]<CPojfnfonZ_M_o[;kKoj^nfonW^]Wo/<3MolgG
jOo_loP04?ooool02_ofn?_o//;NoiVceOmnX/coMZ7:ohZ`d_n;/=;oS[;Cohnbdon?/m@2oi2ce004
oi6ce?n@/mCoT;?Doi6ce0CoT[?D00OoTkCEohJ/dOmOTL;oChJlof6@`_n<[M;odN;`01kooooo00Go
omRaoon^H_ooQ`koog@0oomn000Ioon00003oomm0?ooP@WoolF;02gooooo00Ooo_knoo_knoofm_Ko
k^k^onGUiOoMgMgofMWI00?oemOG00GoeMGEom7AdOo=cLgob<S8olG5a@02olC4a00?okjdXonbJBKo
^XD/oj5h:_o7ORSo^G0UomnV=?oMXSKogM:_on?Shoo/k>com?CdooWinOolo?coo_kn02;ooooo00So
o_knoogmoOokno_omoOgoo7alOo[jn_oi>CTomkNgP;ofm_K00KogmoOonKVi_o^k^komOGeoo[jn_om
oOdcooooo`06om3Sl?n;^]WoC9G5o`i`/Ol0HjWo06R/4?l7K:h03OlBL;3oGhk1oeN;_omERKkoHiC4
ogVTc?n4Z]3oVKKGojo5g_o9e>OofMk/omONk?oDg>/01ooDg>X01_oEgN_od]WZok?3g_n/_]_oZkgJ
oko=h`Oooooo01?og^Gaojo1g?n[_M_oYk[IomSOkOo`lOKol_;foo;cm_oaloKol_?foo?enOocmoko
loCfoo?ZgOocglColm>Zoo7:T_oab8ool/ZC00;ol/ZE00Kok<JDoj>>Q_nZThOoYYB>olb;D_ooOP07
oon0000=oo^11onTU97oZY>7ojNAQ_o3YHWoom:@ooWAVOogfkCon>G<ooW_i?oinooonOcooo[jo007
oo[jnP07ooclnoodm?Oo_/_RojZlf_nZ_M[o^/WQooknoP0Fooooo`05oo_koOoOiO7o_/cSojNjfOnZ
_MX00on/_]/00onZ_=[oa=7Vooooo`3oooooobGooooo003ooooooaWooooo00_oo?gnoloJj_nV^MSo
ZkkKojjog?nkbN7o`LkSoko;hongaMoo[l3Loj^mf`02ojbnf`05ojVkf_nX^mWo`m3UonGZm?ono_h0
4Oooool02_o_loSo[KoLok30g?n_`=coZl3LokK;hOnC]=GoPj_?ohV_dOn</M82ohf`dP03ohfad_n>
/M;oS[7B00GoS[7B00WoT;;CohFZcomRTl?oEHZnoe>9__mFR;ko?hZoogV_dooCiO407Oooool01Ooo
oO[oomR`oonaI_ooR17oog`001Wooh0000?oog/0oon75?oof[D0;?ooool03oono_kono_kooKfm_o^
k^koi>CTomcLg?oFe]Kodm?Com;Bd_oDck_odLo:olg=cOo:b/[oalO7olG5a@02olC4a00?ok>XTOnG
FBGoTfPUoi1W:_oQY3?o^g<UomJK<OoLX3?ogJe?omkKd?oVi^Kokno_ooKfm_ojn_[ooOgm027ooooo
017oo_knoogmoOojn_[om_Kfoo7alOoZj^[ohn?SomcLg?oHf=SoemOGom[Jf_oPh>3ojNWYoo7alOog
moOoo?clooknoP0aooooo`06ojo@iOm[Yloo<hJlo`1WZol0HjWo0fZ]4_l7K:h02olBL;3oGXg1oe67
_Om?Q[goMIo:oj[3g?nocnCod][Zom[PkOoHgncoe]k/00?oemk/00?oemo/omSOk?oHgn`00ooHgn`0
1_oIh>coe=_[ok?3g_n[_]_oZkgJoko=h`Oooooo00kog^Gaojo1g?n[_M_oYk[IomSOkOo`l_Kol_?f
oo?dmoocm__oloSnooCakOodh/golmZgoo?@X0;ol/R@00_oll^Doo?;UOocbiGollZEoo?;UOo/aiCo
Xhj6ojZCQonVU8koc8]Boomn0007oon0000:oo^11onTU93oZY62ojV?POnaWiGoe<Beoo?Wf?omn_?o
nOcoooSjoP;onOSi00?onOWjooWjn_oinOX01Oojn_X01oolo?_oloCgokg;h_nZ_=[oZ[gJok[9hOon
o_h06?ooool01?oam?Wodmc[ok31gOnX^mT2ojbnf`03ojZlf_o4dNKooooo0?oooooo9Oooool00?oo
oooo6Oooool04?oloOkocm[ZojJif?n[_]_o[[oLokc9h_njb>7o//;Mojbnfon[_]_o[;kKoj^mf_nV
^MSo]<GOomkUl?ofmo/Cooooo`0=onocn?n]_mco[;kKojjofoo2cNCoh>G`olWFionaa]koSk;Coh:Y
c_n7[M3oRZkAohZ_d@07oh^`d@0;ohfad_n2Z/koHI;3oeF:__mGRkooH8k1o`][[_l0Ij_o=8JmogZ`
dooOk?D07_ooool00ooo`87ooh04oomo000Ioon00003oomj0?ooU2KoonS@02_ooooo00koo_knoo_k
noofm_Kok^k^onCTi?oJf][oe=CDolo?coo=cLgoeLNAom77Xoo:b/[ob<S8olK6aP?oa<C4013oXI1d
ogA78_mgDRGoW6P]on:W<ooDVS3od98`omNR=?oDUc7og/B0on3Ph?oYjNWol?3`ooOgmookno_ooOgm
7oooool04Oono_koo?cloo[jn_ofm_Kol?3`on[Zj_oShn?ofm_KomKFe_oDe=CoeMGEom_KfooShn?o
k>c/ooCdm?ojn_[ooOgm00Cooooo00?ooO[aooooo_ooool0:?ooool01oo[loSoSKcIodZC`olMNKGo
06BZo`1VZol6Jjh04ol7K:h02ol1JJco0FJZoej>`OmbVlWoRZW@ojo2gOoKhNkogN;^om[PkOoIgngo
fN3/00Cof^3]1_oKhNh01_oLh^koe]g/okC4g_n[_]_oZkgJoko=h`Oooooo00oog^Gaojo1g?n[_M_o
Yk[IomSOk?obm?SoloOnoo?gnoodk=oolmfnoo?DZ_occ9OollV@ooC:ToodbiD01_odc9D01_o^b9Co
Xhj6ojZCQonVU8koc8]Boomn00Kooh0000Woogd0oo]h0?nMSH_oZYjPoj^^_?nY]<[oZkgKoko?jOoP
iO400_olno/2ooShn@;onOSi1_oinOX01ooko?_oloCgokg;h_nZ_=[oZ[gJok[9hOono_h06Oooool0
1?ono_kojNkeol;?iOnW^]T2ojZlfP03olCAi_oooooooooo0?oooooo9?ooool00?oooooo6Oooool0
1ooloOkocm[ZojJif?n/_]_o[KkLok31g_n^_m`00on/_]/01?nY_=[oZkgLom3Jjooam?TEooooo`0>
onocn?n]_mco[;kKojfofonmbn;og^?_omgQk_oIgngoc=SXok76gon:[m7oP:W>ohJ/d?n7[M06ohR]
d00=ohZ^dOmoYlgoH973oeF:__mGRkooH8k1oaAa/Ol5K:ko0FR/o`M/[_laQKcoL:_AonSan00Koooo
o`04ooo;UoooTR[ooh02oomo01[ooh0000?oog/0oonN??oolN80:_ooool03_ono_kono_kooKfm_o^
k^koi>CTom[Jf_oBd];ocLg=ol[:b_oEaX_od;QRolO7aoo6a/KoaLG50oo4a<@04OnJNE7oFcdQof90
9_ncN2kod8`/onBd>?oJX3?of:Peokn3;OoOYS_og=Fmon;Rh_o[jn_ol_;booShn?olo?coo_kn01co
oooo01?oo_knoogmoOolo?conOWiooGemOo_knoojNWYon;Rh_oJf][oe=CDom7AdOoBd];oe]KFomgM
gOoVi^Kokno_ooOgmoolo?coo_kn00?ooooo00?omN>moo?N]Oooooh09oooool01_o8g^goIJ?=oc65
_?l?LK3o06FZo`=Z[A?o1fb^00_o26f^o`1WZol0GjOo6GJdogb`donI/MCoY[[Iojbmfoo2c^CognC_
om[PkP02omcQkP05omcRk_oMh^kogN;^omkRk_oNhnh01_oNhnl01_oOi?3ofMo/okC4g_n[_]_oZkgJ
oko=h`Oooooo00gog^Gaojo1g?n[_M_oYk_KomSSmOocm?Com>;<oo?F[oocd:7om<bDooC:TOodbiCo
m<bE00SomLfE00KoklVDoj>>Q_nZThOoYYB>olb;D_ooOP04oon0000?oomk0?ooL`3ooh/FoofiM?o@
e^7oZ[WCojNlfon/`=koZkkKojZlf_na`]co`loTonk`mOomoOconOWj00;on?Si1_oin?T01ooknO[o
loCgokg;h_nZ_=[oZ[gJok[9hOono_h06oooool01Oofn?_ognGaok?3g_nR]]Ooa=7V0?oooooo9_oo
ool00?oooooo6Oooool00ooloOkocm[ZojJif005ojbnf`05oj^mfonV^]So^LWQonc`mooknod05_oo
ool03oo_loSo[KoLojbnfon]_]_o^lWQomWQk?oFg^_ofMk/om[PkOoEg^_ocMSYok35g_n6[=3oP:S=
ohBZc`05ohF[c`0?ohN/d?mlY<coGi72oeF:__mGRkooH8k1oaAa/Ol6K:ko1fb^o`I[[_l3JJgo2fj_
obb2^_mb[=;ok_Gi01Oooooo00Cooo[doonUC?ooQ@ooogd07?ooP0001?ooO`3oogX2oonaHOoonO<5
ooooo`?oo_kn8Oooool03Oono_kono_kooKfm_o^k^koi>CTomWIfOoAdM7obl_;olO7aooDaXkobZPe
olS4]?o5aLD00oo4a<@04oo3_kKoWfdgoeU28?maBRgo_X4]ol1f9ooQ[SKoh[8gomfb=OnXKRSof9La
omjmJOoKfm[oi>CTonc/k?oclo?on?Shooclo?ono_h06_ooool04oono_koo?cloo[jn_ogmoOolo?c
onk^k_oXj>SohN7Qom[Jf_oCdm?oclo?olk>c_oAdM7of=SHon7QhOoZj^[olo?cooWinOomoOd00ooo
ool00oodhK_ohJ]Moogik`0Vooooo`06ojW=hom7T/?o8Wbgo`Q][_l1JJco1F^]4ol7K:h03?l6Jjko
06JZo`1JY?liRkkoY<WRom_YlooZl?OoYkWHojfofonY_=[o`LkTon;Ul@;og^?_00GognC`on3Tl?oP
i?3oh>C`on3Ul@02on7Vl@0;on3Ul?oQiO3ohNG`on7Ul?oPiO3ohNKaom_Qk_nea=koZkkKoj^mf_no
cN<01oooool02_oNi_;o[l?Qoj_1h_nV/lkof<Nfoo;BYOoccI[om<^CooC;U?oec9D4ooG=U@Oom/fE
01SoklVDoj>>Q_nZThOoYYB>olb;D_ooOP3ooh00oomn0?ooN@3oog@0oonK=ooodjOoongJoooil_ol
o_ook?7hol3>i?nU^MSoZ[gKojbnfon[_M[oZkgKokG5gooDfnX2oo_kn`;onOWj1Oohn?T01ookn_[o
loChokg;h_nZ_=[oZ[gJok[9hOono_h07?ooool01?ono_oolOCiolkIj_o0cNCoooooobKooooo003o
oooooaWooooo00?oo?gnoloJj_nV^MP01?n/_]/01?nX^m[o[;kKom_Rl?ognO`Hooooo`0Aonocn?n]
_mco[;kKojfnfonkb>7oe]k[omCLj_oCfn[oeMcZomGMjooGgNcodmcZolgGj?nY`MgoPJW?ogfVcOn1
Z<h00on2Z<h02?n3ZLkoNJ?<oenA`_mFR[koEh^oof2>`OlDLK7o1Vb^0ol7K:h01_l6K:ko16Z]o`]_
[olTO[SoMjkCooGio1Cooooo00Coomjnoon=7?ooP07oogl07_ooP0001?ooO`3oogX7ooo8TOooo_`2
ooooo`;oo_kn1?omoOd2ooknoQoooooo00_oo?clooKfm_o^k^koi>CTomWIfOoAdM7ob/[:olO7aooC
aI7obZTdolbkO`04olC4a00DokfaW_nQJ2coNU/SohAG;_o5R2ko]FXSomVL<ooN[CGofJddoj5/9OoC
SBgoh:Lfom[@[OoMgMgoiNGUong]kOodm?ConOWiooclo?ono_hGooooo`0Eookno_omoOgono_kooWi
nOoemOGolO7aonc/k?oVi^KogmoOomSHf?oBd];oc/k>olc<c?o>c/kodm?Com_KfooUiNGok^k^ooKf
m_okno_oo_kn00;ooooo00?omn[4omZF?Oo_dJ409?ooool01ooRk_GoO;7Dobf3^olEMK?o1Vb^o`E[
[Ol6K:h04_l7K:h04_l8K:ko16Z]o`1SZOl0IZ_oFYg8ol;KjooYloSoo?gnoooooooemo[oY;OGojbn
fonY^m[o`loTonGXl_oRi_7ohNK`on;Wl@?ohnOa00?ohnSaonCXlOoTj?401OoTj?401_oVjO;og^C_
okG5g_n[_]_oZkgJoko=h`Oooooo00Sog>Ofojj`_onYW9goY9>>omZgT_obbICom<bDooG<U@?omLfE
0_ofcID2ooK>UPGomljF00gom/jFoo39UOnSSXKoZY>7ojJDS_o<Re;oog`0oomf0?ooQ0SoojmPoooU
c?oomN[oookm00Cooooo00Con?[lomcSl?n``=coYk[I0_n/_]/01_n[_M_o[[oLokW7hOoZk??ooOck
ooWjnP;on?Wj0ooinOX01oojno_oloChokg;h_nZ_=[oZ[gJok[9hOono_h07_ooool00ooko?gomoWl
ooooo`3oooooobGooooo003ooooooaWooooo00?oo?gnoloJj_nV^MP00on/_]/01?nU^MSob=CWoo?f
n_ono_lIooooo`07onocn?n]_mco[;kKojfnfonjb>7odMWZoloGj@03om3Ij@0Bom;Ij_oBf^[odm[Z
om7Ij_o=f>WoY;kJogfVc?mlYLgoOJK=ogfUcOmnY/goMZ7;oej@`_mFR[koEh^oof2>`OlDLK7o1Vb^
1ol7K:h01?l8K:ko5WBbogF]d_odnO/@ooooo`03ooono_oo_G_ooh8802;ooh0000_oogh0oomn1_oo
ek3oooknooooooono_kooOgmooclo?okno_on_[joo_kn`02ooclo003ookno_oooooooooo01cooooo
00coo?clooKfm_o_knooiNGUomWIfOo@d=3ob/[:olK6a_oBaI?odK8iolBVA_o5a<03olC4a00EokRS
QOnSIbWo[hD/oiIU;Oo6Rc3o/F<Roln;;_oIXC;ocYdaoie^9?o;PB_ogjHeomfiHOoFe]Gog]kNonKV
i_o^k^kom?CdooWinOolo?coo_kn01Cooooo01Koo_knoogmoOolo?conOWiooKfm_oclo?ok^k^onWY
jOoShn?ogMgMomOGeooAdM7ocLg=ol[:b_o;bl_oc/k>omGEeOoOgmoojNWYoo;bl_ohn?Soo?cl0_oo
ool01?ohk/oogZ=8omZBA?okmNDRooooo`04ol;KjomCVLOo5GFco`Y][aKo1fb^00Oo16Z]o`1TZ_lN
N[KoS;_IonSamoohnogoo_oo00?ooooo00com?KjojBgeon/_]_oZ;_JolC@i?oXjo?ohnSaonGXlOoU
jO7oiNWbonKYl_oVj_88onOZlP06onW[looPiO3o]LGOoj^nfon[_M[o_lgS1Oooool02?ookn7ookIV
om2DC?nTTh;oZY>8ojB?Q_oJ]Y3oll^E0ooecID2ooK=U@03ooK>U_ogcYKomljF00OomljF00WolLVE
oj>>Q_nZThOoYYB<olb8BoooTA_oom:Tooogl?ooo?T02?ooool01Oono_oomoWkol_GjOnY_=[oZ[gK
00?o[;kK00Co[[oLolOAiOodmOOon_[j1?ohn?T00oojn_[olo?gokg;hP02ojZmfP03ok[9hOono_ko
oooo0?ooooooAOooool00?oooooo6Oooool02?oloOkocm[ZojJif?n/_]_oZ[cJokG5gooZkoKoo_oo
6oooool01oo_loSo[KoLojbnfon/_]_o^<KPolgGj?o;e>L00_o<eNL00oo<e^Soc]OXolkGj@02olkG
j@;ocmOY00cob=CVoibgeomiY<coNZ?<og^Tc?mdW/WoGXo1oeJ:_omGRkooH8k1oaAa/Ol6K:h9o`M/
[P04o`AZ[Ol>LK7oOK;Eoo;hn`gooooo00?ooo;ToonD:OooP0009?ooP0002?ooOP3ooh84oooYd_oo
ooooo_knooclo?ojn_[on?Sh0_ogmoL01Oohn?SonOWiooclo?omoOgoo_kn01cooooo00coo?clooKf
m_o_knooiNGUom[Jf_o@d=3ob/[:olK6a_oCaYCoe;DmokjL9oo;_iT3olC4a00Fojn9HOnXKBSoaiLa
ojee;onfQRgo]6TSokig:?oHV3;o`hPZoiI`9_nkL2KogZ<domfR=?oHbYooemOGomoOgooWinOok^k^
ooCdm?oinOWoo?clooknoQ7ooooo01goo_knoogmoOolo?conOWiooOgmoodm?Cokno_on_[jooUiNGo
gmoOom[Jf_oDe=Coclo?ol_;boo9bLWob<S8ol_;boo@d=3of=SHon?Shoo/k>com?Cdoo[jn_ono_ko
ooooooS/c?oLWd?ofiU4onFcO00Pooooo`04ooChnonH`]go:82io`1X[1Oo1fb^00Go1V^^o`]_/?m7
T/?o]mCWooWlo@07ooooo`06ooCfn_nT]mOo[;kKojRkfOo4d>Gojngd0_oWj_801?oWjo;oj>_bonS[
l_oYjo88onW/l`06on_]m?oSi_7o]/GOoj^mfon[_M[o_lgS0_ooool02oooo?[oomR`oonL>OooP03o
ogh0oln:>?nTU8?oZY>8ojB?Q_oJ]Y3om<bE00;omLfE00?om/fEooK>U_ogcYH02_ogcYH01OoabIGo
Xhf5ojZERonVWjCoc<oJ00oooooo00?ojnofokc:hon/_]/01?n/_]/00onc`mkofMo/oo_kn`03ooOh
n@03ooWjn_obloOo_L_R00;oZ[gJ00?o^/WQookno_ooool0oooooom5ooooo`00oooooolIooooo`06
oocmo_o?f^[oYKSHok31gOoFg^kooOgn7Oooool01oo_loSo[KoLojbnfon/_]_o]/GPolSDioo7d^H0
0_o8dnL3ol[Di`;obmGW0_o:e>L01oo;e>OocMGXol;@i?nE/mGoLYg9oej@`_mFRkl00_mGRkl00omP
S/7o576ao`I/[P0;o`M/[P05o`1WZol:K[3oQkSHoo;hn_okoOh02_ooool03?oolnOoonK;ooo=V_oo
`hOooj94oonH<?ooP`coohD:oon42?ooP`Kooh84oon10Qcooh0000Ooogd0oon>7_oom^kooOgmoo_k
nooinOWom_Kf00?olo?c00GomOGeooShn?ojn_[oo?clooknoP0Kooooo`0<ooclo?ofm_Kokno_onCT
i?oIfMWod=3@ol[:b_o6a/Kod/FComJf>oo3YC7oajYC0_o4a<@06Oo4`kooZFhjojQ`:onkS37o/7H/
ohAQ8oo@Sboo]VhTomFA<Oo2O2SoP60QojQO8?oJW3;ogJ8dom^[BooCdLOoemOGomoOgooVi^Kok^k^
oo?cloohn?Sono_koogmoOono_h03?ooool08?ono_kooOgmooclo?okno_onOWiooOgmoodm?Col?3`
onc/k?oWinOohN7QomcLg?oGemOodM7Aolg=cOo:b/[ob<S8olO7aoo8b<Soc<c<om;Bd_oKfm_oi^KV
ono_koogmoOoo?clookno_ogjLSofYPmomjTAOoEPScomnW>7?ooool01ooloOkom_[lomWYlomYYLgo
1fb_o`1VZol6Jjh05_l7K:h01?l<L;3o6WReofRVc_oEi_4:ooooo`06ooCfn_nT]mOo[;kKojRkfOo5
dNGokNod0_oYk?<01OoZkO?ojNgcon[]looZkO?ojngc00;ojngd1Oo[k_@05_o]koGoiNWaokK5gon[
_M_oZkgJokk;hOoolN3ool62oon94_ooN@3oogl0oon00?ooOP3ochXhojBDPonZThSoY8n6omZfT?od
c9GomLfEooK=UOofcYH:ooO>UP07ooO>UoogciWolM2QojBV]on[_M[oZ;cLolgHjP0Aooooo`03omWP
k_nca=oo[KoK00?o[;kK00SoZ[gJok_8h_o[k?ComoOhooKfn?ohmoWol?7fokg:hP;oZ[gJ00?o^/WQ
ookno_ooool0oooooom5ooooo`00oooooolIooooo`04oocmo_oAfn_o_L_Roo;enAoooooo00[oko?h
ojfog?n/_]_o[;kKokC3g_o3cnKo`/kUol?>iOo3cnGo`m3U0oo5d>D03oo5dNKoa]7VolKAi_o6d^Ko
a]7VolC?iOnlbN7oXKOHogNNb_mMSl;oF8^ooeJ:_omJS<3o4g6ao`I/[P0<o`M/[P06o`I[[_l0I:Wo
36n`ohZjf_oTkoKonO_m3oooool03?oomN[oon74ooo=Vooo^77oojA:oonD:OooSQcoohdIoon84?oo
QPcooh85oon000;oogh00oooO`0Aoon0000@oomk0?ooW3_oo_Wdoo_knoohn?Som?Cdoo3`l?o^k^ko
kNg]ono_koobl_;om_KfooWinOolo?cooOgmooknoQSooooo02[oo_knoo_knoofm_Kok^k^onCTi?oI
fMWod=3@ol[:b_o6a/KodLBEonO8@onjXC_o_IDOolW2Zoo4a<Co^[6KohM;9?n/MRoo]H<aoieY:Omj
E2?of9Tbol^>;_oASBood8L]ofU86OnHEAgodXd^omjV=_oGVc;ofKehom7AdOoGemOog]kNonKVi_o/
k>col_;booKfm_oinOWoo?cloogmoOono_h6ooooo`;oo_kn01;ooOgmooclo?okno_on_[jooShn?of
m_Kolo?cono_koo/k>coinOWon;Rh_oMgMgof=SHom?Cdoo?cloobl_;olW9bOo7alL2olK6aP0>olS8
b?o=cLgoe=CDomkNg_oYjNWol_;booWinOomoOgom^O6omZH??oMXSgoeYA6ombIGooooohJooooo`07
ooSkoOoVl?OoXlSQod:?`Ol0GJKo06N[o`I[[P0Co`M/[P06o`I[[_l4JZgo2Ff_oaYg]?lfR;koX<OP
3Oooool02?odm_[oY;OGojbnfonX^mWoam;UonoamOoYkO?ojngd0_o[k_@00oo/k_Cok>odong_m005
ong_m00;ong`m?o]koCoko7fonK[lonfaMgoZk[Doj^aa_n^Xhkoog/0oomi0?ooO`000oooP0002Ooo
OP3ochXhojBDPonZThSoY8n6om^gT?odc9Gom/fEooK>UP06ooO>UP0<ooS?U_ohciGon<nEooSAVOoh
dioonMfgooW^g_ocn?ooYK_KojbnfonX^mWocMSY4_ooool01?ojo?goamCWok72gOn[_M/2ojbnf`07
ojZlf_n/_]_od=SYoo3am_ofmoWolO;fokg:hP02ojZmfP03ok[9hOono_kooooo02Gooooo00?oj>SX
ooCdm?ooool0oooooolMooooo`00oooooolIooooo`03oogmo_ofnOcoo_oo023ooooo00Koko?hojfo
g?n/_]_o[;kKokC3g_o0cN@3oko<h`03oko=i?o1cNCo`LgU00;o`LgU00ko`/gUol;>iOo0cNCo^lWR
ojfog?nZ_=[o[[oLok?3g_nP]]SoNj7<ofVFa_l[OKOo1F^]o`I/[Pko1fb^00Ko16Z]o`1RZOlFMK?o
TkoLomcZlookoOhCooooo`0<oookmOoolNCoomBXooo:UOoo/VKoojA7oonF;oooTbGoohlNoon94ooo
QPcooh420oooO@02oomn0003oomo0?ooP03ooh0000Wooh00013oogT0oojjM_olno[on?Shoo?cloo^
k^koj^[ZonSXj?oYjNWojn_[ono_koodm?Con?Shoo_knoomoOgoo_kn5oooool0:_ono_kono_kooGe
mOo]kNgohn?SomSHf?o@d=3obLW9olK6a_oAaISoj<Y8olFcC_neSQ_ob[A[olC4a?nLRFWoICXSok=m
<?nfOc3oPe@YohaR:?o4Ob_ohk8gomRJ<_oKTS7oQ5PNoha@7Oo6NBWogjlgolJ><?oMXCCoe<RTom3@
d?oGemOogMgMonCTi?oZj^[okno_oo?cloogmoOonOWioo_kn`Koo?cl02?ono_koo[jn_oinOWon?Sh
ooKfm_odm?ColO7aonk^k_oZj^[oi^KVon;Rh_oMgMgofMWIomCDe?o@d=3ocLg=ol[:b_o7alOoa/K6
olG5aOo4a<Coa/K6olW9bOo?clooemOGon7QhOo/k>com?Cdoo[jn_ofil3ofYTlomfO=?oJYd_o`V4Z
oo?M^00Iooooo`07ongdnOo@hnooS;_Iob9k]_l0HJSo06N[o`Q/[P0Co`M/[P06o`E[[Ol0Ij_o3G2`
obEm^?mGVlSo`=W[3oooool01oodm_[oY;OGojbnfonX^mWoam?Voo;bm_o/ko@00_o^ko@01?o^l?Co
k_3eono`mOo_l?D2oo3am@;ol?7f00[ol?;goo3bn?o`l_SolO3`onWTh_nf/k_oZIRBojZ@PonWT6Ko
ogh01OooP0002?ooOP3ochXhojBDPonZThSoY8n6om^gT?oec9Gom/jF1OogcYH03_ogcYGon<jDooS?
UOohdYcon=RXooWTaooimo?on_gooo[lo_odmOSoYKSHojbnfonX^mWocMSY5?ooool02ooUj_Co^/WQ
ojfog?nZ_M[o[;kKoj^nfonW^]Wo]<?NomkSk_o[kOCo_<[Q00;oZ[gJ00?o^/WQookno_ooool09?oo
ool01Oojn_[oWinOojBTY?oUiNGon?Sh0?oooooo7?ooool00?oooooo??ooool01_o_loSo[KoLojbn
fon/_]_o]<?Nol3=i0So_lcS00Co_/_Sok_9hOna`]koZ[cK0_n/_]/02_n[_M[oZ[gJokO5h?oQi?7o
b=k]ofJUc_lZP;Wo1F^]o`5Y[?l6K:h>o`M/[P05o`9Y[?l0HJSo7GVeoiK1gOoFio806Oooool03Ooo
m^coonO@oooBY_ooaHcook=WoonTB?ooVcSooiPaoon>7OooRaOooh<7oomn0?ooNP000_ooO002oomn
0003oomo0?ooP03ooh0000?ooh00013ooWL0ooc@Y?oinOWom?Cdonk^k_oYjNWoi>CTon?ShooTi>Co
j>SXonc/k?obl_;om_Kfoo[jn_olo?coo_kn5_ooool0;?ono_kon_[jooCdm?o/k>cohN7QomOGeoo?
cloobLW9olG5aOo@a9Sokm9=omK9HOnZPaoo_i//olO0[_n2G47oGClVok5n<OncMc7oMDTUojUi;onf
JbGofj8donFh>OoJUc?o`X<[oiEI8Oo6NbWoh;Lgok5j;?oLWC;og:e;olk;_oo@d=3oeMGEom_KfooQ
hN7oinOWonc/k?o`l?3olo?cooGemOofm_KomoOg0_ohn?P2ooOgm`0AooKfm_oemOGolo?coo7alOo_
knook>c/onSXj?oUiNGoh>3PomcLg?oHf=Soe=CDom3@d?o=cLgob/[:olS8b?o6a/H00_o5aLD2olC4
a00>olK6a_o:b/[od=3@omWIfOoShn?ok^k^ooKfm_oci;[ofYXjombM<OoR/TWo_V`bom:2A_ono?HG
ooooo`06omg[m?nnfN[oGj3:o`A[[Ol0HJSo0FR/4ol7K:h01ol6Jjko0FR/o`1WZolGMK?o=XJmogZa
dooRkOD04Oooool02Oodm_[oY;OGojbnfonX^mWob=?VooCdm_o^l?Goko7eoo3am@02oo3amP;ol?;f
0_oal_H03?oaloOolO?ioo7bm_oakN[olNKJoo3H]ooX`I?o]IR2ojVAQOnZThWoZ99[oomo00Gooh00
00Soogh0oln:>?nTU8?oZY>8ojB?Q_oK]i3omLbEooK>UP?omljF00WomlfEooO=T_ogciOon=FTooWM
]ooij]Kon_cnoo[mooojno`00_ojn_X01OodmOSoYKSHojbnfonX^mWocMSY01Kooooo00goc]WZokK6
gonZ_M[oZkgJojbnfonY_=[oZK_Joko;honea=ooZkgKojZmf_njbN7oo_kn02Gooooo00KolO7aokRh
^?nIVIWoTI6Aol30`?o^k^kooooooa_ooooo003ooooooccooooo00Koko?hojfog?n/_]_o[;kKokC3
g_o0cN@6oko<h`05ol3=i?nlb^;o]LGOojbng?n[_MX00_n/_]/01?nY_=Wo/L7MolWEj?o^lOP3oooo
o`05om;Tl?ma[=7o<8Bko`1VZol0Ij`03ol7K:h01Ol0Ijco066XobAm]on=^m[oc^;_01kooooo00ko
ooO`oooO`?oof;3oolB9oongKoooZeSooj94oonK=oooT27oohXEoon10_ooN@3oogP0oomi00;oog`0
01;oogh0ooel0?ojgKoom_Kfoo3`l?oYjNWohn?SomoOgooNg]koh>3PonCTi?oZj^[okno_ooCdm?oh
n?Sono_koogmoOono_hDooooo`0/oogmoOoinOWolo?con[Zj_oOgmooeMGEolg=cOo8b<SoaLG5om33
Uoobee7of]5/okJB;?n_R1Ko_9Q>ohmI<_m^DBGoWg8]oiiV;omgCBSo^8L`ojmT8oo9Qbgoik/jon>b
=ooETc7o]W<YomJG<?oN^SSoXVhWomRE<?oNY3CofKU/ol[:b_o>c/kodm?ComSHf?oMgMgoh^;RonKV
i_oZj^[okNg]ono_koo`l?02oo7al@0Coo3`l?o_knook^k^onc/k?oZj^[oj>SXonGUiOoQhN7og]kN
om[Jf_oGemOodm?Com3@d?o=cLgob/[:olS8b?o7alOoa/K6olG5a@04olC4a00=olO7aoo;bl_od];B
om_KfooVi^Kokno_oo3O/ooJVcWog:4aon:^@Oo;Rcko]4`Ponk=W`0Eooooo`07ooOjo?o4g>coR[WI
ocJ8__l0HjWo06:Xo`AZ[@0Co`M/[P07o`AZ[Ol0IJ[o06R/obb2^_mLW/[oX/SQookooP0Cooooo`09
ooCfn_nT]mOo[;kKojRkfOo9dnKom_Kioo3am_o`l_KolO;f00;ol_;f0_oaloH03_oam?WolOGkoo?`
l?obj=colMo7oo7AY_o_aHgol/N=on_2T_neVhWoZI:7ojZCROnXTV_oogl01OooP0004_ooOP3ochXh
ojBDPonZThSoY8n6ombhT?oec9Gom/jFooO>U_ogc9?omlbAooOBWOogf[3on^G9ooWdk?ojo_oon_go
oo[jn`Con_[j00Gom?GhojFhf?n/_]_oZ;_IolgHj@0Gooooo`04onobn?o7e>Oo/<7MojJjf@;o[;kK
00KoZKcJoj^mf_n/_]_oZ[gJok[9hOono_hWooooo`06om;Bd_nXZ:SoT92@ojBTY?oMgMgonOWioooo
oolIooooo`00oooooollooooo`06onocn?n]_mco[;kKojbnfond`mko`<gT1?noc><01Oo0cN?o_/cS
okS6hOn``MgoZ[gJ00;o[;kK00CoZKcJojVkf_o2cnCohNSc1oooool01Oo<h>koL:[@ob^0^Ol0HjWo
06N[00oo1fb^00Go06N[o`1PYol[PK[oQ[OHoloSl00Rooooo`0Nooojm?ookn3oomjloooDZ_ooaH_o
okUdoon]G?ooZ57ooiPaoonB9_ooQPcooW`0oob32OohgL;ol_;bon_[jooShn?ogMgMom[Jf_oIfMWo
g=cLon7QhOoWinOokNg]oo?cloofm_KonOWiooclo?omoOgoo_kn4Oooool0;Oono_koo?clooOgmoo`
l?3oinOWomgMgOoCdm?oc<c<olO7aoo5aLGod<BIoo3FDOo[iGWo^YXhojIl5OndQQ[oVf@Zoh=S8om_
CRKoP58ZogQ@:_nVNRSo^7DWokMb9_oQZCKoil8jon6]=ooHUS7ohJhfom^i>?nIJRKodHL/omnW=OoK
W3?odl6?olW9bOo<c<cod=3@omCDe?oHf=Sog=cLon3Ph?oShn?oiNGUonKViP03onOWi`0@onKVi_oT
i>Coh^;Ron3Ph?oMgMgof][JomOGeooDe=CodM7Aolo?coo<c<cob/[:olS8b?o7alOoa/K6olG5a@Go
a<C400koaLG5olO7aoo<c<codm?ComgMgOoXj>Soj]:LomZI<ooMY3?ogjHhombYB?n]CR;ob6heoocg
j1?ooooo00OohNgeoj_>i?mZY/ko7WVeo`1NY_l0IJ_o1F^]01?o1fb^00Ko0FV/o`1UZ_l=Kk3o@Xo1
og^ae?o:gndFooooo`0KooCfn_nT]mOo[;kKojRkfOo9e>OomoOioo;bm_oal_KolO?foo;cm_obm?Oo
loKkoo?fn_ocknSolnCAoo?I^?obcIWolLN<oo79TOobbICom<ZEonc5TonfW8WoZI:7ojZCROnXTV_o
ogl000Gooh0000ooogh0oln:>?nTU8?oZY>8ojB?Q_oJ]Y3onLjDooK<TOogc97ommJXooOP_ooijmSo
nOSfoo[nooojo?h01oojn_X01OodmOSoYKSHojbnfonX^mWocMSY01Wooooo00CohNObokk;honZ_=[o
ZKcJ0on/_]/00onZ_M[o^/WQooknoP0Xooooo`06onWYjOo0`<3oUiNGoi>CToo2`/;ojn_[oooooolH
ooooo`00oooooollooooo`06onocn?n]_mco[;kKojbnfond`mko`<gT0onoc><02oo0cNCo^/WQok?3
g_n/_M_oZkgKojbnfon[_M_oYk[IokG6gooHh>kom_Sk00[ooooo00Goa=c[ogB]dOlSOKKo062Xo`1W
Z`0?o`M/[P05o`1VZol0HJSo<XFloh6de_oAi?009oooool06_oon_KoonSAoooQ`ooodZGoolN@oofj
M_ojaY?omOGeonk^k_oVi^Kog]kNomSHf?oEeMGoe]KFomWIfOoOgmooiNGUon_[joo`l?3om?CdooOg
mooinOWono_kooclo?omoOgoo_kn3Oooool0;_ono_kooOgmoo[jn_odm?Cok>c/on?ShooIfMWodM7A
ol[:b_o7alOoa<C4om35W?o^eEComoB1okfQAOnZOaSo[HHHoj]l:?nOMbSo@2hKof8o:?n5FR[oRV0U
om6A;onnO2Woe98aonFk>_oW`C_oh:TfonBd>?oI]cOoSF@SolUi:?oNXcCoeITcomRP>oo>a:Sob<S8
ol[:b_o=cLgod=3@om?CdooFe]Kof=SHom[Jf_oKfm/2omcLg00=om_KfooJf][ofMWIomOGeooFe]Ko
e=CDom7AdOo?cloocLg=ol_;boo9bLWoalO7olK6aP02olG5a@Ooa<C400goaLG5olS8b?o=cLgoeMGE
omoOgooUc9?og9dcomjU=?oMXS?ohk99oka/;On/A1ooi[V301;ooooo00KodnC`ohZjfOm6T/?o3W2`
o`1OY_l0J:`Co`M/[P07o`I/[_l0IZ_o062WoaYg]?mIWLWoXLOQon;^m@0Hooooo`0AooCfn_nT]mOo
[;kKojNkfOo:eNOon?Oioo;cm_ocm?OoloGioo?hooodmOSom>[Moo?Pa?oceJcollZCoo;7SOobbI<0
0oocbiD01ooec9Gok<JDokJLROnYTXOoZY>9ojRBJoooO`001OooP0003_ooOP3ochXhojBDPonZThSo
Z924ok^KPooN_9Con]bboo[XcoohlNKon?_nooWkoooinO_onOWj2?ojn_X01OodmOSoYKWHojbnfonX
^mWocMSY01[ooooo00WomoSkomCMk?nb`mkoY[WIoj^mfon/_]_oZ[gJok[9hOono_h0:_ooool01_oF
e]KoYjNWohf=SOnWYjOodm?Coo_knooooooo5_ooool00?oooooo??ooool03?o_loSo[KoLojbnfon/
_]_o]<?Nol3=i?noc>?o`<gTokg;h_neaMoo[L3Loj^mf`;o[;kK00CoZ;_Ioj^mfoo>fN[ok?3g3_oo
ool01Oo6gNcoOK;Eob1j]_l0GjOo06R/00oo1fb^00Go06J[o`1UZ_l`Q;_oMjoComOXlP0Zooooo`0H
ookno_olln[on?Shoo;bl_oZj^[ohN7QomWIfOoDe=CodM7Aom?CdooGemOog=cLon;Rh_oWinOok>c/
oo3`l?oclo?om_KfooShn?ojn_[ono_kooclo?omoOgoo_kn2?ooool2ooknoP0]ooclo?ojn_[om_Kf
ono_kooWinOog]kNomGEeOo>c/kobLW9olK6a_o4a<CoclBKoo3HF?oilh;obkQFojio7?nTOAKo]X/P
okj@;_li:aKoKdHZogiD:_nAIBcoaX4YomZS=?oAS2ooh:TfonO3>ooP[3Koh:LfomZf=_n3HR7o_6XU
omfN<oo8Uc?ocXd`omb]C?o;a[CoalO7olS8b?o:b/[oc<c<olk>c_o@d=3odM7A00Cod];B00[odM7A
om3@d?o?clooc/k>olc<c?o;bl_obLW9olS8b?o7alOoa/K60_o5aLD9olC4a00=olG5aOo9bLWoc/k>
omOCaooL/7CofIDbomnV=OoMXc;ohJ]2olj>>_nW@Qgo_5dZooW_eP0?ooooo`08oo[lo_ncd^KoI:?=
ocB6_?l0Ij_o06FZo`=Z[Ol8K:hAo`M/[P08o`Q/[_l5Jjgo06>Yo`1QZ?lcQ[coR[[IokkIj_o_m_XJ
ooooo`0?ooCfn_nT]mOo[;kKojNjfOo:eNOon_Wioo?fo?ocnOoom?;`oo?Tcoocf[Kolm2Poo?9T?oc
bY7oll^D00;om<bE0_odbiD02?odc9Gom/jEonk6U?nfW8WoZI:7ojZCROnXTV_oogl01OooP0003ooo
OP3obhTjoj2@OonZSX3oZiRAojNS[_na]LCob]3Lon[anooooooon_[kooWhnOohn?WonOSiooWinP07
ooWjnP05oo?dn?nU^MSo[;kKojRkfOo=f>T07?ooool01ooZk_KobmKYojZlf_nX^]WoZ[gJok[9hOon
o_h0:oooool01_o[jn_o`/;2oi6ATOnBTY;o^KVionWYjOoooooo5Oooool00?oooooo??ooool04Oo_
loSo[KoLojbnfon/_]_o]<?Nol7=i?nocN?o]lKPok30gOn/_]_oZkkKojbnfon[_M[oXkOGok_:h_oT
j_Conocm013ooooo00KooOknol_Pk_mo/mGo6GJdo`1PYol1JJ`>o`M/[P06o`I/[_l0Ij_o0VV/ocB7
_Ome[M;ohnof:Oooool06?omoOgono_kooKfm_o^k^koiNCSomcLg?oEeMGod=3@olo?coo@d=3oe=CD
omWIfOoNg]kohn?SonOWioo[jn_ok^k^oo7alOodm?Com_KfooShn?ojn_[ono_kooclo0;ooOgm0oon
o_h2oogmo@0]ooclo?ojn_[on?ShooGemOo_knoojNWYon7QhOoIfMWodM7Aol_;boo7alOoaLG5olC4
a?o=a:7olM]LoooiQ?oFbFCo[glRoj5k5On]QQSodj@Yoei67_mbARSoNTlUojAe;_neJR?ofJ<con2Y
=_oJUc?oi[djon2/=_oKVc?ofJ/dogYL7_ncHR?ofi/aok^C<?o0NbcohJLdomZ[C_o9aKGoaLG5olK6
a_o7alOobLW900;ob/[:1Oo;bl/00oo:b/[obLW9olS8b002olO7a`03olK6a_o5aLGoaLG500;oaLG5
2_o4a<@03?o5aLGobLW8omFoU_oESdGobfLWomN@<?oPZCCog9lhon6dBon`E2;oZDDPom^OI`kooooo
00Ook?Cioi6nfom;U<Go8G^fo`1TZ_l0Ij_o1V^^01;o1fb^00Oo26f^o`9Y[?l0GjKo06J[oe:IaonN
a]oodnKa01gooooo00gom?KjojBgeon/_]_oYk_Jol_Hk_oko?oom>_Qoo?M_ooceJ_om<jIooC:T?od
bi?om<^E00OomLfE00OomlnEono6U?nfW8WoZI:7ojZCROnXTV_oogl000Cooh0000ooog`0oomb0?oY
QaSo^:B:ojBZ^onZ/l[o[;gJoj^ogonY_Mco^/SPomKNkOohmoWoo_kmooWin_ohn?T02?oin?T01Ooc
m?OoYKWHojbnfonX^mWocMSY01gooooo00Kon__mon?Ylonlbn;oY[SHokW8hOono_h/ooooo`07oo[j
n_oLg=co[:b/ohb<S?nRXZ;oclo?oogmo@3ooooooa?ooooo003ooooooccooooo00Woko?hojfog?n/
_]_o[;kKokC4g_nmbn;o//;Nojbog?n[_M/00_n/_]/01?nV^MSo[[oLomGNkOobmOXDooooo`06ooSk
oOo@ho3oP[GFoa1a/Ol0H:Oo0FV/3_l7K:h01_l6Jjko06R/o`Q/[_ldQkgoMZkBon_cn2Oooooo00So
o_knooclo?oinOWolo?con[Vg_oMaJ?of=SHom7Ad@;ocLg=013oc/k>om7AdOoEeMGofMWIomgMgOoQ
hN7oiNGUonSXj?o[jn_ok^k^oo7alOoclo?om_KfooOgmoohn?SonOWi0oojn_X0;?oinOWon?ShooOg
mooemOGolO7aong]kOoWinOohN7Qom[Jf_oCdm?ocLg=olW9bOo6a/KoaLG5olC4a?o<a:[olMeSoooh
P_oId6co`iDcojEj5_nSOAOo`IHPof168OmY?b;oSed[ojUj;_naK2Co`h@[on>e>?oHU3;ohJhgomn[
=_oCT2oog:<dogAC7_n]Gb7oei<_ojj=:oneK2OohJTfomfP<ooGZUSoaLBn0oo5aLD2olK6aPCoalO7
0oo6a/H8olG5a@[oa<C400cob/6`omJVGOoJUS7obW8[ol]U:?oHT33odH``on>bCOoCVd7oYd8Nok1<
8_odh;`<ooooo`06olcQkomWYLgo=XRmoa9c/_l0J:co0fV]5?l7K:h01_l0Ij_o05^Uoa5b/Omh[];o
_mWZonK`maoooooo00[om?KjojBif_n/`^;oYkWIol[5`oojgK?olm2QooC;UOodbY;omL^D1OoecID5
ooK=U@0BooO?UOo_aiCo]ib9ojVBQonZThWoZ99[oomo0?ooP03oogl0oomi0?ooMP3oohdKoonnO_oo
h/;olnkWomkVloncaN7oZ;_I0_n/_]/02?nZ_M[o[l3Lol3=h_oTj?7oooomoo_kn_oin?[onOWj1_oh
n?T01OocmOSoYKWHojbnfonX^mWocMSY01oooooo00ColoKjomGOkOnkb^7oo_kn;_ooool01_oalO7o
alO7oi>CTonHV9So[jn_onSXj?oooooo4_ooool00?oooooo??ooool01_o_loSo[KoLojbnfon/_]_o
[[oLojk0g0?o[;kK00GoZ[gJojBgf?o4d^Koko;hoogmoP0Gooooo`06ooOjo?oNk?CoX<KPoamk]_l0
I:[o16Z]3_l7K:h01_l6K:ko16Z]o`]^/?lWP;WoLjcBoo7fnRKooooo00Soo_knoo_knoofm_Kokno_
omjlRooBW6coeM7:olk>cP;obl_;00koc<c<olk>c_oAdM7oe=CDomOGeooJf][og]kNon7QhOoUiNGo
j>SXon_[joo^k^kol?3`oo7al@;olo?c00oom?Cdoo?clooclo?olO7aono_koo/k>cojNWYonCTi?oO
gmoofMWIom?Cdoo=cLgobLW9olO7aoo5aLD00_o4a<@07_o;aJgolMmWooceP?oXhW;o_i<jok=k7?nQ
OAKo[HDIof]=8OmeAR7oWf/_oiU[:Oo5PB[o^WLWomNQ<oo@T2oog9deombS=Oo8P2[ohZPeoieb9on]
HR;ocH0[ojB3:_n]HR?ogj<eombQ=?oJVc;oe[5XolG4_`koa<C41_o5aLD7olC4a00>olK4_Oo?/XCo
eiXnomnS=?o<Qboo^V4YoliW9oo7K2Sod910oo3GG?nnJbgo/TdQolaj@?omno<:ooooo`06oi_3gom4
TL?o6WNdo`U][_l3JZgo1F^]4ol7K:h01ol6Jjko06F[o`1RZ?lcQ[goXlSPomo/m?oenO`03?ooool0
0ooo]Vgool:4ooooo`0Booooo`08ooCnoonS[/SoZj>XojFET_o9[I7on]6EooC;U?oec9D3ooG=U@;o
m/fE0oofcYH4ooO>UP0=ooS@U_o`b9Co]ib9ojVBQonZThWoZ99[oomm0?ooN@3oogX0oonVC_ooeZko
oo3Qoookm`02ooooo`05ooknoooemo_od]_/ojNkfOnZ_MX00_n/_]/01On[_]_o/L;Mol[Dioodm?Oo
o_kl00?on?Wj00WonOWjooSin_ohnO[on?Wjoo;dn?nU^MSo[;kKojRkfOo=f>T08?ooool00ooloOko
m_Skooooo`0_ooooo`06oo_knooUiNGoZ:RXoi2@T?nMWIgobLW9oooooolAooooo`00oooooolloooo
o`03onocn?n]_mco[;kK00Go[;kK00CoY[[IokK6gooUj_Con__m6oooool01_oko?kojo?hoiW2g_lF
MK?o06JZo`I[[Pko1fb^00Ko1Vb^o`E[[Ol;KZoo7g^fogF^dooen_`Tooooo`09ookno_omoOgonOWi
oo?cloo[imkob70holUkB_oBaJooc<c<00;obLW900kob/[:ol_;boo=cLgoclo?om7AdOoDe=CoemOG
om[Jf_oMgMgohN7Qon?ShooVi^Koj>SXon[ZjP?ojn_[00coj^[ZonSXj?oVi^Kohn?SomoOgooJf][o
e]KFom7AdOo=cLgobLW9olO7aoo5aLD3olC4a00Oolc4Yoochf_oo?N2onWOK_neTC_od8h/oj5i5On_
Qa_o]H/Zog]=8_n/NC;oV6L[olEn:Oo=TRkocX/^ol:0:_oKUc?ofYTcokea9OoIX3?oh:Leol5e:?o0
JbGoTVlVojEI7ooLVS;odIleom>D<?oNXcCoek5RolO4^@0=olC4a0KoaLG51Oo4a<@03oo6`K[ocKB;
omFHB_oLWC?ogjPeombI<_nWIbgo`EdWolaS9_o<LS7ogIe5omR??_o;J2SocVTXon:YK`08ooooo`06
onOamomh[m?o7GVfoa1a/Ol7K:ko1F^]5?l7K:h01ol4JZgo06J[o`9Y[?mPXL_ob]o^ongenOokoOh0
3Oooool01Ooo_Wgoogl6oomn2Ooo[Ugoooci013ooooo00OoomJ/ooBMB?nQUICoZYB9ojF?QOo:Zhgo
nm6F00?omLfE00?om/fEooK>U_ofcYH02?ogcYH02ooid9KolLRDokNLROnYTXOoZY:7ojN?I?ooQ`go
okaioooZe?oon?7oookm00Kooooo00Coo?gnon[_m_njbN7oZ;[I0_n/_]/01_n[_]_o[;kKokK6gooK
h^gonO[ioo[jnPGon?Si00Gol_CgojFif?n/_]_oZ;_IolgHj@1Dooooo`06ooShn?o?clooVi^KoiZJ
V_nYZJWokNg]ooooool?ooooo`00oooooollooooo`03onocn?n]_mco[;kK00?o[;kK00GoZ[cJojk0
g?oCgNconO[mookno`0Nooooo`05oocmo_odnOcoTKkKo`ma/Ol0Ij/04Ol7K:h01?l8K:ko5gFdogfb
eOofn_`Sooooo`09ookno_okno_om_Kfono_kooRbZ3o`5HUol=T<?o?/HcobLW900?oalO700cob<S8
olW9bOo;bl_ocLg=olo?cooAdM7oe=CDomOGeooIfMWofm_KomgMgOoOgml3on3Ph00;omoOgooMgMgo
fm_KomSHf?oEeMGod];Bolk>c_o;bl_ob<S8olO7aoo5aLD01?o4a<@08Oo>`igojLE9oo[aNooWg6co
/ia0omNH??nWMQgobYdXomn`<?n]MRKoVfX_ojMa;_ndJR;oej0bom^N=?o3OR[oeI4aom^I<oniJB?o
cXl^on>_=_oDTS3o_fPTogaC7onREaoof90_ol>Q=Oo6PRcogZ8dombN<ooHYU7oc<:YolG5a@02olC4
a0GoaLG51?o4a<@6olG5a@?oa<C4017oal:golj`P_oEVDGocW0Yom5k:ooNZ3GohJ0cokf0<?nKER_o
cF4VolYQ9_oBNRoodGP[olmg:_oEQ2kob6PVonW3U006ooooo`05okcGj_mEV/Oo2fj_o`]^[ol6K:h0
5Ol7K:h01ol5Jjgo0FR/ob1k]on8^=OohnofooWkoOonool03_ooool01ooob9;oog/5oomo0?ooP03o
ogh3oonO?_oom^/03?ooool02_oom>[ookUdoon=6oooQ0Oom8<Coj6EUOnZThOoYHn6olZ[SOoldYH2
ooG=U@03ooK=UOofcYKomljF00WomljF00SonM2Foo37U?nfVhSoZI22ojVKV_nf][Oooo[dooolnP_o
oooo00Coo?gnomSQk_nY_=_oZ[gK0on/_]/01?n[_M_o_/cRon[]l_oinOX4ooOhn@05oo7dmonU^MSo
[;kKojRkfOo=f>T0E_ooool01_o>c/koWIfMoiVIVOnKVi_o_knoookno_oooooo3Oooool00?oooooo
??ooool00oo_loSo[KoLojbnf`02ojbnf`03ojfofonocNCoko;h02Cooooo00Coo?gnohbjf_lGMK?o
1V^^4Ol7K:h01Ol2JJco2fj_oh2de_oamo[ooOkn027ooooo00WooOgmooWinOobl_;oj^SSom6:Conn
EbGo_eLTol^CI?o:`K400oo5aLD02oo6a/KoalO7olS8b?o9bLWobl_;olg=cOo>c/kod=3@om;Bd_oD
e=CoeMGE00?oe]KF00[oeMGEomCDe?oBd];od=3@olk>c_o;bl_obLW9olO7aoo6a/KoaLG51Oo4a<@0
8_oC`X[ohK0_on[3A_oTcU[oZY@nom>UBOo:UCGoh[<eonBi>_oCW2OoU6H]ojA/;OnlM2Co`H<ZonVj
>_o?SRoocX/^ombI<oniIb?o`7XWon:]=_oQZSGod8@/ohYA7OnYGb?oh:8cokJK<OnjLRKog9hbomVL
=?oCTc;og:@mom:kQoo6aL07olG5a@Coa<C41?o5aLD07Oo4a<Coa<C2olVnZ_o@[gSof9m3omnT=?o?
Q2oobVTWom1d:_oNXSCofYHaoheO;ondFBSocEhVolmb:ooERBkodh</omVE<_oFSS3o]eHSoo?M^_oo
ooooo_oooocmo_oen_coWLGOobEo^?l3JZgo1V^^01Ko1fb^00Co2Ff_o`M/[_m0SL7oZ<_S4Oooool0
1?ooo_goom:Uoon10oooOP03oon00004oomm0?ooSAcoon[DooonoPKooooo00KoookmoooknOoog;Wo
oj11oon00?ooO`02oon00009ooB34_nQUIGoZY>7ojF?Q_o:[8goo=:FooG=UOofcIGom/jF00_omljF
00KonM2Foo3<Vong[ZcoZ[K>oj^nfonocN@?ooooo`03ooOho?o7dnOoZKcJ00Co[;kK00?oZKcKolcF
ioo`l_H00oofm_P01Oo`l_KoYKWHojbnfonX^mWocMSY057ooooo00_oo_knoogmoOoXj>Soa<C4oinO
WonGUiOoVYZJoiVIVOnk^k_og]kNooclo03oooooo`gooooo003ooooooccooooo00Koko?hojfog?n/
_]_o[KoLokG5gooOiO4Xooooo`06oocmoon2]MOo7GVeo`Y][ol6Jjko1Vb^3_l7K:h01_l6K:ko06J[
o`]_[on7^=SokoGjoo[loAoooooo00_oo_knoo_knooemOGokNg]on;?Zoo6HBSo^U/TokMF8Oo2JSKo
c;BColG5a@02olC4a0;oaLG500Soa/K6olO7aoo7alOobLW9ol[:b_o;bl_oc<c<olg=c@?oc/k>00Oo
cLg=olc<c?o;bl_ob/[:olS8b?o7alOoa/K600;oaLG51_o4a<@09?oLaWKohKLfomZ^:OoN[S;o^Ie0
oln]BooT/3Cok<e@onc=D_o2URCoZgdUojeZ:oo0OBSo`X4Zomn]=_oR/COoch/^om^H<_nkJB?o]6TS
omjV=?oQ[3GogZ8dokId:?nfKbWokKhiojR@;?naIRCofYDaolVE<oo8QS3oh:LdombN<ooGYECoc[bG
olK4`@KoaLG51?o4a<@07_o5aLGoa/G2olZnYoo@/WkoeZ9Com5k;OoIU33oh:XfomRH<OnfJbcobF@V
ole/:OoNTc3o/H0boh58;Oo;H2KocF/YomF:;_oCP2gogjPgon>^>?nkHRGo]eT/ooS_g?odn?_oc^;_
og:/d?l8K:ko06J[o`E[[ACo1fb^00Ko1V^^o`M/[_l=Kk3o5gJcofNUc_oOkODBooooo`04ooomnooo
dZKoogl0oomn00Gooh000_ooO`002ooofK;ooogjooooooooooooookmooojmOookn3ool23oon:5ooo
N`3oogh000Cooh0000Som8<Boj6EUOnZThOoYHn6olZ/SOoldYKom/fEooK>UPOomljF0_ohciH02Ooh
d9Oon=2HooWGZOokj]?olO7eokS9i?n[_McoZkgJoko=h`0Aooooo`04onS]m?njb>7o[;kKoj^nf`;o
[;kK00[oZ;cIok?2gOoLhnkol_CgooGfn?o_l_KoYKWHojbnfonX^mWocMSYC_ooool02oolo?con_[j
onc/k?o4a<CoX:2Poi6ATOnIVIWoWIfMoj^[ZooAdM7oo?cl0?oooooo4?ooool00?oooooo??ooool0
1Oo_loSo[;kLok?3g_o=f>[on__m02_ooooo00Koo?knoh6ee_l[PK[o3G2`o`=Z[Ol6Jjh>o`M/[P06
o`E[[Ol0Hj[o476aohfkfooOk?GonOcm7Oooool03?ono_koo?clooOgmoo_knooi^KSom>CF_o4H2Oo
]E/SojeH7onhFB?obii_olG3_@Goa<C40_o5aLD00oo6a/KoalO7olO7a`05olS8b0;oalO700?oa/K6
olG5aOo5aLD02?o4a<@0Boo4a<;ojM9YomnnCOo:Xb;oejhTomfa>?o3W3?oj;i0ooKZLoobeegoaIX/
ojj46Oo5OBSo[V`Uom>J<OoGUC7ojL@kombS=?oIUC7o_FXTojYM7ooGW37ohJ`domnZ=OoJVc;oe9Db
ooC>?OnFObSoZUhSomR:;_ngTRoo_gHZon2T=?oJW3?ofIDaombP=?oHZ5;odKB0ol^mXoo7`[Soa/Bo
olK5`?o5`kooaL:molS2]?o:^Z;ocK><om2/M?oDVdgofi/domfR<ooCSBoob6TWomRB;ooQYSGo_Gh_
ojeQ:_o>HBKoc6DWom>@<_mhDc7oXU4Yom5W9ooDQbkodh<^onBg>ooW^c_ob7@YojU77oo3MTCo[/gO
odB@`_l0IJ[o06BYo`I[[P0Co`M/[P07o`I[[_l3JZgo2Ff_oaUg]?lkRkooU/7MooKjo00Cooooo`04
ooomo?ood:3oogd0oomm00Sooh0000WoogT0ooo9TOool^Kooo7SoooI/oooYTooogX0oomg0?ooOP00
1_ooP0001oodPa;oXIFEojZCQonUShKobZb=oogBU_ofcYH01_ogcYH03OohciGon<jEooSAVooheJGo
n>2mooWbi_ojoOooo?kooo;cmonhan3oZkgKoj^mf_nocN<04oooool03_oEg^go/lCOojbnfon[_M_o
[;kKoj^mfonT^=SoaM3TonOZlOo]k_CoYKWHojbnfonX^mWocMSYBoooool02ookno_omOGeong]kOo9
bLWoZ:RXohn?SonFUYKoX:2Pok2`/?o@d=3om?Cd0?oooooo4oooool00?oooooo??ooool00oo`m?Wo
`/oUonW]mP0_ooooo`06ooKio?mo/mKo<hJmo`a_/?l1JJco1V^^3_l7K:h01_l3JZgo06:YoaMf]?nC
_mcof>SboocmoQcooooo00cooOgmooShn?obl_;ojNWYomoA/oo9IR_oaV<XokEJ8onXFQko[eHPolAn
B_o9_ZT8olC4a0OoaLG53?o4a<@0BOo9a;Col=iZon[CGoncQbKodJdLom:[8OoM[c?om>=/ooS]NOob
ff7odjTioj5j5?njRAoo^G@XolZB;ooQYcKoh[0gonW7??oLWC?o/VLXojEI7oo;RBcohZdeomnZ=?oN
YCCoh:TfooCA?on0KB;oY5TQomN9;On[T2oo]6@UomnO=?o=U3?odH``omnW=OoJVc;oeH`_ombP=OoK
X3_oeYQ3omRQBooIXdSoeYHoomJ?=ooLWCCogZ<domF6;OoBOb[ogZPeomnQ<_nhMRco`UhVomN;;OoL
VC;oUVD`okiQ:?o;GbKocf@Woj]Z<om`@S3o`f0WomAo;?oFSC3oil8non_9?oo>P2_o[4lQojQ37on?
N5[o05nWo`1UZol6Jjh04ol7K:h01_l3JZgo0FR/o`a_/?l]Pk_oHJ;<ol3JjaKooooo00?oomN^ooml
0?ooO@002_ooP0001_ooNP3ooiTcoonE:oooM@3oogT0oomo00Sooh0000Oom8<Boj6EUOnZThOoYHn6
olZ/SOomdYKom/jF00?omljF013omljEooO=U?ohciKon=BPooSI[Ooij=7onOOeoo[oooojnogon_[j
ooclnoobloKo^<OPoj^mfon[_M[o_lgS5?ooool01?oam?WoaM7Vojo1gOnZ_MX2ojbnf`07ojRkf_n]
_m_oc]OWojVlf_n/_]_oZ;_IolgHj@19ooooo`0:ooKfm_o/k>coc<c<ojf][On?ShooTi>Coj6QXOn`
/;3oa<C4on_[jooooooo5_ooool00?oooooo??ooool00ooin_goooooooooo`0aooooo`06ongdnOmm
/]Co>HZoo`M/[_l0Ij_o1V^^3_l7K:h01Ol2JJco062Xob1k]onB_m_odnGa01_ooooo00gooOgmooWi
nOoclo?ojn_[on3Ph?oCVfGobF<YolIU:?ncFB;oYe/NojUG7_njJ2oobZn;01[oa<C404OocKnCooGX
LOohiFcoZgl_ol:M8oo?ZaSoejhYooOWLoogk7KolMYQon2jB_nUNQGoYGlHolZ@:?o>SBooej8bomVK
<ooYaScogjLfolZ:<?n[GB3o_GHVon6[=OoOZcGogZHdomfQ=?o[^ccoKU`QojAI8OoCOb_oUg`ZojYE
8OoPW3?o_I0aolAg:ooPYSGocI4colan;OoOYCCogJ8com>7;_oLWC?oh:Peom69<?oCQRooh:TeomRJ
<oo0LbcocgDXomnT=?o@TS3oXf@[olUM9OoFO2[o^XLcohYA;Oo=IRKobEhVoliS9_n]G2[oT4`[omAg
:OoMWSCok=11onkF@_oFSboo]e/TokAA8onmF2GoJGU`o`E[[@0Bo`M/[P07o`I[[_l1J:co06J[ob1k
]_m3T<;oOK7Don?_mP0Gooooo`03oooRaOooR1Goog`000cooh0000?oog/0ooml0?ooP0002_ooP000
4OodPa;oXIFEojZCQonUShKobZb=oogBU_ofcYKomljFooO=U?ogc97omlnIooOFYoohhKkonNkOooWk
oOojo_oon__l00?on_[j00Koo?ckoo;cm_nhan3oZkgKoj^mf_nocN<Fooooo`07omkUlOnnbn?o[;kK
ojZlf_n/_]_oZkgKojNjf@02ojbnf`03ojRkfOo=f>Wooooo04Gooooo00[om_KfonSXj?oIfMWo^;Rh
oiRHV?n>SXkoWIfMok:b/_o6a/KoiNGUoooooolIooooo`00oooooombooooo`06onSamon3]]Oo?Hc0
o`1X[?l0IJ[o1V^^3_l7K:h01Ol0Ij_o066XobIn^?n8^=SocN7_01Wooooo013oo_knoo_knooemOGo
k>c/on;Rh_oJd;WobFT^olYW:Oo4HbSo/ETQojMK7onWFAko[ULPol>8Foo8/iKoaL:l5_o4a<@0B_o2
]Yko^i13ooccNOomlg[o`98hoiig:OoE/AcodZLPonoDHOohkWOolMeUon_;FOn[NQKoWgXFokJ97OoP
YSCobhd^ol^9;OoT]3Wofj8domjQ=?noMROo[f8QombS<ooPZcGogJ<domjU=?oUYcSoOf8XojIN8oo7
K2OoNe/Qoj]B8OoJVC?o[HT]ol1[:?oQXC?o_8Taol9/:OoNXCCoeITcolEg;OoLVC;og:8dokef;oo=
NRgohZHeol67<?ndIR[ocfhWomnJ<?n_Pc;oXeHYoleM9OoHS2koQV@coj9F:_o?I2KobElVolYP9_o6
IbSo_F@YomfI<ooW_cgoi;DkomJ:<?o>MB[ocG8Zom1b:oo:I2WoNhb8o`E[[Ol0HjWo1F^]3Ol7K:h0
2?l8K:ko16Z]o`1UZ_l0J:co;H:joefOb_nfe>Oonocn3Oooool2ooknoPCooOgm0_ono_h3ooooo`03
oooP`OooSAkoogX001[ooh0000oom8<Boj6EUOnZThOoYHn6ol^/S_ooe9KomlfBooO<TOogdYoon=^b
ooWVc_oim>con_kooo[looojno/01Oojn_X01_olo?_ol_?fokS7h?n[_M_oZkgJoko=haOooooo00Go
moSkomGNkOnhan3oZ;_Ioj^mf`03ojbnf`03ojRkfOo=f>Wooooo04;ooooo00[oo?clonWYjOoFe]Ko
^;RhoiRHV?n:RX[oVYZJojj^[_o4a<Cog]kNoooooolLooooo`00oooooomdooooo`05omg[m?n7^=So
>8Vno`1TZ_l0IJX03ol7K:h01Ol0IZ_o066Xobf2^on2]]OocN;_01Oooooo01?oo_knoo_knoofm_Ko
k^k^onCTi?oIfMWodj5]olQQ:?o:JB[o`V4WojmI8OnWFakoZEXOokI?8_neDB;o^G8molJOLoo8^Z;o
aLC101;oa<C404goakRFoieG9Oo<XdCoo_V0oo_eO_oQ]DKoPe/[olVU8ooAYa[oil1=ooO/M_ocgfWo
lMQTokEo6_nNNAGoa9<Son:];ooMYcCo`h4ZombL=?oBSbooe9TaomjW=OnhKBCod98^on2Z=OoLYSGo
dIhcon2U<ooBVS;o`G@ZokaM9?miCago/5TSomV[=OnHM2SoaFLWomjN=?n[PRoo^edVon2M<_nmSC;o
`F/YomZB<?oBWCCoZ6@[om9d:_oOWc;oYgT`ol5U9oo;I2KofI/`ohER<_njERKoeG4Xol:I=_mZ@Boo
`V@Xol]O9_o9GbKobF8Wole[:?o@LB[odgl^om9n;OoBOBcodh@]om>2;OoFQC7odG/]okME8ooQdKKo
S[gJod6?`Ol0Ij_o06BZo`I[[P0:o`M/[P06o`9Y[?l0H:So1F^^od2>`On5]mSoa]g/3Oooool2ookn
oP09oogmoOolo?cono_koo_knoojn_[ono_kooclo?omoOgoo_kn00;ooooo00?oon73oon?8?ooNP00
6oooP0003OodPa;oXIFEojZCQonXTHGo]iZ3om^hT?oee:WonnC4ooW]g?oin?KonO_oooWjoOoinOX0
1oojn_X01_olo?_ol_?fokS7h?n[_M_oZkgJoko=haWooooo00CojnogolWEion]_]_oZ;_J0_n/_]/0
0onX^mWocMSYooooo`0oooooo`0;ookno_oZj^[odm?Cokno_onTY:CoRXZ:oiBDU?n][Jgoa/K6om_K
foobl_80oooooolNooooo`00oooooomfooooo`05omCVlOn9^MSo=HNno`1QZ?l0IJX03ol7K:h01Ol0
IZ[o06>Yoc65_?mo/mGodnGa01Kooooo01Goo?clooOgmoo`l?3oi^KVom_KfooDcl3ocGXoolQU:?o:
JB[o`F0VokYY;?n^FR3o_5LTokiL9On`ER7oYUHNojeJ8OnmODOobZUlolRlY_o5`l003Oo4a<@0D?o5
_[3o^YQ^oi]D8onXF1cog[E1ooW`N?okmh?olmEJoi5L:OnLOR[oek4KombV=?obffWom>=[oo?NJoo<
WCKo]H`Son:_<ooDXB[oeZP[om6D<?oETS7od8L^ol5n:OoX^c[ofJ0com2>;_oOYCGogK8gokN6;OoN
XS?ohZ`fomRF<_o5JbOoUUTQokib:OoH_3SoPEXRolUS9ooEXcGoU6X[ol=N9_oLUc;oZhDaokaM9OoJ
RBoo_9DeojAF9oo@JbSocYPcoiAU;Oo9HbKocV@Vojmk<?mmBRkobUhUonF[>onLPdSoOd@/oliW9oo9
HBOoc6LXoli`:_o=Jb[odWd]omF;;ooFRbooeX`_om9n;?oJU3Oog9`hokUN8onbDBKom^O>oooooooQ
kOGoU<3Lod6>`Ol0I:[o06FZ1_l7K:h01ol6K:ko06J[o`1OYolEM;?oHJ;<oik5gooMjo@03?ooool2
ooknoP0@oogmoOolo?con_[jooWinOohn?SomoOgooKfm_ogmoOon?Shoo[jn_olo?cooOgmookno_oo
h<3ooi<Wooml01cooh0000[olh<CoifBU_nZT83oZYJ<ojJNX_n][KWoalcFonK/m_omoooon__l0_oh
n?T2ooWhn@03ooWin_oin_[onO[j00?onO[j00Konockoo7bm_nhan3oZkgKoj^mf_nocN<Jooooo`07
ooclo_oPi_;o^/WRojJjfOnZ_M[oZ;_IolgHj@0nooooo`0:oo7alOoEeMGo_KfmojNWYon<S8coSHf=
ojVYZOo1`L7ofm_Koo3`l?oooooo8Oooool00?ooooooN?ooool01OoFio;oUL3Moc65_?l0H:Oo06J[
00oo1fb^0_l0Ij/00olaQKcoM:gBomcZm00Dooooo`0HoogmoOohn?SolO7aonSXj?oMgMgodm?Com>i
S_o8HRSobfXZolMX:Oo5P4Kob8YDokmJ9_o6IROo`5dVojiI8OnXG1koYePNok9=8OnbERGo]WE0okn@
J_o5/I[oa<6l1oo4a<@0C_o5`kkoakVKokfHI?nWHB_oWE0NoiI=8?neKRCoh[<conJm?oogjgCon^Q]
okIl;OmbEBkocjXQomRS:?o[aeWomNI_ooKYM_oIZT7ofj`gono?E?oFYS7o/8HJom^U<?oFU3;odXL_
ok=[9?oO[3Koj<<komfR=?oOYCGog[dhoj9a9ooKW3;oh:`eon2X=OoGTS7o_74Yom^O=?o3/3OoO50P
oliU9onoSC3oQ5@Vol]P9_oDWSCoUg4^olAN9OoLTC7oUgdcok5D9_oGN2[o[XlfoiEF:Oo>HbKocf@V
oi9D:onBBb[og8</omg7HOmnHD_oY5LZom9[:?o@Mb_of94`olme:oo9IbWoe88^omJ=<?oERbkod7L[
on2U?_oY_TCo_fLTojM57onhGC3on>oOooknoP;ooooo00kogncdoj?9hOloSL3o062Wo`1VZol8K:ko
1fb^o`AZ[Ol0HjWo066Xoc65_?n<^m[o`=WZooGjo0_ooooo0_ono_h01oomoOgoo?cloo[jn_oinOWo
moOgooGemOoclo<00oobl_802?odm?Com_KfooShn?okno_ooOgmookbi_ooUbkoogd06oooP0003_oo
OP3oogT0ooMi0?nfWg_oYJJaojRbaon/^mKoZkoOojRmgOneaMooc=GWoo?emoomoOconOWj0_ohn?T6
ooWhn@06oo_jn_oal_Ko^<OPoj^mfon[_M[o_lgS7?ooool01Ooam?Woe=k/ojk0g?nQ]]KocMSY03_o
oooo00_omOGeomWIfOnn_[koZj^[oiBDU?n;Rh_oY:BTolK6a_oNg]kok^k^ooknoP3oooooob?ooooo
003oooooog[ooooo00GoenOboi_4golYP;Wo066Xo`1W[00>o`M/[P06o`I/[_l0Ij_o16Z]ocB7_?md
[=;oi>og4_ooool0K_omoOgonOWioo;bl_oYjNWog]kNomCDe?o?c<?obWY1olEN:?o6HBSo`GToolF8
Doo1GR_obFTXolAR9onnG2KoZeTOojUK7onhEBCo]e<TojUH7onWF1koZeHPokAU=_nhPU3o^HUPoknE
Joo2WW;o_i]_ok^@I_nkReKo/70hojEF7onJBAcoYeTNoj=G8?nREbGo_XLaonk=BooL[R[ohk/konW?
E_oBUbkoKT`Zojj?;_oO/bcohZm5ooKZLooilX7ogZ`eonc<E?ocgFKohK<kojIl5onoTR3ogYhcom>5
;_nZHR3odY@aon[6??oT^3Wohk4gomg0>OnDIB?oeY0^on6/=OoOZSCogJ<domVE<_o/`3[o/J4loh5@
9?o@J2KoWV@XohI<9?oDL2SoaZPhohaL:Oo<HBGobX8^ogYH;_o0FBGogihcohM_<onXFBSoc64Vol]Q
9_nZGBWo/F4ZonVe>_oAW3koYePZolid:_oGSS3ogjPdomV?<?nnHRKoaF@XomF5;_oDQbkodGX]on>a
@Oo_eDcobg`Xoje;7on`C2;oaF/hooObjOolo?coo_kn0oooool02OoMjoCoY<[QocN9__l0FjCo06:X
o`E[[OmEV/SoZlgSomKWlP0;ooooo`0;ookno_omoOgoo?cloo_knoojn_[on?ShooKfm_odm?Col_;b
oo3`l?o^k^h00oo/k>`02?o^k^kolO7aooCdm?ohn?Son_[joogcjOonXdSoogl06_ooP0004OooOP3o
ogH0oomn0?ooZE?oo]BWoo;Zf_oQj?;o^L_UojFif_n[_M_o[;kKojZlf_n[_M_o_<[RomgQk_ono_co
no[k00;onOWj1Oohn?T01_okn__olO;gokS7h?n[_M_oZkgJoko=hagooooo00CooOgnonW^m_o2cnGo
amCW>?ooool02oono_kohN7Qokfm_On[Zj_oVi^KohZ:R_nJVY[o_knoom_Kfoo]kNgoo?cl0?oooooo
9_ooool00?ooooooNoooool01_onoooofn[coig5golSOKOo066Yo`9Y[0ko1fb^00Ko1V^^o`5Y[?l:
KZoo<8BlogJ^d_o^mOT@ooooo`12oogmoOoinOWolo?con[Zj_oOgmooeMGEolg=cOo=YW[o_4hSol5I
9Oo1FbKo_ULTol1I9Oo;K2Wo`f<WolQU:OnkG2GoZELOokiL9Oo1GROo^5TTojQK7_nZFB3o]eDSoj]D
7onWFAkoYe@NojQ:7onTDQgoYULMoj==7_nVE1koZU`OojED8OnSEb3oXEHOokIW9_oJ^4golmmVomFV
;OoC[B3ofJl[on6W<OnBIRCoNF4con_<E?oMX3Com^Ueoo;MJOoV_T;on_=monkDG_oX`T_o[h<Loj5l
5_o9URGoeHL]ojUN7oo1OR[oiKHionW7??oQ/cKof;`johAH7_o?Q2_ohZdf0_oOZS@0:ooMX3CoiZXg
ojVABon7E2Soc68UojEP9_nED2CoiY`cojJE=on@DbOocV8UokEU:OmjAbWodW@ZomZj@?mZBRoo`VDW
olQM9_o7GRKoaVTWolmj:ooDQBkodGPZombC;ooOYS?ohK4fomZB<?o:LBWo[58QolUY:?oBO2coeH@a
on[8B?oagE3oeH@`olAS9?o8JB[ocfl/olig?Oodl^conOWioo_knoomoOd00_ono_h2ooooo`05omo/
mOnadNKoNJoCol_Qk_oYl_P01oooool3ooknoP;ooOgm00_oo?cloo_knoojn_[on?ShooKfm_odm?Co
l_;bono_koo/k>coj^[ZonSXj003onKViP09onWYjOo/k>col?3`ooCdm?ohn?Sono7XoofUBoonOP3o
ogl001Wooh0000Googh0oon?7?oo`XKoonK=ooodj@03ooooo`04oo;fn_oBg>_o[;kKojNkf@;o[;kK
00KoZ[cJok72gOo3c^ColO7fookmo?oin_X2ooSinP;onOWj00Oon?Wjoo[knooal_Oo^<OPoj^mfon[
_M[o_lgS01oooooo00?omoWlooCfn_ooool0=Oooool02_oQhN7o`/;2ojb/[?nPX:3oSXj>oiFEUOnj
^[[of][Jong]kOohn?SoooooobWooooo003ooooooggooooo00KonognonOamonOa^3o77Reo`1UZOl5
Jjd>o`M/[P06o`I/[_l4JZgo2fj`obAm]om`Z]7ol_Ok3_ooool0L?ono_kon_[joo?cloo[jn_oh>3P
omKFe_o=cLgoc;NKokmE9OndF2Co`64UolET9Oo1H2Goa60WolMX:?o4HbSobVLZokMH9?o1GbKoaFHX
ol9O9onbFR;oZELOol5Q9_nlGRGoZ5POojYK8?nfF2?o[ULQojIJ7_n`Fb7o/5dTojII7_n`GB?o[60U
oi]A7_o3MRSolMURoo[_M_o6VCKocjPVolj/6_oI[bSodZ<^ogUK;_ngVcgoiZlgoo7JJOoU^d3om>=/
oo_fPOo[beCokm9MokR;8_nNNAGo[h@IomVI:?n^I2;o/VlUomnS=OoU`3[oe9/`om6d>OmhDA_obGXW
omnX=OoOZSCogjTdomfR=?oLW3Cobi4cok]f:_o4GRGo^fDWok=]:OoccT?oU892oiiE9_o:GRGo^f@X
oiYD:OoZ/3Wo^JaOogI9<?o;IRKobV@Vola]9oo@LbOodW/ZomRD<?oOZ3Coh:deon2]=?oKW3;odWd/
ok=Q9?nYBb3obfTYom^E=oo`fDkoln=BomVC=_o?Mb[oeXTbomnM?oo5KB_o`6Xionk/j?oclo?omoOg
ooWinOokno/2ooclo0?ooOgm00?om?OjoogmoOomoOd01?omoOd3ooclo0;ono_k00gon_[jooWinOoh
n?SomoOgooKfm_oclo?olO7aono_koo/k>cojNWYonKVi_oShn?ohN7Q00;oh>3P00Woh^;RonCTi?oX
j>SokNg]oo;bl_ofm_Kon^kRoobRA_onOP807?ooP0000oooOPGool>6ooooo`05ooooo`0<oocmo_o`
m?Wo`LoUojNjfOn[_M[o[;kKoj^nfon/_]_o]L?Nom7Hj_oinOWono_j1?ohn?T01_ojn_[olO7fokS7
h?n[_M_oZkgJoko=heCooooo00_ok>c/okjn__nUYJGoWIfMoiBDU?nCTi?o[:b/omCDe?o`l?3onOWi
ooknoP3oooooob_ooooo003oooooogoooooo00Konognoo3fn_nKa=ko4g>bo`1VZ_l6Jjh?o`M/[P05
o`I[[_l:KZoo6WNdogJ^doodnO`03?ooool0Loono_kon_[jooCdm?o[jn_oh>3PomKFe_o>c/kobl>c
olY/<_nhFRKoWEHTokEM9Oo6I2Go`5hUolER9oo2HRKobFLYolEQ:?o4HBOobF/Yol1N9_o5I2Oo[U<Q
ol=T9_o7IbSo/e/TojQF7onoHBGo^UlTojQG8?ncGR7o`6/XojAF8?ngHR?o]fTYoiQ?8Oo?SS;on^me
ooggOoo@Yd7o/hT/omFb7oo;ZaWoek4Som:U<?n_Qboog[4donFi?_o^e5[onoF0ooS`NooZb57omN1/
oknA9_nPNAGociTSomZT:?nnOb;oYf8QomNF<_oQ/SSob8X[olZS<omaC1Wo`flUombT=?oPZcGogZLd
ombQ<ooKX3?oh:LdomfJ<ooCQRoocWX/om^M=?oWdUCoR7ACokEQ9oo6G2Goa6DWolQl;OoZ`4Co^8a@
ojiR:OoCMbOoe88ZomB5:oo>L2SoeHT]on2^=OoOZSGogj/eomfV<ooFPbko_g4Xoj=77on]CR7ocg@]
ooCRDOodiU;ogIliom5m:OoJUSSojKaAol]l<OnYAQko_FTionKTgoo/k>col?3`oo?clooemOGom_Kf
ooOgmoohn?P02?oinOT2ooShn00LooOgmoofm_Kom_KfooGemOodm?Colo?coo;bl_o`l?3ok^k^on_[
jooXj>SoiNGUon;Rh_oOgmoog=cLom_KfooJf][ofm_KomkNg_oQhN7oi^KVon_[joo`l?3omOGeooWf
m?okZ5GooGX3ooio01cooh0000?oogl0oon22?oo/6401oooool01?oko?gohNObokC4gonZ_=X3ojbn
f`05ojjog?nib>7oh^O`ookmo?ohn?T00_ogn?T01_oin_[ol?7fokS7h?n[_M_oZkgJoko=he7ooooo
00_olo?colW9bOnXZ:SoWIfMoiNGUonEUIGoZZZZom?Cdooclo?on_[joogmo@3oooooobkooooo003o
oooooh7ooooo00GooOknooSko?n=_=[o4W:ao`5X[00Ao`M/[P04o`I[[_lAL[;oOk?FooGio0[ooooo
07Coo_knoo[jn_odm?Cojn_[on3Ph?oFe]Koc/k>olW8aOo;P4SobfDXokAJ9_n=EBCoXeXTol5P9Oo3
GRGo`V4VolAS9oo6H2SoaV<Wola^:Oo0GbOob6LYol1L9_o4IBOob6TXolAW:?n^ER?oa6HVokmT9Ond
GRCo/E/Qolac9on]GRKo]64Sol9_:OnUG2Kod:4loogeO?olmh?ok<eGoiQY:Oo<Z2[ocjdJol^[6OoA
[QgofZl[omj/;ooX`TOon_AoooWaO?ohkWWojLM?oo[[MonnTRoo]X@Ioo3?DooJ/3_o/H<Hok9b7oo:
R2gogJ<eok]e9Oo5T2goLDhKokeV9?oEV37oh:`eombW=OoCW3CofYTaon2/=OoNYcCofilcomVF<ooH
SS3oeI<jokQj=Oo=NB_ocgH[om5l;?oDPRgodX4]omR8;_oMUC3ofj0bomnX=?o@OR_oc6/Xom9l:_oN
Z3CogjXdon2/=OoFRBkocH</ojUA8OnUBAoo/4lRomJ0<Oo]g4ooeYdgom5l:OoPZ4ColMMOom68=On/
BAko[DXQol9X=OoMf<oohn?SonOWiooZj^[okNg]ono_koo`l?3olO7aoo;blPKolo?c013ol_;boo7a
lOoalO7ol?3`ono_koo^k^kokNg]onc/k?oZj^[ojNWYonKVi_oTi>CohN7QomgMgOoKfm_of=SH0ooF
e]H02ooHf=Sofm_KomoOgooUiNGoj^[Zoo3`l?odm?Con?Kfoo^eL?omO0;ooWl001oooh0000?ooh42
oonO@?oon_L01_ooool01?onoooonocmolkIjOn]_m/4ojbnf`0;ojfofoo4cnGolO7gooWgnOofm_So
n?Siono`mOnhan3oZkgKoj^mf_nocN<0C_ooool02oolo?coclo?ojZZZ_nKVi_oVIVIoiNGUonSXj?o
bLW9oo3`l?omoOgoo_kn0?oooooo<Oooool00?ooooooQOooool00on8^MWo6GReo`U][`0Ao`M/[P05
o`1WZol9KJooOk?Eoo3en_okoOh01oooool0Loono_kon_[joo?cloo[jn_oh>3PomKFe_o>c/kob<S8
olfLJOo8I2Soc6LYokAI9_n7EbGoTETUok9K9Oo2FbGo`EhVol5K9oo8IbWoc6hYolIV:?o2H2Kobf/Y
ol5Q9_o7JBOobF/Xol5S9oo7JBOo`FHUol5X9_nhH2Gobg0Vol5^:?nlJ2Go`F`WolEn;OoO]SOojlY9
ooS^NOojjFko[WP^oiek;OoI]27oc:`Jolb[6Oo@[1oogjhbonBg?oogk7Kon_=nooS/M_oYaTkon_9n
omFT=_oN/S_on>Ybon>kA_nTNaCo[h4JolV::OoLVcCo^FlTol>ICOmmGbko]f0RolN0:_oMYCCog;0f
okn=<?oFSBkoh:/eon2Z=?oOZcCofYLcomRE<_oKVc;ogYTbomVE<OoIUc7oeHX^omF8;_oMY3CogjTd
on2/=OoQ[SGoei0^okU[:oo8I2Oocg<YombR=?oR/CWoeHP]ombC<_o1N2goXd@NojE;7ondDb?o`W4^
ok5c;ooCR2ook<EDooCRI_oITCWo`5lQolAS:?o;IBWoaVD`omK<_OoIfMWogMgMon3Ph?oShn?oiNGU
onKVi_oXj>P00_oYjNT4on[ZjP;ojNWY00koj>SXonOWiooVi^KoiNGUonCTi?oRh^;ohN7QomoOgooN
g]kofm_KomWIfOoGemOoe=CDom;BdP;odM7A00codm?ComGEeOoJf][ogmoOonCTi?oZj^[ol?3`ooGe
mOoim>koo;A]ooeh0?onO`0Qoon00004oomo0?ooSaoooo3Qooono@Oooooo00?oloOjokg;hon^_m`0
0on/_]/02_nZ_=[o/<7LomWOkOodmOSomoSionk`mOnhan3oZkgKoj^mf_nocN=9ooooo`05ookno_ol
o?com_KfomcLg?nc/k<00_nHV9P01?nKVi_oXj>SolO7aooYjNWoooooocKooooo003oooooohKooooo
00Koo?knohBfeolQNkKo2fj_o`E[[Ol6Jjh>o`M/[P06o`I[[_l0I:[o36n`oh^jf_oYl_SonOcm1Ooo
ool0L_omoOgonOWioo?clooZj^[ogmoOomGEeOo=cLgob<S8oljfSOo6GROobFPYol]U:OnbEbKoR5LU
ohQH9OnOEbGo]E@TokeF9?o:JBWoc6hYol]^:OnoGRKoc6/YokeV9OnlHRGob6PXolAU9oo8JbOoaFTW
ol=Y9OnmIROo`VPVolM`9oo2K2Ko`6TUomRU?OoafU[odjPWon:m>?oehfSofJ<kogMB:_o9Y2[ocjdI
ol^Z6?oG[BSoh[0fomfX;ooX`4Son_9mooKXL_oZb5;om_20omN`@OohjW3ol]iWonS5DOnZOaOoWgXF
ol6?7ooNW3?ob88[okIf;omlEb?o]F0Qol=f9ooPYcCofkPhoj]j:_oBPbgogjXdomn[=?oNY3Coe8db
omZJ<ooP[CGoh:/domn/=?oNYCCoeHL^omF7;OoOZcGogjXdomn]=OoNVRoo`WX]ojYP:oo;HBKobfPU
on:cE?oS/D[oe7lZomZZAOnaHBkoXdHMojA97ongEbCo^ehXolYk<?oU[d[ohZY9omN:=oo@NBWoe88b
omV:>oo1HROo/4lSom71Z?o@d=3odm?ComKFe_oHf=Sof][Jom_Kf`;ogMgM00?og]kNomoOgooOgml0
0_oOgml03_oNg]kogMgMomgMgOoLg=cofm_Kom[Jf_oIfMWof=SHomOGeooEeMGoe=CDom;Bd_o@d=3o
clo?0_o>c/h03Oo?cloodM7AomCDe?oIfMWogmoOonGUiOo[jn_olO7aooKfm_ojm>goo;A_ooif0?oo
O`008oooP0001?ooOP3oohD:oooI/_oonoH8ooooo`04om[Skona`Mgo[KoKoj^mf`;o[;kK00SoZ;[J
ok[7h?oVj_7ojnkdokO7h?n[_M_oZkgJoko=hdOooooo00[ono_kooOgmooRh^;o]KFeoiNGUonDU9Co
W9bLoinOWonl_;cog]kNooooooliooooo`00oooooon8ooooo`06ooSkoOmm/]Co:X6io`a_[ol3JZgo
1V^^3_l7K:h01_l5Jjgo06>Yoa9c/_nF`MgohNgeoo[lo@?ooooo01WooOgmooWinOobl_;ojNWYomkN
g_oDe=CocLg=olO7aoo<`:Co`5DWol1G9Oo3GBKo`e/VokQH9OndFRGo]ETUok]H9?nlDbCo^eHUol5L
9_o6I2So`ElWolIS:?o7KRWoYf4S00;o`60V05Sob6/Wol]_:?nnHbCob70WojmN9_o4JRKo`6TVolei
9_o]deconNmgolJN<oo:Ya_ogKP^onJ`=onNL3GoSg<`on?3=oo=[Akog:h]on[2AooCYS?oci/WonoA
F_o^fFgojleJooK]OOoL]DSon_5ioo;MIoo^dUoo[X<Ioj9l5oo<UAkod9@TomBA;onfMBGoNU<LokIO
8_nkJRCohj`folZb=_nUL2KocWXZomnY=?oPZcGoei/dol:1<OoIU37ogjXdon2Z=?oOZSCof9Hbom5n
;?oBOR_ogjTeomnZ=?oNYC?ofHd]oiQ]<OnhG2Sob5lVolYV9_oHSC[oehLaolZ3;?nkLcGo^FH[okAC
8_nlFbKoaV<Xolm/:_oEPC7oe8D`om>5;?oCPB[ofI0lon>/Doo3KbkoZ4LOoji78Oo?/hgob/[:olc<
c?o>c/koclo?om7AdOoBd];odm?C0_oDe=@4omGEe@;oe=CD00Oodm?Com;Bd_oBd];odM7Aom3@d?o?
clooc/k>00;ocLg=0_o;bl/03_o:b/[obl_;olg=cOo@d=3oe=CDom[Jf_oPh>3oinOWong]kOoclo?o
moOgoo[elOom^WKooW@06_ooP007oomo00?oogh00_ooO@001?ooN`3oogd0ooo5Rooon_D8ooooo`03
oo[joOo6d^Ko/L7M00;oZkgK00So[;kKojVlfOn/_M_oaM3Vok?3gOn[_]_oZkgJoko=hdCooooo00_o
n_[joo?clooShn?o`/;2oj6QXOn?ShooVi^Koj>SXonj^[[ofm_Koogmo@3ooooooc_ooooo003ooooo
oh[ooooo00KoloSkognce_lgR;ko2fj_o`1X[?l6Jjh>o`M/[P0Fo`=Z[Ol0HJWo6WRdoi6mfooEi_7o
oOknooooooolo?comoOgoo3`l?oWinOog=cLom?Cdoo;bl_oalO7olS1/_o6JC?o^E<TokiM9?o7IBGo
afPUolMW9@;oaVLU05_o_UHUokUA9?ncEB;o]EHRokQC9?njEBCo`U`WojEK9On^ER?o^ePTolY/9oo>
LRSo`6DUolaa9on[I2Oo[U`TokmU9?oKVCConO1eoogfOooG/4Go/8/Solnb6?oG[BKog:E4ogaY>oo6
YCgoj]9Don2_<_odgfWog:lkojb16ooJYc;ogZHjongCHOobj87ogJe:ooKYLOoch6_olmm/ojj47?o0
T1oohk0fokN76Oo0S23o`H4Woh1M7onjJRGo_VlUonk3>on_WS3oY6XUolYc:OoNYcCogjHdomBL=?n]
Kb_of8`_on2Z=?oOZcCogj@colN:<_o8LRWocgHYomfR<OoP[SKogYD`okN4<OmjBRgobF<VolMN9_o9
IRSocF/Wolmb:_o7JRSoc6d[olm_;?o@LB_odFl[olaU:?o?LR_of94aomJ<;_oBORgohJM>ong;Ioo9
Mc3o/d/MokiL9Oo2F2GobheL00;oalO700Cob<S8olW9bOo:b/[obl_;0_o<c<`6olg=c@;oc<c<0_o;
bl/2ol[:bP;obLW91?o8b<P03_o:b/[oc<c<om3@d?oFe]Kog=cLon;Rh_oYjNWokno_ooCdm?ohn?So
no[joog6T_onM`3oogl02?ooP0001?onPP;ooh00oon00?ooP003oomo0004oomn0?ooO@3oogd0oomm
00Coog`00_ooN`002OooO03ooh<6oon42OooP`KoohTCoon>7OooSA_oohlNoonF;@02oonG;`06oonO
?_ooXD;ooj12oonUBooo_WkoonO?2_ooool02ooWk?Go_lgSojk0g?nY^mWo[;kKoj^nfonX^mWoZkgK
ojbnfon[_M[o_lgS047ooooo00_oo?cloo;bl_oRh^;o`l?3oj>SXon:RX[oUIFEoiJFU_nWYjOoeMGE
oogmo@3oooooockooooo003oooooohcooooo00Kok?CiogjceOlkRl3o1V^^o`1WZol6Jjh>o`M/[P0D
o`1X[?l0HJSo8gfgoi2mfoo?h^oono_kooKfm_o^k^koi>CTomWIfOo@d=3ob/[:olK6a_o5`koobWY1
ol=O9onXEBCo[5TTolAO9Oo8IbD2olIX9@1LokmH9Oo3G2Oo^5LTojiO8?n_Gb3o/5/Qok5G8_ncEB?o
]58SokEA8onhFBCo_UdUokUJ9?nkGbCo^6<Toim@8_naEakoh[M3oo_fO_okmh;olmQMoj5c:OnoXAoo
d[8Lon>V>OnlZ5_oQFX^on[2A?oW_d?onO5oonW1B_nZNQWo/8LMomnW;OobfVKojnB>om;0S_obgfSo
m>1/oo3QL_o4TbWoi/99onW5D?niRQooX7/Fok^57_nPMbGo^gLZomFH;ooff47oX90nojEX9_o7KRSo
gjXeon>X=OnnV3?oZfDWomB3;_oOZCCogjPcomVL<_ndPc7oaVHWola`9ooW_DkokL]NomfJ<_moGc7o
Ue4ZoliS9_o6GRKobF8Wolme:ooANbgoe84^omB5;ooDQS3ofH/folQZ:?nkF2Cod7<[om>5;?oEQSKo
k<UUoo?LLOoCOCCobV`TomR?>ooHS3go]E<SokME:_o8`K42olG5a@;oa/K60oo7alL5olS8b0CoalO7
0oo6a/H3olG5a@0@olK6a_o7alOobLW9olc<c?oAdM7oemOGomgMgOoTi>Cojn_[oo7alOofm_KonOWi
ooclo?onc9Woog/0oomm00?oogh000Ooogd0ooml0?ooO@3omG`8onR66?oaUQoooH<800?oogT000So
ogh0oon62oooQ0SoohTCoon@8OooTB;ooi0OoonK=`;ooidk00cooj51oonYDoooZE?oojeKoonoP?oo
`hKookn0ooo@XOoog;[oomZeoooN_Oool^@2ooodjA7ooooo00GooOgnomSQkongan3oZ[cJojZmfP03
ojbnf`03oj^mf_nocN?ooooo03kooooo00golO7aon?Shoo:b/[o[Jf]ohn?SonATI7oYJFUokVi^One
]KGoUIFEok2`/?oOgmoomoOg0?oooooo?_ooool00?ooooooS_ooool01_oQkOKoPKCFocR9_ol0Ij_o
06JZo`I/[Pko1fb^01[o06N[o`1PYolYOkSoR;OEolGHi?oZj^[oh>3PomKFe_o>c/kobLW9olK6a_o4
a<CobH1=ol]W:Oo5HBSoWUPSoiII8oneFBCoaV0UolQX9Oo0G2GoaF0XolMT:?nfER?o[V0PojiQ80;o
[f4P05Co/5lQokQD8oncDB;o[UDPojmE8On/Db7oZe8PojY=7oniLBWoj<Doon[;B_ogjG?onnmdol>@
=?n@L2OodkDKomRO:oo_cfKoPg<oolRI:oocfF3onoJ5oo3@FOnlQ1ooUgHDokf>8OoX_4Coj<]Zom:h
P_oZcekomnUeonC@H_oN/3SomnYconBoD?nkTBSoWGPDok>46Oo2R2;o_hH]onVn>Ooaf5;oYIU[ojUZ
9_o3IbKogJHdonVc>?nPQc7o/5dUom1l;OoU]c[oiK<kolVJ=?nTKbcoc6DUolUZ9Oo[bfCoi[5;ol>8
;_mY?Bgo`F8XolUP9_o7GRKocg<ZomJ><OoHTC;oeXh`omF8<OoSZdWoe8<cojeC7oneE2?ocf`ZomjO
BOogj7Som>9domJ8=OoCQ2goiKIBom^NB_neERCoZTPPokA:8_o=YWX6olC4a0OoaLG52?o4a<@03_o5
aLGoa/K6olW9bOo<c<cod];BomSHf?oOgmooi^KVong]kOobl_;omoOgoo[jn_olnOKoo/:60_ooM000
2oooN`3oohL>oon52_onQPkom8lSon26:ooJTCCohkE4ooJoC_omZDWoojA800;ook9U00Wook=Voonm
NooobYGoolN?oooAXooog[goomo0oooM^_ool^H00_oom^d00oooo?[oooooooooo`0Nooooo`08oo7d
nOo;e^So[l3LojRkfOn[_]_o[;kKoj^mf_nocN<looooo`0BooKfm_oQhN7obl_;ok2`/?nATI7oSHf=
oinOWong]kOobl_;onWYjOoooooojn_[okZj^_nHV9SoSHf=okJf]_oTi>Coo_knoooooollooooo`00
oooooon@ooooo`05omWYlon9^MSo>HZoo`1RZOl0IJX03_l7K:h08?l7K:go06BXo`1OX_lZNZooLj70
ok?3cooCdm?oc<c<olO7aoo5aLGoa<C4olbAG_o9I2WobfPZolQO:?nLEbCoR5hSoiiI9?nkFRGo`eTU
ol9M9oo=L2WoaF0Wok=F8_n^HB3o[f4PojiQ8?naGB7o^eDUokeF9?n`Fb7o[f8P0_n_H200DOn]F1go
hKQ;ooGQHOoM/bcog[XcooCRI_o[_4OoR5hZok6F8_oIZB7oi;=@okJH=OoI[SGon>Ydoo[dQ?ocgFGo
bXlVoi]d5OnMNaKobYTXomnP=?oDQRooiKU8ooW`OOoV`4Sol^1YooGTK_oVaESo^Y0Zoj5h4ooAVb_o
a94SokR77OoT_3Koim1_oi=cB_n^KbKo_f4UomZH<_oU^ccoSgLaokEJ8oo>NBcok]59onk1AonYR3;o
[6PZolUO9Oo9JBKofI0honBW=onEGBooP4//om5c:Oo6FbKoc6XXomN=<OoGT3;oeHT^omF6<_o^cE_o
gia0okIL7_nRB1oo]U4QomEn>?omnX?om^MgomB5<_oGT3KolMU]on2ZDoniE23o^eDRolQT:_nmDRCo
^UL/ol[1[?o5`k_o`;FNolC4`P0@olC4a00LolG5aOo6a/Kob<S8olc<c?oAdM7of=SHon3Ph?oWinOo
k^k^ooCdm?ohn?Sono_koogmoOonmN_ook]goonmOOoo_h3oolB9ooO;VOoIVfGobX53om6D?ooT^dOo
l=MAoo[X[_oomo3oooSaoooilS3ooooo00KohNScol?@iOnY^m[oZKcJoj^mf_nocN<iooooo`0;ooSh
n?oNg]koc<c<okFe]OnFUYKoR8R8oi^KVoni^KWoclo?on?ShoomoOd01?ooool01oono_kog=cLok2`
/?n;Rh_oVi^Kol?3`oo/k>`0oooooolkooooo`00oooooonBooooo`05omGVl_n<^m[o<hJmo`1PZ?l0
IJX02ol7K:h0Lol7K:go1f^/o`MYZOl7IZGo05jMo`1HUOlZL9ooI92/ojZg`?o6a/KoaLG5olC4a?o8
TVSo`5@UolEN9_o7GbOo`ELUoiYG8on5Gb?oS5`SojYE9?o4FRKobfhYol]/:Oo1FbKo/ETQojeQ8?n`
HAoo/UXQokaG9Oo7HbOo^UPTojiM8?n_HB3o[5`Ookeh9Oofj6gon>edomB/>Oo@[ROofKL[onVm?_o0
S3KoPF`]omnk=?oATc7oa9PUonc9BOoil7konO60ooGVL?oJWS;o[X<MoiYh5OnUOa[oeZ0/omZC;_oO
ZCcoj/UBonW6COolnXGok]EPon[AH_nbRBSo^hTOon[7EOnlT2[oX7TDokJ:7_oGX4OoNT@SokEj9_nn
GRCoei8aomo3B?n9J3Go_5/Tolae:ooU^3goi;<johU/<?nmK2WoaU`UolQV9ooFQb_ogZY2ogi==?nR
JRgogiT_olMM9OoEQBkof9<bom>4;OoHScSolMUPonRhCoo4JR7oYddOojA:8?ndCb7odgLdonWCJ_oH
UCoog:14ong>JOoT[UKoc6dVolif;?oJT47obG0bok1<8?nYB27o[gI6oij2D?o5_:404Oo4a<@06?o6
a/Kob<S8ol_;booAdM7of=SHon3Ph?oXj>Sokno_ooGemOoinOWoo?clookno_oooooooochookmo?oc
j=Sog[jTolnGJOo3McOod98lonBlB_o^ddkol]mUoo[ccSGooooo00Gom_Skom[Rkonfa]ooY[WHokk=
h`0gooooo`0:onSXj?o9bLWo]KFeoibLW?n:RX[oUIFEok6a/Oo<c<cohN7QooWin@Wooooo00Ool_;b
olo?conPX:3oSHf=ojVYZOo>c/koo_kn0?oooooo>Oooool00?ooooooROooool4ooknoPOooooo00Go
dnGaoi>og?l/P[[o062Wo`1WZ`07o`M/[P0Ho`M/[Ol7Jjgo1f^/o`MYZOl7IjKo1VBQo`IQW?l5GIGo
05B=o`1BROlZJiGoGXRSoj^e_?o4a<Cob9E_ol5J9_nbFb?o_f@Uol]Z9_o4H2CoYUPToi5S9_nCFB?o
`UPV0oo;K2T0F_o0FBKoVe@UojAP9?ndFB?o_e/UolY[9oo6HbOo]EPRojeO8?n/Fa_ogKA3oogiPOok
mGooh;a7okjD;_o@/B7od;0SonJk>OnBMS;o/9]6on6V>OoIYBgolMYPoo[bPOohl7komnefon:Z=oo<
QbOoXWXHoiYh5On/Q1cofJ8^omnW<?oV_dGon?1koo_fPOoZc5Ook=]]okF6:OoT`E3okme[ojf19_nR
O1GoYWdFolB47OnOKB3o^gdYokQI9?oMXcGobYXlogi:9_o4H2GobG4ZomjN=OoAXSKoOU8[olY^:?o3
FbGoaF0TomZC=_oP`ecoMDddolfF>OoY_TOodGTZomVE<OoBP2gogZ52ooOZJOo]aeOob7DUojYC7onV
BB3oY4XPok1?8Oo;HbSoaFl/omF8>_oMVTGoeXLbom5k:?oJUSooikEIolen>_nYCR;oUe0UoheI:?me
D2KoW64holVnZQ3oa<C401SoaLG5olO7aoo:b/[od=3@omOGeooOgmooinOWono_kooemOGonOWioocl
o?ono_kooO_hoo7TcooI/i7o`WmBokaX:_o:PS7oeZ51ombcA_oWaDGokmM>ooGVPOoln>Dhooooo`03
onkamoo=f>[o_<_R03Cooooo00[ok^k^olk>c_nh^;SoY:BTohj>S_nBTY;o/;2`olg=cOoRh^;ol_;b
3_ooool01_oXj>So`l?3oi6ATOnEUIGo];Bdon;Rh_oooooo>?ooool00?ooooooQoooool2ooknoP03
oogmoOolo?coo?cl00Coo?cl0_omoOd4ooknoP05omWYlonNaMoo:H2io`1QZ?l0J:`01?l7K:h0NOl7
K:go1f^]o`MZZol7JJWo1fNVo`MTX_l6HIco1UjGo`IJTOl4EXco05:7o`1;P_l0BX7o55^;ofV>Yoo;
WgGobVDYokeM9onNFB;oZF4SolAV9Oo9HBGo_fL^ok5Q9_noF2GobVXYolY/:Oo;KB[oafTWokED9_n8
DB[o[e@VolEO9_o;L2SoafDWolET9on`DQooa8P[on_;@OoafeconoB1ooOTIonoSbko_Id[olnb7_o?
/B3odZh]ojB7<_oK[CSoi[TjooKZM_oil7kon?1oooO/K_oS/cOodiYAolB>=_nONaOoV7LEol2A8OoO
YBOol]iWoociQ?oil7_ojlaGonCCIoo5WcconnmgonOAHonVObOoY7XColRE9_o5SB?oZh8Hojij7Oni
J2;ofYLaojMK:On:FRGob6<UolM[:?oT[COoZF`]ohYI;Oo8LC3oa5/UolAM9?oKRcKoakELogm:;?o^
bF;oh:A;omjS>?oCP2gohjm;oo[cKOo`dUgoeHTaojU/:OnQAB3oZD`Pok5B8_nnFRGobE/Vom5f;?oG
Sc7oe8L[omJ9<ooY_5_oj/QXokQ]=?nCCB;oR5HYohUM:?mfE2OoPdTWokA98_nhERko`YIcolNjZ?o4
a<<03?o4a<@06?o5aLGoalO7ol[:b_o?clooe]KFomgMgOoVi^Kok^k^ooGemOoinOWon?C_oncJ`ooC
YXKo`7M9ok]P9Oo8Mbcoej0kom^gA?oCZCoodI/don6e>oobgUGomn^MookmmS[ooooo00?on__moo3c
nOooool01oooool00ookno_on?Shooooo`0Vooooo`0;ooShn?o>c/ko/k>cojFUYOnEUIGoRh^;ojZZ
Z_o:b/[oinOWoo?cloono_h04Oooool01oojn_[oiNGUoj^[Zon>SXkoXZ:Rokno_ooemOD0oooooolf
ooooo`00oooooon7ooooo`05ookno_omoOgono_koo[jn_oinOT01?ohn?P2ooWin@;on_[j0_okno/0
8oolo?con__komgZlonL`mgo87Zeo`1QZ?l3JJco1f^]o`M[[?l7JZ_o1fVZo`MXZ?l7IZGo1VBQo`AO
Vol0FIGo05>>o`1=Qol2DhWo8fFAodQjVomdU:_oU:Rdojbf_?o9Ug3obFHYolaW:Oo2GBOoVEPQoi1O
8?nXHR?o^ehTol9H9_noERGobFXY00;obfdY06?oaV/Xol1P9OnbDbOo]58UolMU9_o=LRSoafHWolUW
9oo6K2Kok=MMoo3JG?oE[RSoila6ooW^M?oU^TGoX7HZolb]9oo;[Qcoc:lNomFc9ooN]3;ojLE7ooW`
O_oilH3on_5oooCTH?oS]S[odjYVom2/K_nkQ2?oZH8HomNP9?oMYB[ogj/aooGUKoodjGOokLeHolBe
G_niW4GooO5fomo<HonKMAoo`Y<VonG3EOnkRb[oY7`Foj=m5_nkPago`7lQoj1J8omfDRGo]ULUomB4
;ooY^ScoTEL]oi9T;on^LSSob5dVolEN9_oENB_oTVLioiiQ<_oMSc_ogIhlon:[BOoX_e?onoU`oo;J
H?oJSC7o`iU1oiiF;OnnFRGob6DWolYR:?o2FBKo`U<Uom1f;?oHSS;ohJA;onS?J_o:]UkoUV8_ohME
8on>IBCoTFLRog9>8omhCB[oaG0bokAD9_nY@akoZTDOojm@9onkNU7o`I]hol:YT?o4]ZCoa/2dolC2
_Oo4`l801?o4a<@06?o4a<?oaLC4olK5a?o9alCocL[5om7:_ooCaK?odKZVom2aV?o9YXWo^Y9hok=o
I?ndICko_5lTolMb:?oCSc?og;91omZm@Oo:VS?oa80Yom2>:_oU]coomN=RooW`^TKooooo00?obl_;
oj:RX_o=cLd08oooool02oojn_[of=SHokNg]onUYJGoVIVIohb<S?nTY:CoaLG5onKVi_oclo?ono_k
01Kooooo00Kolo?comCDe?nKVi_oU9BDojZZZ_oAdM7oooooocGooooo003oooooohKooooo00Soo_kn
oogmoOolo?con_[jooShn?ofm_Kom?Cdoo?cl`;ol_;b0_oclo<2ooCdm00HooGemOofm_Kom_KfooOg
moohn?SomOKhon7ZlOnH`=Wo5G:_o`1RY_l5J:So1fRXo`5SY?l0H:3o05ZJo`1HU_l@I9[o@WjUofbD
[on@Z;So[KRookBk`?ni_/7o`<;20_o4a<@0Roo9TVSo`EDUolIO9oo:HbOo`UXUoj]K8onUG2;oZe/S
ok]G9?o0DbGoa5`VolAM9oo4FbOo`UXVokaF9?o2EBGo_U<UolQY9oo=LRSobFXWolEQ9?oW_4Woo?V0
ooS[LooCZSKoajLPomg1<oo/adCo`H`aoj24;_oH^b[ob:/Jolb_7ooR^cGohkLfonW6BOofj7?oknAd
on_FDOoJ[CSoeI]4olc1YooBU3SoeYdRon>a=OoKZS3oaI0Mon6_=?oM[TCok]1Nolc0IoneVTConNM/
omC8I_nQMB3ok]=QomfnD?nXORGoY7/DokJ78oo2SBgoXgXGojUn6OnRLQko^6PRomfU=OoYa4coSg8n
okZ8@?o;Se3o`eTTolEN9_o=K2OoRD`YokU_<OoEQS7ohJY9oo;JH_ohl6_oi;=>om9g<oo@MRSocWP^
om9j;?oCNbgobf/]ol1F9On[CB3o^e0SolaM:_oDYE;o_ZECoiQa<_n>GagoVW0Koief6onKMAgoKDdP
of]C=Oo:V4co_6Taoji<7_nlJ2co`WLgojiA9_nX@QgoZTDNoj]=9?nQAB;oZE0XojmN=?nbKDKo]H1H
ojagG?n`Mego]WeHok1_BonVJD[oVUi6ojER?onYERooYTdWojaH9oniMCKo[GDloiYI;onWF2OoaG4V
om:8;OoFWSSofKQ1omNo>oo6Tb[o^6PQolMo:OoLXC;oj;m4ooCSLOokmMD0Aoooool01Oo=cLgoUIFE
oiVIVOn`/;3ol_;b01oooooo00[og]kNokNg]onQXJ7oVi^Koi6ATOnGUiOo^[ZjomoOgoodm?Con_[j
6_ooool01oomoOgokno_okfm_On=SHgoVi^Kok6a/OoZj^X0oooooolcooooo`00Voooool01Oobl_;o
Hf=So`T92OmFEUKoa<C40>Gooooo00Woo_knoogmoOokno_on?ShooGemOobl_;okno_ong]kOo/k>`0
1?o[jn/05oo/k>cokNg]onk^k_o_knool?3`oo7alOobl_;olo?coo3al_oYkO3oS[OBoa=^ZOl2HZ7o
@HNcof^M_OnD/lOo_LWAolc@d_o9c<gob<W:olK7aoo6a/KoaLG500Coa<C408[oc8aHolAJ9_ngFB?o
_F4Tol]X9_o=K2Ooc6/VolYZ9_o7IbKo`ePVol5C9Oo1EbCoaUlUolEQ9Oo5HBKoaF<UolER9_o4GbKo
bfhXolU[9_oHV37ol=UAooS_N_okmX;oj/U>okbC:Oo6[1_odkDTonF]=_nVQcgo`ja3onGBB_oD/RSo
jL8oonBk>?oO/Rooi[/kombi@ooSa4CodjHeomRE;Oo=_I[ofK5Con:_=?o`eekoh[DkojMn6?nnSAgo
fi`SonoJJOoLdVgo`JM:ooOUKOoD_5KodZi7ooOXMOo@ZC[oU74Pok1n6OoH]U3o[84[ojIl5onSO1Go
]WdMoj]h6on]Oa_o_9@^oj1b;?o2OS3o]eXVol=M9_o4G2KocVTXokm[;?o>KbcohZ94oo3@G?o[_eCo
fhllom1Y:?oCMbcof8LaomZ><OoBOS7odH=1ol=W;_n[DR3oXDlOojIA8OnSFRKoVG4VoiI/6OnQN1Ko
YGlGoi]e6_nHMAkoHDTPoe@n;?noUDSobgdcolIi;_oLZToodim?okEQ:_nbEB3o`7@cokin?_nXF2[o
YD@LojmD8_nmM3Co]G8hoj198onR@QcoZU0Rok9X<_n^M3ooVUXboiY88onaGBKo_GXeom6RC?o@/e[o
W7]7oh5:;onCDRSoXVH^okJ7?OoF^TOog<PmolVJ:_naFQgo^fLVomNI<OoOYCGoj/M;ooKYR_omn^]8
ooooo`06oogmoOoYjNWoYZJVoiRHV?nKVi_odM7A6oooool02ooPh>3o_[jnoj2PX?nJVY[oUYJFoiVI
VOni^KWohN7QooOgmoolo?coo_kn01kooooo00Ooo?clonKVi_nSXj?oU9BDoifMWOo2`/;on?Sh0?oo
oooo<Oooool009_ooooo00Kol?3`of=SHom@D53og=cLogIfM_n8R8SDooooo`Koo_kn2_ooool02oon
o_kooOgmoo_knoohn?Som?Cdoo3`l?o]kNgojNWYonKVi_oTi>Cohn?S00?oh^;R00Kohn?SonCTi?oU
iNGoi^KVonSXj?oYjNT3on[ZjP0<onWYjOoXj>SoiNGUon7QhOoLg=coemOGom;Bd_o>c/kob/[:olO7
aoo6a/KoaLG51?o4a<@04?o5`l3obWa3olYW:Oo3HBOoYe/QojIO8OnnHRCobVPVol]]9_o9KBKoa5TV
olMP:?njFBCo/elSolMW9Oo<KRH2olU^9P1holES9Oo3FbCofilfooKZJ_o[c4CoiLHlooGVK?oij6go
dZ0cojj>9Oo;/acog:l/omZ]B?nLRd;oglMCon:m>_o`ee[oj<Q=om6W:_oE/RKogk@aon:d=ooDXS;o
g9l`omRN>_oQ[cColn1ZooCQJ_oY`dWo[h8Ioi]i5_o4TAkogJ/fojf?@_o7ZdWoj]1Lon:oC_oikgco
jm5Polbb@On?Iagog[Q>omk8Fon9H1WoZ7dDok^>:OnfP2_oXWHHoj5n5_nRMQGo/GDMojIe6OnVMQWo
[78Lok1V7oncJR3o^VhQoka`9Oo3P2ko`6lXok]W8_nlL2?o_gdXokn2:?nkOBSo/VdSojea9on/O2[o
X6/Joia/6_nIHb3oTUXRoi]b6_nUOaKoZ84Foimi5onGLQ_oVW/Moe908?m2:bOoXV/]omF<=_oJYDSo
hK]JomJRBOo0KbSocX/jombeF_o<WToo]Vh^okid;Oo=Ud?ofkUJolBCAon/GbOo/fP[ol^JAooC]Uko
_iiCokAo>OnkOC;ocie3olfSBooEZdoo_XU1oiUA:_n<A2KoWF4`ojEf?_o7[Ecol>]momo0DOnkKB_o
/E<Tolb6;_oNYC?ogZ<eong>E_oikkKoooonC?ooool01Oo4a<CoVYZJoiVIVOn`/;3om?Cd01Kooooo
00?ok>c/olC4a?nPX:000_nIVIT01?nJVY[o[Jf]omKFe_olo?`Uooooo`07oo[jn_o=cLgoVi^KoiJF
U_nPX:3oemOGooknoP3ooooooboooooo002Oooooo`03ok:b/_m7AdOob/[:01kooooo00?oa/K6ohJ6
Q_ofm_H0/?ooool01?ono_kooOgmooclo?olo?`4oo_kn`Goo?cl1_omoOd02oolo?con_[jooShn?od
m?Col?3`onc/k?oWinOohn?SomoOgooLg=cof][J00?of=SH00GofMWIom[Jf_oKfm_ogMgMomkNgP04
omoOg`08omgMgOoJf][oemOGom?Cdoo@d=3oc<c<olW9bOo7alL2olG5a@Goa<C408SobKjZolIP;Oo7
H2OobV<YolMM:?nXFB7oTf4Noj=P8?niGbCoaf@UolAH9_o:JBSobFHXojmG8onLG27o]V0TolUW9_o9
JRGoaVDQomJB<_ofjfkoo?N4oo7LG_oL]BgoekXXoncEDOo]`T;o^8T^ojZA8ooF]BCoiJ`kom?4I?n[
T3Gojl@kooO[MooafF3o_Xh/ol^[8_o=[aoof;4/on>c=OoQ[cGogj/`onkEGOokn8Col=YRoo3@FOnh
RAgoVWTEoiml5oo3Sa_o`X/Sojn7;_oN/d7ol=a[oocePooZbU?o^JDloiah;oonlWco_YhlogQC4_nl
S2CogKYBoi9S8OnMMAKoYGTFokfB>?nJJRCoYghGoj9n5_nUMa[oX6PLoj1j5onQOQOoX7TEoj1Y6onL
Ha[oXWXHoj5l6?nPNAKoVfPIoi9H7_nLLaSoXGdFoj9m5OnQNAWoY7PRohYL:?n?F23oZGlGojV26?nE
L1SoVGDKoij17Om8=aoo?RXWoiU];OoCSSOoeii4omFG??o@RS;odiLoon[>IooWdg3oaiA5olN6=?oA
W4?oej]=omJVB?o=U3_ocIHoon70GOo`i7God;iWojam@?nfLbkoahHfolF5>_o0Mc;o_70[okIW9onl
N33oa9DjolRN>?o:VD3oi/AFookdKooO]Ego[4PRokaY9_oIWS;ogZ8domfS=oo_efkoo?KHCoooool0
1_oWinOoY:BToiVIVOnKVi_oe]KFooclo0oooooo00_ooOgmoo_knoobl_;oc/k>ojNWYonFUYKoVIVI
oibLW?n/[:cod=3@ooOgm`0Zooooo`07oo7alOnf][KoUiNGoi:BT_na/K7oj^[ZooknoP3oooooobgo
oooo002Oooooo`04onKVi_l/;2coKfm_oo_knakooooo00?og=cLoe1@D?obl_80[_ooool01oono_ko
oOgmooclo?okno_onOWiooShn?ogmoL00oofm_H3ooOgm`;on?Sh1_oinOT02oohn?Som_Kfoo?cloo_
knooj^[ZonGUiOoPh>3ofm_KomOGeooDe=CodM7A00?od=3@00CodM7Aom;Bd_oCdm?oe=CD0ooEeMD0
2OoDe=Codm?Com7AdOo?cloocLg=ol[:b_o8b<Soa/K6olG5a@07olC4a027olfZOoo5EbKo^e`SokaT
8oo:JBKocFHWokAL8onBH1koSfLMoimP7oo2ERGobVPXol]^:Oo;IBWo/5PSohiN8?nKFB3o_F@RomnV
>_o/dDKolMiNoo_bO_ojl7[ohk`nom>_;?o=]1gogK``onNd>On`S3Go^Z4Zon6]=?o^cf3oi<M9ongA
CooilX?onN]`olNF<on_Qb[oe;DPolV^7Oo@[bCog:l^onc=E?ojmH3onO5moo3GGooegVKo`HPUoiQ`
5OnMNaOoX7/GolFB7Oo?TQkoiLADoookR?o`hWCoi<97oif4:onVS43oonicoi=d9OmoEQSok]=QolJR
AOmX@Q7oYGHEom:]AongVT[oMThEojQn5On/P2;o[WlbohUI6onVOaOoX7LDokJ:;On>HR[oVfLJojF1
5onRNAGoYgPPoi=M9?n;Eb;oYGdGoj9l5_nRMAcoZhPVohET:?mY@RSoWFTOohUZ7?mXBa[oWG/Jok:G
7Om3<R3o=R@UohQJ9onhIBGo`WL]olEk:_o8QcOog;MKonkPMOo?[ekoYV0/okId;OnnPCGo`h@dokYe
;?naKc3o]hM7ok^IEoo0Xe[oWgY7ogLi:?n:@bKoVTdYoiI69onCBROoUe//okZ;?OoF]T7odK4eokf6
:?o1OcKoh:m=onk@COobh6ko^VX^olEk9_oJWBoofi`aomnW>OocghSooO__05;ooooo00Ko`L71oifM
WOnDU9Co/k>cono_koomoOd:ooooo`0;ookno_ohn?Sok^k^olo?conWYjOoTY:BoiFEUOnNWYkoZJVY
olK6a_o^k^h0;oooool01OoNg]koZj^[oiJFU_nCTi?oinOW0?oooooo;Oooool00:3ooooo00?oM7Ad
oalO7ooFe]H07oooool00onVYZKoLW9booooo`2]ooooo`08ookno_olo?cono_kooWinOofm_Kom?Cd
oo?clooalO45oo3`l0;olO7a0_obl_85oo?cl`0;oo7alOo_knook>c/onSXj?oShn?og]kNomWIfOoD
e=Cod=3@olg=cOo;bl/00oo:b/X00oo;bl_oc<c<olg=c@04olg=c@05olc<c?o;bl_obLW9olS8b?o7
alL00_o5aLD7olC4a027olG4__o;NT?obVLYolMS:OnbG27oYFDLokQ/8Oo:JbKo`U`TojeO8_nRIb7o
`5PUol]Y:Oo:KBWobfdYol]T:?n_DB3oXgPWon38D?okm7Woln1Somjh;?oRb3oon>]boo;JGOoGYc?o
c[0[olRa5ooD^2Gogk/gok2J?_oI]D?ohjlion_9?ooeifoonO60ooWaOOoY_4;oRUdYokVI:Oo?/ako
bJhLom6]8Oo^dUWonoF2ooS_N_o_eEcomNI_ol^;:_n_J1ooXG/GoiUh5_naQa[odYPOomJS<oo]gFoo
]Ia:on34BOmmIbgo[YA4ooKHFonTPRgo_j=<oog/M_n;HAkoG3X?om2V@?ocg6goESTFogaD4on]Oaoo
fkYCogMC9_n1F1SoXgHCol>L=on]TdCoHS`NojEe6OnOMQCo/8P[ojMm<_mU@2KoT60Ooj9i5OnWNR3o
^Z4]ogeS9OmG>2_oM4PVogYF8om8=AcoXH<Jolnc7OmGAB3o;1/Roh1T:?njL23oXD0Ooj137OnJ?Qco
V4@Soi159onDA2CoTc`NoiDn7_nI@R3oUd0PoiQ48_nEAbGoU50ZohmH;On7FB_oP4DUogPc8omn?BOo
Q48YohmF<?nJKCGoXgdlolVdG_oYgW7o_8HToj]L8Oo6Ocgoi;1;onS0?_obgEoohLANomJWA?oYaECo
k<YIong?G?oeiI_oookm05Cooooo00Kohn?SojNWYonDU9CoVi^KomKFe_ogmoL7ooooo`0:ooOgmoo]
kNgof=SHokFe]OnCTi?oT92@oijNW_n[Zj_oa<C4onCTi3?ooooo00Coo_knolG5aOnk^k_omOGeoooo
ool]ooooo`00X?ooool01?ni^KWo3@d=oj>SXoolo?`2ooooo`08ong]kOni^KWoc<c<ookno_oooooo
d=3@okjn__ohn?P2ooooo`05ong]kOnk^k_o/k>colS8b?o^k^h01Oooool01?oYjNWo];BdokZj^_od
m?@3ooooo`03on[Zj_nDU9Co51@D00Sooooo00ColO7aol[:b_o:b/[od];B0oooool02?olo?cofMWI
okJf]_oOgmooooooooKfm_nk^k_oe=CD0oooool01?oKfm_o/k>cokZj^_oRh^85ooooo`04oo[jn_o9
bLWo/K6aom[JfXOooooo00_ooOgmooclo?ojn_[omoOgooCdm?oalO7ok^k^onc/k?oZj^[ojNWYonSX
j002onOWi`;oj>SX0_oYjNT00ooZj^[ojn_[on_[j`02on_[j`0;on[Zj_oYjNWoi^KVon?ShooOgmoo
f][JomKFe_oAdM7ocLg=olW9bOo7alL00oo6a/H3olO7a`Cob<S80_o7alL00oo6a/KoaLG5olG5a@09
olC4a025oljdROo4E2Koaf0WolYT:?o;HBWo]eLRoiiR6onRJ1_o]6LPokmM9Oo2GBSoaEXVolY[:Oo:
KBWob6HWolab:?oFV3?ok<]5oo[`MOokmH?onO5konW5@ooD[bCod[PVon_BCOoU^3[ocZ<dom2e;?o8
/QWoc;<Iolb_:oo<[3Soik`fonoFDooilH3on>mmooSaP?o/cE3o_H0/ohU];ooE/2SobjhNolf^7_oT
^d?onO1nooCYN_o]dUoojMA[om:D9ooAO2SoaIY?ojF17_o@W27oc9LRokb76_o4SBCo]H/_omc5B_n;
NS[oYhLiomBV<OoAZT?oooR4onO1DOmN>`coKE8RooofOOnaTD3o2000oiUV7OoXdV7o_ie6ocTQ5OnB
GaOoaZ8jon;AG_m@>RGoKDDMojAa5_nmVC?o]j0oofe58omF>2OoQeLNojZ09?o<^S;oLEhOoeXi:OmC
>BgoNd/Sofa<6?nmXA[of[lNogMQ8?lZ6R3oITdZolNQ9on]EQkoXD@MojAA9OnYJCKoT4d/oi4l7_nQ
@akoY4LOoj=<8_nYFBOo[fLZoj]];?nLH2goVF8_ok1k;onGF2[oRTPZoiUL;?ncP3SodZi0oln]=oo4
UC7ofkIAoogbM_o7SDKoZeP[om:??ooU[T?ohkTkonO4B?ohkWGonO5gooWfNooek77omna_ooO/YP1G
ooooo`06ooclo?o3`l?oWIfMohj>S_ne]KGoinOW0oooool02_oinOWok>c/omGEeOng]kOoU9BDoh^;
RonNWYko[Jf]ol71`OoQhN7oooooofOooooo002Pooooo`04on?SholR8R;oC4a<onc/k0;ooooo013o
PX:2o`000?m0@43oX:2PomcLg?mEEEGo0000oi6ATOo^k^kooooooiNGUol0003o;bl_ohN7QonIVIWo
clo?0oooool02oo]kNgoIfMWo`000?lo?cooS8b<oo?cloooooool_;boeIFE_l:2P[o7alO00Sooooo
00GoP820ofUYJOn;Rh_oADE5ok>c/`02ooooo`09on?Sholl?3co0000oeiNG_o5aLGoc<c<o`L71olZ
:R[o^KVi00;ooooo00GoCDe=o`000?mNGUkoXJ6Qol_;b`04ooooo`05ok6a/Ol?3`oo5QHFog1`L?o6
a/H0Q_ooool03?ono_koo?cloo[jn_ogmoOolo?cono_koo/k>coj>SXonGUiOoShn?ohN7QomoOg`Go
g]kN017ogmoOon3Ph?oPh>3oh>3Pon7QhOoPh>3ogmoOomkNg_oKfm_ofMWIomGEeOoAdM7ocLg=ol[:
b_o7alOoa/K6olG5a@04olC4a0KoaLG53?o4a<@0Q_o8a;OobW8iolQP:?nnFRCo^F8RolUZ9_o?KROo
bf`VolE[9Oo0J2Co`6LTolAJ9Oo5EbKoaEXUolIN9_oGTC?okm=Goo[eNOo_ddgoiL8honcGEOolmH7o
ln1Ton>d=?oA/2;oa[0Fomnl<OoP[SOodkI9onGCDOo@_2_oaZ`Bom^l;?oZaS_oln1Too[cQ?oilGoo
mNQfon36CooVYcKoXX0nojf9;_o1U2Gobj/Qomf]<OodiWWof/nMon_AI_oYcFKodI8SomB8=?o=`jgo
dI`don2_;oo3S23oXWdHokJ66_o=TB;oaIP/oh9/9?n[Q33oe:DhooGXNOodjGOoc9</od/a2On?NS[o
onedogaO9_l`6PWohLQOooSWKomU@Qco=B0EokbC>?oonW7oQVdgob`J6omnC1codJdnom7:ComkDB7o
BS8Vof0l9_n[ORSok>11ofaP8?mI=R?oD3P^of4o:_n7DR?oUf@Sojn28OnIN27o=bDPodPb9OnCMB_o
]XTPok=]:OnnSDCock=MoiYT>onH@b;oXTXRojQL:Oo0ORkocI0bokZ:<_n^QC7o/6P[ok9P;?nfJb_o
S4P/oi=P=?nWPd3oaK1Eon_PI?nmSb3oZfLVom>QCooaeU[oi/]Lol:3@_oHTS[oh:<lomBK=OoKZdco
oOMioo[kN_oQeVWoekE@onBoBOoch8coooonFOooool03ooOgmoo[Zj^ohj>S_nMWIgoeMGEonSXj?oK
fm_o`L71oj>SXon9RHWoVIVIojn_[oo2`/;og]kNoo[jnP1Qooooo`06omkNg_nRXZ;oX:2PojBTY?n[
Zj_oemOGooooool2ooooo`00XOooool00omLG5co4Q8Bom[JfP02ooooo`0Aoc/k>ol51@Go[:b/oh:2
P_nKVi_oNWYjo`H61_mUIFGo][JfooOgmon2PX;o0000om?Cdooooooo][Jfog1`L?o8b<P00_ooool0
2?o3`l?o10@4of1PH?oQhN7oPh>3ojBTY?oemOGoj>SX0_lD51@00onATI7oooooooooo`05ooooo`0I
onSXj?l=3@godm?CoooooonJVY[o30`<olk>c_ooooooc<c<o`<30olo?cooVYZJogmoOonk^k_o9RHV
obLW9ommOGgoclo?oooooolg=cOo6QXJoooooooRh^;oN7Qhok:b/P03ooooo`06od=3@ol0003o`<30
okbl_?mUIFGoemOGQOooool04?ono_kooOgmoo_knoohn?SomOGeoo7alOo]kNgojNWYonGUiOoRh^;o
g]kNom_KfooIfMWof=SHomOGeooFe]H2omGEe@Koe]KF00WoeMGEom?CdooBd];od=3@olg=cOo;bl_o
b<S8olO7aoo5aLD05_o4a<@0Q_o6aKgocYEPolMM9oo;J2[obF8YokML8onYHAgo/fXOolI[9?o>L2Oo
cgDWolac9Oo6G2?oae`Tom>1<?oOZ3GolMeIoochP_olmHComNAYonFm=_oF/B[ogL@mooCUIooZ`d;o
hK8dol^^7_o<]1koi;@eon2nC?oKb5Sol^EXom_9?ooS`S?ok<`monW8?_obgF3on_>1onoGH?oS_coo
iKDmolf<<On8Jb_o^8`/ol2:=OoJX2kog:57olf]Koo^f6?oh[YIom2;7ooDZFOocl>Oon2d>ooUaDco
`H`Roj=l6?nMNQOo[X0JolF87_n/NQko]X0Ton_EJ?ojn8Go`IlnokAi5olj:0SoW7lfomV`@onUQ3_o
`jQ>ookkOOnmTSKo?2PEodX`6_o_gF7odl=GodD]6omA<Qkock=5on_VF?n5IBKoGCTSod4^:?maB2Go
l]e5oiRD>?m=<1goEST^og1:9on@HBGoREdZohIG:On4D2SoQU0Uog]99?n7HR[oVgLSol^R8_oQb67o
cKQVoheJ>OnCCbKo]70Zol24<?o>US?o]80aoiQV<?nGIbooWF8/oiiO<_nLK37o]i93om:c?oo8Y3?o
c:<ooo?OIonnRD3oYELXomRQC_o^c5Ook<a9onS8HOoGS3CodhLaolR0>?oM/UOok>aeom37GonnTTGo
b8lmomfU?Oo[b6GooOWYFoooool02oodm?CoalO7oi^KVonBTY;oXJ6Qoh^;RonATI7oZJVYokno_ooH
f=Som_Kf06Cooooo00Kob/[:ofe]KOl0003o0000og9bL_o0`<3oooooo`;ooooo002Qooooo`07oj>S
Xol10@7oX:2Poo_knoooooooH61Po`X:2P02ooooo`0Bol30`?mTI6Co7AdMokVi^On^[Zkodm?CojNW
Yol0003oclo?ookno_oooooobLW9odU9BOoMgMgooooool30`?l0003oRXZ:0_ooool01_o2`/;omOGe
ooooooo3`l?o^;RhooShn0Oooooo00?o_;blo`000?oQhN400_ooool05Olb<S;o=cLgoooooooIfMWo
6a/Kof1PH?oooooojNWYokBd]?lc<c?o?Shnon[Zj_mlO7com_Kfof5QHOlF5QKooOgmooooooo@d=3o
F5QHokno_`02ooooo`06ocTi>OlS8b?om?CdoooooooCdm?oe=CDQOooool04?ono_kooOgmooclo?oj
n_[on?ShooGemOoalO7okNg]onWYjOoTi>Coh>3PomgMgOoIfMWoe]KFomCDe?oBd]82om3@d0;oclo?
1?o>c/h02Oo=cLgoc<c<ol_;boo:b/[obLW9olS8b?o7alOoa/K6olG5a@0EolC4a026olO4^?o>SeSo
aEPVokmI9?nnI2?ob6XVoliV:?o3GbCoYUhKoiYU5_nXIASo_FLNom1o:?oMX3kokM1JooW`M?odiFCo
hk/fon;6Aooej6koo?F2ong@C_oS]SCocZPUolZ_8_oRa3Soi[Lion2b=Oo:[Aoof[D]onNg??oUeVWo
g<UJoo3GDoo/cd?ol^1Oon[;??oU`3CokM9>ooCSJoobgfSojla<omf@;OnYOBgoYX/col6IEoo4Qbko
eHHYol9k9_o`h6Wodim;om>:9?oE]6cof:m5oo;NI_oM^dWob9dfoj=j5OnMNaKoWG/GojAm6?o0QAgo
_80Oom6XA?o7ZTOo/WhRolfaC?l_:1?oUVPHok9h7OoNaEkoo_Ymol>M=_nKJQCo;B@Iof506ooD^TSo
YhTbofe:7ooJ`T_oiMQ=ogeL7On6DacoCCHXodL`9on:GbWoZZ0nof586OmeDBKoQEdToj1g9?n7Gbco
PEL]ohIL:_n?HbOoReLVoiIP9OnQMBgoU6`Rol^Z8_nnVC[oJC8ZofLa:?m^@2koK4T]ogUE:om]?RWo
K3h_ogiA<?nIKS_o]Y@mokBF=_o?^5?oi=AVojml8_nfNSGoiKa<on31FOngLSOofii7onc9D_oU_COo
k]=JomZ?=_oEQC7ocHa6oljiFono^EWoZWThokU];ooGVC_oh:LjonFhCoojm=INooooo`06on7QhOn_
[jooZZZZol;2`_oGemOok^k^JOooool00omGEeOo:b/[ooknoP0eooooo`03ojFUYOoooooooooo0<[o
oooo002Qooooo`0Conc/k?lP823oD51@oo7alOooooooUiNGo`410OoFe]KoooooooWinOn?Shoo1@D5
oh^;Roo[jn_oi>CTon3Ph?l@413oLg=cooknoP02ooooo`06ohJ6Q_lo?cooooooomGEeOlL71coMGEe
3oooool00ond];Co0000olo?c`02ooooo`0JoinOWol0003oaLG5ooKfm_m9BDWo=cLgong]kOoooooo
h^;Rode=COl61PKok>c/om3@d?o[jn_oYjNWo`@41?o5aLGoooooookno_n:RX[oGemOonk^k_oooooo
JVYZoa<C4oo/k>b9ooooo`0Dookno_omoOgoo?cloo[jn_ohn?Som_Kfoo;bl_o^k^koj^[ZonKVi_oR
h^;ogMgMom[Jf_oFe]Kodm?Com3@d?o>c/koc<c<ol_;boo:b/X2olW9b@;ob<S800CoalO7olO7a_o8
alCoa/K60oo5aLDEolC4a026olc3Y_o;OdWoaehWolYX:_o7HBSo^ETRoj]P6onbKA_oaW@Tolme:?o2
PR[ob[0jon?:D_oYaCool=]EooWaN?olmh?on_9non[9AooGYb[oc:@WonC@C?ofiFOojL4monBg=oo>
XbSo_Z@Gom6f9OoS^CKoh;8eomBd;?oP[c7ol==Lon[HG_oV`cComNAXooS_O_o^ddSohl8domJg9_oW
ackom>5QooCRI?oLW3;oei0_oi5b;_nZLbWo[fdTomFB<?oCS2comNYbomRC@?oCQROofJLXonW9DOoj
lWooek0nolbXB?nmXUooWglOoiik5_nUO1So^h4Nok5m7?n[MQSo/gHJokIk8?o@/DooDSlMoi]U7?oM
`EOoo?akom?1Bon_OAkoVWlRobHM6Om^BA_oWW<Koj^6;?oUde?ojMi:ogmO6?n=H1coQVPRodHa:Om>
=BWoMTdOoe]65?nbS2?o/8LNoj=k9On6FR[oSV8VojAn8?n^R1goUV`PogA;8onSMB[oWW4Yoi9[8onl
WBCoeKP[ol:O@on[Q4?oW7DjokVC@?nfTCko]9I;okRM>?o6[4Woj]QPokR>9OnnT3_okMITok=m?_ng
LcOoi;93onoED?oM[e?oei0konW5DOoU_3Soj<E2on[1EooFRcOo_958ojF<AonOKc;o[eHVolal<ooP
ZCkogJ4domnX?OohkL1Pooooo`03oo3`l?o]kNgoo_kn06_ooooo00?oU9BDo`T92OoShn<0=Oooool0
0onb/[;oM7Adooooo`3:ooooo`00X_ooool01omHF5So3@d=onc/k?ooooooj>SXo`000?n8R8P00_oo
ool01?oEeMGo7QhNod];BooalO42ooooo`03ocTi>OlA4A7ok^k^00;ooooo00OogMgMob4Q8Onb/[;o
moOgod];Bom=CDgom?Cd00kooooo00codm?Co`l?3onBTY;on_[joooooooWinOo1PH6ogUiNOoooooo
TI6Ao`P82?o5aLD2ooooo`08oi>CTol10@7oWinOoooooooinOWoi^KVo`000?mKFe/2ooooo`08olg=
cOla<C7oZJVYoooooonYZJWo0000omCDe?ono_j:ooooo`0Eookno_omoOgoo?cloo[jn_ohn?SomOGe
oo7alOo^k^kojNWYonGUiOoQhN7ogMgMomSHf?oDe=CodM7Aolk>c_o<c<cobLW9olS8b?o7alOoa/K6
00;oaLG500WoaLC0omC8UOoOd83ogM:>omK=WOo@c:gob/NholK5_oo5a<804?o4a<@0Qoo6`kcocJQl
olQU<?o2CRCo_UDSol5O8Oo:JRCodGT[olio<?o6Vc3oek0boo3HF?omm7SoooR2ooghPoobg5koi;Xb
omfe=ooTbU3onO1gooSYK_oV_3WofJ@_ol2<6oo9/BKoh<8gonBf=ooT^3Soe:Daol>V8oo4[a_of;DZ
on:m>OoR^SSoi[`jon_<>ooag5WonO1oooWaP?obg5cogKHiomRk;Oo</Acog[d^onoCC?oS]3coi[10
okMg;onDLBco/VlSolnB;oo=TC3onNmholf0<_oDSaooi;dlooWaP?ochFcof[M7ol^/C?o4^jKoV7e?
oiih6?noS2Oo`X/YojYl6_nMNaKoY7/IojAe6OnTKAOoZ6lKojQ_8Oo2VSoo_ILaokZ@<_oB[Dgo/Z=A
oc<S6?mfB1_oZglXonKFCookmfGoc<=GoheX:On6KcGo@C0SodPc:OmH>RSoMDLOoiAV7ongSR7o[hTN
ojAn7onkW1Woa:XHokVF7?nAJb3oC3@PohQP9_nPM2goY7@WoiE_:?nXRB_o`j/aom2k=ooG`d;oe/1<
omJl@?o=]4OoeKmCojn4;ooK_57oZgXlokMm?oo/bUGog[mEolN5??oOYSkog[LmomnV@ooGRSOojL=A
onFn>OoR]33okmEHon[5G?nnV4OoVf4/oj];8?noFbKoeiLjon6/??oLWc?ogjXoooGUYP3?ooooo`04
ol?3`ol61PKoZ:RXoogmoCGooooo00?oS8b<oiZJV_ooool0bOooool00:;ooooo00OoYJFUo`820_nT
Y:Coo?cloooooomFEUKo7AdM00;ooooo00ConOWiofUYJOlH61Soclo?0_ooool00on7QhOo0`<3oeQH
F002ooooo`07ooCdm?mXJ6So>SXjoooooon@T93o>3PhomWIf@0>ooooo`0<oo[jn_lL71coF5QHooOg
mooooooonOWiochn?_l^;RkoooooomCDe?lM7AgoMGEe0_ooool04_oalO7o5QHFoemOGooinOWooooo
oo?clole=CGo5ADEom3@d?oooooonOWiodm?ComBDU;olO7aoo?clolF5QKoTi>CoogmoHcooooo01Co
o_knoogmoOolo?con_[jooShn?oemOGol_;bonk^k_oZj^[oi^KVon;Rh_oMgMgofMWIomGEeOoAdM7o
cLg=ol[:b_o8b<Soa/K6olG5a@;oa<C4013oa/Bnom;4TooUbEWok]MHooCSJ?oejg[olnV1onkXROoW
gh_ohmbBomkFU_oIdYkoe<jVolo:[?o:akOoa/G01_o4a<@0R?o6`kcob[6@olb4B?o>MBcoe8HaomJ=
;_oIVcKoh;a<oo3KH?oeif_on_5hoo_`M_oZaD3ohKPjon?5C_odj6goo?J0oo_cOooZb4Goh[@bom2J
:Oo7WBWoi=9Aong=AooV^COogZ@dol:58Oo1Y2?oh;deon:c=?oZadSohKE;om_4Boo6]BKoc;8SonS7
>ooZbS[ol=UEooWaPOohkgkon?1oooS]M?oP^SkocJLgomFj9_o5[AKoe;LUon>n=_o[aD;oiK0iohaR
:_nWNbWoc94/om>R>?oeiWGocXdXonFm=?ofjW?onoJ6onS>FooK_U;oaJaNolW0Y_njY7goZ7PTomjl
ConhR2_oXgLJoiik5_nNNaOoWG/Foj=i6?nVKakoWFdIoia[5?nMIaKoW6@HoiiV7OnKI1coUEhKoiML
7?nRK2CoYgHVojMe9onHIBSoU5dUogY;8_moC2;oP4lRohAA8_nBEb;oZG`Mol2T5oo7/1Ooc;LFok^M
6on/PAooPUlPocTY7omXB2;oYGX/ojEd9on^OROoYWl[oj>2<?nVQSGo_J=8ojZ9??nlWD[oZH4lom>g
F?nQKSkoejU4omJbCOnoPT3oj;e8onc;B_oMXTSob7lcolJ@?Oo@QSCodh0_onS1C_oU_SSoi;Xhon[9
BoogjgKom>U`omZaDooIVTgofjA?oo7IIOoaffCokmQToo?QJoofjJ?@ooooo`03ooOgmolF5QKoOWin
03Oooooo00?o4a<Cooooooooool0b?ooool00:3ooooo00[o_knoomcLg?oemOGo71`LoeIFE_oemOGo
ooooon?SholE5AGoX:2P0_ooool00onPX:3o0000oj:RXP02ooooo`0<olo?col=3@goBd];oiFEUOoo
ooooo_knojn_[ol820Soe]KFomgMgOlb<S;oZZZZ3oooool03?miNGWo2@T9onSXj?oooooonOWiofYZ
J_lI6AWooooooo_knonATI7o;Rh^omCDe0;ooooo017o@T92o``<3?oinOWoooooooWinOmlO7co0@41
ohN7QooemOGoooooogalO?lU9BGod];BoooooomVIVKoHf=Soogmo@2>ooooo`0Dookno_omoOgoo?cl
oo_knooinOWom_Kfoo?cloo_knook>c/onOWiooShn?og]kNomWIfOoDe=Cod=3@olc<c?o9bLWoalO7
olK6a_o5aLD2olC4a02LolK4__oC`HOohkm8onW7@oo^eUGolMeTooO]M_ojlWgonoF1oo[dOooilGgo
nO1looO]O_obj87oj^28onKOTooOdHSoekmeom[3M?oRcgGok=U[oo3HH_oag6KomNI]ooS_M_o]dToo
i[hfon_9B?o^f63on?1googgPOolmhColMaPon:d<_oDW2_oaXlXomFg?_o_hVComnAVonJk=ooU^CKo
eIT_okQm6_o3YR?ofKD_onJk=ooU[CSodhlkomV]>_oU^SKoiK`noo;NHooW_eKok]eVomo3=?oZc3_o
k=0moo3ID?ogjW?onO61oo_eP_oWbV?ohkHholRJ<oo=/3Gof/0]olVb7?o</acog;`/on_2>On`ORoo
PFL^olnR;ooY_dSok]INon>g<?oeifoon_>3onkTQ_oD^FSoh/iWol2[MOo;`:3oc;9eomVhD?oPaUOo
UF/MojEh6OnONaKoW7PCoj1h5oncOb3oVfDPoiae6?nOOAOoWg/Goiik5onNNQKoW6hFoiIL8?nEHQko
Vg0GoiU]5onHJaOoVV/HoiY/6_nNL1[oWF/LoiQL7onAER7oQeHWoi1N9?nVO1go^9LJoj^57_nVNb3o
OEhOoc4S8?m0:R7o[88VojIg:On`OR7o_Y0YokN@;_n`Rc;o`Z93ojV3@_o:Y4Go[X53omnlCOo7WD_o
dIXionW5AOoDVDSoh[96onS4??oV^57oaW`dol64?Oo>NRcodgl]onc:F?o`eeCokMELooKXLoojlWko
noAgoo_eLoooogOooomjooSlM?oXhf_ojMi[oo;SJoodhWgoo_gg[?ooool02_omoOgobLW9oc@d=?m6
ATKo_knooooooonFUYKo:2PXofm_Koo]kNd4ooooo`05ookno_o6a/Ko:b/[oc@d=?o4a<@00oooool0
1?nYZJWo<30`ocLg=on8R8P;ooooo`06odi>C_lN7QkoHf=Soi2@T?mFEUKobLW91?ooool01?n^[Zko
M7AdoeIFE_nVYZH3ooooo`03ok^k^olZ:R[oJVYZ00Oooooo00goG5aLoc`l??n6QXKooOgmooooooo^
k^ko?CdmodY:B_o9bLWooooooi:BT_ld=3Cod=3@00?ooooo00[oMgMgoda<C?oclo?oooooooCdm?nC
Ti?o92@Todm?Coo0`<3oo_kn0_ooool01?oIfMWoM7Ado`000?oEeMD9ooooo`04oj^[Zol^;RkoADE5
okjn_PCooooo00Coc/k>odU9BOmWIfOojNWY0_ooool01?n6QXKo8b<SofYZJ_nj^[X3ooooo`0BomKF
e_lm?CgoD51@omWIfOoooooo]kNgocHf=_m5ADGoh>3PooooooogmoOoAdM7odA4A?o1`L7oooooojRX
Z?l/;2co`L710_ooool01?o`l?3oJFUYof5QHOofm_H8ooooo`05ojj^[_lb<S;o=CDeoh>3Poolo?`0
1?ooool03_o?cloo>3Phof9RH_oNg]koooooofYZJ_m6ATKoj^[Zooooooo4a<Co<S8boc0`<?nVYZKo
lo?c0oooool00on:RX[o:RXZojJVYP03ooooo`0:om?Cdoln?Sko=SHfokjn__ooooooa<C4ocDe=Oln
?SkoV9RHooKfmV7ooooo002Pooooo`0Pokjn__nSXj?ooooooeYJF_lE5AGol_;booooooomoOgoX:2P
oadM7Oojn_[oooooolK6a_l>3PkoKfm_oogmoOooooooo?clobDU9Ola<C7o`/;2okBd]?oooooodM7A
o`000?nQXJ7ooOgmoginO_mkNg_om_KfoooooooAdM4<ooooo`07oo;bl_l51@GoQhN7ookno_oinOWo
MGEeocDe=@02ooooo`03oo;bl_m8B4SoL71`00;ooooo00?oQXJ6o`000?o9bLT00_ooool03oo3`l?o
0000ogmoOonTY:CoooooojFUYOl30`?o/K6aoooooooclo?o8B4Qoo;bl_oooooojn_[onGUi@2=oooo
o`;oo_kn017oo?cloo_knooinOWomoOgooCdm?o`l?3ok>c/onSXj?oShn?ogMgMomSHf?oCdm?oc/k>
ol_;boo8b<Soa/K6olG5a@03olC4a01TolS4]_oG`GWohk/lon:e=ooO/Cgohl1;onkIGooejG7ono5l
oo_cOoojlgoon_9noo[bOOojlgoom>E]onFl>OoT^3Goh[ToonS;EoodjG3ooOMoooggPookmX;omn]d
onFl>ooR]3?ofZH_om2I<_oK^d[ol^EZoocdO?o/c4[ohkDdomfT<oo3NB?o]GdLolN^<OoO_SSohkHe
onFk=ooNX3?o`g`XokjT;Oo2Z2?oek4[onc:C_oPXDOohK0gon6`<Oo]deWokmMGonS4>?o_ddGomNI/
oo;MEooZc3SoiL/jooCQGoohkgSocjYCokN2:ooU^Sco_I`ionC;Boo?/cgo_j@GolZc6OoB]b?oiL4f
okZJ?Oo;ZCCojlE1onBk=_obgF7on_>3ooO`Q?o>ajSodK5IonCHPoo3/hSoaJEOolnX@oojlGkoaZ0g
ofm>6?niP1ko/8/`ok:C<_nlTBco/X<^oh=D7OnONAOoWG/Goiml5onOO1KoW6lGoii/9_n4DB?oVFTL
oj1o5`;oWgdG0_nPOQH0<OnMLQWoVFLNoh9A7on;EBGoPE/^oh5H;_n1E2coQU@Xoi5L9?n2ERGoB2lQ
oc<Q8?n5HbCo]8PXoie]9OnWMROo`iHYolVO<?o>Ycgoc:E5om6T>_oBZ4[oejPnonBlBOo9SS_od9df
om29>?oO[4KoiKXcon[7C_oFVdOocHhoomR<=ooPXTKolMa[oncLIooI]5Goi<MSooO]Moooo7_oooma
oo_gKOoRhF?obLEIolJZD?oFZeGohkQ@onJiB_oklmH0[Oooool02oodm?CoB4Q8o`000?m0@43oP820
ogAdM?lc<c?o10@4oeYJF_m4A4Cog=cL00?ooooo00Kolo?cocDe=Ol<30coTI6AogEeMOnLW9`2oooo
o`06oda<C?l0003o_knoomWIfOmJFU[ohn?S2Oooool01onDU9Co0000oi>CTooalO7obLW9ob@T9?o<
c<`00_ooool02ooEeMGoI6ATokVi^OoTi>Co6a/KohR8R?olo?cooooooo7alOl0003o9bLW00Oooooo
023oATI6o`000?oLg=coJFUYolk>c_o]kNgo0000obXZ:_nVYZKobl_;okVi^Ol61PKo>SXjokZj^_ol
o?coooooogYjN_l20P;o6ATIol?3`ooYjNWo61PHobPX:?oYjNWoWYjNohF5QOo`l?3ooooooc8b<_l2
0P;o3@d=oo[jnPSooooo00Kobl_;obDU9Ol30`?oL71`of5QHOmjNWX3ooooo`0;ol_;bolN7Qko820P
ofIVI_oTi>Con?Shoa4A4Olg=cOoj>SXok2`/?n4Q8@00_ooool06Ona/K7o0000oiBDU?oGemOolO7a
olG5aOl92@WoS8b<ogEeMOoVi^Kolo?co`000?lK6a_oZJVYok^k^oo=cLgo2PX:obl_;ona/K7ooooo
oj>SXolA4A7o10@4oadM7OoTi>@01oooool01_mDE5Co0000okVi^OoLg=coFUYJon3Ph0?ooooo00oo
/k>co`000?m=CDgoVIVIono_komaLG7o0000oe=CDooVi^KoF5QHo`000?o9bLWogMgMof=SHooLg=`0
0_ooool04On8R8So0000odM7AonBTY;on_[joooooom4A4Co10@4ohf=SOmiNGWoUYJFohR8R?l0003o
/K6aomkNg_mmOGgoi>CT063ooooo002Pooooo`0@ookno_o5aLGo^;Rhoj:RX_l0003o^k^kookno_oo
oooomoOgoiVIVOmTI6CoooooomgMgOl[:b_o>3PhomkNgP;ooooo013oP820o`410OoNg]ko`l?3oe9B
D_mTI6Co0000ohj>S_oooooomoOgog=cLooBd];oWYjNo`D51OmbLW;oo?cl2oooool01_nLW9co30`<
onc/k?okno_oFEUIog]kN`?ooooo00Ooi>CToeeMGOna/K7oooooojf][Ol30`?oOgmo00;ooooo00So
i^KVob8R8_mXJ6Sohn?Sog]kNom=CDgo0000ojZZZP;ooooo00Ko`L71ohR8R?oooooo5QHFob0P8?o]
kNf9ooooo`03ooooo_ono?Wooooo00?ooooo013oo_knoogmoOokno_onOWiooOgmoodm?ColO7aonc/
k?oWinOohN7Qom_KfooFe]Kod=3@olc<c?o9bLWoalO70_o5aLD3olC4a02Fol[3[ooI`6oohK@mom^N
<OoAT2ooeZDjombmB_oZeUkom>I^oo_aNoojlGgon_9noocgPoodi6Soi;/gon6_<ooEVBkobh`_om6V
?ooVdESom^]`ookhPOobgF7oh[Deon>e=_oOZcCob7lXok]k9oo;[3ooh/Q9onFj=_oV]cKoi;<gomJ9
;oniJAko`IPWonFo>?oR/cGoi;XfonB_>ooJT47oeKM@ol6^<?o0Z2Ooek/non>e>ooV_SWoj<Djonc@
@?oafeGomnagooWbP_ohkGKok<m2omfl<OoD^bSohlPiomK0DonXQccok</oomndBOo5/dKoai`/okfM
=_o3Z3So_jLFol^b6_oM_B[oi;hgonBi<Oo^dU;onOB2oo[bPOoPag[oaLG5omZhAOoIbX[o]:B8okf;
9_ocigKoj=AWok^=:omO@aGo/7XRojn2:_o8YD;oh/=BogYB7OmiCQWoZh4Joj^66OnRNQOoUfPGokjG
=_n4IRkoJ3hLoie]6onMNaKoWg/Goj5n5onMNAOoVFHMojQe7omQBaCoLD@MohQJ:on1FbooPU/^oh5K
;on0FRooP5H]ohID:On9DRCoOddSokAn9On[NbGoVfTXokZ;9_ncQ2_obI/aomBW>_o4TCKociXjomFO
>ooV_C[oahXnokAh=Oo5MC3og:E1onBh<_oV_C_om>5aon_>I_o[bUoojMMOom_4ConoR33o^gHcomZZ
C_o[aEConnQcon;<GOo1_ECo[ZM=ok:=@_o5PT3ofY]9on6Y@_oLXCGoln2K[_ooool03?oalO7o9bLW
ob8R8_okno_oo?clol71`Ol;2`_oN7Qhoo_knooOgmooJ6QXoo3`l0;ooooo00oojn_[o`410OmUIFGo
oOgmong]kOnKVi_oa/K6oooooomMGEgo92@TonOWioono_koj^[ZocDe=OoalO402?ooool05Oo:b/[o
0`<3ojj^[_oooooon_[joiBDU?lH61SomOGeoooooonATI7o>SXjomOGeooooooo[:b/o`820_o=cLgo
o_knoo_knolk>c_o410@ol;2`P06ooooo`0OoiZJV_l0003o_;bloo_knon5QHGo/k>cob8R8_lf=SKo
oOgmol30`?nEUIGo9BDUoiBDU?nKVi_og=cLoooooonb/[;o0000ofUYJOm`L73od];BonSXj?oRh^;o
ooooolW9bOl];Bgo^[Zjoooooon=SHgo>CTiol?3``09ooooo`03okJf]_l10@7o][Jf00;ono_k02_o
TI6AoiVIVOooooooooooon_[jom;Bd_o9BDUokZj^_n9RHWoh>3Pokfm_Ooclo?oooooooWinOl30`?o
a/K6ooooooo@d=3o61PHog]kNooooooo^;Rhon[Zj_lZ:R[oFe]Koo_knomWIfOooOgmobXZ:_lQ8B7o
o_knol[:b_n@T93o>3PhogUiNOnXZ:SofMWIolW9bOlE5AGo0000ohB4Q?m8B4SohN7Q00Kooooo00Oo
I6AToadM7OoQhN7oooooono_kold=3CokNg]00;ooooo00oobl_;o`410OmaLG7ooOgmojZZZ_nOWioo
30`<ol?3`on:RX[ojn_[omSHf?ono_kok^k^oeQHF?mRHV800_ooool04_o6a/Ko5ADEogYjN_nOWioo
TI6Aooooool0003oA4A4oogmoOoXj>SoShn?oj^[ZooDe=Coo_knoooooom2@T;oMGEeooGemEoooooo
002Rooooo`05omcLg?meMGGo1PH6oiZJV_omoOd00_ooool01ookno_o[jn_ofMWIon?Shoo>3Pho`00
0?ng]kL00_ooool02?o7alOo0P82oiJFU_ooooood=3@odY:B_lW9bOo`l?30oooool01Onh^;So6a/K
oa0@4?nj^[[oo_kn00cooooo00CoZj^[oeMGEomgMgOoMgMg1Oooool01_oalO7oPh>3ogemOOn9RHWo
2`/;obDU9@;ooooo00SolO7aoemOGolX:2Soo?clomcLg?m3@d?oADE5om[JfP?ooooo00Cod];Bog9b
L_l61PKoJf][R_ooool0/OonoOWomNS<on6gRooP]7oohK:>onFmWoo/c:kojlRgoo3J`oochLoolMoE
ooK^h_odknWol^k[onk]j_oZjNSoi>CTomkNg_oHf=Sod];Bolg=cOo:b/[oalO7olK6a_o5a<;oa<6m
olFm/oo5^:Wob;>HolbJFooCUS7oh:PcomJ<;Oo?Pb_obX/^oljQ>?oE^TSoim5Gon[9D_o/aUCoj/1F
on>e>ooS]cGohk<eomjV<oo>P2co_6/Wokn8<?oA]DKohlYConFl>ooR]3Gohk@fonFh=ooITS7o_F<U
ok5g9onoY3CocjT`omja<_oW^cOoh9leolma;?oLX3?oi;/gon6b<ooW`T3ok<]CombA@?o/bFSoglaC
olZ[9_oT`CGojl`konkDA?oej6gon_:4ooS`P?ohkggon_:2ooCSH?oV_3KoekL^olF^7?oLaCCoj]99
oo7KA_oV]Soog/aXolFa@?oB^S[obIE=ol639ooA^27oa[0Gomjo<?oX`SKojle=oo_fPooR/eKoc7@]
om2gPooN`D[of;emokRYT?oMa5OonNmoolNK>oo</DWoJe0Ooj=k<?n^Ob7ok]eUol^R@_m09@goPe@J
okfA7?nnS1goWVPNoljb@onlY4Co=b<IogA77On_QA[oaJDNolNU7_ncRQooWFLNokB;7?mKD0oo=R0@
oi5M9_n4GRgoP5P^ogmD;_n1DbcoQeTYoi5R9OnDGRCoP4`Toh9B9onoQb;o[7LSokJ69_n^Pb[oZgL^
omZ_=OnfQ3So[g8eolb?=ooS^BgofJa7okak=oo6LB[oh:Y8onoBD?o]dUKomNQaonOMI?oIaDOob:8_
ok9^7OnXBAWoa7hoonFlE?oSZc[ojMQYokBRHOnJOCoo[Whkol1Y<_o?McWog9m2omfS=ooIV2koj/MP
ooklm02^ooooo`03ooOgmom[Jf_o92@T00?ooooo00_oHf=Soi:BT_oooooooooooi^KVon][JgooOgm
ooooooo[jn_o0@41ogIfMP02ooooo`06ooShn?ogmoOooooooijNW_l410Cog=cL0_ooool00one]KGo
>c/koogmo@08ooooo`0Do`l?3on<S8cooooooooooooShn?o3Ph>ogYjN_ooooooOGemobHV9_oJf][o
ooooookno_lM7AgoCdm?oo_knoomoOgoQ8B4o`000?n@T906ooooo`03olk>c_l;2`_oLg=c00;ooooo
017oi^KVof5QHOlN7QkoinOWooGemOnm_Kgo;2`/od=3@oodm?CoU9BDoo7alOoooooo3Ph>od=3@ooo
ooooP820oo7al@02ooooo`03oj2PX?l0003o/K6a00gooooo00?o]kNgo`000?oLg=`00_ooool00ook
no_oRh^;onWYj@02ooooo`05oiZJV_l0003oZj^[oo?cloofm_H00oooool07onPX:3o0000ojBTY?oo
ooooj^[Zodi>C_lf=SKojNWYooKfm_o?clooHf=Soa0@4?o_knood=3@olW9bOmgMgOo410@on7QhOoj
n_[o`<30oc`l??lc<c?oj^[Zoj2PX?omoOgo=cLgo`000?nk^k_okNg]ofi^K_ono_h01Oooool00onS
Xj?o1`L7omCDe002ooooo`0>ok^k^olg=cOooOgmoooooooTi>Co>c/kod51@Oofm_Kog]kNok2`/?lE
5AGoIfMWono_kon8R8P2ooooo`03on7QhOlA4A7oCDe=00?ooooo00OoA4A4obh^;_oXj>Soi>CToooo
oolT92CoDe=C00Kooooo00Cog=cLob8R8_mHF5Sok^k^Goooool00:gooooo00CoZ:RXo`820_n<S8co
o_kn0_ooool00ol?3`ooC4a<ooooo`0Uooooo`08oeIFE_l0003oinOWooooooolo?coY:BTo`820_n/
[:bFooooo`2_ooonoOojl]coj<R>om2B>Oo3MbCo_f`RokiZ8_nmHBGo_ehYol1M:oo3G37oaEldolQ[
?oo<N4cobgYEom6<HOoATV_oci=bomBYOOo<WX3oa9Ilol6:J_o0PUSo`7Y8ol9a=onoH2ko_eTYol1K
9onnF2Oo^U@UolAb:_oIX3;og9dbomJ7;OoAOb[ocHX]okVE=?o2[ccod[Q0on6oA_oT`4[oi[lnon6b
=?oQ/3CohkDeomjM<_o<KR[o^UdVokAf:?noV37og[Dfon:b=OoQ/SGoi;Tgon:[=OoBMBcobWdjol^c
Coo0[T3o`Z@aomJc<ooX_dWofXlgon:c=_oR]CGohK<don_<D?oU^CcohJ/bon_:?_o`dTSolmmOonoG
DOo[cScol=Y>ooGVJOojlGkon_>2ooO]OOofj7CokM54on>b=OoL_SKo`JXNolbc8?oWdCcojL<nonVj
DOnjQSOob;4komFjDonhPCGoejPeol228_oWaSWok<hmonFn<OoS^TGoc7D/olUV9?o@PbOoiLQ@olNH
EOnJPU[oim=PomVbEOo1UCWo^JaFogYL9_nkRcCoi=5Mon[IHonTKAko<20=oi9T6_ngSQSoY74Son3?
C?oSeD[oITTRob@H5_n1D27oh/m?on36B?nQJAooYGDQol:Q7omVEACo1@86og117OnSJB?oUF4UohiN
9OnMLb3o[8PKokF@6_nSN1goHD4PoeTh9?nSMb;obi4Oojij9?o2UbWoZW4[omBU;Oo>YCko/Fhbolb<
<OoP/bGojLU7omjdF?oMYTkojLINonSFIOoRbV?onOF3oo7JKoo8Tcko^VhWojQ26_n_DBWoejEAonNl
BooIUBWol=9Lom_9I_nfO3_oa60/olEK:ooMXTgol==Ion[6COoXa4kojlY?ooS^a02_ooooo`04ookn
o_o1`L7o61PHooWin@;ooooo00?oaLG5oiNGUooYjNT00_ooool01omYJFWon?Shooooooo`l?3o71`L
od];BooinOT01?ooool02?o?cloo30`<oginO_ojn_[ooooooo[jn_m1@D7oV9RH2?ooool02om<C4co
IfMWooooooooooool?3`oe=CDol[:b_ono_kohN7Qol?3`ooalO700;ooooo00SoPh>3o`000?oShn?o
ooooom_Kfol410Co;Bd]oo[jnPKooooo00?o=CDeob`/;?ono_h00_ooool05Oo3`l?o0P82ojRXZ?oo
oooocLg=ofUYJOlB4Q;o_knooo[jn_ono_koooooofQXJ?l71`Ookno_oogmoOoGemOoooooooclo?mE
EEGo2PX:om3@d00=ooooo`03ooCdm?lC4a?oemOG00?ooooo00Solo?cohf=SOooooooooooomGEeOlS
8b?oF5QHoo;blP?ooooo00Coo_knodA4A?l@413oj^[Z0_ooool02?n/[:co4A4AokNg]ooooooo`<30
ogUiNOl0003o/;2`0_ooool02?oKfm_o10@4oijNW_oooooofMWIofa/K?lI6AWoYjNW0_ooool01_n;
Rh_o0000oh20P?oooooolo?con?Sh`Gooooo00SodM7Aoa@D5?mgMgOomoOgooooooono_ko@d=3oiBD
U0;ooooo00koSXj>oa8B4_o4a<CooooookRh^?mEEEGo30`<onc/k?oemOGooooooogmoOn/[:co0000
oi6AT@?ooooo00?oRh^;o`000?ne]KD00_ooool00omMGEgo6QXJooooo`05ooooo`04oiNGUol0003o
WIfMooclo5oooooo002Uooooo`03ookno_oooooooooo00Gooooo00Cofm_KobXZ:_m1@D7oinOW0_oo
ool00om_Kfoo20P8ooCdm00Uooooo`03ok2`/?l10@7oRXZ:00;ooooo00?ofm_Ko`H61_mTI6@0VOoo
ool0<Oomn_?olMf_om^^FOo;QbOoa7hTokik9OnjNROo^7dYokZ0:OnlO2_o`W//olYk:oo9LRcobg8Z
olU]:_o5IBSoafPYol=S:?nfCbCoYdDOojAA7?nYIQgo^8<Ool2:8Oo0Q2?o`GhUol9j9onoKbSo`WLZ
oljB;ooKXS;ofY@`omF4;?oAPbco_Gl^ok^=>?o3ZTGoeKm:on6f=ooT^3OohK4eon2]<?oS/cCohk8e
omZ?<?o>I2WoaF8Xom^Q=?oS^3H00_oQ/SD0N?oR]CGoiK/jomV><OoEMcKoi[eMomVmDOnhRbco^9L^
om:`>?oT]cKoi[hhonO1>_oX`ccojle7oo3KFOoeiF[onNmkooWbPoofjWCojl`non_:>_oP`cKoim99
oo;IH_oIT3[odW`_omjb@?oU_CSoi;4iomk0?_o4[BSoaJhNomk6=?oMX3OoeH0/okR1<?oKbTooXX@h
om>T<onaNS7okldnonoGAooJ]cCofjh[omBC:_o6IRSoch<Uom_3E?nYIbooSEDTomRY>onlOC3o[Gd[
oi:1@on4Gagog[m?oo3YKOnjRRWoXgLOoc0Q3OnHJAWoZ7lSonC?D?o6Z4;oUG0QofAB7?lV6AOoT5hX
om[2H?nNIbgoYg/Noi]n9?mfFBSo4@d:ocDN4OnJIB;oZhLLokNJ6?o3[AKo`JTFok:?6On<IAooBC8P
od0Z8OnAI2Ko[HDQom2K8?oDZbWo^H</olND:ooR`T;oahdoom6HA?o]dUCokmIHoo?WLOoXf5goe[e8
okR9<OnoSD3oj<eOoo[bN?oJVT_o/DHNojM07Oo0Mccoi;iGon:]??oFT2KoiKQ6on_<Ioo1EbOo_DTR
omN>@oogi6[om?Ibon;EHooRc5cok]MGoo?RQ;7ooooo00?ol_;bog5aLOnIVIT00oooool03OnCTi?o
b<S8ooooooooooooXJ6QokRh^?oooooom?Cdoclo?ol>3PkoZZZZomOGeooZj^X00oooool02?l^;Rko
61PHon?Shooooooono_koiBDU?lL71comoOg1Oooool01?olo?coooooojf][OlQ8B42ooooo`07ooSh
n?n8R8So2PX:olS8b?o0`<3o30`<oibLW002ooooo`09olS8b?l10@7oZ:RXooooooobl_;oBd];ocPh
>?nb/[;oo?cl00Gooooo00?oTI6Ao`000?oPh>000_ooool02Oo[jn_oCDe=odi>C_olo?coooooogYj
N_l20P;oOWinooWin@02ooooo`03ojFUYOl0003oT92@00?ooooo00CoalO7oaXJ6_mMGEgokno_3_oo
ool00omdM7CoZ:RXoogmo@02ooooo`03oo3`l?nEUIGol_;b00;ooooo00?oIfMWoa8B4_o<c<`00ooo
ool00ooJf][o0000ofUYJ@03ooooo`0Gom[Jf_lM7AgoHf=Soo[jn_ooooooS8b<o`<30omADE7oo?cl
oooooooemOGoGemOoclo?ookno_ooooooi2@T?l410CoJVYZooKfm_ooooooa<C4o`D51Olc<c<02Ooo
ool04Oll?3co51@DomkNg_ooooooo_knoi^KVolF5QKom_KfoooooooGemOo;Rh^ogmoOoomoOgooooo
oe=CDol0003oYJFU00;ooooo00Col_;bode=COlP823of][J0oooool02?oNg]ko6ATIoeIFE_oalO7o
ooooojf][Ol51@GojNWY1?ooool01?ohn?So?ShnoaLG5ooPh>1Pooooo`00Y?ooool00oo7alOoYZJV
ooCdm007ooooo`03oeIFE_lG5aOoemOG00;ooooo00?o[:b/o`000?nQXJ409Oooool00oo^k^ko2PX:
oe9BDP02ooooo`04onWYjOlm?Cgo;2`/on_[ji[ooooo0:Woo_gjooGW`ooO]63och/YolUo:?o4LBOo
^fTXokI]:?n^M2WoXgd[ojn::onbR2ko`8`aom2B<?o7ORgo^fLYokMJ9_ndC2Co]4DTok9:8oneGBCo
_W`Vokmn9OnoNbGo_g`Uokmj9?nkKRCo]UhTok9F9Oo=RBkogZ4bomJ9;OoGQRcoeXd^omNM<?oS]CGo
j/U<ooKYLOodiVgoi<Q@om^`=ooN[C7ohk@bon>`>_oEPC7ocFPZon:`=OoR]CGohK8eon6`=OoS]SSo
l^1Hon:_?Oo>J2SoeX4_omnS<_oFYBkog;<bonJm>OoW`3Woj<@koo?OHOojlX3onoB5ooWaPOohl7ko
nNmnoo[cPoocgUcoil0fonK3>_o;YBWobjhYon>i>_oS[3Woil0monc??ooR/3OokmAHon[FE_oYfeoo
fLPnon>i>ooDP2cod8Lgok^G>Oo6ZScoejPeomjg>oo_eTWomnQRol^Y<onkUBcohk/[om:69oo=QbWo
h/AGokU/:_nWGbCocH/XolAo<OnPLBWoS6@XokjN@_ock7?o/HlZokR6;oo=`6;o=RDBoiY[9_o/fU?o
aHdkof8i7Oo5WQgoI4`KoblO6On>FBGoXG4Zok>@7_n?MROoY7T/ofa;6_l=20OoMdHOokVI6_o8]AGo
`jDHok>:6onUN2?oZh8boc`[8?l/7R3oOUHToh]Q9onRNB3odJTOon_?=_o]fEOomNM_ooKZMoodiG;o
h/mOoncMLOofkGWoaJ<VojQ/5_nHBASo`h]7onW2Foo]cTcoln9cok5D9_nZBR?oe:9ConS2D_oLWS3o
f9D[om^N<OochFcob6deolIN:ooQ_ecof]YVokJYD?nkRCkoci4nomn[?_oS/ckonoGN0:oooooo00Ko
hn?Sooooooooooooe]KFoeYJF_oclo<2ooooo`0>ohj>S_nc/k?oo?cloooooooinOWoH61Poooooooj
n_[oRh^;oa@D5?nl_;coLg=coemOGooFe]H2ooooo`08og9bL_l0003oOgmooo[jn_oooooogmoOo`41
0Onb/[85ooooo`05oo?clooLg=coc/k>o`000?obl_800_ooool01onh^;So0@41ok6a/OoTi>Co8R8R
of=SHooinOT00_ooool02?l;2`_oOGemon?Shookno_oRXZ:o`T92On`/;3of=SH1Oooool00oo9bLWo
0P82ohN7Q`03ooooo`08ok>c/olN7Qkoc<c<oooooooWinOo;Rh^oahN7_oRh^82ooooo`03ooGemOl=
3@go?Cdm00;ooooo00Coo_knohF5QOl30`?o_;bl3Oooool01Oolo?coo_knonCTi?mbLW;omoOg00;o
oooo00?oo?clolS8b?nIVIT00_ooool01?n^[Zko0@41oiVIVOokno/2ooooo`0:ogEeMOl61PKoa/K6
ooooooolo?cok>c/oooooombLW;o61PHolg=c@;ooooo00?o9bLWo`@41?oemOD00_ooool02?o:b/[o
61PHol71`Oooooook>c/od10@?lD51Cod];B0_ooool00olN7Qko0000on_[j`08ooooo`08ogmoOol0
003oNGUiooShn?ooooooinOWo`000?n][Jd2ooooo`0<oh61POlf=SKohN7Qooooooo>c/ko3Ph>ocPh
>?oinOWoooooom_Kfol0003oMGEe1Oooool01om?Cdoo0000omgMgOoooooono_koa`L7?nQXJ401?oo
ool01?ni^KWo3`l?og1`L?oclo=Pooooo`00Y?ooool00ole=CGo0000omOGe`07ooooo`04ohb<S?l0
003o][JfooknoP;ooooo00?o0000oe=CDoooool09Oooool02?la<C7o4A4AooShn?oooooooOgmohR8
R?l61PKoZJVYW?ooool0Y_onoO[oln:jonC1L_oBUc7oc8DZolYg:_o6J2Wo_F8Xok=S9onWIRSoXF`Y
ojI_8on[KA_oYUXMojaJ8_nfIBOo_g<ZolIh:oo8MBcoagH]olEd;?noJR[o^5`WokYI9onkEbKo^50U
okY?9OnoEROoc7/]omJG<?oPZS?ohkHeon[7AoobgVConO1jooS`Nooil7con?5monkSLOoQcEcoeKM5
omF^>OoN^S[ofYLaom^J<_oS^3OohK4eon:c=OoQ/3;oil=4onW6@ooR/cCohkLionW8AOo^deGol]eT
ooCUK_oXa4;oiK`gon>j>OoVb4gomNEXoo_`N_oilH7on>mnoo7WLOoXf5Koj/TmonFi=ooX`CcoaI<W
ol2S9?oHbCKok]Y5oo;KA_oT]cKojLI6oo?SG?ogjG7om>MeonS7@OoHT2ood8Ddoj=^:_o6[S[oj/Dn
ong>@_o`g5Kon_1eonBo??nFL2SobZD_on:b:_oEZC;oi[YGom5a9OnnK2KoYg4SokV0<?nFGbKo[8@`
oo?/M_naUckoVFPGolRM=?nl]eko=B4ColbZ@_oFWCooIS`Ooj=g9_oV]4GoD44ZodX_6_n:DBCoXG4S
ok2D;OnhP2[o]WHXoal@2olh8Q7oT5TUojec8?nmIB3oWeTToh9A:_n9F2_oREL/odl`8Om>=2;oU6XS
ohmT9?nYP27oa:@]ol^]8ooKbEWoknEWolZ]<on/PBSoa:99ooO`N_oEZT3oWT/Doie>9_o:TTWoi[MF
onFj>oobg5cogKEOokIR<?oO]EGoi[U7omVF:ooHUbgof9@Yon_8E?oS/E[o^FPcojZ@BOnYT4GoYV<_
okiY;ooKTcWohJ/kombO<oo`fHV`ooooo`04oh61POofm_Kooooooo_kn`;oY:BT0_ooool01_nMWIgo
Jf][onSXj?ooooool_;boa`L70;ooooo013of][JoalO7onUYJGoooooofYZJ_m8B4Soj>SXoooooond
];Co1PH6oeeMGOnk^k_ooooooo7alOlI6AWoKVi^1_ooool01?nATI7oYZJVo`410OnTY:@2ooooo`07
olo?col0003oTI6AoooooomcLg?o4Q8Bolk>cP02ooooo`0;o``<3?n7QhOoPX:2omoOgooHf=So1`L7
ohB4Q?nf][KolO7aooooooolo?`00oooool00olW9bOoB4Q8ooooo`02ooooo`0Eoo?clomiNGWoKVi^
ooclo?ooooooLg=co`000?na/K7ooOgmooooooono_koFUYJo`X:2_oYjNWoooooooOgmom<C4co@T92
on[Zj_oooooono_k00_ooooo00GocLg=oo3`l?ooooooR8R8ol_;b`03ooooo`08om;Bd_mIFEWooooo
on_[jooNg]ko<S8bocXj>_oTi>@2ooooo`0?oaHF5_m=CDgooooooooooooVi^Ko[Jf]omkNg_o4a<Co
1PH6ohn?Soono_koooooofe]KOl0003o_kno00;ooooo00gonOWiohF5QOmJFU[on_[joooooon8R8So
0000oi^KVookno_oooooogYjN_l0003oWIfM00Sooooo00So_Kfmo`T92OmIFEWo^;RhooooooogmoOo
6a/KofQXJ0;ooooo00coj>SXoe9BD_nLW9coo_knoooooom9BDWo0000om7AdOono_koXj>So`D51OoE
eMD3ooooo`09oo?cloo]kNgo^;Rho`D51OnRXZ;ooOgmoooooon9RHWoEUIF00;ooooo00Ooo?cloooo
oomjNW[o3Ph>olo?cooooooom_Kf05oooooo002Tooooo`03ojf][OmgMgOom?Cd00Kooooo00OodM7A
oeaLG?l0003oJ6QXooKfm_oYjNWoYZJV00;o000000?on_[jooooooooool08_ooool02Ona/K7o;Bd]
o`000?nf][Koooooom7AdOmRHV;o0000ofATI02Oooooo`2SooS_eooXbhSoeZ8nolj@;Oo;Q2cobGDZ
olQW9oo3GbOo_UdWokUh8?nfTa_o^XLSok=e9On]KRKoZW4Xojal:On]Mb7oXU/PojED8on^H2Ko]fXW
oka/:?niJR[o]V@WojmH9OnaDRGo`6TYomNM<OoS/cKoiKQ1on[;EOoafF;ol]eWoo?OJOobgVOolmiX
oo?OJOo]fFGogLEGol^Y@?oG]Ckoh[8fon6c<_oR]SKohkPgonO3@oo[c57ok]ALoo?QJ_ofjWCon>il
ooWbP?oilX7on_>3oo3JH?oU_3Koh[Hfom:J;_o5T2coe;@loncDE_o]aTkogKPgomS7=_o_fe;oi[dg
on>e=_oZa3goeihbolNO:_o5/Rcof/Hgonc@@OoW^Skom>Idoo;RHoodhfOoln5Son>b>OoCRbkoSELT
ojB1:?oScTgolMQ>ooOWJoo[hWWohLA1okaf:_n@KRWoaZ0[omZd:_oGVSGodW4WolIn;?n>GakoZWl^
ojIj;OoYgf[oRWi0oh]U:On[N2Koe[<coinJC_ln:AKo^6l[oh=H8OnOOSOoiKIIolfQB_m/Ab7oRF0W
ogmD;On5DBSoS5<UojiM9omi>ago2`T7ogE47On3B2_oSTHWoiIJ9_mkEBkoMe<aogaH;_n7FRWoRU8V
ohEC9_nFJRGoRE/WojR5>?naS2WoXG`eomo9HOn/OBWoS4hMol:IC?ojkG3oek=EoiM35On]JcGoe9]9
on6WBOoV_CkohkLcooS[M?oQ_V?ofZE;om^N<ooHUB_ofYX_omVH;OoP[3gom>=aolNBB?nVLcOo[U/Y
ol5G9OoHQSCohZXlon2X=ooKWC?oi;I6oochiP2`ooooo`0>olO7aom^KVkogmoOomgMgOni^KWoKVi^
onOWioooooooFe]Koa@D5?oIfMWojNWYofMWIol00002ooooo`0@ooWinOnDU9CoBDU9onc/k?oHf=So
61PHoj:RX_ooooool?3`oa<C4om`L73oYjNWokJf]_o1`L7o4a<CocPh>0Oooooo00?ocLg=ochn?_mA
DE400_ooool01onDU9Co0@41ok2`/?ooooooeMGEoahN7_mnOWh00_ooool0:_l0003o[Zj^olc<c?mO
GeoolO7aocDe=OmKFe_oh>3Poj>SXonFUYKoNGUiomWIfOnd];CoRHV9obXZ:_l10@7oTI6AohV9ROne
]KGoooooomWIfOm8B4SoYZJVoooooono_koo1@D5odM7Aooclo?oooooookno_n^[Zko0000oi2@T?oo
oooomoOgoeIFE_meMGGooooool_;bomaLG7od=3@ooknoPWooooo00GoRh^;ojb/[?oIfMWog]kNofIV
IP02ooooo`09ono_komFEUKo=CDeoooooonm_Kgo^KVioeiNG_l92@WocLg=00;ooooo00oo<c<cokBd
]?ooooooaLG5og9bL_nc/k?oQXJ6onSXj?m=CDgo?cloon_[jooooooobl_;o`<30omKFe/00oooool0
3?oTi>CoBd];oiNGUoooooooc<c<oa0@4?lg=cOoj>SXooooooo<c<co0000oe=CD`Sooooo00Solo?c
oaTI6Om[Jf_oYZJVokFe]Oo5aLGo5QHFoc4a<@?ooooo02;o/K6aodI6A_o:b/[ooooooj2PX?l0003o
KFe]oooooonh^;So5QHFooooooo`l?3oOWinojNWYooUiNGo_[jnol30`?lC4a?o@T92ooOgmooooooo
mOGeoe5ADOoHf=Sol?3`ogUiNOnb/[;oPh>3ofATI?oinOWok^k^ofi^K_nj^[[oo_knGOooool00:go
oooo00[o`<30ogQhN?mJFU[oU9BDooOgmooRh^;oPh>3ofe]KOmXJ6Son?Sh9?ooool02OnFUYKoNg]k
oe5ADOo2`/;ooooool30`?maLG7oJ6QXoiRHV02Qooooo`2Poo_ei_o]eIcofj]>om2C;_o=SRkobX@/
olMe:_o5IRWo_78Rol2F8Oo:UbSo`glVoka/9_njHROo]W0Qojn76_n_OB;oZflUojM^:?nUMbGoVfTP
oimQ9_nZK2SoZg4YojMW:_nYIb_o_h@]omBI<?oGV3;of:<kon2mCOoZdEkol^=_oo[^N?oikW_onO1m
oo_bOoojkG_ok=1KonBm?ooYaTWohK4con:b=OoWa4[ol]eTooW_N_okm8;on_B3ooWbP?oilH7on_62
oo[aP?ohkWSojLI1onBi=_oT]cKofIdcokid:?ndPBKob:/`on74>?ochDWonO1Oonc>?ooR/cCoiKdm
ong=B_oU[cooh[aLolFW>?o4YROohLe1onBoCOo9ZSCokM]GooGVJOo/cTgohJLdok5k;?n^NRSoimIK
ooGTHOokmWooh;e/omRbD?o5RC7oTULZohe_:?nlU27ocIdKoln69Oo3NRco_h8XokF5:_oKbEco_K9J
ofE9:_nUP3SobjeUon77DOn:Q4;o@BDFoiE^:?nZT33od9i2omBS?_nQKAooXGlTogaN<?mcE3;oMeD`
ogaB;?n3D2WoO4XTof<k7?n@E2?oUF4SoiM[8On=JROoUg@SojF37onYPQkoRf<QofM09OnBHbSoTV8W
ojAm=OnYPCCoSV8ion37F_n/NScoRdLWolfPDOo_dU;oi/YKojIO<?noQD;oeiE1omfN@OoYaD3ogj`Z
onS5B_ojlgoon>mjoo3HJOocgFSol]eWoo7KJ?obffWomNAZooGYJ?oR_Dooi[9:onZfBoo`dE?okmiE
onWACooYcdkok]9<ooCSUK7ooooo00kooOgmo`h>3_l];Bgo9bLWobDU9OlJ6Q[oPH61oooooomTI6Co
0000olg=cOoDe=Co0000ocPh>0?ooooo00Kon?Shoi2@T?nDU9CoTY:Boa/K6onb/[82ooooo`07oe=C
DolP823oooooojFUYOmPH63o0000ofIVIP08ooooo`07oiRHV?l:2P[oWinOoh20P?l:2P[o?3`lon7Q
h@02ooooo`0GokJf]_mCDe?oXZ:RoifMWOm2@T;okno_oooooon5QHGoYJFUodI6A_lK6a_oinOWojf]
[OlE5AGo0000oj:RX_nJVY[oH61PofATI?l0003o:RXZoemOGonJVYX00_ooool03?nc/k?oKFe]okVi
^On3Ph?o>CTio`000?oAdM7oo_knooooooo^k^ko51@DodE5A@;ooooo00Oo`<30ohn?SonVYZKo9BDU
o`410Onl_;cooOgm00Wooooo01goa<C4oc@d=?lU9BGo;Bd]o`D51Onb/[;oooooomcLg?l0003oATI6
ooooooo[jn_o];BdoeiNG_l0003oVYZJoogmoOoooooo`l?3oi6ATOnSXj?o5ADEoa`L7?o8b<So`L71
ojj^[_mADE7o0000okfm_@02ooooo`03oaTI6Ol0003oo?cl00?ooooo00co`/;2ofQXJ?ng]kOoSHf=
oc`l??l0003o^[Zjookno_oooooo8R8RoaDE5Oojn_X8ooooo`07oeYJF_lL71coo?clojRXZ?mUIFGo
0000of1PH004ooooo`0Coi>CTon4Q8Co_Kfmofe]KOla<C7o0P82oo;bl_oinOWoMgMgojn_[omPH63o
0000ogYjN_ooooooinOWok2`/?lP823o0000oo?cl`02ooooo`0<omgMgOnMWIgoNWYjo`000?mLG5co
emOGoinOWon^[ZkoBd];o`000?n8R8SooOgmGOooool00:oooooo00?onOWiooooooooool0:oooool0
0oo`l?3oooooooooo`2Wooooo`2<oogklooagZoog[9Nom6E<?o?TboocI0^olR1:onjP23o`YLRom6Q
;Oo;U2_oaXDXol=a9onlMR7o`9LPol>@8onkM2Co_FHVok=h7OncPb;o[VlXojY/9OnOLakoVfPVoiMT
:_nOMBWodHl]omJ6;?o?PRWobhP[oljE<_oCZD7oh/YIonW<G_oZbe[ojLI9on[9C?ofjG7onoJ0onkC
FOoOZc7oeID/om6F;OoEZSKoh/98ongFG?ogiVcolNESongPE_oYed_oj=4nonC2=_oU^SSoh[DeonBj
=_oU/cOodhD_olB1;?nnVRgo`jD`omVo>oo]dD3ojL8ion6a=?oP[CWojL0konRhA_noK2go/f@Kok^6
7_o</2koel8fon_MH?ocgF3ok<a?onJk@Oo]b5KojlYGooO[Koohk7ConoF2ok^9EOo9Q3;o_IXcoh98
:omhDR_oQf/WokB<7onoU1_o]WlRokR89_o:/TkoiM9Vofm>:on7FS;o/WdYol^aM_oP`dcoNG<godT_
7?o2XTKo^8<Wokn99_nUNago`9d/okAf=_n1DBooLU0bog=@<OmjEbooPUP[ohYD:_n;DRWoQU8Woieb
8?ndUQSo^j4FokNK5onROAgoJd/QocTV8Om_BR?oXg0Sojb1<?nmVS[oVFdkom^gAoo1VTKoVeh`omBS
C_oY`dCok<i9omB`G?o>TT?oeHDcombL?OoQ]CkocH`ZomZ[B?ogk6@2ooolH`0@ooGdHooZi6?oj]mZ
ooS`M_oeiV;onNmIooonFOoooe_olO5Hon3OE?o@`dcod[=6omR`AOoU`4?oi[e5oo_fgk;ooooo00go
][JfogalO?mlO7coOWinoh20P?ne]KGoooooom;Bd_n>SXkojNWYooShn?nFUYKoclo?00Cooooo00Go
n?Shol30`?nQXJ7o[Zj^ooCdm002ooooo`07oifMWOl0003oalO7oooooonn_[koWIfMomgMg@08oooo
o`06okjn__l0003oI6ATohV9ROn3Ph?obl_;1?ooool01?o6a/Ko/K6aoj2PX?oOgml3ooooo`08okVi
^OnWYjOoUIFEon_[joojn_[o/;2`oh^;RooJf]X3ooooo`03o`h>3_mQHF7ooooo00Cooooo00cofm_K
okVi^OnWYjOoa/K6ohN7QooOgmooo_knooooooogmoOoF5QHoa<C4ooQhN42ooooo`05on7QhOnVYZKo
R8R8okFe]Oolo?`02oooool02OnKVi_oOGemogalO?n3Ph?o_knooooooooclo?oUYJFokbl_003oooo
o`04olK6a_n8R8SoalO7oogmo@;ooooo00[o`l?3ojFUYOmoOgoo`l?3ooooooono_kodm?CojJVY_n6
QXKofMWI0_ooool00on^[ZkoQHF5ooclo004ooooo`0;on?Shong]kOoZZZZol;2`_n=SHgoe=CDookn
o_ooooooN7Qho`000?nn_[h02?ooool01onSXj?o0000ol71`Ooooooo`<30oibLW?oKfm/01Oooool0
3?o;bl_o_Kfmoj:RX_o;bl_oPh>3oo;bl_oooooom_Kfojn_[on=SHgoX:2Pong]k@;ooooo00Com?Cd
ok:b/_n6QXKonOWi0oooool02_oQhN7oWYjNohR8R?oBd];oooooonGUiOnd];CoPH61oijNW_o_knmN
ooooo`00oooooon:ooooo`0Rookmn_oeilCoe;5LokV?6oniU1[o^YLIokZK6?o5YAkobYLUolV6:_o7
PR_oaX8Zokn68oo7WbGoc:4Xol2:9?o0MBKo^X4QolBI9_o4ObOo^fhSokB28?niNRGo/fLSok=l9Oo@
VBgof8/^omF4;?oCPB_och8[omFR>OoH[3Goj<=6ooCRJ0;onoF007Oon_Anoo_fPOo_eUcohJhdomF;
;_o<ObcoaHD[ol>=;?o8WS;odZlbomJe<_oE]37ocZhlolfX?ooQ]SSoi;Phon:d=OoS]cKoh;0dom^=
<OoGQBooci/[okjK9oniWR_oiLHkonBg=ooT]cGobZ4bom_2AooZ`D_o`WD]okEW8?n_Iako[H<Solnk
>Oo_gF7okLU<on_:AOo[bEOonoInooWaNookmH3oj=5^ohD`8OnODRGoejhdof@k8_m/?BWoNT/Vohm`
:?nYQB3o^i8Koj^07onmXDSo[7XeoheV<OnWJ2Wo^88UoiY:8_oT_RkoIV8]oePg7_ncPBgo[GXSok:@
<?o7]W?ob;B9okUa?_nSH2KoU6hToj5o7onTOB3oTF8Tofe28omoCbcoN5DaogYB;on7FbWoUV<Soj1O
8omT>b7o:1lOod8[8_nMJBCo/X0Zol>R?On[Od3odjDiomNhB_nbNCcoeIe9onK1@ooR^Bcol]i]omNF
@Oo@N2WodXXeol1e;OnlKS7oh;QJoo[dJ_o^k5Coem=;olBiBOo3XTWoeJYDonO5E?oT^Sook]A=om[2
G_o4/Tco[Ye1ojn>>_njOS;oc84bomZG=_oPZ3Sofi`bonc=M@3;ooooo`03onOWiol30`?oLG5a00co
oooo00?om?Cdoj>SXooOgml06Oooool00on6QXKoGUiNooooo`0<ooooo`04oogmoOn`/;3o0000oi2@
T3oooooo00?od];Bo`000?mOGel02?ooool00ooYjNWo20P8of][J`26ooooo`00oooooon<ooooo`0Q
ookmn_oYf:Co`YD^okZ47onhPaco]8@Iok>56?nhRA[o^WLPol1g9oo:QBgob8TZolbP9ooEZBgob9TX
ol659onoS2GocZ4/olVA:_o0P2Ko_YLUolBF:_ngNRKo^8XWomFT<?oHTBooehl_omfS<_oW_d;om>9X
oo[dOookm7oon_5l00;onO1k00oonO5loo[cOooR`eCogJP`omR?;ooEPRkodH4]olYn:oo1PBko_9<[
ol:N;ooB/DWoeKU[omjjDOoU^cP00_oR]3D0>OoP/CCocIT[omJ?<?oENb_oc7LYojMk:oo1YSGojlDk
on>d=OoAUSCoZfL^om:6=?oR]TGoei<lol>5<?n/I2;oZ78QokfV8ooG_Ckok]M>ooCSIoojlgoonO5n
oo[eP_oJ^5_oZfY0ohTn8OoF[C;oXePUog4n9onaDbOoZfLXohm/:?nYPaooTf`Ooi1T6_n?H2?oVVh/
oia/9_nHIB[oUTdWokbD;OmTDBKoKD@ToiIU9_nSORGo/9=4ok2GD_nRPb3o[9<IokZU6ongW1[oY80N
ohYO8_lh9a7oEc<MogiD<002ogEG<P0ZogAD<_meDS7oP54]og55:?mC<b?oLTTTokAn8_oB/3go`Y=1
oljK<?oWbd[ocYU8om6C@_oW`dGogZdLonoJFooJVDCoc78Tolf6=OnhIBgobh90omRAA_o2Q4Go]Z=Z
ojZDEOn^Mcko`gU0omfSBOoU]D7ofi`^on[0?_o>_U;oXGm9ojmf<oo0K2_oc6HYomR6<_oOXcKogjLe
ombN<ooMY3Gomn^lc?ooool00ol];Bgo5ADEooooo`0Wooooo`03oo;bl_oQhN7ooooo00gooooo00?o
i>CToaDE5Om8B4P0?oooool00oono_ko;2`/ob4Q8@09ooooo`03oc<c<olD51Cooooo08Gooooo003o
ooooohkooooo01comnoComJ^F?o7QRWo`7LVokY[8_naGB3oZf4MojIL7?n[H1oo^WPVokn79Oo<X2So
fjd`om2S:oo6TBSoaXT[olR5:_o2NROo`X0WolRH:_o?Yboo_hh[oknB:_oEXC3ogjXcon>e>?oZadco
k<mF0_o]ceP0NOo/cEKojl]Donc<EOo/cEGoj/YEomblFooR^dKoh:hdomJ>;_oDPbkoeHD^omJ3;?o?
T3[o`JE?ok6<8_nmSbcog;0gonBh=OoS^COoh[@bonFg=?o:X3?o]G`Xoln9:ooHR33ocVPZolUb:_oX
`S_oi;Tgon>f=_oN]C?og:dcomjc=Oo]cT[oik=?omj]@_o8RBgo_iTUom_?DoocjFoonO1eoo[cO?oi
lGoomNYiomW1N_nKQEOo;A8Aokn<;?o?R3Co^i9]ok=O;Oo>HBSo_G@Roha^7on1H2OoSfhSohmX9On;
HRKoQUdYoh5G;?n0F2goOU8]oh5E;OmoDRkoQU//ojR:7_niVQSo`9TJolfeDoo=WBgo/hPaoiMR:?nN
H2Co>BL@oaP@2_n6CRWoY5l]oh9B;omiDRooO5<]oh1G;?n7GB[oREPYoge7:On?FbKobZ0_olZH>oo7
U2kof[<gom6E@?o@Scooi/51omf/6ooV`SWojlQRolig:Oo@RSSoah0golZ>@oncN3coVf@^oj9a>?ne
JcSo`V0`omF8?ooS]4Koh:/fomRE:ooLX33ok]E7om6;=?o:HbSocE/VomV4=?o]bdKojmI5onC:@OoN
^CkoiL8mon[8C?omnN/0c?ooool00on3Ph?o0000okjn_P0gooooo`04oo;bl_mDE5Co6ATIomGEeAko
oooo00CoR8R8obl_;oo2`/;oo_kn7Oooool00omiNGWo1`L7olG5a@08ooooo`03ohR8R?l0003o^KVi
01Oooooo00?ono_kod=3@om1@D40Joooool00=?ooooo00OooOgmojj^[_l/;2co6a/KobXZ:_m>CTko
g=cL0;Cooooo09KooO_conG:Qoo>U2kocHl]olZ5:_o4LbKo_f8VokUN9?ncG2;o]G0RokF77Oo8WRGo
ejT^omBY;Oo9W2SoahhZol^8;Oo7Ob[o`WdWol:?9ooD[3;ocZ4`ol:::oo;RRgofY`aom^H;ooPZcco
il5>ongAG?ochF_omnefooS^N_ogk7_on>ikoo_dOOojlh3ol=MQon6]=OoHTC3odh8^omB5;_oDQ33o
d:mholjiMOoIZ2cohkHgonkEF_odiG3ojM9Jombj@_oM]3SocJ8gokV28Oo7PbKoeh/_oliV:_oJUS?o
j<Hkon>d=OoEY33oah/[olZT>?oA[bkoi/HnonNlAoo`f5Ool=]Noo_aNOojlGoonO1kooO]K_okm7oo
g/=[om>lLom_FBooER8Fojb6@?o1SBKoaHMMokj@Hoo3Kc;o^h`KogmV:On:Gb[oV7@^ohm`:On;K2So
RV`XohQ[:On;JbWoQeh[oh1D;_m^Bc7oLDdaogmG;OnTIBoobjQdolRiW?nSIbgo/IIGolFJG_nHFbCo
4Ph8odX/6onFIROoWg@Noi]g7?nQP1coXh@Ioj5l6on1Fb3oCc8SofI19?nmSB7o]W`ToimT;?noQcOo
a7PaomBJ@_oU`3_ogZdMomf]7_o`ff;og9e5om6E??nlUDCoYhLmoimf<_ndOC3o`6XZol9D9_o:LCGo
h:e8on>e?ooJW2kofIL]omVF;_oV_cWoh:`golI?9?o;Jbcoc9/kolbiA_o4ZT;o`hliolR:=OoKYCOo
gjXfon[8J?ono_k<ooooo`03om;Bd_l0003oKVi^03Sooooo00?oZJVYo`820_nIVIT07_ooool00on2
PX;o0000ol;2`P0Nooooo`03omKFe_l0003oNg]k00Sooooo00?oemOGo`<30omXJ6P05oooool00oon
o_ko8B4Qoc8b<P1[ooooo`00e?ooool01_ohn?SokNg]oeADE?lS8b?oclo?ooclo;Kooooo09ColNBi
om:P@_o?TS3ocY@^olJ;9oo0NB?o`7LRok^07onhT1[o^IPIok>=6_nfSQco^Y0PokJ=7_ngRR7o_8dV
okb;9OnjQb7o]hlMom:/;_oBZc;oa9D/olfA;_oITc3oeHD[om>4:OoERR_oeiD`omVM>_oR]dSoi;e?
omNXC_oHYT[ogKa8ombl@?oIZRoogj`bomRB<?oCPBkoe8H_om^K<_oQ/ckoj<94ooCTK_oilh;onO:1
oo[cPoofl8;of<YmolVPE?o6Tc3oaYP/olnC;?oLUC7oehX`onS3>ooU^cSogk0holN<@on`MRoo^Y`e
ongFAOoagU;omNARooS[L?ohkW[onO1nooceP_oilWSolNENonkSLOoRdfSoN5hUojQ_A?nfZ8So`:@Y
okQa>Oo2UVoo]HllolJ_=On5LS[oV5PXolb1=onZPcoo/YaPojb<C_n_P3koQUh[ohAO:?mdCBooKTd`
of18;omVBc7oKTXaohQQ@?n3ECCo/X`ool^oX_o2SDcoGD0Fo`h92?meABSo]8@PolJN8?o2T23o[GhP
ojin:_m`E2ko;AhOocHT8_nUNb;o_8LRoj9W<OnjM37oagTaomnaCOoU_COogJ/Jom^W5ooWaCoom>9^
on6hA_noVSkoY78_oj9E9?n[BB3o_D/Pol9O;OoHVdCogZTnom^L<?oGTR_of9@/omNC;?oMXc7okM10
omF8=?nnMS?oYW4eojET<?nfGbco`f4YomJ8;ooPXcCogJ0domZJ<_o^eX_oo_knboooool01?nQXJ7o
?3`lo`000?lG5aLfooooo`05ooWinOnFUYKo6ATIo`000?mGEeL07_ooool00oogmoOokNg]oo_kn`0M
ooooo`04ojb/[?l];Bgo0000ob`/;0Oooooo00CoYJFUochn?_l0003o3`l?6?ooool00oo`l?3ol_;b
ooooo`1Zooooo`00`Oooool00onn_[koRh^;ooooo`0Booooo`03oiRHV?l20P;o^;Rh00Wooooo00?o
/[:boiBDU?ooool0[?ooool0:oojm>3oe[EQokJ:6onfSa[o^YXJoknU6?o2Z1WoajlIol^g6Oo3[1Wo
]Y@IokZ68?nfMB?o/F/Sojm/9?nZLR?oYWPToiaj8OnRQ1oo/I8Kok2=7OnYP1ko/XLSol^B;OoFRBko
e8@/omB5:ooFSbcoh[91oo7JI?o_fVWojLIIon;0DOoI[c?odjHWomBV:?oOZc;ofYTaomnX<ooS]SSo
k<mGooOZMoogkGX00_ofjGH0Ioodig?ohkmKomFOH_o:Jc;oaF0Tol1^:?o2Q2[obIL^om^/=?oV_SWo
jLLlon_=?_o/ddCokm=0oo?IAOoag5Com>AUooO]M_ommX7ooON1oo_aOOoXc6;ojmMUooCRI?oH`Sco
hmYPomoCK?oE^gOoa/6cojj?:OoA]G7o^Gm@olRY9ooKceooQFDboi9H;oo3M2koWVdmolbkR_o6TeGo
VVe1oiih9omeFb;oMTL^olNCC?nbXW[oKe4dof1<<OmUBc3oKT/`oh1G>?nBHccoTUPXoa/@2?la7aGo
XeX/om23;OnbMc3oR5L_og=;<?n0DBkoJD<YoclZ8_mP@2;o^hXXok=h=?nnKBSobGdbomVWAooCWS7o
gZlSon>k<ooXadGom>E/ooS/L?o^f6;oh[EAomnW@OoDT3godhXlomRKA?o/ce7oj<Dmon2Z<ooU]SOo
hkDfon>f=ooR]3Ooil4jonkB@ooJ[CcobXhcom61;_oIPRgog8l^onRj=OoT^CGogJXeomn[=ooQ[SKo
l=nPooclo?ono_h0b_ooool01?omoOgon_[jomOGeoo[jn/gooooo`04ooclo?oalO7od];BonGUiCko
oooo00CooOgmooShn?oDe=CogmoO1oooool01?omoOgon_[jomOGeooYjNV5ooooo`00`_ooool00oo=
cLgoEeMGoo[jnP0Aooooo`04omCDe?lO7aooMgMgooWin@Wooooo00?oSXj>ohZ:R_olo?`0[?ooool0
7OonoOSohLR5okn>8_niPaoo/g@Nok5b7?n`MA_o[WLJok:16_ncPQ_o]h@OolRG:?o6RROo`7DSol1V
9Oo0GBSo_UdZokiZ:_niQ1oo/HlIokJ08?n[JR;o]6dXomJ<;ooJV33ohJhkonoGG_ohkGGomnUc00;o
mNE^07Gom>5Zoo;NJ?o]eF7ogk]9omj[<ooP[C;ohK0donBk??o]dECol=UMoo7KH?oag6?olMaRoo7N
H_o^eEcokmAOoo3GH_oafF?ol]MRonoDH_oYdV3oilA9onBh=OoW`S[oi/8ionS5>_o_eU?om^YcooS_
O_ogjWgokn5komW8L_nWPTSoTVLbojY]9?njR3Com>EeomjfAoo8Y2_ocK=5ooK`N?oEbhooTVdaomRn
K?o?^6;ohm50ol:QDonAE2OoUVTjol=X:?nmPdWo`:Ugogi=;?nJN2So_iE3oea5<_nHEBkoekUoolC4
a?o:T5goW5<ZogEA;omUCS7oId`aofa:<?mhCC3oHSdWofXo9onTIB[o[WX`ogaE;_m`D2koN5P]ogYJ
;?n4FRcoO4TYoiEM:_nlNBoo`FdWom:D@?o/c6?oi;]GonK7G?oci6kom^Y]ooCTG_oejE3om_55ooSd
BoojnTconOU:oo_kBooknTKono@hoo7T<OoXfC3oi=Hfon3>?_oZddOokM=7on[:@OoXa3ook]H^ooCW
8oobhR;ojmXOomo;8?oG`2Cod:lVomB[:ooK[S7oi;/hon:d=_o_h:_on_[joogmoOono_h0oooooooK
ooooo`00`oooool00onIVIWoRHV9ooooo`0@ooooo`04oogmoOm=CDgo>CTion;RhPWooooo00?olo?c
ogAdM?nb/[80Zoooool0UOonooooloSkomk[lon_]I3ocY0^ol^>;?o3PRGo_F/SokUQ8oncH27oZV4N
oj5F6on^O1_oc9/[om:K<Oo8Tb[o_X4Rol1[9?o4GRSoaElYokQo7_o3XbCobIXXokai8_noK2Goei<`
on2X>?oS]TCoi/=AongIIooejGCom^]hooS_NooikW[ol]eYonNnB?o]ce[okLmKomjT<OoJUc3ofi`c
on:b?OoYaTgol=YPoo?OK?o_cfWokLaUon_6H_oZ`Ugoik]HonFiF_oV_UoojlYBonW7?oobgV3ol]eS
onJn>OoQ/CGogJdeonO6A?oZcE3och@ioke=;?mb?C3oDBPUof/d9On7@b3oUdhOolnZDoo`eVSoekMW
omBlIonjVdOojN9XonKFLOoK`D;oeKhRoncNJ_ndTUSoWedWoi5X>?o:TU[o^7`oogeS@OnOPR_ofYLl
ojNAKomI>2go`6l`olZnXoo3`;[o^iMboj9?:on@E2koMTl`ogI=;omhCBooNd`bogY:<OmmC2ooOe4Z
oiUg8?nQQ1[oW88Ioi5g6on4Gb?oI44UoeHf9Oo2U4Soi/1PoncGJoofl7Woh/iTolnRD?oEZTgoilQ6
onkD@Oo/f5_ogLMXon6e7ooR]akohZhQon2N8?oHVAoocI<QokJ@9_nbV2ooaj/lom:W>ooIX3Kogj/f
omn[<ooNYS7oj/HnolfgL_nmWUko[Gh^ojI^9?niPB_oaGh[olaf;?oDRC3ogjDeomfQ=OoLX3Cok=j/
ooKfm_okno_ooOgm0?oooooofoooool00:3ooooo00Solo?comKFe_oTi>Coo_knooooooomoOgofMWI
omgMg@?ooooo01?omoOgomWIfOoRh^;oo?cloooooooalO7oe]KFonc/k?ono_kooooooogmoOoEeMGo
e]KFonGUiOokno_ooooooo3`l?oIfMWokno_00Cooooo00?okno_oiRHV?lZ:RX01oooool01?oYjNWo
e=CDon7QhOo`l?03ooooo`07ooWinOoLg=cohN7Qooclo?n@T93o0`<3olG5a@02ooooo`03oo[jn_oO
gmooi>CT00?ooooo00GooOgmonk^k_m<C4coOWinooknoP2Xooooo`2HooknoooVlOOo_MSZoenPbol2
JJco062VoeN4O_o0TC_odI@aolfA;Oo6P2Wo`W0Vol=X9oo1IbKo_6XSokZ07oo8URSoeY/dom:K<?o9
UBWo`X<Tol1]9Oo0HRGo^8<MoljZ;?oCZ2oo`HhUol639_oCTBgoeHL/omF<;OoFU3?oeihlomZ/B?oM
]Dkoi;];on[6D?obgVWon_>1oo[bP?oZae?ofid`om>4;_oCQ2coe8T[omB@;?oHVc3ofI`bomVO>_oG
TS7oe8`bom2WL?oA[gOofje5onW6A?oeiVgon_:2oo[dPoo/cUGoi;TeomJE;_o9Q2[oaID^omVY<ooP
VSGo_G4coiaeC_m5:QkoH2dJoh0i7OnXMDcok=ehomjhFOoLa77od;I`okfH>_oOdEKok^9EonKG?_oP
eYgo`ZQboiAC9onGMD_od<Nbog1@;?nJNbKoe9Xlom2^POn;Of;oHSd^oi9M<?n@MdgoP6@fogeP:_n4
IRKoSf`Toi=_8on7I2GoOEH/odP/7OmA<B3oLD/`ofI;<?mdD2goUf@XohEF9OmO?BGo@2TRob`N7omY
CR_ojmYOonG:E_o@WSko]Vd[okQ`:_oAVS7ogj`aon>e<ooag4GoiL58omZfE_oBZV?obHe:okUS:OnW
EbcoZVXcok1k>OnnR3cochThomJ5<OoFR2gofi``ombR<OoHURgohJ`donBo??n`NCoo[VPaokm`;?o?
Mbcodfl[omAh;_oLUS?oh:TgomjR=_oLWSGogJ8donSIXooalO7omoOgoo_knoono_koooooom[ooooo
002Pooooo`09ohj>S_l71`OoG5aLom3@d?ooooooeMGEo`000?lm?CgoemOG00;ooooo01Cof=SHoa/K
6olO7aoogMgMooooooo1`L7o0000odi>C_okno_oooooooCdm?l410Co0000ofQXJ?o=cLgok>c/oj^[
Zol0003oFEUIomCDe0;ooooo00Col_;boeiNG_l=3@go<30`1_ooool05Ookno_oATI6o`000?maLG7o
XJ6QomgMgOoooooooOgmokFe]OlI6AWoMWIfol[:b_o8b<So3Ph>oiBDU?okno_ooooookVi^Ol@413o
:2PXokJf]P02ooooo`05om7AdOm:BT[o0000ogYjN_okno/0BOooool00oojn_[onOWiooooo`1Joooo
o`2KooKio?oBi?3oW/KPocV:__l0GjOo06>Yo`E[[Ol8K:ko1fb]oc5iU?n/SCko`8/Sol2C8OnlV1co
`9PLol>78Oo5L2KoaVHXokag8?o0TB;odiXaomFJ<ooCW37ocIP]olN::?noNR?o]hhKom:/;ooL/cOo
d:@^olfG;?oFTBooeHD]om>3:ooDPbWoei4[on:e@oobgV_onoJ3oo_fQ?ohlGkon?1moo?QL?oLY3Oo
fYT^omB5;_oDPbkodh<^om>6;_oCScKodj]Som:iOooG^Vgog;A>on>kA_oag5oonO5moo[cPoogkh7o
i==nolj4>_oIVBooiklhomR<;?nVG2GoRe@]oj=e;ooIYSooh/ILoi>=AOn=Jcco/iiooj=mGOoEa8ko
mN1]olNA>?oG]5;oeK1Moimh;onJPbgoj]mWom3?b_o6/7goT4PUoin8H_n^Y83oO5lOom:A;oo@V6;o
`[ZXoe@o<On1FB_oTVPRoimR8_ngJB?o_VlUokUo:_nNGb[oUfliokjQB?mfH2So1083of0i9?nMIBko
N5P`ofE=<OmTBC7oKTX_ofU4:om><bCo>2LQoiYJ:OoANc7o^F8RokYX:_oCVcKohK8domRH9ooJWR_o
kM90omF/>_o7/WOo`KB=okNQMOnhUE3o]hTaolB8<?o?Obkod6h[oleV:?oAN2[of9@^omfS<?oKW2oo
fIP^omRF;_oR/SKoh[8goli/:OoAJ2Sod6@Wom=g:ooKY2Wogl4Womjm:OoI[R_oe:0]ombY<ooQ/SKo
i=:Bon_[jooclo?on?Shooclo?ono_h0Z_ooool01?oMgMgo^k^kokno_ooRh^8aooooo`06oo3`l?o:
b/[o^[Zjokfm_Oo0`<3oe=CD1?ooool01ooalO7o`/;2okRh^?nm_Kgo`L71om[Jf_okno/0j?ooool0
0:3ooooo00[oJFUYoginO_o0`<3oOWinoo?clon=SHgo1@D5olO7aomXJ6SolO7a0_ooool00on9RHWo
0000ojJVYP02ooooo`0DodU9BOl0003oiNGUooooooolo?coTi>Co`410On=SHgoaLG5ojBTY?o2`/;o
:b/[o`L71omADE7of][JoooooooFe]Ko1`L7oa@D5?nEUID6ooooo`0BooGemOm:BT[oR8R8oooooooK
fm_o=cLgonc/k?ofm_KoGUiNod=3@ooooooo/;2`okBd]?le=CGoAdM7onWYjOooooooQXJ60_l00000
1ol_;boo[jn_oooooonZZZ[o0000ob<S8oo8b<P0B?ooool01_o`l?3of][JolC4a?o2`/;ohn?SooWi
nEOooooo00KojO;hokoIj_mk/MCo7WZeo`1MY_l0IZ/5o`M/[P1lo`M[[OlUM9[oY8dkok^28?niNb3o
]gLNok=h7?n]KacoZUhNokMR8oniLB3o_H`Qom2H;ooEVC?odiPaoljH;_o3TbGo]H/JokVE6oo?YBgo
e9hcom:L<Oo>V2coe94^omVB;ooOZ3Sok<iHooCQKOocg6Wol==Qonk>GOo]cecok]5Mon_8E?oZbEGo
hkA1omRC;ooCQ2koe8D^omF5;_o@S3OobYmGomJM?OoM[dCoj/UBooKXM_ojmHCon_20onCHS?o;akKo
a/K6ol^oYoo;Q4;ofId`on>g=_oHRBco/V4YogA19omm?RGoZ5P[oln<@?oJ]E_oi=nBok^[K_nNMD_o
imEcon;4J?njXFoo_9i3okZ7<On>DbCo]9A6ohmbG?nRMD7oWU@Xoe]8<_mmIBGo_88bokiQ:OnMDCOo
GCd`oe0d:OndFS?ocX9DoljROOo:Wg?oXVDdoi1L<onjTdGoiL=FonNkCOll:a7o6Q0=ogY:;OnYKRgo
XVd^oh1K<?mkEc3oM58^ogMA;_moCRkoM4@ZojmK:_o2LcCoejE4on:d??oJW2SodHHPomVJ:_o_dSoo
ekLkoj=X;_ncP3[ob9<nom>cJ?oEZEkoaf@Xol=?9?o8GbOodX0[omVK:ooJYBKofY//omRF;P;ofIP^
01GofIH^on6b=OoPZSKobe`Volea:Oo3NR[o/g0UokIh7onhLb7o^fPSolId9ooFTboogJDdomfT=?oQ
a7OoiNGUong]kOoclo?onOWiooclo?ono_h0ZOooool01OmRHV;o0000odE5AOmlO7cod];B033ooooo
00KoemOGogIfM_lB4Q;o0000oeADE?n@T904ooooo`07omcLg?mPH63o1`L7o`000?m5ADGoWinOooCd
m03Xooooo`00X?ooool02_nm_Kgob<S8ooooooo8b<So^;Rhofa/K?ld=3CoooooolK6a_oMgMd2oooo
o`08ol;2`_l=3@goFEUIooCdm?oooooo_[jno`<30omaLG42ooooo`0?on?SholA4A7o<30`oogmoOnm
_Kgo/;2`odQ8B?lZ:R[oVi^KohR8R?oWinOon_[jok2`/?n/[:conOWi00Oooooo01Wok^k^oooooooo
oooojn_[o`000?nVYZKon_[joeYJF_lW9bOojn_[ooclo?oBd];oB4Q8oa<C4ooLg=coooooom[Jf_l0
003o3Ph>okJf]_mjNW[o][Jfoo3`l?nNWYkoa/K604Kooooo00[ono_konGUiOo?cloo[:b/ohb<S?n@
T93oTI6AoiBDU?no_kooi>CTE?ooool01_oHj?;oV<;MoeBIaol;KZoo066Xo`1X[0Oo1fb^09Co1fb]
o`MZZolUM9Wo/913olf<;?o6PRWo_f`VokaP9OngG2Co/EPRok=P8_neN1ko^HdNol6@9?nkSako^90L
okbH6Oo4YQSocKHHom6j6?o;Za_ob8lQol=d9Oo6LbSofiXbomfQ=OoP[3oog[97omjkD_oQb5gojMUW
ongMJ?oYdF?ojLUPooOWL?ofhfgohJPjomR@<?oCPbkoe8@^omRA<_oK[4CojLM?ooKWL_ojmH;on_=o
ongPN_oH[57odImMoln`POo>_I[oc/>Som:fO?oESc;oh[8fon2Z<ooHQ2Wo^6hYoh5C9on0@B?oNChS
oj1>9Oo9WV[oc<:9ok2QFOoG`VCoo>eeoi9^?OmlDcWo`9e=okEo<On/PCWoWW=5oj]f@onADR[o:QhJ
oe4l7on3Bb?oYCdQokaU??mI=RGoOVI<olc7`?o8`k_o]jN;ogYO?_mC>BcoLT`bojU]<Oo?VUCo_kFG
oa0@2olj8ASoVfTboiIj;_m_F2?oJ4hToem:7omXBRCoHd4Vodla9?mdCRWog[90onO6?_oP[CCoe8/R
om688OoET2Koi;/ion[8??oHXc3odh`/omIl:oo=IR_ob6@folIN;oo<Jb[oei@_on6e<ooR]c3ohkdZ
onK89ooQ/C3oh:`aomjX<OoLY37ogJ8aon>d=_oS]3Ooei<`olN0;OnlIRSoa6LYolYV:_o?K2_ofXXa
omnP=?oOYCKogIleomZK<ooN]EGogMgLonKVi_o]kNgolo?cooShn?olo?cooOgmZ?ooool01_n^[Zko
V9RHooWinOnn_[ko:b/[onCTi37ooooo00?oWinOo`000?ofm_H01oooool00onFUYKo4Q8Bom;BdP19
ooooo`03oogmoOoGemOod=3@02oooooo00?oj>SXol?3`oooool0K?ooool00:3ooooo00OooOgmooOg
moomoOgoooooojFUYOlZ:R[oKVi^00;ooooo01SonOWioooooooooooolO7aode=COlD51Coclo?oooo
ooomoOgo=cLgo`L71oo?clooooooooShn?mgMgOo0P82ojNWYoohn?SokNg]ohR8R?l0003oeMGEol;2
`_o6a/H>ooooo`0DohJ6Q_l0003o^[ZjoooooonEUIGo0P82ojVYZOoooooom_Kfog1`L?l0003oZJVY
ooclo?oooooo>3Pho`T92Oo9bLWom_KfojBTY?oemOE6ooooo`0>ooKfm_oJf][o_[jnoj2PX?n8R8So
W9bLokfm_OoCdm?od];BojVYZOn:RX[oWYjNol[:b_o^k^i@ooooo`06ok[Fj?mg[];o?Hboo`1WZol0
HZWo0fZ]2_l7K:h0UOl7Jjco1fVYobYdU?ngScgodI@aolnD;_o8SROo`h4SolF28oo6TR3oaj0LolV[
6_noUaco^i0NokbA7OnkR1co^XHKokR06oneP1Wo]XDGokN06_nmP2Go`7dWolJ1:?oGSbooe8H/omB9
;_oDS33odX``olZ:<Oo:Vd7obYU4olF9>Oo4RS7obii9olnUC?oIWC;ofI@aombP<_oP[CCojLE:onoE
G_o]cESoj/9?onNjB_oQ/dSoh[0nonNlA_oZ`T_oj/QDon_@H?oZeFOog/IDonBlC?oO[3KogZ@aom5l
:_nJL3goL50]ogY=9On4CbKoW4hToi1F=_n8K2coglU:oo[aK?o[df3oc/6QoiB5JOnNKbko]8Hfom6m
OooBbJgoUVlnoiF6Fom9=bGo=2DOodl]8on6FccoBSDXoij7J?nn[8[oXWM8ol:5>?o9WEcoY8]Qof15
;OmH?2coO5@joh1SA_lN4`goES<RogaA9OmRB1OoB2hKoe@d9?mV?BKoCc<SocDT8?l[6agoVgdiooge
I?oWaEWod8HXom><8_oCS2?ogJD`onBk>OoV`3SodI4]okmO9?o:HbKobF0WomAo;ooLXCcog[4gomV_
9ooAXR?ocYhSolRL8_o5VBCoa9HUolZE:?oAW2gog:`bon>f=_oQ/SGoh[Deombn:OoM_RgogKdcom^a
:OoFYRKoejXYomR_:ooHZRgof:P`omZU<_oOZCCogjlkomWB^ooNg]koi^KVong]kOoclo?on?Shoo_k
noomoOgoo_kn0:[ooooo00?o;Bd]ofQXJ?ooool0<?ooool01?oBd];o20P8ojVYZOono_h6ooooo`03
okbl_?l@413oYJFU04Wooooo00CooOgmolk>c_nDU9Co^;Rh;_ooool00ooTi>CoYJFUoiVIV@1/oooo
o`00Y?ooool00oo/k>co30`<ohf=S@06ooooo`0DoiNGUol0003oMGEeooWinOooooooShn?o`000?lc
<c?oclo?oooooooCdm?o51@DodQ8B?ogmoOooooool?3`ol<30coNg]koooooooZj^X=ooooo`08oogm
oOlS8b?o:2PXooOgmoooooooaLG5o`D51OmSHf<2ooooo`0;okno_ol=3@goFEUIooCdm?ooooooPH61
o`410On2PX;oooooooclo?oclo<0A?ooool02Oo]kNgoc/k>ok6a/OnGUiOoSHf=ojNWYoo6a/KohN7Q
oo_kn`02ooooo`07on_[joo6a/KoWinOohj>S_nYZJWoclo?oo_kn`1;ooooo`07onOamonH`mkoGj7;
ob5l]ol0HZWo06FZo`E[[@0<o`M/[P0Uo`M[[Ol7JJ[o1fNVocahQonlRb[o_X`Ookf>7_nmTQ_o_YHI
oknK6?o2WaSo`j4GolBK7Oo0SRKobYDZolVA:Oo0OBCo^VdRokQT8oncGB?o[UDRoj]I8?nZGaooYUXM
ok]a9ooGS2koe8@/omF9;OoNXCkok<ULooWYM_okkgWomnUdon_FI_oQ_53oeZ8gomZO=002om^M<P1b
omVG<_oHU3;of9XfomRX@ooK^E3oglQSomg<N?oEbhooclVSol[7]?o9akgob/Nmom32WonSICKo`V<Z
omJ3;?oU[SGofiH_om=n;omlC2coFc/Xoh=N;?nkQ2_oh;8kooONEooehfOojMR0om[CZ?oFcjCoWXmB
oiUeAOo>[6CobJ98olfoTOn_TUkobkV6ohaR=?mVABko=2POobdQ7om8<2OoJ4HcohiS;onULc;oZXM=
ojnCH?n[ODGoUfDaog1E<OmL@bcoKdD`ogI6<?meA2goID0Rof=19_m`CS7oJU0bofY=<Om`BBgoGc/X
odT^8_naHc3okL9SonW:FooCRR7odXTRomNE:?oP[CGogj/dom5m;?o;IBSocV/Yom:1;?o8Qc;oaJ5W
olNYM?o0Re7o/V8Vok1N8oncI2Go^6PUokmZ9_o9L2Wod7d/omNE<?oNZC?ofj0`ombQ<OoS]SKoeIl^
ol6=@oo0UE7o]gPZokE_8?nlN2Co`G/WolIk:Oo=PRcof9TaomnY=?oMY3?ofl9oomOGeooNg]koiNGU
onc/k?oclo?omoOgoo_knoomoOgoo_knooooooodn?coe>KaY_ooool00on;Rh_o2PX:om_Kf`0`oooo
o`04ooclo?lD51CoJFUYooclo0Kooooo00Cof][JoahN7_m`L73omoOgB_ooool00ooEeMGoLW9bomWI
f@0^ooooo`03oo[jn_mdM7Co_kno06_ooooo002Tooooo`03onWYjOl;2`_oBDU900Cooooo01Goo_kn
oooooooDe=Co;Rh^oaDE5Onf][Koo_knon_[jol92@Wo@D51og]kNoogmoOonOWiof5QHOl92@Wo]kNg
ooooooobl_;o<S8bob0P8?oXj>P03_ooool00onn_[ko0000oh>3P`02ooooo`0=ong]kOm;Bd_o51@D
omcLg?ooooooo?clod92@_lE5AGol?3`oooooooCdm?o0000oc@d=015ooooo`03on3Ph?nj^[[oZ:RX
00;oT92@00Co/[:bomWIfOo]kNgoo_kn1Oooool01oono_kojNWYol71`OnDU9CoTY:Bok2`/?oGemL0
B?ooool01_o8gngoNK3DocN8__l?LK7o06FZo`5X[0oo1fb^09_o1fb]o`MZZol8J:Oo0V6OoeMkL?o6
RROoaHDVol1i8onlKB;o]f@Rok5M8On[FB3oYUHOojIM7onlRB3od9T]omBK<Oo>Ubgob8hXolJ09_o5
MBKoa6/Vol=S9oo2HbOo`6XUom64;_oITc7oh:e1oncCH?o_ffOojmMSon[EH?o[fF;ol]mSonk@EooY
`U?ol]i^on>cBooFSRooe8H_omF8;ooESC3obg`^oka_;?o5S4;oaj=[ol:MKOnlV73o^j62oknPMoo3
PD_o_edWom5a:_o?MRWo/6DWoj]f:OoMWcCoeH@/olin:Oo<Rbkogjlioo;FE_obh6_oh/EWol>RF_ng
Q4[oc:amolg4[?mfI4KoTgA:om?7X_oE[fSo_9M:ojR<E?n=M4WoRgA?ofeI>om8<B3o=bHJodD`9?mL
@R[oHclZok>@D_oB_GgockMgol6VFonKOCGoN5d]ofQ5:OmQ?2SoFcHUogI6;_mfD2koNUD_oe]48omC
@2;oG4@Tof539om`ABcoNdPZol]d:_o>KBWocX<UomB=8ooBRb;ofih^on6`=_oKW37ocW0Zolj3;Oo2
OR[o_7@WojmK9OnhN4[o`YAJolF8??o5JRKobFHXoleT:?o?IbWodgL]omZE<ooOYc;og:<`omVI;ooI
UbkofY/^on>d=OoCUc7o_6LYol9]:_o;N2god7X]olma:ooBLRcoeh<_om^F<_oMX3CogIldom^L=?oM
ZD;odlo0omKFe_oMgMgoi>CTonc/k?obl_;omoOgoo[jn_oin_coT;gJodFA`ol^Pk_oGj3;olKMk@2T
ooooo`03onOWiol0003oS8b<037ooooo00?oAdM7ocHf=_ooool01_ooool01?ohn?SoATI6odI6A_oi
nOU;ooooo`03oi6ATOmaLG7ooooo02kooooo00?of=SHochn?_ooool0J_ooool00:;ooooo01WoaLG5
oo?cloo0`<3o0`<3oh20P?n[Zj_oooooooKfm_oLg=cofm_KokVi^Oolo?coJFUYobh^;_m2@T;oh^;R
oooooomOGeoo6ATIokfm_OmNGUkoooooolC4a?l0003oJf][00;ooooo00?oOWino`000?o7alL03_oo
ool00om=CDgo20P8on_[j`02ooooo`09ookno_nn_[ko4Q8Bofe]KOomoOgoooooohj>S_l0003oalO7
00;oo_kn00?o:b/[oa4A4OoPh>00@Oooool02OomoOgoc/k>ok:b/_nPX:3oSHf=oiVIVOo4a<CoinOW
oo?cl`0:ooooo`07ooWinOoQhN7o/k>coi6ATOnKVi_o];BdonGUi@14ooooo`06okSDj?mAV<Ko9gni
o`Y^[ol0IZ_o1F^]4Ol7K:h0WOl7K:go06JYo`1JX?lBJjKoGIBgol6_MOo?T2oodI<aolb:;Oo8OR[o
a78VolI]9oo5I2Wo`f8Wol5Z9Oo2R27od9L]omFJ<ooDVc;odi/`olnI;_o;TR[oaWlVol=c9_o2HbOo
a6lXomB@<?oGTC;od8X^olV5<?o5R3Co`XLfol2:>_oL[T[ol=EVooWbP?olnXOokm5ZomRB<OoGSS3o
e8@^omB5;_o>OB_o^VP^okea=Oo>XV[odY=<omjJ>_o/c63oj]5VombcE_o1U4coX6d[okAj<?nGJR[o
TFPUomNE<OoLWCGoi;<non[2AooZcUSohm1Mom:eB_o5WC_o_iPmokjKAonoVT?o]hd]oiQ^:OnRKS;o
aj5[olb^MonXNcKoSg=2ogUT@omK@bgoV7Y;olFLG_lf91SoFS`Xol>OHOn@N5[oECTZojJ@KOnVUGOo
OEm3ofI09omE<b[oBc0Voa8=1oli8QKoIClYoe0n:omSABkoEcPTodP[6om@<b3oBRhRocXV8OmYBBKo
fjl`omb`<ooR]CGohkLgon:f=_oQ/CKogjTdomfS=?oFVc3ocXl]om2?;ooGW37ogjDdomNYH_o@Zg_o
d7dnoleQ9oo>IbWoe7l/omZJ;_oK[Roof:h_omRJ:ooIV2kofIT^omZI;_oIV2kogJ@bon6]=OoEObgo
cVTZoleU:?o?K2[odWh/om:I:OoEZB[oeZ@]omNO;ooIX3;ofj8combQ<ooJ`GWod=3@omGEeOoLg=co
hn?Son[Zj_oalO7oUkkGocb9^ol@LJoo06R[o`1X[?l2JJco9Gjhof6QbooCiO40Xoooool00oli>CWo
;Bd]ooooo`02ooooo`08ol;2`_m>CTkoO7alono_koooooooHf=Sof][Joono_h3ooooo`05ookno_nj
^[[o@410od];Bonl_;`01?ooool01omkNg_oDE5Aojb/[?oooooof=SHochn?_n][Jd02Oooool01omQ
HF7oEeMGol30`?oooooo^;Rhod92@_o8b<P00oooool01_nDU9Co3@d=ofa/K?n<S8coOWinojn_[`Co
oooo00KoO7aloa<C4omPH63oVYZJof=SHond];@2ooooo`03oo;bl_mVIVKoOWin00Cooooo00?oQ8B4
odE5AOnn_[h00_ooool01Oono_kod=3@odm?Com@D53od];B00;ooooo00Oo/k>codm?Con3Ph?on?Sh
oooooomFEUKoN7Qh00?ooooo00CogMgMod];BomHF5So]KFe0oooool00onKVi_oFe]KojFUY@04oooo
o`05omcLg?mhN7SoM7Adoi>CToomoOd00_ooool00oohn?SoBDU9og9bLP02ooooo`04onc/k?mBDU;o
ATI6ojNWY`;ooooo00Co/[:bocdm?OmTI6Co[jn_1?ooool00on][Jgo;Rh^odI6AP08ooooo`04onSX
j?mGEeOo>c/kokFe]@;ooooo00CohN7QoemOGom[Jf_olO7a0_ooool00omRHV;o?clookZj^P02oooo
o`05oo_knone]KGo?Shnof=SHooZj^X00oooool01?nCTi?o>c/koeIFE_o<c<`2ooooo`03omoOgomM
GEgoT92@00Cooooo00?ofMWIog5aLOl00000Joooool00:;ooooo01ooT92@oogmoOnKVi_o0000onk^
k_miNGWol?3`onSXj?mDE5Coh^;RogmoOoomoOgo/K6aoa8B4_n3Ph?oIVIVoo_knoo<c<co0000oj^[
Zonj^[[oH61PonKVi_m7AdOo92@TomWIfOoooooo_[jno`X:2_mjNW[omoOg00gooooo01?o4a<Cog]k
NoooooooooooomoOgooooooono_kohj>S_l820So_knooooooooRh^;o4Q8Boh>3Poojn_[oooooog=c
Lol20P;oWinO03oooooo00Wojn_[olC4a?nXZ:SoVIVIohn?SonTY:CoemOGono_koojn_X03_ooool0
1ooemOGofMWIoj>SXonBTY;oX:2Pol71`Ooclo<0?oooool01?o/m?WoT;gKocV:__lNNKD2o`=Y[@03
o`I[[_l7K:ko1fb^00oo1fb^0:7o1Vb^o`1VZ_l0HJKo97beohRdd_o6en;oe]cPomWIeOoAZU_oaXTW
olJ=9Oo6UB3oaIhJolNR6_o1R1ko_6XSol1O9oo2K2GoaH/Qom6H;_oDVC?odiTbom>H<OoAV2kocIPX
olVK8?o8WAgocZhKomJc8?oGSBkoe8@]omF6;?oFQR_ogiljono>G_ohk7[on>emooCTL_o[bUkofiPl
ombN=_oHTS;oeHL^omB5;_oDQRgoehLdomZ<>ooFRSCojLALoo[cPOofhWWogZYDol^HF?noSe7o[g4[
olR;:_oDV2OogiXaomV@>OoBOB_oe8<]om>3<?o;PC3obh0XokU/9?nVG2Go[VTfokf2D_neP57o/792
oj=G9onlQ4Oob:Ifol:CDOnCNDKo<20FohUZ>OniRdgobj]_ok><E_lT5aCoKD</okEj@_neQdgoUW91
oei1:_m?;b[oSUT[olIn:On_JbcoFC/Mo`P71Om?;aooEc@Roe4i8_mG@bSoGDL^ofY8;_mK>bOo?RTQ
obdQ7omoDB[oe9<fom^W>_oW_43oi;HmomfT=?oJW37ofihdomRJ<_o<U2Gocj4Som6V9_oAXb[odJ8/
oljO:Oo:U2Ooc98XoljC:OoFY2gofk0aomV/:ooI/RGogl4Ron2c:_oMX3;ogIl`omZK;ooIVBkofY/`
on2[=?oIUS7ocFXYom5l;?o;Nbco^f@UokEP8?njJB7o`74Tol=d9Oo7MbOod8P[ombS<_oNZCWod<R]
olo?cooDe=Cofm_KokO9e?loQ;;o46ZVo`9UYOl5J:Wo1f^/o`M[[Ol7K:go0fV/o`M/[_lVOkSoGj3;
omo/m@2Qooooo`03ohB4Q?l61PKoclo?00;ooooo00WoT92@o`000?mMGEgoTi>Coooooom7AdOo10@4
ofm_Koo_knl00_ooool01ooShn?o=cLgo`000?mFEUKoBd];ogYjN_oclo<00_ooool02OlB4Q;o0000
oinOWonQXJ7okno_oa8B4_lP823oYjNWooShn007ooooo`0Ao`000?lA4A7oYZJVokbl_?o@d=3o1@D5
oc<c<onf][Kono_kooooooo<c<co1@D5of5QHOoQhN7od=3@oeMGEon1PH400oooool03Onc/k?o2PX:
oeYJF_oLg=coe]KFob/[:onl_;cooooooo3`l?m2@T;o20P8od];BooUiND00_ooool08OmZJV[o0000
oeEEEOnPX:3ooooooo[jn_ln?Sko0`<3oginO_mdM7Co[Zj^oooooomeMGGo0000ofa/K?n?Shoooooo
obl_;ol71`OoNGUiooOgmooooooodm?Co`000?mADE7oaLG5ohn?SooZj^[ooooooh20P?l20P;oDU9B
ohV9R@02ooooo`0Noo3`l?n3Ph?oQhN7om_Kfom7AdOoIVIVooGemOoooooooOgmoc8b<_l51@GoiNGU
ooooooo]kNgo?3`lob8R8_nUYJGo[jn_ooWinOm0@43o2PX:ol30`?nl_;coRHV9ooooooomoOgo^k^k
o`d=3Ol0003oLg=c2?ooool0:OmTI6Co0000ofa/K?n8R8SoOgmooooooonCTi?o>3PhogmoOonCTi?o
n?Shok^k^ol410CoFe]KoginO_nl_;coooooom_KfolM7Ago7QhNoh20P?m_Kfooe]KFoooooonh^;So
5ADEob@T9?nBTY;oOgmoohN7Qooooooofm_Koc<c<ol;2`_oHV9Ronk^k_oooooolO7aocLg=ol20P;o
7alO06_ooooo002Rooooo`0Ooj^[ZomBDU;o3Ph>oaLG5ookno_oj^[Zod92@_mdM7Co:2PXooclo?n<
S8coVYZJoooooold=3CoHV9Rokno_ombLW;oalO7o`000?lf=SKooOgmokRh^?m3@d?oADE5o`820_nO
Wioooooooo[jn_lW9bOo71`Lonk^kP0=ooooo`0CofYZJ_nXZ:SoooooohJ6Q_lC4a?o^KVioooooooh
n?SoQhN7od92@_oIfMWoooooobDU9OlO7aoon?ShoooooooAdM7o0000oeUIF@0;ooooo`03onKVi_o/
k>cooooo02oooooo00Woh>3PokFe]OnPX:3oUiNGoi>CTonl_;coi>CTooOgmoono_h04Oooool01oon
o_komoOgolk>c_nKVi_oV9RHoj:RX_o@d=00??ooool01_oEi_;oGZ3;oaij]_l?LK7o1F^]o`I[[Q;o
1fb^0:Go1F^]o`1UZ_l0IJ_oAi;3ok[Fj?oXl?Gol??donk^k_oTi>CofMWIom?>_?o6Sc;o`H0Sok]c
8OngIR3o/U`QojiI8?nXDR3oZeLPokER8onlN27oaHdRolbD9oo9Tb?oaY@OolFI7?o6X1Wob:HHolVX
5oo7Y1OobZa0olbGB_oER2koehl`on2]@ooZbEcojLYMonK5D_oU`D[oi/=7onFn@Oo/c4kok]9AombL
=?oERBooe8D^omB6;_oFS3;ohjm=ooGSLoogjG?ok<mLomB>;ooCUBSog:lgolj>;oo1PROo_8<Xom:H
?_o_dfWoiKYDolia9_oANBOod7LWokmn9_nWMRKoVV/lokbIL?nmXg_oPTl_okUL:oo7GRco_DXVolNL
Doo8VV3oQ5dgoh=]BOn9K4GoRElaom2`Joo:WUcoTFHiobXL6?m_@booUe``ojec?OnmPdCo^h/ooh9T
<omH>RSoODX/ojMU;_mL?1Wo2@L5oeLc8OmO>RCoGC`Vog5<;_m^CBcoITH/ofQ5;?maA2_oGCHWoimR
:ooJU3[oc9@nok^99ooAS2Goe8/SomB>9_oHUS;ofYLdomRI;_oF/AooekPPomRh9_oF]2Ood[<Qom:d
6ooC]aSoeKlGom6h5oo:ZB7o`98`okYl8?nmOBCo`hHVolR<:Oo?URcofJ@aomn[<ooNYc;ogZLdomjX
=?oKWS;ocXP/olM_:Oo;KR_ocg4]olm/;?o?Jb_oe7d^om^C<OoMX3?ogJ0dom^M<ooK/UOobl[6olg=
cOmNSJgo3ejFo`IOVOl5HIgo1fFRo`MWY_l7JJWo1fZ[o`M[[Ol7K:go1fb^o`E[[Ol:KJoo7GVeoeVL
bOoBiO40Woooool00ooShn?o0000ohV9R@02ooooo`0Mojj^[_l0003oUiNGoo?clonSXj?oVYZJo`00
0?oAdM7oRh^;ookno_ooooooa<C4o`000?miNGWol_;bonc/k?n6QXKoW9bLooOgmoooooooBTY:o`00
0?odm?Cof=SHohb<S?mTI6Co>CTiol30`?nf][H01oooool03OlX:2So6a/KooWinOo8b<SoTI6Aoc`l
??m/K6coZJVYom7AdOoooooono_ko`D51On5QHD00_ooool00onh^;So4Q8Bol_;b`02ooooo`0iom_K
folO7aooMWIfooShn?oooooo][Jfo`d=3OoUiNGono_kogAdM?l71`OoHV9RohN7Qoo]kNgooooook>c
/ol820SoRh^;oiBDU?nJVY[ono_ko`000?m;Bd_omoOgom;Bd_n6QXKoiNGUoj6QXOl0003o/[:boo;b
l_nNWYkoUiNGo`000?oHf=SoShn?oooooooXj>So>CTiochn?_ogmoOo_KfmohR8R?o_knooa<C4o`L7
1om`L73o_[jnoh61POooooooe=CDobPX:?nk^k_ooooookno_olD51CoVYZJ00;ooooo01GoT92@o`41
0OmnOWkoooooookno_nVYZKo10@4ol?3`oni^KWo_[jnolK6a_oCdm?oo_knoooooolB4Q;o[jn_oooo
oooGemOo?Shnoe]KFooOgml02?ooool0:Ol61PKo=cLgooKfm_o/k>coXZ:RokZj^_n^[ZkoNWYjooKf
m_nLW9codm?CoibLW?l0003ok^k^ono_komEEEGoooooolC4a?l0003oP820ooKfm_nh^;SoTI6Aoocl
o?mmOGgo0000ol[:b_oinOWol?3`ok:b/_nLW9con_[joeYJF_lD51CoGUiNoiBDU?oemOGooOgmofi^
K_lf=SKo/[:b06_ooooo002Rooooo`0;oo_knonIVIWo0000ohf=SOomoOgoooooom7AdOlW9bOoGEeM
oooooooOgml00_m_Kfl03OlQ8B7o0000omKFe_oXj>SoKVi^o`000?m7AdOooooooogmoOoKfm_oATI6
o`000?nOWil00_ooool01?mmOGgo0000olS8b?ono_h<ooooo`06ooWinOn9RHWoH61Po`000?mGEeOo
l_;b0_ooool03?okno_o_knoog]kNomeMGGoOgmooeMGEooFe]Kooooooo;bl_lb<S;o8B4QooKfmPWo
oooo00Col?3`oiFEUOnPX:3ob<S8;?ooool02_oinOWod=3@ojFUYOnJVY[oUYJFoijNW_o7alOokno_
ooclo?ono_hEooooo`07oogmoOobl_;o_;bloiFEUOnJVY[oZj^[omoOg`0hooooo`04ojo@iOlgRKko
2Ff_o`Y^[aCo1fb^0:;o1F^]o`1VZolFMK?oP[GFomg[m?ogn_coo?gmoo_knooemOGokNg]on?ShooH
f=Sod=3@om2hP?o@T2oodI8`olf;;Oo9OR[oaVhWolE/9oo4MBCoahLQolnU7?o:WA[oaXPOolV=8_o7
RR3oa88Pokmi8?nkLR3o]V`Pok9X7on_J2So/fhYomB=;_oHT33oeY8com2@<oo9Rc7o`h<aok]j;ong
LBko/f<Wok=S;_noQDGo_WXdomB:;ooER2ooeHT^omZS?ooH[dGobIL_ol238_o5Rb7ocj0/om^eA?oT
aUCoh:a<om1o>?oX_UgokMM`omBAB?o8IbWocW0Xom5h:OoBNROo^70`okR8BOo9Y5cob:=Ool^IG_o3
MSGocYHkokia=?nmAB;oSDdVoiAL=_n;LEOo[8U=okF?G?mYBSGoZ8A?om_:UOnh[7go;Q`Loif3I_nh
Y7ooSf8mohiO?_nJISOo[FT/oieX<OmRBc?oIT<^oe`j8_lF3PWoG3DSodh_8Olf9Qko>bPQod0[7om>
<b?oGSXVofLm:?mV>bWo]gllolfGBoo6Ue;o`H`]oljB9_oDSB?odh`RomF?:OoHTc?ofILcom2J:_nn
P2Co_WdSol608?o0LB3o^64QokEJ8_nmIRCo`F/VolAb:_o7NBooagP[olYm;?o=QBgodH/^omB<;_oE
S2oofIHbom^M=?oKW3;ogJ4comZU<_o:X2Kobj<VolVN:?o8VBkobH`WolfA:OoGY2oofZDbomZR<ooK
XC?ofihcom^M<onm[gCo8VJCo`EFRol5F8oo1U^Co`INV?l6HIco1VBQo`MVY?l7J:So1fZ[o`M[[?l7
K:d3o`M/[P04o`Q][ol>L;3oBY?4olgQkigooooo00?om?Cdod92@_lY:BT00_ooool03_oDe=Co7QhN
ofEUIOomoOgobl_;oj^[Zol30`?oRh^;onSXj?n<S8coooooom7AdOlj>S[o_Kfm0_ooool03_ojn_[o
S8b<onGUiOooooooTY:Bo`000?o;bl_oo_knokbl_?mVIVKo5ADEomKFe_o0`<3o`l?31_ooool03Om_
Kfoo3Ph>on7QhOohn?So^[Zjoclo?old=3CoinOWoj:RX_oPh>3ooooooeeMGOm5ADD00_ooool00ooY
jNWoA4A4oeEEE@02ooooo`1@ookno_m0@43oEeMGoo3`l?oooooooOgmoa`L7?mIFEWooooool_;bol0
003oPh>3ol_;bonKVi_oo_knooclo?lY:BWoBDU9ono_kooIfMWon_[joa@D5?mRHV;oooooookno_oi
nOWoo_knolW9bOlE5AGoO7alookno_o6a/KoYJFUo`000?nGUiOohn?SoiBDU?ono_koQHF5o`l?3oo7
alOooOgmonc/k?oinOWooOgmobTY:OlL71coooooomKFe_oooooob/[:o`<30oo3`l?ooooooogmoOm4
A4Co;Bd]on3Ph?ooooook>c/o`P82?l:2P[ol_;boooooooGemOo8b<SogIfM_ohn?SoeMGEoo[jn_on
o_kooooool[:b_l51@GoPH61ooooooono_komoOgooShn?ono_h8ooooo`0Ko`000?mADE7ooooooooo
ooofm_Kol?3`onk^k_oKfm_on_[joo_knon^[ZkoDU9Boc8b<_ojn_[oo_knomKFe_oooooobl_;o`P8
2?nDU9Coooooooclo?ojn_[oooooogEeMOl0003ok>c/00;ooooo00con_[jon[Zj_ooooooZZZZo`00
0?nYZJWo/[:bojf][Oolo?conOWiooKfm_olo?a[ooooo`00__ooool01?o0`<3o2PX:og1`L?olo?`L
ooooo`04ooShn?mjNW[o10@4ojb/[0Wooooo00Koo_knol_;bonDU9CoUiNGojJVY_oShn<Xooooo`08
onc/k?nj^[[oVi^KoiRHV?nFUYKoZJVYom7AdOolo?`Looooo`06on[Zj_n[Zj_oUYJFoiZJV_ng]kOo
l_;b<_ooool01OonoooohNkfognce_lHM[Co0VV/01Ko1fb^00Co2Ff_ocF7_OnTbN7om?Wl0oooool0
6Oono_kon_[jooCdm?o/k>cohN7QomOGeoo>c/koblRkolfF>_o?TBkobXhYolRD9?o:XQcocJ/Iom2e
6?o>]1Kock<Nom2eD_o7Sc3ocI0Yom:G<?o?Sb_obhDXolQe9Oo7KbH00_o6IRL0Poo5IBOobg@/omJ:
;_oEQRgoe8D/om9o:OoBPRcoi;IEonkHL?o[cf_ogk=Dolb3;?o=RBkodh@^omB6;ooER2oocX4[olMg
:?o2MBOo_V/YokaY:_nlKB_o]V@UokUQ8OoOYDWomnMhomZUEOo3HB_oaEhVolEh=_o>M2kod7<Yom9j
:?nUIbgo]917olJ_G?o4RTCocW0[onNhB?nnV47oT4l]okI28_nOB2OoUEP`oiIX??oE^ggoaYaWolFa
LomS@S;o_IeOok2TN?le7R7o[YU`omoFU?oSaTgoaYDmojmj@_nPOUOoPE@gogI9<_mT?bcoLD@`ofHl
:_m_@2[oABdQoe<b9?mJ=bKoJ3lZofDj9_m0:R;o=bHPod0[8_o6VD?ojKHmomjS<?oS[3cofY/comB:
:OoCSB;odh`RomF?:_oHU3?of9<colem;_o>ORoodH@aom6<;_oGW3;ofIdbomRI<?oEV2_odh4]omAn
;OoCO2godGD/oli/:_o=JB[odGL/omR?<_oKVc?ofY``omZJ;_oJVRoogZDdombQ=?o8LRWo`FX]okmd
?_nhGB?o^F0QokYT8_nmJB?o`g<Volb5:ooEUboog:8combR=Om;MG;o1UF9o`IFRol6F8ko1U^Bo`IN
Uol6H9_o1V>Po`MUXol7J:Oo1fVZo`MZZol7Jjgo1fb]00?o1fb^00Co1V^^o`A[[Om=ULGod>C`Vooo
ool01?ojn_[oRXZ:o`X:2_o8b<P2ooooo`0=of5QHOlX:2Sof][JoooooonRXZ;oC4a<oahN7_oooooo
k^k^oooooooQhN7oFEUIoj6QX@03ooooo`0=oo3`l?n<S8cokno_ookno_l0003oPh>3oooooooYjNWo
L71`oc8b<_mmOGgoooooooKfmP06ooooo`0=om[Jf_l0003oWIfMoooooooGemOoJFUYoalO7onVYZKo
o?cloo_knoooooooV9RHo`l?3`02ooooo`04ooShn?n5QHGo4A4AolK6aP;ooooo00?oMGEeodY:B_oV
i^H00_ooool04OmgMgOo1PH6oo;bl_oWinOo<C4aoc/k>oooooooi>CTonOWioooooooKFe]o`000?oC
dm?ooooooo_knom5ADGo:b/[00Gooooo00goD51@ocTi>OoTi>CooooooiFEUOm6ATKo9bLWooooooo_
knoooooookNg]ol0003oRHV900Cooooo00?oTi>Co`000?nk^k/00_ooool00oo:b/[o0000ojRXZ002
ooooo`03oj6QXOl0003oZj^[00;ooooo00So?cloo`410OmhN7Sooooooo;bl_mVIVKo9BDUon;RhPCo
oooo00?oLg=co`000?o6a/H03Oooool00olc<c?o;2`/ooooo`07ooooo`04om7AdOlO7aooHF5Qoocl
o0?ooooo00?ofm_Kob8R8_mXJ6P01?ooool01?nCTi?o0000ol[:b_ono_h4ooooo`06om?CdolM7Ago
HV9RoooooooKfm_ol?3`K_ooool00;oooooo00?o:RXZoaHF5_ohn?P07Oooool00ooCdm?o0`<3oeiN
GP0;ooooo`07onk^k_n][JgoVIVIoiBDU?ng]kOok^k^oogmo@0Qooooo`09ooclo?ogmoOofMWIojVY
ZOnDU9CoVIVIoijNW_nj^[[ok>c/027ooooo00Cof][Joj>SXonFUYKo`l?3;oooool01ooio?golOOj
olONkOm>U/Go06J[o`1WZol6Jjh04_l7K:h2o`I[[P04o`e`/?lFMK?oGYo;om3Sl0Kooooo01kooOgm
ooWinOobl_;ojNWYomoOgooEeMGocLg=olS8b?o=[6Oo`h4Qol628?nnNQko^W<Nok=Y7on]GaooYeLN
ojAB8?nVFRko]W<SolV<8_oBV33oe9/com>K<OoBUbood94/olj;:_o<PbWoag8VolEY9ooBPRh2omF7
;@1PomjO?ooae6GonO1conoMGooXe53of[4`omFL9_oV_e;oiKEDom9n:ooDQBkoeHD^omF6;_oHRc;o
f8/aomN8;OoDORSofH`bonk:H?ofiGOofYM6olec:ooCRSOobhH]olfFAoo>LC3ocflYomAm:OndQD;o
SflbokUd?_oGNS3oeJ=3ol:YLOnl/I_oNE]3ojdm8Oo7FBOoTT8Tojf5?OnTQeKo_Wi8omG:XOnm[X;o
NTh`ogiS<Om59ROo^ZA_oo[jNOool6goimn2okf[P_nFNe[oGDTgoclW8OmO=ROoMd8^ogQ4;_mj@bco
M44YogM5;_n4CbooGD0Xoedn:OmG=BCo>2DPodTc9ooG]dooj/13onoEHOojlWooiKQ:omJ<;_oBQROo
dXTQom>;8_oESbWoei<bomZE<ooFVboof9hcombS<?oD/bWohL<eomVM;oo?N2Soc6PXolaW:Oo<IRSo
cFPXom1e;?oFRC3of9i2omNWBooJVBoofIT^0_oJVBh07_oKWC3ogJ<eolYa:oo6HbWobVh[oled;?o>
MbcodG/]om9n;OoBO2godGX]omJ7;ooKVc?og9lcolBK?olVI7go1EF8o`IFRol6F8go1UZAo`ILUOl6
Gi[o1V:No`MTX_l7IjKo1fVYo`MYZ_l7Jjco1f^]o`M/[@?o1fb^00Go0FV/o`1TZOm<U<Coc>7^ooCi
o02Iooooo`03onCTi?l61PKoQ8B400;ooooo00So_knooa`L7?nZZZ[oo_knooooool_;boo0000olS8
b0?ooooo00?oWIfMofm_Koooool00oooool02onFUYKoinOWoooooomeMGGo8B4Qoo_knooooooo_;bl
o`<30om;Bd_om?Cd00Oooooo00kom_KfoeUIFOll?3coo?cloooooon?Shoo0P82ofa/K?ogmoOooooo
ookno_oShn?o0000omcLg0;ooooo00?oalO7o`000?nKVi/00_ooool00oo4a<Co;2`/om?Cd`02oooo
o`07ok6a/Ol0003oVIVIooclo?mXJ6So410@ol;2`P03ooooo`08olk>c_l;2`_oM7Adoo[jn_omoOgo
T92@o`h>3_ogmoL4ooooo`08okJf]_lE5AGo`l?3ookno_oooooo7AdMo`<30ooGemL2ooooo`04omkN
g_l_;booDE5Aooclo0?ooooo00?ojn_[o`X:2_mKFe/00_ooool00ooNg]ko8B4QofMWI`02ooooo`0=
omSHf?lK6a_oMgMgooKfm_oooooo/;2`o`000?mFEUKoi>CToooooonl_;co30`<ojf][@03ooooo`04
ooOgmol@413o?3`looknoPgooooo00GoG5aLo`000?nJVY[ohN7Qoo;blP06ooooo`03oadM7OmYJFWo
no_k00?ooooo00Col?3`oemOGolo?cooo?cl0oooool01_nh^;So2@T9oeADE?nRXZ;oi>CTooCdm0;o
oooo00Coj^[Zodm?ColT92Cod];BL?ooool00;oooooo00?oR8R8o`000?o:b/X07Oooool01?o^k^ko
>3Phob`/;?ohn?P<ooooo`07omKFe_nTY:CoUIFEoiNGUoo>c/komOGeooknoP0Mooooo`09ooWinOoa
lO7oa/K6oj2PX?n@T93oW9bLojVYZOo<c<comoOg02Cooooo00?ooOgmom[Jf_oclo<0;Oooool01_od
nO_oi>ofohflfol/P[[o066Wo`1X[1;o1fb^00Oo1Vb^o`AZ[Ol6K:ko57BbobV0^_n2]MKoloSk00Oo
oooo01Koo_knooclo?ogmoOol?3`onKVi_oLg=cod];Bol_;boo7alOobl2Solb<;_o?Sbooc8H/olYk
:_o6KbOoaFHWolIS:?o6I2Ooa6<Vol=T9_o4O27ocI0Y0_oDVS80JOoDVc;oe9Xbom:G<?oCWBgociTS
om2J7_oFWbCoeXT]omJC=_oFYDCob94eokUh8On_IQWo_g`Zon>eC?obg73ooOb8onc8H_oBObcoe8@]
omB5;_oBPB_ogjE4on[5GOoGSCCohJ]9ooCUM?o^cFOodG4_ol=K7_o5M2Ko_W/^ok:7>onVNc3oaV<Z
olm/:OoCOR[obYI=ol9W:ooFNB_of;ASol6hYoo5aLGo`l:kodli:_n[@bGo]4HRoiIO>OnOP47oC2lS
oiAC;_ndXGOoaKbMohe]@Om=;BGoFC@/ojnMOon]Y77oNV/loeM4;om:;bKoEcDVofi5:_mkARgoJ3XW
ocXS5_l]6a?oM44Xof@l9omH<b7oBRXJod`_8?m?=bWoHChZofXm9omZ@2WobH/gomVH?OoS]5GojlMR
on36OOoKYTGofYLdomfU>ooETROodh`RomF=:?oFSS3oe8d`olB3;?o8SBooe9@]olio:?o>Jb[oc6LY
oleX:Oo<J2Sod7@[omB;<?oHVS;odiX/olZG:Oo:Y2Soej4XomZI;`02omZI;P04omVI;_oKW37ogJ<e
omF6;P;od7<[01[ocW0Zole[:Oo=K2WodW/]omZB<OoOXCGogZ8eomfP=OoLWC?o]iQ7oaYNOol5E8So
1UJ:o`IGSOl6FI3o1U^Co`INUol6HIco1VBPo`MVY?l7IjKo1fVYo`MZZol7Jjco1f^]o`M/[@?o1fb^
00Go06N[o`1SZOmFV/Sob^7^oo7gnP2Eooooo`06ooOgmooemOGol?3`odQ8B?l];BgonOWi0_ooool0
3OmFEUKoD51@onk^k_oooooo]KFeo`<30omHF5Soooooooclo?oooooodM7AohR8R?o^k^h00oooool0
2oo8b<SoUiNGooWinOo[jn_o30`<ojb/[?ooooool_;bofMWIol820So/;2`00Sooooo00gob/[:o`l?
3oo6a/KoooooonWYjOm0@43o5QHFom3@d?oooooohN7Qoo;bl_lJ6Q[oUIFE00;ooooo017of=SHoa4A
4OmUIFGoooooonk^k_oRh^;o5QHFol30`?ono_koooooonKVi_l0003oQHF5oooooonh^;So0@41ohB4
Q004ooooo`07oc4a<OlA4A7olO7aoooooooUiNGo5aLGok>c/`05ooooo`07oclo?omTI6Colo?coooo
oonUYJGo0000ofYZJP02ooooo`04ooShn?m/K6co6ATIom3@d0Cooooo00SoCTi>o`P82?odm?Cooooo
onc/k?m>CTko=CDeooShn0;ooooo00go>c/kode=COoAdM7on_[jooooool:2P[oRh^;og5aLOoooooo
iNGUocPh>?mCDe?ono_k00;ooooo00CoWinOo`820_nLW9cooOgm3Oooool01_nZZZ[o0P82okJf]_mm
OGgoE5ADomCDe0;ooooo00Kom_Kfoo_knooLg=co5ADEobTY:OoDe=@2ooooo`;ooOgm00?o/[:bobPX
:?o>c/h01?ooool02olN7QkoH61PokNg]omKFe_oJVYZomoOgoono_kooooooiJFU_l0003oXJ6Q073o
oooo002oooooo`03olo?col820SoKVi^01gooooo00Con_[johB4Q?l:2P[o/k>c3Oooool01oofm_Ko
`/;2oijNW_n<S8coZJVYomoOgooinOT06Oooool02_ono_kom?Cdon?Shonn_[koTI6AoiBDU?nQXJ7o
];BdomgMgOono_iDooooo`06oncdnOo7gngoMZgBoaIe/ol0HjWo0FR/4_l7K:h01_l5Jjgo06R/o`U]
[_lPNkKoB9;3ojS;h`[ooooo0:Coo_knoo[jn_oemOGokNg]on?ShooIfMWod=3@ol[:b_o6a/KoaLG4
olfPD_o@TC3ocY8^olV>:Oo8TR;obY`KolB;7_njIR;o_V8Uol=P9oo4LB?ob8TTom:G<?o?Tbgoc8`X
olR99?o:UAoobYdLolNQ8?o6W2oo^G8Polim;?oERBgoch0Wolel:?o9LROocH0bonBkGOokmH?onNal
onFgDoo@Q2god7dYom>0;?oDQRoodh<^omB7;OoOZ4Cokm=VooOWMooT]4ood80[oln6<ooEVc_odiLc
olbG??o<[63oaImColMS:_o?L2Wod7TXoleV:?oHRCWoc;b=olC3__o1_;;o]JF:oi5^EOm`=2GoX3dR
oi`o8?ma>R[oIc@[ofXg:omZ>RcoHcD[of0c:omY?2koJC``ofDl<?mC<RSoCB/SofU1;OnEJdCoVGUL
oh1=;?o@]EGoe;5?oga>:?l=2@Go7A<=ohQ::?m_BAkoA30QoeDd8omC=2OoGCPXof@j:?mS>2KoNdTZ
onK8F?oVbE_odjeNolZRIoo9VeoocHi3om:8<?oFSCKoehd_omB:9OoCSB;oe8dUomJ=;OoFRS7obgP/
olaY:Oo<IBWoc6PYoleZ:Oo@Lb[oe8H]omJ@;_o=URgoaI@^ol:E:oo3Ub[ocj@YomBX:OoGWC3og9l`
ombM<?oKVboofYX^omZM<?oJW3Cod7L/olaW:?o>KR[odgl^omB4;oo5P2Oo`hTVolV?:Oo?U2goeYT`
omVK<_oJW3;o/IQ<oaYNPOl1DHKo1EB9o`IFRol6FHoo1U^Bo`IMU_l6H9[o1V:No`ITXOl7IZCo1fNV
o`MYZOl7JJ[o1fZ[o`M[[@;o1fb]0_l7K:h01Ol0IJ_o06BYof>Rc?o<hNkokoKj09?ooooo00KodM7A
oibLW?ono_koTi>Co`d=3Oo2`/82ooooo`03omOGeoln?Sko`L7100;ooooo00So:2PXo`T92OoZj^[o
e=CDoo?clooooooo/k>cojBTY0Cooooo00_oKVi^oo?cloooooooXZ:Rochn?_ohn?SooooookBd]?l3
0`?oK6a/oo[jnP07ooooo`0=ooShn?n7QhOoG5aLoo_knoooooooRHV9o`000?nJVY[oo?clojNWYon;
Rh_o=3@dofe]K@02ooooo`09omWIfOl:2P[oG5aLoooooonRXZ;oW9bLoalO7omkNg_on?Sh00;ooooo
00So0000oeaLG?oooooogmoOobHV9_m4A4ComoOgooooo`;om?Cd00OoXj>So`000?nn_[koooooooSh
n?mdM7CoLG5a00;ooooo00Kono_kookno_ooooooc/k>ocHf=_o?cll2ooooo`03oadM7OlI6AWolo?c
00;ooooo00?o/[:bo`820_nYZJT00_ooool01Ookno_okno_ok:b/_l0003oT92@00;ooooo00?o[Zj^
o`@41?nXZ:P00_ooool03Om5ADGoF5QHoibLW?o2`/;oooooof1PH?m4A4CoZJVYomKFe_ooooooPh>3
oalO7ooCdm<00_ooool01Om3@d?o8R8Roo[jn_oooooomoOg00cooooo02Gon_[job0P8?n;Rh_ooooo
oi>CTolY:BWoh^;RoooooonYZJWohn?Sol;2`_l20P;oa/K6of][JooTi>CoooooomOGeonl_;coiNGU
oeQHF?nKVi_oooooookno_ojn_[ooooooi:BT_l:2P[om?CdoooooonGUiOo3Ph>om[Jf_oooooocLg=
o`h>3_mTI6ConOWi06oooooo002nooooo`04ong]kOo2`/;o10@4oaTI6Acooooo00GooOgmom_Kfomo
Ogoo0000og=cL`0?ooooo`06onGUiOng]kOoV9RHoi2@T?nn_[koi^KV5_ooool02Oolo?coj^[ZomGE
eOn^[ZkoS8b<oiJFU_n/[:coa<C4on[ZjP1Dooooo`07oocmo_oBi?3oXlWQoeNKb?l0IZ[o066Xo`9Y
[00Bo`M/[P06o`5Y[?l0Ij_o4G:aocN8_Om_Z]3oeNKa3?ooool0[oomoOgonOWioo;bl_oYjNWogmoO
omGEeOo=cLgob<S8olG5aOo4a<Coc[Akol9m8_noN27o_7DMokM]7_n`HaooZ5HOojA<8?nZDR3o]f<R
ol=f8_o6PR7ob8<RolEn8Oo1NB3o_GLNokIZ7on`Gaoo[U/RojiG9onZCb7oagDYomJ:;_oEQRcoeXX_
onBaCOofhg7olmm[on>kCooBV33obH8PomJU>_oNXd?od7PWomB5;_oCQ2cogZ10onVoE_oOZT_ocH4]
olQh8oo@TS?oilUPoo7MK_odhg?om>5aoo?NK?oW^U;oc6@YoleZ:?o;HRSo_FhZoj9k@_nRNE_oXF10
ojU@:on`B2GoVSPPok1S?OniF3;oVclQoiYF:onYQV3oZ7YLoi949OnLID?oXGYLoiAS:OmZ>ROoLc`/
ogM2;on8CS;o]hE7on>mEoo:aK;oZYb3ohUQA?o6^I7o_k5koaPB2olU5PkoOT4Wog@i7om?<bCoECXY
of@l9OmN=bCo?BTPoc0R7_mQABgoj=Mlom73U?o?_hgod;j9olnjPoo;^8Ooc:maolf@<oo9PBkobgh]
om21:ooBQRWoe8PYomF:;_oGSC3odWd]oleZ:Oo?Lb_oe8<]omF6;ooGU37obGXVolIZ9?o:MR[oaW8X
okaa8OnmK2Wo]f4Wok]Z:?o1MR[ob88/oln@;ooGV37ofY/aom^O<ooJVC?oe88^omJ7;oo>L2coaePW
olAG9_o3GBKoaF4WolMY:?o7LBSobgTYom>8;OoJVS;o`:1?od=cPol4DhKo0526o`EERol6F8go1UV@
o`IKTol6GYOo1V2Ko`IRW_l6I:7o1fJTo`MWY_l7J:So1fVZo`MZZol7Jjco1f^]o`M/[Ol7K:ko1V^^
o`1TZOl0J:coI:?<ol7KjooZl_P0T_ooool01OnRXZ;obLW9omCDe?l410CoPX:200?ooooo00goShn?
oeMGEooTi>Cooooooh>3Pol0003oRHV9ol;2`_mnOWkoinOWol;2`_nEUIGoinOW00;ooooo00?oW9bL
obLW9oo^k^h00_ooool01om?CdooSHf=oooooooTi>Co:BTYoahN7_o@d=002?ooool04Oo[jn_oAdM7
oj>SXooooooobl_;oa<C4olj>S[oi^KVoooooooOgmooG5aLob0P8?oinOWooooool_;bol30`?oKFe]
00;ooooo01?ohN7Qode=COll?3coiNGUooooooo?cloo0000ohJ6Q_oooooolo?cofe]KOlA4A7o_kno
oooooooHf=So_KfmolG5aOl820SoG5aL00;ooooo01_oinOWoda<C?oXj>Sojn_[oh^;Ronj^[[ooOgm
oooooomnOWkoG5aLono_koooooooMWIfo`000?nNWYkon_[jokFe]On7QhOo2@T9oe9BD_nZZZ[oZ:RX
on7QhOnNWYkogMgMo`h>3_m1@D400_ooool04_oYjNWo?ShnodQ8B?ogmoOoooooocPh>?mZJV[oo?cl
ogYjN_o/k>coYjNWo`000?oIfMWoMgMgon;Rh_no_koo0P82oj2PX0;ooooo00KoBTY:oi2@T?oooooo
iNGUogYjN_oOgml<ooooo`0Kojf][Ol^;RkoinOWong]kOla<C7oM7AdoooooonRXZ;o[:b/ofe]KOl1
0@7ok^k^onWYjOm/K6cobLW9ogmoOolf=SKoooooojj^[_mZJV[om_Kfolk>c_n8R8SoemOGoooooom?
CdooLG5a00;ooooo00OoADE5oeUIFOooooook^k^odU9BOlO7aoodM7A06oooooo002nooooo`04omOG
eomgMgOoD51@odI6AQcooooo00Gono_kojn_[omLG5coBd];ohR8R00Aooooo`06omCDe?n^[ZkoSHf=
oiZJV_oAdM7ol_;b4_ooool02Oofm_Koh>3PolK6a_nNWYkoRXZ:oibLW?nf][Koclo?ooCdm01Doooo
o`07oo3fn_nnf>WoQ;KGobMn^Ol0H:Oo06>Yo`E[[@0Ao`M/[P07o`I[[_l0Ij_o06FZob9l]om?UlKo
T[kLoo7gnP0=ooooo`2bookno_okno_om_Kfono_kooUiNGofm_Kom;Bd_o;bl_oalO7olG5aOo4a<Co
bk^Gol^9:oo<RRcobGlZolMc:?o4IBKoaVHWolYg9Oo@Tb7oe[0TomNg:_o6PBCobhPXolb<:Oo:PRKo
agLUolMa9Oo7JBGoaV<WolMU9oo6HbSob6XZomB6;OoER2oog9m3omRUB?o2O2oo[edMojY@5on`Dago
/eHQokUR<?o9NcOodW/Wom:0;?oDPbooc7/aokMK9?nVAA_oYdLOojaA8on^Cb?oZdPQoja<9?n]CROo
/EP^okEV>OnfFbkoc6<Yol]L:?o4GBSo]5XYokaJ;_o<NDSocWA0omEg=Oo1[8OoHDHbokjFJOo5LT3o
YDHPokeW:_o8`kCo`9ecoi]:9Oo9UUoocl24ojjN8olj8QSoMCTSoh]I=on_S63oWF`iohYA;onbSF7o
a<6jojjNQOnBJD_o`;FMob0O5olW5PkoQD@VogHi8_mV=bCoIc/Xoe4f9_mL>BKoES<Soc4S7omQ?b[o
d[f>olk5X_o@aISoeLJ8omRoKooL/DkofITkom>4;oo<LB[oaV<XolAS:Oo9Jb[ocW<[om9l;OoCPbko
eHP_omF7;ooFSC3odG`^olUV:Oo9I2WobVLZoleV;?o=IR_oc6P[ol]U:_o;I2[ocFL[olaZ:oo:K2[o
bVl[olab:oo=NBcoeH/`omVH<ooKW3CogJ0eom2B;oo:PRcocGl]om1i;?oBMBcodW8[om1`:_oALb[o
eH8^omZG<_oLX3?og9dcomNUA_miTHgo9FJAo`1AQ_l0DHOo1EN<o`IHS_l6FY7o1UbDo`INUol6H9[o
1V6Mo`ITX?l7IJ?o1fJUo`MXYol7JJWo1fZ[o`M[[?l7Jjgo1fb]o`M/[_l4JZgo06:Yo`E[[OmIWLSo
Z/gTonWbn97ooooo00GoXj>SoiVIVOl51@Go>CTiooclo003ooooo`08ofe]KOnGUiOocLg=of][JolQ
8B7o8b<Sonk^k_lS8b<2od10@007obh^;_nIVIWooooooooooolE5AGo0000onc/k002ooooo`07omgM
gOmBDU;o^KViokFe]Om1@D7o0000ohN7Q`09ooooo`07okbl_?mKFe_oalO7oj6QXOli>CWo0000okVi
^@02ooooo`07on;Rh_l0003oTY:Boj^[Zom7AdOo51@DolG5a@03ooooo`07okno_olB4Q;oSXj>oj^[
Zol^;Rko4Q8Bol?3``02ooooo`03okBd]?l0003oQhN700;ooooo00CofMWIojBTY?lB4Q;o0`<30_oo
ool01oono_kocLg=oj>SXomnOWko0000ofMWIookno/00_ooool04omUIFGoXZ:Rolg=cOmSHf?o71`L
ocLg=oobl_;oG5aLodI6A_l/;2co0000oc4a<Om0@43oi^KVol[:b_nHV9So<S8bo`000?oclo<00_oo
ool04Oo>c/koCdm?oiJFU_nj^[[o@T92ok^k^ooooooo[Jf]oi:BT_nVYZKo0000ohV9ROo:b/[oLG5a
ogEeMOl0003oU9BD00;ooooo00Ko`/;2oiNGUoo2`/;o?Shno`000?n^[Zh=ooooo`0NoiBDU?n6QXKo
^k^kob/[:omkNg_oooooom[Jf_mLG5co0000ocTi>Oo_knoooooookjn__mCDe?o9BDUocXj>_oooooo
n_[jokNg]onm_Kgo@410o`000?nKVi_oooooooclo?mSHf?oaLG5ol71`Oll?3coE5AD0_ooool00on<
S8co0000ojJVYP1_ooooo`00mOooool01ooalO7oa/K6oinOWon:RX[o/k>comcLg?omoOd03_ooool0
2Oo/k>coe=CDokRh^?nBTY;oRh^;ojFUYOo2`/;og=cLooknoP1Dooooo`06om_Zm?nVbn;oGj3;oa=c
/_l0H:Oo06N[4_l7K:h01ol3JZgo06FZo`1VZoliRKkoKZW@okOEj?ojoOh03oooool0]?omoOgonOWi
oo?cloo[jn_ohN7QomOGeoo?cloobLW9olK6a_o5aLGoa<C4olRlY?o?T33odYDaoljA;_o8S2Ooai8O
olFG7?o0Ua[o^HlKokZC>?njT5;o`G`YolnA;?oEVc?odiTbom:G;oo@TRcodIL/om6H:Oo9ObGoaFlT
olUe9_oBPRcodX0/olQd:?nmHR7o^U`OokaM9_o4MCOoaWXjol5[;onhFB7o`60Qom9i:_o?M2_ocFhZ
olMV9oo1HBOoaV@YolM[:Oo5IBKoaF8Xolad=?o3FRKo_UHTolM[<_nmFBSo`eXVol]O:?o;GBSobUhX
oi]B:onSM4coa;NQol^6DooG[6co[:F8ofi5;Oo6NSkoaWL`okIc<on`DR_ob/6^ojYgA_nBABGo/70j
omB^>_mZIB[oHcPXoij5FOnDHBCoXgU6om>_F_o>]6CoVf@eoi1G>On/SW;oTG1>ogU4:_lm91Ko91D=
oh559omi@BCo@BHKoeTf:?mW>b[oIc`Yoflo9omZ>RCoL3dTole_:?oY_eSok/iVomnMB_oDNSKoc68W
olYL9oo:FROobelWoleV:?o?K2Wocg0Zom1i;?oBObgodX0^om:0;OoDQRkoe8P^olj2;_o7R2co^hHU
okf@8_o:XBWocJL/omNX<?o?PB[ocg8Zom1d:_o@Lb[od78[oli_:_o?LB[oe84_omVF<ooKW3?ofY/`
om^K<OoDVC;oaIL^ol>G;Oo3UBgo`Hl[ol>8;Oo:Q2godi@`omZT=?oNY3GogZ8eomfQ=OoLWSCofjA0
okRdUOmPRJGo9VRCo`1?QOl0DXSo1UN<o`IISol6FY7o1U^Co`INUol6Gi[o1V6Mo`ISX?l7IJ;o1fJT
o`MXYol7JJWo1fVZo`MZZol7Jjgo1fb]o`M/[_l3JZgo066Xo`1WZomCVLKoYL[RoncdnI3ooooo00Co
[Zj^ogIfM_nATI7on_[j1?ooool01ond];Co/;2`ohf=SOnl_;coK6a/onk^k_nOWil00_mOGel01omR
HV;o]KFeooooooooooooV9RHohb<S?ohn?P00oooool01_o]kNgoXZ:Roj:RX_nUYJGoRh^;ojRXZ0[o
oooo00kogmoOojJVY_nIVIWo/[:bogIfM_o6a/Koo_knooooooono_ko0000obXZ:_mjNW[oGUiNojZZ
ZPCooooo00Kog=cLo`410Olo?cooMGEeof5QHOnSXj<3ooooo`04om_KfolP823oB4Q8oo;blP;ooooo
00?ok>c/oiZJV_m`L7001?ooool01?oDe=CoQ8B4og5aLOoAdM44ooooo`05ojf][On_[jooSXj>okJf
]_mbLW800oooool00on[Zj_o410@olo?c`03ooooo`04onk^k_nFUYKoLG5aong]k@?ooooo00Gof][J
oiFEUOnATI7o`L71ooknoP02ooooo`09ok2`/?n>SXkoKVi^ojZZZ_ooooooZ:RXoeUIFOn9RHWoj>SX
00?ooooo00Goa/K6oifMWOmPH63oXZ:Rooclo00>ooooo`04ok:b/_nKVi_oRh^;onWYj@;ooooo00Co
gMgMog9bL_o4a<Coo?cl0_ooool00oo=cLgoMGEeokJf]P03ooooo`04olO7aomeMGGoOGemonGUi@?o
oooo00Co[Zj^ojJVY_mcLg?oh^;R0_ooool01?o7alOo3Ph>ofIVI_ofm_I^ooooo`00moooool01_oQ
hN7o^k^koi6ATOnFUYKo`<30onGUi@_ooooo00SogmoOolK6a_nWYjOoRh^;oi2@T?ne]KGodM7AonWY
jCSooooo00?olOCiooGgnoooool06_ooool01_o2fn_oPKGFocf<`?l9KJoo066Xo`9Y[1;o1fb^00Ko
0FR/o`1OYol=Kk3oBiG4oiK1gOoGio8Aooooo`09ookno_okno_om_Kfono_kooVi^KogMgMom?Cdoo<
c<cob<S800?oaLG507GobL6/olR4;?o2NR?o_WLPokUd7_naIaoo[5dNojUE7onWCb3oYT`Poj]C8?o1
M2;oci0]omBJ<_oCVS?oe9/com>H<ooK/2kogKTQomNV9_oDXBOodIdWom63:ooEQRgoeHL/omB2:OoL
US[omMe^ooceO_o]eFGodYLdolj7:ooNXDOod7@Zom>1;?oDQBkoe8@^om6@;_oHWbkoeXhZomJ4<Oo_
bVCogJ1>okMN9?o<XDSoc[1^olAj=_o;HRSobf<YolaR:Oo=I2[oRU</ofm<:_n2DC3oaF8YolZbO_mg
IdcoWDhZol:>??o5Nc[oc[AeojIB:oo;V6Ko[HE@oiU88onbKB_o^XhkocX]7onTL2oo_:Qioj>4E_ni
Td;oVF@fonBjCOo^f5ko`I4moi9V??mc@2koKSLUog/n9?mM<1goLchWoePi;_mI>2koGST^of4j;OmU
>R[oLChXogDm9_n2ARGoaflUom1c:oo=JBcob5DTolUI9Oo;H2SocFLXole]9oo@LROodWP[om>3;ooB
P2godWl]om9n:_oBObSodWhXom>1:_oDRRcobi4Vokn5:_nlNBco]gLZokZ59_noQbSobW`[om1_:oo>
KBX00_o=JRT0=?o=JR[od7D[omN><OoGVc?ofYhbomZJ;_oIVBkofYT^om^J<OoOX3GofHlaola`:oo8
K2Wo`flbokUU:oniIbKo_flXolAi:oo:QRgodI4`omRG<_oJVc?ofYlhom>oS?nT/kcoJY6ZobQZUOl0
C8Go05:9o`EHS_l6FHoo1U^Bo`ILU?l6GYOo1UnJo`IQWOl6Hj3o1fFRo`MVYOl7J:Oo1fVYo`MZZol7
Jjco1f^]o`M/[Ol7K:ko1F^]o`1QZ?l6JjkoBiC4oiW3g_ocn?_2ooooo`03oiVIVOne]KGooooo00Ko
oooo00?ooOgmoiFEUOnl_;`01_ooool01?ofm_KoHf=So`h>3_o7alLIooooo`04om_Kfom=CDgoXj>S
ooclo4kooooo00ColO7aodA4A?lH61Sofm_KK_ooool00?Sooooo00Oon?ShomGEeOnZZZ[oRHV9oj>S
Xoo;bl_omoOg00Kooooo00WomOGeomSHf?nh^;SoWYjNoh^;RonLW9co`/;2omgMgOoemOD0>_ooool0
0ooNiO7o`LgTomcSl00Gooooo`07ooGio?n_cnGoHZ;<obZ1^Ol0IJ[o06F[o`AZ[@0Bo`M/[P06o`1U
Z_l0GjOo67JdofZWc_nadNKoh^ke4oooool02OomoOgonOWioo?cloo[jn_oh^;RomSHf?o@d=3ob/[:
olO7a`03olG5a@1nolVoZ_o;R2kobH4YolEc9oo5JBOoa64VolIN9oo8HROoaf8WolMQ9_o6I2Koa7DS
om2D;ooDVS;odYD`olnA:oo;SROobIDUokf99?ndNRCoZ5dQoim57_nmJROoehT]omF8;_oRZT[ok=5W
omV`DOo2PcKobHhmomj[COobfg3ol=EZolib9ooCPRgoe8H^omB5;_oCTR_ocglWomN6>oo/dF[oa8m7
ojaF8OnoRSSocZ9Aom>;=?oDNb_oeHD^omF1;_o:GRWocF8YolEl@?nFQEcoS4l_ola^:_n6H3GoOD<X
okaU;_o9VcoobG0aolbcK?nUKC_o^5X]ok^NK?nD@R3o/VhZogaM;_m;9Qood[=Yom2kI_nIOF?ob[fJ
okV>ConFFBooN5TfoeY1<OmG>RkoESH/ofHh:_n2@2OoT4DVogm19omc?BWoIcLUoeHb8?mV=b7oFC8P
ochY8?lc9B3oHchYolee=Oo?KBSocW0XoleX:?o<IRSocFdYoli^:?oAMbgoc84YolEl8OoES3?ogIlb
omfP=ooOYcooeHP]om5m9_oBOROodh8/om:C9oo?X1gocI0SolAl:onnORgo`hL^olZ5;_o<R2oochD^
om9o;Oo@NBcoe8<_omZG<ooGTS3o`WLZolj4:ooKVbkofY/_0_oJVRh0;OoJVc7ofIHcolm`;?o<IB[o
cVX[om1]:oo@KRcocg0/olac:oo>Mbcocg`]om24;_oESc3ofYLbomZI<_oI^gKoc/g7ojJf`?m]UJko
:FbHo`1?R?l0Dh_o1UV@o`IKT_l6Fi?o1UfFo`IOVOl6HIco1V:No`ITXOl7IZCo1fNVo`MYZOl7JJ[o
1f^/o`M[[Ol7K:go1fb^o`Q/[_l4JZgo06:Xo`e`/?m8TL?oU/7LoocnoP3Cooooo`03ojNWYol0003o
UIFE01Wooooo00Cono_kon3Ph?oShn?ooOgmCoooool00on:RX[o0000okFe]@1^ooooo`00n_ooool0
1_o]kNgoalO7oiBDU?nATI7o/;2`omWIf@?ooooo00WolO7aolS8b?n_[jooVYZJoh^;RonZZZ[ocLg=
onOWiookno/0??ooool01OoNiO7o[;gKojo0g?o6d^Kok_;h01?ooooo00Oojo?iohRhf?m7T/?o7GZf
o`1UZ_l0J:co1Vb^017o1fb^00Oo16Z]o`1RZ?l0GjOo>HZooi>og?o5gNcom?Sk01Cooooo00[oo_kn
oo_knoofm_Kokno_onKVi_oMgMgoe=CDolg=cOo8b<Soa/K60oo5aLD08oo9_J?od94`om>G<_oBU33o
cXlZolV>8oo6RB;o^F<SokeO9?o2GBKo`f@UolEk9?o=S2_obhLWolAm8onmO27o]WHQojaT8?nZFb3o
ZeHOojiK8?n[HbOob8DgomAn:_oAQCOoaglkok9F9?nW>QWo[d@NomZMBoogjW[ol]a/onBcC_o@Lb[o
dh8]00;oe8H^083od7DXomfFA_ojl7Go^i54oiU17onZK2co/hi:omZ[CooGQ2goe94_omVB<Oo?SS7o
aU/YolaQ:Oo?Nd;o`;6Coka_@Oo2NBWoT6DXokE>9_o<IB_o^VPZokm^:onLMB_oP4@SokQ?9onhMdGo
XU0Wok^=@Om0:1SoMS8PolnYLooNbESoSfi8olFo/onbXWGoBRHFofXe9_mX=RKoMCTTohE49_n8AR?o
Ic@Noed^6omo?B7oSTDRoi=<9omU=B?oGblQoeTb8Om=;b7o;b@Poe/h9_o;IBcoc64XolaW:Oo>KB[o
cVlZoli_:Oo@P2gojLILomG7ROo7/g?o`90bolb69ooLVSGohjm<ombM?ooAO2GodWhWom9o:?oCPbco
eIl`om>^:Oo=Va_oc8dUol9m:_oAPb_odX@[om66:ooBRBcoeX`^omVE<ooFUC;ocY8_oln4:oo=M2Wo
e80/omZI;_oIVRkofYT^omZJ;_oJVS3ofiddomNA<OoBOR_odgl/om=n;?oBOB_odW`[om9k:ooAMb[o
dGHZom=o;?oHTC7ofi`comZK<ooL/Ekoem6lomCDe?n`_lSoPZ>iobY_W?l0Ch_o05J@o`IKTol6G9Go
1UjGo`IOVOl6HIco1V:No`ITXOl7IZCo1fNVo`MYZOl7JZ_o1f^/o`M/[@Co1fb^00Go16Z]o`1SZOlB
L[7oA931oic5gP2<ooooo`03ok:b/_m4A4CoYZJV04?ooooo00CoeMGEob4Q8OmBDU;okNg]0_ooool0
0ooclo?oBDU9of9RHP0Kooooo`03oeIFE_mEEEGono_k04Sooooo00CoaLG5oa8B4_m]KFgom?CdKOoo
ool00?_ooooo00ooo?clonKVi_ng]kOoT92@oibLW?ni^KWod];BokVi^OnUYJGoU9BDohn?Sond];Co
hN7Qoo;bl_omoOd0?_ooool01ooNiO7o[l3Loj^mfonZ_=[o]lKOom7Kk?onool03oooool01_nnfN[o
GZ3:obV0^Ol>L;3o0FR/o`=Z[A;o1fb^00Oo0VV/o`1PZ?l5JjgoIJ?=okCCiooQkOGoo_oo01Gooooo
00[oo_knooclo?oinOWol_;bon[Zj_oQhN7oemOGom3@d?o:b/[oalO71?o5aLD0R?o=^8oobH4Zol>0
9oniMb7o/gHOoj]/7_nPE1koVdDNojE;8?niI2;o`g8TolAd8oo4LR?o`fhRol9[8onoHRCo`V0UolET
9_o6IBKoaV@VolAP9OnoJc7ochY6om9k:Oo?NRWoc7@Wolec9OoAORgok<QRoocgPOoW_UOodX8[omRG
?Oo@Lbcodh8/omB6;_o@MB[ohJI?onWGK?o>X3oobI0gokNE?OnOSdSoYgPmom9j;?oFY3Go]F`YomnQ
<oneS2Wo`VHXoleP:_o;Hb[o^H8SolEU9_o0QS3o]F`[okmD9_o8FROo[elWokEb9ommDAgoNSDOojA8
9Oo0E2Ko[edWoj9d>_m07Q7oVD<PojQD;_oU^DOoTG4hol:eX?nAR6oo3@@3ohDj7OnMEB[o_G`/olj/
>?nlWbGo8QX;oa`@3?n:AB;oPD0MoiQ@9?n3AbcoLc`/of`h9omY>2?oDc0QoeXj:?o9L3Woc5hWol]O
:?o=JbWocVdYolmc:Oo=SbkobjM4olbbHOoA_7SockU^olFN=_o1PaoocWXWomF1;_oCPb_odWdVom9n
9ooBObSoehTcon[<GOoPaTCod:HPoljK8?oBTB[oeHL]omF5:ooDQB_oe8H[omN=;ooCSc;o_8l/ol2B
;_o0QRkobhD_om>A<?oKW33og9/^om^K;_oJVRkofYX_omZI<_oEQRoocW0Xoli_:?o?LBT2oli_:00L
om5l;?oESS3ogIddomjP=?oMXCCogJ0dom^M<ooLYTGoglnVomgMgOoLg=co`<cCohf]`_lWL:3o056@
o`1JU_l6GYSo1UnJo`IQW?l6HYko1V>Po`MUX_l7IZGo1fRWo`MYZ_l7JZ_o1f^]o`M/[@Go1fb^00Go
1F^]o`1WZolEM;;o>XZooj77h02:ooooo`03oifMWOl0003oSXj>04Cooooo00?oIFEUo`l?3oo>c/h0
0_ooool00oojn_[o1@D5ocHf=P0Kooooo`03obDU9OlF5QKoo_kn04Wooooo00?oADE5ob8R8_oQhN40
KOooool00?gooooo00[ooOgmomOGeonRXZ;oUiNGoibLW?n@T93oV9RHolC4a?o]kNgom_Kf@Oooool0
2?oNiO7o[l3Lojbnfon/_]_oZkgKojfog?nlbn;ohnWc2oooool01ooio?goW<COocb<`?lHM[Co26f^
o`9Y[?l6Jjh04_l7K:h01_l1J:co06>Yoaei]On6]]Oofn[coo3fnQSooooo00[ooOgmoo[jn_oemOGo
k^k^onGUiOoKfm_odm?Colc<c?o8b<Soa/K61?o5aLD0Y_o<YFOo`G<TokeY8_nmH2?o^U@TokaC9Ono
EbGo`fPUolf=9OoE/33o`gXUolZ0:_o=RBgobGdYolEa9_o3IbCo`EhRol9N9?o3GRKo`edVol=N9_o3
FbGoaF0TomB5;?oERRgoe8<YombJ?_ocgFoolMY/omND??o<N2GodHP^onBgEOo@MBkodh4/om5j;OoM
WT_oejIDokUP;?o8MRgob8XjoimU<_nYG3?o`VTXomb/>_nKJ2Ooc7X/om:M<OnUO1coaf/ToleM:Oo<
I2[obW@holUa;_o9Rccob7hbom:@=?o1D2GobFLaoj9S9Omi=a_oEc4SohY?:?o4DR?o^ULTodlO4OmZ
;QOo^eXZoj5@:OnjHROoVg<ZojnGM_mGDSoo>1H=ojMI9OnZIb_o`gH/omF7:?o4SbKo:1l=oa/?3?nC
DbOoeJI5ohAA9_mS<bKoHC/aofHk;om`?B_oP40VohE9:_noKSKoc5hWol]Q:?o=K2[ocF`Yol]/9oo;
MBOoci4molZ/N_o5ZG?oak1^olR^F?o2Wboo_XlMolJ08ooEQbooeXT]om9m9_oBOROodWlXomJ<<_oJ
[4CodJPholJM8oo;XQkod9/TomB=;?oEQRgoe8D[omB7:ooITC?ocY<[ol>S9Oo<WBko_88Yokek;Oo1
O2oobHX`om>D<OoGV37ofY/`omZJ;ooJVc?oeX/_olmb:Oo>KbSodGT[omJ:<?o@PRoo_gX]ol65;oo9
TC7oeITcomRN<ooMXSGogIhdom^M<ooTaXKoj>KQonOWiooTiNGoc]SNoi>dbolTLjOo05NHo`9OWOl6
HYko1V>Po`ITXOl7IJ?o1fJUo`MXYol7JJWo1fZ[o`M[[Ol7K:d7o`M/[P06o`E[[Ol3JJgo5GBcocV:
__nPan3on?[mQoooool00oobl_;ofMWIoo7al@12ooooo`05on_[jommOGgo20P8o`000?nYZJT00ooo
ool00ooMgMgoiNGUooooo`0Jooooo`03on?ShooOgmoooooo04Oooooo00Goh^;Rog5aLOl10@7o0000
ol_;b`1]ooooo`00o?ooool02Oo_knoo_[jnoinOWonGUiOoTY:BojRXZ?oFe]Kom?Cdoo_kn`13oooo
o`03omkUlOn_`=co[;kK00Co[;kK00?o[l7MolKBioodm_X01oooool01_oYl_SoMJgBoamj]_l@LK7o
1fb^o`E[[A?o1fb^00Ko06R/o`1SZOlhRKko[LoTon_cn?ohnodIooooo`0<ookno_olo?comoOgoo7a
lOoYjNWogmoOomKFe_o?cloobLW9olK6a_o5aLGoa<C40_o5aLD0Yoo8`kKobhhjom6D<Oo?T33obh@/
olId9oo8NRKod9lVomRm<ooA_fGoaj=Rol9`9OoAU33oe9dcom>K<OoBUBooeZ8mom^`C?o9OBko`VPS
ol9R8_o1GB?o`UdUolIS9ooDQ2coe8@[omnOA?oY`EcodHLlokM@8OndBb7o]e8UokA=9?nmF2[ocg4Z
olmc:_oAMS?o`fLbojhl7on]>QooZcTPojXe7ona>b3obV<Won28<?nAEB?oMCdLonRR=?n[Oc3oYU@V
olQX9Oo8GBSoc6@ZolIJ9oo9LR[o_fL`onK:BOoGW2oo_dhUolEJ9onBB23oS3lOodhb9?nCJc[o^5HV
oje68_m37Q7oPc/NolII:?o0IS;oXeH^oj1B8omUA2So5Q0;of/_5onmNb_odIDfoiQ:7_o5IbGod7HY
ocTS4OlH40coPclRokYm?ooG]FkoU6/oog0f8_mn@BKoKc/Tof0e8omW>2;o_UXWoleP:?o;H2SocVPZ
olUX:Oo4K2Gob6`Vokij9oo:WecociiEolnCC?o9YVko_Ii=okjE:OnhTAko_h`Nom21:_oDP2[odWlX
om9n9ooCPB[obgl/ol21;oo6SCCobI4Yom2T7_o>XQoodiLXomF9;_oDQ2_oeHT^omRC<oo:PBWocWD[
oliY:_o=IB[ob6<ZolMU:oo4JRcoaW<]ol]o;_oBSS3ofI@aomZJ=?oGSS3oeHL_omN=<Oo?KB_obUXX
olMI9oo4FBOo`UdXokiT:Oo3Kb_oaWd]oljA<?oHUc;ofYPbon:gI?o^im;ol?3`ono_koo[kNkogNGY
oiFjdOlPLjco05nOo`EUXol7IZCo1fNVo`MXYol7JJWo1fZ[o`M[[?l7Jjgo1fb]00Wo1fb^0_l6Jjh0
1?l@L[7o:X2iohjkf_omoOo:ooooo`05oogmoOo_knooe=CDokjn__o[jn/0J_ooool01Ookno_okNg]
om3@d?nn_[kolo?c06gooooo003jooooo`09om[Jf_n[Zj_oV9RHoiRHV?nIVIWo]kNgonWYjOomoOgo
o_kn04Gooooo00?og^Gaojo0g?n/_]/01On/_]/01?n[_M_o[[oLomKPk_omoOh3ooooo`04ok3@i_m6
TL?o26f_o`U][aGo1fb^00Ko0VV/o`M/[_mTY<cof^Wcoo_lo_ono_lJooooo`0;ookno_olo?conOWi
oo?cloo/k>cohn?Som[Jf_oAdM7obl_;olO7aoo5aLD01?o4a<@0POo=^8gocHX^om:F<Oo;RbgoaX/Y
ok^49?n`OB7oXFLOoiA<8_nAAbkoZeLSolYm:?oDVC;odiTaomBJ<_oDVc;ohL5:omffBoo>TBoob8hX
om:H>ooDTCWoaVlZolIW9OoBOB[odW/]olil=oniCb?o[CXMoj`f7?n^>Aco/T0QokA48_njD2?ocVdZ
olaV:_o6GBSo_E4TokiC9_nnCb?o`5<Sol5G9oo5FbSocfl/om1X:onaEBKo^VXXomfX=OnTJ2ko_6LY
oh]H9_nnFBKocV<ZolEL9oo6IbSoaX8aom>J:ooHUSkoaFLcokYB9?nUABGoVTXToel/7On<ESGoW4XW
ojY48Ome=1_oPd@Poj1:9Oo6Fb[o]fXioie69?mF9QKo914:ohPn7_o=XS?oh;M8om6YD_nMBb3ocWPY
odDZ4OlE3@WoQClOohLa7OnOCc7o_8]KoheU?om]>27o@2XRoblT8Om0:R7o[5LToliQ:?o;GbSocFHY
olIW:_naFbOob6dVolM]9OnbLako^7dSom64;OoAM2Ooc7TWolUm:onlLBSo]7dMokb@7?o9PbGoe7lZ
om>0:?oBObOoe8<]okEc;OnYK2_o/fX/ol>1:oo?UBOod9lSom:L9_oDTB_oe8L/omN><?oDOS3obf8Z
olaU:oo<IB[oc6@ZolaS:@02oleT:P0FolaZ:oo>N2goeX`aomRE<ooIUS?ofYPcom>7<?o>MbcodWL[
om9e:_oALb[od7<[om5c:_o@L2[oc74Zolaf:oo>OBcoeHT^omVC<OoMYD[ol=nhooOfl`;om_Kf00Go
m?Geoo7cm?nN`MSo8GR`o`AVY`02o`MYZ@;o1fZ[00?o1f^]o`M/[Ol7K:h03Ol7K:h01?l6Jjko7gZf
oi2lfoofn_c;ooooo`03ookno_oooooooooo06cooooo00?oo_knooooooooool0K?ooool00?Kooooo
00Woo_knoo[jn_o:b/[oXJ6QoiNGUonIVIWoXJ6Qol_;boogmoL0BOooool01_oNiO7o[l3Lojbnfon/
_]_o//;Nojfog0Co[;kK00OoZ;_JokS7h?oQj??oV<3Mob^1^_l4Jjgo1V^^01Co1fb^00Go26f^o`I[
[OlSO;OoRk[IooWloP0Nooooo`0;oogmoOojn_[om_Kfono_kooVi^KogMgMomCDe?o=cLgobLW9olK6
a_o5aLD01?o4a<@0Voo;WEWoaW/Xokeb9?nfK2;o[60PojYG8OnYCb7o[e<RokQJ8onlH2?o_fTTolf;
;OoEW3?oe9Xbom6@<?o?RBcocI0[ol:69?nbK2;o]7Hgok^<?on`NSSoWUT]ojM>8?o?MB[ocW4ZolUY
9oo:JROocFh[on2SC_oV]e[od8djokYY:?o8JB[ocV`[om1f;?oAN2codgd]omJ4;OoS[4OogII6olmY
:oo=IB[oc6@Zol]U:_o=Hb[ofX``omBK=Oo0IBWoReXYoiA/;_o3KB_ocEdYolAK9_niEbOoYUlUoiQ0
8On=?bOoXD@Uoka=9?nQ?b?oOc4Roh@c8_mo;B3oR3@PojI38_nC?b3oQC@Qoh0b8_n6=2;oRcPToi<o
8Omm>1goG2/FohHk7onILRoof:hlongCJoo1R47oZUDPodha5Ol<1`KoR4<Ool9f9onVFB7oTC`NoiU=
;Omc=1koG38OocHW8?lk:27oW58Rol1Q9?o<GbSoc6<Xole[:_o;K2[obV@VolQ]9Oo8KRKo]70Nok1e
7_noIbGod7<Wom1g9oo=LbOod7l[olF49OnhRA_o`8PPolj2:?oDP2Woe84Xolao;On/GbWoZ4hUokID
9oo4JBcobWP]olj9:ooAU2[oe9@]omN?<?oGTC?ocg<]ol]R:_o=J2[ocfl/om5g;_oDPC3oeh`bomRA
<_oHTS;of94bomJ><?oFS37ofI<bomFM;?o7T2ooahL`ol^6;_o@PRcod7`Zom5h:Oo@MRSod7DXom1f
:?oBNb_oeXX`omRD<_oIUc?ofY/conBhI?obg[?on_O`00Cono_k00GoV/3Kob5i]?l:K:co1f^/o`M[
[@02o`M/[A3o1fb^00Go06J[oa]h]?nF`=golOOjoognoP3oooooojOooooo003cooooo`09ookno_oj
n_[oinOWol30`?nFUYKoV9RHoifMWOn/[:cogmoO04cooooo017og^Gaojo0g?n/_]_o[;kKokO6h?no
c>?o/l?Oojbng?n[_M_oZ[cKoifeeomhW/_oEHRnoe68_OlBL;7o2Vf_o`I/[P0@o`M/[P06o`I/[_l6
Jjko2fn_o`m`/?m2T<7o^]KX8?ooool03?ono_kono_kooOgmooalO7ojNWYon3Ph?oGemOod=3@ol[:
b_o7aLGoaL?1olC3`P?oa<C400Kob<:colN0<_o0KbGo_F@SokiJ9?o3FRD2olAL9@0Lol=L9_o3FBKo
`5lTolMm:OoEW3;odI4_olR1:OnnNbGo[WDToi]N8On;?AooQc@NoiE68_nKBQooYed[ok9Y;_noKbco
dh8[omF9;OoDQ2[oehLbonoBJOo_kGcoeKaMolF<>_oCSccoh:9=oleZ:0;oe8L^07Sodh8]on2/=OoR
[dGodgLeomJA<Oo8JR_obf8ZolaV:_o=J2_ofi`comEi;?nVIbSoZW/_okj6<?nQCROobedWokY<9?n@
>2;oOB`Qoh8`8_n8<B7oXShRokU88onP?R;oW3`Roidn8OnJ?B7oWSlRojQ48_nF?QooSCPQoh`h8On9
=R7oQC@QohPe8OnB@1ooT44Noh`i8Omo<2;oS3lUoj5S?On_KSgoUT4NofHb6?lA2`OoP40PokMm=OnU
J2_oQD`Zogdk9_n9>R3oPSLNofLe8?lj:23oVT`Wok]N9?o3H2Goc64Xol]V:_n]IbOoaFhXolmd9_o8
KbGoc6/Xoki_8onZMa[o_G<Oom1g9oo@N2OocgHWom1j:ooAPR_o`XDQokb87Oo6QB?odX4YomF3:_oE
P2gocfTZolmW:_o=IB[obf<ZolYT:_o:JB_ocgD[omB5;ooGSc7oeXXaom>0;ooDQS3oe8`aomRM;_oH
XR[oeih[omN@<?oFRS3oeXT_omJ:;ooERRooeX/`om^N;OoLZbKoeI`[om:A<?o>Rc7od8daom:;;ooC
QBgodWl/omF:;ooITc7of8X`om^H<ooMX3Gog:0dombM<ooKW3?ohZmEoo3FX_okm^T4ooknoP05oic4
gOl^Pk[o3G2_o`I/[_l6Jjh04Ol7K:h01_l6Jjko06>Yoaii]OnJ`mkokOCioo_mo_ooooooYOooool0
0?7ooooo00Wono_koo7alOoJf][o[Jf]oi6ATOnHV9SoY:BTol71`OoXj>P0C_ooool04ooNiO7o[l3L
ojbnfon/_]_o^<KPol7>i?nmbn?o/<;Noi>_e?mYULGoDXNmoe:9__mFRkooEh^oof6?`OlmQ;_o4g6a
o`I/[_l6Jjh03?l7K:h2o`AZ[@04oaEd/ol]Pk_oL:[AonC_mQoooooo013ooogjooolnOonnoSoo??Y
ooS_i_ocjN3ojmk@on;EaooJc;ood/:bolbkZ_o8/Y_oaImlolBNMoo4^[3oa<C30_o4a<@0MOo</7go
cXh_om:E<Oo?S2oob7`YolIh9OnoIRCo`EhUol=L9_o1FbGo`6TTolV2:_o4NRSo/fLRojQQ8_nOE2;o
W4PPoj=88On`DR?o`W0Vom2C:?oQ^DSohkYJolf><Oo8ObGoe8</omB4:_oITScojLeYomB[F_nfGRko
^58Lolj0=_ohjWSohjeColaZ9_oDQbkodh<]omRA<?oR]3OocflZomF>;_n/KRSoaGH`oleR:oo;Hb[o
dGX^omN2;_nlIBGoWe/Xoi=79?mm<2?oRcDRolEG9_ngBBCoXd0Tok989?njBbCo`E`[ojY<9onhBRCo
`E<VokA;9OncBbGoYDTSogle7On2=Q_o[dXQojY78OnQ@1ooTd0Pohho7onI@1ooUd0NoiQ37On;>Ako
Qc<PohDb8On1;B3oOR/Ooh<c8_n??R3oEBTDogHi7Omc?RkoI3H`ofLh<?mY>c3oKC`^ogXm:?n9@B?o
N3`QoiE79OnSE2Wo]5/VolUP9oo>I2[o^6lVoi]^9?o0K2OocFdVolM^9Oo=K2Oobgd[okFC:oneNako
cWHVom5g9ooAOBWobH/Wol^4:?o<MBWoaWdTolJ18oo?PBSoeHH/om5k;@02olaU:P0AolaT:_o<IR[o
cV/[om1d;?oCPBkoeHT^omJ;;ooGTc7oagT]ok]J9oo1Mb7od9lPomJ[8OoFY2GoeYL/omJ<<?oFRC00
0_oERRl05_oGSc7og:DYomja8ooM[BKofih[omN?<?oES3;oehlbomRA<_oIUc7obIP]olRA:OoBRR_o
fI@_omjN<ooMWSCogJ0dombN=?oKW3?ogjM8ong?Tookln04ooooo`05oj[=holfR;go4g>bo`=Z[Ol5
JZd04?l7K:h01ol8K:ko16Z]o`1PYolQNkKoWLGOon?_m_oloOh0oooooonSooooo`00koooool02Ooe
mOGoj^[ZolS8b?nKVi_oSXj>oifMWOn_[joob/[:ooKfmP1@ooooo`0;omkUlOn_`=co[[oLojnog?n`
`]go[L7MoiBbeOmbW/[oHiG4oen@`omJSL001?mGRkl01_mKS<3oGXg1oaig]?lCL;7o0fZ]o`I/[POo
1fb^00Oo1F^]o`9Y[?l3JZgo8WfgodB@`_nNa]ooo_ko01Gooooo00OoookloookmooonoOoooK]ooob
i_ool^CooncJ00;oon[E01;oonC9oooRaOooh/GoolZEook5S?olaHconJE@ooBSDOo]VTSoiH4Oomak
6?oDLQ7ocF00olUJ0?o6F@3oaEL0olB0>oo4_[P2olC4a00AolK4^oo>UD3odY@aolj=;Oo5R2Wo^H<V
ojMd8onBC1ooVDHPok9I8_noIBCo_FDSokaR9?nhG2?o^EXTokYG9?noFRD00_o4GBD0Roo3FbGo`e/V
olE^9oo:Rb_ob9@XolfN=OoBTSGodWhZomR<>_oHW4ko_V8cok4h7One>Acoeha5ooWVM?ojkWGofiY:
oli^:?oEQbkoe8@]omVH<OoEPbkofiHaojQU9_n`Jb[o`Z5QolIS;_o<HbWodW@/okAJ9_n4=R7oQ2lQ
oi@g8_nW@bCo^E4VolMG9oo7EROocF4ZolU[;?o<KBSo[Gl]og0m9?ngDbGocV0Xok]K:_nlG2_oLc/I
oa081on9=aco]T`Sol9C9On`@b?oRC/RogLb7om>91GoAb8BoiE07on]H3KoZFm1oi937OnA@1koSS`N
oh/h7_n?>R3oTT8NohY17omc?2[oK3/_oflj;?m`=RWoNChYogTn9omo?R?oQD0QoiY79?nnFbKoWePW
okMI:?o=HRWodFl]omBZC?nXPSSo]FPUolUb9?o7KBGoc70Xom2???njVBoo[WlMolUh9?oCMROobGlS
olAd9?o<IR[ocVL[ole^:_o=MRSodGdZomB5;Oo@MBcoc6P[om1d;?oDObooeHP^omJ:;ooER2koe8H/
omB5;?oDS2goc9@Yol^7;_o4LRco`FlXolf<9OoEYR;oeJTQomJQ9ooFTbooeXXaomF9;ooERRoof9<`
om>I:ooFXRSog:hUomf[9ooJWB_oehlaomN<<OoIT3;obXh_oj]m;?n]QRco]XX/ol2?;OoAW33oeiha
om^P<ooNX3<00_oLW3@01?oMXCooj/F0ooKXaOonoO/3ooooo`05oj37h?lmS<3o4g>bo`1X[?l4JZd0
4?l7K:h01ol8K:ko0FV/o`1PZ?lZPK[oX/SQomWXlooinod0oooooonQooooo`00kOooool02?o_knoo
gMgMokFe]OnBTY;oT92@ojFUYOnf][KogMgMDoooool03_oSj??o/L7MoingeonC[m?oOZC<ofVHa_mR
TlCoJ9O6ofZHaom[V/SoIiO6oej@`_mIS<3oEhZo0omGRkl01OmOS/7oDHVnoaEb/Ol9KJoo0fZ]00Co
1fb^00Ko16Z]o`1UZ_l<Kk3o;X>koejPboo3fn/=ooooo`;ooo[e00OoooG/ooo^g_ool>;oon[EoooT
b?ooi/coomfj00;oomZd01[oolR@ooo0P?oo_gkook1PoonUB_ooXTGooi8Uoon:5_ooRQCoogP0ooma
0?ooLP3ooWD0ooad0?oiLP3om7@0onia0?oVK@3ogF/0omIY0?o?I@3obVD0olMS0?o5G`3oa7/aolBl
/P?oa<C4073oc;>3ol=h:?niLBGo/6TRojIK8OnRCR7oY4DQoje;8_neG2?o_G@TokeX9?o3M2So_FHT
okaP9?nnGB?o`5/Tol9K9Oo2FRKo`ETUokmJ9OnnIR?o`gdTolB48OnnOR;of[92omn`@?o=JbWobf``
okiA9?noD2?o_e0Ron2QC_onl7Ood:51ojN0>?noKC7odWH[omB7;_oDQRkod78/omjC<Oo7S2goZehV
ok=^;?mg?BSo]U@Vom1U:_o0FROoX4DSoje;9Oo3FROocVXZom9d;?oDOBgob68Xol]Q:Oo<IR[o`fHW
okm]:Omc?akoWDlTokUQ:?o2ERSobf<Zol5O:omQ>A[o80`8oj]?9ondDRCo^U4Uok]>9OnO@R?o[d8R
oaX?2_m17a3oNc<Kok]R=oo3WVCoP60Roelb5onXKcKoTe4SogPj7on9@1koT4<NohPo8?n:=akoW4/Q
oja]:_nPH2GoW6/Wod8Z8?lh9b3oJCTSol5G9Oo4GbGo/eLYokiM:_o=IR[oeWhaoln2;_nPJ2KoZ6TV
olY^9oo9KbGobfhUol]k:onfOBKoYgHJokmi8OoBMbSod70Z0oo<IBX0<oo<IB_ocFX[om5g:ooCPbgo
e8@^om61;Oo7R2GoaIXPolZC9?oCQbcoeH@]omB5;?oDQBgodi<YolnO8?oBTb[odhP_om22;_oDSbco
eY`ZomBS9OoFZ2?oeihZomN@<?oERC3oehh`ol^4<Oo1LBcoaWd]olfA:ooFX2WofZDYomVJ;OoGT33o
fI8bomJ7<?o9JB[oaVHZolMZ:_o5KR[oa7/[olV9;?o=TRgoe9h`omRN<OoKX3?ofi`comZH<ooT]V?o
lmjaoogkm003ooooo`05oiW3g_m5TL;o4g>bo`1WZol4JZd04Ol7K:h01_l0Ij_o066WobAm^?n9^MWo
cn?`ooknooooooooWoooool00>[ooooo00Wono_konSXj?o:b/[oZJVYohf=SOnFUYKo[jn_ol[:b_o[
jn/0E?ooool01_ofn_go`M;VohRXd?mXULGoD8Jmoef@`PGoJYS700KoJiS7of^Ib?mUU<CoGHo2oeN;
_omFRkl2oeN;_`0<oeZ<_omISL3o=GnioaUc/_l1JZgo16Z]o`1WZol0HjWo4W>aodbEaOn<^m[oeNGb
1Oooool01?oomnkoonO?ooo[e_ooi<P2oooL^@04oooE[?oocI_oolfJooo1P@;ookE[00Oooj]GoonM
??ooXD?ooi@Xoon73_ooRaKoogP000;oog8000OoogD0oomf0?ooMP3oogP0oomi0?ooNP3oog`000;o
ogd0013oogl0ooio0?omO`3oo7h0ooUm0?odNP3okWL0onMd0?oOL03oef`0om1X0?o;IP3oaf@0olEO
0?o4OCCoa;be0oo4a<@0L_o7a;Wo`gliokYQ8_niFb?o^U@Tol1E9Oo3EbGo`f<Uolb<:ooF]CGoa8<W
olEi:OoEW3;od98_olZ3:oo2LR[o_6DXokaN8onoG2Go_f4Tol=e9_o:Qb[oc8</olIe:ooI[43oj]aA
omNH>Oo?M2WodGXZom=o:ooBNB[ok;YHonOMK_nQKRkoUE4OojmV;_o7HRWodg/]omB7;_o@LRcof8/`
olN3;OnC@R;oQcPSoh8`8On:=27o]U<VoliQ:?o8GBSocF<YojU>8oo3KB_ogIdeomJB<Oo9LRSobgHZ
ol]Q:Oo<I2[obF4XokIN9_n7=aooe6PZoi5?8Omn>1ood64YolIM:_mO<a[oL30GojIB:On0@b7oK34H
ol=E9_nJ@RCoJRdKoa4<2?me<a_oJBhIoiM07onSC2CoU6TVodd_4_nPKCKoK5<_ocPW8om3;2;oO3/O
oi]@9_nODbKoVSTNokAO:On[LSCoSUXZoc`Z8?l_923oFc<Sol=E9_o7F2Koc5dXol=K:Oo9HBWoaF8W
olQ`9OoAPRSoZW<Voj1V9?o8KRKobVlUolQf9?o8M2Coa6hUok=d8?nkMb7ocWXVom1c:P?oc6DZ03Co
cVl[om9m;_oCPBgoe8L]olmk:oo0IbGo^W4PoknB7Oo5V1ood8`YomF5;OoDQBcoeHH^om2H9Oo=XQgo
d9/SomF>:ooEQBooeXXaolb5<?o9Pbcod9TXomFQ:?oGVRgoehh`omVA<_oDObkobVDYolUX:oo7KRco
bgX[om2::_oETRcoeXh_omRC<_oBOBkocFHYoleX:Oo=IbWocFDYol]T:Oo:JBWob6hZolYl:oo?RR_o
dY<]omNN;_oHVboofIXaon6_Doo`ej;oo?OY0oooool01OnOa^3oDYW7o`ma/Ol0IJ[o16Z]017o1fb^
00Go06N/o`1QZ?lON[KoP[GFolKMk@3ooooooikooooo003Xooooo`09ooShn?oJf][o_knooj:RX_n8
R8SoWYjNok^k^ooGemOom?Cd03Kooooo00?om_Skoo?fn_ooool06oooool02Oo[loSoZ/gSofFUc_mS
ULGoDHRmoe>9__mGRkooHY?4of^Ia`06ofZHa`05ofbHaomYUlOoHI?4oeZ=`?mER[h00_mGRkl02OmH
RkooH8k1odn8_OlSMkCo3Vn`obb3^_mXY/koXLSPooOjo007ooooo`0:ooodj?oo^77ooiH]oon@8ooo
R13oohPAoomo0?ooM03oog<0oome00;oogL000CoogP0oomj0?ooN@3oog/00_ooO@000oooO`3ooh00
oon00009oon0000?ooio0?omO`3ongh0ooQl0?ocNP3okGL0onIc0?oOL03oef`0om5Y0?o;IP3ob6@0
olIL0?o4Mb[oa;V^00Coa<C400cocJigolf;;oo=S2oob80[ol9^9_o3K2GoaHDWolVT=oo3ZEko^X92
okmZ9OoAUC42omBJ<P1YomBL<OoG/dGoahHdokIK8?njHR?obGd[olf5;_o;ORgoag`]omjmAOo[gDoo
gKe<olYd;_oER2coeHT/omJ1;OoS]eWo`KQOoiQM:?nfHR?od80^ojE<9?o4GRSoe88^om9g;?o?O2go
XV4Xogl^8On8=2;oWChSokEA9oo2GBSoaelXolaR:?o<IR[oc6LZolEO:?oDPbooeJ<[olMb9Oo9GbWo
dhD^ol]W:Oo<H2[ocVHYoi1>8OnWB2?ofFP[oga36oma<A[ocedYol5I9_m58Q7oXT@QolaO:Om?9QKo
<QH<ol9D9on/CROo<a/Aob4C2_n]B2CoHB`KodDU6OmU;Qco/U@Woe<c5Omg?1coF3hYocPX9?mC<BCo
Cb0AohYV>OngPS;o]GLdoi8g7onN?27oSC/Roelc8_lc9AooB2dRok9A9oo5EbGoae/Wol]M:?o;H2Wo
c6HZol=O9oo0GB?od88`okR@>?nQLR_oaVlVola_9_oANRSodGHYolmY:oo6LROo`gPUolml:?o?L2[o
c6DZom1e;?oDPBooe88]00;odWlX03[oc8PXolf9:?oAN2coc7PXolFA8?o2VakobY4UomB7;?oEQ2go
eHP^olj<:oo<UBCocYlQom:G9ooDRbgoeXT`ole`;?o8J2cobWL/oln7:ooDTBkof94aomRC<oo@MRco
c6DYolaV:Oo<IbWoc6d[om1h;ooGSc[ogjIDonBgK_oS[foogIeQombJE_oITd_oeXPnomB4>?oDPCGo
dg`aom5i;OoAORgodH4/om><;?oFUbgoeYD]omJF;_oKXCSojlR4ooW^doooo_coooooooKjo?nOan3o
Ei_9o`Q/[ol0HjWo0VV/4Ol7K:h01Ol0Ij_o066XobAm^?mm/]Goamk]0?ooooooW?ooool00>Kooooo
00Woj^[Zolg=cOnf][KoU9BDohb<S?nVYZKoc/k>onCTi?ojn_X0>?ooool01?oWjoCo_/gSomOPk_ol
o?hHooooo`06om?UlOn7^=SoAi;3o`ma/Ol0HJOoAhBk0omGRkl01OmRTlCoJiW7ofZHaom[VLOoJi[7
00;oK9[70_m/VLL01Om]V/SoKI_8ofVHa_mQT/?oEh_000;oEHZn00GoD8NloeN:__m_VLSoNJG>okcE
j00;ooooo`06oooVc?ooYTgoogT0oomj0?ooOP3oogl05_ooP0003oonO`3ooGl0ooYm0?ogO03olWT0
onaf0?oUL`3ogVl0omM/0?oAJ@3oc6H0olQT0?o6G@3oaG8TolBbX004olC4a02IolW1[Oo=SSOodiLb
om:A<Oo:RR_o_H<VojMc9?nAER;oQD0TohDl9onVCb3ocHL/omBL<_oCVS;oeYdcolf<;_nmJb;o_7<N
okIW8?nnJ2OocXD^ol]n;?o6NBcoh<16on[JD?oEYCSo^VTXolY`:?oFRRgodh8`om6RD?ncRDCo[4lR
ol1=8oo2DBKo_4XUoke;9Oo=J2[od7D/ol=Y:_nMDRKoUc`Tok=A9_o9IRWofXH_om6??_n_FRKocWLX
om5f;Oo;Hb[oc6LZolaT:OoJV3CofJ8iolYR9oo=Ib[ob8@_okYO:Oo<GRWoa6<Woi5:8_naCBKocV8Y
ohA37_nF@B7o^E4VokIC9?mP:QOoX44RolYK9omG:A?oHBTGojQ89?nhDBSoB2<Dod<P4OncBbKoQCPN
ocTR6Ol^81WoZDDQog4^6?mG:AGoCS0TocLY9?m]?RKoHD@QoeA09?nbQCCoQTDWogHn;Omo?2SoTSXP
oi0j8OmX=B;o>bTPohi::_njERKo_ULVol]N:?o;GbSoc68Yol=]:Oo9P3GoaF4Zolmm?_nbOc7oVfTT
olEa9oo=LRKoc6hYolaT:oo>IR[ocF`Zolmd:Oo@NB[od7P[om=o;_noPb?o`8DQom=o:OoCObOodX0Y
ol:;8_o3SB7oe8HZomF3:oo?SBSoaiDSolNG8_o?SBWoeHH]om>2;_o<KRcobgL[olj99oo@U2SoeI4]
omJ:<?o>Jb[oc6@Yol]T:Oo;JR[odGd]omVF??oQZekoi;=hon_5T?o`eJOom>6nooS/eOolmngoo_ci
00;ooooo01?oookmookmn_ono?OooOWdoochk_ojl^?omn[GooOZcoodhL?ol]Vioo;J/Oo^cZGok<ZJ
onc:T?oV^Wkoi;Q_onO0NOoafJcoo?S]00;ooooo00OolOOkojW<homSXlco57Bbo`1PZ?l3JZgo26b^
013o1fb^00Go06N[o`1SZOlWOkWoKZW@olSNk@3ooooooi[ooooo003Tooooo`08omgMgOo0`<3oYjNW
ohn?Son=SHgo]kNgomOGeoo[jn/kooooo`05onK[m?n/_]_o[;gKol7?iOoVjoD05Oooool02?nfdnOo
IJ?<oc25_?l4JZgo06BYo`=Z[Ol0JJcoC8Nm0_mGRkl01_mHRkooI9C5offKaom]VlOoKYc8ofjLb@;o
L9c90_m`WLP2og6Mb00<og:NbOmaWLWoIiK6oeR<_omHRkooMYk9oi:_donQ]mSo]<?Nol7<hooYkOGo
ookn2_ooool01?oom>Wool64oomo0?ooO00Foon0000?ooio0?olOP3onWd0ooIk0?oaN@3ojgH0onAb
0?oMK`3oeV/0om1X0?o<IP3ob6@0olMO0?o5LAkoaK:N00CoaLG5077oaLG4oljSGOo;RBko`7/YojaX
8onLFb7oU4/QoiI58?nPBb7o[E@RokAI8_o0L2KodiTaomFL<_oBUS7ob7l[okea8Oo6Tbco[WLVojmG
8?o6MR[oc84]olIi;?oP`4Ooi<I9olR6;_ngNB[o]V8Volmi:_oCObgobh<mokUW<OnlB27o_THTokY4
9?nj@b?o^T8Sol5@9_o=JB[obF<ZokQI9oo1FRSoc6`Zom1a:ooQYc?oeZHaojQM9_o3I2CoeX`^omR?
<Oo:H2WobfDZoli]:_oLWCKoe7LeolYM:?o?LB_o^Fd/ojM:9_o:G2So^EdXoiU18OnO?Qoo_eTWoiE4
8_nD=agoXclOokA@9_n<>AkoTSLLok9;8omf=a_oRSLLoiHj7OnbCRGoJblIofd`6OnA>b3oZdHRodXW
6Om19a_oWD<Qohlj7Om9817oFc<SocLY9?mn?B3o^Xe1obPP3omfCbKoGC@Uoh0m9oma?2koM3d]oh<m
9on=?bGoK3HRogI3:_n/ERWo[5<UolYL:?o;GRSoc68Xol9P9onbIbgo`fXVol=S8oo5G2GoZ5TUoiIS
9Oo0LBOocW<Wole[:@02olaU:P0PolaT:_o>L2Wodh0[olUb:onbH1oo[X4IokZ77oo@P2Soe7lXom61
:OnnS23o^hhMolj89_oFQ2_oe80]olen:Oo;SRKochlXomF;;OoCP2gocFLZolaW:oo<KB[ocgTZomB8
;_oDPbooeh]3onBbLOo^cigom^G6oo_ej?onoO/Iooooo`03ooonoOomnO?oo_gj00Cooooo00Ool?Kj
okgHj_mYY/ko2Vj_o`1OYol4JZgo26b^013o1fb^00Go06N[o`1UZ_l[PK[oJZO>olgRk`3ooooooiSo
oooo003Qooooo`09ooShn?o@d=3o/K6aoijNW_n:RX[oW9bLol?3`ooPh>3om?Cd03gooooo00Ooi^_d
ok71gOnY_=[oZ;_Jok?3g_o<enWomoWl013ooooo00Oom_[lohNif?m7T/?o87^fo`5X[?l0Ij_o1F^]
00;o1fb^00[o06V/odb7_OmGRkooEh^ooeR;_omVU/KoLik9og:NbOmcW/[oM9o:0_meWlX2ogFPbP;o
MZ3:00coLik9og2LbOn6Z]3oWkWHojg1gOnY_M_o[;kKojjog?n/_]_oX[KGomGOkOomoOh;ooooo`04
oookmoooe:SoohD=ooml01Cooh0000oooWl0ooan0?oiO@3omG/0oo1h0?oYM@3ohg80oma^0?oEJ`3o
d6P0olaV0?o:I@3ob600olM_5oo7]:000oo8b<P2olW9b@2>oljjTOnnJbKo]f@TojeJ8_naEb?o]ULS
okaK9?o1GBGo`e`UokmJ9OniH2?oci0_omFM<oo9Pbgo_WDTokYg7Oo3QRKo_H@kok=/<_nhHBGobW`[
olQk;OoM^DCoeJHmokE`9OnLI2;oUUPYokaR:?o@M2_obfLZol9F9oo0BR?o_d`Uoki88oo1BR;obULW
olAF:?o6G2Soc6DZol]T:Oo>J2[ocVTZoleb:_oDQbkoi;Heol>0:OnmGB?ocf/YombL<ooET33obEhX
ol]S:_oDO2kob7l^okMT9?o<GRWobg4/ojY@9OnC=ago`eHVokUC9_nC>1koTSHLokM>9?nN?QooRc<K
oi@g7On^AR;oV3XNoh/c7?nI>QkoWd8Roi4g7?n>=1_oXD4Ooi8o7onA>agoTSLLoim17om^=B3oHS4L
oi@m8?nK@1ooIR/Gof4b8?ln;2CoRchQojmA9olg7@coA2@Kod`e;?m[>BGoOchXogHk:_mg?2WoP3lX
ohU29?nHB2CoYe@[oieC9_nhEbKoc5hXol]R:Oo9GbKo/EdUoj1P:onmJBCo`6TTol]Z:?niGbOoWelV
oka`9oo@M2Ooc6PZolaU:_o<IR[od7HYom5l:Oo=NbSoaW0YokmU9_n/NA_o/hLKolb29ooEObWodH0Z
ol:29_nkRQooahXTomB6:_oAMBcocVX[olih:_o@Pb_oeX`_om9m;Oo<IbWocg8/omfLFOo]c9Kon>c9
oogjlBOooooo00OolOKjokkIj_mWYLgo0fZ]o`1PYol5Jjgo26b^013o1fb^00Go06R/o`5Y[?l[PK[o
JjO?om[Yl`3ooooooiKooooo003Oooooo`09on_[joo0`<3oY:BToiRHV?n?ShooZ:RXomKFe_o`l?3o
n_[j03oooooo00Soi^_dok71gOnZ_M[o[;kKoj^mf_n/_]_o]LGOomWQk`gooooo00Koamo]of^WcolZ
P;[o3g6ao`9Y[?l3JZd5o`M/[P07o`1Y[?m<QkgoEh^ooeN;_omHRkooJIO6ogRQc002ogNQc0;oNJ;<
00coNJ?<ogZSc?miXlcoMZ7;ogBPb_n@/MCo]/WPolKBiOo=enSodMWYol[DionjbN42ojbnf`03ojFi
f?oFgngoo?gn00gooooo00?oonSAoonD:_ooO0004OooP0004_onO`3ooGl0ooan0?oiO@3om7X0onmh
0?oXM03ohW40om]^0?oEJ`3od6P0oleW0?o<IP3obf@0ol]Z2_o<[Hkoc<c<olg=c@;oc/k>00Woclo?
om7>a?o4OSgo]edQok]I8onoFBGo`EPUol1G9Oo0F2D00_noF2D07oniFR?oaG`Zom>F<_o2N2So^6dP
okMa7_n]D27o[4LTojU58_n^Cb;o^V@UolUm;OoDY3gob8lcok9R7_nOEb?oPclXoii;9?o;MB[ocVT[
olaX:_o=JR[ob6HYol][:OoTWc[ogjM>ohaF:?n?Bb?oc6DZoleU:_o=JRX00_o=JbX09oo<I2WofYPa
on6c=OoANBcocVLYoli_:ooOYSGocW`[olQO:?o<I2[oeX0^ojM<8_nG>Qkobf4Yol=R:OnE>1goRS4K
okQ99?n`AB;oTSDLoido8?niDb[o/5@[ojU@8_nYCB?o]4lTojiA8_nYDb?oY4hRok1?8?nO@b7oVD0R
oiTm7onR@AooTcPMoi8g7OnF>AgoTD4Roh0j7P02oiHj7@0hohLi7?mZ=1ooE34Roi119On@@2OoFbHC
obhH4?mF=b_oC3<Zoh<n8_nCAR;oTDLQogXk8?mg>b7oP3lTok=F:?nSEROoWE<VoleN:?o;HbWoc5lX
ol1P9?nUGBOoVel/okiV8oo1JBGodgLYolQX:?n/HROo`W4Wom1b:Oo<IB_ocFXZom9k:_oBNRWocgTW
ol5n8oo<OBOob74Yok1i7on_Q1_ob8<UomJ1:OoDO2cocG</ol>29Oo7RRGodhP[olm`:oo<IB[oc6HY
om1f:ooJUSooikejooOXbOono_/2ooooo`04ooohlOooeZgoon[CoookmbKooooo00KolOOjolWOk_mV
Y<go0FR/o`1RZ?l6Jjd@o`M/[P06o`I/[_l3JJgo26b^obQo^OmNX<[oa]g/oooooonDooooo`00gOoo
ool02OoMgMgo[Zj^oj2PX?nEUIGoU9BDokRh^?oTi>Com_Kfoogmo@11ooooo`03onK[m?na`MgoZ[gJ
00?o[;kK00CoZkgJok31gOnlbn?ol_Ci2Oooool01_ndd^KoC9G5oaah]?l<Kk3o0fZ]o`I[[POo1fb^
00Wo06V/odb7_OmGRkooEh^ooeR<_om/VLKoO:G=ogZUcOmjY<d00_mlYLd01omkYLcoMj;:ogjUc?nP
^]WoaM;UolgGjOoCf^/00_oDfn/02?oCfn_oeMcZolSBi_n^_mcoZkgKojFif?oFgngoo?gn3_ooool0
0ooolnOooj11oomk000?oon0000Cooio0?omO`3ongh0ooQl0?ocNP3okWL0onQd0?oQL@3offh0omI[
0?oBJ@3od6P0olmX0?o?IP3od6/6om6`SooCdM3oe=CDomGEe@02omKFeP2:omOGeooD[W7ocH/_ol^8
;Oo6NB[o_VDUol1Q9?o2G2Ko`5TUokmH9OnmF2Co^VDSolAk:OniJ2?o/UhOojiC8?nZA27oZTHRoj]7
8OnZAR7o[E0PokiZ9oo6PBoo^W4XojaD7_n[Bb7o[4@Qoje78OniHBGoc7H[omB2;?oDQbgoe8D]om9l
;?o/`d7obLMDogYX=onGHbKoc7d]omJ8;_o?L2_oc6LZoleZ:_o<J2[ocVh[on6`=?oITBooc6<YolaU
:_oDPRkofY@aoj]B8?njEBGod6P[ol5R9on>=1coT3DLol=D9OncBb?oWT0PojmH:_ncGB;o]E4VomNI
AOoFY3co/9QEooGUN?oX_TCobh@/olei;?oHTC7o`X@PolnE9?oMY3WogZA;onCAOoo@Z6OobjAbokUf
@?n??aooTShNoii27onJ@1koTSLMoi4g7OnC?1goQCdQog<i8OnH?1goRcHNohTi7_lg60koEC8Uodlc
:_n<@R7o[E<YolAQ9om6:A[o<R@OodH^9OnKC2So_5XVohiA9_nlFROobf8XolAP9_o9GRKo]V0QoiIL
:onIGRco`6HRolE/9Oo?J2WocFTYol9[:?o=M2SocVdYolm/:_o<N2OoagTVom=h9oo<NBOo]7`NolQm
9?oCNR[oa7XWokIm8?o0PR;odH8Xom5f:oo>JB_oc7@Zolj1:_oBObcocVhZombKE_o`eZ[oo?OW1Ooo
ool02_oonoOool:5oomm3oooSQgooi8UoonSAooo_WcoolRBoooUb_ool>8Rooooo`06oo;gnoo?h^oo
H:7;o`9Y[Ol0IJ[o1Vb^4?l7K:h01_l6K:ko1F^]o`Y^[olKN;CoDIO6olkRk_ooooooT_ooool00=[o
oooo00[on_[jolg=cOnXZ:SoW9bLoiFEUOnNWYkob/[:ooCdm?okno_oo_kn@oooool00ooVjoCo/L7M
ojZmfP06ojbnf`03ok;3g_o@f^_ooooo00Cooooo00Kom?SlohZjfOlWO[So476`o`U][ol6Jjh:o`M/
[P0?o`1Y[?m<QkgoEh^ooeN;_omHS;ooKI_8oh2Wc_mnY/goOZO>ogjWcOmlYLgoS:oBok?7h?o>f>Wo
e=c[00Koemk/00OofMo]olcEj?n^_mcoZkgKojFif?oFgngoo?gn00oooooo00?oookmoonfKOooOP00
3OooP000W_onO`3ooGl0oo]n0?ohO03olgX0onig0?oYM@3ohg80ome_0?oHK03oeF/0omAZ0?oCJP3o
e6X0omI_2?oH]I?of]SGomcLg?oMgMgogmoOon3Ph?oQhN7og/VOolf9;_oBUc;odY4aolj=;?o2R2Co
ZFhUoii?9_n`ER;o_5/TokQM8oneGB;o/ELPoje?8?n[B27oZdLRoj]78On[B2;oZdLRoj]98OnbEb7o
]E`SojiE8OnZBB3oZTDRoj]68_nZAb7o/54Rok=K9?o7L2Woeh/^omB5;?oIPbkof[Dkohn4=?m`?27o
^68Ton2A<OoITC7ogjXcomB1;_o<I2WocF/Zol]S:OoFRBoogjLcomJ2<?o=JBcoc6LZomZ><?nhH2Go
S3<Loja88_o<GRSoWc`Noie07oncF2?o_FD/ol1a:ooMXdcol=1Pol1a8Oo8RD;okLM;olbM<OnSMbco
gj<momnZ=_oDRRgof9<eombP?_nlPb;ociPRomfT=OoLYDood<g0omK2SooF`i;o`i1=oiEB8_n3Cb;o
WE0Moi];7OnIAagoUd4Moi@l7_nG@1goUT4Moi8h7?nC=agoUc`NogDb6_m?;1ooH3LWoi558_nGCRWo
/E0Yoflj7OlZ8Ago>BPRogQ0:oo4ERKo[eXXoj1E9_o9HBSo/EdSolUN9oo1H2Co/V4SoheK;onMGb[o
`6LSolQY:?o=IR[ocVP[ole/:Oo?LRWodGDYolAe9?nMM1So`WPTomAh:?o7NRGoZG/Jol1l8OoFOB[o
d7@]olEd9oo4ObKodH@Zom1c;?o<IB[ocFPZom^JD?ocg[?oo_cg2?ooool04?oolnOoojQAoomf0?oo
P03ooh42oon31_ooQ0SoohH=oon73oooRA?ooiPboonZEOoo`XCooljNooo/f?oonO4Mooooo`05ooKi
o?oDiO7oF9c9o`=Z[Ol1J:`04_l7K:h01Ol6Jjko26f_oa9c/OmCVLOoeNGa0?ooooooT?ooool00=So
oooo00Soj^[Zokfm_OnMWIgoVIVIoiRHV?n/[:cog]kNooclo4Oooooo00Koi^_dok71gOnZ_M[oZkgK
ok;2gOn^_md4ojbnf`08oj^nfonda=ooiN[dooooooo<hNkoDiW7o`]^[ol5Jjd>o`M/[P0<o`1Y[?m<
QkgoEh^ooeN;_omHS;ooL9c9oh>[con2ZLooQ:_@oifif?o7dnKofN3]0_oJh>d00ooJhNgof^3]om[P
k@04om[Pk@07omcQk_o>enSo[/3Loj^mfonU^MSoe]o]oocmoP0>ooooo`03oooP`_ooZeOooh0000go
oh0000_ooWl0ooeo0?okOP3on7`0ooAj0?o_N03ojWD0onEc0?oPL03og6h0omY]0002omU]001lom]^
0?oML@?oh:AYon;Rh_oUiNGoinOWonWYjOoZj^[ojn_[on[Qboo?Sc[odY8aol^7:oniNRCoWVHPohQ:
8?n0>B3oS3lQoii;8OncGB;o^60SokMQ8onfGR?o]elSok9I8OncG2;o/e`Sok9K8on]Db7o[U<QojiC
8?nYC1ooZDTPojU78?nYAb7oZdLRoja:8_n[DR7oY4hPom1m;?oFQbgof8@^olBP=On0H2GoVCdOol=8
9?o>Jb_of90`omF;;ooS^SOof94aolYQ:Oo=JR[oc6LZomjN<_o@OR[o_GXbolMR:ooAKb_oa6`Yoi4f
7?nA=Ago[ddRolEO9Oo7M2Wof90]ol5i;onnOcOoc7@Xono@J?oKXTCo^64[onBoEOoJVS;of9<bomfE
<_oGTC7ogZLcomN<;_oIUC?oeI4aomJR=oo:XSKo_8DKom>BAoo;bl_oe<BKoljQE_nMFR_oYePOohiD
9?nJEQkoVeHMoiUD7_nKDAcoUU0OoieD9on@BRGoTSlOoi4j7OnD=acoTCXNogHh8Omd?2CoR3/OohPi
9OnF?bSoOSTSoc4R7?le9b3oFcHYok1B:?nnF2Oo[UPWol1O:On/G27o]5dSoleP:?ndH27o^68UohUI
;onPHB[o`fTSolaZ:@;oc6DZ01;ocFTZom5f:Oo9J2OoZeTNoiY`5onoN2?oe7XXolAc9_n[LQgo^WXP
om9l:OoAKbcocF/[olih:ooAO2cocgD]on[3R_oln>l;ooooo`03oooXd?ooU2Soog/000_ooh0000So
ogl0oon52oooURgoojiMoonjMOooeZgoonC9ooomnQWooooo00?of^WcoeVLbOl:KZl05?l7K:h01?l6
Jjko16Z]oe6Ga_oCiO7oooooohkooooo003Dooooo`05oogmoOoinOWofMWIojNWYonFUYH00_nIVIT0
0onm_Kgoi^KVooooo`19ooooo`08onK[m?na`MgoZ[gJojZmf_nfaMoo`<cSokK5gon]_m/2ojbnf`06
ojZmf_nV^MWoSJ_Aof6Ca?lOM[?o06R]4?l7K:h03?l0JJcoC8NmoeN;_omGRkooF8boog>Nb_n?/M;o
[lKNomCLjOoPiNoog>;]om_RkP?ogN;^0_oMhnh3omgSk`08omgSk_oOi>ood=WYojnog?n[_M_oYKWH
omKOkOoloOh9ooooo`07ooooo_ooo?[oooWdooo<V_ooTbOoogd0oomn000>oon00009ooio0?olOP3o
nGd0ooIk0?oaN@3ok7H0onQd0?oTLP3ohG4000;ogg00093oh700on9a0?oTL`CoijU/on[Zj_o/k>co
kno_oo3`l?obl_;olo?coo;`jOoEWUGoaX0[okA_9?nNFb3oU4`PoiY78_n[CRCo]eLTokYS8OnoN2?o
`7HXolAa:?o;Ob_oc7l[olEd:?o1NBWogK`jon;4>ongO2coWdlPokAP8onnK2So_6XWok9L8_n/FbKo
ZE<SojM=8OnWC23oWdPOokMH9?oGQRgodh8]okN8<?nIEbGo^DLSolE99Oo:HBWoeHP^olaZ:_oMY3?o
hK0eom=l:oo<IRWobfHZom=j;OoFR2goYD/OohP^6_njDBCocf@XojY98_n[DR7o^fDSolQo:OoJY3go
gJ0lokAX:_nlMCKocVhYomnNB?oei7;o^f@WomV/EooR[D;oeXh_omNA<_oHTS;ofIHcomjT<ooGSS3o
f9@comJA<OoGWCKoa9hgoj=j5_o>ObWof;aiom36Z_nbL2GoU4XKojIH7_naI2CoWedPoimN7onDG2?o
T5PUoi=B8OnGEB;oT5T]ohY@;On0BBcoQT8SoiXn7OnB@23oRT0Qoi0j7?n@=agoUSXOoiHk9?mZ<R?o
<RDOodL^9OnHBb[o^eDWokME:?o3H2[o]5hSoiYG7Oo4H2OobF4WokQP8_nmI2OoQ5T_ojER:?o7JbGo
cFXZolaU:_o<IR[ocg4Yolef:?o5IBOo/5XOoiMZ5onhN27oe7/Yom1e:_nmL2Go_GTSolem:Oo>K2[o
c6@Yom9n>?oei;`>ooooo`03oooM^_ooQ@_oogh000cooh0000?oogl0oomn0?ooOP000_ooO0003Ooo
NP3oohTAoonJ=_oo/fSookimoooM_?oojM?oooWcooojmOoonoOooochooomnoooo_d03oooool01Ooa
mo[oKj[@o`e`/?l:KZoo1V^^01;o1fb^00Go0VV/o`1VZomDVLKoeNOaooOko@3ooooooh_ooooo003B
ooooo`09oo[jn_o^k^kob<S8oinOWonATI7oW9bLojJVY_o<c<con_[j04cooooo01?oi^_dok71gOnZ
_M[oZ[gJokK5gonnc>?o`<gSokc:h_n/_]coX[SHogbQbomIS<3oDHNmoeJ:__mPS/7o@8Bkoa=b/_l9
K:oo1Vb^00go1fb^00_o06V/od^6_?mHS;ooG8k1ofjHaon/`=coh>?^on;Ul?oNi>oog^?_on3Tk`02
omoTk`03on3UkooPiO3ohNG`00GohNG`00OohnOaom?Jjon__mcoZkgKojFif?oFgngoo?gn00Oooooo
00Ooookmooohl?ooiloookYfoon42OooN03oogh000oooh0000SooWl0ooeo0?okOP3on7`0ooAj0?o`
N03ok7H0onUe00?oiW<0057oig@0onUe0?o/MP?okZaYoo7alOoclo?omOGeooKfm_ohn?SonOWiooWh
m_oM/7So^fDTok5M8_n]EB;o]EDTokiG9Oo0EbGo_EhSokmd8Oo4QB?oejhcolEl:_o8N2[ocH0[olMf
:OnoMRWogl0konK@?ooAXc?o]6TRolF<<?o2Mb_ochD^olYm:_o4QCOoj=MXomRdDon[Eb7oY54Ooia7
7_o0IbOodgh]okec;_nbDBKo`TLTol589Oo6FbSodW//ol]W:?oERBkohkLfomV:;OoBPBSobfDYoleV
:_oCN2coZDlQohhb7?nM@1ko]UTUokYV9onbJbKo/g4VolF=<OoHZT;ohJY:olAm=?njMSKodWH_on2S
AooWeV[og[9GolJ2@OoZ`USoeH`^omRB<_oNY3Goh:dfon>f=_oMY3800_oHUC<0?OoHTc?ofYHdolNC
:onQO1Koag`WolbA8_oAZ5SoVeHToi]@7?njJ2?o`FXRojeS7_n^IB7oXF8RohYK9?n7FB_oQU<XohiF
9_moE2goP4h`og9;<On6BR_oWDdVoj5;8onB>QgoScHLoi8h7?nC>1coSc/Toe`_8olf9b7oMd0/okID
9onZDROoaedYol=R9onGEQcoYETOoleS:?o9H2Soa68UokE@9on2D2goZVDXola^9oo=Ib[oc6HZom1a
:Oo;LbKo_W<VolQa9onoI2?oXF@Kok=d8?oANbSodW0[olY]:_o8MbWod7T/om1b;OoeiK`04?ooool0
0ooocYcoogl9oomo000Aoon0000Boomo0?ooOP3oog`0oomk0?ooN@3oogL0oomk0?ooS1Wooj55oon_
GooobI?oomR`ooo^gOoolnOoooG[ooohlOoonOCooogk2oooool01Oo/m?WoHj?=oaAb/Ol;KZoo16Z]
01;o1fb^00Go06N[o`1UZ_mPWl[oe>KaooCin`3oooooohWooooo003?ooooo`09ookno_oclo?ohN7Q
okRh^?nATI7oTi>Coj6QXOnh^;SogMgM04oooooo00_oi^_dok71gOnZ_M[oZkgJokW7h?nmbn;o]LKO
ojNmfon3Z<ooGI32oeJ;_`03oeN;_`05oeJ;_omJS<3oIY72ocEo^?lAL;000_l6K:h9o`M/[P0?o`=Z
[Ol1JJco2Vn_of2Da?mhW/[oUk7DokK4g_o?enSohnOaon7UkooQi_3oh^K`on?WlOoRio3ohnO`00;o
hnSa1_oTj?401ooVj_;oeMg/ojo0gOn[_M[oYKWHomKOkOoloOh01Oooool01ooonoOoongKoooF[Ooo
XD?oogH0oomh0?ooO`004OooP0004_onO`3ooGl0oo]n0?ohO03omG/0oo5i0?o_N03okGL0onaf0?o]
M`3okWL0oo1h0?obM`3om:=AooKfm_ohn?SonOWioo[jnP;oo?cl08KonoWaomf_N?nhGb;o^E`RokeK
9?o0FRGo_UHUokYG9?nnJb?oaGdTolN2:?oM]SSofkDgol5^9oo<P2_oagLYokmd:?oO`3_oh<<lolZ?
;_noKbGoe:<jom:T?Oo5MR[oc7l[okmi<?oVeFOoj=IWolJ?>oneL2cob80]ol1d:oo9IbWobVHYol=D
9oo9E2KoaULWolQO:_o=K2[ocF`Yole[:_oP[3GofY4_olAc8onPBb3o_UPWom1U:_ndDBCoW3lOoj]J
8onQHbOoYg<UoieT8onWKb_oai@holJA?_o?Sd7ogZ<jomBM?ooAN3?oiZi<olFS?_oE`fCodYM<onG1
G_oHU3;og9lconO1??o[cSkoj<@ionBj=_oOZcKog9hdom^M=?oIUC?of98bomRN@oo0ZFCoaghZok5n
7?nYKQcoUD/LojeO8?o4K2?oa7D[olN5=OnfJ2?obg4Woh9@9?nCGRWoVf4ZohAG;OmkDRcoNE0^ogM<
<OmaBc;oND`_oiUA:onbDbKoWd4Oohdf7?nB=acoTSPMohXj9Om@:b;oESDYojQA:_n`EBSo`ePWoliS
:OnbGbCoUUDLokUP9?o?I2Wobf4YoleU:?niDBKoSdl[ok1U:?o?KBSoc6D[olma:Oo=LRKoaFhUoja_
9_o8M2OocW4WokAX8?neLB3ocgTYolm/:oo=J2[ocW0Zonc;S1;ooooo00?ool1ooon01_ooO`005ooo
P0004OooOP3oog`0oomj0?ooM`3oogH0oomc0?ooO`3oohhNoonVC?oo/67ooljLoooL^_ooj=3ooncI
ooo`h_oom>Sooo_h00Oooooo00Koi_3gofRVc_lQN[Ko2Ff_o`5X[?l6K:hAo`M/[P;o06FZ00?oIjG=
ol[Qk_oYl_P0oooooon7ooooo`00c_ooool02?ojn_[oe]KFoj^[Zon=SHgoVYZJojb/[?o1`L7ojn_[
DOooool03_oVjoCo/l;NojfofonV^]WoZ;gJoiZeeomgWl_oHiC4ofJFa_m[VLOoJYW7of2A`omHS<3o
EX^o0_mGRkl01_mFRkooH8k1odV8_OlSMkCo2fj_o`A[[@Go1fb^00go1V^^o`1X[?l2JJco77Reocj=
`On2]MKodMk]okO5gon``=co[KoKolcFiooVj_;ohnO`00;oi>Sa0_oUjO400ooVjO7oi^[aonKZlP06
onKZlP07onS/looGg^co[l3Moj^mf_nU^MSoe]o]oocmoP03ooooo`06oooejoooh/Cool22oon=7?oo
M03oogX05?ooP0001_onO`3ooGl0oo]n0?oiO@3omg`0ooEk00?olgX000Som7X0ooEj0?ogN@3on:19
oo[hm_okno_oo?cloogmo@;oo_kn08Oon_;QomVRG_o=RRkocX/_ol^3;?ngHBCoZEHSokQP9Oo5MbKo
bGdWolQn:_oM]cSog[XiolB2:_o6LbSobGXZokmc:OoN_3_oeJXeol9h:Oo4LbOodITgonG@COo4ORko
bgd[okme;OoQbV7oh<EMol1k;_o7TSooa8<eolj7;_o7LR_ocVPZoleZ:_oBMBgo_VP^ol1[<ooFPcWo
c6DXol]W:OoFRBoog9@`okmZ8on@>AcoRBdKokAA9?o2GbKo[U`Pol>48oncObGo/WlUokIk9On_O3?o
_X/coja]<?o=SD3oikQ4onS1CooEPSSohje<onNo?_oB/4;oj=9_on:kG_oQ[DOoj;]8oo7HA?o]d3ko
jLDjom:?;_oKXCCogjPfombP<ooKW3?ofYPcomRB<_oHU3Goe;A`omJF>onaNQkoUELJoi]A7Oo0KB?o
c7<Wonc@I_oQ^f7o]FdSol9^9Oo0K2[oQ5@/okEX9?o5N2[o[84dog]G;omdCc3oLddaog5<<_m`BS7o
QU0^ok9K:_nUC2CoQSPOoi0f6onA>AkoPCPVoe/b9on2ARgo/ULXolEJ9_o9GbSo_ElZok5M9OnQFAko
b6@XolaQ:Oo>KB[odG8YolEQ9onRE2Wo^fLWoliY:_o>KRWoaW<Xol]_9OnnKRGoWf`UolEd9_oDMBWo
aF/Vol5c9?o@NB_oc6PYomV@BOomno004_ooool01?oon?3ooj]Eoomn0_ooO`0Loon0000;oomo0?oo
O@3oogX0oomi0?ooM@3oog<0oomh0?ooQa3ooiLaoonoOooolN@02Oooool01_oMjoCoIjK>obMn^?l5
Jjgo06R[o`I/[Q3o1fb^00Ko1V^^o`1SZOl0HJSoDIW6okgHjOoZl_SoooooohGooooo003>ooooo`06
oo7alOn>SXkoTi>CoibLW?o2`/;ooOgmDoooool01oo]koKoYkcJoi>_domiWl_oIIG4of>CaOmWU/H0
1?mZV<L01Om[VLSoIYG5oeb>`OmGS;ooEX^o00;oEh^o00goFXboofB@`_leP;Wo8WJdo`9Z[Ol5Jjko
1fb^o`AZ[Ol0IJ[o16Z]ob^2^_mLWl[o[/oU00;ooooo00Woh^Obojo0g?n/_]_o[KoKolgGj?oXjo;o
i^WaonKZl_oWj_800ooXjo83onS/lPGojNcb00koj^kcomSOk?n_`=goZkgJojFif?oGh>ooo?oooooo
ooookMcoomVcoon^GOooO`3oog@0ooml013ooh0000Coogl0oomk0?ooN`3oogl00_ooP002ooio0003
ooan0?okOP3onGd000Con7`000KonGd0ooYg0?olXTKooOWfoogmoOono_h3ooooo`1=ooGUbOo@Rd?o
chd_omBG<_oDUS;o^7TZoimW9On^KBKo`VdVol]l:?o9PR_ofk<gom6R<?nkNb7o^FDRolUh:_o1M2Wo
ejhgolVF;OnaGb7oaW@Yom2E=OoO`dKo_G`]ol=`:?o2MRcofKYIomJ`D_o1LbOodIU2olnWDOo8OB[o
_gD[olUf:?oFQbgoehX]ol=a9_n[GC7ohKQ7omN5;oo;HRWocFlZomR;;_nfH2?oTCLLoi/n7ongHbKo
`G`TokN37onnS1ooai0PolnQ8ooJZ2[odj<dolV@;OnOFR_ofZU:onJoCOoQ_5OofH`oon>^C?oV`Coo
hK0_ooCNI?ofjW_okM1Roo;HHOoXg5OoeKDkom2K<Oo>Tc7o_ELSom6L=OoKX3Gofj@bomZM<ooJUC<0
0_oHTc80>?oIUS?ogj0kokYi:?nECacoZUhPolad8ooIUCkog]NCol_0Y?o<QBgo]G4VolUa9_o2KBSo
[VTRolA`9OoNZC[oXG@Zog5=:?n1F2koQ58^ogM@<?m/C3;oLDh`oiAE;On>Cb[oRT4Soi0g7?n>=ako
PSXXogQ0;_nACbco]UTXolQM:?nkFbOo`U/XokEN9?ndH2?ocVDYol][:OnoJBGocFlYole[:OniI2So
b6dYom=`:OnWJR_o[F`Zom1a9OnfJBGoW6<Uol=d9ooBLR[ocF/Yolme:Oo@MB[ol]b[5?ooool00ooo
jmOooi/eoomm000Roon00004oomk0?ooO03ooj52oooN_Pcooooo00Koe^Obof^Wcol[PKWo06R/o`1W
Zol6Jjh@o`M/[P06o`I[[_l0HjWo06FZoeRLb?nednKok?Cioooooon3ooooo`00coooool01_o5aLGo
XZ:RoiBDU?ng]kOog]kNooShn33ooooo00?oloKjooSjo?ooool07_ooool01oo9h>koTKOHog6Jb?mD
R[koCXJloenA`_mYV<L01_mZV<L04Om[V<OoJYS7of:Ca?mKS/7oEXZooeJ;_omGRkooEX^ooef=`?mQ
Sl7o9gVeo`m`/?l0IJ[o3g2aodbEa?n5]mSod>?`00Cooooo00oog^Gaojo0g?n/_]_o[KoLoloHjOoZ
k??oj>_conS/l_oYk?;oj^ccon[/m?oZkOCojngdon[]m?oZkO<01Oo[kO<02Oo/koCof^3]ok30g?n[
_]coY[gPolkLiOojh<3oolF;oonM>P02oomh0003oomn0?ooP03ooh0000kooh0000Googd0oomh0?oo
P@?ooj=7oonO?P02oomn00;ooh0000CooWl0ooeo0?olOP3oo7h00_okOP02ooan0003ooee0?onVSKo
o_CZ00Gooooo08Sok]F/olYm<OoATC3odiHbol68;_naP2Wo]Xh/olbY>Oo1LB[oaW<Vol^6;?oDY3?o
`XDWojiP7On[DQoo`6/Vol5e:Oo;U2oo^gLVojI@7OnhI2Coci0dom6W?OnbJbCo]F0QolEg:oo@Y4co
a9A0okES8Oo@TC[oh<YWol>2=?o4OBgoaG/`omF5:ooER2godh<Zokmb<ooR^4Soj;lfom>4;_o:GbWo
cVdZokML9?nRAQko]60UolAm:Oo=QbWoaWhXol9l:_o>P2[of9Laomnf=?oZcSWodiHXokMm>?oVaU_o
dZI:ol25@_oDR3koiKE>onK0?_oQ/S3oi;TiooOZMoojlh3on>mkooOSHOnUV5?o[WLWolZ9>OnhI2oo
aG`[ok6=<_oOX3Coh[@fon>h=ooDUC;of9<bomRB<_oHU3?ofiDdokea:OnFCA_oa7HUom9j9ooFT3Co
bl>XolC4a?oATd;oaX0`okQ_9Oo=LROobW<VojiW8Oo=Pbgo_H4XogY@9?n>H2SoY5dXojmG:?nNEBWo
O5<_og1?<?mbCRkoLe0_oh19:_n9?1ooRSLNoh@m:_mlARooWe@/okYK:Oo2G2Oo[eHVolUO:?nfHRGo
afLWola[:On`H27oaFLWolmX:oo>KRWocG8Xom9e:?nmIRSoQed]ok9^:Oo@L2Go_V@VojQT9_o3LbOo
d6hZolaU:OoFR3kooO[_5Oooool00oooh<3oohlOoomo000Ooon00005oomo0?ooN`3oohdOooo1Pooo
n_D03oooool01_oAi?3oN[3Cobj4^ol0J:co06J[o`I[[Q3o1fb^00Ko1F^]o`1QZ?l0J:coEY[7ojK;
h_o^mO[ooooooh7ooooo003@ooooo`06on3Ph?nf][KoUIFEoi>CTonk^k_oh^;R;oooool00ooJh_3o
a];VonGZm00Kooooo`0;oocmo_nYcN?oLZ_AobZ1^_lKLK7oFHZooeJ:_omER[koHI;3ofVHaomZV<L0
0om[VLL3ofbIa`06offIb?m^V/SoJIS6of:C`omHRl3oEHZn0_mGRkl01_mDRKkoF8Znodj<_omNVlSo
Z/gTonofnPKooooo00_og^Gaojo0g?n/_]_o[KoLom7IjOo]k_?oj^gcon_^m?oZk_Cok>kconc^m003
onc_m0GokNoe00_okNodoo3am_oMi??o/<?Roj^ie?nW[lOo`Z^2ooN?8OooM`3oogX0oomo000?oon0
000;oomo0?ooNP3oogH0oon84?oo[UcoolfKooodj_ookmoookI^oomo0OooOP000_ooP006ooio0003
oomg0?ooV3Soon[D00Cooooo08Woo_gionBkROo9MRWodY<aolF=<?nbORWo[gDQokIe9OndJ2[o[50R
okiV8oo6ORWoa8HZok=V8OnWC1koXd8Qok5D8_niI2Co^FlUojiL8OnTAAooYdXPol5h:_o1Q2ooZUHP
ojI77onlJROo`XPkokYi<_nUCQ_ob8<comRiF_ngNSCo_g<XolJ:?OoDPRgoe8L/om>3:_oFSCWojL==
omj^<onbK2KoZD/RoliR:_o6HRKo_FLSokYc:?nlN2[obWhXolAj:OnjLb[odX/^om:G<Oo>Qc3og9Tl
ooGVIooN_e[oi/YRok9a=On/HC3ofIM6on[3DOoU_S_oh;0^on6b<_o/cU?on_>0oo;[PooRa6goe;Y_
ojNIGoo7NR[o`FHYolQW9onQNb_o^8lcon6S=?oS/cKoh;Pgoi]_;OoCSc;oehhbomNB<_oKUC?o_W<X
oj=H7_oDPBWoa7LQolZ0:?oJ[E;oa/>mol^SM?o:R3Co_g//ojmX9OoBM2Soa70WokAY9?noJbCoUElT
ohIJ:?ncKRSoYedYokMI9_nbERKoYeXZojEL;?n<ERgoKe0`og5=<Oml@ROoQcTQoh50:onGERkoWeD/
olAN:?n^EbKo_ETWolEQ:_o7JBWoc6dYojiO8?nbHR;oc6PZolaU:oo=JB[ocg4YoliX9_n_C2KoQU`/
okE_:?oBMBKobfhYokU[9oo7LbSocFPXonBcMP0Gooooo`03oooCZ?ooQ0Ooogl001gooh0000Coogh0
oomk0?ooXTGoomjl4oooool01Oo:h>koSKcJod2=`?l0HjWo06F[017o1fb^00Ko16^]o`1PYol7KJko
E9S6oj;8hOofn_coooooogoooooo003Aooooo`07ooOgmooHf=SoZZZZohV9ROnPX:3oalO7ono_k`0]
ooooo`05omSPkonW^]Wo/l?Nom7Kjoocm_X05oooool04?oJjO?oUL3MoeRKb?lDM;;o06>Yo`1TZ_lY
NKGoGhk1oeN;_omER[koHY;3of^Iaom]V/OoKYc8ofjLbOm_W<T2og2Lb@0>og2Lb?m`WLSoLIg8og:N
bOmaWLSoK9W7oen@`omAQkkoChJlofFDa?n1Y<goWK?Eokg:h_o[k?D7ooooo`0<omkUlOn_`=co[;kK
ojfog?oAfN[oko7eonc^loo/k_CokNodonk`mOo^l?Cok_3e0_o^lOD4onoamP09onoamoo_locolOGk
omgKfon^Zk;oZIfLojFFUoo3R3comgh0013ooh0000Ooogh0oomi0?ooN03ooi/goonmN_oof[Cooo[e
00?ooooo00Cooo[eooo:UOooQ0Soogh01OooP0001?ooP@3oogP0oonG=OoojM84ooooo`2:oocfjooK
XfSobgPXolV><OnhPRco[W<SojiQ7onYBb3oY40Poj=17onaDb7o^F8Sok9O8OnVBakoXSlOojA38?nX
BR7o/ELRojeC8OnVBR3oXd4Ooj=18?nYCaoo[EPRojE77onT@B3oZTlPok1T9_n]GRKoXD4LokAU:?o<
W4Oo[FDZok1L7_o9U4;oeHljom>1:OoCQ2[of90ionO0C_o2Q2_oV48MohX/6_naCB?oaG0Vokif9onk
O2Oo_G`YolJ19oo?S2[odI4^omFA<Oo3Pc3oa7PaomZD=?oYa4komn]gonS0B?nYFQooYUP[on:]E?o[
aTooh[Hbon>g=_o]d5;oln5ZooWaO?ohkW;oi=AfomZ^GOo2]hko^jADolUo@?nhCB;obhdhogYX>OoC
ZDKogZ8don>b=_oDZcGoTfX]omfI<_oGSc;oehhbomZE<oo2N2Wo]VTSomR2:_ngQbko]GLOomVB<OoI
^6Gob[>DolMj:oo4PBkoYFTZoj]U9OoEMRSo_FdUoka[9OneJB?oMTlSok]]:OndJ2So[F4YokAM:?n`
EROo/5XYolIR:_noHB_oOED_ogmE<?mmBRcoOClXoiA<:_nMEBgoZUT[ok9I:?o3G2OobUlXolaT:Oo>
Jb[o]edSojML7_noIbGocFL[olaT:_o<Ib[od7DXolaX9_ndDBKoSUP/okM`:?oALROocVdZol]b:Oo?
M2WolMR]6?ooool00ooo`87oog`0oon0000Koon00004ooml0?ooO@3ook]fooo_gQKooooo00GofNSb
ohjlf_lgQkgo062Wo`1VZP0@o`M/[P06o`Q/[_l4JZgo066Xo`ma/Om@U/KoWlKPoooooomnooooo`00
doooool01oo_knooclo?oinOWon<S8coYZJVom7AdOono_h0:oooool01_oIhNoo[;kKojZmf_nY_=[o
_<[Rom_Sl1Cooooo017ob^3]of^WcoldQkgo3G2`o`1TZ_l3JZgo1fb^o`9Z[OlYNKGoGhk1oeN;_omE
R[koI9C4og2LbOmbW/WoLYk:og>ObP04ogBObP;oMJ3:00coMZ3:ogFOb_m`WLWoM9o;ohJYd?nC[mCo
Vk?Eojfofon_`=coZ[gJokO7h?oin_`6ooooo`06omkUlOn_`=co[;kKojfog?oCfn[olO?f0_o^l?D0
0oo^lOGoko7foo3bmP05oo3bmP0;oo3cnOo`mOgol?Cioo3TeOobfKKogL2NojjEQonYT8;oYI>Aol>=
A_ogPPD03_ooP0001_ooO@3oogH0oomn0?ooYTkoom2Pooo]fPSooooo00?oomnooon94_ooNP001?oo
P0000oooN@3oohlRoooSaP04ooooo`2;oo_fj?oFU5OoaW@Wol28;_n]M2Oo/6HPojQ:7onT@B3oXd4O
ojE48?n_EB_oah99olJ3Doo9SF7odYiaom^aQooO^YWoiLJVonS>[ooVbZ_oh;jRombeU?oFZH;obiIZ
okejCon_Fc7oYT`RojA<7onQA1koY44OojA87onfLbooZU`WojA57?njMc?odIi9omAl:OoCPb[ofI0i
onW4DonbKBSoR2XIoiHe7OnmH2Oo`gh/ojah:?nRL2OoYG0Wok5h:OnfOb_obi@_omZQ=OoHVSSod8Xf
on>]?OoS^T;ol=QZoo?JH_ngIaOoXeH/onBgF_o[adcoi;XgongADoochFcok/aVooGNL?oil7Son>iX
onS6DOoGW4co/:1bom2dG_o6OT[o`V<VolVeN_nFPe[oe<B@ombS>OoV]SKo`YLboj1b;ooUZCcof9<b
omN<<OoITS?obH0]olMh9_oFQB_ocKAjokZDA_o@Pb[ofj8comR_G?o?OC7o/Fd[okEe;On:EbOo_FdU
om1d:?neJbCobG4VohYS;?nLGbWobVlWok9T:?nfIB[o]V4ZojmH9onWF2WoaV<ZokEN:_nBEBcoZETZ
ohiB;?n4CRcoTUD^oj5J;?nIE2[oc64XolYO:?o;H2WocVPZolMS9on/GB3o[f4Pol]Z:_o=IB_oc6H[
olia:?nnKbSobVlVokaH9onGFB_o_g4Xom1_:?o=J2[odGP`ooW^eP0Hooooo`03oookm_oo/VKoog/0
01[ooh0000Coogl0oonJ=?oofkKoooci6Oooool01OoHj?;oV<;Moc24^ol0GZOo06J[017o1fb^00Go
16Z]o`1SZOlCLk;oAY;3oj37h03oooooogcooooo003Dooooo`07ookno_o]kNgo_Kfmoi2@T?nHV9So
[Jf]omgMg@0Zooooo`08omWQkon/_]_o[;kKojbnfonZ_=[o[l3LolCAi_oZk_H@ooooo`06ojS<hom=
ULGo9gnio`AZ[Ol0J:co1F^]0ol7K:h01ol2JZgo:GVeoen>`OmGRkooE8VnofJEaOmeWlX00_mgXL/0
1?mhX/_oNJ;;ogVRbomiXl/2ogZSc00=ogRQc?mcWl[oOjO>oj6lfOnkcN;oam?VolgFj?noc>?o[;oL
ojbnfon[_M[o^LWQooSjo006ooooo`08omkUlOn_`=co[;kKojfog?oCfn[oloChoo3bm_oal_H2oo3b
mP0Aoo7bm_obl_Kol_;foo;cm_obm?Wol_Oooo;^j_oaglSol=6Xoo3;W?obbI?ogKV?ojjER?nYTXOo
YIBBol>=A_ogPPD03?ooP0001_ooO03oog80oon<6?oo^7;oon?6ooobiP_ooooo00WoonO>oonG<?oo
MP3ooh40oon00?ooNP3oohPDoooJ]Oooooh00oooool03_ogjm3od8U9okY/9onbMBWo[60RojU;7onV
@B3oZDLQokUW?_oEXW[ojLf]ooO]h?ono?Soo_gl2oooool0Loomo?[on_G]oo?WcOoPa9kobIEXojmQ
=?nNB1koXDHNojE27onVDb;o/7<bolUd:?oBOBOofYHjon>mDOn[I2SoSbhJojm<8_oBQbgocYl]okN<
9oo8W2[ocIl^okj@;?nbPbgo]8<bolFA=OoEX3_ohJa1on>_@OoCWd3ocH@gonZnGooK[dOo]74conK5
G_o`dE;okM=Doo7JJOoT/U;of8`hombNBOoA^ecoj==Voo[_IooW_4Go^g<]oi9l<?o6VDko_f4comNF
<_o5^97o/9MMom71UooJWSWoj;TfojF1<?ncPc;oiK8momZI<_oGSc3oehdaomB:;ooBPRWodh<[om2f
P_o=`IcodXT^olj>;?o=VbcodX4YolYd:OnnMbgoYfd[ojUe:Oo:LRGob74Wok][9?noQS_oP5l_ole^
:Oo1JROo]F<XokMU:_noIR_oWUPZoj=H:OnnHB[oYUX[oj5D:OnhFRSoYEP[oiUF;?nWFB_oTe<[okML
:?o1GbOobf0YoleV:Oo6JR[o^V@UojML7_nlIRCocVPZolaU:oo>KbSo_FXUojYV:?o9KbGo`f@WojUO
:Oo3L2SocV/YomF4@_onnoD06Oooool00ooom^gooi/gooml000Ioon00003oon21?ooaH[ooooo01co
oooo00GofNWcoiW3g_lZP;Wo05jVo`1W[00Ao`M/[P06o`AZ[Ol0IZ_o67Jdod>@`On=^m[on_cmoooo
oomiooooo`00e_ooool01oohn?SoiNGUoj^[Zon?ShooWIfMokfm_Oo^k^h0:?ooool00ooIhNoo[;kK
ojbnf`02ojbnf`05oj^mf_n[_M_o/lCOoloIjooko?d02oooool01ooZloSoN;3DocF7_OlHM[?o0fZ]
o`=Y[Ol6K:h01Ol7K:h01ol2JZgo:GVeoen>`OmGRkooE8VnofRHa_miX/`00_mjY<d04omkY<goO:G=
ogbUcOmlYLgoNJ?;ogNRbon=[m;o/lKPolKBi_o?f>WoeM_[omCKjooDfn[od][Yok;2g_n[_]_oZkgJ
okW9hOohn_`01_ooool01_oNiO7o[l3Lojbnfon^_mcoe]g[ooGem`;olO;f01?ol_;foo;dm_obm?Ko
l_Cgoo;fo?obn?kol^cSoo;I^_oacj;olLbIoo78T_oabICom<^FomnlTOn^UXSoZ9:7ojFDT_o3SDKo
mh8500Wooh0000Ooogl0oomi0?ooM03ooiDZooo=W?ook=SoooWc00kooooo00OoonoOoonbI_ooL@3o
ogd0oon95?oof;7oookl00;ooooo00_oooonon[;W_o2LS3o/f8VojeJ9?n]C27o/4hWolEnDooN]8ko
lMo7oochl`0Cooooo`1_oogmoOoinOWol>cQomW2WoneMT_oWd<NoiQ87oniHb?odWPUombG>_oK/doo
XU4Soj8k7_o6J2WocY4eojAf;?nNBbCoVeHUoknYBOngWC3oh;/golfU>oniRCKoaIHmomb_B?oNYT?o
`glfol=b<ooKU3kolMYZom:VCOodigCom^AWomjjFOoS`VGofHdhom5h:?oFTD?o_9eAoi1d>?oUbfCo
no9UonJ_@?n>CAcoSgXXojY>9Oo8L2[ohJXjojnEI_o4WU3od9AAomZI<_oV^SSoSg4`olVG=?oZ`SWo
fIPbol]a:_oFRc3oeX`_om>2:_oBP2godY9;omRkL_oV_EOodHD/olJC:Oo8P2Soe7XXol=e:_o5O2_o
]88iok=a:?o;LRKo`70WolEg;?n?IB_oY6<Tole_:OnoJBOo^F<YojiR:OnYGbcoPe<_oiIG:on`GRWo
W5//oiaE:_n^EbSoSe</oiQG;OnRF2coZe/ZojeK9oo3GbSocV@Yol1R9oo0IRSo]F<Soj]N7oo8JRSo
cFD[oli]:_o5K2CoZf<Woj9S:_o;L2Goc6dXokeY:?o;LBSofI9B01_ooooo00?oonWDoon53?ooOP00
6?ooP0001?ooP@7oohhKoonTBOoog[hLooooo`06oocmo_oOk?GoV/;Nob9l]ol0HJOo0VV]4Ol7K:h0
1_l4JZgo0FV/oa5b/_lfR;koSkgKooonooooooooMoooool00=Sooooo00Kon?ShomCDe?nNWYkoUiNG
oijNW_o8b<PWooooo`03omWQkon/_]_o[;kK00Co[;kK00CoZkkKojfng?nca=oog^Ka2?ooool01_o2
f^_oBiG4oaAc/_l=Kk3o1F^]o`I[[PSo1fb^017o0VZ]obUi]OmOS/7oEh^ooeB9__m[VLOoOJG=ogfV
cOmnYlkoOjS>ogjWcOmlYLgoP:S>ojFnf_o3dNGodm_[omGMj`05omONk006omSOk?nea=ooZkgKoj^m
f_nibN7on?[l1_ooool01ooNiO7o[l3Lojbnfon^_mcoeMg[ooGemoobloH00_obm?H02?odm?Som?Om
ooCdm_oci<ool]>Xoo;>VoocbiKoll^D0oocbiD01ooecIKoh;bAojjFR?nXTXOoYIBBol>=A_ogPPD0
1oooP0001oooO`3oogT0oon21?oo[E_oonC9ooofkOoooO/04Oooool01OoonO;oolZHoomn0?oocYko
ookl00;ooooo00Woo?S_om^YL?neG2Co/EPUokYV=ooAUVgoi/NVooK[f_onoO/05_ooool0L?omoOgo
nOWioo?clooZj^[ogmgIol>TP?nXEBOocW0TomVC>?oH[U7o[e8TokaF9_o0L2_oc9HjolBB?OnEGB_o
S3LRoiUc>omkLT7o;1XCom6dBOoJ]4;o`i]4ol6>@_oGXT?ofj8loln5>_oOXccojl]<ooG/NoogjGSo
hl1LokE/=_o1PD7oeXPeomJ3;oo<QSoobY19ohMk?_n7ERgomMe]ooW^H_o9PC?oOe/Qokj3>?nfBb;o
gZTeom6B;on3HC3o/Vd]olUZ9ooKW3?oh[Xhoi5`<?oDUc;ok</molmn;?o1FBCocWT[omJ;;_oCPR_o
dh8^om9o;OoEQS7ok/mWomFE?_oFUS;o]WTZolMd9_oCNbWocG`Wom29<on[LRko]V/Sol]c9_nnL2Oo
Yf0SohAJ7oneKBSob6hYok]W:Oo3IBWoYUdXoh]F;_mjCc7oQU@^oiUL:on8F2goR58]oiQC:on@Ebco
SeL]oiIK;_nMFBSo[EXVom1U:Oo6H2Ko_V4UolUW:?ncHR;o]F<RoleZ:_o>JR[oafhUokmW8_nGH2_o
Xf@Yoli`9_o>K2Woc6lXomfNFoono_hKooooo`03oooO__ooN03ooh0001Sooh0000Googl0oon00Ooo
R0oooilooooQa00Looooo`06oo_mo_o/m?WoWLGNoamj]_l0IJ[o16Z]4Ol7K:h2o`I[[P04o`e_/?l[
PK[oTKkKoogmooooooooMOooool00=Wooooo00Ooo_knoo_knoo3`l?oUiNGoiZJV_nZZZ[ol?3`02Go
oooo00KofN7_ojbnfon/_]_o[KoKok72g_n/_M/4ojbnf`03oj^nfonoc>?om_Oj00Cooooo00GoU<3M
ob^1^_l:KZoo2Ff_o`I[[P0;o`M/[P0@o`9Z[OlYNKGoGhk1oeN;_omDRKkoKI[7oh2XcOn2ZLooPJW?
oh6Xc_n>/M?o/LKPom3Jj_oIh>cofN3]om[Qk@Kof^3]00Kofn;]okK5gon[_M_oZkgJokW9hOohn_`6
ooooo`0=omkUlOn_`=co[;kKojjog?oFgN_om_Ohoo?dmoodm?Som?OmooCajoocg[oollnNoo?<UP07
oo?;U@07ooK=U_oP_97o[YJ8ojRBQonUU9;o`he6ooN21@05oon00007oomo0?ooO03ooh`Hooo5S?oo
mo3ooochoooooP0Dooooo`0;oooln_ool^Gooogkooooooooo_komncDom:GGoo5Oe3og[F@ongF__ok
mnh06_ooool0L?omoOgonOWioo?clooZj^[ogmoOomGEeOo;RDGoehXeon2/Doo2Gb[oc7TdojId>?nb
Mbkobj==olF8<On8F2ooOd8YogIS>OmY?Aoo>20Cok>GB_oO^4Ko_HTnom>SAOoP/D_oh:A7onBe?ooW
`Skol]iWoo7GHOo>QC?oWS`IokUb>?oKUSooehTdolEl>oo:Od3oZh0oohm^<_nODRgomn=aoog]H?nK
GBOoXhDfolIO9oo;Nb[oj/<iokAg:omiDbKo^5TUolU]:OoPYSGod[<iohiX;OoNXC?oeY0`olAO9Oo3
GBGobF`XomN;;_oCQBgodh8_om>2;_oBORgoei0komBGA?oHSRooWfdZok9Y8_o=N2OocgTXolio:_nm
N2_o/FXTol5d9_o8LbKo^6`Woi1J8_nNH2;oZf<Uol9/:OnmJ2[oZUHUoedn7_n3FbooOEL_ogYG;omn
G2ooNEL_og]?<?n;DRgoVeL[ojiL:_n]Fb[oVEDVolIS:?o7HROo]EhRolQS9oo<JRSo]6<RokeV9Oo?
JR[oaVlYokeX9?nmIbCoU5L/ojaV:Oo?KbSocFPZomVCE?omoOdKooooo`03ooomnoooeJ[oog@001_o
oh0000Cooh41oon32?ooX47oonK;7?ooool01_oloOkomOWloiW2gOlWP;Wo0VV]o`I[[QCo1fb^00?o
9GjhoiS2g_oko?h0oooooomcooooo`00g?ooool01?oXj>So/[:boi^KVoo@d=0Uooooo`08omWQkon/
_]_o[;kKojfofonha^3o_/_Rok71gOn[_M/3ojbnf`07oj^nfon/_]coemo]on;^m_m^ZLoo3W2`o`I[
[P0?o`M/[P0=o`9Z[OlYNKGoGhk1oeN;_omCR;koKic8oh>Ycon4ZlooV;KFok_>hooMh^kofn7]omcQ
kP03omgRkPKogN?^00Kog^?^okO5h?n[_M_oZkgJokW9hOohn_`6ooooo`0;omkUlOn_`=co[;kKojjo
g?oGgNcon?OiooCemOodj]com=F[oo?:U?ocbiD01?odc9D5ooG<U@07ooS>U_oQ_I7o[YJ8ojRBQonU
U9;o`he6ooN21@04oon00004oon21?ooXDCoomjlooonoAcooooo00Coo__fonoK`?oej=Soo_km7Ooo
ool0L?omoOgonOWioo?clooZj^[ogmoOom[6WOoFQcGogIY;ol]U:on^H2OoWVXfoiiH9?oBZ4_oaiQ4
ol>A??n<Jd3oCc8VogLj9OnHFb;o>B/Cok2IB?oU`eCo`Hi1olB;@_oP[TOojL96onBkBOoWa5_om^Ib
om>A:OnP?aWo_Wi0omfMAOoNVcgod98nokYW=?o<SdKoSfL^olE^:_nnHS3omNIZoo7HE?n4I2koaXPg
ol1K9?oNYc?ok<0ioi9T:?nUIBKo`eHTom>>;_oX]3Ko]YPfoiU[;Oo?Qb[ob6LWol=M9Oo5HbKodh8/
om>?<_oFSBgoe8D]om>2;ooCPRkodWl]om9o;?o?Pb[ob8d`okii:?nfKbKocgTWolij:?o5OB_o/FTT
ojaQ8OnhJB7oa7<Voj9S9onCFR3oXETNojUT9?noK2Wo`6LZofXi6_m`E2GoU6D/oiiR;?nCH2goQEh^
og]G;omjDc3oNU0`oh5D;onRG2coY5XZokQQ9ongH2Go^EdTokQP8oo>IBSo`VXYokUU8oo;JRSo_fXZ
oi=M:oo3JR?o`f8Uoj5D:_neJ2Socf/YomB3@_olnO<Looooo`03oookmooo^gKoogL001cooh000_oo
O`000oooWC_oombiooomn`0Mooooo`03ok3@i_lYP;Wo1V^^01Co1fb^00Co06R/ob9l]onPan3on?_m
oooooomaooooo`00g_ooool00oo[jn_oooooooooo`0Tooooo`05omWQkon/_]_o[;kKojfofonha^00
0_o0cN<00onhan;o[l3Lojfnf`02ojZmfP05oiB_e?mWU<CoD8Jlobam]ol9KJh04?l7K:h02ol2JZgo
:GVeoen>`OmGRkooEXZnogJQb_nW`=_oe=c[on7Vl?oPi?3og^?_00?ognC_0_oPiNl00ooPiO3ohNG`
on7Ul002on7Ul007on3Ul?oQi_3o^<GPoj^mfon[_M[o^LWQooSjo006ooooo`0;omkUlOn_`=co[;kK
ojjmfOoHf^?omnC7oo?=Voocb8kollZDooC<UOoec9D02OoecID03?ohciKoh[jAojjER?nXTXOoYIBB
ol>=A_ogP@Cooh00oon52OooR1;ookYfooofjd3ooooo077ooOgmooWinOobl_;ojNWYomoLd_oGTDCo
fHe2olnKHonRG2ooR4@ToiQ17oo0RC_od;ILokQl;ooMafCoN64mofH_8OnNAB7oVVhTodlm5_oJ^4go
bIDiolFBA?oYaU?ojKe>omBC@Oo;R3kogjM?ong>Eon]Da[o^WDlomnQB?oPYTCoi/14oki_;ooNY5Go
TeDWojie<OngB1oof:9<ookaH?nl[DGoTWdfola/:_oARBcohJ/eon:k>?n4I2Oo^f8VolQ[:?oQ/3Co
iZleoiYh<?n_ORoo`VDTolAO9Oo3GbGodWX[ok9g;onkP37ofi@_omZK<?oDQRgodh8^om>1;_oDPRoo
c7lYomBB;oo7PRgo^X0]okmk:Oo<N2Koc7dYokYc9_nUF1goYETNokMZ8OnhKbOoUV8SojAK7OnRF1oo
Xf8RokU[:OnZFRKoI48OoiQQ9onbI2WocFXZolaW:OnYHRWoRf0/oieK:onFERcoPUL_ohII;onPHBco
YU`TokAL9Oo2HBKobF@WolYV:_o2IR[oaV/Woli`:?n4ERgoV5l[olI[8oo;JbKo/EhYol5Z:?oAMC3o
m^_DooknoP0Looooo`03oooej_ooXT?oog/000gooh0000?oogl0oon00?ooP0003OooP0001_ooOP3o
ogH0oonD:?oof;CoooO_ooonoAcooooo00GoZ<cSob^2^_l=Kk3o1Vb^o`I[[P0Ao`M/[P06o`E[[Ol0
HjWo7gZfoik5goo`m_[on_cnoooooom^ooooo`00ooooool6ooooo`05omWQkon/_]_o[;kKojfofonh
a^000oo0cN<03?nkb^;oZ;gKohFWcomQT<;oDXVmoeF:__mGRkooFhc0oeN;`?lDLk7o3Fj`o`E[[@co
1fb^00Wo1V^^o`1X[?lXNKGoI972ofJDaOn2Y<goa=3Ton;Wl?oRi_000ooQiO000ooRio7oh^K`on?V
l008on?Wl@06onCXlOnha^7oZkgKoj^mf_nibN7on?[l1_ooool01ooMi>oo[kkGoj^ca_n]XjOoekB@
ooO;Soocbi@00_odc9D4ooG=U@?om/fE1?ofcYH02OoiciGohkjBojnFR?nXTXOoYI>@ol>>B?ogRQKo
oiL_ooo>W@13ooooo`1aoogmoOoinOWol_;bonWYj?oM^7_oeiMDom;2Xoo7alOo]9E^oiXk7_nWG2Wo
_YmAoj=/<Oo7WDSoh=I`og98;_nT?QooXE`Toj9h9_mbAbGof[MDom^kFOo@YdkoeYm8om2;>oo0NSKo
cg@[ono=Hoo9RS?o^6lgon:^D_oW^T[oj/U2oln@;_oSaFcoc;9gohUR<?nlFbSoagTkonc;DoogiUSo
Ui50okn;>_o:LBKog:0conJi>_oB/3OoSFDWolMP9OoGW3Woh[4iombS<_n5H2cob8T_olMQ9_o3GRGo
bV`XomND<?moFC7oaHH`omR:;_oKWC7ofYhaom22:_oDPbkodh4_om:1;Oo<Q2WodH/^olZ:;OnfOBgo
^VdQolUh9_o4NROoZf4OojEG7_nUFAko]V/QojI[9OnKGakoZ5PNojAH7_nSHR3o/fTXoha?9?n3F2?o
We/QojIQ9oo9JR[odV/ZojMS:OnOFbWo]EhXok1L:?nYFb[oZEh/ojAK:?nLEb;obV<YolaV:Oo>IbSo
bfDZolUX:OoBMBSo`EhXogI<;_nUHbWobFdTolm_:Oo5K2SocG0Woo3L]Oono_h07Oooool00oookmko
ohhKoomm0009oon00007oomo0?ooP03ooh`Hoon?7oooP`Koogh0oomo000>oon00005oomn0?ooL`3o
oiL_oooK^?oomN/07Oooool01OnQan7o;X>koa1a/Ol4JZgo1F^]013o1fb^00Oo26b^o`AZ[Ol0HJSo
:H2ioiS3gOoTkoKonO_m0?ooooooK?ooool00?oooooo1_ooool03OoIhNoo[;kKojbnfon^_m_o^/OQ
ol3=hongan3oZKkLohb^dom/V/SoGi;3oeZ=`OmHS;l00omGRkl01_mHRkooGhk1odR5_?l=KZoo26f^
o`E[[@So1fb^00_o16Z]o`9Y[?l=Kk3o8gjgoebHaonR]mSo[l3Mojfnfoo9dnKohNK`on?Vl003onCX
l@04onGXlOoUjO7oi^WaonKZl@Ooi^[b00Koin_bokW7h?n[_M_oZkgJokW9hOohn_`4ooooo`0:oook
m_ook=Soc/J_ojbPW_nZSh3o[9:3omNdSoohciKom<bEooG<U@;omLfE00?om/fEooK>U_ofcYH01oog
cYH01oojd9OohkjAojjEQ_nXU8[oYIFDolN/Q?ohh/D0AOooool0LOolo?con?Shoo7alOoWh<cofk^>
omCAbOo;bl_oalO7ol6bVOnI@27oXW0hoiMG;?n`MC3og/mZohYa@?mg=R;oXT4Ook5l:_mbBacoQUdf
onC4E?naL3GoaH<lon6_?oo>ScWod7/aonNgD_oYbf3o_gXhonJkFooX`4SoiKdfon2b<OoR_U_omoB9
ojfTLonYJC?o`68_on2]C_oRZScoiMYFokNVB?oCPc3oeiT_omfP=OoV/SOo^idbojYY9oo?N2[oh;I4
on>b??o:U33oQ68]om21;Oo3FbCoaF<VomF9;onkOR_oN50_omRU=_oITC7of9<_ombV=?o;S2cod84X
om>2:ooDPRoocWlYom2<;Oo6OBWoZElQojEH7_niKB7oaWTUokI[8OnUEakoYEPOojII7_n_JB7oW6DQ
ojAJ7_nWF1koYEPMoj9Q8?nSHROoQeTUoieN8?nSF1koWelVol5X:_oAJR[oYF<[ojUK:?ngGRSo[e`Y
ojaK:OnnH2[oXUTVokEN9Oo=JBWob6HVoleX:Oo;HR[ocFdYom1V9ondBRSoODl^ojmW9oo<KBOocf`Z
ole/9_o]dZ3ooOgm01kooooo00?oon;4oon95OooO@001oooP0002_ooOP3ooh<9oonQA?oojMCooo_g
oonfKOooT2?ooh45oomm0?ooO`0=oon00006oon10?ooO03oog<0oonN??oofkSooo?X7Oooool01OnH
`]ko=XRnoa5b/Ol2JJco1F^]017o1fb^00Ko0FV/o`1RZ?lCLk?oTkoLomcZloojo?goooooof[ooooo
003oooooo`Kooooo00oofN7_ojjog?n_`=coZ[gJojNlf_nN^=SoOZ?=of>Da?mTU<GoJIO7of^Haom[
VLSoHi?4oe^>`OmFRkl00omGRkl01_mLSL3oEH^oob]k]olAL;3o0f^]o`I/[PCo1fb^00go0FR/o`1V
ZolJMkCo@8k1ognceOoWlOOon_OjokG4g_nZ_M[oYk_IolWCi_oSio3oi^Wa00;oi^[b00Coin_bonS[
l_oXjo;oj>_b0ooXk?84onW/lP07onS/l_oZkO;o^LOPoj^mfon[_M[o^LWQooSkoP02ooooo`0:oooc
j?oog[kookajoon52OnaR2coZI5oojZCQon/U8Oof;F@ooS?UP?omLfE0_ofcYH7ooO>UP09ooO>UOog
cI?on/nDon?2V_n^XYooZZZfojBdcooGiO_ooOoo04Gooooo06Koo?clooOgmoo_knooi^GQom_KfooA
dM7obl_;olK6a_o4_[3oSE<boi969_nSERCobJmGok>EBommEB_oSShToii@8_nXORWoFS@Pok68?oo:
TcKofJU8ong;D?oQ[DGof8dkonJiAoobhF?og;=IonO7G?o[bDWojLU5ong@DooaffCooOR1omcEL_nB
ND;o_U`[omnaDOoMX3Oojl52omC<EOo;VCgoe8`/omnY=_oKW3CoiJlfokRF<?nlK2OogZDcomjW=OoY
_CSo]8D`oiI_;ooCNB[o`U/Tom60;OoNVc?o[WH^oh5F;_oU`3_ofYDbomRD<OoMXC;odITbolR3:?oC
PbKoe88/om:1;Oo<Q2WoagdXojMH7_nUF1ooYeXNokU^8OnlLb;oZ5/OojMJ7onWGAkoZF4NojM[7onQ
HAgoYU`NojIJ7_nUF1koXUhOoiAR9onBHR?oYeTNojAH7_nLG2Co^VPYoliZ:onSHR[o]5/VokYM9onD
Eb_oT5P/ojMM:on[GROoaFPWokEP8oo>J2T2olaT:P0:oli`:Oo?HRSo]ddXohQA;?niJRKocV`Xol]U
:OoV_XOoo?clooknoQkooooo00?oom:Toon33oooO0001OooP0000oooO03ooi0Qooo1Q004ooooo`06
ooobiOoo^gKooiH]oon21OooO03oogl03_ooP0001OooN`3oogD0oonRA_ooeZgoon_G01gooooo00Go
Ul;NodB@`_lBLk7o06N[o`9Y[@0Ao`M/[P05o`9Y[?l0HJSo6gReohfkf_oAho00oooooomYooooo`00
i?ooool00oofn?_omoWlooooo`0Nooooo`07on7Wl_nT^MSoU:oCogfRc?mZVLKoI9G4ofFFaP05ofZH
a`05ofbIaomYUlKoGY33oeV<`?mER[l00_mGRkl03OmIRkooHXo1odV7_?lQMkCo2Fj_o`=Z[Ol4JZgo
06J[o`1UZ_l/PK[oF9c9ojG:h_obmo/00_ooool01ooVjoCo/L7MojZmf_nW^mWob]CVonKYlOoXjo80
0_oXk?801OoZk?;oj^ccon[/looZkO?ojngc00;oj^gc1?o[kO<04ooZkO?ojnkcok[7h?n[_M_oZkkK
okW<ioohn_goonWBooo@WoooZECoog`0oome0?ooN`3o]HlkojVCPonZThOo[9B7omReT?oid9H00_oe
cID00oofcIGomljFooO>UP05ooO>UP0;ooO>U?ogcI;omljCooSFY_okhKcoi=_Aojo1g_n[`N?oYK[J
omKOkOoloOh0A?ooool0;?ono_kono_kooKfm_o^k^koi>CTomWIfOo@d=3ob/[:olK6a_o4a<;oWfM3
oii07_nbRTCo/IM=ok5n=?nBJS3oS3PPojIZ9_nCKbOoPE4]omNkFooP_eSocj9:omJMB_oPXdOoil94
onO3?OodiG?om^]jooS/KOofifool^5dooS`P?okm87oo_V0ok6]F_n]IS;oeiU8onFgA?oJVS3ojLM4
omk<EooGW3?ogZPd0_oLWS@06_oNZcKo`I4`omFC;ooPZSKofiddonJ^=OnVOBoo[Gd`ol]X9_o9KBWo
fIPcomjE<OnXLc7oSF4`ono<?OoITc;ofILbomZJ<OoMYSCodYDbom:;<Oo=P2_oeh</oln1:_o8P2So
/68P0_nUF1h0:OnWFako^FlQokE]8?ndL1oo/g<Noj]`7On]KakoXf`Loj9]6onRJa[oWVLLoiaQ7?nH
HagoSVHSoimN8?nYEakoYUPNoiiL8On^IBOo`fTZoi]R:_nZFbOo]e`WohiI;?n2FRkoS5d^ok5U:OnU
G1ko`F@VoliW:_o;I2[ocVhYolE_:?o:IbKo^e@XoiMD:_o3KBOocFPZomfPIOojn_[oo_kn01kooooo
00CooocioonkMoooO@Coogh00_ooP0001?ooOP3oogX0oonO?_oogK/7ooooo`06ooo]fooo`H?ooj11
oon00OooN`3oogl03_ooP0001OooNP3oogH0oonG;ooobYGoon_F01cooooo00Koo?gnoiO1gOm9U<Co
6GJdo`1VZ_l2JJ`Ao`M/[P05o`1W[?l0HJSo97fgoh^jfOo<hNl0oooooomWooooo`00i?ooool00ooQ
io;oa]?Won;XlP0Mooooo`08om[YlonW`=coLI_8oeZ=`?m@QkgoHI;3of^IaomZV<L5of^Ia`0AofbI
aom]VLSoKI[8ofNFaOmMT<7oEh^ooeF:_omGRkooEX^ooeb=`?mLS/7o>82ioa1_[ol<Kk3o=hRnog>]
d_o5g>`01Oooool02ooVjoCo/L7MojZmf_nW^]WobmKXonOZl_oZk?Cojnkdon[]m?o[k_?ok>kc00;o
k>kd0_o/ko@6ong_m00Eong`m?nkbN?oZl3Poj^lf_nf]kkokkj2oonH<?ooN03oogL0oomo0?ooP03o
ogh0okF?>onYTh?oZY>7ojbDQooH]I3onM2FooG=UOofcIGom/jF00GomljF00gomlfDooO<SoohdI[o
n=Z_ooWUbOojl^KooOooonK]nOn``=goZ[gJojFif?oFgngoo?gn04Cooooo07?oo_knoo[jn_oemOGo
k>c/on;Rh_oGemOoclo?olW9bOo5aLGoa<C4oj5TAonMEb_oU7I3oj5/;_noUd;oUF0Yohe18_nLLbKo
T64VojAj??oWaU;o[VH`olf<@ooU]4[oil8nonFm=oo`eegon_B1oo;HKooKZ5Ko_gDjoljBB?obgF_o
o?N0on_WMonYR4KodHU1onO0BooKW37ofidboncAC?oZcE3oh:`combP=OoLWSCog9ldomn^=_oDXS?o
hJ/dom^O=?oLWSCohjPeojAm;oo1Q2kob6@Vom>:;_o@SRkogiTboiQX<?nIJS7olLdlomJ>;ooGSRoo
f9HaomfS<ooMXSKobX@_oie^;Oo9ORKoeX@[olUo9ongJR;oY5PNojEG7on]H23o`G@Rol5i8Oo0Mb;o
b7TUol=i9_o>OBgoUEhQojm`8?o2LRCo`g<Toja^8?n[Jb3oVFLNoi=U7onMGaooXe/NojQH7_nQFAoo
YV8UokIW:_nAG2[oTePYojiM9on`GRSoZ60[ojYQ;?nQFB7oY5/OoleY:Oo<IB[ocf`YokeW:?n/HbKo
aVXTokiM:OnYG2WobV`XomF3@oogmO3oo?cl01oooooo00SoooCXoonYD_ooOP3oogl0oomj0?ooQ0[o
ok9Woooci`[ooooo00KoooG[ooo4R_ooX43oog`0oomj0?ooO`0>oon00005oomj0?ooN@3ooiTfooo7
S_ook=P07?ooool01_oam_[oZ/cSof2QbolGMK?o06>Yo`=Y[A7o1fb^00Go06N[o`1PZ?lXP;WoQ[OH
olgQk`3oooooofGooooo003Tooooo`05omoVlOnZ_=[o[/3Lol[Fj?o]lOP06?ooool03Oomo_oo_]SZ
ogV`doliR[ooCXJloe:8__mFR[koF8c0ofBDa?m^V/OoKI[7ofjLb?m^W<T00_m`W<T2og2Mb0;oLIg8
00coLYk9og2Lb?mXU/GoFhk0oeF9__mFRkooE8Vnoe26_OmQT<;oHI?4oi>lf_oFi_87ooooo`06onK[
m?na`MgoZ[gJojNjfOo=e^SojNcb0_o/k_@01Oo]koCokO3eonk`mOo^l?Cok_3e00;ok_7e1Oo_lOH0
2Oo_lo_ol?Kook[2e?nZZkSoZJ6Vok:BM_oVOP3oogT0oomo0003oon00008oomn0?neSc_oZI>3ojZC
Qon/U8OofKJ@ooW@U_ofcID5ooO>UP0?ooS<TOohc8konM:NooWP_?ojk=Son_G_oo[nooojo?kooOck
onKZl_n``MgoZ[gJojFif?oFgngoo?gn04Cooooo037ooOgmooWinOoclo?oj^[Zon3Ph?oFe]Koc/k>
olS8b?o5aLGoa<C4oiUTC?n2D33oS4`XokjA@?nnUCkoQddSohm@8_nBGb?oSU<Zok^K@?noO2codIQ9
onk:CooZbd?oj/M;oo3II_ohkG_oh/=Rolf<DOnV>ASo]fDbonJnDoo/bESoo_f4olk8IonoQT?oike?
omfR=?oLWCCofihbonoFDOoX`4;og9hcom^L=?oLWCCofiddon6`=_oS]cKogJ<d00;og9hd047og:8d
okjE<_o=PRgocWHZom>PBOoBUSKog9TcoheR<OnUM33ogIT`om1k:ooDPbcoeHT^om^K<OoOYcGoehX/
oi1X:on0Cb7oeH4Wom22:?nkKb;oYEPNojeP8?o4Mb?o`WTToja]9_o7NBGoe7`Zol]j9ooBP2coY6DV
oieR7oo3M2CocW@XolYc9_o9L2Oo[UdUoem35onLKb7oVVPQoiYR7onNG1koXETNojAQ8onWIBWoRUPZ
oh=G;?nOFbWo]5lXolQS:_niHB[oW5PPokiU9Oo?Ib[ocf`YolYX9onMG2So[F0SolU^9Oo4IB[o_VTY
om5g<Oobj=Cono_kooknoP0Oooooo`05ooo^g?ooWC[oogD0oonD;_oodJ<03_ooool01OoolN?ool^F
oonO?oooN03oogT000kooh0000Koogl0oomi0?ooN`3ooiTfooo0POook=PLooooo`07oocmo_nbdNKo
I:?=oa1a/Ol0H:Oo0fZ]o`Q/[P0@o`M/[P05o`1VZol0HZWo;8:jogN_doo>h^l0oooooomSooooo`00
i?ooool01ooPi_7o/<7MojVlfOnV^]Wo^<SQomOOk_oloOd05?ooool01oodnO_oW<GOoeNLbOlVO[So
06FZo`1SZ_mBR;h00_mGRkl01_mIS<3oIiK6og>NbOmbW/WoLYk:og>Ob@;oM9o90omeX<X2ogJPbP0:
ogNQbomhXL_oL9c8of2A`_mAQkgoGho2oh2ScOnB[m?oX;GFonW/m0Sooooo00Koi^_dok71gOnZ_M[o
Yk[IolkFj?o[k_@2onk`m003onkamOo_lOKol?7f00Col?;f0_o`lOH02oo`l_Sol?Gmoo3enoo`imco
l=_0okVWWOnYThSoZI23ok:@L?oWQ@googl000Cooh0000Soogh0okF?>onYTh?oZY>7ojbDQooI]Y3o
n]2FooK>UP;omljF00WomlfDooO:SoofbXkon=RZooWVb_ojkn3on_Wgoo[looojnod00_ojn_X01oom
o?_oi^[bok31gOnZ_M[oYKWHomKOkOoloOh0A?ooool0<OomoOgonOWioo;bl_oYjNWog]kNomCDe?o=
cLgoalO7olG5aOo4a<CoWGiOoh8h8on/J2_oajUAok:2<Om_?2?oN4/NoiMD9?nFJ33oaZ55onC0FOo`
ee[ojlUBon>[B?oIWTWoi/9Ooo3GH?oARS7o/E<XokAN;_oU`EWogJ8donk@G_ogm7oob[1Mon6eD?oP
ZcWofYTaom^K<ooNYCGok=17onFj>_oV]CSoi;Lion:b=ooQ[SOohkDgon2/=OoLW3<00_oLWS@0@_oK
XCCoeJHdom:1;?oGTS?oe[UaombT?ooHUc;oOETaok=c;_o;J2GocGHZomF8;OoDQRgoehl_omnY=_oO
WRoo[W</oge57_nfIB3odH4VolMj9On`HR3oaGDSolUm9?oARbooX6L/okmg9_o9NbKodGXXolQj9_o7
NB_oRUHOolAd9Oo0LRCobW<VolAb9?o9KRSoISXIoiAO7OniKBGo^6`Voja[9OnHIB;oUelQoiUR8onC
I2SoQeL[oh1D;?n;F2_oX5dYokYR:OnfH2SoZehRoleY:Oo9JRWocVXXok9R9On<ERSo^6@Role]:?o<
KBWocW4Xon_G]OoinOWoo?clooknoQoooooo00?oom^gooniM?ooi<T04Oooool01_ookM_oolbHoonL
>oooMP3oogP0oomo00gooh0000Koogl0oomj0?ooOP3ooiPeoonoP?ooiL/Looooo`07ooCho?ndd^Ko
H:7;o`Q/[_l0H:Oo16Z]o`Q/[P0@o`M/[P05o`1VZol0IJ[o<8BkogB]d_oDiO40oooooomQooooo`00
i?ooool02?oPi_7o/<7Moj^mf_n/_]_oZKcJojfog?nnc>?ohnWc4Oooool02OoHj?;oLJ_@ocN8_OlC
Lk;o06N[o`5X[?l6K:ko0FZ]oe>9_P02oeN;_`03oeV<`?mZV<OoN:;;00;oMj7;0_miX//00omiXl_o
NZ?<ogZSc002og^Sc@0<ogZTcOmhXlcoM:7;ogNRc?nC/]CoY[kKojVnfon[_M_o/<3LojJjf?oLi?3o
oOkn1oooool02?oVjoCo/L7MojZmf_nV^]WocmSYong_mOo`lOKolO;f0_o`l_H2oo7bmP;ol_;f00ko
l_?foo;enOobn?ool_;boo7Td_o`eK7oklfOoo37TOniWHOoZI:6ojVCROnbTG;oihD>oomo00Cooh00
017oogh0okF?>onYTh?oZY>7ojbDQooI]Y3on]2FooK>U_ogcI?omlZ;ooS>U_ohg[[on>_HooWdkOoj
n__on_cnoo[jn`04oo[jnP07ooglnooVj_;o/<7MojZmf_nU^MSoe]o]oocmoP14ooooo`08ooclo?og
moOol?3`onKVi_oLg=cod];Bol_;boo7alL2olC4a00eok><I?nI?aoo`jAAol>PBOnQNSKoKDHWogQC
8OnRGBWo]9Y8onoMKooCZE;oeJ1<omN=>Oo8OSSoch/monc9HOoR/d7o/TlLojmB:?oR^eWohJXjomZI
<?obffOol>YjonC;GooQ[3_og9hcon:b>?oYa3cokM11on_=@?o[bTCoc[<oom^d>?oQ/3Koi;XionBj
=ooQ/CGohJheomfR=?oKWCCogZHdomjW=?oFSS3og:0dombP=_oQZCKochdaog5;<?o1LB[ob6<Tolee
:_oERBd00_oDQbd0=?oLWc;ogZ0aolAf9_nUFAkoXeHNok9T8?o;O2Gob7TTolem9_o@P2_oe8/]olF2
;oncKRWocX4XolYk9oo?NBOocG`Xojm[:?n_JB?ocGLWol1b9?o6LROoag@UojUL8om^AAWo`6lUokYY
9_o;KbWo`VhXojQV9OnVI2GoSfDUohiU:?n7F2coPE</oh5E;On;FB_oX64[ojUO:?o5J2Oo`FPVol9V
9_o:JBGoTePWoh]F:?o3JBCocf/ZolaY:?oT`Y7om_Kfoo_knoomoOdOooooo`03ooomnoooo?Wooooo
01?ooooo00KoonoNoooCY_ooYDcoog/0oomg0?ooO`0=oon00006oomo0?ooN`3ooh43oonA9?oo[Uco
onSA7?ooool01_o_m_[o_=OYof>Rc?l2JJco062Xo`E[[A3o1fb^00Ko1Vb^o`1WZol2JJco;X>koefN
b_o5g>_ooooooeoooooo003Tooooo`03on3VlOn``MgoZkgJ00;o[;kK00GoZkkKojVlf_nc`mkoa];W
ooWio@0=ooooo`06ojo?iOm@UlKo9Gjho`U][ol0Ij_o16Z]0ol7K:h01ol1JZgoDhVnoeN;_omGRkoo
FHc0ofbIaomlYLd00_mjY<d3ogbUc@?oOJG=00goNjC<ogNSbon2ZLkoXKcJokc=h_o<e^SoeMg[olOA
iOn]_mcoZkkKojFif?oLi?3ooOkn00Oooooo00Koi^_dok71gOnZ_M[oY[[Iom3IjOo^l?D2oo7bmP0D
oo;bm_obloKol_Cfoo;cm_obm?OoloGloo;hooockn[olmg1oo7CZ?oacIcolLVCoo39TooabYGo^Yn:
ojVBQonYThWo/Y5bonN53_ooO`04oon0000>oomn0?neSc_oZI>3ojZCQon/U8OofkR@oo[?TOofbhko
mmFRooSVcOoil>KonOKcooWjo?ojno`7oo[jnP07ooglnooVj_;o/<7MojZmf_nU^MSoe]o]oocmoP13
ooooo`09ookno_okno_om_Kfonk^k_oTi>Cof][Jom7AdOo:b/[oa/K600;oa<C406co]HEPoj=S<On/
Udoo[7haojBAC_mD?QooUFDWoiEK;OoQaE7o^G@bok]_=ooKV3coa80iol^8?_oJTS_ol]YUol9`8onZ
B2?ogK9Gon>a@?oKVc7ofidcooCTL?oilW[ojlU<onk5BOoafU?oilI0ombU>_oN^D?olmeAomO3KOmj
JcgoaGLYol5F9?o<Pbkoh;Hhon>e=_oGZSCohK0eomjT=?oNYCCogJ4dom^L=?oLWcCog9hdon2T=Oo4
PS7oNe0_olMb:Oo8IBGobg0XomF9;_oDQbgoe8H]omNA;ooOYcGoaWPVojIG7_nUFAooXeHNol1`8_oB
PRGod80[omB2<?o>PB[odhd`okQf;?o>OB_ocH8YolQj9oo<NBOo`WPXoj9U8oo:MbGoag8WoiUM8Oo1
LR?oag<Uoh9;7_nUI27oafhWokQW9_o5KBSoaFhXol5V9on`FROoG4@Poh=O9on?HB[oSU`[ohIJ;?n1
FbcoQUh/oj9U;?o2JBGo[5hQolaY9onhHb;oPE0Zoi]K9_o;K2OocFLZomRHF_obl_;on?Shooclo?on
o_hfooooo`03oooci_oog;WoojI>00;oogX03_ooP0001_ooO`3oogd0oomo0?ooTB?oojiOooo]fQco
oooo00Kok_Gjol7Kj_mNWl_o06N[o`1RZOl6Jjh@o`M/[P06o`I/[_l2JJco16Z]obAm]omKW/Wocn;_
oooooomMooooo`00i?ooool01OoPi_7o/<7Moj^mf_n/_]_oZkkK00;o[;kK00CoZkgKojbnfonhb>7o
f^;_2Oooool01ooio?goRk_Ioc:5_?lGM[?o1V^^o`=Y[?l6Jjh01Ol7K:h02Ol1JZgoDhVnoeN;_omG
RkooFHg0ofnLb?moYlkoOJK=ognWcP02ognXcP;oP:S>00KoOjO>ogZSc?n:[m;o//KOolgGjOoBfnX2
omONk007omWPkOo8dnKo[[oLoj^nfonU^MSog>C`oognoP07ooooo`07onK[m?na`MgoZ[gJojJjfOo@
fNWol?3eoo;cmP02oo;dmP08oo?dmoodm?Som?OmooCgn_odj]_ol]Ncoo;?WOocc9L2oo?:U009oo?;
UOobbiGollbEokZOR_nYTXOoZI>9ok:AL_oWQ@koogl000Cooh0000_oogh0okF?>onYTh?oZY:6oj^B
Poo9Z8Wom]Zboo_^fOoim_;onOShooSin`03ooWinPOon_[j00OooOckonKZl_n``MgoZ[gJojFif?oF
gngoo?gn04?ooooo00Woo_knoo[jn_oemOGok>c/on;Rh_oGemOoclo?olW9bOo6a/H00_o4a<@0:_nW
MUSoTfdnohaL:Oo6Y4[oU8Y;oee16omk@B7oX7liolb?<oo0NS_oiK94omV[@?o?RcgodGLVonVnFOoO
/TWoZdLMomRYEOoU^4KofYX`omZI<?oMXcOom^YdooOZI_ofhF3o`KQHol^D>_noDb?o]fd_okF6<Oom
hEOoZIY?oi=/:_o:H2Ko`fDVojUh;?oO[CKobZY>oh9Q;ooHTboogjTcon2[=@Cog9ld00Sogj4dol:3
<_n;FRoobg0WolQV9Oo9JROoeH`_omF7;@;oe8L]03CogZ8coln5:_nWF1koY5LNojeO7oo=OBCoa7dX
olj1:?oBPBkodX0]om26:oo<R37obGX[om:2:onhMRWo`gDUolil9_n_KBOo[6XQolag9_nYHbCoWV@N
ol=d8oncIb?oQ5<Mol1a9?o7KRSo[F0VojaS9Oo2KROo`fHWoflj8_mB?b7oXf/Wok5S9_nkH2KoYelY
oj1Q:_nMHRco[6@Yoj9I7_nmI2CobVPWokUP9On7CB[o[F<Uoli[:?o?LS;ojn;AooGemOojn_[ooOgm
>?ooool01OoomN_oomnooonRAOooNP3oog`000oooh0000Googh0oon10_ooSakook1Qooobi00Loooo
o`06onoen_o8g^goEi_9o`1VZol0I:Wo1V^^4Ol7K:h01Ol4JZgo26b^oamk]_mJWLWoe>Ka0?oooooo
Foooool00>Cooooo00Koh>Kaok31gOn[_M[oZkgKok72g_n]_]`4ojbnf`03ojfofonlbn;okO7g00Go
oooo00Koe>Kaof6Qc?lGM[?o3W2`o`I/[_l6Jjh8o`M/[P0Ao`5Z[OmCRKkoEh^ooeN;_omISL3oLIk9
ohB[con2ZLooPZ[?ohBZcon3Z/ooP:S>ognXcOnK^MOoaM?VomGMjooHgn`01?oJh>d01ooMh^kobmGW
ojjog?n[_M_oYKWHomcTl?omo_h01oooool04?oVjoCo/L7MojZmf_nV^]WodMWYoo3bmOocm?Oom?Cg
ooCdn?odmo_olo?booCPaOocd:3ollbHoo?;U_ocbi@5oo?;U@07ooC<UOnjWh[oZI:7ojVCROnbTG;o
ihD>oomo0004oon0000;oomn0?ndSS[oZI9oojZFSOn[YZoo[KS?okK4g?oNhngonockoo[kn_oinOX0
0_oin?T3ooWinPGon_[j00Ooo?_konGYl_n``=coZ[gJojFif?oFgngoo?gn04?ooooo00WooOgmooWi
nOoclo?oj^[Zon3Ph?oEeMGocLg=olS8b?o5aLD00_o4a<@0KOn>JDkoOd<Woie[;OoSeVkoNfLgog4h
8OmcAbOo^Y8oom>I@ooZa4_ok=1:omNG??oBNbgohjm>ooGSK_njI2GodI]@onNlBooIURcog9hconNl
BooehVcon>mdoocdMOoG`fgoQFlhol1M9Oo2IB[oOf@Wokij:_ofheWoNfh_okU/9_o7FRGoYG<Yoi5J
9_o]]c_o[YaRohiS;_o=IRKobW4YomjR<ooNY3Gog:0dombN=?oLWcCogj8dol65<_nKHboocVhVolMT
9?o?Nbcoei4aomJ<<?oER2goe8D]omVE<?oGTRkoZe`Ooj=F7_o1LB;oeHXXojA`;_o:PR[odXL[om:0
;_o?PB_od8X^olAm:oo@OR_oaWh[ok1/9?o2Lb?oa7PVojMW8onbJ1oo`G<Voj1S8on/IAoo_G4Roi]O
8OnIH1go^fhSol1[9_miAakoZFLSol1]9onkHBOoEC@QohYJ9OngJBSo[f8Wok]P9_nhGbOo_V@YolEV
:on/GRGoYE`Ool]Y9oo:IbSo_e`Wohm?:OngIbKocVLXon?7W?oalO7omoOgooclo?ono_h0>?ooool0
1_ooookoooWdoooSa_ooXTCoog/0oomn013ooh0000Cooh43oon84_oo[UcoooCW7?ooool01OoenOco
fNWcog>/dOl6K:ko06N/01;o1fb^00Go1V^^o`Q/[olBLk7oEY_8omSWlP3ooooooeWooooo003Toooo
o`07on3VlOn``MgoZkgJoj^mf_nga^3o_l_Sok?3gP04ojbnf`09oj^nfon]`=gocMSZooclo_oko_ko
[LkTocj<`?l?LK3o2Ff_00co1fb^00oo0FZ]oe>9__mGRkooEh^ooeV=`?mcWlWoQjc@ohF/d?n5Zloo
Pj[@ohZ^dOn[`]goeMg[omgQkOoMh^h00_oMhnh3omgSk`08omgSk_oPiNoocMKXojjog?n[_M_oYKWH
omcTl?omo_h7ooooo`0<onK[m?na`MgoZ[gJojJjfOoAf^[ol_;fooCen?odm__omNkVooGJ]OoccIWo
ll^E0oodc9D6ooG<U@07ooG=UOnjWh[oZI:7ojVCROnbTG;oihD>oomo0003oon00006oomo0?ooNP3o
aia=ojZZ/On[_MWo[;kJ0on/_]/00oo0c>?ok_3eoocln`02ooShn@;onOSi1_oinOX01oolno_oiNWa
ok30g?nZ_M[oYKWHomKOkOoloOh0@oooool0N?olo?con?Shoo7alOoXj>SogMgMom?Cdoo<c<coalO7
olG5aOo4a<Co`l6loh]E??n@AB3obkIJokV_G?m=:QooNc`Roha`<ooWcfCokmINon[AGooQZTcoeXTf
onS1CoogjFOof:M<olf@A_oW_4gofYX_onNnC?obg6Woj<MVomk4H?ofjG7ooo^4oiF;AOnYKbWoae/V
ok:C?_mgBb3ofXP`omS@E?n6JRSob64Uom21;?mmJ2_o/UlWonRf>?n6LS[o/W4ZolMM9?o8J2Ood9Ha
omnT=?oNY3CogJ4dombO=?oOXCCoaXXboj]Z;Oo<JBGoc7@YomRC<ooHTS7oehd`omJ<<?oER2goeHX^
omVF;onbHb7o[5hOom639OoOWC3o]XD^okYd:OoHTRkodXL[om:0;Oo?Q2_oah4[okib9?o>P2_o^WDX
ojaQ7onnLB?o]g@TojYP7onaIb3o/W0UojQT8?n^HQoo/FdQoi]S8OnWH1ko]F/QojYP9?moE1co/VXS
oke]9onQEBCoG3lRoke[:?nmIRSo/F8XokMS9oncH2Oo^V8XolAV:onYGBCo]F8RoliY:_o?JBWo`E`X
oiaC:?o2IRKofIiPonc/k?odm?ConOWioogmoC[ooooo00Koooonooomnoooh<7ooi`ioomm0?ooO`0@
oon00004oon10_ooP@Gooj=7oooYdQcooooo00Goo?gnon_dn?m`Zm3o16Z]o`E[[@0Do`M/[P03o`U]
[omGV/Sog>[d0?ooooooEoooool00>Cooooo00Goh>Kaok31gOn[_M[oZkgJokO6h002oko<h`03ok[8
hOn^_mgo[;kK00;o[;kK00Ko[KkKoj6gf?n>Z];o?HBlo`M/[Ol5K:h>o`M/[P0>o`5Z[OmCRKkoEh^o
oeN;_omJSL3oMJ3:oh^^dOn7[=3oUKGEol3@i?oNh^oohNK_omoTkooPiNl2on3Ul0GohNG`00OohnOa
oloGjOn^_mcoZkgKojFif?oLi?3ooOkn00Oooooo00coi^_dok71gOnZ_M[oY[[Iom;JjOoal_?om>SE
ooCCYoocbY?om<bDooC<UOoec9D9ooG=U@0?ooK>UOnjWh[oZI:7ojVCROnbTG;oihD>oomo0?ooP03o
oh02oon21OooYTgoonO?oooooooen?co`m3U00Co[;kK00GoZkgKojo0fooEgN_on?Shoo[jnP03ooSh
n@GonOSi00Ooo?[jonCYlOn``=coZ[gJojFif?oFgngoo?gn04;ooooo00Woo_knooclo?ofm_Kokno_
onGUiOoJf][odM7Aol_;boo6a/H00_o4a<@0Kono^JooWTXYoim`=oo0]UgoITTWoe8U7On>EbOodKmH
omjiF_nmNckodH`oomfM@_o/c57ojla1onoHIooEXTooi[a?onNeA?obgFWoiL=SolYi>onZMCWo]H<i
ooWWM?oVhWOoR7Lcol=P9_oQYd[oWIQ8oj=<7ooTXCSo][17ojU/9_o<K2Sof[Tioh1N:Oo9IbOofJ`e
ogaS;?o7LBWobF0UokMi:oneOBkohZ@comRQ<ooKXCCog9ldomjQ=?o;Sc;o^W0[ola_9ooGSc;ofYXd
omZG<_o>Qb_oeiLbomN=:ooERBWofI4`okY]8_nmKb;oeXTWomZJ<?oCVS?o]G@ZomJ:;?oGUS7od8@Y
om61;?o<QB_o]FXRoka`8oo7ObWo]6XRojaM7ongLB3o[FXNojUJ7on]I1ooZV`NojYK7_n/GaooXfTM
oj1T7On[G1oo/6PPoiQO8OnKH1ko[VDRokU/9On4BR?oQ5HUolU^:?o2IbSo^68XokMU:?nXGROo/V4X
okaT:_n[GR?oaFLVoliZ:_o@KbSoaf@Yok=O:Oo?N3Coin7Aono_koofm_Kono_kooknoP0mooooo`04
ooo^g_ooYTkoogd5oon10A3ooh0000Googh0ooml0?ooYTgoonSBooomn`0Looooo`04onSbn?mTXlco
1fb^o`Q][Q?o1fb^00Ko0fZ/o`5Y[OmMWl[ofn_coocmo_onoooooooooe?ooooo003Tooooo`05on3V
lOn``MgoZkgJoj^mf_nga^000_noc><03Oo0cN?o`<gTokC4gonW^][oV;;Eog6JaomCRKkoDXRnoeV;
_omTT<;o:7Zfo`a^[ol6K:h03?l7K:h03Ol1JZgoDhVnoeN;_omFRkooGHo1oh6Wc_n/a=godMcZonOY
lOoTio7ohnOaon7Vl?oSi_000_oRio46on?Wl@07onKYl_oAfN[o[[oLoj^mfonU^MSog>C`oognoP07
ooooo`0:onK/m_na`MgoZ[[FojFdcooBa;_olL^Ioo?9T?odbiCom<bEooG<U@ComLfE0_ofcID3ooK>
UP;om/fE00[omljEok^PRonYTXOoZI>9ok:ALOoWQQ3ooh@>oonB9Ooo`H7oooG/1Oooool01?oMiO7o
]<GOojfog?n[_M/2ojbnf`04ojFifOnia^3oh^K`ooGfn@OonOWj00Ooo?_konGYl_n``=coZ[gJojFi
f?oFgngoo?gn04;ooooo00Woo_knoo[jn_oemOGok>c/on;Rh_oHf=Soclo?olW9bOo6a/H00_o4a<@0
L?o0/YooST8TojREC_n?LC;oRU@XofH_8?n_R3_ogJdmoj]D9Oo@RSooiKA>onc@COoW`SGol=YJoo7N
MOoZbekolMITom_EL?oDX53o/D4KokUe>?n2IS3obWhgoookP?nh]UgoZVlYom1l<Oo/i6SoTFddolQ/
9_oYb4Co[Y/lol1Z9_oSZ3Co`jhgoiYK9ooDN2[oaZ<eoi=];?o<IbKobWHYogmM;?o1MbcoiJTdoi]a
;on[Nc3ohZ@domfP=?oCUC?obgX/omF:;ooJVS?og9ldombJ<oo6OBOoe:8bom>@;OoDRRKof8h[olYm
9oo?PBCoe8L[omF<:ooMXSCodI0`om21;?oGTS3ochPZolIg9_oAQB_o`7LVoj]M7onlLR?o_WLSoj]L
7on]Gaoo]G@TokYm>?o4T57obimMolfSH_o3TUKo_H]7ojim<?n[JBGoZElOojER7_nII1goZElNojYT
8OnZIRCoNdhSoieR9?noJbOoaVLYok1L:?nGFbOoUE/Woj=N9on`HBWo]f<Uolm[:Oo2JBKob6TWol][
:_o7JRSohLZSon_[jooclo?onOWiooclo?ono_hnooooo`05ooo/f_ooZ53ooh@Boon10_ooO`003ooo
P0001OooO03oogP0oonXDOooi/goooWb01cooooo00GojO?gof2QbolCL[7o2Vj_o`AZ[@0Bo`M/[P05
o`1WZol0IJ[oI:?<olONkOoamo/0oooooomBooooo`00i?ooool03_oPi_7o/<7Moj^mf_n[_M[o]lKP
ol3=hoo1cNCo^lWQokC4gonL]mSoM9k;oeR;`?mDRKkoEX^o0_mGRkl01_mFRkooH8k1od:6_?lGL[;o
2Ff_o`E[[PWo1fb^00_o1Vb^o`1X[?mAR;koGHo1ofFCa?n8YloobMCVong_mOoUj?7ohnOaon?Xl@02
onGXl@03onKXlOoVjO7oi^Wb00Koi^Wb00OojNccom;Kjon_`=coZkgKojFif?oLi?3ooOkn00Kooooo
00WooochonCSh_n^/l7oZIfOojB=PooB[XWol/ZDooC<UOoec9D00ooecID00oofcIGom/jFooK>UP07
ooO>UP07ooS?U_nkX8[oZI66ojVDR_ncUgoojJMEoooG[@09ooooo`0<oocmo_o<enWo/<7Loj^nfon[
_M_o[;kKojVlf_nW^][obM?Von_^m?ogmoSonO[j1?ohnOX01ookno_oi>Waok30g?nZ_M[oYKWHomKO
kOoloOh0@_ooool02?omoOgonOWioo;bl_oZj^[ogmoOomGEeOo=cLgob<S80oo5aLD0L?nmY8KoQ5Dc
ohYc=on^OcGoSThZofm09?o<Z4;o_G4]omBHBoo/aeGojla4onJo=?oX`c_om^YeooWaOOonm7goc:mS
ojJ>C_nhCb?oc7TjojbVEOnLCb7oei13ooOhOonWU4?oag</on^n@?o<a5WoZfDZomnQ<_oQaD?o]8Pb
omJ;;OoZ^cSo/YLbok9M9ooUZCCo]ILcojmc;?o>JBOo_H/`ogU@:oo@NR[ofje=oh9T?onZKbcofXl_
omfR=OoJVS?oehl`omVH<ooLWS?og9lcombM<oo@Q2coaX`/ok9]9?neJ27oe8`WomJ::OoDQbSoeHL]
om>5:_oGU2gog:0com>6;?oDQbkoe90^okEX8Oo6MbKobX0VojmR8?nZG1oo^6`PolN=A_oWcIkom^cF
oogjm?onoO_oooonooooooono_goo_cioocil_oek]_oj]^jom^nSOnnVeWoZ6lZojUK7_nWGaooVF8S
ohiN9?nWH23o]VPVol9U:?n7BRGoN58VohQJ:_n@G2SoWf8WolM/:Oo4JRKo/EhPoleZ:Oo=JRSofJQ^
onOWioo_knoomOGeoo[jn_omoOe0ooooo`05oooXdOooYdooohTIoon00?ooOP003oooP0001OooNP3o
ogP0oon/F_ooilooooK]01cooooo00Koh>geoejPbolKM[Co2Ff_o`9Y[?l6K:hAo`M/[P05o`1VZol0
H:OoDi[7olWPk_o^mOT0oooooom@ooooo`00i?ooool03_oPi_7o/<7Moj^mf_n]_]_o^LOPokO7h?n^
`]goSjkBog6Kb?mRTlCoJ9O6of^Ib?mTTlCoFXg01?mGRkl01_mJS<3oHXo2ob]l]olGLk;o0fZ]o`I/
[PGo1fb^00_o1F^]o`1WZol9KJoo7g^gogBPbon?[M;o[[oLokG4g_oAfNWoj>_bonKYl@02onKZlP?o
j>_b0ooXk?85onW/lP07on__looDg>_o[[oLoj^mfonU^MSog>C`oognoP04ooooo`09ooofkOooilko
olJ;omZJConQSG?oZY66ojB>QOoB/8oollZE00?omLfE00?om/fEooK>U_ofcYH02?ogcYH01oogcICo
n<jCok^RTOnYVIKoZJBYokW2eOogool03?ooool01?oYk_Ko_lkTojk0g?nZ_=X2ojbnf`0?ojJjfOn^
_]_of>3]oo3am_oin?Won?SiooOhnOohn?Wono[jonCYlOn``=coZ[gJojFif?oFgngoo?gn047ooooo
01Woo_knooclo?ogmoOol?3`onKVi_oLg=codm?Colc<c?o7alOoaLG5olK6a_o7alOoZ8YVof91:_nQ
LBko]H8mohE18omgG2kod9PnomVWDoo^ce?ojLPmon[:@?o]dTooln5W00;onO9n02ColnQhoiEj?Onk
KcGo_Ud[onOIL?nINC[o`F4Xoo7DGoo;bFOo]X8combM>?oXa3oo_Im9oln=;_oU[cKoe;DnolnF<_oO
YCCoh;8gokB6<?o@QBkoikDgokBB<OnlJbWog90^ok>@<_n?ERWoeW/YolnTD?mfFcko`gTZolYW9OoG
TS7ofi`domVF<ooKW3<2ombO=00FombN<ooHSBooa7dYoj=F7OnSEAko/fLQomJ<9ooER2[oeHL^omF7
;OoDR2[ofihbomB<:_oBPb_oeXl^okid9?n/GQooaGPSokMZ8?ngKR[oiLFAoocil@cooooo01[oooon
ooKah_oQcJCoai]PojQ[9onAHb7oVF0PojUM8?naIbGo^V<WofY19On3GBOoSf0ZohAO:_nGHb[oag4/
ok5Y:_nkHR?ocVPZom1j>_oSgm7ojn_[oo;bl_ohn?Soo?clooknoT7ooooo00GoonG;oonXDOooSB3o
oh01oomm000?oon00005oomj0?ooO03ooj]FoooM^ooom>T07?ooool01_oFj?;oGj3;ob5k]_l5Jjgo
06R/o`I[[Q7o1fb^00Go06FZo`1SZOmJWLWoaMc/ongen@3oooooodkooooo003Tooooo`09on;Wl_ne
a=koZ[gJoijeeonI]=KoPZO?ofFFaOmTU<GoJ9O600?oJYS700GoK9W7ofVHa_mPTL?oFHg0oeJ;_`03
oeN;_`05oej=`?mMSL3o6gBbo`e`/?l2JZd00_l7K:h03ol1JJco06FZo`e`/?ljRkooMZkBolSOkOoS
j??o/L7Mojfofon_`=cod][Yon_^looXjo;oj>cbonW/lP02on[/l`04on[]loo[kO?oj^gcon[]l`Go
jngc00OokO3domKMjon__mcoZkgKojFif?oLi?3ooOoo00;ooooo00_oonoOoooF[_oo[5[oohD:ooma
0?oJQ2?oXYB2ojZCR_nTSXKod[2?oo?;U@02ooG=U@03ooK=UOofcYKomljF00KomljF00[omljEooO=
T_ofcI?omm>QooWL/onk^L7oZk[Goj_2honibnCon?[m3_ooool04ooKhnoo_<[Soj^mfonZ_=[o[;kK
oj^mfonS]mSo_/_RomoTkoodmOSonOWiooKgn?oinOWohnSaok30gOnZ_M[oYKWHomKOkOoloOh0@Ooo
ool02?ono_kon_[jooGemOo/k>cohn?SomWIfOo@d=3ob/[:0_o7alL0=?o8b<Soc<_8ogiTAoml?27o
_I8nok5_=OmcAAooX8E0ong<HOocgUWokmQConoEG?oZa5[olMEWooWbN_oil7goo_J1olBnI?n[Q47o
_ELXonoAJoo9aFKo[F0[omjS?oo^fekob;5BomZP>OoPZSGoh;Y0olfQ??oRZSGogjLeon:n>ooMZCCo
gjDeomb_=oo4Rc?oh:HdombW=OnnTS;ocW`[onN`=?nXPS3oYedXomMj:On`Oc7oN5@_olei:Oo8I2Co
bVhWom^H<_oKVc@4ombO=00ComR?;onkKbGoY5HNojAG7_neJB3oe8dZomF=:_oERB[oe8L]omB5:ooH
U2godi0]ol9d8ooERBcobh8XojYM7on_GaoobhTjooGYbP0Booooo`0FooK_gOoMbYko_9eRojQT8onX
Fako[fDTojQL9omdCRCoZFHSokYW:?nZIRgo]8=:ol6BGOn^HB7oaVHWolaU:OoL/G_oj>SXono_kooe
mOGon_[joogmoD?ooooo00GoonO>oonhL?ooURgoogh0ooml000>oon00006oomo0?ooN@3oogL0oonW
Coooek3ooo?W7?ooool01_oDiO7oJ:K>oc>6_?l7K:ko06N[o`I[[Q3o1fb^00Ko1V^^o`1RZOl0IZ_o
Fik9okGDj?o^mO[oooooodcooooo003Tooooo`08omoUlOnJ/mGoP:C<ofJCa?mLSl;oIIG5ofVHaomZ
VLL5of^Ia`06ofbIb?m^V/SoIiO6oenA`omHRkooEXZn0omGRkl02OmMS/3o?8>joaad/_l0J:co06>Y
oaei]_mFVlSoSkgKonken@02ooooo`0:om[Qkon/_]_o[;kKok31g?oCfn[okNodon[/loo[k_Coj^kc
onc^l`;ok>kd0_o/ko@6ong_m00Goo7bmOoHg^co[l3Loj^mfonU^MSogN_noogln_ooi/coolN?oonQ
A?ooN@3oogL0oomm0?ooO`3ofXPZoj:DPOnZTh[oY8j6om:`SoocbiGomLfEooK=UOofcYH01_ogcYH0
3?ogcYCon<b?ooS?UoohejWomn71ooW^g?okoOoo_<gWoj^ng?n[_M[o^LWQooSjo0oooooo01;omOOk
om3Jjona`]goZ;_Ioj^mfon/_]_oZ;_Joj^mg?o?f>Woj>[cooWhnOokn_[oh^Oaok30gOnZ_M[oYKWH
omKOkOoloOi1ooooo`0oooclo?ohn?Sol_;bonWYjOoOgmooeMGEolk>c_o9bLWob<S8olW9bOo<c<co
dlnnohQ@<_nVGbWo_Ie8ojEO:On3JB_oi=ebooWZL?oWc6Coj<=OomN8=?oGU3ood[=ConcEI_oklh3o
mNalojZQD_nmIc3ofJ5?oo[lPon^RTCoe8llonBb>ooWdU_og[a:on6]>OoMXC;ohklnon6d>OoMXS?o
h:XeonNo>OoOYSCogZ8com^]>?oMZCKogjHeomfZ=Oo:TC;ofiTaonF_=_nXOboo]EdUomb:;?nRMS7o
Qel_om9f9oo7HbGocWDYomFG<ooKVS?og9hd00;og9ld01?ogJ0domNA<?n`HB7oYETOojAG7_o9ORCo
^GPZolf8;?oKV2goe8H[omF6;_oDRR_of9L_okAV8Oo4MbCodXPYojmQ7onjKRWom^W901Kooooo01Co
k^C9okjCG?nUGAooZf4RoiAH9on;G2Co]F@QolmZ:_oARTgo^I1UojYS:_neH23oc6PXolmb<_oWh<co
k>c/oo?cloohn?Soo?clooknoTCooooo00GoonWCoonjMOooUbgoogX0ooml000>oon00006oomo0?oo
M`3oog/0oonWD_ooe:SoooG[7?ooool01_oMjo?oQ;KGocZ:_ol1J:co06J[o`I/[Q3o1fb^00Ko1F^]
o`1PZ?l2JJgoGZ3:ojo?iOoamo[ooooood[ooooo003Rooooo`0<on3]mOnPb>7oMjK>of2?`_mAQkgo
DHRmof>Ca?m/VLOoKI[7ofjKb?m^W<SoKic81Om`W<P03_mbW/WoLIg8ofRFaOmNSl;oEXZooeJ;_omG
RkooEXZooeR:__mAR;koAhc0ofnXconbdNKoo_ko1?ooool03?oIhNoo[;kKojbnfon``Mcoe=_Zonoa
m?o/k_?ok>kdong`m?o^koCok_3donk`m@;ok_7e1_o^lOH02oobloKof>3]ojo2h?n[`>7oY[WKom?6
/_ol]VgooiD[oomd0?ooN@3oogl000;ooh0000Woogl0omZ8:_nRU87oZY>:ojB>Q_oC/Hooll^EooK=
UOofcYH01OogcYH02_ogcI?on<b>ooS@V?ohfk;on^O>oo[bjOojoOoon_cooo_ko?nlb^42oj^mfP03
okW9hOohn_cooooo013ooooo013oi>[colCAiOn[_M_oZKcJojbnfon[_M_oYk[IokO6h?oGg^col_?g
onO[lon``=goZkgJojFif?oFgngoo?gn@?ooool02?ono_kono_kooKfm_o^k^koiNGUom_KfooBd];o
c<c<0_o:b/X0=_o=cLgod];BomG;/?nG@R;o^8`ook:8?on`KbOobkA>on:mF_ngJSKocXe3omN8<_oE
S3co^9E=ojQ[<OoXa6?ooo^3om;>JoneQ47ocGljoo;HGooOeFooa8doon>_?_oOZ3Gol=aLonFk?_oN
Y3?oh:lion_>Doo/c6cok]9ooo3GQoo^e87oj/Q^onJlDOoU^3goh:`eomfQ<ooOZcGogJLdomjU=?oL
YCCo[g`]olI^:?oUZS?oVg0`oi]Y;Oo@KRKoc6/Vokio;onhOBoofi<aom^K=0;og9ld01;og:0domVG
<oneIB;oXeLMoj]N7ooJT2SoU6DYok=a:_oPXS;ofIP^omB7:ooDQRcofI@]okid9On[G1ooaGPSol9d
8_oagK4Hooooo`0CooknoOo[gl7oa9aSoj9R8on?GbKoWV0Qok1R8?o:JBSocWHioimI;?nYFaoo`6DT
oleU:OoLZg;ok>c/oo7alOofm_Kon_[joogmo@16ooooo`05oooVcOoo^WCooi@Xoomg0?ooO0003_oo
P0001_ooO`3oogL0oomo0?ooYeCoolnQoooilAcooooo00Gof>SbohFfeoliRKko06>Yo`1VZ`0@o`M/
[P07o`Q/[_l4JZgo05nWo`U][omKWLWoZ/gSooWko@3oooooodSooooo003Pooooo`0=olONkOmh[m?o
?Hc0o`9Z[_lRM;;oG8booeN;_omER[koIYC4og2Lb?mbW/WoLYk:og>Ob@02ogBOb@0?ogBNbOmdWl[o
MJ3:ogJPb_mfWl[oMZ3;ogRRc?mbWL[oJIO5oeN:_om>QKcoF8^oog6Jb?n:ZM3o]lOP00Oooooo00[o
fN7_ojbnfon/_]_o/<7LomKMjooaloKok_3eonk`m?o^lOKoko7f1Oo`l_H4oo3amP09oo3bmoodn?ko
f^?dojnhc_nZZK?oYZ6]olJ=?_ojNP3oog`000Gooh0000Soogl0omZ8:_nRU87oZY>:ojB>Q_oC/Hoo
m<^EooK>UP?omljF00WomljEooO<T?ogbhoonMFSooSR`_ojkMcon_Ocoo[looojo?d00_ojn_X01_ok
no_o_L_Roj^mf_n[_M[o^LWQooSjo1;ooooo00oon?[lomkUlOnjb>7oY[WHoj^mfon/_]_oZ[cJoj^m
foo2c^?obmGWok31gOn[_M_oYKWHomKOkOoloOh0@?ooool0:OomoOgonOWioo?clooZj^[oh>3PomOG
eoo@d=3oc<c<ol_;boo>c/kodm?Com[Jf_o<]YKoVDdVolN^D_nSJBgo`YDnomje@_n/Cakoah4lombF
??o=PSWob9Y@oj=o?ondD2?ol=Y`oo?_OOnjYUGocXM2on6_@_o]dU_of/9Pomn[?ooMXS7oi;Hmoo3K
IOo_eh7om^NZoo[deOono?Koooon00Cooooo02Koo_ggoo[cf_odhZgojLI[on6`=ooOZC?ogZ@domZV
=?njNBcofY@_onF/=OnEJboo]7@/olaV9Oo=ObcoPEX`okif;?oLUC7og9lcombL<ooLWcCog:0dombK
=?njK2GoX5<MokU]8_oPWBgo]h``ojU]:ooMUBkogjXeomNB:ooDQB[oeX`[olV1:?nYFaoo[elNon[9
RQcooooo017olNK:olFWLOnJKB_oYU/NojiR8?o3JBKo`6<YoimD9?n^GR3ob6LWoleZ;?oZg;kolO7a
ooKfm_ojn_[ooOgmooknoP17ooooo`05oooUb_oo_goooi4Roomc0?ooNP003_ooP0001_ooO`3oogL0
oon21?ooY4cool>6ooo`h1cooooo00Goe^Oboh^kfOldQ[go062Wo`1VZ`0@o`M/[P07o`Q/[_l4JZgo
062Xoa5b/OmBV<KoY<WQoncdn@3oooooodKooooo003Nooooo`0FojO;h_mIWLWo:h:jo`1X[?l0IJ[o
06N/oc=m]omMSL3oEh^ooeF9__mXUlKoM9o:ogNQbomfXL_oN:;;ogVRbomhX/_oN:?;ogVSc?mjXlco
Nj?<ogZTc0;oNZC=00WoMj?<og:Nb_mgXL_oR:_@oiB_donT^MWo[koLol;?i?ojo?d01_ooool01ooI
hNoo[;kKojbnfon``Mcoe]g[oo?dn?o`lOH00oo`l_H00ooal_Kol_;foo;bmP04oo;cmP0:oo;dn?ob
mokol_GiooGYeooIa[Co[YbFojVBQonUTXkob8/jooZ10`Kooh0001;oogl0omZ8:_nRU87oZY>:ojB>
Q_oC/Hoom<^EooK>U_ogcYKomlfDooO;Soogc9;on=Z_ooWZeOojl^Kon_Wioo[mooojno`4oo[jnP06
oo_knonmbn;oZkgJoj^mf_nibN7on?[l5?ooool03Oo_l_Soe=k/ojZlf_nW^mWo[;kKoj^nfonY_=[o
[;kKojfog?n/_]_oYKWHomKOkOoloOh0?oooool09Oono_kono_kooKfm_o_knooi^KVomcLg?oDe=Co
clo?olg=cOo?clooe=CDom[Jf_oRh^;o]He[okJ4@?nWRDSoUe`Zom^iAonlKBOoaGhnon6U@ooAT3Wo
di]?okFYE?nXD2;obX4hoo_bN_oAbF[obi]?on6]AooNXc7olMaVon[=DooV^Tcol]b@oo[bc_onoOH0
3?ooool08oooookonNo<on[6KooNYCCogJ@com:E<OoOYSCogJ@dojAg<?o6N2[odG<XokZ1<OmcC33o
bWLYomfG<OnaP37oa8LbomfN=?oLX3CogYddokmc:?nRE1gobWlZomnT<_oJZc?o[7PXomF7;OoMXc?o
fIX`okm`8ooCQbWodHLXojeM7oo>TT_oo_ce01kooooo00ool^_GolFQKOnTFAooZelNol1Y9OnjH2Wo
We@SokMR8Oo<IROofIMIoo?bkoofm_Kon_[jooclo?ono_h0BOooool01Oooi<WoolVCoonI<_ooM@3o
og/000kooh0000Koogh0oomh0?ooP03ooiThooo2Q?oomN/Looooo`05om;Ul?n>_M[o:h6io`1NY_l0
Ij/04Ol7K:h01_l3JZgo06:YoaMf/om3T<;oTKkKooCho?ooooooA?ooool00=_ooooo00oofn[cohNh
f?m5TL;o6gReo`1VZol0J:co1V^^o`M/[_l1JJgo<Wfgoef=`?mGRkooE8Vnof^IaomiX/`00_mjY<d0
1?mkY<goO:G=ogbUcOmlYLd3ogfUc@0<ogbUcOmhXl_oMJ;;ohb_don]a=go`]3Tol[Ei_nd`moo[KkL
ojVlf_nocN?onO_m1_ooool01_oIhNoo[;kKojbnfon``Mgoemk/ooCen0;olO;f00?ol_;foo;cm_oa
loH00_obloH03_ocm?OoloCfoo?en_odn?oolo;`oo?QbOoae:gomM6NomZfSOn]ThCoZI:6ojFDT_o8
S3conX431_ooP0004?ooO`3ofXPZoj:DPOnZTh[oY8j6omJcT?ofc9Kom/fCooO:SOogd9[on>30ooS]
g_oim>oonO_moo[lo_ojn_/6oo[jnP06oo_knonmbn;oZkgJoj^mf_nibN7on?[l5Oooool01OomoOko
jNkfol3>i?nV^MWoZ[gJ00Co[;kK00?oYKWHomKOkOoloOh0?oooool08_omoOgonOWioo?cloo[jn_o
h^;RomWIfOoBd];oclo?om3@d?oDe=Cofm_Kon?ShooYj>?oZG9;ojB<B?mT>BOo]hhnolR8<oo4O3co
hjm:on>g?ooFWdSogMQaojI^<oo1J2[ojl]Eoo7[N_oI_V;oh[5=omjS<_oQ[CcomNAiooOZ[Oomn^/A
ooooo`0Pooooo_odhk;oh[=7omnX=?oOYCCof9lcokf:<Oo?N2Wog9D`okF0<_n6ERkocW@Xom^D<On:
HC7oUVDaon2L<ooLWSCogZ0eol=i:On/GR3oeHdaom^J<?oS/CCoai8^oln3;?oIU33ogjDcokUZ8_nf
JR7odXHVol5c8ooeil@Pooooo`0>ookno?oE_YOoXf<ZojQM7OnmJ2?o/edYoj5E8_o2IBCocFDYoncD
Z_ohn?Son_[jooclo?ono_i;ooooo`05ooo/f?oocI_ooi@Yoome0?ooO0003_ooP0001_ooO`3oog/0
oon31_ooVSGool:5oookmQcooooo00Goe>GaohnnfolTOKSo05nVo`1X[00Ao`M/[P06o`=Z[Ol0IZ_o
4G:aod:>`OnF`MgooOgooooooom2ooooo`00fOooool01_o6gNcoI:?<obR0^Ol?LK7o0FR/o`AZ[@Co
1fb^00Wo0FV]oc9m]omMSL3oEh^ooeB9__m]VlSoO:C=ogfVcOmnY/h00omoYlh04?n0YlkoP:S>oh2W
c_mjY<goOZK>oi^he_o1dNCocMOXomGMjooHg^coeMg[ok?2g_n[_M_oZKcJoko=hooinod6ooooo`09
omWQkon/_]_o[;kKok31gOoHgncomOGhoo;cm_obm?Kol_Cg00;om?Cg013om?GgooCen?odmogom?So
ooC]hoocf[Oolm2Qoo?<V?ocbY;om/fEomZhT?n]UHOoZI:7ojFDT_o8S3conX431_ooP0002oooO`3o
fXPZoj:DPOnZTh[oYY26okjPR?o/`H[onmRWooSYd_oil^_on?Kd00;onOWk0_oinOX7oo[jnP06oo_k
nonlb^7oZkgJoj^mf_nibN7on?[l5oooool01?ognOcoh>Kbojjog?nV^MP3ojbnf`03ojFif?oFgngo
o?gn03kooooo00Ooo_knooclo?ogmoOol?3`onOWiooNg]koe]KF00;od];B01SoeMGEom_KfooShn?o
j^[ZonKNc?nFJScoFd@Xofa2:Oo<Vd;oci14onNjD?oYackogkA6oo?YO?ngWTko^f@Zomn/?Oo[bE?o
l^ajonS6EooQ[C[ok<]YooS^_OonoOHDooooo`0Nookno_ojlmkoil1VomfS<ooKY3CocY4aomB6;OoT
ZCGo/WdboiIM;OoBLbOoeY@iogiF=OnNJS3ofhd^omZI<ooNX3GoaWh[okaa9ooITS?oeXh^omnY<ooQ
[3?oeX`^omF9;ooNXC;oaG`VojQI7ongJ23oiKU_8oooool03?o_i]3o[81<oj1J7oniIb;oZeXWojMH
8_o9IRGoeH93ooSejOolo?cooOgmooknoTgooooo00Gooo3PoooAXoooTB?oogL0oomn000>oon00006
oomo0?ooO@3ooh@9oonG;Ooo`XGoooci6oooool01_oloOkog^cdoiO2gOlPN[Ko05nVo`1X[17o1fb^
00Go1F^]o`9Y[?lBL[;o>8Vnoi>og03ooooood7ooooo003Fooooo`07ookooonZcNCo?Xg0oaMf/ol:
KZoo1F^]o`I[[P06o`M/[P0:o`5Y[OlbOKOoGHg0oeN;_omDRKkoL9c8ognXc_n1Z<ooPJ[?oh:Zc`;o
Pj[?00KoPZW>ogjVcOn;[m;o[/CNolcGiooEgN/3om[Pk@07omWPkOoGh>co/l?Noj^mfonY_=[o_lgS
ooWko@06ooooo`0BomWQkon/_]_o[;kKok31gOoHgncom_Ohoo?dmoodm?Oom?GgooCen?oem_WomOWn
ooCfn?odiMCom=J_oo??WOocbiKollZD0_ocbiD01oogcYKofkR@ojfEQonYTXOoYIBBolR<??ojP@<0
1_ooP0003?ooO`3ofXP[oj:DPOnZT8CoZI63oj^QXOnc^LOoeMOPoo_knOoknoconOWjooShn@;onOSi
0_oinOX5oo[jnP03ooWin_ojn__o_<[Q00;oZkgJ00?o^LWQooSjo?ooool05oooool02Oono_kol_Gi
olcGjOnW^m[oZ[cJojbnfonU^MSoe]o]oocmoP0nooooo`0OoogmoOoinOWom?Cdonc/k?oShn?ofm_K
omKFe_oDe=Coe]KFomcLg?oShn?ojn_[oo7alOoA`ZKoJT<WofHi6on:JCSohK9Bon_7D?o]cdGokM9@
ooW^NooHcfco]Fh`omfW?ooNYS?ol=MSooOZL_o^cfWon>fhookmn00Gooooo`0Mookno_oknO7ojLUj
omfT=?oJVS7og9hconBY=OncP3?oYF@[olm]9Oo?T3ooMe4hojmc;oo@M2Ooe8X_ombL=?o?RBkocXH^
omR@<_oFRRoofi``on6_=?oHU2coeXT]omVB;oo@Rb[oZU/NokEY9Ooil=H09?ooool02_oim^_o_Z5b
oiII8_ncIB7oY5LUok5M8oo=IBKojL:>oogmoOono_i?ooooo`06ooomo?oolnOoom:Soon<6OooNP3o
ogd03_ooP002oomo0004oon42_ooU2Wool:6oooim1_ooooo00Kon_cmonK`monbd^Ko;H>jo`1TZ_l3
JZdAo`M/[P05o`I[[_l5Jjgo3g6aoc>6_?nK`mh0ooooooloooooo`00e?ooool01_oTkoKoL:[Aoaei
]_l?LK3o26b^o`I[[PWo1fb^013o0FV]oc9m]omMSL3oEh^ooe>8__mbW/[oPjW?ohF/d?n5ZlooQJc@
ohB[con2Z/koUkGEol7AiOoHg^cof^7]1_oMhnh01_oKhNgo]<?Noj^mf_nY_=[o_lgSooWko@Kooooo
00oofN7_ojbnfon/_]_o/<7Mom[OkOohn?Wom?GgooCen?oem_WomOWoooGdl?oehLKom=6PooC=VOod
c9D01Ooec9D01ooiciKofkV@ojfEQonYTXOoYIBBolR<??ojP@<01_ooP0003?ooO@3of84EoifBMonY
Y[Co[;S@ojbmf?n/_]_o[KoLokg:h_o[k_Goo?ckooWinP;on?Si0_oin?T6ooWinP06oo[in_nlb^7o
ZkgJoj^mf_nibN7on?[l6_ooool00ooloOkojNgeokW8h@02ojFif003omKOkOoloOkooooo03cooooo
01koo_knooclo?ogmoOol?3`onSXj?oPh>3of][JomOGeooHf=Sog=cLon?ShooZj^[olO7aooOgmonQ
RW7oRDHPog=A8_o;^f3oo>e/ooCTI_o_eVWomnQhoo;^O_o0TDKof9`kon2Y=OoOZ3Soln5eooS[/Oon
o?DJooooo`0KoogmoOokn_OojL]oombP=?oNYCCohjTdok=o<OnfJBWod7<WolZ5<?maBC7o_W/^ole^
9Oo;L2Oof98bomVE<ooGTC;oeXdaomJ<<OoGT2oohJddomRG;Oo>PBKof8h^omF@;?n^GQkogK9a02Ko
oooo00Woo_klom>oVOn@GRSoYF4QoimF9?nmHBGodW<booWafoono_h0DOooool01_oooO_oooO`ooo<
V_ooVC?oogX0oomo013ooh0000Cooh<7oon95?oo]F_oooSa6oooool01_omo_kolOOjojo@iOlXP;Wo
06N[o`E[[A7o1fb^00Go1V^^o`M/[_l;KZoo;8:koj;8h03oooooocgooooo003Aooooo`05oo_mo_nk
enWoA932o`U][ol5Jjd03Ol7K:h03ol1JJgo<Wfgoef=`?mGRkooDhRnog>Nb_n6Zm3oQjc@ohR]d?n;
[m;oZl?Lom;LjOoQi_3ognC_on3Uk`02on3Ul0CohNG`00Ooh>G`omkSkone`mkoZkgJojVlf_nocN?o
nO_m00Kooooo00KofN7_ojbnfon/_]_o/<7Mom_PkOohnOX2ooGfn003ooG]hOodf;3omLbF00WomLfE
00OonM2FombiT?n]UHOoZI:7ojFDT_o8S3conX4300Gooh0000Kooh84oonN??oofK7om_CdolWFjon]
_m/4ojbnf`05ojfnfoo=e^OomoSioo[jn_oinOX00_ohn?T6ooWhn@06ooWin_nlb^7oZkgJoj^mf_ni
bN7on?[l7Oooool01?oJh^ooZ[cJomCNkOoloOhmooooo`06oogmoOojn_[om?Cdong]kOoUiNGog]kN
0_oJf]X05?oMgMgohn?Son[Zj_oalO7omoOgoo[imOnEGd;o]6/Soj6@A_oim7oog[aPolN0@?oMYd_o
o?N1om[3HooCW3gohJ`ionBfAoodhYSooOSY7?ooool04Oono_kooOgmooWhmOoXb7gogJ8don:X=?nj
Q37o`FXWomVA;oo=SS7oN4l`olUo;Oo;K2GobFXUolmj:_oIU3?oei0b00;oeXda00SoeHX_omfR<OoK
X37o]VHQolQl9OoGSR[o`WDUooO[cbSooooo00OoimZloiQ`?_nHGB;oWeLTolMR9_oRZFkoooon05Go
oooo00?oom^foonG;oooO@004OooP0001?ooO`3ooh85oonfK?oom^hMooooo`03ojc>i?lUO[So1F^]
01Co1fb^00Co06R/obAm^?nPan3onO_mooooooljooooo`00]_ooool01?omoOooe>Kaok?CiooloOhD
ooooo`06ooWkoOodn?_oS[cJobf2^ol0IJ[o16^]3ol7K:h03ol1JJgo<Wfgoef=`?mGRkooDhRnogNP
b_n;/=7oVKOGok[>h_oMh^goi>Obon?WlOoQi_3oh^K`on;Wl@07on?Wl@06on7Ul?nea=ooZkgJojVl
f_nocN?onO_m1_ooool02_oIhNoo[;kKojbnfon``Mgofn7/ooWel?oei<[om=6RooC:SooecI@3ooG=
U@?om/fE1?ofcYH01oojd9KogKZAojjER?nYTXOoYIBBolR<??ojP@<00_ooP0001?ooP`KoohTAoonb
IOook=/4ooooo`03onW^m_nib>7o[KkK00?o[;kK00GoZkgKok;3g_oNhnoon_[kooSinP07ooWinP06
oo[jnonlb^7oZkgJoj^mf_nibN7on?[l7_ooool00oobm?[ojo3goocmoP0looooo`0Kookno_olo?co
n?Shoo7alOoZj^[ohn?SomkNg_oMgMgogmoOonCTi?o[jn_olO7aooOgmookno_oimW1oii<8_o=UcCo
i/]Eokn4>_nU@Akoc7d[ong>F?oekg_ogKI9onBc@Oo^dgKon_;@01oooooo01[oo_knooclo?ohmoKo
ilV1omnU<oo:SC7oc7d/on2V=Oo>Sc7oQeT`olan;?o:JRGobF/Uola`9ooITS7oehlaomJ<<OoGSC7o
eX``omRC;ooOYc?o^V`SojUL7oo5N2?ohZmPoooooRWooooo00KomNkLoj^:G?n@FR;oXEPTolaU9ooa
ejYGooooo`04oooH/?ooURgooh07oon00A3ooh0000Goog`0oon00?oo^WKoooGZooomnP0Looooo`03
oik6h?lSO;Oo2Vf_01?o1fb^00Ko1V^^o`1TZ_lZPK[oR[[Ioo;hn_okoOkoooooocOooooo002foooo
o`05omCUl?l3JZco3g6`ojO;h_ofn_`04?ooool01oolo_kolOOjomGWlOm[Ylko1V^^o`1VZol4JZd0
4Ol7K:h03?l1JJgo<Gfgoeb=`?mHS<3oF8^oohj_doo4dnKoin[bonKYl_oTj?7ohnOaonCXl@;oiNSa
00?oiNWaonGYl_oUjO801OoUjO801_oSio7o]LGOoj^mf_nY_=[o_lgSooWko@Kooooo00SofN;`ojbm
f_n/^mGo/;S=om[9]ooid9Oom<V?ooG<U0;omLfE00?om/fEooK>U_ofcYH01oogcYH02ookdIOog[ZA
ojfER?nYTXOoYIBBolR;>_ojPPKoohL>oonD:Oooahooookm00Sooooo00?oeMg/okC4gon]_m/00_n/
_]/01_n[_M_oZ[cJol3=hooZk??on?SiooWinPGon?Wj00KonOWjokc:hOn[_M[oZkgJokW9hOohn_aM
ooooo`0JoogmoOojn_[om_Kfono_kooXj>Sohn?Son3Ph?oQhN7oiNGUon_[jooalO7omoOgoo_knoom
o?co/XARok9Y9OoX`d[of9`dojQ37Oo9N2oogjLdoo7KIoodiVWojliOooO[/OonoOPQooooo`0Hoogm
oOojn_[om_C`onBoJ?oHUc7ofY/con2X=Oo=T3;oU68`olmm:_o9JRGobV`Uom24;_o6R2oofi/`omRC
<_oFS37oeXdaomJ;;ooOXc;oa7/WojQJ7on^Gaool]jc:oooool01_olnO?oaZf0ohaH9?nYF2CoeGdl
oocgjESooooo00Goom>XoonH<?ooP`cooh00oomo000?oon00005oomj0?ooP07ool23ooodj?oon_D0
7?ooool01OnG`]go9Gnio`e_/?l5Jjgo1V^^017o1fb^00Ko16Z]o`1UZ_l?LK7oUL3Lon[cn?ojo?ko
ooooocGooooo002eooooo`07om_Ylol/P[[o06J[o`9Y[?l4JjgoN;3Con_cn@0=ooooo`07ooOko?oL
j_CoYl_Sod^EaOl0HjWo06FZo`E[[@0Ao`M/[P0:o`I/[_l3JJgo06R/ocV1^_mZU/GoN9o;oijde_oC
f^[oin[bonKYl@;oi^[b00Coin[bonS[l_oXjo;oj>_b0ooXk?84onW/lP07onS/l_oVj_7o]LCOoj^m
f_nY_=[o_lgSooWko@05ooooo`07ooojm?oCe]SoZjfmoj^JV?n^Th;ofkF;ooS@U@02ooG=U@03ooK=
UOofcYKom/jF00WomljF00Sonm6GomjjTOn]U8OoZI65ojFDT_o9UToonZiMoooK]Pcooooo00ComOOk
olOCionb`mkoZ[cJ0_n/_]/01_nX^mWoZkgJom7IjOo`l_Gon?SiooWin@?on?Si00KonOWjokc:hOn[
_M[oZkgJokW9hOohn_aLooooo`06ookno_olo?conOWiooCdm?o]kNgoj>SX0_oTi>@04OoWinOok>c/
oo7alOogmoOono_koogmoOo/hm7oSdDSomFS??oU_DKo/58PokmV:OoPYSKoh:`kooKYL_ogk9Soo?SS
02?ooooo01Soo_knooclo?oinOWol^kNon2^C?oMXcCoh:LdoljA<_nSKS3odWXXolUY9OoEPRcoYg8a
ojI/;OoNV2koh:deomVF<ooFS37oeX/`om^G<?o=R2_oZETNol9o>_omn_4]ooooo`04omg<YonBHBco
ZULTonVkQE[ooooo00Goom:UoonP@?ooRa[oogl0oomn000>oon00006oomo0?ooN03ooh85ooncI_oo
jM;oooSb7?ooool00onD_mgo=8Nloa9b/P02o`=Z[A7o1fb^00Ko16Z]o`1SZOlFMK?oUl7Momg[m?ok
oOkooooooc?ooooo002dooooo`09om_Zlol`QK_o06>Yo`Q][_l7K:ko0VV/o`1UZ_mGVlSofn[d00[o
oooo00Ook?Ciol_Pk_n5]]Ko7g^fo`1QZ?l0I:[o1V^^017o1fb^00co1F^]o`1X[?l3JZgo8WbgodbF
aOnC^=So//;Nok;1gOnZ_=[oc]OXonOZlOoXjo82onS/lP05on[/l_oZk??oj^ccon[]loo[kO<00_oZ
kO<4on_]l`07on[]looWjo;o]/COojZmf_nY_=[o_lgSooWko@03ooooo`09oooej_oohlOookafok>K
F_nZSgooZY:4ojnFR?oK^93onM2F00;omLfE00?om/jFooO>U_ogcYH02OogcYH01ookd9Cog[V?ojfI
S_nYViWoYJ6/omGKgoolool03oooool02ooSjO?o^/WQojfofonZ_=[o[;kKoj^mfonU^MWo^<OPomkT
koocmOOon?Wi00;om_Oh00KomoShokc9hOn[_M[oZkgJokW9hOohn_aLooooo`0Hookno_okno_on?Sh
oo?cloo]kNgojNWYonSXj?oYjNWokNg]oo;bl_ogmoOono_koogmoOono_ko_Z60ojAL9?o]c53o`gX/
ok9>8ooLWSOogZ@bonBgA?oil;Coooon9Oooool05_ono_kono_kooOgmoo]gkCogJ8domnV=?oBUS;o
/GP`olmc9_o?MRWobhPaogI><On^KRcofHX]on2[=?oQ/SGof9<`omN><_oGT33odhh]ojYJ7_oO]WP_
ooooo`04onSK^onLKS_o]f8Yoo_dge_ooooo00Goon31oonWCoooSAcoog`0oomn000>oon00006oomn
0?ooN03ooh00oongL?ooi<[ooo[d7?ooool01OnG`MgoBI?3oaYg]?l1J:co0fZ]017o1fb^00Go0VV/
o`1QZ?lPNkKoU/7MomOWlP0Cooooo`03onkenOoooooooooo0?oooooo7?ooool00;?ooooo00Cok_Gj
ocB7_Ol0IJ[o26f^0ol7K:h01?l5Jjko062Wod:=`?o6gN`7ooooo`06omk[m?n/cNCoGZ3;o`]_[ol0
G:Go06R/4_l7K:h04_l3JJgo06J[o`U][olaQKcoJJK>ol3Ij_oooooolO7gok72gOn[_M[oYk_Iom3H
jOoXjo;oj^ccon_]looZkO?ojnkconc^l`;ok>kd00?ok>odong_m?o]ko@01Oo]ko@03OoZkO?o]lGO
ojZmf_nY_=[o`<kUoo[oooooooooongKoooF[?ooZeWoogh0oome0?n]SCl00_nZThL01On_UXSofkR@
ooW@U_oecIGom/fE00SomljF00_on<nFooS?UOohcI;on<jDoocHYOoNb:oo[[;0ojZlfonU_=oogNKe
oogno`0@ooooo`0>ooWko?oAfn_o]<COojNkfOn[_M_o[;kKojRkfOnY^m[oam;UonCXlOofmOSon?Oi
ooOgn?nlbN42oj^mfP03okW9hOohn_cooooo05_ooooo00GooOgmoo_knoogmoOolo?conk^kP02onc/
k00?ono_kooclo?omoOgoo_knoomoOgoo_knooOcj?n6CC;odj4oomb]@_n^Baooe8`comnX=OoP[C_o
m^Vk02Sooooo01GooOgmoo[jn_odm?CoiLMnomfR<ooGVc;o`7h_olib9ooJT2oo_7/^og59<?nhLb[o
eX</om^M<OoS^CKof9P]olj1:ooIT37oeHh]okIW8OochK/0<?ooool00ooflN3o]XaJomNVK@1Moooo
o`05oooL^?ooZUGoohdJoomj0?ooOP003_ooP0001_ooOP3oogL0oon21_oo^G?oon73oookmacooooo
00GoZlgSoe6IaolIM[Co06J[o`=Z[@0Ao`M/[P05o`1W[?l0H:So:H2ioiBog?oBiO404?ooool00oo1
fn_oI:?<omCVl@3ooooooagooooo002booooo`03onofn_mQX/co06J[00Ko1fb^00Go26f^o`1OYolR
NkKoY<WQoogno`03ooooo`07okcHjOn4]mOo@8g1o`1VZol0HJSo0fZ]o`Q][P0Ao`M/[P06o`1X[?l0
HJSo6WRdoe6Haon?_M[of^Wc0oooool01_oOi_7o/<7Moj^mf_nW^]Wod]WYon[]lP;ok>kd00KokNod
ong`m?o^koCok_3donk`mOo^lOD7onkamP0=ong_mOnga^3oZ[kMojZogonkbMcolmjoooo1P?ooVcSo
ogX0oomg0?ooOP3oogl0ojj@A002ojZCQ`05ojnFR?oK^I7onM2FooK=UOofcYH01OogcYH2ooS?UP0<
ooS>Toohc97omm2GooSJ[ooii<Ooo_GVon3Wl_n_`n?oZkkLojFif?oLi?3ooOkn4_ooool01?oYk_Ko
a]?Wojk0g?nV^]P2ojbnf`06ojFhf?nb`]goc]OXon[]m?ojnOWo^lWQ0_n[_MX00onibN7on?[loooo
o`1Kooooo`0EoogmoOojn_[omoOgooCdm?oalO7ol?3`oo7alOodm?ComoOgoo_knoomoOgoo_knoooo
ooo:^9SoUeTXon_9D_ngGbGobgP^on2Y=_oQ[c_om^Vk02Wooooo01Goo_knooclo?ogmoOol>gTon2b
DooKWS?od8H_om>4;_oOXS?o`H4^ogE;<?o0MRWodgl[omNC<?oR]3Gofj0`okIT8Oo9ObSofI0^om>?
>_omn_40<Oooool00ooln_GodK:4ooCTa01Nooooo`05oooJ]?oo[Ugooh/Goomf0?ooO@003_ooP000
1_ooOP3oogH0oon63Ooo/fWoombioookmQcooooo00Go[<kToefObolDM;;o06>Yo`=Z[@0Ao`M/[P05
o`1VZol0H:Oo:h6johRhf?o?ho003?ooool01_o_mO[oUL3LoaEd/ol0H:Oo<HFkonG_mooooooo7?oo
ool00;7ooooo00?ol?KjofJTcOl0IJX02?l7K:h02ol8KJko06BZoa1b/Omn/mGodNC`ojW<hom^ZM3o
7gZfo`1RZ?l0IJ[o1F^]013o1fb^00So26b^o`AZ[Ol0IJ[o062WobIn^?m[Yloo/M7UonkfnPGooooo
00Koh>Kaok31gOn[_M[oYk[Iom?KjOo/ko@2onk`m003onkamOo_lOKol?7f00Col?;f1Oo`lOH02_o`
l_Ook_7jokO9i_nZ^=;oZZg0okFTT?oZT2CoogL0oomj0?ooO`02oon00008oomo0?n^T4CoZY>7ojZC
Qon_UXSog;VAoo[AU_ofcYH5ooO>UP0?ooS?UOohcI;on<b=ooSCX?ohg[Won>[Eoo[fl?ojo_ooo_oo
on3VlOn_`=goZkgJojFif?oLi?3ooOkn01?ooooo00oooOgnomoVlOnmc>;oZK_IojVlfOn/_]_oZ[gJ
ojJifOnlbN;ofn3/okS7h?n[_]_oZkgJokW9hOohn_`0G?ooool01?omoOgono_kooShn?ofm_H2ooCd
m00>ooKfm_ohn?Sono_koogmoOono_kooooooo_il_n0ECcodZQ7olj>>Oo1IBOoh:Hfon:b>oofjKX[
ooooo`0CoogmoOojn_[om?Cdon_Q`_oLXCWoei8aomZI<ooQYcCoahD]ogY?<?o6MbSodWhZomN?<OoN
Z3?oh:XcokY[9?nZG1ooaW/UonRnL`0cooooo`03ooono_oek=Woookm05oooooo00GoomRaoon^HOoo
R13oogL0ooml000>oon00006oomm0?ooMP3ooh/Foon[GOood:7oooci6oooool01oojo?koZ/gSoe^M
b_l=L;3o066Xo`AZ[Ol8K:h04?l7K:h01Ol0IZ_o06:Xoc:5_?n3]]Oo`m_[00Wooooo00Sob=o]oefN
b_l0Ij_o06N/o`Q/[_l0IJ[oFik:ooknoooooooo6oooool00;7ooooo00?oJjO?o`1X[?l6K:h02Ol7
K:h01ol8K:ko06R/o`E[[_lfR;go57Bbo`1QZ?l1J:`04_l7K:h01_l2JJco062Wo`=Y[OloSL7oS;_I
ol?Kj`Sooooo00Ooh>Kaok31gOn[_M[oYk[IomCLjoo^l?Gol?7f00?ol?;f0_oal_H2oo;bmPCol_?f
00[ol_Cgoo;fo?oam_gokNOOokJ`/onYW9_oZ9F?okF<H?o[P@Googl01?ooP0002?ooO`3o[Y14ojZC
QonZThOo[iJ8ombiTOojdIKom/jF0oogcYH04OogcIGoml^@ooO=TOohejWon>?4oo[^goojn?Gon_go
oo[koOojn_[oo_glon3Vl?n_`=goZkgJojFif?oLi?3ooOkn01Gooooo00OoloKjomKOkOna`]goY[WI
oj^nfon/_]_oZ;_J00;o[l3L00Co[;kKoj^mf_nibN7on?[lG?ooool00oomoOgoo?cloo[jnP03ooSh
n004oo[jn_okno_ooOgmooknoP;ooooo00OoelV[oi5M;_oR]dko_V0VomfO=OoS]Scom^Vj02cooooo
01?oo_knooclo?ogmoOokno_onC;RooIUc;ogZ<domnV=?o<RRgoQ5D`olQf9ooAO2[oehhaomZI<OoS
/CCo`WDVojQI7onbHb3om>:j09Kooooo00KooogjoooI]?oo^gKooh/Hoomd0?ooO00>oon00005oomm
0?ooMP3oohD:oonWE?oodJ<07?ooool01ooamo_oZlgToeNKb?l5Jjgo062Xo`E[[Ol8K:h04?l7K:h2
o`1UZP03obV0^Om]ZLooaMc/00Kooooo00CoY<WQobb1^_l0I:[o16Z]0ol7K:h00ol5JZgoP;CFoooo
o`3ooooooa[ooooo002`ooooo`03oh2ce_l8K:ko1F^]00co1fb^00?o1F^]o`1WZol3JZd04_l7K:h0
1_l0Ijco062Wo`ma/OmSX/co/m;Vomk[m0[ooooo00Koh>Kaok31gOn[_M[oYk[IomGLjoo_lOD2oo7b
mP0Doo;bm_obloKol_?foo7cm_obloKolo?goo?dm_ocm?OoloGiooChooocmOOolnKDoo7G/oo^cZ;o
]Y^7ojR@PonXTX[o]I1Yon^42oooO`04oon0000Boomo0?n^T4CoZY>7ojZCQon_UXSog[^Boo[BU_of
cYKomljFooO=U?ogbXgon<fDooSJ/?oik=Oon_?Zoo[jn_ojo?kon__l0oojn_X01oonoOcoh>K`ojo0
gOn[_M[oYKWHomcTl?omo_h05oooool01_o]l?Oob=?WojRkfOnY^m[o[;kKoj^mf`;o[;kK00?oZkgJ
okW9hOohn_`0G?ooool00oono_kooOgmooclo003oo_kn`03ooclo?omoOgoo_kn00;ooooo00OonoWb
ohMNAOo>YTgobgXbomN@<?oT^3_om^Ri02kooooo01;ooOgmooWinOobl_;ojNOQomn`E?oMXc?ogjHd
om6@;_n@GBkobWDWolmh:?oGSc7oei0aon6]=?o9P2SoZ5PNolF5@?ono?FHooooo`06ooono_ooi<Wo
okmooon95?ooM@3oogd03_ooP0001OooOP3oogT0oon84?ooXTGoom:V01cooooo00Ook?Ciok?Bi_mK
W/[o06R/o`1OYol3JZgo26b^00oo1fb^00Ko1V^^o`1X[?l0IZ_o:82iofNUc_o;h>h2ooooo`05onC`
momSXlco3g6ao`1WZol6Jjh01?l7K:h00ol6Jjko3W2aoiS2g@3ooooooa[ooooo002_ooooo`03ohZj
fOl=L;3o1F^]01oo1fb^00Oo1V^^o`1UZ_l0H:Oo8GbgohZifOo<hNook_Gi00cooooo00Koh>Kaok31
gOn[_M[oYk[IomGMjooalOD3oo;cmP0Coo?dmoodm?OoloCgoo?emoodmOOom?KmooCiooodl^goln35
oo?E[?occYgol/VAono8T_nfW8WoZ9:7ojRCRoneT6Wojh@;oomo0004oon0000@oomo0?n^T4CoZY>7
ojZCQon]UHOocjj>oo[?U_ojd9;om/Z<ooOAW?ohhlGonNoQooWekooin_con__loo[jn`Gon_[j00Oo
o_glon3Vl?n_`=goZkgJojFif?oLi?3ooOkn01Sooooo00Gon?Wlon;Yl_ngan3oYk[Ioj^mf`02ojbn
f`03oj^mf_nibN7on?[l05cooooo0_ono_h4oogmo@;oo_kn0oooool01_o<^Y[oTV0eomZOBOoBPbco
i;XkooKW]boooooo017oo_knoo[jn_oemOGok>c/on?G/OoLX3GogjHdom>F<?nNIbgobg<Volec9ooG
Sc7oeXhbomfP<OoASR_oZUTNomfcM`2Kooooo`06ooolnOooim3ookmooon63?ooM`3oogh03_ooP000
1OooOP3oog/0oon:5OooXDCoomF[01cooooo00Kojo?iokKDiomUY<go2Vj_o`1OYol5JjdAo`M/[P08
o`9Y[?l4JZgo:X2iofBSc?n:^]So<XJlo`E[[_l2JJ`7o`M/[P03o`E[[_lPNkKo^=KX0?oooooo6Ooo
ool00:kooooo00?oTKkKo`a^[ol3Jjd07_l7K:h01ol4JZgo06BZo`1SZOmFVlOo[m3Uomg[m?ohnod0
3_ooool01ooPi_7o/<7Moj^mf_nV^]Woemg[oo7cmOocm?L00_odm?L04oodmOOom?GhooGfnOoen?ko
m?WoooG/h?odfKColm6Soo?<V?ocbY?ollZDoo?;UOo`bICo]Yb9ojRBQonXTh_o]I1Yon^42oooO`00
1?ooP0002oooO`3o[916ojZCQonZThOoZY>6ojjCPonoX8Koi/VVook^eoojmNoon?Ke00;onOWk0ooi
nOX5oo[jnP07ooglo?oOiNoo[l3Loj^mfonU^MSog>C`oognoP0Jooooo`08ooCgn_oBg>_oZ[cJojVl
f_n/_]_oZkgJokW9hOohn_aNooooo`?oo_kn1Oooool01_oln_?oSF93oljOD?oFRC;ohkLhooGV/c3o
oooo017oo_knooclo?ogmoOokno_onKVi_oN^fgogZ<comBJ<_n]LR_oc74Uolmj:OoFT3;oehlbomVF
<OoFURko[UdOonoHZP2Mooooo`06oookm_oojmSookekoon21?ooM`3oogh03_ooP0001OooO`3oogh0
oon95?ooWckoolnO01cooooo00KokoKjom?UlOm`Zm3o0VV]o`1RZOl6Jjh@o`M/[P06o`I/[_l3JZgo
26b^oa5b/Ol2JJco1V^^2Ol7K:h00ol5JZgo?8c0onWbm`3ooooooaSooooo002]ooooo`03oj[<holE
M;?o0VV/01go1fb^00Oo16Z]o`1UZ_l?LK7oMJgBom;Ul?obmo_ooOko013ooooo017oh>Kaok31gOn[
_M[oY[[IomONk?ocloKom?GgooCen?oem_SomOKiooGio_ofmOKom^C9ooCDZ?odcYWomLbEooG;U004
ooG<U@07oo7:U?nfVhWoZ9:7ojRCRoneT6Wojh@;oomo0004oon0000;oomo0?nmSSOoYY>=ojV@PonZ
U8WoZZ>Xoj^fc?n`_mSob=;UooCfnOomoO`00_ohn?T2ooWhn@KonOWj00OooOckomoTkon_`=coZkgK
ojFif?oLi?3ooOkn01_ooooo00Ooo?gnoo?fn_o2d>GoY[WHojZlf_nibN7on?[l06Kooooo00Gog<b^
ok:7BOoRX4Coh:heooGV/P0booooo`0@oogmoOoinOWol_;bonWYjOoPflGogZDnomFK<_nlNb_od7DV
om2;<?nnPboofY8bomRA<_oFTbgo_70WooW`fIoooooo00Kooo_goooah_ooc9SoohL@oomk0?ooO`0>
oon00005oomo0?ooP03ooh@;oonD9_oobYD07?ooool01Oofn_coh>cdog:/dOl0J:_o06N[01;o1fb^
00?o1Vb^o`M/[_l7K:h02_l7K:h00ol3JJgoFIc9ooooo`3ooooooaOooooo002/ooooo`03ok;AiOlD
Lk;o0fZ]01co1fb^00Ko16Z]o`1SZOlYPK[oR[[Ioo;hn_ojo?dCooooo`0=on3VlOn``MgoZkgJojJj
fOoGg^coloCgooGfn?oem_Wom_OjooG`j?oegKcomLjHooG>UP08ooG=U@07oo;;U?nfVhWoZ9:7ojRC
RoneT6Wojh@;oomo0004oon00006oomn0?olO03ofY4dok6a]?nY^MOo[;gI0_n/_]/01On/_][o]<?N
on3Ukookno[onOWj00?on?Si1Ooin?T01oomno_ognC_ojo0g?n[_M_oYKWHomcTl?omo_h07Oooool0
1OoloOkoh>Oaok31gOnga^3on?[l06Gooooo00GooOciojZ7G_oJVdOogj@cooGV/@0cooooo`0@ookn
o_ojn_[om?Cdonc/k?oRh^;og/F7omRI<Oo<QBcoeXP^olJ3;On/KROoeY0`omN@<_oDS2godiM6ookl
mj7ooooo00Goooglooojm?ooaXkoohD;ooml000Aoon00004oon01_ooTB?oolbIooonoA_ooooo00Go
nOcmon?_m_mWYLgo06R/o`AZ[@0Mo`M/[P03o`I/[_l3JZgoL:[A0?oooooo5oooool00:[ooooo00Co
o_koojk?i?l;K[3o0fV]6ol7K:h01?l8K:oo2fn`oe:Ha_o=hNlGooooo`0;on3VlOn``MgoZkgJojJj
fOoHgngom?GfooKemoofj=GomMJ]ooG:T?oecI@00ooecID2ooK=U@?om/jF0_ofcID01oocbiGo]ib:
ojRBQonXTh_o]I1Yon^42oooO`000_ooP0002OooP@;oogh5oonZE?oog[koooooookooooDgNco[[oM
oj^nf`03ojbnf`04ojNjfOo0c>;oj^gcooOhnPOonOWj00OooOclomoUkon_`=coZkgKojFif?oLi?3o
oOkn01oooooo00?on_[momSPk_ognO`0IOooool01?oWg<?o_HI2onF]?_ofik0dooooo`0?ookno_ok
no_om_Kfono_kooUiNGog]_BombZD?oHTRgofiLcolj>;_n[K2Oo`7/Xol=h:_oGSRooikie0:Gooooo
00Coooomooo3R?ooR13oogl34OooP0001OooN`3oohdLooo=VooonO?oookm01_ooooo00Coj?;hoenP
bol5Jjko26f^7?l7K:h01?l4JZgo2Fj^ohZif?ono_oooooooaGooooo002Yooooo`04ookoooo8gngo
7GVeo`1WZa[o1fb^00Co1Vb^o`1W[?m?UlGog^cd6Oooool02OoPi_7o/<7Noj^mf_nV^=Kof=cUooCP
aOodcicomLZAooG<T`02ooG=U@03ooK=UOofcYKom/jF00OomljF00_om<bEokNLR_nXTXOoZ9>;okF@
JOo[P`[oogl1oon32OooSQcookI]oooej@05ooooo`03ooKhnoo3cnGo[;kJ00?o[;kK0_nZ_=/00ooB
f^[olO?fooOhn@05ooSinP07ooclnooOi>oo[l3Loj^mfonU^MSog>C`oognoP26ooooo`04ooono_no
W6kogjI1ooS]a3Kooooo00koo?clooShn?oalO7ojNWYon7QhOoNeKOofIPeom^L<ooQYCCo/WTZokM_
9_nZFaoo`gLXonkAW:Oooooo00Coooglooo1P_ooRQKooh874?ooP0001_ooO`3oogP0oon>7_oobYCo
ooO^ooolnQ_ooooo00Goh^keoeNKb?l>K[3o2Fj_o`E[[@0Jo`M/[P04o`1X[?lKNKCo]]CXoogno_oo
oooo5?ooool00:Wooooo00Cod>C`obEn^?l0IJ[o26b^6ol7K:h01?l7Jjko06:Yog2ZdOoZl_PHoooo
o`07omoUkon__]KoZk;6ojFMYooH/hcom<V?ooG=U002ooG=U@03ooK=UOofcYKom/jF00WomljF00So
m<bEokNLR_nXTXKoZ9::okFAK?o[S1[ooihkooo?W`[ooooo00CohNSbokW8hOn]_m_oZkgK0_n/_]/0
1OnW^]Wo/l?Mon?Xl?odm?OonOSi00?on?Si00Ooo?_komoTkon_`=coZkgKojFif?oLi?3ooOkn08Ko
oooo00?ol^[HolZC?_ofiJh0=oooool03_omoOgon_[jooCdm?o/k>coi>CTomoOgooN]VcogJ4con>Y
=OnjQbko]flUojYL7on]GB3ok]J]ZOooool01?oonoOool63oonE:_ooQ0d2oomo00kooh0000Koogh0
oomh0?ooQ0SoolN@ooobi?ooo?TKooooo`05omSYlomEVlSo5WBbo`a_/?l6Jjh06?l7K:h01?l8K:ko
06FYobf1^_o:gnkooooooaCooooo002Xooooo`04om7Sl?lTOKOo06>Zo`Q][Qko1fb^00?o066XodRA
`_o;h>h05Oooool02?oon?7oonS>omS2Z?nXVHgoZHn2ojB<POoH]I3om<bE0_oecID00oofcIGom/jF
ooO>UP0:ooO>UP06ooC;U?ngVhSoZ9B:ojRIUOng[:;ok^OC3Oooool00ooloOgodMc/okK6h002oj^m
f`0?ojbnfon[_M[oY;SHolK@iOoXj_;omOKhooShnOofmoSon_[jomkSk_n_`=coZkgKojFif?oLi?3o
oOkn08Gooooo00?oooonomNkR_obg:00>?ooool03_ono_kono_kooKfm_o_knooj>SXon?ShooQcJCo
g9lcon>X=OnnSS3o]g4Uoj]L7on_Gb3ok]Jd[?ooool01OoocIcooihloon74?ooO@3oogl000kooh00
00Koogh0oomh0?ooR13oolJ>ooo[eooooO`Kooooo`04omg/m?mXYLgo476ao`AZ[ASo1fb^00Co26f^
o`1OY_m7T/?ognceoooooolCooooo`00Yoooool01?oRk_Ko<XBko`1SZOl8KJhOo`M/[P04o`Q/[_l0
GjOo97fgokKDia;ooooo00gooo3QoooJ]Ooo]Fcooh@6om619?nSTWooZY>9ojB?Q_oH]I3om<bEooG=
UOofcIGom/jF00OomljF0_ohciH02OohciGomlfCooO=Tooed9go]jRSojVY]onY^=?o`=C`oo_oo`0?
ooooo`04oo3cn?o7e>Oo[l3MojZlfP;o[;kK00coZ;_Iojo0gOoHgngok_3eooShnOokn_[ogN?^ojo0
g?n[_M_oYKWHomcTl?omo_j5ooooo`03ooWdi?obhkCooooo03Wooooo00goo?clooShn?oalO7ojn_[
onKVi_oTh=;og:0non2W=Oo<VC;o[VdVojaL7oncHb;ol=Zo0:kooooo00GoolfIoonP@?ooQPgoog/0
oomo000>oon00005oomm0?ooMP3oohdKooo7Soooj=006_ooool01?o`m_[oX/OPobIn^?l1JJ`Io`M/
[P04o`I/[_l0GjKoIZC=ooGio?oooooo4_ooool00:Kooooo00Coj_;hoeFJb?l0HJSo26f^8Ol7K:h0
1Ol8KJko06BZo`Y][onG`]kon?_m00kooooo00koonK<ooo>WOooXTGoogX0oome0?ooO03odXXeojBD
P_nZThWoY8j6omVfT?odc9Gom/fEooK>UPKomljF0_ohciH02oohcYGon<fAooS>U?ohejOonN2kooOY
e_nhbNGoZ/3QojVmg?nocN?onO_m017ooooo013ofn?_okg;h_nZ_M[oZ[gJojbnfonZ_M[oYk[Iokg:
hOoOi>oom_Ohon3Ukon_`=coZkgKojFif?oLi?3ooOknQOooool00oono?Goooooooooo`0iooooo`0=
oogmoOoinOWom?Cdonk^k_oYjNWoinOWon2eJOoNXS?oej8cojY]:?n^G1oo]F@RooKXc02_ooooo`06
ooolnOoobIGooj93oon31oooN@3oogh03_ooP0001_ooO03oogD0oon@8OooaXgoon;5ooomnaKooooo
00GodNC`oeFJaol0HZWo06R/o`Q/[P0Jo`M/[P03o`AZ[Ol0IZ_oS;_J0?oooooo4_ooool00:Gooooo
00Coj?7goeNKb?l0HJSo26f^7_l7K:h02_l4JZgo0FV/o`9Y[?l0Ij_o06FZo`1VZol0H:Oo05bUof6Q
booBiO0:ooooo`0@ooodj_ooejoookYdoonB9?ooM@3oogT0oomo0?ooP03oogl0om::=OnTU8;oZY>9
ojB>Q_oI]Y3om<bEooK>UPKomljF00kon<nFooS>Toohbhgon=2HooSL/ooii/[on_;Woo[looognooo
^LORojZmf_nY_=[o_lgSooWkoA;ooooo00ColoKjomCMkOnda=koY[[I0_n/_]/02OnY_=[o[KkKol_D
i_o=e^So[l7Loj^mfonU^MSog>C`oognoP31ooooo`0=ookno_okno_om_Kfoo7alOo]kNgoj^[ZonO@
X?oLW3?oej8cojmf:_n_H1oo^6HVooKXe02aooooo`06ooohl_ooc9SoojUDoon84?ooM@3oogh03_oo
P0001OooN`3oogL0oon<6Ooo]6Woomfj01?ooooo00Goo?gnoiO1gOlZP;Wo06:Xo`I[[P0Mo`M/[P03
o`5Y[?l3JJcoZ/kS0?oooooo4Oooool00:Gooooo00?oHj?<o`1UZ_l8K:h04ol7K:h01?l5Jjgo0FV/
o`5Y[?l0IZ/2o`1UZP0@o`1SZOl0HJSo066Xo`1PYol0GJKo05jWo`E[[OlHM[?o4G:aobj3^oloSL3o
>XZnoeJKb?mRXLcoFIc9olWOkPSooooo00KoonkMooo;U_ooYTcoohP@oomf0?ooO004oon00008oomo
0?oBRSGoY9B2ojZCROnTSXKofKJ@ooG<UOofcYH4ooO>UP0@ooO>UOogc93omlb>ooSCX?oih;gon^[G
oo[gl_ojoOoon_cnoo[jnoogn?Wo^LOQojZmf_nY_=[o_lgSooWkoACooooo00Ooj>ceolWFj?nW^][o
Z;_Jojbnfon[_M_oZK_J00;o[KoK00Co[;kKojFif?oLi?3ooOkn`Oooool03Oono_koo?clooShn?od
m?Col?3`onk^k_o]i]?ofi/iomNP=?neOb_o[f8Poka[:_ohk^00/oooool01_oonO?oomJ]oon]Gooo
P`Ooog@0oomn00kooh0000Goog`0oomf0?ooSA_ook9VoooM^P0@ooooo`05on?^m_mNX<[o26f^o`1T
ZOl8K:h07_l7K:h01?l8K:ko0FN[oaaf/oo<hNkooooooa3ooooo002Tooooo`03ogZ`e?l8KJoo1fb^
00So1fb^00Co1F^]o`5Y[?l1J:co06N/0_l0I:X03Ol0HjWo062Wo`1PZ?l0GjOo05bUo`1KYOl0IZ_o
5WBcoaEd/olaQK_o@i32od>@`OmJWLX00_mbZm403?n2]MKoWLGOoik5gon]cnCo_=OYokODioo<hNko
fNSbomGVlOoYl_Som?Sloo?gn`Oooooo00KoomfloongK_ooVcWooh85oomj0?ooO@06oon00008oomo
0?oBRSGoY9B2ojZCROnTSXKog;RAooO=UOofcYH2ooO>UP09ooO=U?ogbXoomlbBooOJ/?oiilconO3S
oo[jnOojoOoon__l00?on_[j00KomoSiokW7hOnZ_M[oZKcJoko=hooinodEooooo`07oo[loOoNiO7o
^LSQojFifOnZ_M_o[;kKoj^mf`02ojbnf`03ojFif?oLi?3ooOkn0<;ooooo00cooOgmoo[jn_ogmoOo
m?Cdoo7alOobl_7ohJmQombP<onjQbkoZehPol1`;Ooln>beooooo`06ooojlooof;3oojiRoomo0?oo
M@3oogl03_ooP0001OooO03oogP0oon?7ooo/VCoon7300gooooo00CoVl?Noc24^ol0G:Go06N[8Ol7
K:h01?l8K:ko06BZocR:__ogn_coooooo`oooooo002Sooooo`07ogR_dol3JZgo06N[o`1X[?l0I:Wo
06BZo`1SZ@02o`1PY`0Co`1OYol0G:Go05ZTo`1TZOlHM[Co7GVeobIn^?m?UlGoDIO6of2Pbon7]mSo
P[GFoi6nfonfe>Oo]M?WokkIj_o:h>kob]o^omOXlP02on3]m@04on_cnOogn_como[lookoo`oooooo
00Oooochooo:UOooXTCoohdMoomm0?ooN`3oogl000Sooh00017oogl0om::=OnTU8;oZY>9ojJ@Q_o5
Yhcol/ZEoo[AU_ofcI?omlZ?ooK@VOohgkcon>cKooWel?oin__on_cnoo[jn`05oo[jnP06ooOhnOnh
a^3oZ[gJojVlf_nocN?onO_m5oooool01?oam?WoeMg]ojZlfonV^MP3ojbnf`03ojFif?oLi?3ooOkn
0<;ooooo00Coo_knoo_knooinOWomoOg0_oemOD01_o/dI_ogYXbokf<;on[HB;oa7Ddoochl[Oooooo
00KoooSaoooN__oo/6Coogd0oomg0?ooO`0>oon00005oomm0?ooO03ooi0Poon]FooohlL02_ooool0
3?odn?coQkSHod6>`?laQK_o4G:ao`1NYol0GJGo062Xo`1RZOl0IJ[o06N[o`AZ[Aco1fb^00?o06R/
odbEaOooool0ooooool>ooooo`00X_ooool04OmVY<ko06:Yoaah]OlRO;Oo8W^goebNbOmJWLWoH:3;
ohZjfOn?_=_oWlKPol?Lk?o6gNcobn3^omGVlOoGio;ofNWc00;oio7g00Cok?CiooWkoOogn_coo?gn
6Oooool01_ooj=3ookM_oonC;oooQ`ooogd0oomn00_ooh0000coogl0om::=_nTU8?oZY>9ojVCQon]
UHOo^9f6ombeROoof:ConNS=ooSbjoohmO82ooWin`;onOWj1Oojn_X01ooinO[om_OiokS6h?nZ_M[o
ZKcJoko=hooinod06?ooool02OoloOkojNgfol;?iOnV^]WoZ[cJojbnfonU^MSog>C`oognoP32oooo
o`04ookno_omoOgono_kooWin@;on?Sh00KomNcBomfG=OnnRc3o/VXSolZ1@Oomn_Fiooooo`06ooog
k_oohlOoojiNoomi0?ooM`3oogl03_ooP0001OooOP3oogl0oon?7oooXTGoom^f00Sooooo01?onogn
onoen_oVl?OogN_dom?UlOo8g^go/=3UohRif?m]Z=3oAi;2obf2^ol3JZco05fUo`1PYol0HJSo06FZ
o`1WZol2JJco26b^01Ko1fb^00?o16Z]og2Zd?ooool0ooooool=ooooo`00X_ooool02ooPk?Goe^Ob
on7]mOoRk_Goh^geonkenOo]m?WokoGjooSkoOoinogoo?gn02?ooooo00KoomZdoonM>_ooS1[ooh<6
oomm0?ooO`0=oon0000<oomo0?o>RRgoWYB3ojVCS?nZTH;oZHn0ojZLW?n`]<CoalgKoo7am?onoooo
nOWk0_ohn?T00ooin?WonOWjooWinP05ooWinP06ooKfn?nha^3oZ[gJojVlf_nocN?onO_m6_ooool0
0oohn_coh>Obok;2g@02ojFif003omcTl?omo_kooooo0<;ooooo00?oo_knoogmoOolo?`00_okno/0
1_olnoSohjeHol29<?nfLBGod8e=ookmnK_ooooo00GoooO_ooo[e_oo^WGoogh0oomj000?oon00005
oomn0?ooO`3oohPEoonQ@ooogkl03Oooool04_ogn_colOOkonWbn?oTkoKofn[comOWl_nQa^3oS[cK
oenOb_m0Sl3o6gNdo`1KYOl0H:Oo06>Yo`1TZ_l0Ij_o0FR/o`I[[Q7o1fb^00?o476aoiW3gOooool0
ooooool<ooooo`00cOooool01_oolNCookeloonA8oooQ@_ooh00oomo017ooh0000koo7h0om^24On]
TV[oYjB/ojbhdOn/_=Oo[;kKojfog?nc`]koemg[ooglo?okno[onOWjooShn@OonOSi00KomOKhokS6
h?nZ_M[oZKcJoko=hooinodKooooo`06ooknooojnogocmW[ojFheooJh_3ooOkn`oooool2ooknoPCo
oOgm00Gok]6Dolb<<?naL2Sodi1Fookmo02mooooo`03oookn?oolN;ookI^00;oog`03oooP0001Ooo
O`3ooh01oon23?ooW3Soon74017ooooo01;oo?gnoo[loOofn_coloSkoo3fn_oYl_SocN7_oio7h?n2
]MKoEY[8ocf=`?l5Jjgo06>Yo`1UZ_l0Ij_o06R/o`=Y[Ol4JZd<o`M/[P03oaij]_oAi?3ooooo0?oo
oooo2oooool00<gooooo00?oom^goon<5oooP0004_ooP0002?ooO`3oogh0oonD:_oncikooOWcon3W
l_n``]goZkkK0on/_]/01On]_m_o^/SQonKYl_omoOcon?Wj00OonOWj00Kom_OiokS6h?nZ_M[oZKcJ
oko=hooinodMooooo`04ooknoooYkOKoj^kfoogno/Gooooo1?ono_h01?ohkLkodHhbok9b:_oIWfC0
ooooo`03ooono?ool>3ook1Q00;oogh04?ooP0001?ooP07oogd4oonM>ooohlPEooooo`0@ookoooom
o_koo?knoo_mo_oko?konOcmoo3fn_o2fn_oWLKOog^adom:ULCo<hJlo`1UZ_l2JJco0fZ]o`AZ[@;o
1F^]1_l7K:h00ol5Jjgo;X>jonWbn03oooooo`_ooooo003>ooooo`03ooohlOooWC[ooh0300oooh00
00Cooh03oon73Ooo[UgoonSB1?ooool00oomoOoob]GXojfog004ojbnf`04ojfng?o9e>Kol?;eooWj
nPKon?Wj00KomOKhokS6h?nZ_M[oZKcJoko=hooinogZooooo`04ooklmOoGW4So^7D[omn]Kl?ooooo
00Cooo3Qoon/FOooP@Gooh024?ooP0001_ooO`3oogX0oonJ=OooeZgooociooonoQkooooo00ooi_3g
okSDj?nK`mkoKJS?oe>IaolNN[Ko2fj_o`a_/?l;KZoo2Vj_o`U][ol8KJko0fV]odJA`_oloOh0oooo
ool:ooooo`00B_ooool02?ogmoOojNWYon?ShooWinOomOGeooWinOo/k>con_[j0oooool01?oclo?o
i^KVon?ShooYjNT2ooShn006ong]kOokno_oooooooShn?oTi>Cono_k0oooool04OogmoOoinOWon?S
hooXj>SonOWiooKfm_o_knooo?clooooooofm_Koi>CTookno_o_knooi^KVon?ShooZj^[onOWi00Co
oooo00SooOgmoo;bl_oUiNGohn?Song]kOojn_[om?Cdonk^kP;ooooo00Gono_kon_[jooShn?oi^KV
ooGem@04ooooo`05oo?clooVi^Kohn?SonWYjOofm_H01?ooool01?o_knoohn?SonKVi_ogmoLgoooo
o`04ooo4R_ooQA?ooh42oomo00Sooh0000Koogl0oon00OooR0oooi<Uooo7T?oomnl8ooooo`04onk`
n?nmbn;o[/7Loj^mf`;o[;kK00CoZ;_Iok30g?oHh>com?Gg1Oohn?T01_oem_So^<KPojZmf_nY_=[o
_lgSooWkoN_ooooo00?oil9nokeh:ooLZgH0aOooool01OoolnKookM_oon=6oooPPKoogl000oooh00
00Koogh0oomh0?ooTbOoomN_ooofk_ooo_dSooooo`08omg[m?nke^WoVL;MofRVc_mDV/So6WRdoaah
]Omd[M88ooooo`06ookno_o^k^koi^KVon?ShooZj^[om_Kf1_ooool00oodm?Coooooooooo`04oooo
o`06ooclo?o]kNgohn?SonCTi?o/k>cooOgm0oooool00ooTi>ComOGeooooo`09ooooo`03onWYjOoT
i>Coi>CT00Gohn?S00[ol_;boooooooooooooooooo?clooXj>Sohn?SonGUiOo`l?3oo?cl2oooool0
1OoalO7oi>CTonCTi?o^k^kooOgm00;ooooo00?okNg]on_[joolo?`00oooool01ooclo?oi>CTon?S
hoo]kNgonOWioo7alOodm?@00_ooool00oo[jn_okNg]ooknoP02ooooo`03ookno_oTi>Com_Kf00?o
oooo00Oono_kon_[jooShn?oi^KVooGemOogmoOok>c/00Cooooo00_om_KfonWYjOoShn?oinOWooKf
m_oinOWok>c/ooclo?oooooolo?conGUi@06ooooo`04oo_knooZj^[ohn?SonKViP;om_Kf00?ok>c/
ooooooooool01_ooool2onc/k00:oogmoOooooooooooooooooolo?cok^k^onGUiOoShn?oj^[ZooKf
mP?ooooo00?omoOgonCTi?olo?`01?ooool00oohn?SoiNGUooWin@02ooooo`;ok>c/00GooOgmoooo
oooooooolo?conGUi@04ooooo`0;oo?clooUiNGohn?Son_[joono_kokno_oo?cloono_kooooooo7a
lOoWinL00oooool01Oofm_Koi^KVon?Shoo^k^koo_kn03Oooooo0018ooooo`0:ookno_oUiNGoNg]k
oaTI6Ol0003o51@Dog=cLonGUiOo:BTYol_;b`;ooooo00gohn?SoemOGol71`Oo0000obHV9_n?Shoo
TI6Aoc`l??oFe]KooooookBd]?l0003of=SH00;ooooo01?ok>c/ogmoOol61PKo0000oa/K6onEUIGo
OGemoda<C?oPh>3ooooooj2PX?l0003oalO7od51@OlC4a?o0000ob0P8?n@T93okno_00;ooooo017o
n_[jokZj^_m?Cdoo0@41o`000?lk>c_oU9BDog=cLom3@d?oooooooKfm_nPX:3o8R8Ro`000?l10@7o
L71`onc/k002ooooo`07olo?comKFe_o20P8o`000?lN7QkoN7Qhonc/k002ooooo`06om?Cdoln?Sko
0000o`@41?mmOGgoo?cl=oooool01OookMWoojI<oon95oooP03oogd000Coogl000Googd0oon31_oo
S1Wooj=7oooM_00=ooooo`0;om_Rl?na`]go[;kKoj^mf_n/_]_oZkgKojFhf?noc>;oi^[aooGfn?oh
n?T00_ofmoP01_ocmOOo^<KPojZmf_nY_=[o_lgSooWkoN_ooooo00?omNBiol=m;OoN]8<0aoooool0
1OoonO;ookQboonA8oooPPKoogh000oooh0000Googd0oomh0?ooVC?oomVcooocj00Xooooo`03ooSl
oOoJjO?onogn00Kooooo00Soo?clokRh^?lk>c_o3@d=o`000?lQ8B7oL71`on;RhPGooooo00?oJVYZ
onc/k?ooool00oooool02?ogmoOoYJFUocDe=Ol0003o1PH6obPX:?n][Jgono_k0_ooool00ol0003o
UIFEooooo`08ooooo`03oogmoOm7AdOo000000Ko000000_oQXJ6ooooooooooooh>3PoeiNG_lC4a?o
0000o`X:2_m2@T;o[:b/ooShn009ooooo`06om3@d?m;Bd_o0000o`000?li>CWob/[:0_ooool00om6
ATKo;Rh^onCTi002ooooo`08omKFe_mOGeoo0000o`000?lo?cooT92@oe5ADOn3Ph<2ooooo`03obTY
:Om4A4Col?3`00;ooooo00?olO7ao`000?nPX:000_ooool02?oemOGoWYjNobDU9Ol0003o410@og9b
L_n9RHWo92@T0_ooool03Oono_kohN7QogQhN?lE5AGo0000oaHF5_miNGWoU9BDobPX:?oJf][ooooo
ohB4Q?l000001Oooool02?oclo?oW9bLoalO7ol0003o4Q8BogMgMon6QXKo9RHV2?ooool2oc`l?00;
on[Zj_oooooooooooo[jn_n/[:co=SHfo`/;2ol0003o8R8RogMgMooUiND00_ooool00onZZZ[o0000
on3Ph004ooooo`03okZj^_l0003o`L7100;ooooo00?o?3`locDe=OoWinL00_ooool01on4Q8Co0000
oooooooooooooOgmomWIfOmKFe/00_l000002?lW9bOo_knood92@_mhN7SonOWioooooomXJ6So0@41
0_ooool01ooShn?oMGEeo`d=3Ol0003o=cLgom3@d?omoOd0=_ooool004Sooooo05;olo?coe=CDol0
003oGemOokJf]_nIVIWo<S8boa4A4Ol0003o`/;2ooooooo_knoo9BDUo`h>3_mnOWko][JfohV9ROl`
<33o0000obd];OoGemOooooookZj^_l0003ofm_Kooooooono_koI6ATo`000?mVIVKo/[:bohf=SOld
=3Co0000oclo?ooPh>3oooooojRXZ?l:2P[o5aLGocdm?OnWYjOoZj^[oeADE?l0003oJf][ooShn?oo
oooo][Jfo`T92OlN7QkoTI6AokBd]?m`L73o2PX:oaXJ6_lQ8B7ooooookbl_?l71`OoBDU9okFe]Omj
NW[o0000oiJFU_omoOgok^k^oa8B4_lF5QKoShn?ok:b/_maLG7o1PH6ode=COo_knooo?cloc@d=?lP
823oZ:RXogmoOol0003ocLg=>Oooool01?ooh<7oojQAoonB:OooS1L2oon52`04oon<5oooTbgookQa
oooVcA3ooooo01;ol_GiolOCion``MgoZKcJoj^nfon/_]_oYk_Iojbmfoo@fNSojngcooKfn?ogmoSo
loCgokS6h?nZ_M[oZKcJoko=hooinog[ooooo`03oogikOo:Qc?oi<6=0<Wooooo00GoooK^oonfKooo
UB[ooh43oomm000?oon00005ooml0?ooN03ooihmoooH[ooolN80;oooool02On][Jgo0000oclo?onL
W9co/;2`ogAdM?l?3`oo>SXjonGUi@03ooooo`03onCTi?l0003oMgMg00?ooooo00goo?cloj:RX_l0
003o@D51ojJVY_nZZZ[oA4A4o`000?nXZ:Soo?clooooool0003oWYjN00[ooooo00Goo_knoc4a<Ol2
0P;oTI6AokJf]P02ok6a/@0<ojVYZOoKfm_oooooom7AdOlD51Co4Q8BofQXJ?n`/;3oWYjNob`/;?l3
0`?oUiNG2?ooool05_olo?co=3@doa<C4onPX:3oXj>SobLW9olg=cOolo?coooooomFEUKo@410onKV
i_ooooool?3`oadM7Ol?3`ooRh^;ok:b/_m]KFgo10@4o`L71om_Kfl2ooooo`03oc/k>omDE5ColO7a
00;ooooo00gol_;bo`000?nXZ:Sooooooo_knonCTi?o0000od];BonYZJWoY:BTobDU9OlJ6Q[o0000
00;ooooo00gokNg]odU9BOl20P;oIVIVokNg]onGUiOo;2`/oa@D5?l0003odm?Coooooon>SXko0`<3
00Cooooo00Won_[johF5QOl0003oDe=Coj^[ZonRXZ;o7AdMoaXJ6_l000002?ooool2ode=C@0@onc/
k?oooooooooooj6QXOl0003oATI6oinOWon_[jooL71`o`/;2om6ATKojNWYoooooona/K7o0000on?S
h`Cooooo00?o`<30o`H61_o6a/H00_ooool00om=CDgoATI6onWYj@02ooooo`0Johj>S_l71`Oooooo
oooooooNg]ko=3@do`d=3OmmOGgo^[Zjofe]KOl^;Rko0000ofi^K_oinOWoooooogEeMOlG5aOooooo
ooclo?mhN7So0000ohV9ROn`/;3o:RXZoc/k>ooXj>Pfooooo`00Aoooool01?ono_koa<C4o`000?nB
TY83ooooo`08oo[jn_m?Cdoo0000olG5aOooooooR8R8o`000?o3`l<3ooooo`0<om_KfolT92Co:b/[
omOGeooooooo^[Zjo`000?oKfm_oooooomSHf?l0003oPH610oooool02?oTi>Co9bLWoc`l??oPh>3o
ooooojRXZ?l61PKoCdm?1?ooool01omfMWKo2`/;olK6a_olo?coADE5obDU9OoYjNT00oooool01oo5
aLGo0000obTY:Oooooood];BoiZJV_o[jn/00_ooool01_lb<S;oCDe=oo_knon3Ph?o20P8omOGe`?o
oooo00KoZJVYod10@?oAdM7omOGeogUiNOoAdM42ooooo`03o`L71on0P83ooooo03[ooooo00KoooCX
oooJ]?ooai3oolN?oooI]?oon_DDooooo`0@on?Ylonnc>Co[KoLojRkf_n/_]_oZkkKojBhf?nga]oo
emk/onk`mOoem_So]lKPojZmf_nY_=[o_lgSooWkoNcooooo00?og[9Won:iRoooool0b_ooool01_oo
l^Kook]goonH<OooOP3oogX0oomo00kooh0000GoogX0oomi0?ooWC_ool^GoooXd@0/ooooo`03onc/
k?l<30coDU9B00Cooooo00Coa<C4o``<3?mcLg?onOWi0_ooool01?m`L73o0000oalO7ooalO42oooo
o`04onCTi?lg=cOoADE5oogmo@?ooooo00KoEEEEogEeMOogmoOoooooo`000?nNWYh;ooooo`04omoO
golU9BGoB4Q8ooKfmPGooooo00?oVi^Koc4a<Oo5aLD01?ooool00omVIVKo1@D5om[JfP07ooooo`03
ooKfm_nLW9co`l?300;ooooo00_o^KVio`D51Oo0`<3ooooooeIFE_m0@43oi^KVoooooon=SHgo1@D5
ol?3``03ooooo`03ohf=SOl0003oMWIf00;ooooo00?o>c/koeADE?oalO400_ooool02?obl_;o0000
ojRXZ?oooooof][Jobd];Om@D53on?Sh0_ooool02?oUiNGo9RHVo`000?ooooooo_knokJf]_l0003o
V9RH0oooool01oofm_Ko@d=3o`000?oEeMGoooooohj>S_l30`<01?ooool01?oBd];o92@ToeMGEool
o?`2ooooo`03omoOgolK6a_o000000Sooooo0_m=CDd01Oo/k>coooooonWYjOl410CoI6AT00Cooooo
00Oo^KVio`H61_n4Q8Coo_knok:b/_l0003ohn?S00Cooooo00?o`<30o`H61_o6a/H00_ooool00om=
CDgoATI6onWYj@02ooooo`07ohj>S_l71`Oooooooo_knonFUYKo0@41okFe]@03ooooo`0;okZj^_l9
2@WoL71`ooWinOooooooMGEeoaLG5ooooooom_Kfoi^KVonOWil00_ooool00ond];Co0P82omGEe@0f
ooooo`00Aoooool01?olo?coPX:2oa0@4?oinOT4ooooo`06ojZZZ_l20P;o`/;2oooooole=CGo@D51
1Oooool02on>SXko6a/KomOGeooooooo^[Zjo`000?oKfm_ooooooiFEUOl30`?olo?c00Cooooo00Oo
Kfm_oc<c<ooPh>3oooooojRXZ?l0003of=SH00Cooooo00KoeMGEoaLG5onBTY;ojn_[oaXJ6_nFUYH5
ooooo`03od10@?lQ8B7ooooo00?ooooo00Sol?3`oj^[Zol92@WoMgMgoooooolX:2SoE5ADooknoP?o
l_;b00?ok>c/onWYjOono_h00oooool01?o_knoo[jn_o`000?n^[ZiFooooo`0?oo_loOoFgngo^<SQ
ojVkf_nZ_M[o[;kKojVlf_nV^MWoa<oUomkTk_nfaMooZ[gJojVlf_nocN?onO_m0>cooooo00?okmVT
on>mSOooool0c?ooool01_ookMWook]goonO@OooP07oogT0oomo00gooh0000Koogl0oomi0?ooM@3o
oi@Zooo6S?ooj=4Zooooo`03oj^[Zol0003oi^KV00Gooooo00WoJFUYobh^;_oQhN7oooooonOWiolE
5AGoAdM7o`000?nIVIT00_ooool01?o:b/[o30`<oijNW_ojn_X2oo;blP03oo?clooNg]koo?cl00;o
oooo00?o0000oijNW_ooool02oooool01?o0`<3o1PH6oemOGooemOD5ooooo`03on;Rh_oooooooooo
00?ooooo00?oh^;Roa/K6on8R8P02_ooool03?olo?cob<S8odY:B_lN7Qkog]kNoooooomFEUKo@410
onKVi_oooooo>c/kodQ8B0Cooooo00?ohN7Qoa/K6om/K6`00_ooool00olk>c_oE5ADoo7al@02oooo
o`07oo;bl_l0003oZ:RXoooooonf][Ko4a<CokBd]004ooooo`07ohF5QOl0003ooooooo[jn_mdM7Co
6QXJoo[jnP04ooooo`06oijNW_l10@7odm?Coooooon>SXko0`<31?ooool00onVYZKo5ADEok^k^`04
ooooo`03ogUiNOl0003ooooo00Oooooo0_m=CDd01Oo/k>cooooooj2PX?l0003ol?3`00Gooooo00Ko
EeMGoc/k>oodm?Co]KFeo`000?oShn<4ooooo`03ol30`?l61PKoa/K600;ooooo00?oCDe=odI6A_oY
jNT00_ooool01on>SXko1`L7ooooooo_knooFEUIocHf=_ono_h01?ooool01_lQ8B7oKfm_ooWinOoo
ooooMGEeoaLG5`Gooooo00CocLg=oe=CDolH61SogmoO=_ooool004Oooooo00?oo?clofm_KolI6AT0
1Oooool01_o@d=3o1`L7okno_ooooooo4Q8BohZ:RPGooooo00[oVIVIob4Q8OoFe]KooooookZj^_l0
003ofm_Koooooon2PX;o20P81Oooool01_mlO7co=cLgomoOgoooooooZ:RXo`0000Gooooo00KoiNGU
od51@OmhN7SogmoOo`h>3_ni^KT4ooooo`03ooclo?mmOGgo71`L00;ooooo00[on_[joj6QXOm<C4co
1@D5od92@_oHf=Soooooo`P82?lg=cOoBTY:0om7AdL00omADE7oGUiNok6a/@02ooooo`05okBd]?m<
C4co0000od];Boohn?P0F?ooool01?o^l_SocMSZojjogOnX^mT2ojbnf`07ojRkfOn``=co[l3Lojbm
fonY_=[o_lgSooWko@3/ooooo`03oo[bf_o^eZSooooo0<kooooo00Kooo?Wooo6S?ooWT3oogh0oomh
0?ooO`0>oon00005oomj0?ooMP3ooiLaooo2Q_ooj]D0:?ooool00onHV9So0000ooooo`05ooooo`09
ohN7QolR8R;oe]KFoooooon3Ph?o0@41om[Jf_lm?Cgo:2PX00;ooooo00Co`l?3o`000?m5ADGoC4a<
0om7AdL01_mMGEgoEeMGoo?clooooooo0000oj:RXPgooooo00?oUiNGo`000?mmOGd02oooool00oo^
k^koDe=Coe9BDP09ooooo`05olc<c?mRHV;o6QXJoaLG5onKVi/00_ooool01_mFEUKo@410onKVi_oo
oooo61PHoh:2PPCooooo00?oinOWod51@OmXJ6P00_ooool00olj>S[oF5QHoo;blP02ooooo`07oo;b
l_l0003oZ:RXoooooonVYZKo6QXJom?Cd`04ooooo`06ojj^[_l0003oooooooWinOmRHV;o:2PX1Ooo
ool01_o9bLWo0P82om;Bd_ooooooSXj>o`<30`Cooooo00?oU9BDob<S8ooFe]H01?ooool00onTY:Co
0000ooooo`07ooooo`;oCDe=00Cok>c/oooooon>SXko00001_ooool01_maLG7o;Bd]on_[jone]KGo
0000on?Sh`Cooooo00?o`<30o`L71oo9bLT00_ooool00om=CDgoB4Q8on[ZjP02ooooo`06ohn?Sol5
1@Goooooon_[jom7AdOoBDU91Oooool01_l^;RkoL71`ooWinOooooooMGEeoaLG5`?ooooo00Kodm?C
og5aLOlH61So2`/;oj>SXoohn?Pfooooo`00Aoooool01?olo?coPH61oa4A4OoinOT4ooooo`06okBd
]?l30`?o`/;2oooooolc<c?oCDe=1Oooool02_nCTi?o8B4QomKFe_oooooo^[Zjo`000?oKfm_ooooo
oiBDU?l410@5ooooo`07ogEeMOlg=cOogmoOoooooonXZ:So0000om[JfP04ooooo`06omgMgOlX:2So
SXj>on[Zj_lI6AWoV9RH1Oooool02Om>CTko820Pooooooobl_;oR8R8o`L71om7AdOoWIfMonWYj@02
ooooo`03oc8b<_lJ6Q[oRh^;00;oPX:200[oQHF5oemOGol0003oSHf=oooooonj^[[o4A4Aoclo?onG
UiOok^k^F_ooool03?ono_ooiN[dol3=i?nW^]WoZ[cJojbnfon[_M_oZkkKojbnfonY_=[o_lgSooWk
oNcooooo00?oo_gjoocgioooool0d?ooool01_ool>;oolbIoonP@oooNP3oogP0oomo00kooh0000Go
ogX0oomi0?ooV3;ookilooo/f@0Vooooo`03ojZZZ_l0003oj>SX00Cooooo013ooOgmofATI?l_;boo
j>SXong]kOlU9BGo@d=3oooooonm_Kgo0000okRh^?ooooooc/k>o``<3?m8B4SoQXJ60_n2PX801on9
RHWo8R8Ro`820_o^k^koooooo`000?n7QhL03_ooool00omeMGGo0000oiJFUP0:ooooo`03oo3`l?m<
C4coGEeM00Sooooo00GoalO7obXZ:_lO7aooQHF5olk>cP03ooooo`06oeIFE_m0@43oi^KVoooooolh
>3SoE5AD1?ooool00ooUiNGo9BDUof][J`02ooooo`;o?Shn00[ol?3`oooooooooooonOWio`000?nV
YZKooooookBd]?lH61So^[Zj1?ooool01onBTY;o0000ooooooojn_[oM7Adoa/K6ookno/01?ooool0
1_nYZJWo0@41om?CdoooooooSXj>o`<30`Cooooo00?oY:BToa/K6oo0`<001?ooool00on6QXKo0000
ooooo`07ooooo`;oCDe=00Gok>c/oooooonOWioo0000oo7al@04ooooo`07ooclo?mBDU;o>c/kooCd
m?ne]KGo0000onc/k004ooooo`03ol71`Ol30`?o]KFe00;ooooo00?oDE5AocXj>_oWinL00_ooool0
1_n;Rh_o30`<ooooooo_knooF5QHoc`l?0Gooooo00Ko:RXZog1`L?oinOWoooooogEeMOlG5aL2oooo
o`05om[Jf_lk>c_o410@ogAdM?o2`/80>?ooool004Oooooo00Coo_knol;2`_l0003oUYJF0oooool0
2?okno_oEeMGo`000?o5aLGoooooohF5QOl0003oa/K60oooool03?oNg]ko9bLWobTY:OoFe]Kooooo
ol?3`ol0003oinOWoooooooFe]Ko0000ohb<S0?ooooo00Soi^KVobTY:Olk>c_oh>3PoooooonXZ:So
1PH6oe=CD`Cooooo00OoO7alo`h>3_o4a<Coo?clod=3@olY:BWoj^[Z00?ooooo00SobLW9o`L71olX
:2SoooooomoOgol];BgoF5QHooWin@Cooooo00?oOWinoa0@4?oWinL00oooool01omiNGWo51@DolG5
aOooooooCDe=obTY:OoWinL0G_ooool01?ocm_[of>7^ok72g_nW^]T3ojbnf`03ojVlf_nocN?onO_m
0?oooooo`_ooool01_ookmkoolnNoonN@?ooN@3oogL0oomo00kooh0000Goog/0oomm0?ooVC?ookai
oooUc00Tooooo`03on[Zj_l;2`_oEeMG00Cooooo00ooa<C4o`X:2_m`L73oooooohf=SOl0003o^KVi
oogmoOolo?co9bLWoc8b<_ooooooi^KVocHf=_mBDU800oooool01oogmoOo8R8RoeEEEOoemOGooooo
o`000?m=CDd03_ooool01?oalO7oDU9Bo`P82?nm_Kd9ooooo`03olc<c?l<30coVYZJ00Sooooo00?o
PX:2o`000?oUiND01Oooool01omKFe_oA4A4oo?cloooooooRh^;o`@41?oCdm<00oooool00onCTi?o
0P82ogEeM@02ooooo`03odM7Aol;2`_ok>c/00;ooooo00Oof=SHo`000?nZZZ[oooooomWIfOlZ:R[o
FUYJ00?ooooo00SoinOWobl_;ol0003oooooookno_nd];Co0000oibLW0?ooooo00Son?Shod];Bol0
003oeMGEoooooon>SXko0P82onCTi0?ooooo00?odM7Aob4Q8OmQHF400oooool00ooQhN7o9BDUo`00
0008ooooo`07oe5ADOmBDU;on?ShoooooooWinOo0`<3ofUYJ@04ooooo`07okVi^Ol410CoPX:2ookn
o_nb/[;o0@41okjn_P04ooooo`03ol?3`ol0003oS8b<00;ooooo00?oCDe=o`T92OoLg=`00_ooool0
1omFEUKo=3@doooooookno_oU9BDo`D51Onm_Kd00oooool01onn_[ko2@T9ofm_KooinOWoooooogal
O?lH61P00_ooool01OnNWYko10@4ojn_[oooooooo_kn03Sooooo0018ooooo`1Aoo?clom:BT[o10@4
ofa/K?nn_[koXj>Sochn?_l@413o0000olC4a?ooooooj^[Zoa<C4olE5AGoO7alol30`?nDU9Co=SHf
o`000?l];Bgofm_Koo;bl_n:RX[o0000oifMWOoAdM7ooOgmoe]KFol0003oLg=cok^k^onHV9So?3`l
o`000?ln?Skoh>3PoooooonXZ:So2PX:oa@D5?m7AdOo/;2`ok:b/_mDE5Co0000of=SHoogmoOooooo
ojn_[ol410Co:RXZoibLW?nl_;coO7alo`l?3olE5AGo8B4Qooooooo]kNgoB4Q8obLW9on/[:coIFEU
ocXj>_oOgmooooooonWYjOl=3@go7alOoiZJV_ne]KGoG5aLo`000?maLG7omoOgoooooomiNGWo5QHF
oj:RX_mNGUkoDE5A05gooooo00Woo_koongan?o8e>OoY[WIojVlf_n/_]_oZKcJoko=hooinod0oooo
ooo4ooooo`05ooo_goood:7oojI>oomj0?ooN@003_ooP0001_ooO`3oog`0oon00OooTbOook=Wooo[
eb?ooooo00goXZ:Ro`000?m<C4coYJFUokVi^On0P83o5aLGoc8b<_oUiNGom?Cdoc0`<?lc<c?ok>c/
00;ooooo01?oU9BDo`000?o<c<coo?cloi^KVol0003oCDe=ok>c/onNWYko<30`o`410Oo8b<SooOgm
ooooool0003o4A4AohN7Qonk^k_obl_;00cooooo00CoemOGoc8b<_m0@43oi^KV0_ooool00oomoOgo
/k>cooShn002ooooo`04okFe]OlU9BGo6QXJon_[j`Sooooo01GoY:BTo`000?nCTi?oVi^Koc4a<OnG
UiOoooooonOWiolh>3So:b/[oinOWooRh^;ok>c/oaLG5olN7QkoUYJFokZj^_mgMgOo1PH6o`@41?m_
Kfl00_ooool04_m5ADGo0000ochn?_n_[joo[Zj^oc<c<ol;2`_ojn_[ooooooojn_[oS8b<o`000?mJ
FU[o/[:bojj^[_l];Bgo5QHFo`0000;ooooo01[ojn_[od10@?l61PKoLg=cokno_onQXJ7o=SHfoa4A
4Ol0003odm?Coooooon>SXko0000ocPh>?nf][KoUYJFoooooooinOWoOGemo`000?mQHF7o];Bdojb/
[?lU9BGo5QHFo`0000Oooooo01Goj>SXocLg=old=3CoZj^[ok:b/_ooooooUYJFo`000?mCDe?oZJVY
okRh^?mlO7co4Q8Bocdm?OoUiNGooooook6a/Ol?3`oo6QXJokJf]_n2PX800_ooool03?o3`l?o0000
ob@T9?nIVIWoTi>Co`l?3ol51@Go?Cdmok6a/OnFUYKo0000ogIfMP;ooooo01Kofm_Kobd];OlE5AGo
RHV9ol;2`_mjNW[o<C4ao`000?m^KVkono_komGEeOm?Cdoo4A4AolW9bOoZj^[o_[jnoa4A4OmfMWKo
X:2Pobd];OnIVIWonOWi=_ooool004Sooooo00[oo_knon;Rh_meMGGo5QHFo`000?lD51CoKfm_oi>C
Tol820So`L710_ooool02oo=cLgoFEUIo`820_l0003o:BTYoiFEUOn;Rh_o>SXjon;Rh_o9bLWo7alO
00;o000001GoLg=coooooooYjNWoJVYZo`D51Ol0003o6a/Kohn?SomhN7SoBTY:on3Ph?ooooooZ:RX
o`820_o2`/;oFUYJoa8B4_l0003o6QXJohZ:R_o/k>`00_ooool04OoinOWo];BdodU9BOl10@7o0000
ocPh>?nLW9coKfm_od10@?oooooooOgmolG5aOle=CGo0000o`l?3omoOgool?3`00;ooooo00OobLW9
oeEEEOl820So0000oahN7_nBTY;okno_00;ooooo00Gokno_ofm_Kol0003o5aLGoiZJVP1Oooooo`07
ooWjo?oYkOKo^/WQojBhf?nX^m[o_lgSooWko@3oooooolKooooo00GoooGZoooSaoooZ5?oogL0oomk
000>oon00006oomo0?ooOP3ooh01oon>7ooo[UoooncI8Oooool03Oolo?co/K6aocLg=ol>3Pko0000
oalO7omZJV[og]kNoooooonGUiOo0000oj2PX?olo?`00_ooool01oo_knoo0P82oc8b<_oooooom_Kf
oijNW_l`<3000_l000000oli>CWo`l?3oogmo@02ooooo`05o`000?m]KFgoATI6o`000?n2PX803Ooo
ool00onRXZ;o30`<ojb/[003ooooo`07ogAdM?l/;2co:2PXob<S8ol61PKo7AdMolS8b009ooooo`08
oo?clomXJ6So0P82o`000?mADE7odM7Aoooooon2PX83o`00000:oiFEUOono_kodM7AodU9BOl0003o
0@41od10@?nGUiOoBd];oh61P@;ooooo00OoFe]KoeaLG?m/K6co92@To`000?lK6a_oZ:RX00?ooooo
00Solo?cohf=SOlI6AWo0000o`l?3omlO7coQhN7o`0000;ooooo01[oo_knomgMgOmbLW;o4a<Co`00
0?lD51CoOGemoiJFU_lS8b?of][Joooooon3Ph?o0000og1`L?l0003o9BDUonGUiOooooool?3`oh^;
RolF5QKo0000oa4A4On1PH7oPX:2o`0000Oooooo00?oVi^Ko`X:2_l000000_l000002Oobl_;on_[j
ojFUYOlb<S;o30`<o`000?lO7aooLG5aon;RhP02ooooo`0CojVYZOl0003oIfMWoa0@4?l20P;oc/k>
ooooooo;bl_o:BTYogMgMolZ:R[o0000oeaLG?o?clooJf][o`@41?l0003oC4a<onc/k002ooooo`03
oogmoOo>c/koBTY:00;o000000Ko92@TokVi^Olm?CgoMgMgookno_n4Q8@2o`000009oaLG5onj^[[o
n?ShoiRHV?l=3@go0000od10@?oDe=CooOgm03Kooooo001:ooooo`08ooGemOoShn?ofm_Kon3Ph?oc
lo?oa/K6o`L71oo0`<03ooooo`0=oo3`l?oOgmoofm_KonCTi?oinOWomoOgonSXj?olo?comoOgojFU
YOl0003o_;blonc/k002ooooo`0Aoo?clooPh>3ofm_Kon7QhOohn?Som?Cdon[Zj_okno_oooooojRX
Z?l0003olo?coo3`l?oOgmoofm_KonGUiOohn?P01?ooool02?omoOgok^k^omgMgOoKfm_oj>SXoo_k
nooalO7oj^[Z0_ooool01OomoOgoj^[Zom_KfooRh^;om_Kf00Cooooo00Gol?3`omkNg_oKfm_oiNGU
ooWin@04ooooo`04oo?clooLg=coi>CTooWinF7ooooo00Gom_SkomGOkOnY_=[o^l[RooWko@3ooooo
olSooooo00GoooO_oooTbOooYD[oogD0oomm000?oon00005oomo0?ooPPCoohXHoon_H?ool>408?oo
ool01_ono_koj^[ZomoOgooKfm_oi>CToo?cl`;ooooo00?okno_omcLg?ogmoL01?ooool2on;RhP;o
oooo00Gono_konWYjOoKfm_ogMgMon_[j`04ooooo`05omgMgOobl_;ojNWYom_Kfoo_knl01oooool0
0onQXJ7oclo?ooooo`03ooooo`03om_KfolT92CoOWin00?ooooo00KoZJVYo`410OmADE7oJVYZoi>C
TooOgml;ooooo`0Doo;bl_oNg]kogMgMono_koono_koooooong]kOm:BT[o=cLgolK6a_o`l?3oo_kn
ooooooo^k^kogMgMom_KfooYjNWon_[jonc/k?oalO42ooooo`07ong]kOo`l?3olo?con7QhOoKfm_o
i^KVoo_kn`04ooooo`07ooWinOoTi>Cofm_KomkNg_ofm_KoY:BTo`000004ooooo`0?ooCdm?oRh^;o
fm_Kon3Ph?ofm_Kon?ShonOWiookno_ooooooo3`l?oMgMgolo?com_KfooShn?ono_k00;ooooo00Oo
n?Shon?ShooKfm_ogmoOooOgmonJVY[o000000Oooooo00golO7aodA4A?m2@T;obl_;om_KfoomoOgo
ooooooclo?oYjNWog]kNom_KfooTi>Com?Cd00?ooooo01;omOGeomkNg_obl_;og]kNomoOgoogmoOo
ooooooWinOoXj>Som?CdonCTi?oLg=col?3`ooooooobl_;og=cLomgMgOo^k^h4ooooo`0Dookno_o^
k^kog]kNom_KfooUiNGoo_knon_[joo_knooooooonk^k_mUIFGo51@DomkNg_oemOGoooooooShn?oQ
hN7ofm_Kong]kOono_hgooooo`00Coooool00oo6a/Ko1PH6ol30`00<ooooo`03ok^k^ol0003og=cL
00cooooo00?oZ:RXo`000?obl_80Roooool01?omoOkokO7homCMk?oin_cooooool[ooooo00GoooWd
oooQaOooWCcoogD0oomn000?oon00005oomo0?ooP@CoohH?oonaHoook=X0A_ooool00om=CDgoIFEU
ooooo`03ooooo`03olc<c?lR8R;oUiNG00?ooooo00Gon_[jo`L71omeMGGomoOgoo[jnP0Cooooo`03
oeMGEom0@43oinOW01cooooo00?oXj>So`000?ooool06Oooool00onIVIWo0000ooooo`07ooooo`;o
CDe=00?okNg]ooooooooool0:_ooool00omfMWKo5aLGooooo`0nooooo`00Coooool00oo6a/Ko1PH6
ol30`00<ooooo`03okZj^_l0003ofm_K00cooooo00?oZ:RXo`000?obl_80oooooooooooooecooooo
00CoookmoooRa_ooW3Soog/04_ooP0001?ooN`3ooj54oooXd?ooooi3ooooo`03oiBDU?l10@7o^[Zj
00;ooooo00Cokno_oeYJF_lT92Coe=CD1?ooool00om4A4Co7AdMooooo`0Dooooo`03oeIFE_m0@43o
i^KV01cooooo00?oXj>So`000?ooool06Oooool00onIVIWo0000ooooo`07ooooo`;oCDe=00?ok>c/
ooooooooool0:_ooool00omeMGGo5aLGooooo`0nooooo`00Coooool00oo6a/Ko1PH6ol30`00<oooo
o`03onk^k_o5aLGomoOg00cooooo00?oZ:RXo`000?obl_80oooooooooooooeoooooo00CoongJoonX
D?ooP`Wooh024?ooP0001OooO`3oogT0oonVCooojmOoooch047ooooo00Sono_kocTi>Ol30`?oJFUY
og]kNolj>S[o1@D5oiRHV0Gooooo00CoXJ6Qo`000?m^KVkoOGem0_mlO7`00onf][Koooooooooo`0>
ooooo`03omWIfOoBd];onOWi01cooooo00?oXj>So`000?ooool06Oooool00onIVIWo0000ooooo`07
ooooo`03odi>C_m<C4cok>c/02cooooo00?og]kNol_;boooool0?_ooool004oooooo00?oa/K6o`H6
1_o0`<006oooool00onXZ:So0000oo;blP3oooooooooooooHOooool01Oook=Sooj]Goon:5_ooP@;o
ogl000oooh0000Goog`0oomh0?ooZU?oonSAooohl@10ooooo`06oogmoOnFUYKo:b/[oaPH6?mGEeOo
d=3@1_ooool00ooemOGo9bLWoaPH6002oaLG5`03oalO7onEUIGooooo02kooooo00?oXj>So`000?oo
ool06Oooool00onIVIWo0000ooooo`07ooooo`05ofEUIOl/;2codm?Cong]kOono_h0Joooool004oo
oooo00?oa<C4o`000?nn_[h06oooool00onVYZKo0000oo;blP3oooooooooooooHoooool01Oooj=3o
oj]Goon>7OooO`3oogh000oooh0000GoogX0oomi0?oo[eooonG;ooodjP20ooooo`03oj2PX?l0003o
oooo01Wooooo00?oUYJFo`000?ooool01oooool01Onb/[;o7alOoc`l??m4A4Com_Kf06_ooooo001?
ooooo`03omGEeOm7AdOod=3@01_ooooo00?o_knood92@_oemOD0ooooooooooooofGooooo00GoonC:
oon[EoooSakoogl0oomm000>oon00006oomo0?ooN03oogX0oonWD?ooejoooo;UO_ooool00onk^k_o
@T92ooooo`0Iooooo`03ok>c/om2@T;ooooo00Sooooo00Co[Jf]oclo?olo?coom_KfJoooool00?oo
oooooooooooGooooo`03oooQ`_oo^G?ooiD]00;oog/03_ooP0001_ooO`3oogP0oomj0?ooXdSoom:S
oooahooooooo4oooool00<gooooo00?oemOGoi6ATOolo?`0ooooooooooooo`Wooooo00GoonO?ooni
LoooU2_oogT0oomk000>oon00007oomo0?ooM`3oog`0oonSBooobYGooo7TooonoP0Oooooo`03onCT
i?nEUIGoinOW05_ooooo00?ol?3`oi6ATOoPh>00Soooool00<gooooo00?oVYZJo`000?ohn?P0P_oo
ool00oo5aLGoW9bLoinOW`06oinOW`03oijNW_nLW9cok^k^00Kooooo00?od=3@ofIVI_o?cll01_oo
ool00oo2`/;oW9bLoinOW`09oinOW`03oj2PX?nLW9coVi^K00?oWinO00GoWYjNoibLW?nKVi_oXj>S
ooKfmP04ooooo`04omWIfOnIVIWoW9bLoifMW@KoWinO0_nMWId01?o]kNgoh^;RoiZJV_nLW9`8oinO
W`03oi^KVonZZZ[onOWi00Cooooo00ColO7aoinOWonLW9coWYjN1onOWil00onMWIgoW9bLon_[j`02
ooooo`04oo_knonSXj?oW9bLoifMW@OoWinO00OoWYjNoi^KVono_koooooookZj^_nJVY[oWIfM017o
WinO00KoWYjNom;Bd_ooooooemOGoiZJV_nLW9`4oinOW`04oifMWOnKVi_oYZJVoo_kn`Gooooo00?o
YZJVogYjN_oinOT01?ooool01OogmoOoWYjNoi^KVonLW9coWYjN00GoWinO00CoWYjNoibLW?nKVi_o
Vi^K1?nOWil01?nMWIgoW9bLoi^KVooEeMD4ooooo`04ooWinOnVYZKoVi^KoibLW0KoWinO00OoWYjN
oiZJV_o4a<CoooooolC4a?nJVY[oWYjN00OoWinO00?oWIfMoiZJV_o0`<001_ooool00oo1`L7oVYZJ
oifMW@07oinOW`04oijNW_nLW9coWinOonc/k0Gooooo00gokNg]ojb/[?n3Ph?oJ6QXoeIFE_m6ATKo
D51@oeIFE_mVIVKoOGemoiFEUOn`/;3oeMGE00;ooooo00?od];BoiZJV_nNWYh00onOWil01?nNWYko
W9bLoi^KVooOgml5ooooo`03olK6a_nJVY[oW9bL00OoWinO00?oVi^Kol30`?ooool0K?ooool01Ooo
iL[ook]goonB9_ooM`3oog/000gooh0000Kooh40oomm0?ooKP3ooi8Vooo[eoooo_hOooooo`03okZj
^_l0003o`L7105_ooooo00?of=SHo`000?n_[jl0Soooool00<gooooo00?oXj>So`000?oinOT0P_oo
ool00ommOGgo0000o`000008o`000003okno_ooooooooooo00Cooooo00CoPH61o`000?lk>c_ooOgm
1Oooool00omdM7Co0000o`00000Bo`000003oaDE5OoUiNGooooo00?ooooo00?o^k^ko`/;2ol00000
2?l000001?l71`Oo`l?3olc<c?l61PH:o`000003ob<S8ooalO7ooooo00?ooooo00?ojNWYoalO7ol0
00002Ol000001_l30`?obLW9oooooooooooon_[jocDe=@_o000000?oEUIFoooooomSHf<05?l00000
1?lN7Qkolo?cok6a/Ol51@D7o`000003oahN7_oZj^[ooooo00Cooooo00?o@D51o`000?nOWil01?oo
ool00oo`l?3o:2PXo`000009o`000003o`H61_l410Co000000Go000000?o10@4ohf=SOooool00ooo
ool00oogmoOo@410o`000009o`000003oemOGoooooooMWIf00_o000000?oFUYJooooooooool01?oo
ool00omnOWko0000o`000009o`000003o`L71oo<c<cooooo00?ooooo00?oY:BTob0P8?l000000_l0
00001OlD51CoDe=Coh:2P_maLG7o>3Ph00?o000000Go20P8oc<c<onFUYKoUIFEo`<30`07o`000003
ok2`/?oooooooooo00?ooooo00?oSHf=o`820_l000002?l000000omGEeOoooooooooo`1]ooooo`06
oooUbooo`hKooi0Qoome0?ooNP3oogl02OooP0001_ooO`3oogH0oomo0?oo/VKoonC8ooonoB3ooooo
00?o`<30o`T92Oo6a/H0Foooool00ooKfm_o0000okJf]P2?ooooo`00cOooool00onSXj?o0000ooWi
n@22ooooo`05ooKfm_o8b<SoalO7ok6a/Olo?cl00_l000001OlA4A7oVIVIolO7aoo?cloomoOg00Ko
oooo00CoGemOo`000?l0003o];Bd1Oooool01_ofm_Kob/[:olO7aonj^[[oQhN7oa`L70Co000000co
;2`/ojFUYOo7alOob<S8omOGeonFUYKo0`<3oa0@4?nc/k?of=SHomOGeooZj^X6ooooo`04onKVi_oG
emOodM7AoeaLG0Co000000?oNWYjom3@d?oRh^800_ooool01?oQhN7oemOGokbl_?m4A4@4o`000004
oc`l??nm_KgoeMGEonCTi0Kooooo00Gojn_[omKFe_o8b<SoIfMWo`820P03o`000005oaTI6OnYZJWo
dM7AomkNg_omoOd00oooool01Oo_knooemOGomCDe?nRXZ;o1`L700?o000000_o3`l?oiNGUooAdM7o
emOGon[Zj_ooooool_;bomOGeooBd];oZj^[obd];@03o`000003obPX:?nj^[[oalO700OoalO700Wo
ZJVYoahN7_l0003o0000ogalO?ooooooh>3PomKFe_n6QXH00_l000001?m;Bd_odm?ComSHf?o/k>`5
ooooo`05ooOgmolY:BWo0000ob/[:ooemOD01?ooool01Oodm?CoemOGomSHf?nm_Kgo8B4Q00?o0000
00go92@Tokbl_?oHf=SohN7QomoOgon7QhOo0@41o`000?m[Jf_oe=CDomSHf?oOgmoon_[j00Gooooo
00Gom_KfomWIfOoGemOoX:2Po`H61P03o`00000:ocLg=ono_koof=SHoo?cloooooool_;bomOGeoo@
d=3oXZ:Rob0P80?o000000Go10@4oiBDU?oCdm?oemOGonk^kP06ooooo`05oo_knooJf][oe]KFol?3
`omQHF400ol000001_l10@7oJFUYol_;booGemOog]kNoogmo@?ooooo00OoR8R8o`000?l0003o0000
o`P82?n2PX;okNg]00Cooooo00?odm?CoeMGEol000000ol000002_n][Jgog]kNokJf]_lK6a_o0000
obl_;oo7alOof=SHom[Jf_oinOT5ooooo`04oogmoOoMgMgoemOGohZ:RPCo000000Co30`<oinOWooC
dm?okNg]LOooool01Oooi/goolRAoonI=?ooN03oogX000Kooh0000Koogl0oomh0?ooNP3oojE=oooG
[_oon?4Rooooo`03ol30`?l92@Woa/K605_ooooo00?ofm_Ko`000?nf][H0Soooool00<gooooo00?o
Xj>So`000?okno/0Q_ooool01?oShn?o4a<Co`000?mZJVX:ooooo`05oc`l??l0003o0000oc`l??ol
o?`02Oooool00on^[Zko0000o`000002o`000003ol[:b_oooooooooo00?ooooo00?oK6a/oa<C4ooj
n_X03?ooool01OnHV9So0000o`000?l0003o?Shn00Sooooo00?og=cLo`X:2_l000000_l000000on@
T93oooooooooo`0;ooooo`05obh^;_l0003o0000o`000?mIFET02oooool01OmADE7o0000o`000?l0
003o?Shn00Wooooo00Go][Jfo`410Ol0003o0000ofATI00:ooooo`05omOGeolT92Co0000oa<C4ooT
i>@00oooool00oli>CWo0000oj2PX008ooooo`05on_[jol=3@go0000o`000?nNWYh02?ooool01OmO
Geoo0000o`000?l0003oQhN700Gooooo00?oHF5Qo`000?nXZ:P03?ooool01_oclo?o2`/;o`000?l0
003o10@4olO7a`Sooooo00KoX:2Po`000?l0003o0000oa8B4_o]kNd=ooooo`06ooclo?lX:2So0000
o`000?l820SoemOG1_ooool01_o6a/Ko0000o`000?l0003o20P8ojj^[PSooooo00GoVi^Ko`T92Ol0
003o0000ohV9R@02ooooo`03ok>c/ol0003oCTi>00cooooo00?of=SHo`000?l000000_l000000omj
NW[oooooooooo`1dooooo`05ooo]g?ood:7ooiL_oomh0?ooN@000_ooO0001_ooN@3oogH0oomh0?oo
XTOoomN`ooobiBCooooo00?o`<30o`T92Oo8b<P0Foooool00ooJf][o0000okRh^02?ooooo`00C?oo
ool01ooFe]KoLg=cobl_;olL71co;bl_og1`L?oEeMD01?ooool01_oTi>CoK6a/obXZ:_lR8R;oFe]K
ol[:bPCooooo00Go=3@doi^KVoooooooooooono_k`02ofYZJP;ooooo00?oclo?oc4a<Oo3`l<00ooo
ool00olZ:R[oZZZZooooo`02ooooo`06oo[jn_nATI7o;Bd]oa/K6omADE7o_[jn1?ooool01_oZj^[o
KVi^oahN7_lX:2SoLg=comoOg`;ooooo00?oE5ADogEeMOoclo<01oooool00onJVY[oADE5on3Ph003
ooooo`05oiNGUom4A4Co7AdModI6A_nKVi/02oooool01_no_kooB4Q8oa`L7?l`<33oWIfMooKfmP;o
oooo00?oc<c<ob/[:ooCdm<00oooool01olZ:R[o/[:booooooooooooZj^[oc`l??oKfm/00oooool0
1Oo0`<3oCTi>oadM7Om2@T;oUYJF00?ooooo00?oXZ:Rod51@OoKfm/00oooool02?nSXj?o0000ookn
o_n>SXko=3@doahN7_mNGUkodM7A0oooool00omSHf?oJVYZono_k`03ooooo`03ooShn?n1PH7oB4Q8
00?ooooo00Go/;2`ocHf=_lN7QkoPh>3ooknoP03ooooo`06ok^k^om2@T;o71`Loc8b<_nRXZ;onOWi
IOooool00omRHV;o0000ofEUI@09ooooo`03ooclo?lU9BGo000000;o000000?o/;2`ooooooooool0
1oooool00ooKfm_o30`<o`000002o`000003omOGeooooooooooo00?ooooo00?ohn?So`d=3One]KD0
3?ooool01Om]KFgo0000o`000?l0003oPh>300Sooooo00?oo?clob@T9?l000000_l000000omjNW[o
ooooooooo`0;ooooo`06of1PH?l0003o0000o`000?m4A4Coo_kn2_ooool01_n6QXKo0000o`000?l0
003o9bLWooGem@Sooooo00Goh^;Ro``<3?l0003o0000odU9B@0;ooooo`04omCDe?lG5aOo0000ogal
O0?ooooo00?oTY:Bo`000?moOgl02?ooool01Oo;bl_o0`<3o`000?l0003oDe=C00Sooooo00GoL71`
o`000?l0003o0000og=cL`05ooooo`03omSHf?l410CoDU9B00cooooo00Kobl_;o`410Ol0003o0000
oalO7oojn_X8ooooo`06olk>c_l0003o0000o`000?l=3@gofm_K3_ooool01OmDE5Co0000o`000?l2
0P;o_[jn00Kooooo00GoLG5ao`000?l0003o0000oi2@T00:ooooo`04ojn_[ol;2`_o0000of=SH`?o
oooo00?o>3Pho`/;2ooVi^H02oooool01_nYZJWo0000o`000?l0003o0@41okjn_WOooooo00[oookn
ooobi_oodjGook1QoonH<OooTbOook=Xooo5S?ooiL_oooG[5?ooool01onVYZKo:RXZoooooooooooo
dm?Cobl_;oo<c<`00_ooool00oo?cloo;bl_ol[:bP03ooooo`0;obXZ:_n^[Zkooooool30`?l>3Pko
`l?3okFe]Oli>CWo7AdMoe=CDoo1`L401Oooool01_n`/;3oB4Q8oa`L7?ld=3CoUYJFooWin@?ooooo
00?o>3Phoi6ATOooool00oooool00ooXj>SoFEUIoh:2PP09ooooo`08olC4a?mIFEWo7AdMocLg=on]
[Jgodm?Cog1`L?oEeMD2ooooo`05oc0`<?nKVi_oooooooooooo_knl00_mZJVX3ooooo`08oo;bl_nG
UiOo;2`/oadM7OmZJV[of=SHojZZZ_mgMgL9ooooo`0;om?CdomJFU[o7AdMobDU9On=SHgokno_oooo
ooo>c/ko<C4aofUYJOobl_800oooool02oo0`<3o9BDUogemOOoWinOo0000okJf]_nn_[ko@d=3oa`L
7?m:BT[o][Jf00Gooooo00Ko_Kfmoe1@D?lL71co;Rh^ohn?Soobl_83ooooo`03odi>C_n1PH7on?Sh
00?ooooo00?olO7aofYZJ_mSHf<02Oooool02?o=cLgoHf=SoadM7Ola<C7oXZ:RomWIfOmiNGWo_[jn
0oooool03?nk^k_oATI6oadM7Om6ATKo/[:bonWYjOmWIfOodm?CoooooooEeMGo=CDeok^k^`?ooooo
00Sog=cLodi>C_lN7Qko?3`lokJf]_oJf][oKfm_om_Kf`Oooooo00?ok^k^obXZ:_nj^[X00_ooool0
0onJVY[oBTY:on3Ph003ooooo`03ocPh>?nFUYKooooo03?ooooo001:ooooo`0DooShn?mZJV[o20P8
oaLG5omQHF7oMgMgoeIFE_l51@Go20P8oiBDU?omoOgoo_knolS8b?l@413o5QHFofEUIOm[Jf_o:b/[
o`T92OnIVIT3ooooo`05o`X:2_n7QhOoooooooooooo/k>`00_m;Bd/2ooooo`03olG5aOl61PKo][Jf
00?ooooo01[o0000oiRHV?oooooooooooo3`l?mYJFWo0000odI6A_n0P83o<S8bo`T92On<S8cono_k
oooooooHf=So4a<Coa@D5?m`L73oH61Po`/;2omHF5Solo?coooooola<C7oF5QHoo7al@Oooooo00go
QHF5oalO7ooJf][ooooooo[jn_m5ADGo1@D5oda<C?m_KfooBd];o`@41?mADE7oo?cl00Sooooo00co
/k>co`X:2_lM7AgoNWYjoeUIFOl20P;oAdM7onGUiOoooooo`L71o`000?o9bLT3ooooo`07o`000?nR
XZ;ooooooooooonIVIWo51@DomCDe002ooooo`07ogemOOl820So=cLgofm_Kom?Cdoo0000oeiNGP02
ooooo`03ohn?SolJ6Q[oe=CD00?ooooo00WoXj>So`H61_m5ADGo3@d=of][JomWIfOo6QXJoa4A4OnX
Z:P00_ooool00om2@T;oBd];onc/k003ooooo`03ooOgmomVIVKo8R8R00;ooooo013oSXj>o`H61_m?
CdooJFUYo`H61_miNGWom_KfoooooonXZ:So2@T9ob<S8omlO7coEUIFo`000?mADE7oj>SXI?ooool0
1?ne]KGo0000ocTi>OomoOd8ooooo`03ono_kolN7Qko000000;o000000?o>CTioo_knoooool01ooo
ool00oofm_Ko7AdMo`000002o`000003okVi^Ooooooooooo00Cooooo00?o?Cdmod];Boooool02ooo
ool01Oln?Sko0000o`000?l0003o`L7100Wooooo00GoC4a<o`000?l0003o0000oeaLG00=ooooo`06
ohZ:R_l0003o0000o`000?l/;2comOGe2_ooool01_nZZZ[o0000o`000?l0003o3@d=on[ZjPSooooo
00Kon_[job@T9?l0003o0000obLW9oogmoL;ooooo`04okRh^?l410Co61PHon[ZjP;ooooo00?oemOG
o`410Om<C4`02?ooool01_nSXj?o0000o`000?l0003o6a/Koo7al@Oooooo00GoQ8B4o`000?l0003o
0000oeMGE`06ooooo`03oe9BD_l30`?ofm_K00_ooooo00GoX:2Po`000?l0003o0000oeUIF@09oooo
o`06onk^k_lH61So0000o`000?l71`Ooclo?3_ooool01OmkNg_o0000o`000?l0003oYjNW00Gooooo
00Kojn_[oadM7Ol0003o0000oc@d=?olo?`;ooooo`03ojRXZ?l0003o>c/k00?ooooo00?o[Zj^o`00
0?nFUYH02oooool01_miNGWo0000o`000?l0003o5aLGonSXj7Wooooo00Kooogkoooilooom^goooK/
ooojm?ooo?TFooooo`07oi>CTol0003oooooooooooo9bLWo0`<3ol71`@02ooooo`03olG5aOl30`?o
_kno00?ooooo01Oo0000oifMWOoooooo`l?3o`410Ol];Bgo51@DoeeMGOmcLg?o7alOo`X:2_nBTY;o
no_kooooooono_koIfMWo`@41?l];BgoOgmoodU9BOl0003oC4a<onGUi@02ooooo`03o`l?3omkNg_o
oooo00?ooooo00?ohn?SocLg=omWIfL02?ooool02OnGUiOo2PX:oaTI6OmcLg?oGUiNoaHF5_l[:b_o
1PH6okbl_002ooooo`05o`@41?n7QhOoooooooooooo/k>`00_m;Bd/2ooooo`09omoOgolo?coo0000
odi>C_mcLg?o>c/ko`P82?lm?Cgo8R8R00Sooooo01coaLG5oaLG5olA4A7oLg=cofIVI_l:2P[o=CDe
om_KfooinOWoNg]ko`000?nDU9Coo_knooooooo_knoo:2PXoalO7oo_knoogMgMo`000?lf=SKo3`l?
oeIFE_meMGGo:2PXo`H61_mlO7com_Kf0_ooool02?mgMgOo1`L7obDU9OmlO7coEEEEo`000?ll?3co
f=SH0_ooool00olY:BWoIVIVooOgm`03ooooo`03onk^k_m;Bd_o@T9200Sooooo00Wo[Jf]o`d=3OlA
4A7oKFe]of9RH_lL71co820Po`X:2_nHV9P00_ooool03OmoOgoo1`L7obh^;_m`L73oFe]KoadM7Olg
=cOo7QhNolK6a_ooooooc<c<o`/;2on][Jd00_ooool02Onm_Kgo4a<CoaLG5omWIfOoH61Poa`L7?l/
;2co;Rh^om3@d007ooooo`03on_[jol0003o[:b/00;ooooo00?oQHF5obDU9OoJf]X00oooool00ol?
3`ooPH61ooooo`0cooooo`00BOooool04?oalO7oAdM7o`@41?n1PH7okno_ooWinOojn_[on?Shoo7a
lOn<S8coOGemooclo?ono_ko61PHocHf=_o]kNd2ooWin@04ooGemOmUIFGo10@4olG5a@;ooooo00Go
30`<ohR8R?ooooooooooonc/k002ode=C@;ooooo00?oa/K6o`T92Ong]kL00oooool06_l0003oVIVI
oooooooooooo/;2`o`410On;Rh_omoOgoo[jn_ofm_KoEeMGo`000?oKfm_oooooobHV9_ln?Skom?Cd
oo[jn_oinOWobLW9oi:BT_oTi>Cooooooc<c<omJFU[olO7a1oooool03On6QXKo8B4Qom[Jf_oooooo
IFEUo`P82?nk^k_om_KfooWinOofm_Ko]KFeo`@41?m]KFd02?ooool03?lL71coA4A4oo;bl_ojn_[o
n?ShojJVY_l0003oLG5aooooooo3`l?o0P82ol[:bP?ooooo01Go0000oj>SXooooooooooooiZJV_lF
5QKoe=CDoooooooAdM7o4Q8BofQXJ?o]kNgonOWiooKfm_n][Jgo0000oiBDU?ooooooT92@oa`L7?oD
e=@00oooool01?nSXj?o1`L7obPX:?o[jn/2ooWin@08om_Kfoln?Sko;2`/omkNg_ooooooA4A4ode=
COo/k>`3ooooo`0EooOgmomXJ6So92@ToooooooalO7oGUiNofUYJOohn?SonOWiohZ:R_lI6AWoj>SX
ooOgmolD51CoBDU9ooGemOojn_[on?ShoiZJV_l0003oNGUi06Cooooo00Cokno_oaHF5_l<30coi^KV
2?ooool00ooNg]ko4a<Co`000003o`000003ojf][Ooooooooooo00Oooooo00Go<c<co`000?l0003o
0000oj2PX006ooooo`03ogmoOol10@7of][J00[ooooo00Kokno_oaPH6?l0003o0000o``<3?oVi^H9
ooooo`06ogIfM_l0003o0000o`000?m5ADGoo_kn3?ooool01_n[Zj_o0000o`000?l0003o4A4Aon_[
j`[ooooo00Koc/k>o`L71ol0003o0000o`<30oo?cll9ooooo`05ode=COl0003o0000o``<3?oXj>P0
3?ooool00on:RX[o0000oh>3P`03ooooo`03ocLg=ol@413olO7a00Oooooo00?oNGUio`000?l00000
0_l000000onEUIGoooooooooo`05ooooo`06oijNW_l0003o0000o`000?ln?Skoo_kn1Oooool00oo7
alOo0000ogMgM`0;ooooo`05ofa/K?l0003o0000o`000?nCTi<02Oooool01_okno_o>CTio`000?l0
003o0P82ol;2`Pkooooo00GoXJ6Qo`000?l0003o0000ohZ:RP05ooooo`05ojFUYOl0003o0000o`00
0?nGUiL03Oooool00om]KFgo3Ph>ong]k@02ooooo`04ooOgmolW9bOo:2PXooShn0[ooooo00GoDe=C
o`000?l0003o0000ochn?P2Fooooo`07oiBDU?l0003oooooooooooo:b/[o1PH6ol;2`P02ooooo`03
olK6a_l61PKo`<3000?ooooo01_o0000oijNW_ooooooaLG5o`000?lY:BWo`L71ooShn?ojn_[omOGe
oe1@D?l51@Goh>3Poooooong]kOo0@41oh:2P_ofm_Kon_[jooOgmon`/;3o1PH6ogUiNOogmoOooooo
oa4A4OmlO7`01?ooool00ooShn?o>CTiofUYJ@07ooooo`0:onc/k?l92@WoBTY:ooCdm?ojn_[on?Sh
om;Bd_le=CGo0000okfm_@;ooooo00Go1`L7ohR8R?ooooooooooonc/k002ode=C@;ooooo00WoJf][
o`<30ona/K7on?Shoo[jn_ofm_KoQhN7o`410OlR8R802?ooool0:olb<S;o;2`/omoOgoojn_[onOWi
olC4a?l0003oAdM7ooooooodm?CoD51@o`T92OoCdm?ooooooe]KFol51@Godm?CoooooooMgMgo0000
oa/K6onf][Kon?Shoo[jn_oemOGoJ6QXo`@41?o=cLgoooooolS8b?l30`?oK6a/ooGemOojn_[on?Sh
okjn__lB4Q;oG5aLooGemOoooooo:b/[ofQXJ?ogmoL00oooool00oo^k^koCDe=odA4A007ooooo`04
oo_knolH61So>SXjooCdm0;onOWi01?ofMWIodI6A_l0003oVYZJooooooo6a/Ko3Ph>ofEUIOoclo?o
n_[jooShn?o4a<Co2@T9oadM7Oo6a/Koooooolg=cOl=3@go[Zj^00;ooooo00Wo:2PXobHV9_o/k>co
nOWiooShn?o<c<co6ATIobTY:Oo@d=001oooool00oo[jn_o0000ojf][@02ooooo`03ohJ6Q_lW9bOo
f][J00?ooooo00?o4A4Aoh:2P_ooool0<oooool004Sooooo00Con_[johJ6Q_l10@7oY:BT1oooool0
1OoQhN7ooooooj6QXOl71`Oofm_K00Cooooo00Ookno_obh^;_mRHV;olo?cooooool<30coR8R800;o
oooo00?ok>c/ode=COm=CDd00_ooool00oo6a/Ko2@T9okNg]`03ooooo`07o`000?nIVIWoooooong]
kOmDE5Co?Shnooooo`03oogmo@06onOWiooMgMgoooooojf][Ol0003oe=CD1oooool00olc<c?oFUYJ
oo7al@07ooooo`07ohJ6Q_lQ8B7ohn?SomoOgolB4Q;oUYJFoo_kn`03ooooo`04oo[jn_n7QhOo5aLG
omgMg@Kooooo00CoZ:RXo`000?o[jn_oo_kn0_omoOd01oodm?Cofm_Koo3`l?oooooo`/;2o`820_o:
b/X00oooool04?l0003oXj>SooooooooooooVYZJoaHF5_oDe=Cooooooh20P?lL71cog]kNookno_om
oOgoo_knooWinOo4a<@2ooooo`03oi2@T?lL71coe=CD00?ooooo00?oXj>So`000?nj^[X01?ooool0
1onh^;So2PX:oj>SXoooooooA4A4ode=COo/k>`00oooool00oogmoOoJ6QXob@T9004ooooo`08ookn
o_okno_oOgmoo`@41?o]kNgoWIfMo`820_o_knl3oogmo@03oo;bl_oKfm_olO7a06Gooooo00?oG5aL
o`000?nm_Kd02?ooool00oo>c/ko20P8o`000003o`000003oc4a<Oohn?Sooooo00Oooooo00GoCdm?
o`000?l0003o0000oh>3P`06ooooo`03olo?col0003oKVi^00[ooooo00KoalO7o`H61_l0003o0000
ob8R8_o`l?09ooooo`06oibLW?l0003o0000o`000?l[:b_om?Cd3?ooool01_o<c<co1PH6o`000?l0
003o0P82omGEe@[ooooo00?olO7aoa<C4ol000000_l000000ona/K7oooooooooo`07ooooo`05ogAd
M?l0003o0000o`<30oo8b<P03Oooool00ommOGgoUiNGooooo`02ooooo`03oh:2P_l0003o`<3000Oo
oooo00OoDe=Co`000?l0003o0000o`@41?lM7AgokNg]00Kooooo00Ko^[Zjo`410Ol0003o0000obHV
9_oinOT6ooooo`03od10@?l@413ok^k^00Wooooo00Koo_knod=3@ol0003o0000o`<30oo2`/8:oooo
o`05oeUIFOl0003o0000o`000?nf][H03_ooool01Oo8b<So0000o`000?l0003oJf][00Gooooo00Go
H61Po`000?l0003o30`<omOGe`0=ooooo`03ooCdm?lR8R;oXZ:R00?ooooo00?oVIVIo`000?n][Jd0
2Oooool00oomoOgo?Cdmo`000002o`000003ogIfM_oooooooooo09Cooooo00OoU9BDo`000?oooooo
oooool[:b_l61PKo`/;200;ooooo00?oa/K6o`H61_o0`<000oooool01_l0003oWYjNooooooo4a<Co
0000oh20P0Cooooo00KogmoOo`/;2onEUIGoooooodM7Aolh>3P5ooooo`06ogQhN?lS8b?oe=CDoooo
oolA4A7oO7al1?ooool00ooShn?o>CTiofUYJ@07ooooo`03oj:RX_l71`Oofm_K00Cooooo00?oTi>C
o`000?nk^k/00_ooool01Ol71`OoR8R8ooooooooooook>c/00;oCDe=00Goooooon?SholW9bOoLG5a
ooKfmP03ooooo`03ooclo?lU9BGo7QhN00Oooooo00?o_[jno`000?o<c<`00oomoOd00ooinOWog=cL
on_[j`02ooooo`06omWIfOlW9bOoCTi>oh20P?l30`?oTY:B0_ooool00ooLg=co0000of9RHP04oooo
o`06onWYjOlL71coP820oooooomFEUKo:BTY1Oooool01onHV9So61PHol?3`ooooooo:b/[ofQXJ?og
moL00oooool00oo^k^koCDe=odA4A007ooooo`03ok>c/ol0003oclo?00Cooooo00Oo[Zj^o`410OnG
UiOoooooofm_KolA4A7ojn_[00Cooooo00_oYjNWo`T92Oo6a/Koooooolg=cOl=3@go[Zj^ooooooo2
`/;o0@41okZj^P04ooooo`03ohb<S?lJ6Q[od=3@00Oooooo00?ojn_[o`000?n][Jd00_ooool00on6
QXKo9bLWom[JfP03ooooo`03oa4A4On2PX;ooooo03?ooooo0018ooooo`03on[Zj_l92@WoOgmo00[o
oooo00?oP820oa8B4_ooool01Oooool01_m?CdooA4A4onc/k?oooooo30`<ohR8R0;ooooo00?ok>c/
ode=COm=CDd00_ooool00oo6a/Ko2@T9okNg]`03ooooo`07o`000?nIVIWoooooonWYjOm:BT[o;bl_
okZj^P03ojNWY`05ojVYZOnVYZKoj^[Zoh^;Rol30`<02?ooool00olc<c?oFUYJoo7al@07ooooo`06
ohJ6Q_lQ8B7oinOWol?3`ol10@7oe]KF1Oooool00oo4a<Co1@D5olC4a006ooooo`03oiRHV?l0003o
/K6a00?oYjNW00OoZ:RXojNWYoo8b<Sooooool?3`ol20P;ob/[:00?ooooo00co0000oj>SXooooooo
oooooiZJV_lF5QKoe=CDoooooom6ATKo>SXjoijNW_nXZ:P2ojNWY`07ojRXZ?n[Zj_o_Kfmoooooon@
T93o71`LomCDe003ooooo`03oj>SXol0003ooOgm00Cooooo00Oog=cLoc8b<_mkNg_oooooodA4A?m=
CDgok>c/00?ooooo00?omoOgofQXJ?lT92@00oooool02Oofm_Koa<C4oeIFE_l0003oMGEeookno_n=
SHgo0P82ok>c/`03ojNWY`04ojRXZ?nWYjOob/[:oo_knfCooooo00?oYZJVo`000?mlO7`02?ooool0
2?nn_[ko0@41o`000?l0003o0P82oaDE5Ol0003oVYZJ2?ooool01Om/K6co0000o`000?l0003oIfMW
00Oooooo00?oCTi>o`/;2ooWinL02Oooool01_nGUiOo0000o`000?l0003o>3Phoo_kn`Wooooo00Ko
_;blo`820_l0003o0000o`d=3OoXj>P<ooooo`03oo3`l?lE5AGo000000;o000000?o]KFeoooooooo
ool02?ooool00oono_ko=3@do`000002o`000003oiBDU?oooooooooo00Oooooo00GoUiNGo`000?l0
003o0000ojFUY@0Booooo`03ol[:b_l0003oQ8B400Kooooo00?onOWiobXZ:_l000000_l000000om8
B4So0@41ohB4Q006ooooo`06omCDe?l410Co0000o`000?l@413okNg]1_ooool00onf][Ko0000ohV9
R@09ooooo`06onk^k_lE5AGo0000o`000?lF5QKokno_2_ooool01OmoOgoo0000o`000?l0003oZJVY
00kooooo00Goj>SXoa0@4?l0003o0000oda<C004ooooo`06ooWinOla<C7o0000o`000?lU9BGoo?cl
3_ooool00onJVY[oXZ:Rooooo`02ooooo`04oo?clolG5aOo=cLgoo_kn`Sooooo00?ol_;bobXZ:_l0
00000_l000000on_[jooooooooooo`2Dooooo`07oiBDU?l0003oooooooooooo:b/[o1PH6ol;2`P02
ooooo`03olK6a_l61PKo`<3000?ooooo00Ko0000oijNW_oooooo`L71o`@41?nn_[h5ooooo`05oaPH
6?mcLg?oooooo`T92OnBTY801Oooool01_nl_;co410@okbl_?oooooo4A4AogalO0Cooooo00?ohn?S
ocTi>OmYJFT01oooool00on0P83o4Q8Booooo`04ooooo`03olg=cOl>3Pko]kNg00;ooooo00Go1`L7
ohR8R?ooooooooooonc/k002ode=C@04ooooooo?cloo4A4AojRXZ0Cooooo00?oo?clogYjN_lG5aL0
1oooool00on`/;3o0P82oibLW003ojNWY`04ojRXZ?nYZJWo_[jnooShn0;ooooo00Co]KFeoa<C4ol0
003oEeMG0oooool00ooKfm_o0000ojf][@05ooooo`05ocDe=OmOGeoooooooa8B4_n2PX801Oooool0
1oo<c<co7QhNoj6QXOoooooo:b/[ofQXJ?ogmoL00oooool00oo^k^koCDe=odA4A007ooooo`03oi:B
T_l0003ooooo00Cooooo00Oof][JoahN7_n@T93oooooocPh>?mKFe_olo?c00Cooooo00_o`/;2o`L7
1oo6a/Koooooolg=cOl=3@go[Zj^oooooonQXJ7o0000oogmo@04ooooo`03ojJVY_lG5aOod=3@00Oo
oooo00?ojn_[o`000?n][Jd00_ooool00on6QXKo9bLWom[JfP03ooooo`03oa4A4On2PX;ooooo03?o
oooo0017ooooo`04ookno_n[Zj_o1@D5omgMg@[ooooo00?oQHF5oa0@4?olo?`01?ooool01oomoOgo
B4Q8odU9BOo]kNgoooooo``<3?n2PX800_ooool00oo/k>coCDe=oe1@D002ooooo`03olK6a_l92@Wo
][Jf00?ooooo00Oo0000oiVIVOooooooj^[ZoeEEEOl410Co4a<C00;o4Q8B00Oo4a<Co`P82?l0003o
[Zj^ohn?Sol20P;ono_k00Oooooo00?o<c<coeYJF_oalO401oooool01_n6QXKo8B4QonOWioo8b<So
0`<3olc<c0Gooooo00?o^;Rho`P82?o9bLT01_ooool00onLW9co0`<3oa4A4@02oa8B4P08oa<C4ol?
3`oo0000ode=COomoOgoa/K6o`820_o9bLT3ooooo`0Eo`000?nSXj?ooooooooooonJVY[o5QHFomCD
e?ooooooIfMWo`000?lA4A7o4a<Coa8B4_lC4a?o4Q8Bo`000?m3@d?ooooooi2@T?lH61SodM7A00?o
oooo00?oXj>So`000?obl_801?ooool01ooLg=co=cLgoh61POooooooADE5odQ8B?o[jn/00oooool0
0oogmoOoJ6QXob@T9002ooooo`09onc/k?mQHF7o0000oaHF5_moOgooo?cloooooonBTY;o000000?o
4Q8B00Go4a<Co`h>3_l0003oDe=CooCdm01Tooooo`03onKVi_l92@WoADE500Sooooo00Wo[jn_o`00
0?l0003o0000o`410OnMWIgo5QHFob4Q8Oodm?@01oooool01On8R8So0000o`000?l0003oD51@00Oo
oooo00?o`/;2o`000?moOgl02Oooool01OmUIFGo0000o`000?l0003oCdm?00[ooooo00?og=cLo`h>
3_l000000_l000000oo@d=3oooooooooo`0:ooooo`03ookno_l`<33o000000;o000000?oTi>Coooo
ooooool02Oooool01OmHF5So0000o`000?l0003oMGEe00Wooooo00Go^;Rho`000?l0003o0000ohF5
Q@06ooooo`03on;Rh_ni^KWoo_kn00Wooooo00?on_[job8R8_lm?Cd01_ooool00ooShn?o2PX:o`00
0002o`000004oj6QXOmBDU;o4Q8Bonc/k0Gooooo00Kojn_[o`d=3Ol0003o0000o`T92OoCdm<6oooo
o`04ooclo?lc<c?o51@Doo;blPSooooo00Goa<C4o`000?l0003o0000oclo?`0;ooooo`05oj6QXOl0
003o0000o`000?nKVi/03_ooool01OoemOGo;Bd]o`000?l0003o:BTY00Cooooo00Gojn_[oaPH6?l0
003o0000od92@P0Eooooo`03ohB4Q?l0003o^;Rh00Sooooo00Koi^KVoaHF5_l0003o0000o`/;2ooE
eMFFooooo`07oiBDU?l0003oooooooooooo:b/[o1@D5ol30`002ooooo`03olG5aOl51@Go`L7100?o
oooo00Ko0000oijNW_oooooo`<30o`P82?o0`<04ooooo`06ooclo?lF5QKoMWIfoooooolS8b?oP820
1Oooool01_n_[joo7QhNolC4a?oooooo4A4AogIfMPCooooo00?ohn?SocTi>OmYJFT01oooool00on5
QHGo410@ooclo004ooooo`03olC4a?l;2`_o]kNg00;ooooo00_o1`L7oh:2P_ooooooooooonc/k?m=
CDgoD51@oooooooBd];o51@DoijNWP04ooooo`03oogmoOm]KFgo61PH00Oooooo00[o];Bdo`l?3ol?
3`oo4a<Coa8B4_lC4a?o4A4Ao`000?l/;2cojn_[0_ooool01OoPh>3o:b/[o`000?nBTY;ono_k00;o
oooo00?ofm_Ko`000?n_[jl01?ooool01_omoOgo<C4aof9RH_oooooo;Bd]og5aL@Gooooo00Oo`/;2
obHV9_n][Jgoooooob`/;?mRHV;omoOg00?ooooo00?ok^k^ode=COm4A4@01oooool00onGUiOo0000
oo[jnP04ooooo`07omCDe?lH61SoTI6Aoooooom0@43oFUYJooCdm004ooooo`0;ol?3`olB4Q;oa<C4
ooooooo=cLgo3@d=ojj^[_ooooooYZJVo`000?oemOD01?ooool00onXZ:So8R8Rolo?c`07ooooo`03
on_[jol0003o[Jf]00;ooooo00?oQhN7ob<S8ooGemL00oooool00olA4A7oPX:2ooooo`0cooooo`00
Aoooool00oolo?coKVi^oaTI6@0;ooooo`03ok^k^ol20P;o/k>c00Cooooo00OoalO7oa@D5?mkNg_o
m_Kfooooool@413o@41000;ooooo00?oj>SXochn?_m`L7000_ooool00oo6a/Ko3@d=oiNGU`02oooo
o`07ooShn?l0003oVYZJooooooofm_KoLg=coc4a<@04ooooo`06oibLW?l410CofMWIolG5aOl10@7o
[jn_0oooool01oolo?cojn_[ooShn?oooooo=3@doeaLG?oemOD01oooool01on9RHWo8R8RonGUiOo/
k>co8B4Qofa/K?oemOD00oooool01?o`l?3oDU9BobTY:OoXj>P6ooooo`03olc<c?l0003og=cL00?o
oooo00Oohn?Sob8R8_m^KVkooooool?3`ol61PKoYjNW00;ooooo00?omOGeo`000?nTY:@00_ooool0
1onMWIgo5QHFomSHf?ooooooUIFEoaPH6?oPh>000oooool01oo`l?3o30`<ohJ6Q_ooooooUIFEo`00
0?n_[jl00oooool00onSXj?o0P82ohn?S`04ooooo`07oinOWolA4A7o/[:boooooom<C4co5QHFomkN
gP03ooooo`03ooOgmomXJ6So92@T00;ooooo00?oX:2Po`<30omnOWh01?ooool00oo2`/;o0000on7Q
h@03ooooo`03omSHf?lI6AWoMWIf06Kooooo00?o?ShnobLW9ooinOT01oooool02On=SHgo0000o`00
0?l0003o3@d=oo7alOn:RX[o0000oiNGU`07ooooo`06oinOWol0003o0000o`000?lk>c_oo?cl1ooo
ool00olg=cOo4A4Aon_[j`08ooooo`05oc0`<?l0003o0000o`000?mTI6@02_ooool00ooinOWo7AdM
o`000002o`000003ojj^[_oooooooooo00_ooooo00GoDe=Co`000?l0003o0000ogMgM`0;ooooo`05
ogUiNOl0003o0000o`000?mGEeL02Oooool01OoIfMWo1`L7o`000?l0003oIfMW00Kooooo00?oPX:2
o`000?oWinL02_ooool00om^KVko1@D5onc/k005ooooo`09okVi^Ol0003o0000o`000?l20P;odM7A
om3@d?l0003oOgmo00Gooooo00Kom?Cdob<S8ol0003o0000o`410Ono_kl7ooooo`03oj>SXol0003o
UYJF00Sooooo00GoTY:Bo`000?l0003o0000ogAdM00;ooooo`05olC4a?l0003o0000o`000?n2PX80
3_ooool01_ono_koBDU9o`000?l0003o5aLGong]k@?ooooo00Goh>3Po`D51Ol0003o0000odE5A@0E
ooooo`03onOWiol;2`_oATI600Sooooo00Koh>3Po`@41?l0003o0000ob@T9?ohn?RFooooo`07oiBD
U?l0003oooooooooooo;bl_o0000oiRHV002ooooo`03ojj^[_l0003o/K6a00;ooooo00SomoOgo`00
0?nOWiooooooolC4a?l0003oKVi^oo[jnP?ooooo00Oo_Kfmo`820_nJVY[oooooofATI?lM7Agoj^[Z
00?ooooo00Oom_Kfoe=CDolc<c?og]kNoooooolF5QKo>CTi00Cooooo00?oi^KVocXj>_m[Jf/01ooo
ool00onf][Ko0@41okRh^003ooooo`04ookno_n1PH7o0000ok^k^`;ooooo00co2PX:od10@?oooooo
ooooonSXj?ln?SkoL71`ooooooo/k>co=CDeodm?Coo^k^h3ooooo`03onWYjOlN7Qko7QhN00Oooooo
00?ogMgMo`H61_nj^[X00oooool00oojn_[o=cLgodM7A`02ooooo`06ooGemOmEEEGo8b<SocDe=Ol:
2P[oaLG50_ooool01?oLg=co0000oe=CDoohn?P3ooooo`07olg=cOl@413oQXJ6oooooomeMGGo410@
onGUi@03ooooo`08oo[jn_mbLW;o8B4Qom;Bd_oooooo<c<cobPX:?odm?@3ooooo`03oo7alOm?Cdoo
ADE500Oooooo00?oalO7o`000?nYZJT01?ooool01onKVi_o0000oiNGUoooooooQhN7o`820_o?cll0
0oooool03?oinOWoOGemo``<3?o6a/Koooooom3@d?l=3@go/K6aoooooooEeMGo0`<3oj2PX0?ooooo
00Coo?clofe]KOlL71cod=3@1oooool00oo[jn_o0000ojf][@02ooooo`03ohf=SOl10@7o^[Zj00;o
oooo00?oo?clo`l?3on3Ph<0=?ooool004Oooooo00?oo?clog9bL_lH61P03?ooool02Oln?Sko4Q8B
okNg]ooOgmoohN7QolK6a_lj>S[o71`LomWIf@02ooooo`07oa4A4Ol30`?o]kNgonCTi?nYZJWo2`/;
oiZJVP02ooooo`08olK6a_lI6AWo9bLWokno_ooUiNGoTY:Bo`000?o4a<@2ooooo`0Gol?3`ol;2`_o
DE5AomCDe?oVi^Ko]KFeo`l?3om<C4con?Shoooooom?Cdoo6QXJokbl_?oShn?ogMgMoiBDU?mcLg?o
jNWYooCdm?l/;2coCdm?omCDe?ofm_H01Oooool03_ohn?SoLg=coa`L7?nm_Kgom_Kfoh^;Rol0003o
Q8B4om?CdooShn?od];BogmoOol10@7oTi>C2?ooool0>oll?3co4A4Aol71`OoVi^Koc/k>odi>C_l?
3`ooaLG5ooooooo2`/;o4Q8Bobl_;oo3`l?oi>CTohN7Qol0003obl_;ooooooojn_[oQHF5oa<C4oni
^KWol?3`on?SholP823o?Cdmol?3`ooShn?oa/K6oclo?olN7Qkofm_KoooooonIVIWo0000ofMWIooJ
f][ogmoOooclo?nTY:Co20P8oaLG5on_[jooh>3PomoOgonVYZKo7alOodM7Aoo[jn_ooooooe5ADOl0
003oU9BDon3Ph?oNg]koooooooOgmomXJ6So92@T00;ooooo013oTY:BoaPH6?nl_;cofMWIoginO_oA
dM7ooOgmookno_l`<33o5ADEolG5aOoVi^Koc<c<odA4A?lG5aOob/[:I_ooool00onFUYKo2PX:onKV
iP07ooooo`0:oeQHF?l0003o0000o`000?lg=cOooOgmono_kolT92Co6QXJonOWi`Kooooo00Ko^;Rh
o`410Ol0003o0000obHV9_o`l?07ooooo`05okJf]_l0003oA4A4ogYjN_m`L7001?maLG400ombLW;o
JVYZo`T92@03o`000003oiBDU?oooooooooo00Wooooo00Go@D51o`000?l0003o0000ohF5Q@0=oooo
o`05ogUiNOl0003o0000o`000?mADE402oooool01_nNWYko0000o`000?l0003o=3@doo_kn`Sooooo
00KomOGeoaXJ6_l0003o0000od10@?omoOd5ooooo`03oh20P?l0003oc<c<00[ooooo00?o_[jno`00
0?nSXj<01Oooool02_n<S8co0000o`000?l0003o6ATIoo;bl_ooooooEeMGo`H61_oDe=@4ooooo`03
ooclo?ln?Sko000000;o000000?oXj>Sooooooooool01Oooool01OogmoOo<S8boa4A4OmdM7CoLW9b
00CoLG5a00?oL71`ogMgMola<C400ol000000onXZ:Soooooooooo`09ooooo`05onGUiOl<30co0000
o`000?mGEeL03oooool01Om[Jf_o0000o`000?l71`Oob/[:00?ooooo00Gog=cLo`000?l0003o0000
odE5A@0Fooooo`04ogmoOol0003oKFe]og9bLPGoLG5a00?oM7AdoeIFE_l000000_l000000omJFU[o
ooooooooo`2Eooooo`0[oiBDU?l0003oooooooooooo=cLgo0000oc/k>oo@d=3og=cLoe=CDol10@7o
>CTiolS8b?oUiNGoQhN7o`000?o8b<SoooooolG5aOl0003o5aLGoh^;RooJf][oiNGUol;2`_lY:BWo
8R8Ronk^k_ooooooclo?o`l?3omADE7ob<S8onWYjOoDe=CoN7Qho`820_nFUYKono_koooooolI6AWo
2@T9okfm_@02onCTi006ooooooo?cloo<30`oeaLG?o[jn_onOWi1Oooool02_ofm_Ko8R8RobDU9Oo0
`<3oi>CTom_KfonIVIWo7alOo`000?nl_;`2ooooo`07o`T92Ol30`?o]kNgonCTi?nYZJWo2`/;oiZJ
VP02ooooo`09ohR8R?l0003oNWYjomKFe_oTi>Cob/[:oe=CDol51@Go8R8R00Sooooo03?oDe=Co`41
0OnZZZ[oi>CTomGEeOmZJV[o10@4ojj^[_oooooooOgmoi:BT_l30`?oX:2PonKVi_lX:2So;Bd]onSX
j?oooooogMgMo`000?lB4Q;oOgmoomOGeooUiNGoa/K6ocdm?OlH61Sog]kNoooooooOgmoo5QHFochn
?_o5aLGoj>SXomWIfOn4Q8Co1@D5ogYjN_olo?coooooocPh>?l0003oZJVYon;Rh_oQhN7oooooom_K
fom1@D7o?3`lon_[joogmoL01_ooool08olf=SKo5aLGokbl_?oRh^;ogMgMoj>SXolX:2So0000oiZJ
V_oooooofm_KoaPH6?lj>S[o`L71onCTi?oHf=SoShn?o`000?lL71coalO7ookno_ni^KWo2PX:oiVI
VOo[jn_oooooodM7Aol820So^KVion3Ph?oKfm_oUYJFo`T92OlY:BWod=3@00Oooooo00?ojn_[o`00
0?n][Jd00_ooool02?n?Shoo0000of=SHooEeMGohn?SoijNW_l0003o[Jf]=?ooool004Oooooo00Co
oOgmohZ:R_l?3`oom?Cd2oooool02?oQhN7o?Cdmo`h>3_lf=SKo>3PhoaTI6Ol/;2co_;bl0oooool0
1olL71co>c/kob8R8_ln?Sko4a<Cod=3@ooNg]h00_ooool01oo4a<Co:2PXoc@d=?li>CWo?Cdmo`<3
0om:BTX00oooool05oohn?SoTI6Ao`l?3olN7Qko?clooa<C4oll?3coeMGEookno_ooooookNg]od92
@_l=3@go>SXjoc4a<Ol92@WoLW9boooooon?Shoo20P8oa4A4Ol`<33o`<3000Gooooo00go_[jnoaDE
5Ol51@Go:2PXoi^KVoomoOgoMgMgoa<C4ol[:b_o>CTiob/[:olD51CoPH6100Wooooo00OodM7Aobd]
;Ol61PKo@410obLW9olP823oVIVI00;ooooo00Oo`<30ob4Q8Olg=cOo>3Phoc`l??l30`?oD51@00;o
oooo00god=3@oaTI6Ol410Co9bLWohj>S_ooooooZ:RXobPX:?lN7Qko>CTioa@D5?lS8b?oZJVY00;o
oooo00ooShn?o`000?lm?Cgo>3Phoc/k>ooYjNWoX:2Po`000?mcLg?o6QXJochn?_la<C7o0P82od10
@?o@d=000_ooool02Om0@43o5QHFoc/k>olg=cOoCTi>ooooooofm_KoGUiNoaHF5P02ooooo`0?on3P
h?m?Cdoo7QhNoahN7_l;2`_oZj^[oo_knooooooob<S8obXZ:_l92@Wo@D51obDU9OlT92CoXj>S06Oo
oooo00?ol?3`oa8B4_nc/k<01_ooool00oogmoOo8R8Ro`000002o`000006ofm_KoooooooooooolC4
a?l0003oSHf=1_ooool01_oEeMGo30`<o`000?l0003o1`L7on3Ph0Sooooo00CoHV9Ro`000?l?3`oo
;2`/1?lX:2P00ol[:b_o4a<Co`000002o`000003o`H61_oLg=cooooo00[ooooo00GoL71`o`000?l0
003o0000oeUIF@0=ooooo`06ojJVY_l0003o0000o`000?lY:BWomOGe2_ooool01_o8b<So10@4o`00
0?l0003o2PX:onKViPWooooo00GoADE5o`000?l0003o5QHFoo7al@05ooooo`03ogemOOl0003o/[:b
00[ooooo00?oo_knoc4a<Olm?Cd01Oooool01OmADE7o0000o`000?l0003oDE5A00;ooooo00Cokno_
oaXJ6_ld=3Coo?cl1?ooool01OmKFe_o0000o`000?l0003oPX:200Sooooo00GobLW9o`000?l0003o
:RXZobTY:@03obPX:003obXZ:_lS8b?o000000;o000000?o3`l?onGUiOooool02_ooool01_ohn?So
<c<co`000?l0003o:BTYooknoPkooooo00GoVYZJo`000?l0003o0000ojBTY003ooooo`05onOWiol@
413o0000o`000?l`<3005_ooool01?ohn?So;2`/o`000?l[:b/5obPX:003ob`/;?l820So000000;o
000000?oXj>Sooooooooool0UOooool04?nDU9Co0000ooooooooooooc/k>o`l?3ole=CGo<c<cobTY
:Ol>3PkoLW9boc0`<?lc<c?o?Shno`000?m:BTX2ooooo`09okjn__l0003oCDe=obTY:Ole=CGo?Cdm
o``<3?l[:b_o`L7100?ooooo00SoX:2PoadM7OlD51CoATI6ob<S8ol<30coNGUioo?cl`;ooooo00_o
1`L7obd];Olk>c_o>c/kog1`L?ono_koJVYZo`H61_lE5AGoJf][omkNgP06ooooo`09okZj^_l];Bgo
2@T9oc`l??le=CGo:b/[oe5ADOl?3`oo_Kfm00;ooooo00Oo5QHFoc/k>olR8R;o?Shnoa<C4om3@d?o
g]kN00;ooooo00Wok^k^ofa/K?l=3@go92@Toc`l??l[:b_o;bl_oe5ADOlK6a/02?ooool07?oMgMgo
@410o`@41?ll?3co;bl_oaLG5on6QXKoooooooclo?nZZZ[o1@D5oe9BD_oclo?ooooookfm_Ol0003o
CDe=onk^k_oKfm_o0000oe5ADOlY:BWo<c<cochn?_l@413o8b<Sojf][Oono_h2ooooo`08ok2`/?lU
9BGo410@odA4A?l[:b_o20P8ofQXJ?oZj^X2ooooo`0;obHV9_lU9BGo>SXjocPh>?mPH63oooooogal
O?l:2P[o3Ph>of=SHooEeMD01_ooool02Oo=cLgo<c<co`L71olh>3So=SHfobPX:?m7AdOo3Ph>oiBD
U002ooooo`0Hoi^KVolU9BGo1`L7oc/k>oli>CWo=SHfof5QHOlO7aooc<c<on[Zj_m?Cdoo0000ob<S
8omlO7conOWiomSHf?lg=cOo1@D5oc<c<olh>3So;bl_oe=CDol];Bgoclo?1oooool00ooZj^[o0000
ojRXZ002ooooo`08oi>CTolI6AWo<30`od10@?lj>S[o0000ocHf=_oinOTdooooo`00B?ooool00ooG
emOo0000ojVYZ@0<ooooo`06ooGemOnSXj?oLW9bofe]KOnFUYKoi>CT1?ooool01_nVYZKoe]KFokZj
^_m]KFgoQXJ6omgMg@?ooooo00Oohn?Soj>SXooZj^[oXj>SofUYJOn4Q8Cohn?S00Gooooo00Go_Kfm
ogEeMOmXJ6SoVi^Koo7al@04ooooo`0<oo[jn_nTY:CoJVYZog5aLOnXZ:Sokno_oooooonMWIgo5ADE
obDU9OmTI6Cod=3@1Oooool03?o8b<So>3Pho`h>3_mKFe_o[Zj^oogmoOoooooo`L71ohF5QOmYJFWo
QhN7olC4a0_ooooo00GogMgMohV9ROmXJ6SoQ8B4omCDe003ooooo`07on;Rh_nQXJ7okno_oinOWomY
JFWoRHV9onKViP02ooooo`0<omSHf?m1@D7o2@T9oeQHF?nWYjOonOWioooooooMgMgoSHf=ofUYJOn8
R8Soe]KF0oooool03_o3`l?oShn?om;Bd_n1PH7oMgMgono_koo?clooMWIfooooooo5aLGoN7QhofYZ
J_nIVIWojn_[0oooool02OnJVY[o/K6aolW9bOm^KVkoSXj>oooooookno_o/;2`ohj>SP03ooooo`04
on;Rh_n0P83oKfm_ol30`0Cooooo00Gof][JohF5QOmXJ6SoQXJ6om[JfP1Yooooo`03oda<C?mVIVKo
oooo00Gooooo00?od=3@o`P82?l000000_l000001_nQXJ7oooooooooooooooooDU9BocHf=PKooooo
00?ojNWYoaLG5ol000000_l000000oo=cLgoooooooooo`06ooooo`04omGEeOl10@7oGEeMooooo`Co
no_k00?ooOgmog5aLOl000000_l000000olY:BWom?Cdooooo`0:ooooo`06oiFEUOl0003o0000o`00
0?ll?3coo?cl3?ooool01_o5aLGo10@4o`000?l0003o2`/;oo7al@[ooooo00Kom_Kfoa<C4ol0003o
0000o`820_o6a/H9ooooo`05ofQXJ?l0003o0000o`D51OoRh^801Oooool00om?Cdoo0000oiVIV@0;
ooooo`03oh:2P_l10@7oiNGU00?ooooo00?omoOgob<S8ol000000_l000001omkNg_ooooooooooooo
ooooWIfMo`000?n[Zj/01?ooool01OmdM7Co0000o`000?l0003oJVYZ00Wooooo00CoBTY:o`X:2_oQ
hN7oo?cl0ookno/00oolo?coclo?o`<30`02o`000003oc0`<?ono_kooooo00_ooooo00GoDU9Bo`00
0?l0003o51@DonSXj00>ooooo`05ol30`?l0003o0000o`000?n2PX800oooool01_obl_;o92@To`00
0?l0003o6QXJoo7alAKooooo00?oUYJFob8R8_oclo<01Ookno/01_oinOWo>c/ko`000?l0003o1PH6
olc<c9Oooooo013oU9BDo`000?ooooooooooon_[jonUYJGof=SHoiVIVOm[Jf_oYJFUoooooooWinOo
SHf=ofQXJ?n8R8Sohn?S0_ooool02?oMgMgoOgmoonCTi?oEeMGoOGemofUYJOnATI7og]kN1Oooool0
1OoBd];oRHV9ofMWIomjNW[o`L7100Cooooo00_oOgmoolO7aoni^KWoJFUYojNWYoono_koShn?oaPH
6?l/;2coSHf=on[ZjP07ooooo`08on3Ph?nEUIGoJFUYog]kNooEeMGok^k^ojJVY_oUiND2ooooo`06
ojBTY?oFe]Ko^[Zjofe]KOn6QXKogMgM1?ooool02?ono_ko`L71ogAdM?mYJFWoX:2Ponc/k?mnOWko
5QHF2Oooool01OoZj^[oUYJFofUYJOmlO7cob<S800;ooooo00Cono_koj6QXOmbLW;ogmoO0oooool0
2onNWYkoLW9bonKVi_o^k^koMgMgomgMgOoKfm_oQ8B4ofQXJ?n:RX[oe]KF00Gooooo00Kofm_Kohn?
SomXJ6SoMGEeokbl_?ono_h3ooooo`0;ohb<S?no_koo`/;2ofYZJ_nKVi_ooooooj2PX?lQ8B7o71`L
oh>3PooTi>@01oooool02?oVi^KoWIfMofUYJOmgMgOob<S8omWIfOlR8R;oShn?0oooool05ooHf=So
RHV9ofUYJOn7QhOogMgMooKfm_nPX:3oj>SXon_[jomeMGGo1PH6odQ8B?nPX:3om_KfoooooooUiNGo
SXj>ofYZJ_moOgooeMGEonk^k_nTY:Coj>SX00Oooooo00?omOGeog]kNooDe=@00_ooool01ooCdm?o
]KFeom[Jf_nHV9SoJFUYohJ6Q_oQhN40=Oooool004Sooooo00ConOWiodU9BOlU9BGof][J1oooool0
0oogmoOoooooooooo`0aooooo`03ocLg=omRHV;ooooo00Oooooo00?oTY:Bob@T9?o]kNd09Oooool0
0onWYjOo61PHonOWi`2Nooooo`03oiVIVOlR8R;on?Sh00Gooooo00?o/K6ao`000?l000000_l00000
1oo?clooooooooooooooooood=3@o`<30one]KD01Oooool00oomoOgo92@To`000002o`000003ojn_
[ooooooooooo00Oooooo00?oDe=Coa0@4?oXj>P01Oooool01Om6ATKo0000o`000?l0003oEEEE00co
oooo00Ko/[:bo`000?l0003o0000oa`L7?o_knl<ooooo`03on?Shol?3`oo000000;o000000?oQ8B4
ojJVY_nUYJD02?nUYJD00onRXZ;o5ADEo`000002o`000003ojBTY?oooooooooo00Oooooo00GoR8R8
o`000?l0003o0000of=SH`02ohV9R@06ohR8R?maLG7oD51@o`<30ol0003oNWYj2oooool00oo>c/ko
0000oj2PX003ooooo`03omgMgOl820So000000;o000000SoYZJVooooooooooooooooooShn?lU9BGo
9RHVooKfmP?ooooo00GoRXZ:o`000?l0003o0000oe5AD@09ooooo`03okjn__l0003oRXZ:00Gooooo
00GoYJFUo`000?l0003o0000of5QH@0=ooooo`05og1`L?l0003o0000o`D51Oo9bLT03_ooool01OoO
gmoo1@D5o`000?l0003oGUiN00?ooooo00Koo_knod92@_l0003o0000o`H61_o:b/XFooooo`03onKV
i_l:2P[o/;2`00Gooooo00KokNg]oa`L7?l0003o0000oalO7ooalO6Gooooo`03oiBDU?l0003ooooo
02_ooooo00?ol?3`ochn?_mbLW808oooool00omeMGGo5aLGooooo`0eooooo`03oo[jn_mDE5CoBTY:
00kooooo00?ofMWIoa`L7?n@T9003?ooool00ooJf][o3Ph>okfm_@1Cooooo`00B?ooool01Oono_ko
clo?oa@D5?la<C7obLW900Gooooo00?odM7AojBTY?omoOd0<_ooool00olS8b?oCDe=oo3`l007oooo
o`03ogalO?l@413oemOG02Gooooo00?oTY:Bo`@41?oAdM408_ooool01?odm?CoFEUIof9RH_ofm_Ih
ooooo`03olC4a?l20P;ocLg=00Gooooo00KoQ8B4o`000?l0003o0000oaPH6?oZj^X4ooooo`03ocPh
>?l];Bgon_[j00Gooooo00Go?Cdmo`000?l0003o0000oiNGU`09ooooo`03ol_;bol0003oP82000Co
oooo00?om_KfoadM7Ol000000_l000000omoOgooooooooooo`0:ooooo`06olo?col820So0000o`00
0?l410CogMgM3?ooool00ookno_o8R8Ro`00000Bo`000003oh:2P_oooooooooo00Oooooo00?oYjNW
o`000?l000002Ol000000omKFe_oooooooooo`09ooooo`03oo_knolO7aooDe=C00?ooooo00Ko[jn_
o`000?l0003o0000o`@41?o=cLd4ooooo`03oj6QXOl0003oVIVI00?ooooo00KoY:BTo`000?l0003o
0000oc/k>oono_h8ooooo`04ookno_ln?Sko6QXJooWin@Cooooo00GoNWYjo`000?l0003o0000oi:B
TP0=ooooo`05oi:BT_l0003o0000o`000?n][Jd03_ooool01Oo_knoo8B4Qo`000?l0003o>SXj00Co
oooo00GoLg=co`000?l0003o0000oj6QX@0Fooooo`03ooclo?l`<33o>c/k00Gooooo00Goc/k>o`00
0?l0003o0000od10@02Hooooo`03oiBDU?l0003ooooo02_ooooo00?ohN7QobXZ:_mMGEd08_ooool0
0oolo?coMGEeoaLG5`0fooooo`03ong]kOlo?coo=CDe00kooooo00?oemOGoa`L7?n@T9003?ooool0
0oo9bLWo0000ojRXZ00Booooo`03olo?com;Bd_oS8b<03kooooo001:ooooo`0;ok^k^olW9bOo3`l?
oe]KFon[Zj_o`L71oj:RX_m?Cdoo5ADEofMWIoolo?`0<_ooool00onGUiOoZJVYooShn007ooooo`03
ol71`On<S8cojn_[02Gooooo00?obl_;ohN7QooXj>P08_ooool01?o_knoo3@d=oadM7Ookno]hoooo
o`03on7QhOl71`OoPH6100Gooooo00KoEEEEo`000?l0003o0000ocPh>?okno/4ooooo`03ohN7Qol0
003o[:b/00Gooooo00GoEEEEo`000?l0003o0000oginOP0:ooooo`03odE5AOlF5QKol_;b00?ooooo
00?odM7Ao`T92Ol000000_l000000onc/k?oooooooooo`0:ooooo`03onk^k_lF5QKo000000;o0000
00?o^k^kooooooooool02oooool01_m5ADGo0000o`000?l0003oF5QHokJf]PWo/k>c00?o]KFeodi>
C_l000000_l000000omRHV;oooooooooo`07ooooo`06olS8b?l410Co0000o`000?mLG5coemOG0_oA
dM401_n_[jooMgMgo`d=3Ol0003o?3`loogmo@_ooooo00?oL71`o`/;2oo`l?000_ooool01_n7QhOo
0000o`000?l0003o61PHooCdm0Cooooo00ConOWiobPX:?lN7QkomOGe0_ooool01_nm_Kgo0@41o`00
0?l0003o7alOoo[jnPWooooo00?o/k>co`000?o>c/h01?ooool01Om?Cdoo0000o`000?l10@7o^k^k
00gooooo00Go][Jfo`000?l0003o0000ohj>SP0>ooooo`06oo_knoln?Sko0000o`000?lM7AgomoOg
0oooool01Ong]kOo0000o`000?l0003oGemO01Oooooo00?oRXZ:o`000?o7alL01?ooool01OnQXJ7o
0000o`000?l0003oN7Qh09Sooooo00?oU9BDo`000?ooool0:oooool00oo`l?3oVIVIok:b/P0Roooo
o`03ooclo?meMGGo5aLG03Kooooo00?om_Kfoj>SXonOWil03_ooool00ooGemOo71`Loi2@T00<oooo
o`03onCTi?n3Ph?oeMGE01;ooooo00?obl_;o`000?mGEeL0?_ooool004_ooooo00[of=SHoh>3Pol]
;Bgo2`/;o`820_l820So9RHVog=cLooKfm_oo_kn<_ooool00oohn?SonOWiooknoP07ooooo`03oo_k
noogmoOooOgm02Gooooo00?ono_kooOgmoomoOd08_ooool00oolo?coeMGEomKFeP1iooooo`04oo[j
n_lM7Ago=cLgoogmo@?ooooo00?oo?clobLW9ol000000_l000000omNGUkoooooooooo`03ooooo`04
on3Ph?l;2`_o<30`oo[jnPCooooo00GoKVi^o`000?l0003o0000of5QH@0:ooooo`03ol?3`ol0003o
U9BD00?ooooo00KoZj^[o`000?l0003o0000o`P82?oPh>0=ooooo`05obh^;_l0003o0000o`000?nL
W9`03Oooool01OmXJ6So0000o`000?l0003oKVi^00_ooooo00KoTi>Co`000?l0003o0000odA4A?on
o_h8ooooo`05onWYjOl>3Pko0000o`000?mJFUX01Oooool01?nGUiOo0000oaPH6?oemOD;ooooo`03
okbl_?l0003o[jn_00;ooooo00KoEUIFo`000?l0003o0000od10@?ono_h5ooooo`03ojRXZ?l0003o
UIFE00;ooooo00Koe=CDo`D51Ol0003o0000o`l?3oo/k>`9ooooo`03oo[jn_l_;booTI6A00?ooooo
00Kom_KfobXZ:_l0003o0000oa8B4_oXj>P=ooooo`05omWIfOl30`?o0000o`000?m[Jf/03oooool0
1OmKFe_o0000o`000?l>3PkofMWI00?ooooo00Kok>c/oaTI6Ol0003o0000oahN7_obl_8Fooooo`03
onc/k?lB4Q;oDU9B00Cooooo00GoKVi^o`000?l0003o0000ojNWY`2Hooooo`03ohV9ROl0003ooooo
02_ooooo00?oo_knooShn?ojn_X08_ooool00oolo?coMGEeoaLG5`0fooooo`03ookno_ohn?Son?Sh
00kooooo00?oemOGoa`L7?n@T9003?ooool00oomoOgom_Kfooclo00Booooo`03ooWinOo;bl_ohn?S
03kooooo001<ooooo`07ooShn?oTi>Coe]KFom;Bd_oFe]Koi>CTooCdm03oooooo`Wooooo00?oHV9R
o`D51OoQhN400oooool00ooNg]ko4A4Ao`000002o`000003ohZ:R_oooooooooo00Cooooo00?oMGEe
o`000?nPX:001?ooool01On;Rh_o0000o`000?l0003oCTi>00_ooooo00?o>SXjob<S8oogmoL00_oo
ool01_n4Q8Co0000o`000?l0003o:b/[ooGem@gooooo00GoCTi>o`000?l0003o0000ogYjNP0=oooo
o`05ohZ:R_l0003o0000o`000?mIFET02oooool01_n][Jgo0000o`000?l0003o8R8RooCdm0Sooooo
00Kom_Kfoa/K6ol0003o0000ocHf=_okno/4ooooo`04oogmoOlV9RKo0000omkNgP_ooooo00Kom_Kf
oa@D5?m_Kfoooooooo_knola<C43o`000003ofMWIooooooooooo00Cooooo00OooOgmocTi>OlI6AWo
kNg]ooooooo[jn_o3@d=00;o000000?o20P8om?Cdoooool02Oooool00onSXj?o>CTiooknoP02oooo
o`06on7QhOl820So0000o`000?lV9RKoo?cl3Oooool01Oo]kNgo61PHo`000?l0003oATI600oooooo
00GoNg]ko`000?l0003o0P82okfm_@04ooooo`05oeaLG?l0003o0000o`000?ne]KD05oooool00on3
Ph?o0000omCDe003ooooo`05odQ8B?l0003o0000o`P82?o?cll0V?ooool00oo]kNgoeMGEooooo`1@
ooooo`03ooclo?meMGGo5aLG04Oooooo00?oemOGoa`L7?n@T900H_ooool00?ooooooG?ooool00one
]KGo0000oiNGU`03ooooo`03okNg]ol0003o000000;o000000?o]kNgooooooooool01?ooool01?oT
i>Co3Ph>ob0P8?oclo<3ooooo`06oj:RX_l0003o0000o`000?lh>3Son_[j2_ooool00oni^KWo0000
ojJVYP02ooooo`05oe=CDol0003o0000o`000?mBDU803_ooool01OmaLG7o0000o`000?l0003oFEUI
00gooooo00GoZJVYo`000?l0003o0000odY:BP0;ooooo`06ol_;bol410Co0000o`000?l92@Woi>CT
2?ooool01_oinOWo;2`/o`000?l0003o5ADEoo3`l0Gooooo00?oJf][o`000?nl_;`03?ooool01OmR
HV;o@D51oooooooTi>Co2@T900?o000000?oTY:Booooooooool01Oooool01_ng]kOo0000oh61POoo
oooomOGeobDU9@;o000000?o0@41okno_oooool02Oooool00oobl_;o51@Dok>c/`02ooooo`05okNg
]ol0003o0000o`000?lo?cl03_ooool01_oinOWo=SHfo`000?l0003o9BDUoogmo@kooooo00GoWYjN
o`000?l0003o0000oj2PX004ooooo`05oi2@T?l0003o0000o`000?mNGUh05oooool00ooWinOo3@d=
ofATI002ooooo`06oo7alOlV9RKo0000o`000?lM7AgolO7ajoooool00oolo?coKFe]o`X:2P17oooo
o`03omGEeOl?3`ooRXZ:06;ooooo003ooooooecooooo00?ol?3`o`l?3om7AdL00oooool01_nBTY;o
0000o`000?l0003o2PX:omcLg0Oooooo00?oNGUio`000?nEUID00oooool01_ng]kOo0000o`000?l0
003o92@Tono_k`_ooooo00Go<c<cod51@Oooooooo_knob/[:`03o`000003ogalO?oooooooooo00co
oooo00KoTY:Bo`000?l0003o0000oc`l??olo?`<ooooo`06olS8b?l51@Go0000o`000?ll?3cooOgm
2_ooool01_o[jn_o3Ph>o`000?l0003o0@41ol?3``Sooooo00KooOgmoc`l??l0003o0000o`D51OoF
e]H5ooooo`03ok^k^ol0003oTi>C00cooooo00Co[Zj^obPX:?oooooo^KVi1?l000000ong]kOooooo
ooooo`05ooooo`06oogmoOll?3co410@oo?cloono_ko>CTi0ol000000onWYjOoooooooooo`09oooo
o`05od51@Olo?coooooooooooon;Rh/00ol000000omHF5Soooooooooo`0=ooooo`05oeEEEOl0003o
0000oa<C4ooUiND03_ooool01Oo4a<Co0000o`000?l0003oOgmo00Cooooo00KoalO7o`000?l0003o
0000o`d=3OoMgMdGooooo`06ogQhN?l51@Goh>3PoooooooJf][o20P80_l000000om0@43ooooooooo
o`3[ooooo`03ooclo?oinOWooooo04Kooooo00?oo_knoo[jn_olo?`0H_ooool00?ooooooGOooool0
0omJFU[o2@T9onKViP02ooooo`06oe]KFol0003o0000o`000?lV9RKolO7a1oooool01?oVi^Ko3`l?
oalO7oobl_82ooooo`06ol[:b_l61PKo0000o`000?l>3Pkoi>CT2oooool01OnZZZ[o5QHFooShn?oU
iNGo3`l?00?o000000?o/[:booooooooool03?ooool01_nb/[;o0000o`000?l0003o7QhNono_k`co
oooo00Koi^KVoa0@4?l0003o0000ob`/;?ofm_H:ooooo`03ooclo?lT92Co000000;o000000?oXJ6Q
ooooooooool01oooool01Om=CDgo0000o`000?l0003o]KFe00Gooooo00?onOWiogIfM_ni^KT03?oo
ool01?o_knoo;2`/on[Zj_n>SXh3o`000003o`T92OoOgmoooooo00Oooooo00Go^;Rho`000?nn_[ko
oooooe1@D003o`000003oi2@T?oooooooooo00Wooooo00GoX:2Po`000?o2`/;ooooooemOG`03o`00
0003ofe]KOoooooooooo00gooooo00GoLg=co`000?l0003o10@4olK6aP0>ooooo`05omoOgol410Co
0000o`000?mJFUX01?ooool00oojn_[o@d=3o`000002o`000003ogEeMOoooooooooo00cooooo00?o
no_koo;bl_ooool01_ooool01OoXj>So2`/;of][Jooooooo];Bd00?o000000?oM7Adooooooooool0
oooooonJooooo`00oooooomMooooo`06ok6a/Ol0003oXJ6Qooooooolo?co;Bd]0ol000000om:BT[o
ooooooooo`07ooooo`03oh61POl0003oS8b<00;ooooo00?ohN7Qoa<C4ol000000_l000000ooHf=So
ooooooooo`09ooooo`05ooclo?lj>S[o/k>colW9bOl20P800_l000000ol51@GogMgMooooo`0=oooo
o`06om3@d?l820So0000o`000?l410Coh>3P3?ooool01_okno_o8b<So`000?l0003o71`Loo;blP_o
oooo00GoAdM7o`000?l0003o0000ogmoO`09ooooo`05oeeMGOl0003o0000o`000?nCTi<05Oooool0
0omOGeooSHf=ofMWI`03o`000003ob8R8_ohn?Sooooo00Oooooo00Goo_knoc/k>omZJV[oooooofIV
IP03o`000003ogMgMooooooooooo00Wooooo00Gom?CdoahN7_m=CDgoooooocPh>003o`000003ohB4
Q?oooooooooo00gooooo00GoUiNGo`000?l0003o0000ojVYZ@0>ooooo`05onKVi_lA4A7o0000o`00
0?lf=SH01Oooool01_o6a/Ko1PH6o`000?l0003o2`/;om?Cd`gooooo00?oYZJVobDU9OoTi>@01ooo
ool01?m_Kfoo10@4ono_kon:RXX3o`000003ojBTY?oooooooooo0?ooooooV_ooool00?ooooooGOoo
ool01_ogmoOo8b<Soc8b<_ooooooe]KFo`X:2P?o000000?oP820ooooooooool01oooool01ooemOGo
>c/ko`X:2_o3`l?ooooooo[jn_lR8R800ol000000on^[Zkoooooooooo`0:ooooo`03okBd]?lW9bOo
IVIV00?o000000?o<c<coo_knoooool00oooool00omfMWKoDe=Coo7al@07ooooo`03ooGemOlL71co
000000;o000000?ob<S8ooooooooool01_ooool00ombLW;oTY:Booooo`02ooooo`05odm?Col0003o
0000o`L71ooPh>002oooool01_mbLW;o0000o`000?l0003oCTi>ooknoPSooooo00GoLG5ao`000?l0
003o0000ofIVIP0;ooooo`03oo_knon2PX;ogMgM00Oooooo00?oY:BToaPH6?lE5AD00ol000000omJ
FU[oooooooooo`08ooooo`04om;Bd_l<30cob<S8oiFEU@?o000000?oE5ADooooooooool02_ooool0
1?o2`/;o0P82ogEeMOlC4a<2o`000003o`820_ng]kOooooo00?ooooo00?ol?3`odI6A_n0P8002?oo
ool01Oo7alOo0000o`000?l0003oOWin00Sooooo00?ob<S8odA4A?o=cLd00oooool01_o_knoo8b<S
o`000?l0003o4Q8Bon?Sh`Gooooo00Ko[Zj^o`D51Ol0003o0000obDU9OoLg=`<ooooo`03og1`L?l0
003o_kno00Oooooo00Col_;bobd];Om:BT[oAdM70_l000000ol;2`_oemOGooooo`3ooooooi_ooooo
003ooooooekooooo00CoPH61o`000?oLg=co]KFe1?l000000ona/K7oooooooooo`08ooooo`03okfm
_Ol0003o?Shn00;ooooo00Go;bl_o`000?l0003o0000oiBDU00<ooooo`03oo3`l?lC4a?o000000?o
000000?oH61Pooooooooool00oooool00onGUiOo0000oeYJFP08ooooo`05od51@Ol0003o0000o`00
0?ne]KD01oooool00oohn?So410@ohB4Q003ooooo`05og9bL_l0003o0000o`000?nm_Kd02oooool0
1_nBTY;o0000o`000?l0003o9RHVooKfmPSooooo00KoPX:2o`000?l0003o0000od=3@oono_h:oooo
o`03ohR8R?l0003ofMWI00Oooooo00?od=3@o`000?l000000ol000000on3Ph?oooooooooo`09oooo
o`03oc4a<Om2@T;oYZJV00?o000000?o=SHfoogmoOooool02oooool00omMGEgo0000o`000002o`00
0003o`d=3OoTi>Cooooo00?ooooo00Coo?clodi>C_l0003oWYjN1oooool01OoXj>So3@d=o`000?l0
003oE5AD00Sooooo00?oFEUIo`000?o;bl/00oooool01_ogmoOo<S8bo`000?l0003o0P82ol71`@Ko
oooo00KoShn?o`000?l0003o0000oc`l??ofm_H:ooooo`04ookno_lm?Cgo0000ok>c/`Sooooo00?o
/k>co`000?l000000_l000002?lW9bOon_[jooooooo/k>coR8R8ogQhN?moOgoog=cLoooooonFoooo
o`00oooooomNooooo`04olc<c?l0003oQHF5ohJ6QP?o000000?o10@4om[Jf_ooool02_ooool01Om3
@d?o0000okno_ooooooo>c/k00?o000000?oNWYjooooooooool02oooool00omYJFWo0000o`000002
o`000003ohf=SOoooooooooo00?ooooo00Con?Shob`/;?l0003oOGem1oooool01OmRHV;o0000o`00
0?l0003oY:BT00Oooooo00?oXj>So`000?nk^k/00oooool01On>SXko0000o`000?l0003oV9RH00_o
oooo00KoZj^[o`000?l0003o0000o`T92OoVi^H8ooooo`06oi^KVol0003o0000o`000?lR8R;omoOg
2Oooool01?o:b/[o2`/;oa<C4ooclo<7ooooo`03on[Zj_l@413o000000?o000000?oZ:RXoooooooo
ool02Oooool01?mlO7co0000ofe]KOl:2PX2o`000003oa`L7?ogmoOooooo00_ooooo00?od];Bo`P8
2?l000000_l000000ol];BgooOgmooooo`04ooooo`04olo?col51@Go3@d=ol30`0Kooooo00Gom?Cd
obXZ:_l0003o0000oc8b<P07ooooo`04om?Cdol;2`_o5aLGoo;blP?ooooo00?ooOgmocdm?Ol00000
0_l000000onRXZ;oooooooooo`05ooooo`06og1`L?l0003o0000o`000?mMGEgon_[j2Oooool01?oN
g]ko3@d=o`000?nQXJ48ooooo`03oo_knoll?3co000000;o000000WoDE5AoooooooalO7oFEUIofAT
I?oKfm_oIfMWod92@_oRh^80oooooonEooooo`00B?ooool00oognogoV/3Loig5g`02oig5g`04oig4
gonNaMoo]M?WomOWlPCooooo00KooOknoj?9hOnKa=ooVlCNok3@iOoamo/5ooooo`0@omCVlOnPan3o
WLGOoio6h?o@ho3oooooonK`monJ_m_oWLGOoiZog?oNk?Goh^kfojG:h_nLaMooV/?NolkRk`Gooooo
00Oomo[mokcGjOnJ`MgoVlCNoig5googn_co[m3U00GoWLGO00CoW/GOojc=i?o8g^gom?Sk0_ooool0
1Oo2fn_oWLGOoig5gonJ`mkogN_d00Gooooo00gojo?iojk?i?nJ`mkoV/;NokCCi_ojo?goooooonK`
moo3fn_oXlSPoig5gon[cN?oe>Ga00Cooooo00?o^]KXoi[3g_nMaMl01?nMaMl02onUbN7oh^kfoooo
oooooooonO_mom;Tl?n_d>GoWLGOoj37h?nlenWokoKj0:Wooooo00Coo?clobXZ:_l^;Rko>SXj0ol0
00000olR8R;ok^k^ooooo`0:ooooo`05okjn__l0003o@T92oooooom;Bd/00ol000000omMGEgooooo
ooooo`0;ooooo`03om_Kfol>3Pko000000;o000000?o^[Zjooooooooool01?ooool01?nFUYKo0000
o`000?miNGT6ooooo`05ohN7Qol0003o0000o`000?nATI401_ooool01?oRh^;o71`Lo`820_oPh>03
ooooo`05ojZZZ_l0003o0000o`000?m[Jf/02oooool01_o2`/;o0@41o`000?l0003o0@41okZj^PSo
oooo00Ko^[Zjo`000?l0003o0000o`L71ooNg]h8ooooo`05onCTi?lV9RKo0000ob/[:oohn?P01ooo
ool00oohn?So9RHVo`000002o`000003o`D51Oo<c<cooooo00[ooooo00Coh^;Roa4A4OlB4Q;o1`L7
0_l000000ol<30coh^;Rooooo`0<ooooo`05oeiNG_l0003o0000o`000?mLG5`01oooool01?mBDU;o
0000oc0`<?oclo<5ooooo`06ookno_m7AdOo0000o`000?lH61SolO7a1Oooool01?oinOWo@T92o`00
0?lj>SX5ooooo`05odY:B_l0003o0000o`000?mdM7@02?ooool01OmcLg?o0000o`000?l0003oNWYj
00Wooooo00CoMGEeo`000?l0003oQhN72Oooool03Onc/k?o0000o`000?l0003oPH61oooooon^[Zko
QhN7oiBDU?mUIFGoTi>Coj6QXOnIVIT0T_ooool00onRb>7oWLGOoig5g`02oig5g`04oik5gon_d>Go
d^C`ookno`Cooooo00Go/]7Voig5gonMaMooY<WQonSan005ooooo`0Aon7]mOnWbn;oW<COoi[3g_no
fN[ooooooo[loOnJ`MgoWLGOoi[3g_o1f^_omOWlojc=i?nJ`mkoV/7MokoJj_oinod01?ooool00ook
oOkobn3^oi[1g@02oic4g`03omWXl_oooooooooo0<kooooo0018ooooo`03on[cn?l0DIoo05jV00?o
05jV00Go05nVo`i`/?leQkgoQ;KGoo;gnP02ooooo`06oo[loOl`Q;_o05ZTo`1KYOlDM;?o_]SZ1Ooo
ool04?mOXL[o066Xo`1NY_l0HJSo/M7VoooooonieNSo04fMo`1NY_l0CikoWlKPom[ZlolBLk;o05bU
o`1KYOlcQ[`5ooooo`08omSXl_l[PK[o05NSo`1IXolJMkComOWkob1k]_l0GJH4o`1NYP0;o`1OYol2
JJco8gfhofBRc?oKj_Cooooooh6de_l0IJ[o05jVo`1KYOmj/=@01Oooool03onee>Oo0f^]o`1KYOl0
DZ3oH:7;omg/m?nA_]_oC9G5oamj]_l0HZSo05jVo`9Y[?laQKcoR;WHonken@02ooooo`03od2=`Ol0
FJ?o05jV00?o05jV00go05fVo`EZ[OnbdNKooooook_GjOmPXL_o<XFlo`I/[_l0GZKo066XoaMe/omE
V/Oob=k]0:Wooooo00?oP820o`000?l10@400ol000000oln?Skoo_knooooo`0;ooooo`04odM7Aol0
003o`L71of=SH`?o000000?oB4Q8ooooooooool03?ooool01Om^KVko0000o`000?l>3Pkoi^KV00Ko
oooo00KolO7aoalO7ol0003o0000oe1@D?oQhN44ooooo`05oiVIVOl0003o0000o`000?mcLg<01Ooo
ool01Oo2`/;o;Bd]o`000?lL71com_Kf00?ooooo00KoUIFEo`000?l0003o0000ob4Q8OoWinL:oooo
o`03ok2`/?l0003o000000;o000000?oKfm_ooooooooool01_ooool00on][Jgo0000o`000002o`00
0003oi>CTooooooooooo00Gooooo00KojNWYoc/k>ol0003o0000ocXj>_olo?`7ooooo`03on[Zj_l9
2@Wo000000;o000000?o410@onc/k?ooool02oooool00omcLg?o0000o`000003o`000003oj2PX?oo
oooooooo00_ooooo00Gob/[:o`@41?l0003o0000ohR8R007ooooo`06ol71`Ol0003o0000oc<c<onk
^k_oo_kn1?ooool01OmBDU;o0000o`000?l410Coa<C400Cooooo00Gom_Kfof5QHOl0003o0000oeaL
G005ooooo`06od51@Ol0003o0000o`000?lT92Cojn_[2?ooool01_n<S8co1PH6o`000?l51@GoQ8B4
ooShn0Kooooo00GocLg=o`L71ol0003o0000ofUYJ@09ooooo`0=oo_knole=CGo0000o`000?n/[:co
oooooijNW_nXZ:SoRXZ:of=SHom^KVkoZ:RXoiBDU02Booooo`03o`1VZol0GZKo05jV00;o05jV00Go
05nVo`I/[_l`Q;coLJ_AomgZm003ooooo`05oeVMb?l0H:Oo05jVo`1VZonMaMl01Oooool04On>_=[o
06J[o`1MY_l0E:7oP;CFooooooobmo_o05:Po`1NY_l0F:?oCiK5oo;gnoleR;go05JRo`1IY?lGM;;o
jO;h00Cooooo00KokoKjod^EaOl0EJ;o05^Uo`U/[onbdNG@ooooo`00B?ooool04oo/m?Wo062Wo`M/
[_l8KJko06R/o`1OYol0HZWo06J[o`1UZ_l0Ij_oD9O5oo7fn_ooooooo_koojo@i_l0GJGo1fb^o`MZ
[On3]ML01Oooool04Ol_Q;_o1Vb^o`M/[_lKN;Gon_cnoooooonofN[o05bUo`M/[_l0GZKoW/KPoooo
oom:U<Co16Z]o`M/[_l0IZ_oiNog00Cooooo00[o`m_[o`]WZol5Jjko05fUognceOoooooo<HFko`I[
[_l7K:ko1Vb^0_l0GJH02ol0H:Oo06J[o`1WZol0HJSoGZ;;on[bn?oVl?Oo8gbgo`9Z[Ol6Jjko9Gjh
00Gooooo00OoTKkKo`1RZOl5Jjgo066XokgHj_oCiO3o1F^]00;o06BZ00co06:Xo`1QZ?l0Ij_o06FZ
o`=Y[?mk/MColOKjoooooom@UlKo06N[o`M/[_l8KJh2o`1QZ00>o`1PZ?l9KJko]M?VoooooomMWlWo
05RRo`1UZ_l0HjWo062Xo`1UZ_l1J:co06:Xobj3^ooEi_:Xooooo`03ol71`Ol10@7o000000?o0000
00?oGEeMooooooooool02oooool01?o1`L7o0000odM7AomVIVH3o`000003oc8b<_ogmoOooooo00co
oooo00GogMgMo`l?3ol0003o<C4aooOgm`07ooooo`0:ohB4Q?l0003o0000o`000?lH61SoFEUIog5a
LOmcLg?oJf][ob@T90?o000000Ko3`l?ofYZJ_mcLg?oLg=cof5QHOlk>c/3o`000006oclo?ooCdm?o
UIFEoi6ATOmWIfOo4A4A1?l000001OlS8b?oJf][oi6ATOnEUIGoh>3P00;ooooo00GolO7aoiVIVOnB
TY;oKfm_oa`L7004o`00000:o`T92OmSHf?oRh^;oi>CToo@d=3ooooool[:b_nBTY;oQhN7obDU9@Co
000000Wo3`l?oe9BD_mQHF7oLW9bogmoOonDU9CoUIFEogAdM?lQ8B400ol000000om8B4Sooooooooo
o`03ooooo`04okZj^_nATI7oQHF5od];B`Co000000?o8b<SooWinOooool02oooool00ooLg=co30`<
o`000003o`000005o`h>3_mSHf?oSXj>oiNGUooXj>P02_ooool01?mFEUKo0000o`000?nd];@7oooo
o`03oogmoOm2@T;o000000;o000000Ko=CDeof5QHOmcLg?oLg=cofEUIOl>3Ph3o`000006obTY:Oma
LG7oLW9bog5aLOmIFEWo:BTY0ol000001omjNW[oooooom?CdonBTY;oT92@oeiNG_l410@01?l00000
1?lV9RKoKVi^ohn?Son/[:`6ooooo`0@olO7aolk>c_o0000o`000?l_;booW9bLon3Ph?odm?ComOGe
onKVi_n][Jgo9BDUo`000?l10@7o0P82oc@d=0[ooooo00OoZJVYo`000?l0003o_KfmoooooooFe]Ko
Fe]K00;oP82000?oL71`oeADE?o1`L40T_ooool02olCLk;o1fb^o`M/[_l5Jjgo062Wo`1RZ?l0IZ_o
06F[o`1UZ_llRKkoe^Kb00;ooooo00GofNWco`=Z[Ol7K:ko26f^odjFa@05ooooo`0Aof:Sbol0IZ_o
1F^^o`5VZooNjoGooooooo?hnol0HJSo1fb^o`1VZomIWLSoooooognceOl0I:[o1Vb]o`1MY_nheNP0
1?ooool01_oinogo4V^]o`AZ[Ol0HjWoDYS7oo7fn]3ooooo0018ooooo`0<oncdnOl0H:Oo1fb^o`=Y
[?l_Pk_oQ[OGof6RbolEM;;o06R/o`A[[Ol0HJSoLJ_A0_ooool01Oo[loWo87Neo`=Y[?l3J:co8gbg
00CoH:7;00GoF9c9o`i`/?l7K:ko1fb^ofbXc`02ooooo`0;okoIj_l0G:Go1fb^o`1NY_nMaMoooooo
oiBog?lBLk7o1f^^o`AZ[Om0SL401?mPXL/06?lnS<3o0VFZo`=Z[Ol;JZgo_=OYooooool`Q;_o1V^^
o`M/[_l;KjooY/[Roj?9hOmk/MCo9gnho`=Y[?l3JJgo2VN[ok?Bi_ooooooHJ7;o`Y^[ol7K:ko0VV/
oefObP?oH:7;02KoGZ3;ob^1^Ol4Ijco0FN[oc25_?oPk?GoloSkodnGaOl0I:[o7g^fof6Rc?m]ZLoo
6WNeo`=Z[Ol0IZ[o8Gbgol;KjoooooooD9O6o`1WZol7K:ko0fR/og:[dOmd[M7oM:cAognceOoFi_7o
ooooojC:hOl9Jjgo0VV/odJA`omi[m?o@8g0o`]^[ol7K:ko06N[ogB]dZSooooo00?ojn_[oaXJ6_l0
00000ol000000on6QXKoooooooooo`0<ooooo`03odA4A?l0003o>3Ph00?o000000?o61PHon[Zj_oo
ool03Oooool00omaLG7o0000oeADE008ooooo`06on?Shol=3@go0000o`000?l:2P[o0P820ol30`<0
1Ol820So3`l?o`l?3ol?3`oo2`/;00?o0`<300Oo0P82o`@41?l?3`oo1PH6o`000?mOGeooYjNW00?o
000000?o1PH6oa0@4?l?3`l00_l?3`l01Ol61PKo0000o`000?l0003oSXj>00;ooooo00Kog]kNo`D5
1Ol0003o0000o`<30ol@4103o`l?3`07o``<3?l0003o0000o`000?mQHF7ooooooginOP03o`0000Co
3`l?00Co2`/;o`410Ol20P;o0`<32?l000000omIFEWoooooooooo`03ooooo`0:odi>C_l0003o0000
o`000?l?3`oo410@o`D51Ol0003oBDU9ooknoPgooooo00KoLW9bo`000?l0003o20P8oa0@4?l<30`3
o`000003ojRXZ?oooooooooo00Sooooo00CocLg=o`000?l0003ogMgM2?ooool01_n[Zj_o0000o`00
0?l<30co1PH6o`820P?o0`<300Go30`<o`l?3ol?3`oo3`l?o`P82003o`<30`03o`410Ol820So2`/;
00;o000000?oV9RHoooooonDU9@00ol000000ol;2`_o3`l?o`l?3`02o`l?3`05o`D51Ol0003o0000
oadM7OomoOd01_ooool00ookno_oShn?oa`L7003o`000003oa`L7?lN7Qko20P800;o000000CoBDU9
okno_onh^;SoLG5a2_ooool01?ojn_[o<30`o`000?o=cLd2ooooo`05ok6a/OmNGUkoMGEeoeiNG_nO
Wil0Toooool03?lCLk;o1fb^o`I[[_lEM;?oPkKFofZWc_lTOKOo06BYo`I[[_l0H:SoCIK5oo3fnP;o
oooo00Co>hZoo`I[[Ol6Jjgo3g6a1?mPXL/04omMWl[o77Veo`AZ[Ol1Ij_oAi;3ooOjo?ooooooloSk
o`1QZ?l7K:ko06J[oeRLb?oooooo^]KYoaij]Ol2JJco16R/oc65_?mMWlX00omPXL/01OmDVLOo0F>Y
o`I[[_l8JjgoS;[J0=7ooooo0018ooooo`0ConcdnOl0H:Oo1fb^o`1UZ_mMWl[ooOknonkenOo5gNgo
;X>jo`5Y[?l6Jjko26^^ol?Lk?oooooom?WkofBScOl0HjWo26b^o`=Z[@05o`1VZ`04o`I[[_l7K:ko
0VV/omCVl@;ooooo00_o_mWZo`1LYOl7K:ko05jVoig5goooooookoGioaij]Ol4Jjgo1fb^o`1X[004
o`1VZ`0:o`1X[?l7KJko06FZod:?`_oRkOKooooooc24^ol6Jjko1fb^o`e`/0;ooooo00Wonognoj77
hOl0GJKo26f^o`1IY?nRb>7ooooooj_=i?lDM;800_l7K:h5o`1VZ`0Fo`9Y[Ol8KJko05fUoh:de_oj
o?goooooolkRkomLWl[oe>Gaonken_ocn?_oZ/gTo`1NY_l6Jjko16BYoi>ofoooooooD9O6o`1WZol7
K:ko06BYoo3fnP?om_[l00coo?gnooooooo`m_[oOK;DoiG0g?oSk_Komo[lon?^m_lSOKOo1Vb^o`M/
[_lQNkNXooooo`03ooOgmolR8R;o000000?o000000?o[Zj^ooooooooool03?ooool00onc/k?o0000
o`T92@03o`000003o`820_oKfm_ooooo00gooooo00?ohn?SoeYJF_n_[jl02Oooool00omHF5So7QhN
ok6a/@0?om_Kf`0:omgMgOo?clooGEeMogAdM?ohn?Soa/K6olC4a?o5aLGoe=CDomcLg0?ofm_K00Go
f=SHolK6a_o5aLGo`l?3onSXj002ooooo`06ooclo?o:b/[oa<C4olC4a?oBd];og=cL0ooKfm/02_oJ
f][ob/[:olG5aOo1`L7og]kNooooooo/k>co`l?3olC4a?o>c/h8om_Kf`04ol[:b_o5aLGoaLG5olG5
a@?oa/K600?o`L71omoOgoooool01?ooool02OoTi>Co`/;2olC4a?o<c<cofm_KomcLg?o>c/ko`<30
on7Qh@0>ooooo`04oo;bl_o5aLGoa<C4om7Ad@;og=cL00Coe=CDolG5aOo4a<CokNg]2oooool00on8
R8SoKVi^ooooo`08ooooo`04onk^k_l/;2coTI6AomWIf@kofm_K00Oog=cLomGEeOn9RHWo5QHFokRh
^?oooooolo?c00;oaLG500?oalO7omSHf?oKfm/00ooKfm/01?oHf=SoaLG5ol?3`oo>c/h9ooooo`09
ong]kOni^KWoQXJ6ofa/K?mYJFWoJ6QXog1`L?nIVIWoc<c<00oooooo00?o^k^koeeMGOo/k>`00ooo
ool00oo`l?3oc/k>onSXj02Dooooo`0Boa=c/_l7K:ko1V^^obMo^OoloOkolOOkom3Tl?m>U/Go06BZ
o`E[[_l3I:[oV/CNooWkoOooooooS;[Jo`=Y[Ol7K:ko1F^]1Ol0IZ/04Ol4JZgo26f^o`1MY_nZc>?o
o?gnooooooocn?_o066Xo`M/[_l0IZ_oF9c8ooooooofnOcoBYC4o`1TZOl8KJko0FV/00Co06J[00Go
06N[o`M][_l1JJco:X6jol[OkP3Aooooo`00B?ooool01Oo/m?Wo062Wo`M/[_l0IJ[oHJ7;00?ooooo
01CoXLOPoaUf]?l5Jjgo06N[ogN_d_oooooooOknokWEj?l0HJOo1Vb]o`Q][_l2JJco062Wo`1MY_l0
HjWo1F^]o`M/[_l5Jjgo9gjhoognoP;ooooo00Go_mWZo`1LYOl7K:ko05jVoig5g`02ooooo`0BoeRL
bOl:KZoo1fb^o`M/[_l0IZ_o05fVo`1NY_l0IZ_o26f_o`Q/[_l0G:GoP[GFoocmo_oooooo<8Bko`I[
[_l7K:ko3W2`0oooool04om_Z]3o066Xo`=Z[_l4J:_o/]7Vooooooodn?_o:H2io`I/[_l7K:ko1Vb^
o`1SZOl0GJKo05nWo`9Y[?l8KJko0fZ]o`MZ[Onge>P00_ooool00oomo_kok?Ciooooo`02ooooo`0:
okOEj?l0GJKo1fb^o`1MY_n9^MSooooooe2Ga_l0Ij_o1fb^o`1SZ0Oooooo00?ol_OkooWkoOooool0
0_ooool01?lVO[So1Vb^o`M/[_l>L;2Xooooo`03om3@d?l820So000000?o000000?od];Boooooooo
ool03?ooool00oomoOgo?cloo`000004o`000003oiBDU?oooooooooo01Sooooo00?ok>c/on[Zj_oo
ool04_ooool00oo`l?3oooooooooo`1_ooooo`03onk^k_oooooooooo017ooooo00?oi>CTooShn?oo
ool0boooool01?lCLk;o1fb^o`I[[_lXP;T3ooooo`0Dol7JjolZP;[o0FN/o`1SZOmDV/OokOCioooo
oooTkoOo26b^o`M[[_l7K:ko16Z]o`1QZ?l0GJKo066Xo`AZ[Ol8K:ko0VZ]o`i_[ooOk?D2ooooo`05
oo?hnol0HJSo1fb^o`1VZomHW<P00_ooool03On7^=So2fj_o`E[[Ol8KJko0FR/o`1NY_l0GJKo06BZ
o`Q][_l7K:ko06BYodbEaOoinod0dOooool004Sooooo00Gok?Cio`1PYol7K:ko06FZof2Qb`03oooo
o`05ooSkoOldQ[co0VV]o`E[[_lNN[D00_ooool03?oUl?Oo=XRmo`5VZol1IZ_o=hRnol3Jj_oNjoCo
T[kKoaEe/ol5Jjko06R/ogZ`d`?ooooo00Go_mWZo`1LYOl7K:ko05jVoig5g`02ooooo`0<oj_=i?lD
M;;o1fb^o`U][omTXlgog^_dom3SkomMWl[o0F>Zo`5Y[OlJMK?o^mOY0_ooool01?l`Q;_o1V^^o`M/
[_l8KJh2obR0^@06obEm^?l@LK7o16Z]o`1LY_m6T/?oi>of0_ooool03?mg[m;o2fj_o`M/[_l=L;3o
Ul7Momk[m?o2fn_o=8Nmo`5VZol0IZ_o?Hg0om_Yl`Gooooo017o_=SYogB]dOlCL[7o1VZ]o`I/[Ol0
IZ_oUl;Moooooom@UlKo06N[o`M/[_l6Jjgo9gniobR0^OlVOkSo@8k1onK`mP04ooooo`04onSbn?nM
aMoo=HNno`Q][`;o1fb^00?o9gniooooooooool0X_ooool01Oo/k>co_knoojRXZ?nEUIGo>c/k00Co
000000?o1@D5omcLg?ooool03_ooool00onc/k?o0@41o`000003o`000006oa4A4OmeMGGoYJFUokNg
]ooCdm?oo_knoooooomoooooo`04oa=c/_l7K:ko1V^^obR0^@?ooooo00Konognof6Qc?l0HjWo16Z]
o`Q[[OoLj_@2ooooo`0<oeBJaol1JJco16Z]oamj]_n/c^Cog^_dojg>i?lUO[So06R/o`1TZ_mFVlSo
l?Kj0_ooool01Oocn?_o066Xo`M/[_l0IZ_oF9c800;ooooo00cob=o^ob^1^_l1J:co06N[od:@`OoI
j?;og>_cognceOl1IZ[o1FZ]oa9a/OnA_][Booooo`00B?ooool01Oo/m?Wo062Wo`M/[_l0IJ[oH:7;
00Cooooo00Co?hg0o`9Y[?l7K:ko0fV/0_ooool03?odn?coN:oCo`1QZ?l3JZgo476aok;BiOoooooo
HZ;<o`E[[Ol7K:ko06>YomWXlP?ooooo00Go_mWZo`1LYOl7K:ko05jVoig5g`02ooooo`0<oocmo_lK
MkGo1Vb^o`M/[_lNNKKoooooon7^mOldQkgo06N[o`1SZOmBVLKoio7g0_ooool01?l`Q;_o1V^^o`M/
[_l7K:h3o`I/[P05o`9Y[?lPN[KoQ;GFon?^mOonool00_ooool03?o0f^[o3G2`o`M/[_l9KJooGYo:
ooooooo8g^go0fFZo`E[[Ol0GjOoPKCEookno`?ooooo00coXLKPob5k]_l>Kk3o2fj_o`I[[_l7K:ko
06F[oc:5_?oAho3ooooooe2Ga_l0Ij/2o`M/[P;o1Vb^00?o16^]ob9m]ooRk_D00_ooool01?oHj??o
CYK5oa1a/?l<Kk03o`M/[P03o`=Z[On=_=[ooooo0:?ooooo00?oXj>So`000?l000001_l000000ol8
20Soh^;Rooooo`0>ooooo`03oo[jn_lT92Co000000So000000?oh^;Rooooooooool0oooooommoooo
o`04oa=c/_l7K:ko1V^^obR0^@Cooooo00GoNK3Do`1QZ?l7K:ko05bUomKWlP02ooooo`0<oio7h?l0
I:[o1V^^o`e_[on5]]Oooooooi[3g_l2IZ_o1V^^o`1MYOn/cN?ooOko0_ooool01Oocn?_o066Xo`M/
[_l0IZ_oF9c800;ooooo00cooOknodbEa?l0IJ_o1fb^o`ATZ_oVlOOoo?knoe6Ha_l0J:co0FV/oc24
^ooHio?Booooo`00B?ooool01Oo/m?Wo062Wo`M/[_l0IJ[oH:7;00Cooooo00Co?hg0o`9Y[?l7K:ko
0VV/0oooool02_o?ho3o1F^^o`=Z[Ol0HJSoQKKGon_cn?lkRkoo0VV/o`1X[?m:U<@4ooooo`05okoI
j_l0G:Go1fb^o`1NY_nMaMl00oooool02_n1]=Go36n_o`M/[_lCLk;oa]k]ol7Jjol0GJKo1V^^o`1U
Z_nE`=`3ooooo`03oc24^ol6Jjko1fb^00Co1fb^00?o0FV/ob=m]onnfNX01Oooool02_ldQkgo1fb^
o`I/[_lTOKSol_OkohZjfOl0H:So06R/ob5k]_o4g>`3ooooo`03oj77h?l=L;3o1fb^00?o1fb^00?o
0VV/ob=m]onie^P00_ooool00om@UlKo06N[o`M/[P03o`M/[P07o`E[[OlSOKOoh^keoooooooKjO?o
?Xg0o`1VZ`04o`M/[P03o`=Z[OmZYlkooooo0:Cooooo00GoemOGogUiNOmoOgooOWinoi:BTP02oj6Q
X@04oi2@T?mkNg_oRXZ:ooOgma3ooooo00_oYJFUogMgMomoOgooTi>Coj6QXOnPX:3oW9bLoh:2P_ml
O7coP820oo7al@3oooooogoooooo00Co4g>bo`M/[_l6Jjko:82i1?ooool01Omj/=Co066Xo`M/[_l0
G:Goe^Ob00;ooooo00_on_cmoaEe/ol4JZgo06R/odnGaOoenOcoIJC<o`1SZOl0Ij_o;hBkon7]m@03
ooooo`05oo?hnol0HJSo1fb^o`1VZomHW<P00oooool02_nVb^;o6WRdo`E[[Ol0IJ[oXLSPon[cnOl0
I:[o1fb^o`=Y[?mMWl[Cooooo`00B?ooool01Oo/m?Wo062Wo`M/[_l0IJ[oH:7;00?ooooo00Goo?gn
ocJ7_Ol2JJgo1V^^oaQf/P03ooooo`0:onOan?m=ULGo06BZo`1TZ_mLW/[oUL7MobEn^?l4JZgo06FZ
oi:nf`Cooooo00Go_mWZo`1LYOl7K:ko05jVoig5g`03ooooo`0:olOMkOl@L[7o1fb^o`e`/?mg[m;o
R[WIo`1QZ?l0J:co:h:jolKMk0?ooooo00Oo<8Bko`I[[_l7K:ko3G2`oooooooTkoKoBYC400;o06BZ
00?oCIG4onOamoooool00oooool02_n=_=[o1fb^o`M/[_lJN;GoXLOQoeBJaol0I:[o06FZodbDaOoV
l?L3ooooo`08oc^<_ol8KJko1fb^o`M/[_l?LK3o=HNmoi?0g?oYloP3ooooo`0Boe2Ga_l0Ij_o1fb^
o`1VZoo4fn_ob=k]olONkOo?hnoonOcmoooooonZc>?o06R/o`AZ[Ol7K:ko2Ff^oaIe/_mTY<co`M_[
ooooooooooooodcooooo00Co4g>bo`M/[_l6Jjko:82i0oooool01_omo_koIJ?=o`1SZOl5Jjgo0fN[
om_Zl`;ooooo00_oo?gnofbXcol0IZ[o0VV/ocR9__nPan7o?Xg0o`1VZol0HJWoJZO?oo7gnP03oooo
o`05oo?hnol0HJSo1fb^o`1VZomHW<P00oooool02_oMjoCo<HFlo`=Z[Ol0J:coG9k:oj?9hOl0IZ_o
1F^^oaYg]OnVb^;Cooooo`00B?ooool01Oo/m?Wo062Wo`M/[_l0IJ[oH:7;00?ooooo00GoZL_Soa]h
]?l5JZgo06R[og:]d@03ooooo`0:oognoonD_mco0F2Xo`1Y[?lbQKco<hNmo`]^[ol5JZko2VN/onG`
m`Cooooo00Go`=WZo`1LYOl7K:ko05jVoik5g`04ooooo`09oc:5_?l7K:ko1fb^oa]g]?m<U/Go0FJ[
o`1VZ_mGW<WokOGi00?ooooo00Co<8Bko`I[[_l7K:ko3G2`0_ooool01Onke^[o05bVo`1VZolhRKko
dnG`00Cooooo00Woi>ofo`a_/?l7K:ko4G:aodNC`olBLk7o0fZ]o`ETZ_n6^=P01?ooool01OlNNKGo
1Vb^o`M/[_lCLk;o_]SZ00Kooooo00CoD9O6o`1WZol7K:ko06BY1_ooool01_nKa=ko05fUo`M/[_l0
HJSoM:cAooCio?oooooooooooom>ooooo`04oa=c/_l7K:ko1V^^obR0^@?ooooo00Koa]g/obj3^ol1
Ijco06BYoe2Ga_o/m?T2ooooo`0:ooknooo3g>_o0f>Yo`AZ[OlONkKo@Hk0o`ia/?l4JZgo1V:YokGC
i`Cooooo00Gom?Wko`1QZ?l7K:ko06J[oeRLb004ooooo`09of>Sbol7K:ko1f^^o`a^[omGW<So0VZ/
o`AZ[Ol`Q;_ohNge0=?ooooo0018ooooo`0=oncdnOl0H:Oo1fb^o`1UZ_mMWl[ooOknoo;gnooAi?3o
<hJlo`9Y[?l6Jjko1fZ]okgHjP04ooooo`0NolcQkolKNKGo0VR/o`9Y[?l1J:co1Vb^o`1UZ_mRXlco
n?_looooooomo_komo[looSkoOnie^So05bUo`M/[_l0GZKoV<;Moo[loOofn_coo?gnoooooonOan3o
0fV]o`M/[_l4JZgo06N[o`E[[Ol;KjooWlKP1?ooool02ol`Q;_o1V^^o`M/[_l=L;3ooooooognoonL
a=oo05jWo`5X[?lQNkKo_mWZ00Gooooo00SoC9C4o`A[[Ol6Jjko06N[o`E[[Ol0Ij_o;hBkolcQk`Co
oooo00Wo:7nho`I/[_l7K:ko6GJdoo;hnoohnocogNcdomCVlOomo_h00_ooool01Om@UlKo06N[o`M/
[_l0I:Wol_Ok00;omo[l00con?_moocmo_ooooooX<OPo`5PYol6K:ko05fUok?Bi_oinogol?KjolON
kOoenOcoooooooooooooBoooool03OlCLk;o1fb^o`I[[_lWOkWoo?gnooCinooJjO?oEY_8o`1TZ_l5
Jjko0fBZoiC0g?ohnod00oooool06?obmo[o;X>jo`5XZol4JZgo06R/o`I[[_l0IJ[o@i72on7]mOoo
ooooo_koooSko?ogn_cok?Cho`1QZ?l7K:ko06J[oeFJaookoOkom_[loo_lo_oooooo`=[Zoa]h]0;o
1V^^00Co06J[o`M/[_l:KZooKJW@e?ooool004Sooooo00cok?Cio`1PYol7K:ko0VV/ocF7_OnKa=ko
LJ_AoaYh]?l0J:co1F^^o`1SZOmTXld5ooooo`03oncdnOmMWl[o066X00?o1fb^017o066Xoj[=i?ol
oOkoooooom[Ylon1]=GoRk[IofJTcOl2I:[o1fb^o`9UZ_mDV/OoT;gJoh6be?o>h^ooo_knon_cn004
o`M/[P03o`1X[?lcQkgoenOb00Cooooo00_o<8Bko`I[[_l7K:ko2fn_okoIj_nNa^3o9gnho`9X[?l0
IZ[o>8VnomGVlP05ooooo`03ojS;h_l0IZ_o1fb^00;o1fb^00?o06FZoeJKb?o`m_X01?ooool02Om/
Yloo1V^^o`M/[_l;KZooDIS6ohRheolhRKko<XJlomWYl`02ooooo`0Coe2Ga_l0Ij_o1fb^o`9X[?n4
]]OoQkSGohJheon@_M_of^Wcooooooo1fn_o6GNeo`1W[?l2JJco:H2ioh2deOmZYlko26f_oi_4gP3o
ooooooooooooBoooool03?lCLk;o1fb^o`I[[_lHM[CoV<;Log^ae?l/P[[o06BYo`I[[_l0HjWo@i32
oncdn@Cooooo00?on?_lohFfeol0H:L00ol7K:h04ol0H:OoOK;EooKjo?oooooojo?iohjlfOn7^=Oo
P;CEo`9VZol7K:ko0VR/oc25^onG`McoPK?DokWEj?oloOkoo?knobj4^ol5Jjd00_l7K:h00ol6K:ko
5gJcokoIjP3Dooooo`00B?ooool03?o/m?Wo062Wo`M/[_l8KJko06R/o`1OYol0HZSo06N[o`1VZol0
Ij_oA931onken@Kooooo00OoXLOPo`YW[?l4Jjgo1fb^o`=Y[?lEM;;okOCi00;ooooo00ooZlgSo`1F
X_l0H:Oo06>Yo`Q][ol7K:ko26f_o`1UZ_l0GjOo05>Qoi6nf_oio?goooooodBA`_l3JZd00_l7K:h0
0ol0IZ_oFik9ooooo`04ooooo`0;oc24^ol6Jjko1fb^o`I/[_l0G:Go05jVo`1X[?l2JJco06>YofBS
cOo]mOT01Oooool01oocn?_o67Jco`A[[Ol7K:ko1F^^o`Y][_nC_m/01Oooool03ooHio?o:h6io`1V
Z_l4JZgo06BZo`1PYol0HZWo06>YogJ^dooinogooooooe2Ga_l0Ij_o1fb^o`Q][P02o`1PZ009o`1O
Z?l8K:ko/M7Vooooooobmo_oMJgCo`9WZol0J:co06N[00;o066X00?o06BZoaMf]?oXlOL0oooooooo
oooood[ooooo00Ko4g>bo`M/[_l7K:ko16Z]o`1OYol0HJP3o`1VZ`03oc:3^oo@ho3ooooo00Gooooo
00Ood>?`oa1[[Ol4Jjgo1fb^o`AZ[Ol>KJko_mWZ00;ooooo00ood^C`o`9Y[?l0H:So066Xo`Q][_l7
K:ko26f^o`5X[?l0GjOo05FQof:Rboocn?_oooooofjZd?l<Kjl00_l7K:h00ol6Jjko:X6ioo_moP3D
ooooo`00B?ooool00ooZloWo05>Po`1PY`03o`1PY`05o`1QYol=Kk3o;H>kogJ]doo_m_T01oooool0
1ooFi_;o:X6jo`1JY?l0H:Oo05FQofNUcOocmo/00_ooool00on[cN?o05JRo`1PY`06o`1PY`0:o`1C
XOnA_][on_cmoooooon`d>Go05VTo`1PYol0GZKo16Z]oiW2g@Gooooo00?o7gZfo`1OYol0H:L00ol0
H:L01?l0HjWo5GBcodbEaOoCiO07ooooo`06of^Wc_l0FZCo062Wo`1LYOlTOKOod>C`1_ooool03?nk
enWo>h^oo`M/[_l0GjKo06>YoaQe/olkR;koSKcJooGio?oooooo@Xo1o`1KY0Co062W00?o05nWo`Q/
[_nadNH00_ooool02OoVlOOoL:[@oaYg]?l0HjWo05jVo`I[[_l[P[[oDIS6om[Yl`3ooooooooooooo
B_ooool00ol0J:co062Wo`1PY`02o`1PY`05o`1QYol6K:ko:H2jofBSc?oGio801oooool01oo_mO[o
BIC4o`1HXol0H:Oo05RSod6@`OoRk_D00_ooool00ooBi?3o0VV/o`1PY`06o`1PY`06o`1EXOmRX/_o
loWkoooooooDi_7o1f^^0_l0H:L00ol0I:WoKJW?ooooo`3Dooooo`00B?ooool00oofn_coP;3Coh>f
e`02oh>fe`04oh:eeon5]]OoXLOPolcQkPWooooo00Oom?Skoj[<hon0/]CoPkKGoh2_doo@hnoooOkn
00;ooooo00?of>Sboh2ae?n3]]L01_n3]]L02_n0/=Coc>7^oogno_ooooooloSkoh2be?n3]]OoP;CE
oiO1gOoXlOL5ooooo`03oiS2gOn3]MOoPkKG00;oPkKG00CoP[GGohVif?n]c^Coi_3g2?ooool01_o>
h^ooP;;Doh>feomo/mGoYLWRoo_moPOooooo00KofNScoi_3g_n0]=GoR;SHojg>i?oNk?D3ooooo`03
ojS;hon0/mGoPkKG00?oPkKG00?oPkGGohfkf_oKj_@00oooool01oohn_go]]CWohRhf?mo/mGoV/?N
olCLk?oio?d0oooooooooooood_ooooo00?oRKWIoh>feon3]]L00_n3]]L01?n4]]OoV/?NolKMkOon
o_l8ooooo`07oo[loOnmf>[oP;3Doh>feon0/MCo^MKXoocmoP02ooooo`03on[cn?n:^]WoPkKG00Ko
PkKG00?oP;7DokODioojo?d00_ooool01On?_M[oP[KGoh>feon8^MSofn[c0=Gooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooo
ooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Co
oooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003o
ooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooo
ooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Co
oooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003o
ooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooo
ooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Co
oooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003o
ooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooo
ooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Co
oooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003o
ooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooo
ooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Co
oooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003o
ooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooo
ooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Co
oooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003o
ooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooo
ooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Co
oooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003o
ooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooo
ooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooo
ooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooooooooooooooo
o`Cooooo003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo
003oooooooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooo
ooooooooooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo003ooooooooooooo
ooooooooooooo`Cooooo003oooooooooooooooooooooooooo`Cooooo0000\
\>"], "Graphics",
  Evaluatable->False,
  AutoIndent->False,
  ImageSize->{1024, 768},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Deployment",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "A suite of products all using the .nb notebook standard and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language.\n\n",
  StyleBox["\[Bullet] ",
    FontWeight->"Bold"],
  StyleBox["Mathematica\t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\t\t(High level development environment for modelling, analysis and \
computation)\n",
  StyleBox["\[Bullet] web",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\t\t(For widescale deployment of computations) [",
  Cell[BoxData[
      ButtonBox[\(Index\ of\ examples\),
        ButtonData:>{
          URL[ "http://localhost:8080/webMathematica/index.html"], None},
        ButtonStyle->"Hyperlink"]]],
  "]\n",
  StyleBox["\[Bullet] grid",
    FontWeight->"Bold"],
  StyleBox["Mathematica\t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\t(High performance computations for multi-CPU environments)\n",
  StyleBox["\[Bullet] CalculationCenter",
    FontWeight->"Bold"],
  "\t\t(Mid-market computation software)\n",
  StyleBox["\[Bullet] Publicon",
    FontWeight->"Bold"],
  "\t\t\t(Technical publishing environment)\n",
  StyleBox["\[Bullet] ",
    FontWeight->"Bold"],
  StyleBox["MathReader",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\t\t\t(Free reader program for notebooks)"
}], "Text",
  CellTags->"b:2.5"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has been around for more than a decade now, and we have many application \
libraries for extending it."
}], "Text",
  CellTags->"b:2.5"],

Cell[BoxData[GridBox[{
        {\(Control\ System\ Professional\n
          Control\ System\ Professional\ Suite\n
          Database\ Access\ Kit\n
          Digital\ Image\ Processing\n
          Dynamic\ Visualizer\n
          Experimental\ Data\ Analyst\n
          Electrical\ Engineering\ Examples\n
          Finance\ Essentials\n
          Fuzzy\ Logic\n
          Mathematica\ Link\ for\ Excel\n
          Mechanical\ Systems\n
          Neural\ Networks\n
          A\ New\ Kind\ of\ Science\ \(Explorer : Mathematica\ Kit\)\n
          mathStatica\n
          Parallel\ Computing\ Toolkit\n
          Scientific\ Astronomer\n
          Signals\ and\ Systems\n
          Structural\ Mechanics\n
          Time\ Series\n
          Wavelet\ Explorer\n
          Advanced\ Modern\ Control\[IndentingNewLine]
          SchematicSolver\n
          Tensors\ in\ Physics\[IndentingNewLine]
          \(\(Var\)\(+\)\)\), \(\(Analog\ Insydes\)\(\n\)
          \(Derivatives\ Expert\)\(\ \)\(\n\)
          \(Geometrica\)\(\n\)
          \(Global\ Optimization\)\(\n\)
          \(Industrial\ Electromagnetism\)\(\n\)
          \(Industrial\ Optimization\)\(\n\)
          \(Industrial\ Thermics\)\(\n\)
          \(machine\ learning\ framework\)\(\ \)\(\n\)
          \(MathCode\ \(C++\)\)\(\ \)\(\n\)
          \(Mathematica\ Link\ for\ LabVIEW\)\(\ \)\(\n\)
          \(MathOptimizer\)\(\n\)
          \(MathOptimizer\ Professional\ \(New!\)\)\(\n\)
          \(MathTensor\)\(\ \)\(\n\)
          \(Operations\ Research\)\(\ \)\(\n\)
          \(PrimeKit\)\(\n\)
          \(RiskQ\)\(\ \)\(\n\)
          \(TSi\ ProPac\)\(\n\)
          \(UnRisk\ PRICING\ ENGINE\)\(\n\)
          \(UnRisk\ STANDARD\)\(\n\)
          \(VisualDSolve\)\(\n\)
          \(Artlandia\)\(\ \)\(\n\)
          \(Mathematica\ for\ ActiveX\)\(\ \)\(\n\)
          \(MathEverywhere\ Courseware\ Series\)\(\n\)
          \(MathModelica\)\(\ \)\)}
        }]], "Text",
  FontFamily->"Times New Roman"],

Cell["\<\
There are also several education specific application \
libraries.\
\>", "Text"],

Cell[TextData[{
  StyleBox["\[Bullet] Teachers' edition\t\t\t",
    FontWeight->"Bold"],
  "(",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  StyleBox["capabilities with added courseware, test generator and other \
tools for teachers).\n\[Bullet] Calculus Wiz: \t\t\t\t(An interactive \
calculus guide with palette driven interface and the power of ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[")\n\[Bullet] Mathematical Explorer\t\t(Journey to the Frontiers \
of Mathematics)\n\[Bullet] NKSx\t\t\t\t\t(Explore a New Kind of Science \
interactively)",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Java",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ships with a well-developed link to Java that allows you to interactively \
work with a Java runtime, accessing anything that the runtime can work with."
}], "Text"],

Cell[TextData[{
  "Here is an example of an interactive interface based on Java.  The \
EquationTrekker package is a combination of Java and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code.  It uses the GUIKit` application library that provides a relatively \
simple ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " interface for producing graphical user interfaces."
}], "Text"],

Cell[BoxData[
    \(Needs["\<NumericalMath`EquationTrekker`\>"]\)], "Input",
  CellLabel->"In[54]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquationTrekker[{\ \(x''\)[t]\  + \ \[Gamma]\ \(x'\)[\ t]\  - \ 
            x[t]\  + \ x[t]^3\  \[Equal] \ \[Epsilon]\ Cos[\[Omega]\ t]}, \ 
      x, \ {t, 0, 
        100}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), 2}, {\(-2\), 
            2}}, \[IndentingNewLine]TrekParameters \[Rule] {\[Gamma] \[Rule]  \
.15, \ \[Epsilon] \[Rule]  .3, \ \[Omega] \[Rule] 1. }]\)], "Input",
  CellLabel->"In[55]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.035 0 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.035 0 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 1 .016 r
.5 Mabswid
.5675 .66 m
.56753 .66002 L
.56757 .66005 L
.56834 .6606 L
.56911 .66115 L
.56989 .6617 L
.57221 .66335 L
.57455 .66503 L
.57692 .66672 L
.5793 .66843 L
.58376 .67163 L
.58829 .67489 L
.59291 .6782 L
.59762 .68156 L
.60242 .68497 L
.61049 .69064 L
.61881 .6964 L
.62738 .70219 L
.63619 .70798 L
.64526 .71372 L
.65457 .71937 L
.66626 .72605 L
.6783 .73237 L
.68807 .73703 L
.69803 .7413 L
.70816 .7451 L
.71843 .74834 L
.72882 .75092 L
.73742 .75246 L
.74606 .75344 L
.75473 .75378 L
.7634 .75343 L
.77204 .75233 L
.78063 .75041 L
.79208 .74643 L
.80331 .74072 L
.81181 .73505 L
.82008 .72822 L
.82809 .72021 L
.83579 .71099 L
.84314 .70054 L
.85009 .68888 L
.85661 .67602 L
.86352 .65974 L
.86974 .64201 L
.8752 .62292 L
.87984 .60264 L
.88363 .58133 L
.88653 .55919 L
.8885 .53645 L
Mistroke
.88952 .51333 L
.88959 .49009 L
.88871 .46698 L
.88688 .44423 L
.88373 .41944 L
.87946 .39571 L
.87412 .3733 L
.86779 .35242 L
.86053 .33325 L
.85243 .31593 L
.84357 .30051 L
.83405 .28704 L
.82977 .28183 L
.82538 .27698 L
.82091 .27247 L
.81634 .26831 L
.8117 .26449 L
.80699 .26099 L
.8022 .25781 L
.79081 .25158 L
.77917 .24691 L
.76734 .24364 L
.75539 .24163 L
.74338 .24071 L
.73134 .24073 L
.71932 .24154 L
.70736 .24299 L
.69391 .24522 L
.6806 .24792 L
.66744 .2509 L
.65444 .25404 L
.6416 .2572 L
.62893 .26026 L
.61641 .26313 L
.60404 .26572 L
.58785 .26862 L
.57185 .27079 L
.55596 .27213 L
.54014 .27259 L
.52432 .27211 L
.50843 .27066 L
.49241 .26826 L
.47619 .26492 L
.4597 .26069 L
.43991 .25467 L
.41959 .24769 L
.39867 .23996 L
.37709 .23183 L
.35941 .22532 L
.34131 .21908 L
Mistroke
.32282 .21342 L
.30399 .20872 L
.2849 .20539 L
.26565 .20391 L
.24638 .2048 L
.22725 .2086 L
.21168 .21431 L
.19649 .22267 L
.18182 .23393 L
.16784 .24828 L
.15473 .26586 L
.14265 .2867 L
.13178 .31076 L
.12229 .33784 L
.11761 .35432 L
.11344 .37161 L
.10981 .38961 L
.10674 .40823 L
.10424 .42738 L
.10233 .44693 L
.10102 .46678 L
.10031 .48681 L
.10021 .50689 L
.10073 .52689 L
.10206 .5496 L
.10419 .57188 L
.10707 .59354 L
.1107 .61444 L
.11505 .63442 L
.12007 .65337 L
.12574 .67119 L
.13201 .68778 L
.141 .70747 L
.15083 .72491 L
.1614 .74008 L
.17262 .75302 L
.18437 .76379 L
.19656 .7725 L
.20911 .77931 L
.22192 .78438 L
.23493 .78788 L
.2515 .79034 L
.26816 .79098 L
.28481 .79017 L
.30138 .78823 L
.31781 .78548 L
.33407 .78221 L
.35013 .77866 L
.36599 .77505 L
.38165 .77155 L
Mistroke
.39927 .7679 L
.41668 .76478 L
.4339 .76233 L
.45099 .76066 L
.46799 .75984 L
.48497 .75992 L
.50199 .76091 L
.5191 .7628 L
.53636 .76555 L
.55615 .76963 L
.57628 .7746 L
.5968 .78025 L
.61776 .78633 L
.63917 .79249 L
.66103 .79831 L
.68329 .80328 L
.70587 .80677 L
.72863 .8081 L
.75138 .80646 L
.77005 .80228 L
.78837 .79503 L
.80614 .78427 L
.82314 .76962 L
.83911 .7508 L
.85379 .72765 L
.86692 .70021 L
.87334 .68351 L
.87917 .66565 L
.88439 .64672 L
.88897 .62682 L
.89286 .60606 L
.89605 .58458 L
.89851 .56252 L
.90022 .54005 L
.90125 .51408 L
.90129 .48803 L
.90034 .46217 L
.89841 .43675 L
.89552 .412 L
.89171 .38815 L
.887 .36541 L
.88145 .34393 L
.8782 .33316 L
.87473 .32281 L
.87106 .31288 L
.8672 .30339 L
.86315 .29435 L
.85892 .28576 L
.85452 .27764 L
.84649 .26459 L
Mistroke
.83802 .25294 L
.82917 .24268 L
.81998 .23377 L
.8105 .22615 L
.80078 .21977 L
.79085 .21454 L
.77953 .20997 L
.76806 .20663 L
.75649 .20439 L
.74484 .20315 L
.73316 .20276 L
.72148 .2031 L
.70983 .20407 L
.69822 .20554 L
.68292 .20811 L
.66776 .21117 L
.65277 .21452 L
.63796 .21799 L
.62334 .22143 L
.60888 .22471 L
.59459 .22772 L
.58045 .23038 L
.5629 .23311 L
.54551 .23507 L
.52821 .23618 L
.51096 .23641 L
.49369 .23575 L
.47635 .23421 L
.45889 .23184 L
.44124 .2287 L
.42337 .22491 L
.40262 .21996 L
.38148 .2146 L
.35994 .20919 L
.33801 .20416 L
.31573 .20003 L
.29319 .19743 L
.27054 .19704 L
.24797 .19965 L
.22971 .20459 L
.21183 .21253 L
.19455 .22387 L
.17808 .23895 L
.16265 .25802 L
.14851 .28119 L
.13592 .30842 L
.12966 .32525 L
.12401 .3432 L
.11898 .36219 L
.11461 .3821 L
Mistroke
.11094 .40281 L
.10799 .42419 L
.10577 .44608 L
.10431 .46833 L
.10358 .49382 L
.10383 .51931 L
.10507 .54453 L
.10728 .56923 L
.11043 .59319 L
.1145 .61619 L
.11943 .63805 L
.12519 .65861 L
.13132 .67667 L
.13809 .69338 L
.14544 .70867 L
.15333 .72251 L
.1617 .73488 L
.17049 .74581 L
.17966 .75533 L
.18915 .76347 L
.2025 .77247 L
.21625 .77924 L
.23029 .78399 L
.24451 .78695 L
.25885 .78837 L
.27322 .78847 L
.28757 .78751 L
.30184 .78568 L
.31601 .78319 L
.33005 .78022 L
.34392 .77694 L
.36164 .77247 L
.37906 .76799 L
.3962 .76372 L
.41308 .75984 L
.42973 .75649 L
.44617 .75377 L
.46247 .75176 L
.47866 .7505 L
.49479 .75001 L
.51092 .75031 L
.52709 .75136 L
.54572 .75343 L
.56453 .75634 L
.58359 .75993 L
.60293 .76402 L
.62259 .76837 L
.64256 .77265 L
.66284 .77652 L
.68338 .77952 L
Mistroke
.70408 .78115 L
.72485 .78083 L
.74549 .77795 L
.76581 .77187 L
.78071 .76482 L
.79515 .75537 L
.79518 .75535 L
.7952 .75533 L
.79523 .75531 L
.79526 .75529 L
.79528 .75527 L
.79534 .75523 L
.79539 .75519 L
.79544 .75515 L
.79597 .75474 L
.79651 .75433 L
.79704 .75391 L
.79757 .75349 L
.80156 .75019 L
.80551 .74667 L
.80939 .74292 L
.81321 .73894 L
.81697 .73474 L
.82322 .72705 L
.82925 .71867 L
.83504 .70962 L
.84058 .69989 L
.84585 .6895 L
.85083 .67845 L
.85636 .66445 L
.86143 .64959 L
.866 .63394 L
.87006 .61755 L
.87358 .60052 L
.87654 .58294 L
.87893 .56489 L
.88034 .551 L
.88142 .53695 L
.88215 .5228 L
.88253 .5086 L
.88257 .4944 L
.88226 .48025 L
.8816 .46621 L
.88044 .4504 L
.87885 .43487 L
.87682 .41967 L
.87438 .40489 L
.87153 .39057 L
.86829 .37677 L
.8642 .36194 L
Mistroke
.85966 .34789 L
.85469 .33467 L
.84932 .32231 L
.84358 .31085 L
.8375 .3003 L
.8311 .29066 L
.82295 .28021 L
.81444 .27108 L
.8056 .26325 L
.79649 .25665 L
.78715 .25123 L
.77763 .24692 L
.76797 .24364 L
.75819 .2413 L
.74379 .23941 L
.72933 .2391 L
.71489 .24011 L
.70053 .24218 L
.68631 .24508 L
.67227 .24861 L
.65844 .25258 L
.64484 .25682 L
.63148 .26118 L
.61587 .26639 L
.60059 .27143 L
.58564 .27618 L
.571 .28054 L
.55662 .28441 L
.54248 .28775 L
.52855 .29052 L
.51478 .2927 L
.50113 .29428 L
.48469 .29542 L
.46832 .29573 L
.45193 .29528 L
.43548 .29415 L
.41892 .29245 L
.4022 .29034 L
.38531 .28799 L
.36822 .28561 L
.35095 .28347 L
.33298 .28182 L
.3149 .2811 L
.29683 .28173 L
.27887 .28417 L
.26121 .28888 L
.24404 .2963 L
.23047 .30473 L
.21754 .31546 L
.20543 .3286 L
Mistroke
.19429 .3442 L
.1843 .36222 L
.17561 .38251 L
.16836 .40481 L
.16358 .42445 L
.15992 .44496 L
.15742 .46606 L
.15612 .48745 L
.15602 .5088 L
.1571 .52978 L
.15934 .5501 L
.16269 .56945 L
.1671 .58758 L
.17248 .60428 L
.17875 .61938 L
.18582 .63275 L
.19317 .64377 L
.20106 .65315 L
.20941 .66091 L
.21813 .66707 L
.22714 .67171 L
.23635 .67491 L
.24569 .67676 L
.25511 .67738 L
.26452 .67687 L
.27797 .67439 L
.29116 .67015 L
.30396 .66446 L
.31629 .65759 L
.32805 .64981 L
.33919 .64131 L
.34966 .63227 L
.35942 .62282 L
.36844 .61309 L
.37795 .60157 L
.38643 .58987 L
.39387 .57805 L
.40026 .56615 L
.40559 .55418 L
.40986 .54215 L
.41306 .53006 L
.41518 .51788 L
.41622 .50561 L
.41608 .49152 L
.41451 .47725 L
.41149 .4628 L
.40701 .44814 L
.40104 .43328 L
.39356 .41826 L
.38457 .40314 L
Mistroke
.37405 .38801 L
.36201 .37303 L
.34849 .35845 L
.33352 .34457 L
.31721 .33182 L
.2997 .32076 L
.28119 .31208 L
.26195 .30656 L
.24813 .30505 L
.23429 .30588 L
.23153 .30636 L
.22878 .30695 L
.22604 .30764 L
.22331 .30845 L
.22059 .30938 L
.21789 .31042 L
.2152 .31158 L
.21253 .31287 L
.20725 .31581 L
.20206 .31926 L
.19698 .32323 L
.19201 .32772 L
.18718 .33275 L
.18251 .33832 L
.17799 .34442 L
.17063 .35622 L
.16388 .36957 L
.15782 .38438 L
.15253 .40056 L
.14807 .41794 L
.14448 .43634 L
.14182 .45557 L
.14012 .47538 L
.1394 .49553 L
.13968 .51576 L
.14095 .53582 L
.1432 .55545 L
.14639 .57441 L
.1505 .59251 L
.15382 .60431 L
.15753 .61557 L
.16161 .62623 L
.16603 .63626 L
.17079 .64564 L
.17585 .65435 L
.18119 .66236 L
.18657 .66942 L
.19217 .67583 L
.19796 .68162 L
.20394 .68678 L
Mistroke
.21007 .69134 L
.21634 .69531 L
.22273 .69873 L
.2322 .70275 L
.24184 .70573 L
.2516 .70776 L
.26143 .70895 L
.2713 .70938 L
.28118 .70917 L
.29103 .7084 L
.30083 .70717 L
.31304 .70511 L
.32511 .70262 L
.33703 .69984 L
.34877 .69689 L
.36034 .6939 L
.37173 .69094 L
.38295 .68811 L
.39401 .68547 L
.40829 .68239 L
.42235 .67985 L
.43624 .67791 L
.45 .67663 L
.46369 .67605 L
.47737 .67618 L
.49108 .67704 L
.50489 .67862 L
.51884 .68089 L
.53731 .68484 L
.55623 .68981 L
.5757 .69562 L
.59579 .70205 L
.61228 .70741 L
.6292 .71274 L
.64654 .71779 L
.66427 .72225 L
.68233 .72575 L
.70061 .72786 L
.71899 .72811 L
.73729 .72599 L
.75228 .72205 L
.76694 .71584 L
.7788 .70871 L
.79022 .69969 L
.7988 .69121 L
.80699 .68147 L
.81472 .67047 L
.82193 .65822 L
.82859 .64475 L
.83462 .63012 L
Mistroke
.84 .61442 L
.84465 .59774 L
.84856 .58022 L
.85169 .562 L
.85326 .55008 L
.85449 .53798 L
.85539 .52577 L
.85594 .51348 L
.85614 .50117 L
.856 .48889 L
.85552 .4767 L
.8544 .46116 L
.85271 .44595 L
.85049 .43115 L
.84828 .41941 L
.84572 .40807 L
.84284 .39714 L
.83964 .38668 L
.83614 .37672 L
.83235 .36728 L
.82739 .35656 L
.82207 .34667 L
.8164 .33763 L
.81043 .32945 L
.80418 .32212 L
.79768 .31563 L
.79096 .30998 L
.78155 .30359 L
.77186 .2986 L
.76197 .29493 L
.75192 .29248 L
.74179 .29112 L
.73161 .29076 L
.72143 .29128 L
.7113 .29257 L
.69992 .29482 L
.68868 .29778 L
.67762 .30132 L
.66677 .3053 L
.65615 .30964 L
.64578 .31422 L
.63566 .31897 L
.62581 .32382 L
.61375 .33 L
.60211 .33614 L
.5909 .34217 L
.5801 .34803 L
.56971 .35368 L
.5597 .35909 L
.55005 .36424 L
Mistroke
.54076 .36913 L
.5318 .37374 L
.5208 .37924 L
.51026 .38431 L
.50016 .38895 L
.49046 .39318 L
.48111 .39703 L
.47209 .4005 L
.46336 .40362 L
.4549 .40639 L
.44667 .40882 L
.43732 .41124 L
.4282 .41323 L
.41927 .41477 L
.41047 .41588 L
.40177 .41655 L
.39311 .41678 L
.38445 .41656 L
.37575 .41592 L
.36696 .41485 L
.35548 .4129 L
.3437 .41038 L
.33156 .40741 L
.319 .4042 L
.30601 .401 L
.29261 .39816 L
.27888 .39607 L
.26494 .39523 L
.25501 .39568 L
.24517 .3972 L
.23745 .39931 L
.22992 .4023 L
.22265 .40623 L
.21572 .41114 L
.2092 .41705 L
.20316 .42396 L
.19769 .43181 L
.19284 .44053 L
.18869 .45 L
.18527 .46009 L
.18264 .47062 L
.18082 .4814 L
.17982 .49222 L
.17964 .50287 L
.18025 .51314 L
.18162 .52284 L
.1837 .53179 L
.18469 .53505 L
.18577 .53817 L
.18694 .54113 L
Mistroke
.1882 .54394 L
.18954 .54659 L
.19096 .54907 L
.19245 .55138 L
.19568 .55557 L
.19915 .55903 L
.20281 .56177 L
.2066 .56379 L
.2105 .56513 L
.21446 .56581 L
.21845 .56588 L
.2229 .56528 L
.22729 .56404 L
.23157 .56223 L
.23571 .55993 L
.23969 .55722 L
.24346 .55417 L
.24703 .55086 L
.25036 .54737 L
.25416 .54287 L
.25758 .5383 L
.26061 .53377 L
.26327 .52936 L
.26556 .52517 L
.26751 .52125 L
.26915 .51766 L
.2705 .51446 L
.2716 .51166 L
.27248 .5093 L
.27318 .50739 L
.27386 .50563 L
.2744 .50458 L
.27486 .5042 L
.27532 .50446 L
.27583 .50527 L
.27645 .50657 L
.27724 .50824 L
.27812 .51001 L
.27918 .51192 L
.28043 .5139 L
.28188 .51585 L
.2835 .51769 L
.2853 .51933 L
.28724 .5207 L
.2893 .52173 L
.29144 .52236 L
.29362 .52251 L
.29619 .52203 L
.29866 .52077 L
.30056 .51909 L
Mistroke
.30227 .51682 L
.30373 .51395 L
.3049 .51047 L
.3057 .50639 L
.30609 .50171 L
.30601 .49645 L
.30528 .48988 L
.30382 .48268 L
.30157 .47491 L
.29845 .46667 L
.29444 .45809 L
.2895 .44933 L
.28363 .44057 L
.27683 .43205 L
.2705 .42534 L
.26359 .41916 L
.25617 .41371 L
.2483 .40921 L
.24009 .40589 L
.23164 .40397 L
.22309 .40368 L
.21613 .40479 L
.20931 .4072 L
.20406 .41009 L
.199 .41387 L
.19419 .41853 L
.18966 .42408 L
.18549 .4305 L
.1817 .43773 L
.17835 .44573 L
.17548 .45441 L
.17313 .46369 L
.17132 .47345 L
.17009 .48359 L
.16944 .49397 L
.1694 .50446 L
.16995 .51492 L
.17111 .52524 L
.17284 .53526 L
.17502 .54444 L
.17769 .55315 L
.18082 .56134 L
.18439 .56891 L
.18834 .57584 L
.19266 .58207 L
.1973 .58758 L
.20222 .59236 L
.21137 .59897 L
.22104 .60345 L
.22881 .60558 L
Mistroke
.23669 .60662 L
.24462 .6067 L
.25252 .60595 L
.26033 .60449 L
.26802 .60245 L
.27554 .59993 L
.28285 .59707 L
.28994 .59394 L
.2953 .59138 L
.3005 .58876 L
.30555 .58611 L
.31044 .58344 L
.31519 .58079 L
.31978 .57818 L
.32422 .57562 L
.32851 .57312 L
.33485 .56942 L
.34087 .56593 L
.34659 .56263 L
.35203 .55955 L
.3572 .55666 L
.36212 .55394 L
.3668 .55137 L
.37126 .54892 L
.37671 .54587 L
.3818 .54287 L
.38655 .53984 L
.39095 .53668 L
.39497 .5333 L
.39859 .52961 L
.40176 .52551 L
.40443 .52093 L
.40704 .51419 L
.40856 .50632 L
.40884 .49717 L
.40766 .48659 L
.40558 .47725 L
.40238 .46693 L
.39793 .45558 L
.39211 .4432 L
.3848 .42983 L
.3759 .41551 L
.3653 .4004 L
.35293 .38469 L
.34238 .37263 L
.33078 .36062 L
.32049 .35095 L
.30951 .34166 L
.30036 .33469 L
.29083 .3282 L
Mistroke
.28096 .32231 L
.27076 .31716 L
.26031 .31292 L
.24964 .30974 L
.23883 .30781 L
.22648 .30734 L
.21416 .30895 L
.20416 .31201 L
.19436 .31676 L
.18486 .3233 L
.17575 .33169 L
.16714 .34198 L
.15912 .35417 L
.15179 .3682 L
.14525 .38399 L
.1417 .39436 L
.1385 .40528 L
.13565 .41671 L
.13317 .42858 L
.13108 .44085 L
.12939 .45345 L
.12811 .4663 L
.12724 .47934 L
.12679 .4925 L
.12676 .5057 L
.12731 .52204 L
.12851 .53817 L
.13034 .55398 L
.13279 .56932 L
.13584 .58408 L
.13946 .59815 L
.14363 .61143 L
.1483 .62386 L
.15582 .64002 L
.16419 .65417 L
.17331 .66625 L
.18306 .67627 L
.19332 .68428 L
.20398 .69037 L
.21493 .6947 L
.22609 .69741 L
.23736 .69868 L
.25024 .69862 L
.26307 .69721 L
.27577 .69471 L
.28829 .69137 L
.30057 .68743 L
.31257 .68309 L
.32429 .67853 L
.33571 .6739 L
Mistroke
.34683 .66934 L
.35777 .66492 L
.36843 .66078 L
.37882 .65699 L
.38899 .65362 L
.39894 .65071 L
.40872 .64831 L
.41837 .64644 L
.42791 .64512 L
.43738 .64437 L
.45008 .64426 L
.46282 .64522 L
.4757 .64722 L
.48879 .65028 L
.5022 .65437 L
.51602 .65947 L
.53033 .66553 L
.54521 .67251 L
.56075 .68033 L
.57701 .68887 L
.59404 .69798 L
.6119 .70744 L
.63059 .71698 L
.65012 .72623 L
.67043 .73471 L
.69143 .74184 L
.71298 .74692 L
.73485 .74912 L
.75249 .7482 L
.76996 .74437 L
.78474 .73836 L
.79907 .72956 L
.81013 .72033 L
.82068 .70907 L
.83063 .69574 L
.83987 .68034 L
.84831 .66292 L
.85585 .64357 L
.86239 .62244 L
.86785 .59974 L
.87101 .58298 L
.87358 .56566 L
.87554 .54792 L
.87688 .52986 L
.8776 .51161 L
.87768 .49331 L
.87714 .47508 L
.87596 .45704 L
.87417 .43933 L
.87178 .42205 L
Mistroke
.86819 .40235 L
.86381 .38358 L
.85869 .36588 L
.85287 .34936 L
.8464 .33412 L
.83934 .32021 L
.83174 .30768 L
.82365 .29653 L
.81391 .2855 L
.8037 .27621 L
.79309 .26858 L
.78217 .26252 L
.77099 .25791 L
.75964 .25461 L
.74815 .2525 L
.7366 .25143 L
.72501 .25126 L
.71344 .25186 L
.70191 .25309 L
.68868 .25515 L
.67558 .25771 L
.66262 .26063 L
.64983 .26376 L
.63721 .26699 L
.62476 .27019 L
.61248 .27328 L
.60037 .27619 L
.58455 .27964 L
.56896 .28253 L
.55355 .28477 L
.53828 .2863 L
.52308 .28708 L
.50792 .28709 L
.49273 .28633 L
.47746 .28482 L
.46206 .2826 L
.44383 .27919 L
.42528 .27502 L
.40636 .27028 L
.38703 .26519 L
.36727 .26005 L
.3471 .25525 L
.32656 .25124 L
.30573 .24856 L
.28476 .24782 L
.26383 .24971 L
.24701 .25368 L
.23054 .26024 L
.21462 .26974 L
.19945 .28247 L
Mistroke
.18525 .29863 L
.17227 .31833 L
.16074 .34148 L
.15487 .35623 L
.1496 .37199 L
.14495 .38865 L
.14097 .40613 L
.13768 .42428 L
.1351 .44299 L
.13326 .4621 L
.13216 .48146 L
.13183 .50307 L
.13243 .52456 L
.13394 .5457 L
.13636 .56628 L
.13965 .5861 L
.14377 .60498 L
.14869 .62277 L
.15435 .63934 L
.15754 .64739 L
.16092 .65508 L
.16446 .6624 L
.16816 .66933 L
.17201 .67588 L
.176 .68204 L
.18012 .68781 L
.18785 .69723 L
.19594 .7054 L
.20432 .71237 L
.21297 .71818 L
.22182 .72289 L
.23084 .72656 L
.23999 .72926 L
.24923 .73108 L
.26379 .73233 L
.27836 .7319 L
.29286 .73007 L
.30721 .72714 L
.32135 .72335 L
.33523 .71892 L
.34882 .71407 L
.3621 .70894 L
.37504 .7037 L
.38941 .69773 L
.40335 .6919 L
.41688 .68632 L
.43002 .68108 L
.4428 .67623 L
.45525 .67181 L
.4674 .66785 L
Mistroke
.47929 .66437 L
.49094 .66135 L
.50466 .65836 L
.51815 .65602 L
.53147 .6543 L
.54467 .65315 L
.55779 .65254 L
.57088 .65239 L
.58397 .65262 L
.5971 .65317 L
.61028 .65392 L
.62472 .65484 L
.63925 .65571 L
.65384 .65632 L
.66848 .65645 L
.68309 .65587 L
.69761 .6543 L
.71192 .65147 L
.7259 .64712 L
.73939 .64099 L
.75221 .63289 L
.76418 .62267 L
.7751 .6103 L
.78084 .6022 L
.78612 .59343 L
.79092 .58404 L
.79519 .5741 L
.79891 .56369 L
.80206 .55288 L
.80462 .54179 L
.80657 .53052 L
.80782 .52021 L
.80856 .50994 L
.8088 .49981 L
.80854 .4899 L
.80781 .48031 L
.80661 .47111 L
.80498 .46239 L
.80292 .45421 L
.80049 .44663 L
.79769 .43971 L
.79385 .43223 L
.78959 .42583 L
.78499 .42055 L
.7801 .41641 L
.775 .4134 L
.76975 .41149 L
.76442 .41066 L
.75907 .41084 L
.75376 .41199 L
Mistroke
.74855 .41405 L
.74348 .41694 L
.73861 .4206 L
.73399 .42495 L
.72872 .43111 L
.72394 .43808 L
.71969 .44575 L
.71603 .454 L
.71298 .46274 L
.71059 .47187 L
.70888 .48129 L
.70787 .49092 L
.70756 .50067 L
.70797 .51046 L
.70909 .52021 L
.71091 .52982 L
.71344 .53922 L
.71753 .55049 L
.72263 .56108 L
.72865 .57078 L
.7355 .57934 L
.74308 .58653 L
.75124 .59209 L
.75982 .59576 L
.76864 .59728 L
.77561 .59682 L
.78249 .59482 L
.78917 .59119 L
.79553 .58591 L
.80145 .57898 L
.80681 .57045 L
.81152 .56041 L
.81545 .54901 L
.81722 .54234 L
.81872 .53537 L
.81995 .52812 L
.8209 .52064 L
.82155 .51297 L
.8219 .50516 L
.82195 .49726 L
.82159 .48758 L
.82078 .47792 L
.81951 .46835 L
.8178 .45895 L
.81565 .44981 L
.81308 .44098 L
.8101 .43254 L
.80673 .42453 L
.803 .417 L
.79892 .41 L
Mistroke
.79468 .40375 L
.79016 .39803 L
.7854 .39285 L
.78041 .38822 L
.77522 .38413 L
.76986 .38057 L
.76435 .37752 L
.75768 .37457 L
.75086 .37227 L
.74393 .37058 L
.73693 .36946 L
.72989 .36886 L
.72282 .36872 L
.71576 .36899 L
.70872 .36963 L
.6996 .37093 L
.69058 .37266 L
.6817 .37473 L
.67297 .37705 L
.66441 .37956 L
.65603 .38219 L
.64784 .38488 L
.63985 .38759 L
.63022 .39092 L
.62088 .39417 L
.61182 .3973 L
.60303 .4003 L
.59449 .40315 L
.58619 .40585 L
.57812 .4084 L
.57027 .4108 L
.56262 .41308 L
.55287 .41589 L
.54344 .41854 L
.5343 .42106 L
.52544 .4235 L
.51686 .42589 L
.50855 .42826 L
.5005 .43063 L
.49273 .43302 L
.48524 .43545 L
.47802 .43792 L
.47109 .44042 L
.46444 .44295 L
.45717 .44585 L
.45028 .44871 L
.44376 .45147 L
.43759 .45406 L
.43174 .4564 L
.42617 .45839 L
Mistroke
.42084 .45992 L
.41567 .46088 L
.41058 .46117 L
.40486 .46054 L
.39897 .45875 L
.39272 .45565 L
.38591 .45112 L
.37981 .44632 L
.37308 .44047 L
.36559 .43358 L
.35722 .4257 L
.34785 .4169 L
.33739 .40735 L
.32826 .39937 L
.31836 .39123 L
.3077 .38312 L
.29628 .37531 L
.2864 .36934 L
.27608 .36398 L
.26538 .35945 L
.25437 .35599 L
.24314 .35386 L
.2318 .35333 L
.2205 .35466 L
.21124 .35736 L
.20221 .36162 L
.1935 .36755 L
.18523 .3752 L
.1775 .38459 L
.17044 .39569 L
.16413 .40841 L
.1587 .42262 L
.15576 .43224 L
.15323 .44231 L
.1511 .45277 L
.14941 .46354 L
.14816 .47454 L
.14735 .48569 L
.147 .49691 L
.1471 .50811 L
.14766 .5192 L
.14865 .5301 L
.15085 .54528 L
.15329 .55714 L
.15628 .56838 L
.15979 .57889 L
.16378 .58859 L
.16822 .59743 L
.17305 .60536 L
.17824 .61235 L
Mistroke
.18374 .6184 L
.18927 .62331 L
.19499 .62736 L
.20089 .63059 L
.20691 .63302 L
.21303 .6347 L
.21921 .63566 L
.22542 .63597 L
.23162 .63567 L
.2378 .63482 L
.24393 .63348 L
.24999 .63169 L
.25815 .62862 L
.2661 .62495 L
.2738 .6208 L
.28123 .6163 L
.28837 .61154 L
.29521 .60662 L
.30173 .60162 L
.30794 .59659 L
.31384 .59162 L
.32206 .58438 L
.32962 .57747 L
.33655 .57099 L
.3429 .56498 L
.34871 .55948 L
.35404 .55451 L
.35892 .55004 L
.3634 .54606 L
.36754 .54253 L
.37179 .53908 L
.3757 .53607 L
.37933 .53344 L
.38269 .5311 L
.38582 .52896 L
.38873 .52695 L
.39144 .52498 L
.39394 .52296 L
.39622 .52082 L
.39896 .51753 L
.40119 .51364 L
.40282 .50897 L
.40371 .50334 L
.40372 .49658 L
.40267 .48854 L
.40038 .47908 L
.39663 .46811 L
.3912 .45555 L
.38387 .44139 L
.37441 .42568 L
Mistroke
.3626 .40859 L
.35187 .39479 L
.33962 .38061 L
.32858 .3691 L
.31653 .3578 L
.30629 .34919 L
.29546 .34108 L
.28409 .33369 L
.27224 .32723 L
.25997 .32199 L
.24739 .31825 L
.23461 .31631 L
.22177 .31648 L
.20902 .31905 L
.1988 .32313 L
.18887 .32912 L
.17933 .33712 L
.17031 .34717 L
.16193 .3593 L
.15429 .37343 L
.14752 .38948 L
.14171 .40727 L
.13896 .41772 L
.13655 .42858 L
.13448 .43981 L
.13277 .45135 L
.13143 .46313 L
.13046 .47511 L
.12987 .48721 L
.12965 .49937 L
.12983 .51153 L
.13038 .52363 L
.13184 .54078 L
.13406 .55748 L
.13702 .57355 L
.14069 .58885 L
.14504 .60322 L
.15001 .61658 L
.15556 .62882 L
.16164 .63989 L
.16901 .65085 L
.17689 .66027 L
.18521 .66817 L
.1939 .67458 L
.20287 .67956 L
.21207 .68322 L
.22141 .68564 L
.23085 .68695 L
.24033 .68726 L
.25331 .68626 L
Mistroke
.26617 .68392 L
.27883 .68053 L
.29122 .67634 L
.3033 .67161 L
.31504 .66656 L
.32643 .66136 L
.33745 .65617 L
.34812 .65113 L
.36011 .64559 L
.37166 .64052 L
.38283 .63602 L
.39367 .63216 L
.40422 .62901 L
.41454 .62658 L
.4247 .62491 L
.43475 .624 L
.44476 .62385 L
.45654 .62466 L
.46844 .6265 L
.48057 .62938 L
.49302 .63327 L
.50588 .63814 L
.51926 .64396 L
.53322 .6507 L
.54787 .65829 L
.56328 .66665 L
.58138 .6767 L
.60058 .68732 L
.62091 .69818 L
.6381 .70677 L
.656 .71489 L
.67455 .72215 L
.69367 .72805 L
.71321 .73205 L
.73298 .73349 L
.75275 .7317 L
.75275 .7317 L
.75276 .7317 L
.75276 .7317 L
.75276 .7317 L
.75276 .7317 L
.75277 .73169 L
.75278 .73169 L
.75278 .73169 L
.75285 .73168 L
.75291 .73167 L
.75297 .73166 L
.75304 .73164 L
.75367 .73152 L
.75431 .7314 L
Mistroke
.75494 .73127 L
.75557 .73113 L
.7562 .73099 L
.76251 .72937 L
.76876 .72731 L
.77495 .72478 L
.78106 .72176 L
.78709 .71823 L
.79301 .71419 L
.80126 .70747 L
.80923 .69961 L
.81686 .6906 L
.82412 .68043 L
.83096 .66909 L
.83608 .65925 L
.84088 .6487 L
.84535 .63748 L
.84945 .62562 L
.85317 .61316 L
.8565 .60015 L
.85941 .58661 L
.8619 .57265 L
.86395 .55832 L
.86554 .54369 L
.86668 .52885 L
.86734 .51388 L
.86754 .49884 L
.86716 .48074 L
.86609 .46281 L
.86436 .4452 L
.86196 .42805 L
.85894 .41147 L
.85529 .39558 L
.85107 .38047 L
.84629 .36623 L
.83845 .34726 L
.82963 .3304 L
.81995 .31572 L
.80953 .30324 L
.79848 .29292 L
.78692 .28465 L
.77497 .27832 L
.76272 .27375 L
.75027 .27077 L
.73621 .26909 L
.7221 .26889 L
.70801 .26991 L
.69402 .27191 L
.68017 .27465 L
.66651 .27792 L
Mistroke
.65306 .28156 L
.63984 .28538 L
.62685 .28926 L
.61203 .29371 L
.59751 .29792 L
.58328 .3018 L
.56931 .30524 L
.55557 .30818 L
.54202 .31057 L
.52862 .31239 L
.51533 .31362 L
.5021 .31425 L
.48604 .31424 L
.46993 .3134 L
.45372 .31179 L
.43735 .30951 L
.42074 .30667 L
.40388 .30341 L
.38672 .29995 L
.36926 .29649 L
.35152 .29334 L
.33347 .29083 L
.31524 .28935 L
.29695 .28937 L
.27874 .29136 L
.26081 .29583 L
.24658 .30164 L
.23284 .30965 L
.21975 .32007 L
.20749 .33301 L
.19623 .34853 L
.18615 .36659 L
.17744 .38701 L
.1713 .40573 L
.16631 .4257 L
.16318 .44244 L
.16086 .45964 L
.15935 .47712 L
.15869 .49471 L
.15885 .51221 L
.15984 .52944 L
.16164 .54621 L
.16422 .56236 L
.16591 .57069 L
.16781 .57878 L
.16991 .58661 L
.17221 .59415 L
.1747 .60139 L
.17737 .60832 L
.1802 .61493 L
Mistroke
.1845 .6237 L
.1891 .63177 L
.19398 .63913 L
.19911 .64577 L
.20447 .65169 L
.21003 .65689 L
.21576 .66139 L
.22514 .66712 L
.2348 .67121 L
.24465 .67376 L
.25461 .6749 L
.26459 .67477 L
.27453 .67349 L
.28437 .67119 L
.29405 .66802 L
.30353 .66408 L
.31277 .65949 L
.32172 .65435 L
.3323 .64742 L
.34237 .63995 L
.3519 .63206 L
.36086 .62386 L
.36925 .61541 L
.37703 .60679 L
.38421 .59804 L
.39077 .5892 L
.3967 .58029 L
.40202 .57133 L
.4067 .56233 L
.41132 .55188 L
.41509 .54138 L
.41801 .5308 L
.42007 .52015 L
.42127 .50941 L
.42159 .49855 L
.42103 .48757 L
.41958 .47645 L
.41551 .45885 L
.40921 .44088 L
.40062 .42254 L
.3897 .40391 L
.37643 .38517 L
.36437 .37056 L
.35087 .35628 L
.35085 .35626 L
.35083 .35624 L
.35081 .35622 L
.35078 .3562 L
.35076 .35617 L
.35072 .35613 L
Mistroke
.35068 .35609 L
.35063 .35605 L
.3502 .35562 L
.34977 .3552 L
.34933 .35477 L
.34889 .35435 L
.34474 .35041 L
.34048 .34654 L
.33612 .34274 L
.33164 .33902 L
.32707 .33539 L
.3202 .33029 L
.31313 .32545 L
.30586 .32092 L
.29842 .31675 L
.29081 .31298 L
.28306 .30968 L
.27518 .30689 L
.2672 .30469 L
.25914 .30312 L
.25021 .30222 L
.24126 .30225 L
.23234 .30332 L
.22349 .30549 L
.21476 .30884 L
.20621 .31344 L
.1979 .31936 L
.18989 .32662 L
.18224 .33526 L
.17501 .34529 L
.16826 .35667 L
.16206 .36939 L
.15647 .38336 L
.15099 .40034 L
.14641 .41861 L
.14396 .43101 L
.14191 .44379 L
.14029 .4569 L
.1391 .47026 L
.13835 .4838 L
.13805 .49744 L
.13819 .5111 L
.13877 .52471 L
.1398 .5382 L
.14126 .55147 L
.14421 .5706 L
.14807 .58891 L
.15279 .60622 L
.15832 .62237 L
.16459 .63724 L
Mistroke
.17155 .65074 L
.17913 .66281 L
.18726 .67343 L
.19587 .68261 L
.20488 .69038 L
.21424 .69679 L
.22531 .70257 L
.23666 .70681 L
.2482 .70965 L
.25986 .71126 L
.27159 .7118 L
.28332 .71144 L
.295 .71033 L
.30661 .70864 L
.31811 .70649 L
.32948 .70401 L
.34071 .70132 L
.3557 .69752 L
.3704 .69372 L
.38482 .69012 L
.39898 .68685 L
.41291 .68403 L
.42665 .68175 L
.44024 .68007 L
.45373 .67903 L
.46717 .67868 L
.4806 .67901 L
.49409 .68005 L
.51042 .6822 L
.52699 .68531 L
.54389 .68931 L
.56118 .6941 L
.57893 .69955 L
.5972 .70548 L
.61601 .71163 L
.63187 .71663 L
.64809 .72136 L
.66465 .72557 L
.68148 .72894 L
.69853 .73115 L
.71568 .7318 L
.73281 .7305 L
.74977 .72683 L
.76335 .72177 L
.77657 .71464 L
.78929 .70525 L
.80137 .69348 L
.81267 .67925 L
.82303 .66254 L
.8323 .64342 L
Mistroke
.84035 .62207 L
.84704 .59873 L
.85132 .57895 L
.85463 .55833 L
.85694 .53711 L
.8582 .51553 L
.85843 .49386 L
.85762 .47237 L
.85577 .45131 L
.85293 .43094 L
.85108 .42071 L
.84897 .41076 L
.84662 .40111 L
.84403 .39178 L
.84121 .3828 L
.83817 .37419 L
.83491 .36596 L
.83016 .35538 L
.82505 .34556 L
.81962 .33654 L
.8139 .3283 L
.80791 .32087 L
.80168 .31423 L
.79523 .30836 L
.78479 .3007 L
.77398 .2948 L
.7629 .29054 L
.75163 .28778 L
.74025 .28635 L
.72883 .28612 L
.71742 .28693 L
.70608 .28862 L
.69485 .29105 L
.68377 .2941 L
.67287 .29763 L
.65992 .30242 L
.64729 .30759 L
.63501 .313 L
.62309 .31853 L
.61152 .32409 L
.60031 .32958 L
.58945 .33494 L
.57893 .34013 L
.56875 .34511 L
.55887 .34985 L
.5493 .35433 L
.53836 .35928 L
.52779 .36385 L
.51755 .36803 L
.50761 .37185 L
Mistroke
.49796 .37529 L
.48855 .37838 L
.47937 .38113 L
.47038 .38356 L
.45842 .38635 L
.44672 .38861 L
.43524 .39037 L
.42741 .39131 L
.41964 .39204 L
Mfstroke
.02 w
.5675 .66 Mdot
.5 Mabswid
.42741 .39131 m
.41964 .39204 L
s
% Start of user PostScript
-0.29036545 -0.43475513 -0.32143394 -0.43182925 MAarrowhead1
% End of user PostScript
1 .278 0 r
.67 .835 m
.67004 .83501 L
.67009 .83503 L
.67089 .83531 L
.6717 .83559 L
.67251 .83586 L
.67488 .83667 L
.67726 .83747 L
.67964 .83826 L
.68202 .83903 L
.68681 .84056 L
.69162 .84203 L
.69645 .84345 L
.70131 .8448 L
.70618 .84609 L
.71555 .84833 L
.72497 .85025 L
.73445 .85178 L
.74395 .85288 L
.75349 .85349 L
.76303 .85355 L
.77542 .8527 L
.78776 .85069 L
.80001 .84737 L
.81211 .84262 L
.82403 .83632 L
.83569 .82834 L
.84704 .81859 L
.85802 .80698 L
.86856 .79343 L
.87859 .77793 L
.88804 .76045 L
.89684 .74101 L
.90492 .71969 L
.91237 .69608 L
.91894 .67074 L
.92457 .64386 L
.92922 .61564 L
.93283 .58635 L
.93539 .55626 L
.93685 .52568 L
.93722 .49491 L
.93649 .46428 L
.93467 .4341 L
.93178 .40467 L
.93032 .39307 L
.92869 .38165 L
.9269 .37044 L
.92495 .35944 L
.92284 .34868 L
Mistroke
.92058 .33817 L
.91816 .32792 L
.91307 .30882 L
.90746 .29083 L
.90136 .27399 L
.8948 .25836 L
.88782 .24397 L
.88046 .23082 L
.87274 .21893 L
.86597 .20984 L
.859 .20163 L
.85184 .19427 L
.84451 .18774 L
.83704 .18201 L
.82944 .17706 L
.82174 .17284 L
.80996 .1678 L
.79802 .16422 L
.78599 .16195 L
.77389 .16086 L
.76177 .1608 L
.74967 .16164 L
.73761 .16324 L
.72562 .16547 L
.71002 .16916 L
.69461 .17347 L
.67942 .17819 L
.66445 .18312 L
.64972 .18807 L
.63521 .1929 L
.62093 .19748 L
.60685 .2017 L
.58906 .20643 L
.57154 .21028 L
.55422 .21311 L
.53703 .21486 L
.51992 .21547 L
.5028 .21492 L
.48562 .21321 L
.46831 .21038 L
.45079 .20648 L
.42978 .20061 L
.40832 .19356 L
.38633 .1856 L
.36375 .17708 L
.34056 .16846 L
.31677 .1603 L
.29243 .15331 L
.26767 .1483 L
.24265 .14623 L
Mistroke
.21762 .14814 L
.19819 .15313 L
.17914 .16177 L
.16331 .17241 L
.14806 .18633 L
.13355 .20373 L
.11995 .22472 L
.10744 .24933 L
.09618 .27747 L
.08634 .30894 L
.07807 .34339 L
.07442 .36239 L
.07126 .38199 L
.06858 .40212 L
.06641 .42269 L
.06476 .4436 L
.06362 .46475 L
.06301 .48604 L
.06296 .51054 L
.06361 .53492 L
.06495 .55902 L
.06697 .58269 L
.06965 .60577 L
.07299 .62814 L
.07694 .64967 L
.0815 .67024 L
.08847 .69606 L
.09638 .71982 L
.10516 .74139 L
.11471 .7607 L
.12495 .77771 L
.1358 .79242 L
.14716 .8049 L
.15895 .81524 L
.1711 .82354 L
.18578 .83091 L
.20073 .8359 L
.21586 .83879 L
.23108 .83986 L
.24631 .83939 L
.26149 .83765 L
.27656 .83489 L
.2915 .83135 L
.30626 .82726 L
.32083 .8228 L
.33925 .81682 L
.35732 .81086 L
.37505 .80517 L
.39247 .79998 L
.40961 .79546 L
Mistroke
.42651 .79175 L
.44322 .78896 L
.4598 .78715 L
.47631 .78638 L
.4928 .78668 L
.50934 .78804 L
.52599 .79045 L
.54281 .79386 L
.56413 .79943 L
.58589 .80628 L
.60819 .81415 L
.63107 .82268 L
.65458 .83144 L
.67872 .83983 L
.70342 .84717 L
.72858 .8526 L
.75404 .85514 L
.77955 .85371 L
.79929 .8491 L
.81867 .84081 L
.8349 .83035 L
.85055 .81651 L
.86274 .80258 L
.87434 .78619 L
.88525 .7673 L
.89536 .74592 L
.90458 .72212 L
.91282 .69603 L
.91999 .66784 L
.92601 .6378 L
.93082 .6062 L
.93436 .57341 L
.93659 .5398 L
.93749 .5058 L
.93705 .47182 L
.93528 .43829 L
.9322 .40563 L
.92786 .37421 L
.92232 .34438 L
.91757 .32388 L
.91225 .30446 L
.9064 .28622 L
.90004 .26919 L
.89321 .25344 L
.88595 .23899 L
.8783 .22584 L
.87028 .214 L
.85788 .19888 L
.84489 .18646 L
.83143 .17662 L
Mistroke
.81761 .16915 L
.80352 .16386 L
.78925 .16051 L
.77487 .15887 L
.76046 .15871 L
.74607 .15978 L
.73174 .16188 L
.71752 .16478 L
.70196 .1687 L
.68659 .17313 L
.67143 .17787 L
.6565 .18271 L
.64179 .18751 L
.62731 .19212 L
.61303 .19642 L
.59895 .2003 L
.58126 .20453 L
.5638 .20783 L
.5465 .2101 L
.5293 .21127 L
.51215 .21131 L
.49496 .21021 L
.47767 .20799 L
.46021 .20467 L
.44253 .20033 L
.42107 .19396 L
.39913 .18651 L
.37662 .17828 L
.35351 .16968 L
.3298 .16123 L
.30551 .15356 L
.28073 .14744 L
.2556 .14377 L
.23032 .14357 L
.20982 .14674 L
.1896 .15353 L
.16989 .16454 L
.15096 .18027 L
.13308 .20113 L
.11655 .22736 L
.1017 .25898 L
.09577 .27455 L
.09025 .2911 L
.08516 .30856 L
.08053 .32689 L
.07637 .34601 L
.07271 .36585 L
.06956 .38633 L
.06694 .40734 L
.06531 .42349 L
Mistroke
.064 .43985 L
.06301 .45636 L
.06233 .47297 L
.06197 .48965 L
.06193 .50633 L
.06221 .52296 L
.06342 .55092 L
.06552 .57838 L
.0685 .60511 L
.07234 .6309 L
.077 .65557 L
.08244 .67896 L
.08861 .70092 L
.09548 .72135 L
.10633 .7476 L
.11832 .77044 L
.13128 .78984 L
.14271 .80341 L
.15461 .81472 L
.16691 .82388 L
.17952 .83102 L
.19237 .83632 L
.2054 .83994 L
.21853 .84205 L
.23172 .84285 L
.24491 .8425 L
.26636 .83994 L
.28395 .83638 L
.30134 .8319 L
.31848 .82685 L
.33535 .82149 L
.35193 .81609 L
.36824 .81086 L
.38428 .80597 L
.40008 .80156 L
.41567 .79776 L
.43586 .79385 L
.45582 .7913 L
.47566 .79021 L
.49548 .79062 L
.51537 .79254 L
.53545 .79593 L
.5558 .80069 L
.57653 .8067 L
.5977 .81374 L
.62014 .82184 L
.64317 .83037 L
.6668 .83883 L
.69101 .84662 L
.71572 .85298 L
Mistroke
.74081 .85703 L
.76607 .85778 L
.78691 .85514 L
.8075 .84886 L
.8276 .83834 L
.84694 .82302 L
.86524 .80248 L
.88218 .77642 L
.89743 .74482 L
.90347 .72936 L
.9091 .71291 L
.91429 .69553 L
.91904 .67727 L
.92331 .65819 L
.92708 .63837 L
.93034 .61789 L
.93308 .59686 L
.9348 .58054 L
.93619 .56401 L
.93727 .5473 L
.93803 .53048 L
.93845 .51358 L
.93855 .49667 L
.93832 .4798 L
.93723 .45212 L
.93526 .42491 L
.93244 .39838 L
.92877 .37273 L
.9243 .34815 L
.91907 .32479 L
.91311 .3028 L
.90646 .28229 L
.89581 .25552 L
.88399 .23214 L
.87118 .2122 L
.85753 .19565 L
.84319 .18235 L
.82831 .17211 L
.81302 .16467 L
.79745 .15975 L
.7817 .15704 L
.76299 .15626 L
.74429 .15764 L
.72571 .16067 L
.70733 .16493 L
.68921 .17 L
.67138 .17554 L
.65386 .18123 L
.63665 .18682 L
.61973 .19209 L
Mistroke
.60036 .19758 L
.58132 .20218 L
.56254 .20571 L
.54394 .20805 L
.52545 .20912 L
.50699 .20889 L
.48847 .20735 L
.46981 .20453 L
.45094 .20048 L
.4294 .19461 L
.4074 .18753 L
.38486 .17954 L
.36172 .171 L
.33798 .16241 L
.31364 .15437 L
.28876 .14762 L
.26348 .14305 L
.23798 .14166 L
.21253 .14455 L
.21252 .14455 L
.21252 .14455 L
.21251 .14455 L
.21251 .14456 L
.21251 .14456 L
.2125 .14456 L
.21249 .14456 L
.21248 .14456 L
.2124 .14458 L
.21233 .1446 L
.21225 .14461 L
.21217 .14463 L
.21138 .1448 L
.2106 .14498 L
.20981 .14517 L
.20902 .14535 L
.20824 .14555 L
.20042 .1478 L
.19265 .15063 L
.18496 .15407 L
.17734 .15815 L
.16983 .1629 L
.16242 .16835 L
.15214 .17734 L
.14217 .18784 L
.13255 .19992 L
.12333 .21361 L
.11457 .22891 L
.10632 .24581 L
.09862 .2643 L
.09031 .28806 L
Mistroke
.08293 .31381 L
.07653 .34137 L
.07119 .37049 L
.06695 .40093 L
.06386 .43235 L
.06194 .46444 L
.06122 .49684 L
.06171 .52918 L
.06338 .5611 L
.06623 .59226 L
.07021 .62232 L
.07528 .651 L
.08138 .67804 L
.08845 .70321 L
.09642 .72637 L
.10521 .74738 L
.11615 .76869 L
.12793 .78709 L
.14043 .8026 L
.15353 .81534 L
.16711 .82545 L
.18107 .83312 L
.1953 .83856 L
.20972 .84201 L
.22425 .84371 L
.24469 .8436 L
.26506 .84118 L
.28522 .83704 L
.30511 .83175 L
.32465 .82577 L
.34383 .81954 L
.36264 .81339 L
.3811 .80761 L
.39923 .80244 L
.42017 .79738 L
.44081 .79363 L
.46124 .79134 L
.48155 .79061 L
.50188 .79146 L
.52231 .79389 L
.54297 .79784 L
.56396 .8032 L
.58536 .80978 L
.60724 .81734 L
.62967 .82556 L
.65268 .83402 L
.67627 .8422 L
.70041 .84944 L
.725 .85499 L
.74989 .85794 L
Mistroke
.77487 .8573 L
.79497 .85342 L
.81475 .84591 L
.83399 .83424 L
.85244 .81793 L
.86983 .79662 L
.88587 .77013 L
.90027 .73845 L
.90674 .72079 L
.91269 .70196 L
.9181 .68203 L
.92293 .66106 L
.92716 .63918 L
.93077 .6165 L
.93372 .59313 L
.93601 .56922 L
.9379 .53905 L
.93873 .50857 L
.9385 .47808 L
.9372 .4479 L
.93486 .41831 L
.93151 .38959 L
.92717 .362 L
.92188 .33577 L
.91571 .3111 L
.90871 .28814 L
.90094 .26702 L
.88967 .24221 L
.87735 .2208 L
.86412 .2028 L
.85014 .18809 L
.83556 .17652 L
.82052 .16785 L
.80514 .16182 L
.78954 .15813 L
.77382 .15647 L
.75319 .15687 L
.73266 .15956 L
.71235 .16393 L
.69233 .16942 L
.67267 .17553 L
.65338 .18186 L
.63447 .18805 L
.61592 .19382 L
.59769 .19894 L
.57689 .20383 L
.55638 .2074 L
.53607 .20949 L
.51585 .21003 L
.49561 .20899 L
Mistroke
.47525 .20638 L
.45465 .20228 L
.43371 .19679 L
.41235 .1901 L
.39023 .18237 L
.36753 .17401 L
.34424 .16546 L
.32035 .15727 L
.29592 .15014 L
.27104 .14486 L
.24588 .1424 L
.22069 .14377 L
.20088 .14832 L
.18144 .15653 L
.16531 .16678 L
.14976 .18034 L
.13493 .1974 L
.121 .21813 L
.10814 .24255 L
.09654 .2706 L
.08635 .30208 L
.07774 .33667 L
.07205 .36642 L
.06753 .39761 L
.06423 .42988 L
.06218 .46289 L
.06139 .49625 L
.06189 .52955 L
.06365 .56241 L
.06665 .59443 L
.06906 .61324 L
.07189 .63154 L
.07514 .64926 L
.07879 .66635 L
.08283 .68275 L
.08724 .69842 L
.092 .71331 L
.0971 .72738 L
.10252 .74063 L
.10823 .75302 L
.11683 .76917 L
.12593 .78356 L
.13548 .7962 L
.14542 .80715 L
.15569 .81645 L
.16624 .82418 L
.17702 .83043 L
.18798 .83531 L
.19908 .8389 L
.21028 .84134 L
Mistroke
.22286 .84282 L
.23547 .84316 L
.24808 .8425 L
.26064 .841 L
.27314 .8388 L
.28555 .83603 L
.29784 .83283 L
.31273 .82848 L
.32741 .82385 L
.34189 .81909 L
.35614 .81438 L
.37019 .80982 L
.38404 .80554 L
.39771 .80162 L
.41121 .79815 L
.42778 .79455 L
.44418 .79184 L
.46045 .79006 L
.47665 .78929 L
.49283 .78952 L
.50906 .79078 L
.52539 .79304 L
.54187 .79626 L
.55855 .80038 L
.58025 .80683 L
.60245 .81438 L
.62522 .8227 L
.6486 .83137 L
.6726 .83985 L
.69718 .84747 L
.72225 .85343 L
.74766 .85678 L
.77318 .85647 L
.79348 .85282 L
.81346 .84551 L
.83012 .83595 L
.84623 .823 L
.85899 .80958 L
.87116 .79358 L
.88263 .77493 L
.8933 .75365 L
.90305 .72977 L
.9118 .70344 L
.91943 .67483 L
.92587 .6442 L
.92949 .62262 L
.93251 .60039 L
.93492 .57762 L
.93672 .55443 L
.93787 .53097 L
Mistroke
.93839 .50738 L
.93827 .48378 L
.93752 .46034 L
.93613 .43718 L
.93411 .41443 L
.93042 .38453 L
.92565 .35591 L
.91986 .32885 L
.9131 .30355 L
.90545 .28019 L
.89698 .2589 L
.88777 .23975 L
.8779 .22278 L
.86744 .20798 L
.85648 .19531 L
.84509 .1847 L
.83277 .17567 L
.82015 .16865 L
.80729 .16347 L
.79426 .15997 L
.78113 .15797 L
.76795 .15728 L
.75476 .15773 L
.74161 .15913 L
.72674 .16168 L
.71199 .16503 L
.69741 .16896 L
.68301 .17329 L
.6688 .17785 L
.6548 .18247 L
.64099 .18703 L
.62739 .19141 L
.60941 .19685 L
.59173 .2016 L
.57431 .20551 L
.55709 .20846 L
.54001 .21036 L
.52301 .21118 L
.50603 .21087 L
.48899 .20945 L
.47184 .20692 L
.45081 .20245 L
.42942 .19658 L
.40756 .18951 L
.38516 .18151 L
.36217 .17297 L
.33857 .16435 L
.31437 .15627 L
.28963 .14944 L
.26447 .14475 L
Mistroke
.23909 .14317 L
.21374 .14581 L
.19433 .15147 L
.17534 .16086 L
.16123 .17085 L
.14759 .18347 L
.13454 .19887 L
.12221 .21713 L
.1107 .2383 L
.10015 .26232 L
.09068 .28909 L
.08238 .31841 L
.07709 .3415 L
.07254 .36569 L
.06875 .39083 L
.06575 .41674 L
.06357 .44324 L
.06223 .47011 L
.06172 .49716 L
.06205 .52417 L
.06342 .55427 L
.06584 .58376 L
.06928 .61235 L
.0737 .63979 L
.07906 .66586 L
.08531 .69035 L
.09238 .71312 L
.10022 .73403 L
.10875 .75302 L
.11792 .77004 L
.12765 .78507 L
.13907 .79952 L
.151 .81161 L
.16336 .82145 L
.17607 .82918 L
.18904 .83496 L
.2022 .83897 L
.21548 .84139 L
.22883 .84242 L
.24219 .84223 L
.25553 .84102 L
.26881 .83896 L
.28401 .83573 L
.29905 .83183 L
.3139 .82746 L
.32855 .82282 L
.34299 .81807 L
.35721 .81337 L
.37123 .80884 L
.38505 .80459 L
Mistroke
.40308 .79955 L
.42083 .79534 L
.43836 .79208 L
.45572 .78987 L
.47299 .78878 L
.49022 .78883 L
.50749 .79005 L
.52487 .7924 L
.54243 .79585 L
.56377 .80132 L
.58556 .80808 L
.60786 .81586 L
.63075 .82432 L
.65426 .833 L
.67838 .84135 L
.70306 .84866 L
.72821 .85409 L
.75364 .85668 L
.77913 .85535 L
.79896 .85081 L
.81844 .8426 L
.8347 .83224 L
.85038 .81851 L
.86278 .80447 L
.87458 .7879 L
.88566 .76875 L
.89593 .74705 L
.90529 .72286 L
.91363 .69631 L
.92088 .66762 L
.92694 .63702 L
.93176 .60485 L
.93527 .57146 L
.93744 .53727 L
.93823 .5027 L
.93765 .4682 L
.93571 .43421 L
.93243 .40116 L
.92786 .36943 L
.92206 .33939 L
.91511 .31133 L
.90708 .28548 L
.89807 .26201 L
.88659 .23808 L
.87409 .21753 L
.86073 .20035 L
.84666 .18641 L
.83201 .17555 L
.81694 .16751 L
.80156 .16204 L
Mistroke
.78597 .15883 L
.77029 .15758 L
.74971 .1584 L
.72925 .1614 L
.70903 .16598 L
.68911 .17159 L
.66954 .17776 L
.65036 .18408 L
.63155 .19021 L
.61309 .19588 L
.59496 .20087 L
.57428 .20557 L
.55388 .20893 L
.53366 .21082 L
.51353 .21115 L
.49336 .20991 L
.47304 .20711 L
.45249 .20283 L
.43158 .19719 L
.41024 .19038 L
.38789 .18247 L
.36496 .17396 L
.34141 .16531 L
.31726 .15713 L
.29256 .15011 L
.26743 .14512 L
.24204 .14313 L
.21665 .14523 L
.19713 .15042 L
.178 .15928 L
.16198 .17025 L
.14656 .18457 L
.13454 .1989 L
.12312 .21568 L
.1124 .23494 L
.10248 .25664 L
.09345 .28071 L
.08541 .30703 L
.07843 .33538 L
.07259 .36553 L
.06796 .39717 L
.06459 .42995 L
.06251 .46349 L
.06174 .50171 L
.06266 .53978 L
.06464 .57032 L
.06769 .60005 L
.0718 .62869 L
.07691 .65598 L
.08298 .68169 L
Mistroke
.08993 .70565 L
.09771 .7277 L
.10625 .74776 L
.11547 .76576 L
.1253 .78168 L
.13566 .79553 L
.14648 .80737 L
.15988 .81896 L
.17372 .82796 L
.18789 .83459 L
.2023 .83907 L
.21686 .84165 L
.2315 .84258 L
.24614 .8421 L
.26074 .84044 L
.27524 .83785 L
.28962 .83452 L
.30384 .83065 L
.32096 .82546 L
.3378 .82002 L
.35435 .81456 L
.37063 .8093 L
.38664 .8044 L
.4024 .80003 L
.41795 .79627 L
.43333 .79324 L
.44857 .79099 L
.46371 .78957 L
.4788 .78902 L
.49664 .78951 L
.51454 .79124 L
.53259 .79416 L
.55085 .79822 L
.56939 .80333 L
.58828 .80935 L
.60757 .8161 L
.62729 .82336 L
.64746 .83085 L
.6681 .83822 L
.68917 .84505 L
.71064 .85085 L
.73242 .85504 L
.75439 .85699 L
.77639 .85599 L
.79823 .85131 L
.81535 .84445 L
.83205 .83444 L
.84656 .82251 L
.86048 .80759 L
.87064 .79411 L
Mistroke
.8803 .77879 L
.88942 .76162 L
.89792 .74261 L
.90576 .72183 L
.91287 .69937 L
.91919 .67534 L
.92468 .64989 L
.92929 .6232 L
.93298 .59549 L
.93572 .56699 L
.93749 .53794 L
.93827 .50862 L
.93819 .48519 L
.93748 .46188 L
.93614 .43885 L
.93418 .41622 L
.93163 .39413 L
.92849 .37268 L
.92478 .35198 L
.91979 .32905 L
.9141 .3074 L
.90776 .28713 L
.90081 .26833 L
.8933 .25107 L
.88527 .23537 L
.87678 .22125 L
.86787 .20869 L
.85859 .19769 L
.84899 .18818 L
.83911 .18012 L
.82689 .17221 L
.81441 .16616 L
.80173 .16181 L
.78892 .15899 L
.77603 .15754 L
.76311 .15728 L
.75019 .15804 L
.73733 .15968 L
.72227 .1625 L
.70736 .16608 L
.69262 .17019 L
.67807 .17466 L
.66373 .17929 L
.64959 .18395 L
.63565 .1885 L
.62191 .19283 L
.60371 .19813 L
.5858 .20267 L
.56813 .2063 L
.55065 .2089 L
Mistroke
.53329 .21039 L
.51599 .21075 L
.49867 .20994 L
.48127 .20798 L
.46373 .2049 L
.44296 .19997 L
.42181 .19376 L
.40018 .18648 L
.37802 .17843 L
.35528 .16998 L
.33195 .16163 L
.30805 .15396 L
.28367 .14771 L
.25892 .14373 L
.23401 .14297 L
.20918 .14648 L
.20917 .14648 L
.20917 .14648 L
.20917 .14648 L
.20916 .14648 L
.20916 .14649 L
.20915 .14649 L
.20914 .14649 L
.20913 .14649 L
.20906 .14651 L
.20898 .14653 L
.2089 .14655 L
.20882 .14657 L
.20804 .14676 L
.20726 .14696 L
.20648 .14717 L
.20569 .14738 L
.20491 .1476 L
.19714 .15009 L
.18942 .15316 L
.18178 .15686 L
.17423 .16121 L
.16678 .16624 L
.15945 .17198 L
.14944 .18123 L
.13973 .19198 L
.13038 .20425 L
.12143 .21808 L
.11293 .23347 L
.10494 .25042 L
.09749 .26888 L
.08949 .29247 L
.08238 .31796 L
.07624 .34515 L
.07111 .37383 L
Mistroke
.06705 .40374 L
.0641 .43458 L
.06229 .46604 L
.06163 .49777 L
.06212 .52945 L
.06377 .56071 L
.06654 .59124 L
.07041 .62073 L
.07533 .6489 L
.08125 .67549 L
.0881 .70032 L
.09583 .7232 L
.10436 .74405 L
.11531 .76586 L
.12713 .78469 L
.1397 .80058 L
.15289 .81363 L
.16658 .82398 L
.18066 .83182 L
.19503 .83738 L
.20959 .84089 L
.22426 .84262 L
.24475 .8425 L
.26515 .84005 L
.28536 .83588 L
.30527 .83055 L
.32485 .82454 L
.34406 .81828 L
.36289 .8121 L
.38137 .8063 L
.39951 .80112 L
.42039 .79608 L
.44096 .79235 L
.46132 .79007 L
.48157 .78935 L
.50183 .79022 L
.52221 .79266 L
.54281 .79662 L
.56373 .80198 L
.58508 .80857 L
.60691 .81615 L
.62931 .82439 L
.65228 .83288 L
.67585 .84109 L
.69997 .84839 L
.72453 .85399 L
.74941 .85702 L
.77438 .85646 L
.79448 .85265 L
.81427 .84522 L
Mistroke
.83352 .83363 L
.85199 .8174 L
.86939 .79618 L
.88545 .76976 L
.89986 .73816 L
.90633 .72055 L
.91229 .70178 L
.9177 .68189 L
.92254 .66098 L
.92677 .63915 L
.93038 .61652 L
.93334 .5932 L
.93563 .56934 L
.93753 .53924 L
.93837 .50882 L
.93814 .47839 L
.93686 .44827 L
.93453 .41873 L
.93119 .39006 L
.92686 .36251 L
.92159 .33633 L
.91543 .31169 L
.90844 .28876 L
.90068 .26767 L
.88944 .24289 L
.87713 .22151 L
.86392 .20352 L
.84996 .18883 L
.8354 .17727 L
.82037 .1686 L
.80501 .16257 L
.78943 .15887 L
.77373 .15721 L
.75312 .1576 L
.73261 .16028 L
.71232 .16464 L
.69232 .17011 L
.67267 .17621 L
.6534 .18253 L
.63451 .1887 L
.61597 .19446 L
.59777 .19957 L
.57698 .20445 L
.55649 .208 L
.53619 .21008 L
.51599 .21061 L
.49577 .20956 L
.47542 .20695 L
.45484 .20283 L
.43392 .19734 L
Mistroke
.41257 .19064 L
.39048 .18291 L
.36781 .17454 L
.34454 .16597 L
.32068 .15777 L
.29627 .15061 L
.27141 .14531 L
.24628 .14279 L
.22109 .1441 L
.20128 .1486 L
.18182 .15674 L
.16569 .16694 L
.15012 .18044 L
.13528 .19745 L
.12133 .21811 L
.10846 .24248 L
.09684 .27048 L
.08663 .30191 L
.078 .33647 L
.0723 .3662 L
.06776 .39737 L
.06445 .42965 L
.06238 .46266 L
.06159 .49602 L
.06207 .52933 L
.06383 .56219 L
.06683 .59423 L
.0693 .61354 L
.07223 .63231 L
.07559 .65047 L
.07938 .66796 L
.08358 .68472 L
.08816 .70069 L
.09312 .71584 L
.09843 .73013 L
.10406 .74353 L
.11001 .75603 L
.11866 .77175 L
.1278 .78574 L
.13736 .79801 L
.14731 .8086 L
.15757 .81758 L
.1681 .82503 L
.17885 .83103 L
.18978 .83567 L
.20084 .83908 L
.21199 .84135 L
.22468 .84269 L
.2374 .84289 L
.25012 .8421 L
Mistroke
.26278 .84047 L
.27537 .83816 L
.28787 .83529 L
.30025 .83201 L
.31534 .82755 L
.33021 .82283 L
.34487 .81801 L
.35931 .81326 L
.37353 .80871 L
.38756 .80446 L
.40139 .80061 L
.41507 .79724 L
.43153 .79386 L
.44784 .79138 L
.46403 .78985 L
.48017 .78931 L
.4963 .78978 L
.51249 .79126 L
.52879 .79372 L
.54525 .79713 L
.56193 .80142 L
.5834 .80797 L
.60538 .81554 L
.62791 .82382 L
.65104 .83238 L
.67477 .84069 L
.69906 .84809 L
.72381 .85382 L
.74889 .85695 L
.77406 .85646 L
.79422 .85269 L
.81407 .84529 L
.83338 .8337 L
.85191 .81746 L
.86937 .7962 L
.88547 .76971 L
.89992 .73799 L
.90638 .72038 L
.91234 .7016 L
.91774 .68171 L
.92257 .66079 L
.9268 .63896 L
.9304 .61631 L
.93336 .59299 L
.93564 .56914 L
.93754 .53901 L
.93837 .50858 L
.93814 .47815 L
.93684 .44801 L
.93451 .41847 L
Mistroke
.93115 .3898 L
.92681 .36225 L
.92153 .33607 L
.91536 .31144 L
.90836 .28853 L
.90059 .26745 L
.88933 .24271 L
.87701 .22136 L
.8638 .20341 L
.84983 .18875 L
.83527 .17722 L
.82024 .16858 L
.80488 .16258 L
.7893 .15891 L
.77359 .15727 L
.75299 .15768 L
.73249 .16038 L
.7122 .16474 L
.69221 .17023 L
.67257 .17633 L
.65331 .18265 L
.63442 .18883 L
.6159 .19459 L
.5977 .1997 L
.57692 .20458 L
.55644 .20813 L
.53616 .21021 L
.51597 .21075 L
.49576 .2097 L
.47542 .20708 L
.45484 .20297 L
.43393 .19748 L
.4126 .19078 L
.3905 .18304 L
.36784 .17467 L
.34457 .1661 L
.32071 .1579 L
.2963 .15073 L
.27145 .14542 L
.24631 .14289 L
.22113 .1442 L
.20132 .14869 L
.18186 .15682 L
.16572 .16702 L
.15015 .18051 L
.13531 .19751 L
.12136 .21818 L
.10849 .24254 L
.09686 .27053 L
.08666 .30197 L
Mistroke
.07803 .33652 L
.07233 .36625 L
.06779 .39741 L
.06448 .42968 L
.06241 .46268 L
.06162 .49604 L
.06211 .52934 L
.06386 .5622 L
.06686 .59422 L
.06933 .61348 L
.07225 .63221 L
.0756 .65033 L
.07938 .66778 L
.08356 .6845 L
.08813 .70044 L
.09307 .71556 L
.09836 .72983 L
.10397 .74322 L
.1099 .7557 L
.11854 .77145 L
.12768 .78547 L
.13724 .79776 L
.14718 .80838 L
.15744 .81738 L
.16797 .82485 L
.17873 .83086 L
.18965 .83553 L
.20071 .83894 L
.21186 .84123 L
.22455 .84258 L
.23726 .84279 L
.24996 .84201 L
.26261 .84039 L
.27519 .83809 L
.28768 .83523 L
.30005 .83195 L
.31512 .8275 L
.32997 .82278 L
.34461 .81798 L
.35903 .81323 L
.37323 .80867 L
.38724 .80442 L
.40105 .80056 L
.41471 .79718 L
.43118 .79379 L
.44749 .79129 L
.46368 .78973 L
.47982 .78917 L
.49595 .78962 L
.51214 .79107 L
Mistroke
.52843 .79352 L
.54489 .79691 L
.56156 .80118 L
.58305 .80772 L
.60504 .8153 L
.6276 .82358 L
.65075 .83215 L
.67451 .84048 L
.69882 .84792 L
.72361 .85367 L
.74871 .85683 L
.77392 .85637 L
.7941 .85262 L
.81396 .84523 L
.83329 .83366 L
.85183 .81743 L
.8693 .79617 L
.88542 .76968 L
.89988 .73796 L
.90634 .72035 L
.91229 .70157 L
.9177 .68168 L
.92253 .66077 L
.92676 .63894 L
.93036 .61631 L
.93332 .59299 L
.9356 .56914 L
.9375 .53902 L
.93833 .50859 L
.9381 .47816 L
.93681 .44803 L
.93447 .41849 L
.93111 .38983 L
.92677 .36229 L
.92149 .33611 L
.91532 .31148 L
.90832 .28857 L
.90055 .2675 L
.88929 .24276 L
.87698 .22143 L
.86376 .20348 L
.8498 .18883 L
.83524 .1773 L
.82021 .16867 L
.80485 .16266 L
.78927 .15899 L
.77357 .15736 L
.75297 .15777 L
.73247 .16047 L
.71219 .16484 L
Mistroke
.6922 .17032 L
.67257 .17643 L
.65331 .18275 L
.63442 .18893 L
.6159 .19469 L
.59771 .1998 L
.57693 .20467 L
.55646 .20822 L
.53618 .21031 L
.51599 .21084 L
.49578 .20979 L
.47545 .20718 L
.45488 .20306 L
.43397 .19757 L
.41264 .19088 L
.39055 .18314 L
.36789 .17476 L
.34463 .16619 L
.32077 .15799 L
.29637 .15082 L
.27152 .1455 L
.24639 .14296 L
.2212 .14425 L
.20139 .14873 L
.18193 .15685 L
.16579 .16704 L
.15022 .18052 L
.13537 .19751 L
.12142 .21816 L
.10854 .24251 L
.09692 .2705 L
.08671 .30193 L
.07807 .33647 L
.07236 .3662 L
.06783 .39736 L
.06451 .42963 L
.06244 .46263 L
.06165 .49599 L
.06213 .52929 L
.06389 .56215 L
.06689 .59418 L
.06937 .61355 L
.07231 .63237 L
.07568 .65059 L
.07949 .66812 L
.08371 .68492 L
.08831 .70092 L
.09329 .7161 L
.09863 .73041 L
.10429 .74383 L
Mistroke
.11026 .75634 L
.11892 .772 L
.12806 .78593 L
.13763 .79814 L
.14757 .80869 L
.15783 .81763 L
.16836 .82503 L
.17911 .83099 L
.19003 .83561 L
.20108 .83898 L
.21222 .84123 L
.22492 .84255 L
.23766 .84273 L
.25038 .84192 L
.26306 .84027 L
.27566 .83794 L
.28816 .83506 L
.30055 .83177 L
.31566 .82729 L
.33056 .82255 L
.34524 .81773 L
.3597 .81297 L
.37395 .80841 L
.38799 .80416 L
.40185 .80032 L
.41554 .79696 L
.43199 .79361 L
.44827 .79116 L
.46445 .78965 L
.48057 .78914 L
.49669 .78964 L
.51287 .79114 L
.52916 .79363 L
.54561 .79706 L
.56228 .80136 L
.58372 .80792 L
.60566 .8155 L
.62817 .82377 L
.65126 .83232 L
.67496 .84062 L
.69921 .84801 L
.72393 .85372 L
.74896 .85683 L
.77409 .85633 L
.79424 .85256 L
.81407 .84516 L
.83337 .83358 L
.85188 .81735 L
.86933 .7961 L
.88542 .76963 L
Mistroke
.89986 .73795 L
.90633 .72035 L
.91228 .70157 L
.91769 .68168 L
.92252 .66078 L
.92675 .63895 L
.93035 .61632 L
.9333 .59301 L
.93559 .56916 L
.93748 .53904 L
.93832 .50862 L
.93809 .4782 L
.9368 .44807 L
.93446 .41854 L
.93111 .38988 L
.92677 .36234 L
.92149 .33616 L
.91533 .31154 L
.90833 .28863 L
.90056 .26755 L
.8893 .24281 L
.87699 .22147 L
.86378 .20352 L
.84982 .18886 L
.83526 .17732 L
.82023 .16869 L
.80487 .16268 L
.78929 .15901 L
.77359 .15736 L
.75299 .15777 L
.73249 .16047 L
.71221 .16483 L
.69222 .17031 L
.67258 .17642 L
.65332 .18273 L
.63444 .18891 L
.61591 .19467 L
.59772 .19978 L
.57694 .20465 L
.55646 .2082 L
.53618 .21028 L
.51599 .21082 L
.49578 .20977 L
.47544 .20715 L
.45487 .20303 L
.43396 .19754 L
.41263 .19084 L
.39054 .1831 L
.36787 .17473 L
.34461 .16616 L
Mistroke
.32075 .15796 L
.29635 .15079 L
.2715 .14547 L
.24636 .14294 L
.22118 .14424 L
.20137 .14872 L
.18191 .15685 L
.16577 .16703 L
.1502 .18052 L
.13535 .19751 L
.1214 .21817 L
.10853 .24252 L
.0969 .27051 L
.08669 .30194 L
.07806 .33649 L
.07236 .36622 L
.06782 .39738 L
.0645 .42965 L
.06244 .46265 L
.06164 .496 L
.06213 .52931 L
.06388 .56217 L
.06688 .59419 L
.06936 .61353 L
.07229 .63232 L
.07566 .65051 L
.07946 .66802 L
.08367 .68479 L
.08826 .70078 L
.09323 .71594 L
.09855 .73024 L
.1042 .74364 L
.11016 .75615 L
.11881 .77184 L
.12795 .78579 L
.13752 .79803 L
.14746 .8086 L
.15772 .81756 L
.16825 .82498 L
.179 .83096 L
.18992 .83559 L
.20097 .83898 L
.21212 .84124 L
.22482 .84257 L
.23754 .84276 L
.25026 .84196 L
.26293 .84032 L
.27553 .838 L
.28803 .83513 L
.30041 .83184 L
Mistroke
.31551 .82737 L
.33039 .82264 L
.34506 .81782 L
.35951 .81307 L
.37374 .80851 L
.38777 .80427 L
.40162 .80042 L
.4153 .79706 L
.43176 .7937 L
.44806 .79123 L
.46424 .78971 L
.48037 .78919 L
.49649 .78967 L
.51268 .79116 L
.52897 .79364 L
.54542 .79706 L
.5621 .80136 L
.58355 .80791 L
.60551 .81549 L
.62803 .82377 L
.65114 .83232 L
.67486 .84063 L
.69913 .84803 L
.72386 .85374 L
.74891 .85686 L
.77407 .85637 L
.79422 .8526 L
.81406 .8452 L
.83337 .83362 L
.85189 .81738 L
.86934 .79613 L
.88544 .76965 L
.89988 .73795 L
.90635 .72035 L
.9123 .70157 L
.9177 .68168 L
.92254 .66077 L
.92676 .63894 L
.93036 .6163 L
.93332 .59299 L
.9356 .56913 L
.9375 .53902 L
.93833 .50859 L
.9381 .47817 L
.93681 .44804 L
.93447 .4185 L
.93111 .38983 L
.92678 .3623 L
.9215 .33612 L
.91533 .31149 L
Mistroke
.90833 .28858 L
.90056 .26751 L
.8893 .24277 L
.87699 .22143 L
.86377 .20347 L
.84981 .18882 L
.83525 .17728 L
.82022 .16865 L
.80486 .16264 L
.78928 .15897 L
.77358 .15733 L
.75298 .15774 L
.73248 .16043 L
.71219 .1648 L
.6922 .17028 L
.67256 .17638 L
.6533 .1827 L
.63442 .18888 L
.61589 .19464 L
.59769 .19974 L
.57692 .20461 L
.55644 .20816 L
.53615 .21024 L
.51596 .21077 L
.49575 .20972 L
.47541 .2071 L
.45483 .20298 L
.43392 .19749 L
.41259 .19079 L
.39049 .18305 L
.36782 .17468 L
.34456 .16611 L
.3207 .1579 L
.29629 .15074 L
.27143 .14543 L
.24629 .14291 L
.22111 .14421 L
.2013 .14871 L
.18184 .15685 L
.16571 .16705 L
.15014 .18054 L
.1353 .19755 L
.12135 .21822 L
.10848 .24258 L
.09686 .27058 L
.08666 .30202 L
.07803 .33657 L
.07233 .3663 L
.0678 .39746 L
.06448 .42973 L
Mistroke
.06242 .46273 L
.06163 .49607 L
.06212 .52937 L
.06388 .56222 L
.06688 .59424 L
.06933 .61343 L
.07224 .63209 L
.07558 .65015 L
.07934 .66754 L
.0835 .68421 L
.08804 .70011 L
.09295 .71519 L
.09821 .72943 L
.1038 .74279 L
.10969 .75526 L
.11833 .77107 L
.12746 .78513 L
.13702 .79748 L
.14696 .80815 L
.15722 .81719 L
.16775 .8247 L
.17851 .83075 L
.18944 .83544 L
.2005 .83889 L
.21166 .84119 L
.22433 .84257 L
.23702 .8428 L
.24971 .84204 L
.26235 .84044 L
.27492 .83815 L
.28739 .83531 L
.29975 .83205 L
.31479 .82762 L
.32962 .82292 L
.34423 .81812 L
.35862 .81339 L
.37281 .80883 L
.38679 .80458 L
.40058 .80072 L
.41421 .79733 L
.4307 .79391 L
.44703 .79138 L
.46323 .7898 L
.47938 .78922 L
.49553 .78964 L
.51172 .79107 L
.52802 .79349 L
.54449 .79686 L
.56117 .80112 L
.58269 .80765 L
Mistroke
.60471 .81522 L
.6273 .82351 L
.65049 .8321 L
.67428 .84045 L
.69863 .84791 L
.72346 .85369 L
.7486 .85686 L
.77386 .85641 L
.79405 .85267 L
.81392 .84529 L
.83326 .83372 L
.85182 .81748 L
.8693 .7962 L
.88543 .76969 L
.8999 .73794 L
.90636 .72033 L
.91231 .70155 L
.91772 .68165 L
.92255 .66074 L
.92678 .6389 L
.93038 .61626 L
.93333 .59294 L
.93562 .56909 L
.93751 .53896 L
.93834 .50853 L
.9381 .47809 L
.93681 .44796 L
.93447 .41841 L
.93111 .38975 L
.92677 .36221 L
.92148 .33603 L
.91531 .3114 L
.90831 .28849 L
.90053 .26742 L
.88927 .24269 L
.87696 .22135 L
.86374 .20341 L
.84977 .18876 L
.83521 .17724 L
.82018 .16861 L
.80482 .16261 L
.78924 .15895 L
.77353 .15731 L
.75294 .15773 L
.73243 .16043 L
.71215 .1648 L
.69216 .17028 L
.67252 .17639 L
.65326 .1827 L
.63438 .18888 L
Mistroke
.61586 .19464 L
.59766 .19974 L
.57688 .20462 L
.5564 .20816 L
.53612 .21024 L
.51593 .21077 L
.49572 .20971 L
.47538 .20709 L
.4548 .20298 L
.43389 .19748 L
.41256 .19078 L
.39046 .18304 L
.36779 .17466 L
.34452 .16609 L
.32065 .15789 L
.29624 .15073 L
.27138 .14542 L
.24624 .1429 L
.22105 .14422 L
.20125 .14872 L
.18179 .15687 L
.16566 .16708 L
.15009 .18058 L
.13525 .1976 L
.12131 .21828 L
.10845 .24265 L
.09683 .27066 L
.08663 .30211 L
.07801 .33667 L
.07231 .36639 L
.06778 .39755 L
.06447 .42981 L
.06242 .4628 L
.06163 .49614 L
.06212 .52943 L
.06388 .56228 L
.06688 .59429 L
.06932 .61333 L
.0722 .63186 L
.0755 .64979 L
.07922 .66707 L
.08334 .68363 L
.08784 .69944 L
.0927 .71445 L
.0979 .72863 L
.10342 .74195 L
.10925 .75438 L
.11787 .7703 L
.12699 .78448 L
.13655 .79692 L
Mistroke
.14648 .80768 L
.15674 .81682 L
.16728 .8244 L
.17804 .83052 L
.18898 .83527 L
.20006 .83877 L
.21123 .84112 L
.22387 .84254 L
.23653 .84281 L
.24918 .84208 L
.2618 .84052 L
.27434 .83827 L
.28679 .83546 L
.29912 .83222 L
.3141 .82782 L
.32888 .82315 L
.34344 .81838 L
.35778 .81365 L
.37192 .80911 L
.38585 .80485 L
.3996 .80098 L
.41318 .79756 L
.4297 .79409 L
.44605 .7915 L
.46228 .78986 L
.47845 .78921 L
.49461 .78958 L
.51082 .79095 L
.52713 .79332 L
.5436 .79665 L
.56029 .80087 L
.58187 .80737 L
.60396 .81494 L
.62661 .82324 L
.64986 .83186 L
.67373 .84026 L
.69816 .84777 L
.72307 .8536 L
.74831 .85684 L
.77365 .85642 L
.79387 .85271 L
.81378 .84534 L
.83033 .83578 L
.84634 .82286 L
.85909 .80942 L
.87124 .7934 L
.88269 .77474 L
.89334 .75345 L
.90308 .72957 L
.91181 .70324 L
Mistroke
.91943 .67464 L
.92586 .64402 L
.92948 .62233 L
.93251 .59998 L
.93493 .57709 L
.93671 .55378 L
.93785 .5302 L
.93835 .50649 L
.93821 .48278 L
.93742 .45923 L
.93599 .43597 L
.93393 .41315 L
.93022 .38351 L
.92546 .35515 L
.91969 .32832 L
.91297 .30324 L
.90537 .28008 L
.89696 .25894 L
.88782 .23991 L
.87803 .22303 L
.86766 .20829 L
.8568 .19565 L
.84551 .18504 L
.83326 .17596 L
.82071 .16888 L
.80792 .16363 L
.79497 .16005 L
.7819 .15796 L
.76878 .15718 L
.75566 .15754 L
.74256 .15886 L
.72771 .16133 L
.71298 .16461 L
.69841 .16848 L
.68401 .17276 L
.66981 .17728 L
.65581 .18188 L
.64201 .18642 L
.6284 .1908 L
.61061 .19619 L
.5931 .20092 L
.57586 .20484 L
.55881 .20783 L
.5419 .20982 L
.52508 .21074 L
.50829 .21057 L
.49145 .20931 L
.4745 .20696 L
.45334 .20265 L
.43181 .19688 L
Mistroke
.40983 .18988 L
.3873 .1819 L
.36418 .17333 L
.34044 .16465 L
.31608 .15645 L
.29118 .14947 L
.26585 .1446 L
.24027 .14284 L
.21471 .1453 L
.19529 .1508 L
.17626 .15999 L
.16019 .17138 L
.14475 .1862 L
.13301 .2006 L
.12187 .21737 L
.11141 .23652 L
.10173 .25803 L
.09292 .28182 L
.08506 .30776 L
.07823 .33566 L
.0725 .3653 L
.06794 .39637 L
.06458 .42855 L
.06248 .46148 L
.06162 .50043 L
.06251 .53924 L
.06448 .56996 L
.06755 .59986 L
.07167 .62866 L
.0768 .6561 L
.0829 .68194 L
.08989 .70601 L
.09772 .72817 L
.10632 .7483 L
.11559 .76634 L
.12255 .77788 L
.12979 .78835 L
.13729 .79779 L
.14501 .80621 L
.15294 .81363 L
.16104 .8201 L
.1693 .82565 L
.17769 .83033 L
.19195 .83632 L
.20642 .84024 L
.22102 .84232 L
.23567 .84281 L
.25032 .84196 L
.26491 .84001 L
.27939 .83718 L
Mistroke
.29373 .83367 L
.30792 .82968 L
.32486 .82444 L
.34152 .819 L
.3579 .8136 L
.37401 .80844 L
.38986 .80367 L
.40548 .79943 L
.42089 .79583 L
.43614 .79295 L
.45125 .79086 L
.47007 .78941 L
.48885 .78932 L
.50766 .79059 L
.5266 .79322 L
.54575 .79713 L
.56519 .80224 L
.585 .80839 L
.60524 .81539 L
.62595 .82299 L
.64717 .83086 L
.6689 .83861 L
.69111 .84574 L
.71375 .85167 L
.73672 .85573 L
.75987 .85716 L
.783 .85512 L
.80587 .84875 L
.82375 .83999 L
.84109 .82754 L
.85767 .81106 L
.87329 .79033 L
.88772 .76522 L
.90074 .73577 L
.91212 .70219 L
.92006 .67192 L
.92668 .63944 L
.93187 .60514 L
.93558 .56945 L
.93775 .53287 L
.93837 .49593 L
.93741 .45916 L
.93491 .42311 L
.9309 .38828 L
.92545 .35513 L
.91863 .32405 L
.91055 .29539 L
.9013 .26937 L
.89101 .24616 L
.8798 .22586 L
Mistroke
.8707 .21232 L
.86118 .20045 L
.85131 .19021 L
.84114 .18154 L
.8307 .17435 L
.82006 .16857 L
.80925 .1641 L
.79832 .16083 L
.7822 .158 L
.766 .15718 L
.7498 .15803 L
.73367 .16023 L
.71767 .16349 L
.70185 .16753 L
.68623 .17209 L
.67084 .17695 L
.65568 .18193 L
.63805 .18772 L
.62075 .19319 L
.60373 .19814 L
.58697 .20242 L
.57044 .2059 L
.55407 .2085 L
.53782 .21015 L
.52163 .2108 L
.50546 .21044 L
.48569 .20863 L
.46574 .20536 L
.44553 .20071 L
.42495 .19481 L
.40394 .18786 L
.38242 .18011 L
.36036 .17192 L
.33774 .16369 L
.31457 .15598 L
.29091 .14941 L
.26686 .14475 L
.24259 .14285 L
.21831 .14466 L
.19883 .14953 L
.17972 .15801 L
.16119 .17057 L
.14348 .18763 L
.12684 .20948 L
.11153 .23628 L
.09784 .26795 L
.09162 .28574 L
.08592 .30465 L
.08075 .32462 L
.07616 .34556 L
Mistroke
.07216 .36736 L
.06878 .38991 L
.06603 .41309 L
.06394 .43676 L
.06225 .46701 L
.06163 .49752 L
.06208 .52796 L
.06358 .55805 L
.06614 .58748 L
.06971 .61598 L
.07425 .6433 L
.07973 .66922 L
.08322 .68316 L
.08698 .69657 L
.091 .70941 L
.09527 .72167 L
.09978 .73332 L
.10451 .74436 L
.10945 .75477 L
.11792 .77037 L
.12687 .78428 L
.13624 .79654 L
.14597 .80717 L
.15603 .81622 L
.16635 .82378 L
.1769 .82992 L
.18888 .83522 L
.20102 .83901 L
.21328 .84143 L
.2256 .84263 L
.23795 .84276 L
.25028 .84197 L
.26257 .84039 L
.27479 .83816 L
.2905 .83451 L
.30603 .83023 L
.32135 .82555 L
.33645 .82067 L
.35131 .81576 L
.36595 .81099 L
.38037 .80647 L
.39459 .80233 L
.41254 .7977 L
.43023 .79398 L
.44773 .79127 L
.4651 .78966 L
.48241 .78919 L
.49973 .78989 L
.51712 .79174 L
.53466 .79472 L
Mistroke
.5524 .79876 L
.57338 .80468 L
.5948 .81171 L
.61674 .81958 L
.63925 .82794 L
.66235 .83634 L
.68602 .8442 L
.71019 .85085 L
.73476 .85548 L
.75956 .85716 L
.78434 .85487 L
.80376 .84955 L
.8228 .84056 L
.83712 .83078 L
.85096 .81833 L
.86422 .80307 L
.87676 .78488 L
.88847 .76373 L
.89921 .73965 L
.90886 .71276 L
.91731 .68325 L
.92257 .66059 L
.92713 .63685 L
.93094 .61217 L
.93399 .58673 L
.93625 .56069 L
.9377 .53426 L
.93834 .50762 L
.93817 .48099 L
.93698 .45089 L
.93475 .42135 L
.9315 .39265 L
.92726 .36506 L
.92209 .33879 L
.91603 .31405 L
.90913 .291 L
.90146 .26976 L
.89297 .25019 L
.88382 .23262 L
.87408 .21708 L
.86383 .20354 L
.85313 .19196 L
.84206 .18225 L
.83068 .17434 L
.81905 .1681 L
.80723 .1634 L
.79526 .16012 L
.7832 .15811 L
.77109 .15724 L
.75897 .15736 L
Mistroke
.74321 .15878 L
.72754 .16136 L
.71202 .16485 L
.69667 .16898 L
.68152 .17354 L
.66659 .17833 L
.65188 .18318 L
.63739 .18793 L
.62312 .19245 L
.60905 .19664 L
.59516 .20041 L
.58143 .20367 L
.56784 .20637 L
.55436 .20846 L
.54096 .2099 L
.52762 .21067 L
.51071 .21067 L
.49376 .20955 L
.47672 .20733 L
.45951 .20406 L
.44209 .19979 L
.42439 .19463 L
.40636 .18869 L
.38797 .18215 L
.36918 .1752 L
.34998 .16809 L
.3343 .16249 L
.31836 .15717 L
.30218 .15233 L
.28579 .14822 L
.26923 .14509 L
.25255 .14323 L
.23582 .14293 L
.21912 .14453 L
.20254 .14833 L
.1862 .15467 L
.17022 .16385 L
.15475 .17614 L
.14313 .18802 L
.13198 .20202 L
.12138 .21818 L
.11142 .2365 L
.10216 .25698 L
.09369 .27954 L
.08608 .30408 L
.0794 .33043 L
.07371 .35839 L
.06907 .38773 L
.06568 .41652 L
.0633 .44603 L
Mistroke
.06196 .47598 L
.06164 .4943 L
.06172 .51261 L
.06217 .53085 L
.06301 .54894 L
.06423 .56683 L
.06582 .58446 L
.06778 .60176 L
.07221 .6319 L
.07775 .66051 L
.08435 .68733 L
.09057 .70809 L
.09742 .72737 L
.10485 .74512 L
.11282 .76129 L
.12127 .77586 L
.13015 .78883 L
.13942 .80023 L
.14902 .8101 L
.1608 .81993 L
.17292 .82778 L
.1853 .83381 L
.19787 .83817 L
.21057 .84101 L
.22336 .8425 L
.23617 .8428 L
.24898 .84209 L
.26364 .84022 L
.27819 .83745 L
.29261 .83397 L
.30686 .82999 L
.32094 .82568 L
.33483 .8212 L
.34853 .81669 L
.36203 .81226 L
.37872 .80698 L
.39514 .80218 L
.41131 .798 L
.42728 .79454 L
.44309 .79189 L
.45877 .79012 L
.47438 .78927 L
.48534 .78924 L
.49631 .78967 L
Mfstroke
.02 w
.67 .835 Mdot
.5 Mabswid
.48534 .78924 m
.49631 .78967 L
s
% Start of user PostScript
-0.058621573 1.1569438 -0.014747401 1.1586676 MAarrowhead1
% End of user PostScript
0 .788 1 r
.6775 .225 m
.67746 .22503 L
.67741 .22507 L
.67672 .22558 L
.67602 .2261 L
.67533 .22662 L
.67329 .22816 L
.67127 .22969 L
.66926 .23123 L
.66726 .23278 L
.6633 .23588 L
.65938 .23899 L
.65551 .2421 L
.65168 .24522 L
.64791 .24833 L
.6375 .25706 L
.62746 .26568 L
.61994 .27224 L
.61262 .27867 L
.60552 .28496 L
.59861 .29109 L
.59191 .29705 L
.58539 .30283 L
.57529 .31171 L
.56564 .32006 L
.55641 .32785 L
.54758 .33508 L
.53911 .34174 L
.53097 .34781 L
.52314 .35331 L
.51369 .3594 L
.50462 .36459 L
.49585 .36889 L
.48734 .37233 L
.47903 .3749 L
.47086 .37664 L
.46278 .37756 L
.45473 .37767 L
.44293 .37643 L
.43094 .37358 L
.41859 .36919 L
.40575 .36336 L
.39229 .35621 L
.37809 .34792 L
.36304 .33869 L
.34707 .32882 L
.33013 .31868 L
.31223 .30876 L
.29341 .29968 L
.27379 .29217 L
Mistroke
.25355 .28711 L
.23781 .2855 L
.22203 .28635 L
.20643 .29014 L
.19122 .29727 L
.18093 .30446 L
.17107 .31355 L
.16172 .32461 L
.153 .33763 L
.145 .35259 L
.13781 .36939 L
.13154 .3879 L
.12627 .4079 L
.1236 .42059 L
.12133 .43367 L
.11947 .44709 L
.11804 .46075 L
.11703 .4746 L
.11646 .48855 L
.11632 .50252 L
.11672 .51914 L
.11774 .53554 L
.11936 .55159 L
.12157 .56718 L
.12435 .58218 L
.12768 .5965 L
.13152 .61003 L
.13585 .62271 L
.14313 .63987 L
.1513 .65484 L
.16023 .66757 L
.1698 .67804 L
.1799 .68629 L
.19039 .69243 L
.20116 .6966 L
.21211 .69895 L
.22315 .69968 L
.23545 .69881 L
.24764 .69643 L
.25964 .69282 L
.2714 .68822 L
.28284 .68286 L
.29394 .67696 L
.30465 .6707 L
.31498 .66423 L
.32491 .65772 L
.33443 .65126 L
.34356 .64495 L
.35231 .63889 L
.36398 .6309 L
Mistroke
.37499 .62364 L
.38541 .6172 L
.3953 .61165 L
.40476 .60701 L
.41385 .60329 L
.42266 .60051 L
.43128 .59865 L
.43977 .59769 L
.44941 .59768 L
.4591 .59879 L
.46896 .60099 L
.47909 .60423 L
.48959 .60851 L
.50057 .61377 L
.51211 .62 L
.52431 .62716 L
.53726 .63521 L
.55461 .64642 L
.5734 .65875 L
.59026 .6697 L
.60826 .68103 L
.62408 .6905 L
.6407 .69977 L
.65808 .70853 L
.67619 .71639 L
.6949 .72288 L
.71409 .72745 L
.73357 .72946 L
.75308 .72823 L
.76858 .72443 L
.78372 .71774 L
.78375 .71773 L
.78377 .71772 L
.78379 .7177 L
.78381 .71769 L
.78384 .71768 L
.78388 .71765 L
.78393 .71763 L
.78397 .7176 L
.78443 .71735 L
.78488 .71709 L
.78534 .71683 L
.78579 .71656 L
.78945 .71431 L
.79307 .71186 L
.79664 .7092 L
.80017 .70633 L
.80365 .70324 L
.80944 .69751 L
.81505 .69115 L
Mistroke
.82047 .68416 L
.82568 .67653 L
.83066 .66828 L
.8354 .65941 L
.84069 .64805 L
.84558 .63587 L
.85004 .62291 L
.85403 .60923 L
.85755 .59489 L
.86056 .57998 L
.86305 .56458 L
.86461 .55234 L
.86584 .53991 L
.86674 .52734 L
.8673 .51467 L
.86752 .50195 L
.86741 .48923 L
.86695 .47657 L
.86553 .4567 L
.86329 .43729 L
.86023 .41851 L
.85639 .40053 L
.85181 .38349 L
.84653 .36751 L
.8406 .35269 L
.83406 .33911 L
.82547 .32445 L
.81617 .31167 L
.80627 .30079 L
.79586 .29173 L
.78503 .28443 L
.77387 .27876 L
.76247 .2746 L
.75088 .27181 L
.73919 .27022 L
.72252 .26974 L
.70588 .27094 L
.68938 .27343 L
.6731 .27684 L
.65708 .28083 L
.64137 .28513 L
.62597 .28951 L
.61089 .29377 L
.5961 .29777 L
.57924 .30192 L
.56269 .3054 L
.54641 .30812 L
.53033 .31 L
.51436 .31103 L
.49845 .31119 L
Mistroke
.48251 .3105 L
.46648 .30901 L
.45029 .30677 L
.43389 .30389 L
.41722 .30048 L
.40025 .2967 L
.38295 .29275 L
.36532 .28888 L
.34737 .28538 L
.32916 .2826 L
.31076 .28096 L
.29228 .28092 L
.27389 .28297 L
.25577 .28764 L
.24138 .29372 L
.22749 .30211 L
.21425 .31301 L
.20186 .32655 L
.19049 .34278 L
.18032 .36165 L
.17154 .38298 L
.16531 .40273 L
.16027 .4238 L
.15714 .44135 L
.15484 .45939 L
.15338 .47773 L
.15278 .49618 L
.15303 .51455 L
.15412 .53263 L
.15604 .55025 L
.15877 .56723 L
.1605 .57578 L
.16243 .58409 L
.16456 .59214 L
.16688 .59992 L
.16939 .6074 L
.17207 .61458 L
.17493 .62145 L
.17933 .63077 L
.18405 .6394 L
.18905 .64729 L
.19432 .65446 L
.19983 .6609 L
.20554 .66661 L
.21145 .6716 L
.2212 .67812 L
.23126 .68295 L
.24155 .6862 L
.25199 .688 L
.26248 .68848 L
Mistroke
.27297 .68778 L
.28338 .68606 L
.29368 .68343 L
.30381 .68004 L
.31373 .676 L
.32341 .67142 L
.3348 .66527 L
.34575 .65863 L
.35624 .65162 L
.36625 .64434 L
.37576 .6369 L
.38477 .62934 L
.39326 .62174 L
.40123 .61412 L
.40869 .60652 L
.41564 .59895 L
.42207 .59143 L
.42896 .5827 L
.43516 .57404 L
.44067 .56544 L
.44551 .5569 L
.44967 .54841 L
.45317 .53993 L
.45599 .53147 L
.45814 .52301 L
.46004 .51109 L
.4606 .4991 L
.45983 .48697 L
.45771 .47468 L
.45421 .4622 L
.44931 .44949 L
.443 .43653 L
.43523 .42332 L
.42598 .40987 L
.41523 .39621 L
.40295 .38241 L
.38915 .36862 L
.37706 .35776 L
.36402 .34719 L
.35006 .33709 L
.33525 .32773 L
.32269 .32092 L
.30969 .315 L
.29629 .3102 L
.28261 .30677 L
.26873 .30501 L
.2548 .30519 L
.24096 .30762 L
.22738 .31256 L
.21681 .31851 L
Mistroke
.20664 .32633 L
.19901 .33381 L
.19175 .3425 L
.1849 .3524 L
.17853 .36349 L
.17268 .37572 L
.1674 .38903 L
.16274 .40334 L
.15874 .41855 L
.15545 .43453 L
.15288 .45114 L
.15162 .46221 L
.15068 .47343 L
.15007 .48476 L
.14979 .49615 L
.14985 .50755 L
.15023 .51891 L
.15095 .53019 L
.15253 .54599 L
.15476 .56139 L
.15761 .57627 L
.16108 .59052 L
.16511 .60405 L
.1697 .61678 L
.17479 .62863 L
.18036 .63957 L
.18791 .65188 L
.19607 .66266 L
.20474 .67193 L
.21386 .6797 L
.22334 .68603 L
.23311 .69101 L
.24311 .69472 L
.25326 .69728 L
.26353 .69879 L
.27798 .69937 L
.29242 .69845 L
.30675 .69634 L
.32089 .6933 L
.33479 .6896 L
.34839 .68545 L
.36169 .68103 L
.37466 .67652 L
.3873 .67203 L
.40122 .66711 L
.41473 .66247 L
.42789 .65819 L
.44071 .65434 L
.45323 .65094 L
.46549 .64803 L
Mistroke
.47753 .64561 L
.4894 .64368 L
.50112 .64223 L
.51498 .64111 L
.52876 .64063 L
.54252 .64073 L
.55631 .64135 L
.57019 .64242 L
.5842 .64385 L
.59835 .64555 L
.61268 .64737 L
.62719 .64917 L
.6416 .65074 L
.65613 .65191 L
.67076 .65246 L
.68539 .65212 L
.69994 .65063 L
.71428 .64769 L
.72825 .64305 L
.74169 .63645 L
.75439 .6277 L
.76614 .61669 L
.77673 .60341 L
.78211 .59496 L
.78702 .58587 L
.79141 .5762 L
.79527 .56602 L
.79857 .55541 L
.80128 .54447 L
.80339 .53332 L
.80489 .52206 L
.80578 .51081 L
.80606 .49969 L
.80575 .48884 L
.80459 .47617 L
.80263 .46424 L
.79991 .45323 L
.79649 .44328 L
.79246 .4345 L
.7879 .427 L
.78288 .42081 L
.7775 .41596 L
.77462 .414 L
.77167 .41238 L
.76868 .41112 L
.76565 .41019 L
.7626 .4096 L
.75953 .40935 L
.75646 .40941 L
.75069 .41035 L
Mistroke
.74502 .41232 L
.7395 .41525 L
.7342 .41904 L
.72916 .42363 L
.72444 .42892 L
.72009 .43485 L
.71612 .44133 L
.71193 .44977 L
.70841 .4588 L
.70561 .46831 L
.70355 .4782 L
.70226 .48838 L
.70177 .49876 L
.70208 .50923 L
.70319 .51973 L
.70556 .53211 L
.70906 .54422 L
.71365 .55586 L
.71927 .56685 L
.72586 .57695 L
.73333 .58592 L
.74156 .5935 L
.7504 .5994 L
.7571 .60245 L
.76395 .60437 L
.7709 .60503 L
.77785 .60436 L
.7847 .60227 L
.79137 .5987 L
.79775 .59361 L
.80374 .58699 L
.80864 .5799 L
.81308 .57169 L
.81702 .56243 L
.82038 .55221 L
.82312 .54114 L
.82519 .52938 L
.82655 .51706 L
.82718 .50437 L
.82719 .49602 L
.82688 .48763 L
.82625 .47926 L
.8253 .47095 L
.82404 .46275 L
.82247 .45471 L
.8206 .44686 L
.81741 .43604 L
.81365 .42581 L
.80935 .41626 L
.80455 .40746 L
Mistroke
.79929 .39946 L
.79362 .3923 L
.78758 .38598 L
.78122 .38051 L
.77336 .37513 L
.76519 .37086 L
.75677 .36764 L
.74818 .3654 L
.73948 .36404 L
.73071 .36346 L
.72193 .36357 L
.71318 .36426 L
.70449 .36544 L
.69588 .36703 L
.68739 .36893 L
.67758 .37147 L
.66797 .37424 L
.65857 .37714 L
.6494 .38009 L
.64045 .38304 L
.63172 .38592 L
.6232 .3887 L
.61489 .39136 L
.6051 .39436 L
.59556 .39711 L
.58627 .3996 L
.57719 .40184 L
.56831 .40381 L
.55959 .40554 L
.55103 .40704 L
.54259 .40832 L
.53425 .40941 L
.52282 .41062 L
.51152 .41153 L
.50033 .41218 L
.4892 .4126 L
.47811 .41283 L
.46703 .41287 L
.45596 .41276 L
.44486 .41249 L
.43371 .41208 L
.42251 .41153 L
.41122 .41085 L
.39984 .41005 L
.38683 .40903 L
.37366 .40792 L
.36032 .40679 L
.34683 .40576 L
.33583 .40509 L
.32476 .40466 L
Mistroke
.31366 .40459 L
.30258 .40502 L
.29159 .40607 L
.28076 .4079 L
.27019 .41065 L
.26199 .4136 L
.25409 .41727 L
.24658 .4217 L
.23951 .42689 L
.23296 .43282 L
.22699 .43945 L
.22168 .4467 L
.21706 .45445 L
.21453 .45955 L
.21229 .46475 L
.21037 .47001 L
.20875 .47528 L
.20745 .48052 L
.20645 .48568 L
.20575 .4907 L
.20531 .49643 L
.20525 .50183 L
.20555 .50684 L
.20619 .5114 L
.20714 .51545 L
.20835 .51897 L
.20978 .52192 L
.21141 .5243 L
.2134 .52627 L
.21552 .52752 L
.21771 .52808 L
.21991 .528 L
.22209 .52731 L
.22419 .5261 L
.22618 .52442 L
.22802 .52236 L
.2294 .52043 L
.23066 .51834 L
.23177 .51614 L
.23274 .51387 L
.23356 .51157 L
.23424 .5093 L
.23476 .50708 L
.23526 .50426 L
.23551 .50171 L
.23556 .49951 L
.23544 .49774 L
.23518 .49645 L
.23484 .4957 L
.23445 .4955 L
Mistroke
.23407 .4959 L
.23371 .49711 L
.23351 .49911 L
.23356 .50185 L
.23391 .50527 L
.23465 .50928 L
.23581 .51376 L
.23745 .51858 L
.23959 .52362 L
.24166 .52767 L
.24405 .53171 L
.24676 .53565 L
.24979 .53945 L
.25311 .54305 L
.25671 .54639 L
.26057 .54943 L
.26466 .55215 L
.2696 .55481 L
.27477 .55697 L
.2801 .5586 L
.28557 .55968 L
.2911 .56022 L
.29667 .56022 L
.3022 .55967 L
.30766 .55859 L
.31374 .55672 L
.31959 .55418 L
.32513 .55097 L
.3303 .54712 L
.33503 .54261 L
.33925 .53746 L
.34289 .53165 L
.34589 .52518 L
.34861 .51622 L
.35009 .50621 L
.35019 .49515 L
.34877 .48305 L
.34571 .46994 L
.34087 .45592 L
.33415 .44113 L
.32718 .4286 L
.31886 .41591 L
.31884 .41589 L
.31883 .41587 L
.31881 .41584 L
.3188 .41582 L
.31878 .4158 L
.31875 .41576 L
.31872 .41572 L
.31869 .41567 L
Mistroke
.31839 .41524 L
.31808 .41482 L
.31777 .41439 L
.31746 .41396 L
.31472 .41027 L
.31187 .4066 L
.3089 .40295 L
.30581 .39934 L
.30262 .39577 L
.29758 .39049 L
.29231 .38538 L
.28679 .38047 L
.28105 .37581 L
.2751 .37146 L
.26895 .36746 L
.26262 .36387 L
.25613 .36075 L
.24951 .35817 L
.24278 .35618 L
.23597 .35485 L
.22912 .35425 L
.2224 .35442 L
.21571 .35539 L
.20908 .35723 L
.20256 .35997 L
.19619 .36366 L
.19001 .36831 L
.18407 .37395 L
.17841 .38059 L
.17308 .38821 L
.16812 .39679 L
.16223 .40949 L
.15715 .42365 L
.15375 .43588 L
.15095 .44881 L
.14879 .46231 L
.1473 .47623 L
.14649 .49043 L
.14637 .50474 L
.14695 .51901 L
.14821 .53306 L
.15015 .54676 L
.15274 .55995 L
.15595 .57252 L
.15823 .57988 L
.16072 .58695 L
.16341 .59368 L
.1663 .60008 L
.16938 .60611 L
.17263 .61178 L
Mistroke
.17604 .61708 L
.18185 .62479 L
.188 .6315 L
.19445 .63722 L
.20116 .64197 L
.20806 .64578 L
.21513 .6487 L
.22232 .65079 L
.22959 .65209 L
.23691 .65269 L
.24424 .65263 L
.25234 .6519 L
.26038 .65056 L
.26834 .64869 L
.27618 .64638 L
.2839 .64371 L
.29146 .64076 L
.29886 .6376 L
.30793 .63343 L
.31671 .62913 L
.3252 .6248 L
.33341 .62053 L
.34133 .61639 L
.34898 .61241 L
.35637 .60866 L
.36352 .60516 L
.37156 .60143 L
.37932 .59811 L
.38684 .5952 L
.39415 .59271 L
.40129 .59065 L
.40827 .589 L
.41515 .58776 L
.42195 .58691 L
.43266 .58632 L
.44337 .58662 L
.45416 .58775 L
.46514 .58963 L
.47639 .59221 L
.48801 .59544 L
.50006 .59928 L
.51263 .60367 L
.52577 .6086 L
.53955 .614 L
.55403 .61982 L
.56925 .62598 L
.58525 .63236 L
.59901 .63766 L
.6133 .64285 L
.62811 .64778 L
Mistroke
.64341 .65223 L
.6563 .65534 L
.66943 .65778 L
.68272 .65934 L
.69611 .65981 L
.70948 .65896 L
.72271 .65656 L
.73567 .65238 L
.74592 .64751 L
.75579 .64124 L
.76518 .6335 L
.774 .62425 L
.78213 .61352 L
.78947 .60134 L
.79594 .58784 L
.80145 .57315 L
.80591 .55747 L
.80879 .54387 L
.81089 .52992 L
.81219 .51578 L
.81268 .50164 L
.81237 .48767 L
.81129 .47406 L
.80944 .46096 L
.80687 .44853 L
.80499 .44146 L
.80288 .43471 L
.80055 .4283 L
.79801 .42225 L
.79526 .41657 L
.79233 .41129 L
.78923 .40641 L
.78456 .40021 L
.77962 .39485 L
.77444 .39033 L
.76906 .38664 L
.76353 .38377 L
.75787 .38169 L
.75214 .38039 L
.74526 .37978 L
.73838 .38015 L
.73155 .38142 L
.72482 .38353 L
.71822 .3864 L
.71182 .38996 L
.70563 .39415 L
.6997 .39891 L
.69267 .40558 L
.68615 .41295 L
.68017 .42092 L
Mistroke
.67479 .42941 L
.67004 .43835 L
.66594 .44767 L
.66253 .45733 L
.65982 .46729 L
.65738 .48059 L
.6562 .49425 L
.65631 .5082 L
.65774 .52237 L
.6605 .53667 L
.66459 .55103 L
.67002 .56532 L
.67678 .57941 L
.68484 .59312 L
.69415 .60621 L
.70464 .61841 L
.71622 .62937 L
.72875 .63871 L
.74206 .64595 L
.75592 .65059 L
.7675 .6521 L
.7791 .65124 L
.78812 .64874 L
.79694 .6445 L
.80545 .63846 L
.81354 .63056 L
.8211 .6208 L
.82802 .60921 L
.83419 .59588 L
.83951 .58095 L
.84302 .56829 L
.84591 .55488 L
.84816 .54084 L
.84974 .52632 L
.85063 .51146 L
.85081 .49643 L
.85029 .48138 L
.84907 .46648 L
.848 .45767 L
.84668 .44901 L
.84513 .44051 L
.84334 .43221 L
.84131 .42414 L
.83907 .41632 L
.83661 .40877 L
.83338 .4001 L
.82986 .39188 L
.82608 .38414 L
.82204 .37689 L
.81777 .37016 L
Mistroke
.81328 .36394 L
.80859 .35824 L
.80356 .35292 L
.79836 .34814 L
.793 .34391 L
.78751 .3402 L
.78189 .337 L
.77617 .33429 L
.77037 .33204 L
.76191 .32959 L
.75334 .32796 L
.74472 .32709 L
.73607 .32688 L
.72743 .32725 L
.71881 .32813 L
.71025 .32943 L
.70177 .33108 L
.69081 .33364 L
.68003 .33652 L
.66944 .33961 L
.65906 .34279 L
.64889 .34596 L
.63892 .34905 L
.62915 .35197 L
.61957 .35468 L
.60745 .35779 L
.59557 .3604 L
.58388 .36244 L
.57235 .36388 L
.56091 .36469 L
.54951 .36486 L
.53809 .36438 L
.52661 .36326 L
.51501 .36149 L
.49851 .35797 L
.48153 .35327 L
.46393 .34745 L
.44558 .34064 L
.42638 .333 L
.40975 .3262 L
.39245 .3192 L
.37792 .31354 L
.36295 .30809 L
.34756 .30305 L
.3318 .29869 L
.31572 .29529 L
.29943 .29319 L
.28304 .29276 L
.26669 .29439 L
.25057 .29848 L
Mistroke
.23826 .30362 L
.22633 .31066 L
.2149 .31972 L
.20409 .33089 L
.19404 .34421 L
.18488 .35965 L
.17674 .37712 L
.16973 .39646 L
.16513 .4127 L
.16133 .42978 L
.15836 .44754 L
.15627 .4658 L
.15507 .48435 L
.15476 .50298 L
.15536 .52149 L
.15683 .53966 L
.15827 .55127 L
.16006 .5626 L
.16221 .57359 L
.16471 .58421 L
.16752 .59442 L
.17066 .60417 L
.17409 .61343 L
.17781 .62219 L
.1818 .63041 L
.18604 .63808 L
.19173 .64698 L
.19776 .65496 L
.20408 .66204 L
.21068 .66821 L
.2175 .67351 L
.22452 .67794 L
.23169 .68156 L
.24083 .68498 L
.25012 .68727 L
.25949 .68852 L
.2689 .68882 L
.27831 .68827 L
.28766 .68697 L
.29694 .68502 L
.3061 .68249 L
.31715 .67874 L
.32795 .6744 L
.33846 .66959 L
.34868 .66442 L
.35856 .65899 L
.36811 .65337 L
.37731 .64763 L
.38616 .64184 L
.39721 .63421 L
Mistroke
.40766 .62663 L
.4175 .61914 L
.42674 .61176 L
.4354 .60453 L
.44349 .59744 L
.45101 .59051 L
.45799 .58371 L
.46442 .57705 L
.47168 .56895 L
.47814 .561 L
.48382 .5532 L
.48873 .54551 L
.49288 .53793 L
.49627 .53043 L
.49893 .523 L
.50085 .51564 L
.50204 .50834 L
.50251 .49883 L
.50174 .48943 L
.49975 .48014 L
.49655 .47098 L
.49216 .46193 L
.48659 .453 L
.47986 .44418 L
.47198 .43546 L
.46297 .42683 L
.4527 .41818 L
.44129 .40962 L
.42875 .40116 L
.4151 .39285 L
.40037 .3848 L
.38459 .37717 L
.36785 .37019 L
.35351 .36521 L
.33869 .36115 L
.32348 .35829 L
.30805 .35697 L
.29257 .35757 L
.27986 .35979 L
.26742 .3638 L
.25806 .36828 L
.24905 .37401 L
.24048 .38104 L
.23246 .38938 L
.22506 .39902 L
.21838 .40989 L
.2125 .4219 L
.20749 .4349 L
.20342 .44873 L
.20034 .46315 L
Mistroke
.19828 .47795 L
.19736 .49036 L
.19716 .50269 L
.19767 .51479 L
.19888 .52651 L
.20075 .5377 L
.20325 .54824 L
.20635 .55801 L
.20999 .56693 L
.21265 .57228 L
.2155 .57721 L
.21854 .58171 L
.22174 .58577 L
.22509 .58938 L
.22856 .59254 L
.23215 .59525 L
.23791 .59859 L
.24385 .60087 L
.24988 .60212 L
.25597 .60241 L
.26204 .60177 L
.26805 .60027 L
.27394 .59796 L
.27967 .59492 L
.28627 .59038 L
.29251 .58498 L
.29834 .57879 L
.30371 .57192 L
.30856 .56445 L
.31286 .55644 L
.31658 .54797 L
.31968 .5391 L
.32213 .52988 L
.32444 .51649 L
.3254 .50265 L
.32496 .48846 L
.32309 .47405 L
.31979 .45956 L
.31506 .44514 L
.3089 .43099 L
.30135 .41734 L
.29249 .40445 L
.2824 .39267 L
.2712 .3824 L
.25908 .37409 L
.24625 .36824 L
.23549 .36566 L
.22461 .36534 L
.21381 .36753 L
.20329 .37245 L
Mistroke
.19328 .38025 L
.18402 .39098 L
.17575 .40459 L
.17251 .41136 L
.16953 .41861 L
.1668 .42632 L
.16436 .43446 L
.16221 .44299 L
.16036 .45187 L
.15883 .46104 L
.15763 .47047 L
.15689 .47846 L
.15638 .48655 L
.1561 .49472 L
.15607 .50294 L
.15627 .51117 L
.15672 .51938 L
.1574 .52753 L
.1595 .5437 L
.16194 .55666 L
.165 .5691 L
.16866 .58092 L
.17287 .59201 L
.1776 .6023 L
.18281 .61173 L
.18845 .62026 L
.19449 .62787 L
.20219 .63577 L
.2103 .64234 L
.21876 .64764 L
.2275 .65174 L
.23644 .65471 L
.24552 .65666 L
.25469 .65769 L
.2639 .65791 L
.27309 .65743 L
.28525 .65589 L
.29726 .65355 L
.30906 .65062 L
.32062 .64731 L
.33192 .64378 L
.34293 .64018 L
.35367 .63663 L
.36414 .63323 L
.37435 .63005 L
.38747 .62631 L
.40025 .62317 L
.41273 .62069 L
.425 .61892 L
.43712 .61788 L
Mistroke
.44918 .61756 L
.46124 .61797 L
.47337 .61908 L
.48566 .62089 L
.49979 .62373 L
.5143 .62738 L
.52927 .6318 L
.5448 .63692 L
.56095 .64264 L
.5778 .64885 L
.59538 .65535 L
.60979 .66053 L
.62466 .66558 L
.63999 .67029 L
.65572 .67443 L
.67179 .67769 L
.6881 .67974 L
.70453 .6802 L
.72092 .67866 L
.73425 .67559 L
.74728 .67066 L
.7579 .66492 L
.76811 .65763 L
.77579 .65075 L
.7831 .64285 L
.79 .63392 L
.79642 .62399 L
.80233 .61309 L
.80767 .60127 L
.8124 .5886 L
.81648 .57519 L
.81987 .56115 L
.82256 .5466 L
.824 .5362 L
.82508 .52567 L
.82579 .51507 L
.82613 .50446 L
.8261 .49389 L
.8257 .48341 L
.82494 .47309 L
.8237 .46195 L
.82202 .45112 L
.81994 .44067 L
.81747 .43066 L
.81462 .42113 L
.81142 .41213 L
.80808 .40415 L
.80447 .39671 L
.80059 .38982 L
.79647 .3835 L
Mistroke
.79214 .37777 L
.78761 .37261 L
.7829 .36804 L
.77517 .36201 L
.76713 .35738 L
.75886 .35409 L
.75044 .35206 L
.74195 .35122 L
.73343 .35146 L
.72496 .35269 L
.71658 .35482 L
.70748 .3581 L
.69861 .36223 L
.69002 .36711 L
.68177 .37262 L
.67388 .37867 L
.66639 .38518 L
.65933 .39209 L
.65272 .39932 L
.64657 .40683 L
.6385 .41817 L
.6315 .42991 L
.6256 .44199 L
.62082 .45437 L
.6172 .46701 L
.61475 .47991 L
.6135 .49306 L
.61348 .50646 L
.6147 .52009 L
.61757 .53561 L
.62205 .5514 L
.62816 .5674 L
.63594 .58354 L
.64538 .59966 L
.65647 .61559 L
.66918 .63105 L
.68344 .64564 L
.69635 .65673 L
.71016 .66655 L
.72474 .67468 L
.73992 .68065 L
.7555 .68395 L
.76882 .68425 L
.78206 .68194 L
.79222 .67812 L
.80212 .67241 L
.81164 .66472 L
.82066 .65499 L
.82908 .64321 L
.83678 .62942 L
Mistroke
.84364 .61372 L
.84957 .59625 L
.85372 .58056 L
.8571 .56394 L
.85969 .54656 L
.86145 .52862 L
.86236 .51031 L
.86241 .49185 L
.8616 .47345 L
.85993 .45532 L
.85708 .43567 L
.85323 .41686 L
.84842 .39911 L
.84272 .38263 L
.83619 .36755 L
.82892 .35398 L
.82097 .34199 L
.81245 .33159 L
.80843 .32742 L
.80432 .32357 L
.80012 .32003 L
.79584 .3168 L
.79149 .31387 L
.78708 .31123 L
.7826 .30888 L
.77136 .30423 L
.75989 .30109 L
.74829 .29929 L
.73858 .29869 L
.72885 .29878 L
.71915 .29948 L
.70949 .30068 L
.6999 .30228 L
.6904 .30421 L
.681 .30638 L
.6717 .30872 L
.65769 .31249 L
.64397 .31629 L
.63052 .31995 L
.61733 .32333 L
.60438 .32632 L
.59163 .32881 L
.57905 .33075 L
.56658 .33209 L
.5542 .33277 L
.54183 .33278 L
.52945 .3321 L
.51455 .33038 L
.49946 .32767 L
.48408 .324 L
Mistroke
.46834 .3194 L
.45215 .31394 L
.43545 .30772 L
.41817 .30087 L
.40026 .29358 L
.3817 .28607 L
.36599 .27999 L
.34984 .27419 L
.3333 .26894 L
.3164 .26455 L
.29923 .26135 L
.28187 .25975 L
.26448 .26016 L
.2472 .26304 L
.23309 .26761 L
.21932 .27442 L
.20603 .28367 L
.19337 .29552 L
.18151 .31009 L
.17061 .32739 L
.16082 .34735 L
.15231 .36983 L
.148 .38401 L
.14419 .39888 L
.14091 .41437 L
.13818 .43039 L
.13603 .44683 L
.13446 .46359 L
.13348 .48056 L
.13313 .49342 L
.13313 .50629 L
.13347 .5191 L
.13414 .53182 L
.13515 .5444 L
.13649 .55678 L
.13815 .56892 L
.14144 .58762 L
.14549 .60545 L
.15028 .62228 L
.15575 .638 L
.16185 .65252 L
.16854 .66577 L
.17575 .67772 L
.18344 .68835 L
.19265 .6988 L
.20232 .7076 L
.21236 .71482 L
.22272 .72054 L
.23331 .72487 L
.24408 .72792 L
Mistroke
.25496 .72982 L
.26591 .73069 L
.27688 .73066 L
.28783 .72985 L
.29872 .72838 L
.31123 .726 L
.32358 .72305 L
.33577 .71967 L
.34775 .716 L
.35954 .71215 L
.3711 .70821 L
.38245 .70427 L
.39359 .70041 L
.40815 .69546 L
.42235 .69087 L
.43624 .6867 L
.44984 .68303 L
.46318 .6799 L
.47632 .67732 L
.48929 .67531 L
.50213 .67386 L
.51488 .67295 L
.53029 .67256 L
.5457 .67289 L
.56116 .67385 L
.57674 .67535 L
.59247 .67726 L
.60838 .67942 L
.62449 .68165 L
.64079 .68372 L
.65726 .68538 L
.67473 .68632 L
.69223 .68606 L
.70963 .68417 L
.72676 .68018 L
.74039 .67507 L
.75356 .66806 L
.76611 .65896 L
.77788 .64767 L
.78869 .63412 L
.79838 .61836 L
.80679 .60055 L
.81268 .58435 L
.81751 .56711 L
.8206 .55258 L
.82292 .53768 L
.82447 .52256 L
.82524 .50739 L
.82523 .49234 L
.82446 .47758 L
Mistroke
.82293 .46328 L
.82069 .44959 L
.8191 .44212 L
.81729 .43491 L
.81528 .42798 L
.81307 .42137 L
.81067 .41507 L
.80809 .40912 L
.80534 .40352 L
.80135 .39649 L
.7971 .39015 L
.79261 .3845 L
.78791 .37955 L
.78302 .3753 L
.77798 .37174 L
.77281 .36886 L
.76463 .36569 L
.75631 .364 L
.74792 .36371 L
.73956 .36469 L
.73129 .36684 L
.72319 .37004 L
.71531 .37417 L
.70771 .37912 L
.70044 .38481 L
.69355 .39112 L
.68705 .39799 L
.67921 .40768 L
.67219 .41805 L
.66601 .42896 L
.66074 .44032 L
.6564 .45204 L
.65302 .46407 L
.65061 .47634 L
.64921 .48882 L
.64881 .50145 L
.64945 .51421 L
.65111 .52705 L
.65421 .54149 L
.6586 .55588 L
.6643 .57015 L
.67127 .58415 L
.67949 .59774 L
.68891 .6107 L
.69761 .62081 L
.70704 .63014 L
.71714 .63849 L
.72782 .64563 L
.73898 .65131 L
.7505 .65525 L
Mistroke
.76225 .65717 L
.77406 .65679 L
.78372 .65457 L
.7932 .65047 L
.80235 .6444 L
.81107 .6363 L
.81922 .62614 L
.82668 .61395 L
.83332 .59983 L
.83903 .58393 L
.84283 .57014 L
.84594 .5555 L
.8483 .54015 L
.84989 .52427 L
.85069 .50805 L
.85068 .49166 L
.84987 .47531 L
.84825 .4592 L
.8463 .44605 L
.84381 .43328 L
.8408 .421 L
.8373 .40928 L
.83333 .39819 L
.82892 .38779 L
.82409 .37813 L
.81888 .36925 L
.81549 .36416 L
.81197 .35937 L
.80833 .35489 L
.80459 .35072 L
.80074 .34686 L
.7968 .3433 L
.79277 .34003 L
.78289 .33343 L
.77265 .32838 L
.76215 .32476 L
.75329 .32275 L
.74434 .32154 L
.73535 .32104 L
.72635 .32118 L
.71737 .32186 L
.70844 .32299 L
.69957 .3245 L
.69079 .32631 L
.67875 .32919 L
.66692 .33235 L
.65532 .33563 L
.64394 .33892 L
.6328 .34211 L
.62187 .34511 L
Mistroke
.61114 .34785 L
.6006 .35027 L
.58878 .35258 L
.57714 .35438 L
.56561 .35562 L
.55416 .35628 L
.54274 .35636 L
.5313 .35583 L
.51979 .3547 L
.50817 .35298 L
.49639 .35068 L
.48062 .3468 L
.46439 .342 L
.44761 .33637 L
.43021 .33003 L
.41212 .32315 L
.39329 .31597 L
.37816 .31039 L
.36257 .30502 L
.34657 .30009 L
.3302 .29587 L
.31352 .29271 L
.29664 .29096 L
.27969 .29103 L
.26284 .29337 L
.24924 .29726 L
.23597 .30319 L
.22316 .31133 L
.21097 .32186 L
.20152 .33237 L
.19269 .34457 L
.18458 .35844 L
.17726 .37391 L
.17083 .39087 L
.16537 .40915 L
.16093 .42856 L
.15758 .44886 L
.15585 .46405 L
.15472 .47945 L
.15421 .49495 L
.15432 .51041 L
.15504 .52573 L
.15636 .54079 L
.15828 .55546 L
.16169 .5741 L
.16605 .59168 L
.17021 .60493 L
.17492 .6173 L
.18012 .62872 L
.18579 .63915 L
Mistroke
.19188 .64856 L
.19834 .65694 L
.20514 .66429 L
.21222 .67062 L
.22092 .67683 L
.2299 .68171 L
.23909 .68533 L
.24843 .68779 L
.25787 .68917 L
.26736 .68957 L
.27684 .6891 L
.28627 .68785 L
.29686 .68562 L
.3073 .68265 L
.31756 .67906 L
.32759 .67496 L
.33738 .67045 L
.34691 .66563 L
.35616 .66056 L
.36615 .65469 L
.37577 .64868 L
.385 .64259 L
.39385 .63647 L
.4023 .63036 L
.41037 .6243 L
.41806 .61829 L
.42537 .61236 L
.43384 .60521 L
.44174 .59819 L
.44911 .59132 L
.45595 .58458 L
.46228 .57797 L
.46809 .57147 L
.4734 .56508 L
.47821 .55878 L
.48426 .54991 L
.48932 .54119 L
.49342 .53257 L
.49657 .52405 L
.49878 .51561 L
.50005 .50724 L
.50039 .49895 L
.49982 .49071 L
.49803 .48133 L
.49505 .47204 L
.49088 .46283 L
.48554 .45371 L
.47904 .44467 L
.47139 .43568 L
.46259 .42676 L
Mistroke
.45266 .41788 L
.44159 .40905 L
.4294 .40029 L
.41609 .39166 L
.40169 .38323 L
.38952 .37681 L
.37671 .37072 L
.36331 .36512 L
.34937 .36019 L
.33497 .35617 L
.32023 .35333 L
.30527 .35198 L
.29026 .35247 L
.27795 .35452 L
.26843 .3573 L
.25914 .36122 L
Mfstroke
.02 w
.6775 .225 Mdot
.5 Mabswid
.26843 .3573 m
.25914 .36122 L
s
% Start of user PostScript
-0.9262704 -0.57078599 -0.96345451 -0.55513294 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[55]:=",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00_`3oool400000<d0oooo002o0?ooo`030000003o
ool0oooo0<h0oooo00300?ooo`030000003oool0oooo00H0oooo0`0000340?ooo`00^@3oool40000
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`340?ooo`00_`3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo0<@0oooo00300?ooo`8000001`3oool00`000000
oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?oo
o`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?oo
o`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3o
ool200000<D0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo
0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo
00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?oo
o`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`800000
a@3oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool0
0<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo
00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3o
ool0a03oool00<T0oooo0P0000350?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool0
0`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000
oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?oo
o`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?oo
o`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool200000<D0oooo00390?ooo`030000003o
ool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo
0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo
00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo002c0?oo
o`D000000P3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0<@0oooo002e0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`340?oo
o`00]@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo0`0000340?ooo`00
[@3oool4000000@0oooo00<000000?ooo`3oool0203oool2000000L0oooo00<000000?ooo`3oool0
a03oool00;D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0<@0oooo002d0?ooo`8000002P3oool3000000H0oooo00<000000?ooo`3oool0a03oool0
0<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool005h0oooo
2@3oA`1R0?ooo`030000003oool0oooo0<@0oooo001H0?oooaT0odL0F03oool00`000000oooo0?oo
o`340?ooo`00EP3ooolO0?m705@0oooo00<000000?ooo`3oool0a03oool005<0oooo3@3oA`090?oo
oa00odL0D03oool200000<D0oooo001@0?ooo`T0odL0603oool=0?m704/0oooo00<000000?ooo`3o
ool0a03oool004h0oooo0`3oA`00103oool0odL00?m7003oA`0Q0?ooo`@0odL000<0oooo0?m7003o
A`001@3oA`170?ooo`030000003oool0oooo0<@0oooo001<0?ooo`<0odL000<0oooo0?m7003oA`00
:03oool30?m700030?ooo`3oA`00odL000D0odL0A03oool00`000000oooo0?ooo`1K0?oooa<0odL0
EP3oool004X0oooo1P3oA`0]0?ooo`<0odL00P3oool60?m70440oooo00<000000?ooo`3oool0EP3o
oolM0?m70540oooo00190?ooo`@0odL0<`3oool30?m70080oooo1P3oA`0n0?ooo`030000003oool0
oooo0580oooo903oA`1>0?ooo`00A`3oool40?m703P0oooo0`3oA`020?ooo`D0odL0?03oool00`00
0000oooo0?ooo`1<0?ooo`T0odL00P3oool50?m701<0oooo2P3oA`1;0?ooo`00AP3oool30?m703d0
oooo0`3oA`020?ooo`D0odL0>@3oool00`000000oooo0?ooo`180?ooo`T0odL000<0oooo0?m7003o
A`000`3oA`0L0?ooo`P0odL0B@3oool004D0oooo0`3oA`110?ooo`<0odL000<0oooo0?m7003oA`00
0`3oA`0g0?ooo`030000003oool0oooo04D0oooo3@3oA`0U0?ooo`D0odL0B03oool004@0oooo0P3o
A`160?ooo`<0odL000<0oooo0?m7003oA`000`3oA`0d0?ooo`030000003oool0oooo0440oooo303o
A`0/0?ooo`D0odL0AP3oool00480oooo0`3oA`1:0?ooo`<0odL000<0oooo0?m7003oA`000`3oA`0a
0?ooo`800000@03oool;0?m70340oooo103oA`150?ooo`00@@3oool30?m704h0oooo2@3oA`0^0?oo
o`030000003oool0oooo03d0oooo2@3oA`0g0?ooo`@0odL0@`3oool00400oooo0`3oA`1B0?ooo`T0
odL0:`3oool00`000000oooo0?ooo`0j0?ooo`L0odL0?@3oool40?m70480oooo000o0?ooo`<0odL0
EP3oool80?m702T0oooo00<000000?ooo`3oool0=`3oool80?m70440oooo0`3oA`110?ooo`00?P3o
ool30?m705X0oooo203oA`0V0?ooo`030000003oool0oooo03<0oooo2@3oA`150?ooo`@0odL0?`3o
ool003d0oooo0`3oA`1N0?ooo`P0odL08`3oool00`000000oooo0?ooo`0`0?ooo`T0odL0BP3oool3
0?m703h0oooo000l0?ooo`<0odL0HP3oool80?m70200oooo00<000000?ooo`3oool0;@3oool90?m7
04h0oooo0`3oA`0m0?ooo`00>`3oool30?m706H0oooo203oA`0M0?ooo`030000003oool0oooo02X0
oooo2@3oA`1B0?ooo`<0odL0?03oool003/0oooo0P3oA`1Z0?ooo`P0odL06P3oool00`000000oooo
0?ooo`0V0?ooo`L0odL000<0oooo0?m7003oA`00EP3oool30?m703/0oooo000j0?ooo`<0odL0;P3o
oolB003o12`0oooo2P3oA`0F0?ooo`030000003oool0oooo02<0oooo2`3oA`1I0?ooo`<0odL0>P3o
ool003T0oooo0`3oA`0Y0?ooo`H00?l44P3oool6003o12T0oooo2`3oA`0B0?ooo`800000803oool8
0?m700040?ooo`3oA`00odL00?m705d0oooo0`3oA`0i0?ooo`00>03oool30?m702H0oooo1000o`@N
0?ooo`@00?l4:03oool20?m70080oooo203oA`0>0?ooo`030000003oool0oooo01T0oooo2@3oA`03
0?ooo`<0odL0:@3oool>003o12X0oooo0`3oA`0h0?ooo`00>03oool20?m702@0oooo0`00o`@20?oo
oaH00?l43P3oool5003o12D0oooo0`3oA`040?ooo`T0odL0203oool00`000000oooo0?ooo`0B0?oo
o``0odL00`3oool40?m702<0oooo2@00o`@>0?ooo`@00?l49`3oool30?m703L0oooo000g0?ooo`<0
odL08P3oool7003o11H0oooo1@00o`@>0?ooo`@00?l4903oool50?m700<0oooo4`3oA`080?ooo`h0
odL00`3oool50?m70240oooo1P00o`@K0?ooo`D00?l48P3oool30?m703L0oooo000g0?ooo`80odL0
8@3oool4003o1200oooo1000o`@>0?ooo`@00?l49@3oool70?m700030?ooo`3oA`00odL001`0odL0
0`3oool60?m70240oooo1@00o`@V0?ooo`<00?l4803oool30?m703H0oooo000f0?ooo`80odL0803o
ool4003o12H0oooo0`00o`@?0?ooo`@00?l4:03oool70?m70080oooo00<000000?ooo`3oool03`3o
ool70?m702@0oooo0`00o`@^0?ooo`800?l47`3oool30?m703D0oooo000e0?ooo`<0odL07P3oool4
003o12/0oooo1000o`@?0?ooo`D00?l4:P3ooolD0?m702L0oooo1000o`@c0?ooo`800?l47P3oool3
0?m703@0oooo000e0?ooo`80odL07@3oool4003o1340oooo1000o`@@0?ooo`@00?l4:03oool00`00
0000oooo0?ooo`0`0?ooo`H00?l42P3oool30039ob`0oooo0P00o`@M0?ooo`80odL0=03oool003@0
oooo0P3oA`0L0?ooo`@00?l4=`3oool2003o1180oooo1000o`@T0?ooo`030000003oool0oooo02`0
oooo1000o`@?0?ooo`D00<Wo;@3oool2003o11`0oooo0P3oA`0c0?ooo`00<`3oool30?m701/0oooo
0`00o`@k0?ooo`800?l4503oool4003o1200oooo00<000000?ooo`3oool0:@3oool3003o1180oooo
1`00bOl^0?ooo`800?l46P3oool20?m703<0oooo000c0?ooo`80odL06`3oool2003o13l0oooo0`00
o`@E0?ooo`H00?l46P3oool2000002H0oooo1000o`@E0?ooo`L00<Wo<03oool2003o11T0oooo0P3o
A`0b0?ooo`00<P3oool20?m701/0oooo00<00?l40?ooo`3oool0@P3oool4003o11L0oooo1P00o`@D
0?ooo`030000003oool0oooo01l0oooo1P00o`@I0?ooo`L00<Wo<P3oool00`00o`@0oooo0?ooo`0F
0?ooo`80odL0<P3oool00380oooo0P3oA`0I0?ooo`800?l4B@3oool2003o11/0oooo1`00o`@=0?oo
o`030000003oool0oooo01T0oooo1P00o`@P0?ooo`D00<Wo=03oool00`00o`@0oooo0?ooo`0F0?oo
o`80odL0<@3oool00340oooo0P3oA`0I0?ooo`800?l4C03oool2003o1200oooo1`00o`@60?ooo`03
0000003oool0oooo0180oooo1`00o`@U0?ooo`030039o`3oool00<Wo00800<Wo=P3oool00`00o`@0
oooo0?ooo`0F0?ooo`030?m7003oool0oooo02l0oooo000a0?ooo`80odL0603oool2003o14l0oooo
0P00o`@U0?oooa/00?l4:P3oool20039oc`0oooo00<00?l40?ooo`3oool05@3oool20?m70300oooo
000`0?ooo`80odL0603oool2003o1580oooo0P00o`@Y0?ooo`030000003oool0oooo03/0oooo00<0
0<Wo0?ooo`3oool05P3oool;003o11`0oooo00<00?l40?ooo`3oool05@3oool00`3oA`00oooo0?oo
o`0^0?ooo`00<03oool20?m701L0oooo0P00o`AE0?ooo`<00?l49P3oool00`000000oooo0?ooo`0i
0?ooo`800<Wo3`3ooolI003o11T0oooo00<00?l40?ooo`3oool0503oool20?m702l0oooo000_0?oo
o`80odL0603oool00`00o`@0oooo0?ooo`1G0?ooo`800?l46P3oool5000000D0oooo00<000000?oo
o`3oool0>03oool00`00bOl0oooo0?ooo`0<0?ooo`<00?l400<0oooo003o1000o`@00`00o`@C0?oo
o`@00?l45P3oool00`00o`@0oooo0?ooo`0D0?ooo`030?m7003oool0oooo02d0oooo000_0?ooo`80
odL05`3oool2003o15/0oooo0`00o`@I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0>03oool00`00bOl0oooo0?ooo`080?ooo`P00?l4703oool4003o11<0oooo00<00?l40?ooo`3o
ool04`3oool20?m702h0oooo000^0?ooo`80odL05`3oool2003o1280oooo5P00o`@W0?ooo`<00?l4
5P3oool00`000000oooo0?ooo`050?ooo`<00000=P3oool20039o`L0oooo1`00o`@T0?ooo`<00?l4
4@3oool00`00o`@0oooo0?ooo`0D0?ooo`030?m7003oool0oooo02`0oooo000^0?ooo`80odL05P3o
ool2003o1200oooo0`00o`@F0?ooo`H00?l4903oool4003o10X0oooo100000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0=@3oool00`00bOl0oooo0?ooo`040?ooo`D00?l43@3o
oolB003o10`0oooo0`00o`@@0?ooo`03003o103oool0oooo01<0oooo0P3oA`0]0?ooo`00;@3oool2
0?m701L0oooo00<00?l40?ooo`3oool0703oool3003o11l0oooo1000o`@T0?ooo`@00?l43P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo0P00bOl20?ooo`D00?l43@3oool5
003o1180oooo0`00o`@:0?ooo`<00?l4403oool00`00o`@0oooo0?ooo`0B0?ooo`80odL0;@3oool0
02d0oooo0P3oA`0F0?ooo`800?l46P3oool4003o12H0oooo1P00o`@R0?ooo`800?l42`3oool20000
00L0oooo00<000000?ooo`3oool0<P3oool00`00bOl00?l4003o1003003o10`0oooo1@00o`@J0?oo
o`800?l42P3oool3003o10l0oooo00<00?l40?ooo`3oool04P3oool20?m702`0oooo000]0?ooo`80
odL05@3oool2003o11T0oooo0P00o`@;0?ooo`/00<Wo6P3oool6003o11h0oooo0`00o`@A0?ooo`03
0000003oool0oooo0340oooo00<00<Wo003o1000o`@02`3oool5003o1240oooo1000o`@80?ooo`80
0?l43`3oool00`00o`@0oooo0?ooo`0A0?ooo`80odL0;03oool002`0oooo0P3oA`0E0?ooo`800?l4
603oool2003o10T0oooo1000bOl;0?ooo`L00<Wo6@3oool4003o11d0oooo1000o`@=0?ooo`030000
003oool0oooo02d0oooo0`00o`@00`00bOl00?l40?ooo`070?ooo`D00?l4:P3oool3003o10H0oooo
0`00o`@>0?ooo`03003o103oool0oooo0100oooo0`3oA`0[0?ooo`00;03oool20?m701D0oooo0P00
o`@G0?ooo`03003o103oool0oooo00D0oooo1000bOlF0?ooo`D00<Wo603oool3003o11h0oooo1@00
o`@80?ooo`030000003oool0oooo02P0oooo1`00o`@00`00bOl0oooo0?ooo`030?ooo`D00?l4<P3o
ool00`00o`@0oooo0?ooo`050?ooo`<00?l43@3oool00`00o`@0oooo0?ooo`0@0?ooo`80odL0:`3o
ool002/0oooo0P3oA`0E0?ooo`800?l45P3oool2003o10@0oooo1000bOlO0?ooo`<00<Wo603oool4
003o11l0oooo1000o`@40?ooo`030000003oool0oooo02<0oooo1@00o`@0103oool00?l4003o1000
o`@20?ooo`030039o`3oool00?l400@00?l4>03oool2003o10H0oooo00<00?l40?ooo`00o`@03@3o
ool00`00o`@0oooo0?ooo`0?0?ooo`<0odL0:P3oool002/0oooo0P3oA`0D0?ooo`800?l45P3oool0
0`00o`@0oooo0?ooo`020?ooo`800<Wo9P3oool30039oaT0oooo1000o`@O0?ooo`@00?l400<00000
0?ooo`3oool07@3oool6003o10<0oooo0`00o`@30?ooo`800<Wo0P00o`@L0?ooo`D00?l42`00bOlC
0?ooo`03003o103oool0oooo00@0oooo00<00?l40?ooo`00o`@0303oool00`00o`@0oooo0?ooo`0@
0?ooo`80odL0:P3oool002/0oooo0P3oA`0D0?ooo`800?l45@3oool01000o`@0oooo0?ooo`3oool2
0039ob/0oooo1000bOlI0?ooo`@00?l47`3ooolP003o10H0oooo0`00o`@40?ooo`03003o1000bOl0
oooo01T0oooo1000o`@70039o`/0oooo1@00bOl?0?ooo`03003o103oool0oooo00@0oooo00@00?l4
0?ooo`00o`@00?l42`3oool00`00o`@0oooo0?ooo`0?0?ooo`<0odL0:@3oool002X0oooo0P3oA`0D
0?ooo`800?l45@3oool01@00o`@0oooo0?ooo`3oool00<Wo0340oooo0`00bOlJ0?ooo`<00?l4703o
ool200000240oooo0`00o`@40?ooo`<00?l400<00<Wo0?ooo`3oool0503oool3003o10H00<Wo5`3o
ool30039o`03003o103oool0oooo00X0oooo0P00o`@50?ooo`03003o103oool00?l400/0oooo00<0
0?l40?ooo`3oool0403oool20?m702T0oooo000Z0?ooo`80odL04`3oool2003o11@0oooo0P00o`@3
0?ooo`030039o`3oool0oooo03<0oooo0`00bOlJ0?ooo`@00?l4603oool00`000000oooo0?ooo`0L
0?ooo`@00?l400<0oooo003o1000o`@01000o`@20?ooo`030039o`3oool0oooo0100oooo0`00o`@5
0039ob00oooo0P00bOl00`00o`@0oooo0?ooo`0:0?ooo`03003o103oool0oooo00<0oooo00<00?l4
0?ooo`00o`@02`3oool00`00o`@0oooo0?ooo`0?0?ooo`80odL0:@3oool002X0oooo0P3oA`0C0?oo
o`800?l44`3oool01000o`@0oooo0?ooo`3oool20039ocT0oooo0P00bOlL0?ooo`H00?l44P3oool0
0`000000oooo0?ooo`0G0?ooo`X00?l41`3oool00`00bOl0oooo0?ooo`0?0?ooo`800?l40`00bOlW
0?ooo`<00<Wo2`3oool00`00o`@0oooo0?ooo`030?ooo`03003o103oool00?l400X0oooo00<00?l4
0?ooo`3oool0403oool20?m702P0oooo000Y0?ooo`80odL04`3oool2003o11<0oooo00D00?l40?oo
o`3oool0oooo0039o`0G0?oooa/00<Wo00<00?l40?ooo`3oool0203oool20039ob00oooo1P00o`@<
0?ooo`030000003oool0oooo01D0oooo1P00o`@<0?ooo`030039o`3oool0oooo00`0oooo0P00o`@4
0039obd0oooo0P00bOl:0?ooo`800?l4103oool00`00o`@0oooo003o100:0?ooo`03003o103oool0
oooo00l0oooo0P3oA`0X0?ooo`00:@3oool20?m701<0oooo0P00o`@B0?ooo`05003o103oool0oooo
0?ooo`00bOl02@3oool50039o`H0oooo1000bOl20?ooo`D00?l4503oool50039o`P00?l40P00bOlT
0?ooo`H00?l41P3oool00`000000oooo0?ooo`0?0?ooo`H00?l44@3oool00`00bOl0oooo0?ooo`09
0?ooo`03003o1000bOl00<Wo00<00<Wo<`3oool20039o`X0oooo00<00?l40?ooo`3oool00P3oool0
0`00o`@0oooo003o10090?ooo`03003o103oool0oooo00l0oooo0`3oA`0W0?ooo`00:@3oool20?m7
0180oooo0P00o`@B0?ooo`05003o103oool0oooo0?ooo`00bOl0103oool60039o`D0oooo1P00bOl2
0?ooo`@00?l47P3oool40039o`H0oooo0`00bOl3003o12@0oooo6P00o`@D0?ooo`030039o`3oool0
oooo00P0oooo0`00bOlM0?oooa400?l4303oool00`00bOl00?l40?ooo`080?ooo`03003o103oool0
oooo0080oooo00<00?l40?ooo`00o`@0203oool00`00o`@0oooo0?ooo`0@0?ooo`80odL09`3oool0
02P0oooo0P3oA`0C0?ooo`800?l44@3oool00`00o`@0oooo0?ooo`020039o`030?ooo`00bOl00<Wo
00800<Wo3@3oool20039o`030?ooo`00bOl00<Wo00800<Wo203oool00`00o`@00<Wo0039o`040039
o`l00?l41`3oool50039o`@0oooo1000bOl6003o12<0oooo00<000000?ooo`3oool01P3oool5003o
11T0oooo00<00<Wo0?ooo`3oool01P3oool30039oa/0oooo1@00o`@60?ooo`<00?l4203oool3003o
10X0oooo0P00bOl00`00o`@0oooo0?ooo`060?ooo`03003o103oool0oooo0080oooo00<00?l40?oo
o`00o`@0203oool00`00o`@0oooo0?ooo`0?0?ooo`80odL09`3oool002P0oooo0P3oA`0B0?ooo`80
0?l44P3oool01000o`@0oooo0039o`3oool20039o`l0oooo0P00bOl20?ooo`800?l46000bOl90?oo
o`D00?l41`3oool50039o`<0oooo1000bOl20?ooo`H00?l47@3oool00`000000oooo0?ooo`06003o
11d0oooo00<00<Wo0?ooo`3oool0103oool30039oaX0oooo1000o`@20?ooo`T00?l40`3oool8003o
10<0oooo0P00o`@:0?ooo`030039o`00o`@0oooo00H0oooo00<00?l40?ooo`3oool00P3oool00`00
o`@0oooo003o10080?ooo`03003o103oool0oooo00l0oooo0`3oA`0V0?ooo`00:03oool20?m70180
oooo0P00o`@A0?ooo`03003o103oool00<Wo00800<Wo403oool00`00bOl0oooo0?ooo`02003o10/0
0<Wo2P3oool:0039o`T0oooo1000o`@80?ooo`@00<Wo0`3oool20039o`H0oooo8000o`@Q0?ooo`80
0<Wo0`3oool40039oaT0oooo1000o`@20?ooo`@00?l4503oool4003o10040?ooo`00o`@00?l4003o
10P0oooo00<00<Wo003o103oool01P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool00?l4
00P0oooo00<00?l40?ooo`3oool03`3oool20?m702H0oooo000X0?ooo`030?m7003oool0oooo0100
oooo00<00?l40?ooo`00o`@0403oool01000o`@0oooo0039o`00bOl@0?ooo`800<Wo00<0oooo003o
1000bOl01000bOl90?ooo`<00<Wo3@3oool80039o`T0oooo1000o`@80?ooo`@00<Wo00<0oooo0039
o`00bOl08@3oool00`000000oooo0?ooo`0P0?ooo`H00<Wo6@3oool4003o10<0oooo0`00o`@@0?oo
o`<00<Wo2@3oool3003o10030?ooo`00o`@00?l400L0oooo0P00bOl70?ooo`07003o103oool0oooo
0?ooo`00o`@0oooo003o10090?ooo`03003o103oool0oooo00h0oooo0P3oA`0V0?ooo`009`3oool2
0?m70180oooo0P00o`@@0?ooo`03003o103oool00<Wo0100oooo0P00bOl01@3oool00?l40039o`00
bOl0oooo00800?l43P3oool30039o`l0oooo1P00bOl:0?ooo`L00?l41@3oool50039oal0oooo0P00
000N0?ooo`@00<Wo00<00?l40?ooo`3oool06@3oool2003o10D0oooo0P00o`@70?ooo``00<Wo0`3o
ool70039o`D0oooo0P00o`@00`3oool00?l4003o10070?ooo`030039o`3oool0oooo00D0oooo00L0
0?l40?ooo`3oool0oooo003o103oool00?l400P0oooo00<00?l40?ooo`3oool03P3oool30?m702D0
oooo000W0?ooo`80odL04@3oool00`00o`@0oooo003o100@0?ooo`800<Wo3`3oool20039o`800?l4
0P00bOl9003o10d0oooo0P00bOl@0?ooo`H00<Wo3P3oool5003o10D0oooo1000bOlK0?ooo`030000
003oool0oooo01T0oooo1000bOl00`00o`@00<Wo0?ooo`0J0?ooo`<00?l4103oool3003o10D0oooo
1000bOlF0?ooo`800<Wo1@3oool01000o`@0oooo0?ooo`00o`@70?ooo`030039o`3oool0oooo00@0
oooo00D00?l40?ooo`3oool0oooo003o10020?ooo`03003o103oool0oooo00H0oooo00<00?l40?oo
o`3oool03P3oool20?m702D0oooo000W0?ooo`030?m7003oool0oooo0100oooo0P00o`@@0?ooo`03
0039o`3oool00<Wo00d0oooo00@00?l40039o`00o`@00?l40P00bOl5003o10X00<Wo2`3oool20039
oa40oooo1P00bOl@0?ooo`@00?l40`3oool60039oaL0oooo00<000000?ooo`3oool04`3oool60039
o`800?l40P3oool00`00bOl0oooo0?ooo`0H0?ooo`800?l40`3oool4003o10030?ooo`00bOl00<Wo
00D00<Wo703oool40039o`80oooo00<00?l40?ooo`3oool00P00o`@60?ooo`030039o`3oool0oooo
00@0oooo00L00?l40?ooo`3oool0oooo003o103oool00?l400P0oooo00<00?l40?ooo`3oool03P3o
ool20?m702D0oooo000W0?ooo`030?m7003oool0oooo00l0oooo00<00?l40?ooo`00o`@03`3oool0
0`00bOl0oooo0039o`0;0?ooo`800?l40P00bOl01@00o`@00<Wo0039o`00bOl00?l400D00<Wo0P3o
ool5003o1080oooo00<00?l40039o`00bOl01000bOl70?ooo`800<Wo4P3oool60039oa40oooo1000
o`@01@3oool00<Wo0039o`00bOl0oooo00H00<Wo4@3oool00`000000oooo0?ooo`0<0?ooo`L00<Wo
0`00o`@60?ooo`030039o`3oool0oooo01H0oooo0`00o`@30?ooo`800?l400<0oooo0039o`00bOl0
0P00bOlW0?ooo`<00<Wo0P00o`@20?ooo`03003o103oool0oooo00<0oooo00<00<Wo003o103oool0
1@3oool01000o`@0oooo0?ooo`00o`@20?ooo`03003o103oool0oooo00D0oooo00<00?l40?ooo`3o
ool03P3oool30?m702@0oooo000V0?ooo`80odL04@3oool00`00o`@0oooo003o100=0?ooo`800<Wo
00<00?l40039o`3oool02@3oool2003o10040?ooo`00bOl00?l4003o10800<Wo00<0oooo0039o`00
bOl00`3oool4003o10D0oooo1000o`@01@3oool00?l4003o1000o`@0oooo00@00<Wo1@3oool20039
oa<0oooo1P00bOlB0?ooo`@00?l41000bOl30?ooob000<Wo1000o`@;0?ooo`030039o`3oool0oooo
01D0oooo0P00o`@40?ooo`800?l400<0oooo0039o`00bOl0;P3oool00`00bOl0oooo003o10020?oo
o`03003o103oool0oooo00<0oooo00<00<Wo0?ooo`3oool01@3oool01000o`@0oooo0?ooo`00o`@2
0?ooo`03003o103oool0oooo00D0oooo00<00?l40?ooo`3oool03P3oool20?m702@0oooo000V0?oo
o`80odL04@3oool2003o10d0oooo00@00<Wo0?ooo`00o`@00<Wo2@3oool2003o10050?ooo`00o`@0
0<Wo0?ooo`00o`@01000bOl90?ooo`<00?l41P3oool3003o10030?ooo`00o`@00?l400<0oooo0P00
bOl50?ooo`800<Wo503oool60039oaD0oooo0P00o`@20039o`T00?l42@3oool00`000000oooo0?oo
o`0;003o10l0oooo00<00<Wo0?ooo`3oool0503oool2003o10@0oooo00<00?l40039o`00bOl00P00
bOla0?ooo`800<Wo0`00o`@60?ooo`030039o`3oool0oooo00@0oooo00L00?l40?ooo`3oool0oooo
003o103oool00?l400L0oooo00<00?l40?ooo`3oool03P3oool20?m702@0oooo000V0?ooo`030?m7
003oool0oooo00l0oooo00<00?l40?ooo`00o`@0303oool01@00bOl0oooo0?ooo`00o`@00<Wo00L0
oooo1@00o`@00`00bOl0oooo003o10030039o`H00?l4203oool2003o10L0oooo0P00o`@00`3oool0
0?l4003o10030?ooo`<00<Wo103oool20039oaD0oooo1P00bOlF0?ooo`800<Wo1`3oool<003o11T0
oooo00<00<Wo0?ooo`3oool04`3oool2003o10<0oooo1000bOlg0?ooo`040039o`3oool00?l4003o
10H0oooo00<00<Wo0?ooo`3oool0103oool01000o`@0oooo0?ooo`00o`@20?ooo`03003o103oool0
oooo00@0oooo00<00?l40?ooo`3oool03P3oool20?m702@0oooo000U0?ooo`80odL04@3oool2003o
10d0oooo00@00<Wo0?ooo`00o`@00<Wo1P3oool2003o10050?ooo`00o`@00?l40?ooo`00bOl00P00
o`@20039o`03003o103oool0oooo00D0oooo1000o`@60?ooo`800?l41`3oool2003o10030?ooo`00
o`@00?l400@0oooo0P00bOl40?ooo`030039o`3oool0oooo01D0oooo0P00bOl00`3oool00<Wo0039
o`0F0?ooo`800<Wo3P3oool00`000000oooo0?ooo`0G0?ooo`800<Wo4`3oool3003o1080oooo0`00
bOll0?ooo`030039o`3oool00?l400800?l4103oool00`00bOl00?l40?ooo`040?ooo`07003o103o
ool0oooo0?ooo`00o`@0oooo003o10070?ooo`03003o103oool0oooo00d0oooo0`3oA`0S0?ooo`00
9@3oool20?m70140oooo0P00o`@<0?ooo`050039o`3oool00?l40?ooo`00bOl0103oool2003o1080
oooo0`00o`@01P00bOl0oooo003o1000bOl0oooo003o10`0oooo0P00o`@60?ooo`800?l41`3oool2
003o10030?ooo`00o`@00?l400@0oooo0P00bOl30?ooo`800<Wo5`3oool20039o`030?ooo`00bOl0
0<Wo01H0oooo1000bOl:0?ooo`030000003oool0oooo01H0oooo00<00<Wo0?ooo`3oool04@3oool2
003o10030?ooo`00bOl00<Wo00800<Wo8`3oool:0039oa<0oooo0P00bOl20?ooo`03003o103oool0
oooo0080oooo00<00<Wo0?ooo`3oool0103oool01000o`@0oooo0?ooo`00o`@20?ooo`03003o103o
ool0oooo00@0oooo00<00?l40?ooo`3oool03P3oool20?m702<0oooo000U0?ooo`80odL0403oool2
003o10d0oooo00@00<Wo0?ooo`00o`@00<Wo103oool00`00o`@0oooo0?ooo`04003o10060039o`3o
ool00<Wo0039o`3oool00?l43`3oool3003o10D0oooo0P00o`@70?ooo`800?l400<0oooo003o1000
o`@0103oool20039o`<0oooo0P00bOlG0?ooo`800<Wo00@0oooo0039o`00bOl00<Wo5`3oool50039
o`D0oooo00<000000?ooo`3oool05@3oool00`00bOl0oooo0?ooo`0@0?ooo`D00<Wo00<0oooo003o
103oool07@3oool70039o`X0oooo0`00bOlB0?ooo`040039o`3oool0oooo003o10<0oooo00<00<Wo
003o103oool01@3oool01P00o`@0oooo0?ooo`00o`@0oooo003o10L0oooo00<00?l40?ooo`3oool0
3@3oool20?m702<0oooo000U0?ooo`030?m7003oool0oooo00l0oooo0P00o`@<0?ooo`050039o`3o
ool00?l40?ooo`00bOl00`3oool00`00o`@0oooo0?ooo`03003o10030?ooo`00bOl0oooo00800<Wo
00<0oooo003o103oool04P3oool2003o10D0oooo0P00o`@70?ooo`800?l400<0oooo003o103oool0
103oool20039o`<0oooo0P00bOlG0?ooo`<00<Wo00<0oooo0039o`00bOl06P3oool30039o`80oooo
0P00000E0?ooo`030039o`3oool0oooo00`0oooo1@00bOl40?ooo`800?l45`3oool80039o`/0oooo
0`00bOl60?ooo`@00<Wo3`3oool00`00bOl00?l4003o10040?ooo`030039o`00o`@0oooo00@0oooo
00@00?l40?ooo`3oool00?l40P3oool00`00o`@0oooo0?ooo`040?ooo`03003o103oool0oooo00d0
oooo0P3oA`0S0?ooo`00903oool20?m70100oooo00<00?l40?ooo`00o`@02`3oool01@00bOl0oooo
0?ooo`00o`@00<Wo0080oooo0P00o`@20?ooo`800?l40P3oool01P00bOl0oooo0039o`00bOl0oooo
003o11H0oooo0P00o`@50?ooo`800?l41`3oool3003o10H0oooo00<00<Wo0?ooo`3oool00P3oool0
0`00bOl0oooo0?ooo`0G0?ooo`800<Wo00<0oooo0039o`00bOl06`3oool40039oa@0oooo00<00<Wo
0?ooo`3oool0203oool50039o`80oooo0P00o`@30?ooo`800?l45P3oool30039o`P0oooo2`00bOl3
0?ooo`H00<Wo103oool30039o`d0oooo00<00<Wo003o1000o`@0103oool00`00bOl0oooo0?ooo`04
0?ooo`06003o103oool0oooo003o103oool00?l41P3oool00`00o`@0oooo0?ooo`0=0?ooo`80odL0
8`3oool002@0oooo0P3oA`0@0?ooo`800?l42`3oool01@00bOl0oooo0?ooo`00o`@00<Wo0080oooo
00@00?l40?ooo`3oool0oooo0P00o`@30?ooo`<00<Wo00<0oooo003o103oool0603oool2003o10D0
oooo00@00?l40?ooo`3oool00<Wo1@3oool2003o10H0oooo0P00bOl30?ooo`800<Wo6@3oool20039
o`040?ooo`00bOl00<Wo0039oaX0oooo00<000000?ooo`00bOl01@00bOl=0?ooo`030039o`3oool0
oooo00@0oooo1@00bOl50?ooo`800?l40`3oool2003o11H0oooo0P00bOl80?ooo`<00<Wo503oool6
0039o`030?ooo`00bOl00<Wo00`0oooo00<00<Wo0?ooo`00o`@0103oool00`00bOl0oooo0?ooo`03
0?ooo`04003o103oool0oooo003o1080oooo00<00?l40?ooo`3oool0103oool00`00o`@0oooo0?oo
o`0=0?ooo`80odL08P3oool002@0oooo0P3oA`0@0?ooo`800?l42`3oool01`00bOl0oooo0?ooo`00
o`@00<Wo0?ooo`00o`@00P3oool4003o1080oooo0`00bOl00`3oool00?l40?ooo`0K0?ooo`800?l4
103oool00`00o`@00<Wo0?ooo`060?ooo`<00?l41P3oool20039o`<0oooo00<00<Wo0?ooo`3oool0
603oool30039o`030?ooo`00bOl00<Wo00800<Wo5P3oool00`000000oooo0?ooo`050?oooa@00<Wo
203oool2003o10<0oooo0P00o`@D0?ooo`@00<Wo1P3oool40039oad0oooo0P00bOl00`3oool00<Wo
0039o`0;0?ooo`030039o`00o`@0oooo00<0oooo00<00<Wo0?ooo`3oool0103oool01P00o`@0oooo
0?ooo`00o`@0oooo003o10H0oooo00<00?l40?ooo`3oool03@3oool20?m70280oooo000T0?ooo`80
odL03`3oool00`00o`@0oooo003o100:0?ooo`070039o`3oool0oooo003o1000bOl0oooo003o1002
0?ooo`04003o103oool00?l4003o10<0oooo0P00bOl00`3oool00?l40?ooo`0N0?ooo`800?l400D0
oooo0039o`00bOl00<Wo003o10080?ooo`800?l41`3oool20039o`80oooo0P00bOlK0?ooo`800<Wo
0`3oool30039oa<0oooo00<000000?ooo`3oool03`3oool00`00bOl0oooo0?ooo`0=0?ooo`800?l4
0`3oool2003o1180oooo1000bOl60?ooo`@00<Wo8`3oool20039o`030?ooo`00bOl0oooo00T0oooo
00<00?l40039o`00o`@0103oool00`00bOl0oooo0?ooo`030?ooo`06003o103oool0oooo003o103o
ool00?l41P3oool00`00o`@0oooo0?ooo`0=0?ooo`80odL08P3oool002<0oooo0P3oA`0@0?ooo`03
003o103oool00?l400T0oooo00/00<Wo0?ooo`3oool0oooo003o1000bOl0oooo003o103oool00?l4
0?ooo`02003o10<0oooo0`00bOl00`3oool00?l40?ooo`0P0?ooo`<00<Wo0P3oool2003o10L0oooo
0`00o`@70?ooo`050039o`3oool0oooo0?ooo`00bOl0703oool20039o`@0oooo1000bOl?0?ooo`03
0000003oool0oooo00d0oooo0P00bOl>0?ooo`800?l40`3oool2003o10l0oooo1@00bOl70?ooo`<0
0<Wo:@3oool40039o`T0oooo00<00?l40039o`3oool00`3oool00`00o`@00<Wo0?ooo`040?ooo`03
003o103oool00?l40080oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo0?ooo`0=0?ooo`80
odL08P3oool002<0oooo0P3oA`0@0?ooo`800?l42@3oool02`00bOl0oooo0?ooo`3oool00?l40039
o`3oool00?l40?ooo`00o`@0oooo00800?l4103oool20039o`030?ooo`00o`@0oooo0200oooo1000
bOl40?ooo`03003o103oool0oooo00D0oooo0`00o`@70?ooo`800<Wo0P3oool20039oa`0oooo0`00
bOl50?ooo`<00<Wo303oool00`000000oooo0?ooo`0<0?ooo`030039o`3oool0oooo00`0oooo0P00
o`@30?ooo`800?l43P3oool30039o`X0oooo0P00bOl^0?ooo`030039o`3oool00<Wo00T0oooo00<0
0?l40039o`3oool00`3oool00`00bOl0oooo0?ooo`030?ooo`06003o103oool0oooo003o103oool0
0?l41P3oool00`00o`@0oooo0?ooo`0=0?ooo`030?m7003oool0oooo0200oooo000S0?ooo`80odL0
3`3oool00`00o`@0oooo003o10090?ooo`070039o`3oool0oooo0?ooo`00o`@00<Wo003o10020?oo
o`03003o103oool00?l400@0oooo0P00bOl00`3oool00?l40?ooo`0O0?ooo`D00<Wo00<0oooo003o
103oool00`3oool00`00o`@0oooo0?ooo`060?ooo`800?l4203oool01@00bOl0oooo0?ooo`3oool0
0<Wo01h0oooo0P00bOl60?ooo`<00<Wo2@3oool00`000000oooo0?ooo`0;0?ooo`030039o`3oool0
oooo00/0oooo0P00o`@40?ooo`03003o103oool0oooo00`0oooo0P00bOl:0?ooo`<00<Wo<@3oool3
0039o`P0oooo0P00o`@01P00bOl0oooo0?ooo`3oool00?l40039o`@0oooo00@00?l40?ooo`3oool0
0?l40P3oool00`00o`@0oooo0?ooo`030?ooo`03003o103oool0oooo00d0oooo0P3oA`0Q0?ooo`00
8`3oool20?m700l0oooo00<00?l40?ooo`00o`@0203oool03000bOl0oooo0?ooo`3oool00?l40039
o`3oool00?l40?ooo`00o`@0oooo003o10@0oooo0P00bOl20?ooo`03003o103oool0oooo01d0oooo
1P00bOl20?ooo`800?l40`3oool00`00o`@0oooo0?ooo`060?ooo`800?l4203oool01000bOl0oooo
0?ooo`3oool20039oah0oooo0P00bOl70?ooo`<00<Wo1P3oool00`000000oooo0?ooo`0:0?ooo`03
0039o`3oool0oooo00T0oooo0`00o`@40?ooo`800?l4303oool30039o`P0oooo1000bOlf0?ooo`<0
0<Wo1`3oool00`00o`@00<Wo0?ooo`030?ooo`030039o`3oool0oooo00<0oooo00H00?l40?ooo`3o
ool00?l40?ooo`00o`@50?ooo`03003o103oool0oooo00d0oooo0P3oA`0Q0?ooo`008P3oool30?m7
00l0oooo0P00o`@90?ooo`0:0039o`3oool0oooo0?ooo`00o`@00<Wo003o103oool00?l40?ooo`80
0?l4103oool20039o`030?ooo`00o`@0oooo01h0oooo1`00bOl40?ooo`05003o103oool0oooo0?oo
o`00o`@0203oool2003o10P0oooo00<00<Wo0?ooo`3oool00P3oool00`00bOl0oooo0?ooo`0M0?oo
o`<00<Wo1`3oool30039o`<0oooo0P00000:0?ooo`030039o`3oool0oooo00L0oooo0`00o`@60?oo
o`03003o103oool0oooo00P0oooo1000bOl70?ooo`@00<Wo>`3oool20039o`L0oooo0P00o`@01@00
bOl0oooo0?ooo`3oool00<Wo00D0oooo00@00?l40?ooo`3oool00?l40P3oool00`00o`@0oooo0?oo
o`020?ooo`03003o103oool0oooo00d0oooo0P3oA`0Q0?ooo`008P3oool30?m700h0oooo00<00?l4
0?ooo`00o`@0203oool00`00bOl0oooo0?ooo`020?ooo`040039o`3oool00?l40?ooo`<00?l4103o
ool20039o`030?ooo`00o`@0oooo01d0oooo4000bOl20?ooo`03003o103oool0oooo00D0oooo00<0
0?l40?ooo`00o`@0203oool00`00bOl0oooo0?ooo`020?ooo`800<Wo803oool40039o`H0oooo1000
bOl90?ooo`800<Wo203oool2003o10L0oooo0P00o`@60?ooo`D00<Wo1`3oool40039obD0oooo2@00
bOlB0?ooo`800<Wo1`3oool00`00o`@00<Wo0?ooo`030?ooo`030039o`3oool0oooo0080oooo00@0
0?l40?ooo`3oool00?l40P3oool00`00o`@0oooo0?ooo`030?ooo`03003o103oool0oooo00`0oooo
0P3oA`0Q0?ooo`008P3oool20?m700l0oooo00<00?l40?ooo`00o`@0203oool02P00bOl0oooo0?oo
o`3oool00?l40039o`00o`@0oooo003o103oool2003o10<0oooo0`00bOl00`3oool00?l40?ooo`07
0?ooo`800?l41`00bOl4003o10P0oooo4000bOl00`00o`@00<Wo0039o`030039o`H0oooo00@00?l4
0?ooo`00o`@00?l41`3oool20039o`@0oooo0P00bOlR0?ooo`<00<Wo1P3oool00`0000000<Wo0039
o`070039o`P0oooo0P00o`@70?ooo`03003o1000bOl00<Wo00L00<Wo203oool40039ob<0oooo1P00
bOl90?ooo`<00<Wo403oool30039o`D0oooo0P00o`@01@00bOl0oooo0?ooo`3oool00<Wo00D0oooo
00H00?l40?ooo`3oool00?l40?ooo`00o`@50?ooo`03003o103oool0oooo00`0oooo0`3oA`0P0?oo
o`008P3oool20?m700l0oooo00<00?l40?ooo`00o`@01`3oool00`00bOl0oooo0?ooo`020?ooo`04
003o1000bOl0oooo0?ooo`<00?l4103oool20039o`030?ooo`00o`@0oooo00D0oooo1@00bOl70?oo
o`<00<Wo00<0oooo003o1000o`@00P00o`@30?oooa<00<Wo0`3oool00`00o`@00<Wo0039o`040039
o`030?ooo`00o`@0oooo00800?l4203oool00`00bOl0oooo0?ooo`030?ooo`030039o`3oool0oooo
0280oooo1000bOl20?ooo`030000003oool0oooo00@0oooo0P00bOl00`3oool00<Wo0039o`0@0039
o`l0oooo0P00bOlU0?ooo`800<Wo4P3oool30039o`h0oooo0P00bOl60?ooo`800?l400D00<Wo0?oo
o`3oool0oooo0039o`040?ooo`06003o103oool0oooo003o103oool00?l41@3oool00`00o`@0oooo
0?ooo`0=0?ooo`80odL0803oool00280oooo0P3oA`0?0?ooo`800?l4203oool00`00bOl0oooo0?oo
o`020?ooo`060039o`00o`@0oooo003o103oool00?l4103oool30039o`030?ooo`00o`@0oooo00<0
oooo0P00bOl00`00o`@0oooo0?ooo`0<0?ooo`800<Wo0`3oool00`00o`@00<Wo0039o`080039o`/0
oooo1P00bOl40?ooo`D00<Wo2@3oool00`00bOl0oooo0?ooo`030?ooo`800<Wo9P3oool40039o`<0
oooo0P00bOl70?ooo`800?l41`3oool2003o10l0oooo0`00bOlT0?ooo`<00<Wo5`3oool20039o`d0
oooo0P00bOl50?ooo`800?l400D00<Wo0?ooo`3oool0oooo0039o`040?ooo`07003o103oool0oooo
0?ooo`00o`@0oooo003o10040?ooo`03003o103oool0oooo00d0oooo0P3oA`0P0?ooo`008P3oool2
0?m700l0oooo0P00o`@70?ooo`030039o`3oool0oooo0080oooo00D00?l40039o`3oool00?l40?oo
o`02003o10@0oooo0P00bOl00`3oool00?l40?ooo`020?ooo`800<Wo00<00?l40?ooo`3oool0403o
ool70039o`03003o1000bOl00<Wo0100oooo00<00?l40?ooo`3oool00P3oool60039o`030?ooo`00
o`@0oooo00800<Wo203oool00`00bOl0oooo0?ooo`040?ooo`800<Wo9P3oool00`000000oooo0039
o`050039o`@0oooo0P00o`@70?ooo`800?l4203oool90039obD0oooo0P00bOlL0?ooo`030039o`3o
ool0oooo00/0oooo0P00bOl50?ooo`800?l400D00<Wo0?ooo`3oool0oooo0039o`030?ooo`07003o
103oool0oooo0?ooo`00o`@0oooo003o10050?ooo`03003o103oool0oooo00`0oooo0P3oA`0P0?oo
o`008@3oool30?m700h0oooo00<00?l40?ooo`00o`@01`3oool00`00bOl0oooo0?ooo`020?ooo`06
003o1000bOl0oooo003o103oool00?l4103oool30039o`060?ooo`00o`@0oooo0?ooo`00bOl00?l4
203oool30039o``0oooo0P00bOl00`3oool00<Wo0039o`02003o1140oooo0P00o`@30?ooo`03003o
103oool0oooo0080oooo1000bOl00`00o`@00<Wo0039o`070?ooo`030039o`3oool0oooo00D0oooo
0`00bOlS0?ooo`0300000000bOl00<Wo00D0oooo5`00bOl/0?ooo`800<Wo1@3ooolC0039o`L0oooo
00<00<Wo0?ooo`3oool02`3oool20039o`@0oooo0P00o`@01@00bOl0oooo0?ooo`3oool00<Wo00@0
oooo00H00?l40?ooo`3oool00?l40?ooo`00o`@50?ooo`03003o103oool0oooo00`0oooo0P3oA`0P
0?ooo`008@3oool20?m700l0oooo0P00o`@70?ooo`030039o`3oool0oooo00<0oooo00@00<Wo0?oo
o`00o`@0oooo0P00o`@40?ooo`800<Wo00D0oooo003o103oool0oooo0039o`070?ooo`<00<Wo0`3o
ool50039o`P0oooo0`00bOl30?ooo`800?l44@3oool01@00o`@0oooo0?ooo`3oool00?l400H0oooo
00<00?l40039o`00bOl00`00bOl60?ooo`030039o`3oool0oooo00L0oooo0P00bOlP0?ooo`800<Wo
1`3oool2003o10L0oooo0P00o`@g0?ooo`P00<Wo1`3oool30039o`<0oooo2P00bOl40?ooo`030039
o`3oool0oooo00X0oooo0P00bOl50?ooo`800?l400D00<Wo0?ooo`3oool0oooo0039o`030?ooo`06
003o103oool0oooo003o103oool00?l41@3oool00`00o`@0oooo0?ooo`0<0?ooo`<0odL07`3oool0
0240oooo0P3oA`0?0?ooo`800?l41`3oool00`00bOl0oooo0?ooo`020?ooo`06003o1000bOl0oooo
003o103oool00?l4103oool01`00bOl0oooo0039o`3oool00?l40?ooo`00bOl01P3oool20039o`/0
oooo1000bOl20?ooo`800<Wo0`3oool20039o`<0oooo0P00o`@@0?ooo`05003o103oool0oooo0?oo
o`00o`@01`3oool2003o10@00<Wo1@3oool00`00bOl0oooo0?ooo`080?ooo`<00<Wo2@3oool20000
00@0oooo0P0000040?ooo`800000103oool20039o`030?ooo`000000oooo00<0oooo0`00o`@70?oo
o`800?l4=`3oool30039o`D0oooo1`00o`@20039o`D00?l41`3oool20039o`80oooo0P00bOl30?oo
o`030039o`3oool0oooo00X0oooo0P00bOl40?ooo`800?l400D00<Wo0?ooo`3oool0oooo0039o`03
0?ooo`04003o103oool0oooo003o1080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?oo
o`0=0?ooo`80odL07`3oool00240oooo0P3oA`0?0?ooo`800?l41`3oool00`00bOl0oooo0?ooo`02
0?ooo`03003o1000bOl00?l40080oooo00<00?l40?ooo`3oool00P3oool20039o`040?ooo`00o`@0
0<Wo0039o`D0oooo0P00bOlA0?ooo`800<Wo1`3oool00`00bOl0oooo0?ooo`020?ooo`800?l43`3o
ool01@00o`@0oooo0?ooo`3oool00?l400L0oooo0P00o`@00`3oool00<Wo0039o`020039o`@0oooo
00<00<Wo0?ooo`3oool02P3oool20039o`H0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030039o`<0oooo00<00000003o1000o`@00P00o`@80?ooo`800?l4=@3oool40039
o`030?ooo`00o`@00?l400D00?l41@3oool20039o`L0oooo1@00o`@40?ooo`800<Wo0P3oool20039
o`80oooo0P00bOl;0?ooo`800<Wo103oool2003o10050039o`3oool0oooo003o1000bOl00`3oool0
1P00o`@0oooo0?ooo`00o`@0oooo003o10@0oooo00<00?l40?ooo`3oool03@3oool20?m701l0oooo
000Q0?ooo`80odL03`3oool2003o10H0oooo00<00<Wo0?ooo`3oool00`3oool01@00bOl0oooo003o
103oool00?l400@0oooo00H00<Wo0?ooo`00bOl0oooo0039o`00o`@50?ooo`030039o`3oool0oooo
0100oooo00<00<Wo0?ooo`3oool00P00bOl60?ooo`030039o`3oool0oooo00<0oooo0P00o`@>0?oo
o`05003o103oool0oooo0?ooo`00o`@01`3oool2003o1080oooo1000bOl30?ooo`030039o`3oool0
oooo00/0oooo0`00bOl30?ooo`040000003oool0oooo000000@0oooo0P00o`@20?ooo`@00<Wo1@3o
ool2003o108000002@3oool00`00o`@0oooo0?ooo`0a0?ooo`@00<Wo00<0oooo0039o`00o`@00P00
o`@:0?ooo`800<Wo3P3oool3003o10<0oooo0P00bOl20?ooo`800<Wo00<0oooo0039o`3oool02P3o
ool20039o`@0oooo0P00o`@01@00bOl0oooo0?ooo`3oool00<Wo00<0oooo00H00?l40?ooo`3oool0
0?l40?ooo`00o`@50?ooo`03003o103oool0oooo00`0oooo0P3oA`0O0?ooo`008@3oool00`3oA`00
oooo0?ooo`0=0?ooo`800?l41`3oool00`00bOl0oooo0?ooo`020?ooo`03003o1000bOl00?l40080
oooo00<00?l40?ooo`3oool00P3oool20039o`03003o1000bOl00?l400@0oooo0P00bOlB0?ooo`03
0039o`3oool0oooo00<0oooo00<00<Wo0?ooo`3oool0103oool00`00bOl0oooo0?ooo`040?ooo`80
0?l43@3oool01@00o`@0oooo0?ooo`3oool00?l400H0oooo00<00?l40?ooo`00o`@00`3oool50039
o`030?ooo`00bOl00<Wo00/0oooo0`00000?0039o`030?ooo`000000000000@0oooo0P00o`@00`3o
ool000000?ooo`080?ooo`800?l4<03oool40039o`80oooo0P00o`@00`00bOl0oooo0?ooo`0;0?oo
o`030039o`3oool0oooo0140oooo0P00o`@30?ooo`800<Wo0P3oool00`00bOl0oooo0039o`0;0?oo
o`800<Wo103oool00`00o`@00<Wo0?ooo`020?ooo`050039o`3oool0oooo0?ooo`00o`@00P3oool0
0`00o`@0oooo003o10050?ooo`03003o103oool0oooo00`0oooo0P3oA`0O0?ooo`008@3oool00`3o
A`00oooo0?ooo`0=0?ooo`800?l41`3oool00`00bOl0oooo0?ooo`020?ooo`03003o1000bOl00?l4
0080oooo00@00?l40?ooo`3oool0oooo1000bOl00`00o`@0oooo0?ooo`020?ooo`030039o`3oool0
oooo0100oooo0P00bOl70?ooo`800<Wo1@3oool20039o`H0oooo0P00o`@<0?ooo`04003o103oool0
oooo003o10L0oooo0P00o`@60?ooo`@00<Wo00<0oooo0039o`3oool03`3oool00`000000oooo0?oo
o`05003o10D0oooo00<000000?ooo`3oool00`00o`@30?ooo`030000003oool0oooo00D0oooo0P00
o`@_0?ooo`<00<Wo0`3oool3003o10030?ooo`00bOl0oooo00`0oooo00<00<Wo0?ooo`3oool0203o
ool70039o`D0oooo0P00o`@30?ooo`060039o`3oool0oooo0039o`3oool00<Wo2`3oool00`00bOl0
oooo0?ooo`020?ooo`800?l400@00<Wo0?ooo`3oool00<Wo0`3oool01P00o`@0oooo0?ooo`00o`@0
oooo003o10D0oooo00<00?l40?ooo`3oool0303oool20?m701l0oooo000P0?ooo`80odL03`3oool2
003o10L0oooo00L00<Wo0?ooo`3oool0oooo003o1000bOl00?l40080oooo00<00?l40?ooo`3oool0
0P3oool30039o`030?ooo`00o`@0oooo0080oooo00<00<Wo0?ooo`3oool0403oool00`00bOl0oooo
0?ooo`090?ooo`030039o`3oool0oooo00@0oooo0P00bOl60?ooo`03003o103oool0oooo00X0oooo
00@00?l40?ooo`3oool00?l41`3oool2003o10L0oooo1@00bOl?0?ooo`L00?l41@3oool4003o10H0
oooo00<000000?ooo`3oool00`3oool2003o12h0oooo0`00bOl20?ooo`@00?l40P3oool20039o``0
oooo0P00bOl80?ooo`<00<Wo1`3oool20039o`D0oooo00D00?l40?ooo`3oool0oooo0039o`020?oo
o`800<Wo2`3oool20039o`<0oooo00<00?l40?ooo`00bOl00P3oool00`00o`@00<Wo0?ooo`020?oo
o`03003o103oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0<0?oo
o`<0odL07P3oool00200oooo0P3oA`0?0?ooo`800?l41P3oool00`00bOl0oooo0?ooo`020?ooo`03
003o1000bOl00?l40080oooo00<00?l40?ooo`3oool00P3oool30039o`05003o103oool0oooo0?oo
o`00bOl04P3oool00`00bOl0oooo0?ooo`0;0?ooo`030039o`3oool0oooo00D0oooo00<00<Wo0?oo
o`3oool0103oool00`00o`@0oooo0?ooo`0:0?ooo`04003o103oool0oooo003o10H0oooo00<00?l4
0?ooo`00o`@0203oool40039o`/0oooo2P00o`@00`3oool00?l4003o1002003o10X0oooo00@00000
0?ooo`3oool0oooo0P00o`@^0?ooo`800<Wo0P3oool3003o10D0oooo00<00<Wo0?ooo`3oool02`3o
ool00`00bOl0oooo0?ooo`060?ooo`800<Wo303oool20039o`@0oooo00D00?l40?ooo`3oool0oooo
0039o`020?ooo`800<Wo2`3oool00`00bOl0oooo0?ooo`020?ooo`03003o1000bOl0oooo0080oooo
00D00<Wo0?ooo`3oool0oooo003o10020?ooo`03003o103oool00?l400D0oooo00<00?l40?ooo`3o
ool0303oool20?m701h0oooo000P0?ooo`80odL03P3oool00`00o`@0oooo003o10060?ooo`030039
o`3oool0oooo0080oooo00@00?l40039o`3oool0oooo0P00o`@30?ooo`<00<Wo0P00o`@20?ooo`03
0039o`3oool0oooo0100oooo00<00<Wo0?ooo`3oool03@3oool20039o`H0oooo00<00<Wo0?ooo`3o
ool0103oool00`00o`@0oooo0?ooo`090?ooo`05003o103oool0oooo0?ooo`00o`@01P3oool00`00
o`@0oooo003o10090?ooo`<00<Wo203oool=003o10h0oooo00@000000?ooo`00o`@00?l4;P3oool2
0039o`040?ooo`00o`@00?l4003o10L0oooo00<00<Wo0?ooo`3oool02`3oool00`00bOl0oooo0?oo
o`040?ooo`<00<Wo403oool30039o`80oooo0P00o`@20?ooo`050039o`3oool00<Wo0?ooo`00bOl0
2P3oool20039o`<0oooo0P00o`@01000bOl0oooo0?ooo`00bOl30?ooo`06003o103oool0oooo003o
103oool00?l41@3oool00`00o`@0oooo0?ooo`0<0?ooo`80odL07P3oool00200oooo0P3oA`0>0?oo
o`03003o103oool00?l400H0oooo00@00<Wo0?ooo`3oool0oooo0P00o`@01000bOl0oooo0?ooo`00
o`@40?ooo`<00<Wo00@0oooo003o103oool00<Wo4P3oool00`00bOl0oooo0?ooo`0@0?ooo`030039
o`3oool0oooo00@0oooo00<00<Wo0?ooo`3oool0103oool00`00o`@0oooo0?ooo`090?ooo`05003o
103oool0oooo0?ooo`00o`@01P3oool2003o10/0oooo0`00bOl30?ooo`d00?l4403oool3003o12d0
oooo0`00bOl3003o10X0oooo00<00<Wo0?ooo`3oool02P3oool00`00bOl0oooo0?ooo`030?ooo`80
0<Wo5P3oool20039o`80oooo00P00?l40?ooo`3oool00<Wo0?ooo`00bOl0oooo0039o`X0oooo00L0
0<Wo0?ooo`3oool0oooo003o103oool00<Wo0080oooo00<00<Wo0?ooo`3oool00P3oool01@00o`@0
oooo003o103oool00?l400D0oooo00<00?l40?ooo`3oool0303oool20?m701h0oooo000P0?ooo`80
odL03P3oool2003o10H0oooo00<00<Wo0?ooo`3oool00P3oool01000o`@00<Wo003o103oool2003o
10@0oooo0P00bOl2003o10030?ooo`00bOl0oooo0140oooo00<00<Wo0?ooo`3oool04P3oool00`00
bOl0oooo0?ooo`040?ooo`030039o`3oool0oooo00@0oooo00<00?l40?ooo`3oool02@3oool01000
o`@0oooo0?ooo`00o`@60?ooo`03003o103oool00?l400/0oooo0`00bOlA003o10/0oooo0`00o`@0
0`3oool000000?ooo`0Y0?ooo`@00<Wo00<0oooo003o1000o`@0303oool00`00bOl0oooo0?ooo`0:
0?ooo`030039o`3oool0oooo00<0oooo00<00<Wo0?ooo`3oool0603oool01000bOl0oooo0?ooo`00
o`@20?ooo`040039o`3oool00<Wo0039o`X0oooo00L00<Wo0?ooo`3oool0oooo003o103oool00<Wo
0080oooo00<00<Wo003o103oool00P3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo
0080oooo00<00?l40?ooo`3oool0303oool20?m701h0oooo000P0?ooo`80odL03P3oool2003o10H0
oooo00<00<Wo0?ooo`3oool00P3oool01000o`@00<Wo0?ooo`3oool2003o10<0oooo0`00bOl0103o
ool00?l40?ooo`00bOlA0?ooo`030039o`3oool0oooo00L0oooo3@00o`@00`00bOl0oooo0?ooo`04
0?ooo`030039o`3oool0oooo00@0oooo00<00?l40?ooo`3oool02@3oool01000o`@0oooo0?ooo`00
o`@60?ooo`800?l42`3oool00`00bOl0oooo0039o`020039o`80oooo3P00o`@80?ooo`800?l4103o
ool00`000000oooo0?ooo`0T0?ooo`@00<Wo0`3oool2003o10d0oooo00<00<Wo0?ooo`3oool02@3o
ool20039o`D0oooo00<00<Wo0?ooo`3oool06P3oool01000bOl0oooo0?ooo`00o`@20?ooo`800<Wo
00<0oooo0039o`3oool02@3oool01P00bOl0oooo0?ooo`3oool00?l40039o`<0oooo00D00<Wo0?oo
o`3oool0oooo003o10020?ooo`03003o103oool00?l400D0oooo00<00?l40?ooo`3oool02`3oool2
0?m701h0oooo000P0?ooo`030?m7003oool0oooo00d0oooo0P00o`@60?ooo`030039o`3oool0oooo
0080oooo00<00?l40039o`3oool00P00o`@40?ooo`<00<Wo00<00?l40?ooo`00bOl04P3oool00`00
bOl0oooo0?ooo`030?ooo`@00?l43@3oool00`00o`@00<Wo003o1003003o10030?ooo`00bOl0oooo
00H0oooo0P00o`@:0?ooo`04003o103oool0oooo003o10H0oooo0P00o`@;0?ooo`030039o`3oool0
oooo00<00<Wo1P3oool:003o10<0oooo0`00o`@60?ooo`030000003oool0oooo0240oooo0`00bOl3
0?ooo`@00?l43P3oool00`00bOl0oooo0?ooo`090?ooo`030039o`3oool0oooo00<0oooo0P00bOlM
0?ooo`080039o`3oool0oooo0?ooo`00o`@0oooo0039o`3oool20039o`X0oooo00L00<Wo0?ooo`3o
ool0oooo003o103oool00<Wo0080oooo00D00<Wo0?ooo`3oool0oooo003o10020?ooo`03003o103o
ool00?l400D0oooo00<00?l40?ooo`3oool02`3oool20?m701h0oooo000P0?ooo`030?m7003oool0
oooo00`0oooo00<00?l40?ooo`00o`@01P3oool01000bOl0oooo0?ooo`3oool2003o10040039o`3o
ool00?l4003o10<0oooo1000bOl00`00o`@0oooo0039o`0A0?ooo`040039o`3oool0oooo0?ooo`<0
0?l44P3oool00`00bOl0oooo0?ooo`020?ooo`800?l400<00<Wo003o103oool01P3oool00`00o`@0
oooo0?ooo`080?ooo`04003o103oool0oooo003o10D0oooo00<00?l40?ooo`00o`@02`3oool01000
bOl0oooo0?ooo`3oool20039o``0oooo1P00o`@90?ooo`8000007P3oool40039o`<0oooo0`00o`@A
0?ooo`030039o`3oool0oooo00T0oooo00<00<Wo0?ooo`3oool00`3oool00`00bOl0oooo0?ooo`0N
0?ooo`040039o`3oool0oooo003o1080oooo00@00<Wo0?ooo`00bOl00<Wo2@3oool20039o`80oooo
00<00?l40?ooo`00bOl00P3oool00`00bOl0oooo0?ooo`020?ooo`05003o103oool00?l40?ooo`00
o`@01@3oool00`00o`@0oooo0?ooo`0<0?ooo`030?m7003oool0oooo01`0oooo000O0?ooo`80odL0
3P3oool00`00o`@0oooo003o10050?ooo`030039o`3oool0oooo0080oooo00@00?l40?ooo`00bOl0
oooo0P00o`@30?ooo`<00<Wo00<00?l40?ooo`00bOl04@3oool00`00bOl00?l4003o1002003o11H0
oooo00<00<Wo0?ooo`3oool0103oool00`00bOl00?l4003o10060?ooo`03003o103oool0oooo00L0
oooo00D00?l40?ooo`3oool0oooo003o10050?ooo`800?l4303oool00`00bOl0oooo0?ooo`020?oo
o`030039o`3oool0oooo00P0oooo1000o`@<0?ooo`030000003oool0oooo01H0oooo1`00bOl30?oo
o`@00?l44`3oool00`00bOl0oooo0?ooo`090?ooo`030039o`3oool0oooo00<0oooo00<00<Wo0?oo
o`3oool0803oool01000bOl0oooo0?ooo`00o`@20?ooo`030039o`3oool00<Wo00X0oooo00H00<Wo
0?ooo`3oool00?l40?ooo`00bOl20?ooo`030039o`3oool0oooo0080oooo00H00?l40?ooo`3oool0
0?l40?ooo`00o`@40?ooo`03003o103oool0oooo00`0oooo00<0odL00?ooo`3oool0703oool001l0
oooo0P3oA`0>0?ooo`03003o103oool00?l400D0oooo00<00<Wo0?ooo`3oool00P3oool01@00o`@0
0<Wo0?ooo`3oool00?l400@0oooo0`00bOl00`00o`@0oooo0039o`0>0?ooo`<00?l400<00<Wo003o
103oool01@00o`@B0?oooaX00<Wo0P3oool01000o`@0oooo0?ooo`00o`@60?ooo`800?l4303oool0
0`00bOl0oooo0?ooo`020?ooo`800<Wo1@3oool3003o1100oooo00<000000?ooo`3oool04`3oool3
0039o`L0oooo0`00o`@G0?ooo`030039o`3oool0oooo00T0oooo00<00<Wo0?ooo`3oool00P3oool0
0`00bOl0oooo0?ooo`0R0?ooo`070039o`3oool0oooo003o103oool00<Wo0?ooo`020039o`T0oooo
0P00bOl20?ooo`800?l400@00<Wo0?ooo`3oool00<Wo0`3oool01P00o`@0oooo0?ooo`00o`@0oooo
003o10@0oooo00<00?l40?ooo`3oool0303oool20?m701d0oooo000O0?ooo`80odL03P3oool00`00
o`@0oooo003o10050?ooo`030039o`3oool0oooo0080oooo00D00?l40039o`3oool0oooo003o1003
0?ooo`@00<Wo00<00?l40039o`3oool0303oool2003o1080oooo00<00<Wo0?ooo`3oool01P3oool2
003o10`0oooo1000bOl30?ooo`030039o`3oool0oooo00<0oooo00<00<Wo0?ooo`3oool00`3oool5
003o10H0oooo2P00bOl20?ooo`03003o103oool00?l400`0oooo00<00<Wo0?ooo`3oool00`3oool0
0`00bOl0oooo003o1002003o11<0oooo00<000000?ooo`3oool0303oool70039o`L0oooo0`00o`@I
0?ooo`030039o`3oool0oooo00T0oooo00<00<Wo0?ooo`3oool00P3oool00`00bOl0oooo0?ooo`0T
0?ooo`030039o`3oool00?l40080oooo00<00<Wo0?ooo`00bOl02P3oool01P00bOl0oooo0?ooo`00
o`@0oooo0039o`80oooo00D00<Wo0?ooo`3oool0oooo003o10020?ooo`03003o103oool00?l400D0
oooo00<00?l40?ooo`3oool02`3oool20?m701d0oooo000O0?ooo`80odL03P3oool00`00o`@0oooo
003o10050?ooo`040039o`3oool0oooo0?ooo`800?l400@00<Wo0?ooo`00o`@00?l40`3oool30039
o`03003o103oool00<Wo00/0oooo0P00o`@30?ooo`03003o1000bOl0oooo00T0oooo0P00o`@60?oo
o`@00<Wo1`3oool00`00bOl0oooo0?ooo`040?ooo`030039o`3oool0oooo00L0oooo1000o`@60?oo
o`04003o103oool0oooo003o1080oooo4`00bOl20?ooo`<00?l400<00<Wo0?ooo`3oool0503oool0
0`000000oooo0?ooo`0<0039o`/0oooo0`00o`@K0?ooo`030039o`3oool0oooo00T0oooo00<00<Wo
0?ooo`3oool00P3oool00`00bOl0oooo0?ooo`0E0?ooo`P00<Wo00<00?l40?ooo`3oool01P3oool0
0`00bOl0oooo003o10020?ooo`<00<Wo2@3oool01P00bOl0oooo0?ooo`00o`@0oooo0039o`80oooo
00D00<Wo0?ooo`3oool0oooo003o10020?ooo`03003o103oool00?l400D0oooo00<00?l40?ooo`3o
ool02`3oool20?m701d0oooo000O0?ooo`80odL03P3oool2003o10H0oooo00H00<Wo0?ooo`3oool0
oooo003o1000bOl20?ooo`800?l40`3oool30039o`03003o103oool00<Wo00T0oooo0P00o`@40?oo
o`03003o1000bOl0oooo00`0oooo0P00o`@20?ooo`800<Wo303oool00`00bOl0oooo0?ooo`040?oo
o`030039o`3oool0oooo00L0oooo00<00?l40?ooo`3oool01@00o`@01@3oool00?l40?ooo`3oool0
0?l400H0oooo0P00o`@<0?ooo`03003o1000bOl00<Wo01d00<Wo503oool3003o11d0oooo00<00<Wo
0?ooo`3oool02P3oool01@00bOl0oooo0?ooo`3oool00<Wo01H0oooo0P00bOl3003o10D0oooo0`00
bOl60?ooo`050039o`3oool0oooo003o103oool00`00bOl90?ooo`800<Wo00@0oooo003o103oool0
0<Wo0P3oool01@00bOl0oooo0?ooo`3oool00?l40080oooo00<00?l40?ooo`00o`@01@3oool00`00
o`@0oooo0?ooo`0;0?ooo`80odL07@3oool001l0oooo0P3oA`0>0?ooo`800?l41@3oool01000bOl0
oooo0?ooo`3oool2003o10040039o`3oool0oooo003o10<0oooo1000bOl00`00o`@00<Wo0?ooo`08
0?ooo`03003o103oool0oooo00<0oooo00<00?l40?ooo`00bOl03`3oool20039o`h0oooo00<00<Wo
0?ooo`3oool0103oool20039o`T0oooo00<00?l40?ooo`3oool0103oool:003o10030?ooo`00o`@0
oooo00`00?l400<0oooo0039o`3oool01@3oool20039oa<0oooo00<000000?ooo`3oool0403oool4
003o1200oooo00<00<Wo0?ooo`3oool02@3oool01@00bOl0oooo0?ooo`3oool00<Wo01D0oooo0P00
bOl00`00o`@0oooo0?ooo`0:0?ooo`030039o`00o`@0oooo00@0oooo00<00<Wo0?ooo`00o`@00P3o
ool20039o`T0oooo0P00bOl20?ooo`800?l400@00<Wo0?ooo`3oool00<Wo0`3oool00`00o`@0oooo
003o10020?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool02`3oool20?m701d0oooo
000O0?ooo`030?m7003oool0oooo00`0oooo00<00?l40?ooo`00o`@01@3oool01000bOl0oooo0?oo
o`3oool2003o10040039o`3oool0oooo003o10<0oooo0`00bOl2003o10030039o`3oool0oooo00H0
oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo0039o`0>0?ooo`800<Wo0P3oool00`00o`@0
oooo0?ooo`0<0?ooo`030039o`3oool0oooo00D0oooo00<00<Wo0?ooo`3oool01`3oool00`00o`@0
oooo0?ooo`060?ooo`04003o103oool0oooo003o10<0oooo1@00o`@<0?ooo`030039o`3oool0oooo
00D0oooo00<00<Wo0?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`@00?l48`3oool00`00
bOl0oooo0?ooo`0:0?ooo`050039o`3oool0oooo0?ooo`00bOl04`3oool20039o`030?ooo`00o`@0
oooo00d0oooo00<00<Wo003o103oool00`3oool01@00bOl0oooo0?ooo`00o`@0oooo00<00<Wo2@3o
ool00`00bOl0oooo0?ooo`02003o10040039o`3oool0oooo0039o`<0oooo00<00?l40?ooo`00o`@0
0P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00/0oooo0P3oA`0M0?ooo`007`3o
ool00`3oA`00oooo0?ooo`0<0?ooo`03003o103oool00?l400D0oooo00@00<Wo0?ooo`3oool0oooo
0P00o`@01000bOl0oooo0?ooo`00o`@30?ooo`<00<Wo00<00?l40?ooo`00bOl01`3oool00`00o`@0
oooo0?ooo`030?ooo`04003o103oool0oooo0039o``0oooo0P00bOl50?ooo`03003o103oool0oooo
00`0oooo00<00<Wo0?ooo`3oool0103oool00`00bOl0oooo0?ooo`080?ooo`03003o103oool0oooo
00H0oooo00<00?l40?ooo`00o`@01@3oool00`00o`@0oooo003o100<0?ooo`030039o`3oool0oooo
00H0oooo00<00<Wo0?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`<00?l49P3oool00`00
bOl0oooo0?ooo`0:0?ooo`050039o`3oool0oooo0?ooo`00bOl04`3oool01000bOl0oooo0?ooo`00
o`@@0?ooo`030039o`00o`@0oooo00<0oooo00<00<Wo0?ooo`00o`@00P3oool20039o`T0oooo0P00
bOl0103oool00?l4003o1000bOl20?ooo`070039o`3oool0oooo0?ooo`00o`@0oooo003o10020?oo
o`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool02`3oool20?m701d0oooo000O0?ooo`03
0?m7003oool0oooo00`0oooo00<00?l40?ooo`00o`@01@3oool01P00bOl0oooo0?ooo`00o`@0oooo
0039o`<0oooo00@00?l40?ooo`3oool0oooo0`00bOl00`00o`@00<Wo0?ooo`060?ooo`03003o103o
ool0oooo00<0oooo00@00?l40?ooo`3oool00<Wo2`3oool20039o`P0oooo00<00?l40?ooo`3oool0
2`3oool00`00bOl0oooo0?ooo`050?ooo`030039o`3oool0oooo00P0oooo0P00o`@60?ooo`04003o
103oool0oooo003o10D0oooo00<00?l40?ooo`00o`@0303oool00`00bOl0oooo0?ooo`060?ooo`80
0<Wo3`3oool00`000000oooo0?ooo`050?ooo`@00?l4:@3oool00`00bOl0oooo0?ooo`090?ooo`05
0039o`3oool0oooo0?ooo`00bOl04`3oool01000bOl0oooo0?ooo`00o`@B0?ooo`030039o`3oool0
oooo0080oooo00D00<Wo0?ooo`3oool00?l40?ooo`020039o`T0oooo0P00bOl01`3oool00?l4003o
103oool00<Wo0?ooo`00bOl00`3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080
oooo00<00?l40?ooo`3oool0303oool00`3oA`00oooo0?ooo`0K0?ooo`007P3oool20?m700h0oooo
00<00?l40?ooo`00o`@01@3oool01P00bOl0oooo0?ooo`00o`@0oooo0039o`80oooo0P00o`@20?oo
o`@00<Wo00<00?l40039o`3oool01P3oool00`00o`@0oooo0?ooo`020?ooo`05003o103oool0oooo
0?ooo`00bOl02P3oool00`00bOl0oooo0?ooo`090?ooo`03003o103oool0oooo00/0oooo00<00<Wo
0?ooo`3oool0103oool00`00bOl0oooo0?ooo`0:0?ooo`03003o103oool0oooo00@0oooo00@00?l4
0?ooo`3oool00?l4103oool00`00o`@0oooo003o100=0?ooo`030039o`3oool0oooo00L0oooo00<0
0<Wo0?ooo`3oool0303oool2000000<0oooo0`00o`@/0?ooo`030039o`3oool0oooo00X0oooo00D0
0<Wo0?ooo`3oool0oooo0039o`0B0?ooo`040039o`3oool0oooo003o11<0oooo00<00<Wo003o103o
ool00P3oool01000bOl0oooo0?ooo`00o`@20?ooo`030039o`3oool0oooo00P0oooo00T00<Wo0?oo
o`00o`@00?l40?ooo`00bOl0oooo0039o`00o`@00P3oool00`00o`@0oooo003o10020?ooo`03003o
103oool0oooo00<0oooo00<00?l40?ooo`3oool02`3oool20?m701`0oooo000N0?ooo`80odL03P3o
ool00`00o`@0oooo003o10040?ooo`070039o`3oool0oooo0?ooo`00o`@0oooo0039o`020?ooo`07
003o103oool0oooo0?ooo`00bOl0oooo0039o`02003o10030039o`3oool0oooo00@0oooo00<00?l4
0?ooo`3oool00`3oool01000o`@0oooo0?ooo`00bOl:0?ooo`030039o`3oool0oooo00/0oooo00<0
0?l40?ooo`3oool02P3oool00`00bOl0oooo0?ooo`050?ooo`030039o`3oool0oooo00X0oooo00<0
0?l40?ooo`3oool00`3oool01000o`@0oooo0?ooo`00o`@50?ooo`03003o103oool00?l400`0oooo
00<00<Wo0?ooo`3oool0203oool00`00bOl0oooo0?ooo`0;0?ooo`030000003oool00?l400800?l4
;`3oool00`00bOl0oooo0?ooo`090?ooo`050039o`3oool0oooo0?ooo`00bOl04P3oool01000bOl0
oooo0?ooo`00o`@E0?ooo`030039o`00o`@0oooo0080oooo00<00<Wo0?ooo`00o`@00P3oool20039
o`T0oooo00<00<Wo0?ooo`3oool00P00o`@01000bOl0oooo0039o`00o`@20?ooo`03003o103oool0
0?l40080oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo0?ooo`0;0?ooo`80odL0703oool0
01h0oooo0P3oA`0>0?ooo`03003o103oool00?l400@0oooo00L00<Wo0?ooo`3oool0oooo003o103o
ool00<Wo0080oooo00T00?l40?ooo`3oool0oooo0039o`3oool00<Wo003o1000bOl01`3oool00`00
o`@0oooo0?ooo`020?ooo`05003o103oool0oooo0?ooo`00bOl02@3oool00`00bOl0oooo0?ooo`0=
0?ooo`03003o103oool0oooo00X0oooo00<00<Wo0?ooo`3oool01@3oool00`00bOl0oooo0?ooo`0:
0?ooo`03003o103oool0oooo00<0oooo00@00?l40?ooo`3oool00?l4103oool00`00o`@0oooo003o
100=0?ooo`030039o`3oool0oooo00L0oooo0P00bOl;0?ooo`<00?l4<@3oool00`00bOl0oooo0?oo
o`0:0?ooo`040039o`3oool0oooo0039oa80oooo00@00<Wo0?ooo`3oool00?l45`3oool01@00bOl0
oooo0?ooo`3oool00<Wo0080oooo00@00?l40?ooo`00bOl00<Wo2@3oool20039o`040?ooo`00o`@0
0?l40039o`80oooo00@00<Wo0?ooo`3oool00?l40P3oool00`00o`@0oooo003o10050?ooo`03003o
103oool0oooo00/0oooo0P3oA`0L0?ooo`007P3oool20?m700h0oooo00<00?l40?ooo`00o`@0103o
ool01000bOl0oooo0?ooo`3oool2003o10040039o`3oool0oooo003o1080oooo1000bOl00`00o`@0
0<Wo0?ooo`050?ooo`03003o103oool0oooo0080oooo00D00?l40?ooo`3oool0oooo0039o`090?oo
o`030039o`3oool0oooo00l0oooo00<00?l40?ooo`3oool02@3oool00`00bOl0oooo0?ooo`050?oo
o`030039o`3oool0oooo00/0oooo00<00?l40?ooo`3oool00P3oool01000o`@0oooo0?ooo`00o`@5
0?ooo`03003o103oool00?l400`0oooo00<00<Wo0?ooo`3oool0203oool20039o`L0oooo0`00o`@0
0`3oool000000?ooo`0`0?ooo`030039o`3oool0oooo00X0oooo00D00<Wo0?ooo`3oool0oooo0039
o`0B0?ooo`030039o`3oool00?l401T0oooo00L00<Wo0?ooo`3oool0oooo0039o`3oool00?l40080
oooo00<00<Wo0?ooo`3oool01`3oool20039o`070?ooo`00o`@00?l40?ooo`00bOl0oooo0039o`03
0?ooo`03003o103oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0;
0?ooo`80odL0703oool001h0oooo0P3oA`0>0?ooo`800?l41@3oool01000bOl0oooo0?ooo`3oool2
003o10040039o`3oool0oooo003o1080oooo1000bOl00`00o`@00<Wo0?ooo`050?ooo`03003o103o
ool0oooo0080oooo00D00?l40?ooo`3oool0oooo0039o`080?ooo`030039o`3oool0oooo0100oooo
00<00?l40?ooo`3oool02P3oool00`00bOl0oooo0?ooo`050?ooo`030039o`3oool0oooo00/0oooo
00<00?l40?ooo`3oool00P3oool01000o`@0oooo0?ooo`00o`@40?ooo`03003o103oool00?l400d0
oooo00<00<Wo0?ooo`3oool0203oool20039o`<0oooo0`00o`@40?ooo`030000003oool0oooo02h0
oooo00<00<Wo0?ooo`3oool02`3oool01000bOl0oooo0?ooo`00bOlB0?ooo`040039o`3oool0oooo
003o11T0oooo00D00<Wo003o103oool0oooo0039o`020?ooo`03003o103oool00<Wo00T0oooo0P00
bOl01`3oool00?l4003o103oool00<Wo0?ooo`00bOl00`3oool00`00o`@0oooo003o10020?ooo`03
003o103oool0oooo0080oooo00<00?l40?ooo`3oool02`3oool20?m701`0oooo000N0?ooo`80odL0
3@3oool00`00o`@0oooo003o10050?ooo`040039o`3oool0oooo0?ooo`800?l400@00<Wo0?ooo`00
o`@00?l40P3oool50039o`H0oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`020?oo
o`030039o`3oool0oooo00D0oooo00<00<Wo0?ooo`3oool04P3oool00`00o`@0oooo0?ooo`090?oo
o`030039o`3oool0oooo00D0oooo00<00<Wo0?ooo`3oool0303oool01@00o`@0oooo0?ooo`3oool0
0?l40080oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo003o100=0?ooo`030039o`3oool0
oooo00P0oooo0P00bOl2003o10L0oooo00<000000?ooo`3oool0;P3oool00`00bOl0oooo0?ooo`0:
0?ooo`050039o`3oool0oooo0?ooo`00bOl04@3oool01000bOl0oooo0?ooo`00o`@J0?ooo`050039
o`3oool00?l40?ooo`00bOl00P3oool01000o`@0oooo0039o`00bOl90?ooo`090039o`3oool00?l4
003o103oool00<Wo0?ooo`00bOl00?l40080oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo
0?ooo`020?ooo`03003o103oool0oooo00/0oooo0P3oA`0L0?ooo`007P3oool20?m700d0oooo00<0
0?l40?ooo`00o`@0103oool00`00bOl0oooo0?ooo`020?ooo`800?l400@00<Wo0?ooo`00o`@00?l4
0P3oool30039o`03003o1000bOl0oooo00D0oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo
0?ooo`020?ooo`030039o`3oool0oooo00@0oooo00<00<Wo0?ooo`3oool0503oool00`00o`@0oooo
0?ooo`080?ooo`030039o`3oool0oooo00H0oooo00<00<Wo0?ooo`3oool0303oool01@00o`@0oooo
0?ooo`3oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo003o100=0?ooo`03
0039o`3oool0oooo00L0oooo0P00o`@20039o`P0oooo00<000000?ooo`3oool0;@3oool00`00bOl0
oooo0?ooo`0;0?ooo`040039o`3oool0oooo0039oa80oooo00<00<Wo0?ooo`00o`@0703oool01000
bOl00?l40?ooo`00bOl30?ooo`03003o103oool00<Wo00T0oooo0P00bOl01`3oool00?l40?ooo`00
bOl0oooo0039o`00o`@00P3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080oooo
00<00?l40?ooo`3oool02`3oool20?m701`0oooo000N0?ooo`80odL03@3oool00`00o`@0oooo003o
10040?ooo`030039o`3oool0oooo0080oooo0P00o`@01@00bOl0oooo003o1000o`@0oooo00800<Wo
00@0oooo0039o`00o`@00<Wo1@3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo0080
oooo00<00<Wo0?ooo`3oool01@3oool00`00bOl0oooo0?ooo`0E0?ooo`03003o103oool0oooo00P0
oooo00<00<Wo0?ooo`3oool01@3oool00`00bOl0oooo0?ooo`0=0?ooo`800?l400D0oooo003o103o
ool0oooo003o10040?ooo`03003o103oool00?l400h0oooo00<00<Wo0?ooo`3oool00`3oool3003o
10<0oooo0P00bOl70?ooo`030000003oool0oooo02d0oooo00<00<Wo0?ooo`3oool02P3oool01@00
bOl0oooo0?ooo`3oool00<Wo0140oooo00@00<Wo0?ooo`3oool00?l4703oool01000bOl0oooo003o
1000bOl30?ooo`03003o103oool00<Wo00T0oooo0P00bOl01`3oool00?l4003o1000bOl0oooo0039
o`00o`@00P3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080oooo00<00?l40?oo
o`3oool02`3oool20?m701`0oooo000N0?ooo`80odL03@3oool00`00o`@0oooo003o10040?ooo`03
0039o`3oool0oooo0080oooo0P00o`@00`00bOl0oooo003o10020?ooo`800<Wo00@0oooo0039o`00
o`@00<Wo1@3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo0080oooo00<00<Wo0?oo
o`3oool0103oool00`00bOl0oooo0?ooo`0F0?ooo`03003o103oool0oooo00P0oooo00<00<Wo0?oo
o`3oool01P3oool00`00bOl0oooo0?ooo`0>0?ooo`03003o103oool00?l40080oooo00<00?l40?oo
o`3oool00P3oool00`00o`@0oooo003o100=0?ooo`030039o`3oool0oooo00<00?l41`3oool00`00
bOl0oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo00<00<Wo0?ooo`3oool02P3oool01000
bOl0oooo0?ooo`00bOlB0?ooo`030039o`3oool00?l401d0oooo00D00<Wo0?ooo`00o`@0oooo0039
o`030?ooo`03003o1000bOl00<Wo00T0oooo00P00<Wo0?ooo`00o`@00?l40039o`3oool00<Wo003o
1080oooo00H00?l40?ooo`3oool00?l40?ooo`00o`@40?ooo`03003o103oool0oooo00/0oooo0P3o
A`0L0?ooo`007P3oool20?m700d0oooo00<00?l40?ooo`00o`@0103oool01000bOl0oooo0?ooo`3o
ool3003o10030039o`3oool00?l40080oooo0P00bOl0103oool00<Wo0039o`00o`@50?ooo`05003o
103oool0oooo0?ooo`00o`@01@3oool00`00bOl0oooo0?ooo`030?ooo`030039o`3oool0oooo01P0
oooo00<00?l40?ooo`3oool01`3oool00`00bOl0oooo0?ooo`060?ooo`030039o`3oool0oooo00l0
oooo0P00o`@20?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`00o`@03P3oool00`00bOl0
0?l40?ooo`090?ooo`800<Wo1P3oool2000002d0oooo00<00<Wo0?ooo`3oool02P3oool01@00bOl0
oooo0?ooo`3oool00<Wo0140oooo00@00<Wo0?ooo`3oool00?l47@3oool01@00bOl0oooo003o103o
ool00<Wo00<0oooo00<00?l40?ooo`00bOl02@3oool02000bOl0oooo003o1000o`@0oooo0039o`3o
ool00<Wo0`3oool01@00o`@0oooo003o103oool00?l400@0oooo00<00?l40?ooo`3oool02`3oool2
0?m701`0oooo000N0?ooo`80odL03@3oool00`00o`@0oooo003o10040?ooo`040039o`3oool0oooo
0?ooo`<00?l400<00<Wo003o1000o`@00P3oool50039o`D0oooo00<00?l40?ooo`3oool00P3oool0
0`00o`@0oooo0?ooo`030?ooo`030039o`3oool0oooo00<0oooo00<00<Wo0?ooo`3oool0603oool0
0`00o`@0oooo0?ooo`080?ooo`030039o`3oool0oooo00D0oooo00<00<Wo0?ooo`3oool0403oool2
003o1080oooo00D00?l40?ooo`3oool0oooo003o10020?ooo`03003o103oool0oooo00P0oooo0`00
o`@00`00bOl0oooo0?ooo`0:0?ooo`030039o`3oool0oooo00@0oooo00<000000?ooo`3oool0;03o
ool00`00bOl0oooo0?ooo`0:0?ooo`050039o`3oool0oooo0?ooo`00bOl04@3oool00`00bOl0oooo
003o100O0?ooo`040039o`3oool00?l40039o`<0oooo00<00?l40?ooo`00bOl02@3oool02000bOl0
oooo003o1000o`@0oooo0039o`3oool00<Wo0`3oool01@00o`@0oooo003o103oool00?l400D0oooo
00<00?l40?ooo`3oool02P3oool20?m701`0oooo000N0?ooo`030?m7003oool0oooo00`0oooo00<0
0?l40?ooo`00o`@0103oool01000bOl0oooo0?ooo`3oool2003o10040?ooo`00bOl00?l4003o1080
oooo1@00bOl50?ooo`05003o103oool0oooo0?ooo`00o`@01P3oool00`00bOl0oooo0?ooo`020?oo
o`030039o`3oool0oooo01X0oooo00<00?l40?ooo`3oool01`3oool00`00bOl0oooo0?ooo`060?oo
o`030039o`3oool0oooo0100oooo0P00o`@00`3oool00?l40?ooo`030?ooo`03003o103oool00?l4
00P0oooo0P00o`@40?ooo`030039o`3oool0oooo00X0oooo00<00<Wo0?ooo`3oool00`3oool00`00
0000oooo0?ooo`0/0?ooo`030039o`3oool0oooo00X0oooo00@00<Wo0?ooo`3oool00<Wo4@3oool0
1000bOl0oooo0?ooo`00o`@O0?ooo`040039o`3oool00?l40039o`<0oooo00<00?l40?ooo`00bOl0
2@3oool02000bOl0oooo003o1000o`@0oooo0039o`3oool00<Wo0`3oool01@00o`@0oooo003o103o
ool00?l400D0oooo00<00?l40?ooo`3oool02P3oool20?m701`0oooo000N0?ooo`030?m7003oool0
oooo00`0oooo00<00?l40?ooo`00o`@0103oool01000bOl0oooo0?ooo`3oool2003o10040039o`3o
ool00?l4003o1080oooo1000bOl00`00o`@0oooo0?ooo`030?ooo`05003o103oool0oooo0?ooo`00
o`@01@3oool00`00bOl0oooo0?ooo`020?ooo`030039o`3oool0oooo01/0oooo00<00?l40?ooo`3o
ool0203oool00`00bOl0oooo0?ooo`050?ooo`030039o`3oool0oooo0140oooo0P00o`@00`3oool0
0?l40?ooo`020?ooo`04003o103oool0oooo003o10D0oooo0P00o`@60?ooo`030039o`3oool0oooo
00X0oooo0P00bOl40?ooo`030000003oool0oooo02`0oooo00<00<Wo0?ooo`3oool02P3oool01000
bOl0oooo0?ooo`00bOlA0?ooo`040039o`3oool0oooo003o11l0oooo00D00<Wo0?ooo`00o`@0oooo
0039o`020?ooo`03003o103oool00<Wo00T0oooo00P00<Wo0?ooo`3oool00?l40?ooo`00bOl0oooo
0039o`<0oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0
oooo00/0oooo00<0odL00?ooo`3oool06P3oool001h0oooo00<0odL00?ooo`3oool0303oool2003o
10D0oooo00@00<Wo0?ooo`3oool0oooo0P00o`@01000bOl0oooo003o1000o`@20?ooo`@00<Wo00<0
0?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00<0oooo00<0
0<Wo0?ooo`3oool00P3oool00`00bOl0oooo0?ooo`0L0?ooo`03003o103oool0oooo00L0oooo00<0
0<Wo0?ooo`3oool01@3oool00`00bOl0oooo0?ooo`0A0?ooo`04003o103oool00?l4003o10@0oooo
00@00?l40?ooo`00o`@0oooo1000o`@90?ooo`030039o`3oool0oooo00X0oooo00<00<Wo0?ooo`3o
ool00P3oool00`000000oooo0?ooo`0[0?ooo`030039o`3oool0oooo00X0oooo00D00<Wo0?ooo`3o
ool0oooo0039o`0A0?ooo`030039o`3oool00?l40240oooo00@00<Wo003o103oool00<Wo0P3oool0
1000o`@0oooo0039o`00bOl80?ooo`080039o`3oool0oooo003o103oool00<Wo0?ooo`00bOl30?oo
o`03003o103oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0;0?oo
o`030?m7003oool0oooo01X0oooo000N0?ooo`030?m7003oool0oooo00`0oooo0P00o`@50?ooo`08
0039o`3oool0oooo003o103oool00?l40039o`3oool2003o1080oooo1000bOl00`00o`@0oooo0?oo
o`020?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool00`3oool01@00bOl0oooo0?oo
o`3oool00<Wo0200oooo00<00?l40?ooo`3oool01P3oool00`00bOl0oooo0?ooo`060?ooo`030039
o`3oool0oooo0140oooo00<00?l40?ooo`00o`@02000o`@=0?ooo`030039o`3oool0oooo00X0oooo
0P00bOl30?ooo`030000003oool0oooo02/0oooo00<00<Wo0?ooo`3oool02P3oool01000bOl0oooo
0?ooo`00bOlB0?ooo`030039o`3oool00?l40240oooo00@00<Wo003o103oool00<Wo0P3oool01000
o`@0oooo0039o`00bOl80?ooo`080039o`3oool0oooo003o103oool00<Wo0?ooo`00bOl30?ooo`03
003o103oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0;0?ooo`03
0?m7003oool0oooo01X0oooo000N0?ooo`030?m7003oool0oooo00`0oooo0P00o`@50?ooo`080039
o`3oool0oooo003o103oool00?l40039o`3oool2003o1080oooo1000bOl00`00o`@0oooo0?ooo`02
0?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool00`3oool01@00bOl0oooo0?ooo`3o
ool00<Wo0200oooo00<00?l40?ooo`3oool01`3oool00`00bOl0oooo0?ooo`050?ooo`030039o`3o
ool0oooo0140oooo00@00?l40?ooo`3oool00?l40`3oool00`00o`@0oooo003o100>0?ooo`030039
o`3oool0oooo00/0oooo00D00<Wo0?ooo`3oool0oooo0000000/0?ooo`030039o`3oool0oooo00/0
oooo00@00<Wo0?ooo`3oool00<Wo4@3oool01000bOl0oooo0?ooo`00o`@R0?ooo`030039o`3oool0
0<Wo0080oooo00@00?l40?ooo`00bOl00<Wo203oool20039o`060?ooo`00o`@00?l40039o`3oool0
0<Wo0`3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3o
ool02`3oool20?m701/0oooo00070?ooo`@000004`3oool00`3oA`00oooo0?ooo`0<0?ooo`800?l4
0P3oool30000000:0039o`000000oooo003o100000000?l40039o`3oool00?l40?ooo`8000001000
bOl00`00o`@0oooo0?ooo`020?ooo`05003o103oool0oooo0?ooo`00o`@01P3oool01@00bOl0oooo
0?ooo`3oool00<Wo00l0oooo1@00000=0?ooo`03003o103oool0oooo00H0oooo00<00<Wo0?ooo`3o
ool01P3oool00`00bOl0oooo0?ooo`050?ooo`800000103oool2000000@0oooo00<00?l400000000
o`@00`3oool00`00o`@0oooo003o100>0?ooo`030039o`3oool0oooo00`0oooo00@00<Wo0?ooo`3o
ool00000:03oool200000080oooo00@00<Wo0?ooo`0000000000103oool2000000@0oooo00@00<Wo
0?ooo`3oool00<Wo4@3oool00`00bOl0oooo003o100<0?ooo`D000004P3oool00`00bOl0oooo0039
o`030?ooo`03003o1000bOl00<Wo00P0oooo0P00bOl0103oool00?l4003o100000020039o`80oooo
0P000002003o1080oooo00<00?l40000003oool00P3oool00`00o`@0oooo0?ooo`0;0?ooo`80odL0
5@3oool400000080oooo00070?ooo`030000003oool0oooo01@0oooo00<0odL00?ooo`3oool0303o
ool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00o`@01@00bOl0oooo003o10000000oooo00D0
0<Wo00D00?l40?ooo`3oool0oooo003o10040?ooo`03003o103oool0oooo00@0oooo00D00<Wo0?oo
o`3oool0oooo0039o`0A0?ooo`030000003oool0oooo00d0oooo00<00?l40?ooo`3oool01P3oool0
0`00bOl0oooo0?ooo`060?ooo`030039o`3oool0oooo00@0oooo00@000000?ooo`3oool00000203o
ool0100000000?l40?ooo`00o`@30?ooo`04003o103oool0oooo003o10h0oooo00<00<Wo0?ooo`3o
ool02`3oool01000bOl0oooo0?ooo`00000W0?ooo`060000003oool0oooo0000003oool00<Wo1P3o
ool010000000oooo0?ooo`0000030?ooo`040039o`3oool0oooo0039oa40oooo00<00<Wo0?ooo`00
o`@03P3oool00`000000oooo0?ooo`0B0?ooo`040039o`00o`@0oooo0039o`80oooo00<00?l40039
o`00bOl02@3oool02000bOl0oooo003o1000o`@000000039o`00o`@00<Wo0`3oool2003o10050?oo
o`0000000?l40?ooo`0000000P3oool00`00o`@0oooo0?ooo`0;0?ooo`80odL05@3oool00`000000
oooo0?ooo`030?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`030?m7003oool0oooo00`0oooo
0P00o`@40?ooo`040039o`3oool0oooo0?ooo`<00?l400<00<Wo0?ooo`00o`@00P3oool50039o`05
003o103oool0oooo0?ooo`00o`@0103oool00`00o`@0oooo0?ooo`030?ooo`050039o`3oool0oooo
0?ooo`00bOl04P3oool00`000000oooo0?ooo`0>0?ooo`03003o103oool0oooo00H0oooo00<00<Wo
0?ooo`3oool01@3oool00`00bOl0oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo00@0
0?l40?ooo`0000000?l40`3oool00`00o`@0oooo003o100>0?ooo`030039o`3oool0oooo00`0oooo
00<00<Wo0?ooo`0000009`3oool01P000000oooo0?ooo`000000oooo0039o`T0oooo00@000000?oo
o`3oool00<Wo0`3oool00`00bOl0oooo0?ooo`0?0?ooo`030039o`3oool00?l400h0oooo00<00000
0?ooo`3oool04P3oool01000bOl00?l40?ooo`00bOl20?ooo`03003o103oool00<Wo00T0oooo00P0
0<Wo0?ooo`00o`@00?l400000000bOl0oooo0039o`<0oooo0P00o`@20?ooo`03003o103oool00000
0080oooo00<00?l40?ooo`3oool02`3oool20?m701H0oooo00<000000?ooo`3oool00P3oool00003
0?ooo`000000000000800000103oool00`000000oooo0?ooo`0B0?ooo`030?m7003oool0oooo00X0
oooo0P000002003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00o`@01@00bOl0oooo003o103oool0
000000D00<Wo00D00?l40?ooo`3oool0oooo003o10040?ooo`03003o103oool0oooo00<0oooo00D0
0<Wo0?ooo`3oool0oooo0039o`0:0?ooo`@00000103oool00`000000oooo0?ooo`0>0?ooo`03003o
103oool0oooo00H0oooo00<00<Wo0?ooo`3oool01P3oool01000bOl000000000000000020?ooo`04
0000003oool0oooo000000T0oooo00@00000003o103oool00?l40`3oool00`00o`@0oooo003o100>
0?ooo`030039o`3oool0oooo00`0oooo00@00<Wo0?ooo`00000000009P3oool01@000000oooo0?oo
o`0000000<Wo00P0oooo0P0000030?ooo`040039o`3oool0oooo0039oa40oooo00@00<Wo0?ooo`3o
ool00?l43P3oool00`000000oooo0?ooo`0B0?ooo`040039o`00o`@0oooo0039o`<0oooo00<00?l4
0039o`3oool0203oool02000bOl0oooo003o1000o`@000000039o`3oool00<Wo0`3oool01P00o`@0
oooo003o103oool00?l4000000<0oooo00<00?l40?ooo`3oool02`3oool20?m701L0oooo00<00000
0?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool000004`3oool00`3oA`00oooo0?ooo`0<
0?ooo`800?l4103oool01000bOl0oooo0?ooo`3oool3003o10050039o`00o`@00?l40?ooo`000000
1@00bOl01@00o`@0oooo0?ooo`3oool00?l400<0oooo00<00?l40?ooo`3oool0103oool01000bOl0
oooo0?ooo`00bOlC0?ooo`030000003oool0oooo00h0oooo00<00?l40?ooo`3oool01P3oool00`00
bOl0oooo0?ooo`060?ooo`030039o`3oool0oooo00<0oooo00@000000?ooo`3oool000002@3oool0
1@0000000?l40?ooo`3oool00?l40080oooo00<00?l40?ooo`00o`@03P3oool00`00bOl0oooo0?oo
o`0<0?ooo`800<Wo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`0000000<Wo00P0oooo
00<000000?ooo`3oool00P3oool01000bOl0oooo0?ooo`00bOlA0?ooo`030039o`3oool00?l400l0
oooo00<000000?ooo`3oool04P3oool01000bOl0oooo003o1000bOl30?ooo`03003o1000bOl00<Wo
00P0oooo00P00<Wo0?ooo`00o`@00?l400000000bOl0oooo0039o`<0oooo00D00?l40?ooo`00o`@0
oooo003o10040?ooo`03003o103oool0oooo00/0oooo0P3oA`0E0?ooo`040000003oool0oooo0000
0080oooo00080?ooo`800000503oool00`3oA`00oooo0?ooo`0<0?ooo`800?l40`3oool00`000000
0<Wo0?ooo`020?ooo`<00?l400D00<Wo003o1000o`@0oooo000000050039o`05003o103oool0oooo
0?ooo`00o`@00`3oool00`00o`@0oooo0?ooo`040?ooo`040039o`3oool0oooo0039oa80oooo0P00
000A0?ooo`03003o103oool0oooo00D0oooo00<00<Wo0?ooo`3oool01`3oool00`00bOl0oooo0?oo
o`030?ooo`8000002P3oool200000003003o103oool00?l40080oooo00<00?l40?ooo`00o`@03P3o
ool00`00bOl0oooo0?ooo`0=0?ooo`030039o`000000oooo02L0oooo0P0000000`3oool00<Wo0?oo
o`070?ooo`<000000P3oool01000bOl0oooo0?ooo`00bOlA0?ooo`030039o`3oool00?l400h0oooo
0P00000D0?ooo`040039o`3oool00?l40039o`<0oooo00<00?l40039o`00bOl0203oool02000bOl0
oooo003o1000o`@000000039o`3oool00<Wo0`3oool01@00o`@0oooo003o103oool00?l400800000
0P3oool00`00o`@0oooo0?ooo`0;0?ooo`80odL05P3oool2000000<0oooo000M0?ooo`80odL03P3o
ool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00o`@00`00bOl00?l4003o10020?ooo`D00<Wo
00D00?l40?ooo`3oool0oooo003o10030?ooo`03003o103oool0oooo00@0oooo00@00<Wo0?ooo`3o
ool00<Wo9@3oool00`00o`@0oooo0?ooo`050?ooo`030039o`3oool0oooo00L0oooo00<00<Wo0?oo
o`3oool04@3oool00`00o`@0oooo003o10020?ooo`03003o103oool00?l400l0oooo00<00<Wo0?oo
o`3oool0303oool00`00bOl000000?ooo`0Z0?ooo`030039o`3oool0oooo00/0oooo00@00<Wo0?oo
o`3oool00<Wo403oool01000bOl0oooo0?ooo`00o`@T0?ooo`040039o`3oool00?l40039o`<0oooo
00<00?l40039o`00bOl0203oool02000bOl0oooo003o1000o`@0oooo0039o`3oool00<Wo0`3oool0
1@00o`@0oooo003o103oool00?l400@0oooo00<00?l40?ooo`3oool02`3oool20?m701/0oooo000M
0?ooo`80odL03P3oool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00o`@00`00bOl00?l4003o
10020?ooo`@00<Wo00<0oooo003o103oool00P3oool01@00o`@0oooo0?ooo`3oool00?l400D0oooo
00D00<Wo0?ooo`3oool0oooo0039o`0U0?ooo`03003o103oool0oooo00D0oooo00<00<Wo0?ooo`3o
ool01`3oool00`00bOl0oooo0?ooo`0A0?ooo`03003o103oool00?l40080oooo00@00?l40?ooo`3o
ool00?l43P3oool00`00bOl0oooo0?ooo`0<0?ooo`030039o`000000oooo02X0oooo00<00<Wo0?oo
o`3oool02`3oool01000bOl0oooo0?ooo`00bOl@0?ooo`040039o`3oool0oooo003o12D0oooo00<0
0<Wo003o1000bOl00`3oool00`00o`@00<Wo0039o`080?ooo`080039o`3oool00?l4003o103oool0
0<Wo0?ooo`00bOl30?ooo`05003o103oool00?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;
0?ooo`80odL06`3oool001d0oooo0P3oA`0>0?ooo`800?l4103oool01000bOl0oooo0?ooo`3oool2
003o10040039o`3oool00?l4003o1080oooo1000bOl00`00o`@0oooo0?ooo`020?ooo`05003o103o
ool0oooo0?ooo`00o`@01@3oool01@00bOl0oooo0?ooo`3oool00<Wo02H0oooo00<00?l40?ooo`3o
ool0103oool00`00bOl0oooo0?ooo`070?ooo`030039o`3oool0oooo0180oooo0P00o`@30?ooo`03
003o103oool00?l400h0oooo00<00<Wo0?ooo`3oool0303oool20039ob/0oooo00<00<Wo0?ooo`3o
ool02`3oool00`00bOl0oooo0039o`0A0?ooo`040039o`3oool0oooo003o12D0oooo00<00<Wo003o
1000bOl00`3oool00`00o`@00<Wo0039o`080?ooo`080039o`3oool00?l4003o103oool00<Wo0?oo
o`00bOl30?ooo`05003o103oool00?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;0?ooo`80
odL06`3oool001d0oooo0P3oA`0>0?ooo`800?l4103oool01000bOl0oooo0?ooo`3oool2003o1004
0039o`3oool00?l4003o1080oooo1000bOl00`00o`@0oooo0?ooo`020?ooo`05003o103oool0oooo
0?ooo`00o`@01@3oool01@00bOl0oooo0?ooo`3oool00<Wo02H0oooo00<00?l40?ooo`3oool0103o
ool00`00bOl0oooo0?ooo`070?ooo`030039o`3oool0oooo0180oooo0P00o`@30?ooo`03003o103o
ool00?l400h0oooo00<00<Wo0?ooo`3oool0303oool20039ob/0oooo00<00<Wo0?ooo`3oool02`3o
ool00`00bOl0oooo0039o`0A0?ooo`040039o`3oool0oooo003o12D0oooo00<00<Wo003o1000bOl0
0`3oool00`00o`@00<Wo0039o`080?ooo`080039o`3oool00?l4003o103oool00<Wo0?ooo`00bOl3
0?ooo`05003o103oool00?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;0?ooo`80odL06`3o
ool001d0oooo0P3oA`0>0?ooo`800?l4103oool01000bOl0oooo0?ooo`3oool2003o10040039o`3o
ool00?l4003o1080oooo1000bOl00`00o`@0oooo0?ooo`020?ooo`05003o103oool0oooo0?ooo`00
o`@01@3oool01@00bOl0oooo0?ooo`3oool00<Wo02H0oooo00<00?l40?ooo`3oool0103oool00`00
bOl0oooo0?ooo`070?ooo`030039o`3oool0oooo0180oooo0P00o`@30?ooo`03003o103oool00?l4
00h0oooo00<00<Wo0?ooo`3oool0303oool20039ob/0oooo00<00<Wo0?ooo`3oool02`3oool00`00
bOl0oooo0039o`0A0?ooo`040039o`3oool0oooo003o12D0oooo00<00<Wo003o1000bOl00`3oool0
0`00o`@00<Wo0039o`080?ooo`080039o`3oool00?l4003o103oool00<Wo0?ooo`00bOl30?ooo`05
003o103oool00?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;0?ooo`80odL06`3oool001d0
oooo0P3oA`0>0?ooo`800?l4103oool01000bOl0oooo0?ooo`3oool2003o10040039o`3oool00?l4
003o1080oooo1000bOl00`00o`@0oooo0?ooo`020?ooo`05003o103oool0oooo0?ooo`00o`@01@3o
ool01@00bOl0oooo0?ooo`3oool00<Wo00X0oooo00<00<Wo0?ooo`3oool06@3oool00`00o`@0oooo
0?ooo`040?ooo`030039o`3oool0oooo00L0oooo00<00<Wo0?ooo`3oool04P3oool00`00o`@0oooo
003o10020?ooo`03003o103oool00?l400h0oooo00<00<Wo0?ooo`3oool0303oool20039ob/0oooo
00<00<Wo0?ooo`3oool02`3oool00`00bOl0oooo0039o`0A0?ooo`030039o`3oool00?l402H0oooo
00<00<Wo003o1000bOl00`3oool00`00o`@00<Wo0039o`080?ooo`080039o`3oool00?l4003o103o
ool00<Wo0?ooo`00bOl30?ooo`05003o103oool00?l40?ooo`00o`@0103oool00`00o`@0oooo0?oo
o`0;0?ooo`80odL06`3oool001d0oooo0P3oA`0>0?ooo`800?l4103oool01000bOl0oooo0?ooo`3o
ool2003o10040039o`3oool00?l4003o1080oooo1000bOl00`00o`@0oooo0?ooo`020?ooo`05003o
103oool0oooo0?ooo`00o`@01@3oool01@00bOl0oooo0?ooo`3oool00<Wo00X0oooo00<00<Wo0?oo
o`3oool06@3oool00`00o`@0oooo0?ooo`040?ooo`030039o`3oool0oooo00L0oooo00<00<Wo0?oo
o`3oool04P3oool00`00o`@0oooo003o10020?ooo`03003o103oool00?l400h0oooo00<00<Wo0?oo
o`3oool03@3oool00`00bOl0oooo0?ooo`0Y0?ooo`030039o`3oool0oooo00/0oooo00<00<Wo0?oo
o`00bOl04@3oool00`00bOl0oooo003o100V0?ooo`030039o`00o`@00<Wo00<0oooo00<00?l40039
o`00bOl0203oool02000bOl0oooo003o1000o`@0oooo0039o`3oool00<Wo0`3oool01@00o`@0oooo
003o103oool00?l400@0oooo00<00?l40?ooo`3oool02`3oool20?m701/0oooo00060?oooaL00000
0P3oA`0>000000800?l4100000001000bOl00000000000000002003o10040039o`0000000?l4003o
108000001000bOl00`00o`@000000000000200000005003o10000000000000000000o`@01@000000
1@00bOl000000000000000000<Wo00X0000000<00<Wo0000000000006@0000000`00o`@000000000
0004000000030039o`000000000000L0000000<00<Wo0000000000004P0000000`00o`@00000003o
100200000003003o100000000?l400h0000000<00<Wo0000000000003@0000000`00bOl000000000
000Y000000030039o`000000000000/0000000<00<Wo00000000bOl04@0000000`00bOl00000003o
100V000000030039o`00o`@00<Wo00<0000000<00?l40039o`00bOl0200000002000bOl00000003o
1000o`@000000039o`0000000<Wo0`0000001@00o`@00000003o100000000?l400@0000000<00?l4
0000000000002`0000020?m701P000000`3oool000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`80odL0103oool00`000000oooo0?ooo`07
0?ooo`800?l4103oool01000bOl0oooo0?ooo`000002003o10040039o`3oool00?l4003o1080oooo
1000bOl00`00o`@0oooo0?ooo`020?ooo`05003o103oool000000?ooo`00o`@01@3oool01@00bOl0
oooo0000003oool00<Wo00H0oooo00D000000?ooo`3oool0oooo0039o`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo003o10060?ooo`030039o`3oool0
oooo00L0oooo00<00<Wo0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`0400000000o`@0
oooo003o1080oooo00@00?l40?ooo`00o`@000002@3oool01@000000oooo0?ooo`3oool00<Wo00D0
oooo00<000000?ooo`3oool01`3oool00`00bOl0oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00D00<Wo0?ooo`3oool0oooo000000090?ooo`030039o`3oool00<Wo00L0oooo00<000000?oo
o`3oool01`3oool00`00bOl0oooo003o10060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`050000003oool00<Wo003o1000bOl00`3oool0
0`00o`@00<Wo0039o`080?ooo`080039o`3oool00?l4003o103oool00<Wo0?ooo`00bOl20?ooo`06
00000000o`@0oooo003o103oool00?l4103oool00`00o`@0oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo0P3oA`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`010?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`80odL03P3oool2003o
10@0oooo00@00<Wo0?ooo`3oool000000P00o`@01000bOl0oooo003o1000o`@20?ooo`@00<Wo00<0
0?l40?ooo`3oool00P3oool01@00o`@0oooo0?ooo`3oool00?l400D0oooo00D00<Wo0?ooo`3oool0
oooo0039o`0:0?ooo`030039o`3oool0oooo00<0oooo00<000000?ooo`3oool01P3oool2003o10/0
oooo00<00?l40?ooo`3oool0103oool00`00bOl0oooo0?ooo`070?ooo`030039o`3oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`00o`@0oooo003o10020?ooo`03003o103oool00?l400h0
oooo00<00<Wo0?ooo`3oool03@3oool00`00bOl0oooo0?ooo`0Y0?ooo`050039o`3oool0oooo0?oo
o`0000002@3oool00`00bOl0oooo0039o`0A0?ooo`030039o`3oool00?l40100oooo00<000000?oo
o`3oool04`3oool00`00bOl00?l40039o`030?ooo`03003o1000bOl00<Wo00P0oooo00P00<Wo0?oo
o`00o`@00?l40?ooo`00bOl0oooo0039o`80oooo00H00000003o103oool00?l40?ooo`00o`@40?oo
o`03003o103oool0oooo00/0oooo0P3oA`0G0?ooo`030000003oool0oooo0040oooo000M0?ooo`80
odL03P3oool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0P00o`@01000bOl0oooo003o1000o`@2
0?ooo`@00<Wo00<00?l40?ooo`3oool00P3oool01@00o`@0oooo0?ooo`3oool00?l400D0oooo00D0
0<Wo0?ooo`3oool0oooo0039o`0:0?ooo`030039o`3oool0oooo00`0oooo0`00o`@90?ooo`03003o
103oool0oooo00D0oooo00<00<Wo0?ooo`3oool01`3oool00`00bOl0oooo0?ooo`0B0?ooo`03003o
103oool00?l40080oooo00<00?l40?ooo`00o`@03P3oool00`00bOl0oooo0?ooo`0=0?ooo`030039
o`3oool0oooo02T0oooo00<00<Wo0?ooo`3oool02`3oool00`00bOl0oooo0039o`0A0?ooo`040039
o`3oool0oooo003o12D0oooo00<00<Wo003o1000bOl00`3oool00`00o`@00<Wo0039o`080?ooo`08
0039o`3oool00?l4003o103oool00<Wo0?ooo`00bOl30?ooo`05003o103oool00?l40?ooo`00o`@0
103oool00`00o`@0oooo0?ooo`0;0?ooo`80odL06`3oool001d0oooo0P3oA`0>0?ooo`800?l4103o
ool01000bOl0oooo0?ooo`3oool2003o10040039o`3oool00?l4003o1080oooo1000bOl00`00o`@0
oooo0?ooo`020?ooo`05003o103oool0oooo0?ooo`00o`@01P3oool01000bOl0oooo0?ooo`00bOl:
0?ooo`030039o`3oool0oooo00`0oooo00<00?l40?ooo`00o`@02@3oool00`00o`@0oooo0?ooo`05
0?ooo`030039o`3oool0oooo00H0oooo00<00<Wo0?ooo`3oool04P3oool00`00o`@0oooo003o1003
0?ooo`03003o103oool00?l400h0oooo00<00<Wo0?ooo`3oool03@3oool00`00bOl0oooo0?ooo`0Y
0?ooo`030039o`3oool0oooo00/0oooo00<00<Wo0?ooo`00bOl04@3oool01000bOl0oooo0?ooo`00
o`@U0?ooo`030039o`00o`@00<Wo00<0oooo00<00?l40039o`00bOl0203oool02000bOl0oooo003o
1000o`@0oooo0039o`3oool00<Wo0`3oool01@00o`@0oooo003o103oool00?l400@0oooo00<00?l4
0?ooo`3oool02`3oool20?m701/0oooo000M0?ooo`80odL03P3oool2003o10@0oooo00@00<Wo0?oo
o`3oool0oooo0`00o`@00`00bOl00?l4003o10020?ooo`@00<Wo00<00?l40?ooo`3oool00P3oool0
1@00o`@0oooo0?ooo`3oool00?l400H0oooo00@00<Wo0?ooo`3oool00<Wo2@3oool20039o`d0oooo
00<00?l40?ooo`3oool00P00o`@80?ooo`03003o103oool0oooo00D0oooo00<00<Wo0?ooo`3oool0
1P3oool00`00bOl0oooo0?ooo`0B0?ooo`03003o103oool00?l40080oooo00@00?l40?ooo`3oool0
0?l43P3oool00`00bOl0oooo0?ooo`0<0?ooo`800<Wo:`3oool00`00bOl0oooo0?ooo`0;0?ooo`03
0039o`3oool00<Wo0140oooo00@00<Wo0?ooo`3oool00?l49@3oool00`00bOl00?l40039o`030?oo
o`03003o1000bOl00<Wo00P0oooo00P00<Wo0?ooo`00o`@00?l40?ooo`00bOl0oooo0039o`<0oooo
00D00?l40?ooo`00o`@0oooo003o10040?ooo`03003o103oool0oooo00/0oooo0P3oA`0K0?ooo`00
7P3oool00`3oA`00oooo0?ooo`0<0?ooo`800?l4103oool01000bOl0oooo0?ooo`3oool3003o1003
0039o`00o`@00?l40080oooo1000bOl00`00o`@0oooo0?ooo`020?ooo`05003o103oool0oooo0?oo
o`00o`@01P3oool01000bOl0oooo0?ooo`00bOl90?ooo`800<Wo3@3oool01@00o`@0oooo0?ooo`3o
ool00?l400L0oooo00<00?l40?ooo`3oool01P3oool00`00bOl0oooo0?ooo`060?ooo`030039o`3o
ool0oooo0140oooo00@00?l40?ooo`3oool00?l40P3oool00`00o`@0oooo003o100?0?ooo`030039
o`3oool0oooo00`0oooo0P00bOl[0?ooo`030039o`3oool0oooo00/0oooo00<00<Wo0?ooo`00bOl0
4@3oool01000bOl0oooo0?ooo`00o`@U0?ooo`030039o`00o`@00<Wo00<0oooo00<00?l40039o`00
bOl0203oool02000bOl0oooo003o1000o`@0oooo0039o`3oool00<Wo0`3oool01@00o`@0oooo003o
103oool00?l400@0oooo00<00?l40?ooo`3oool02`3oool20?m701/0oooo000N0?ooo`030?m7003o
ool0oooo00`0oooo0P00o`@40?ooo`040039o`3oool0oooo0?ooo`<00?l400<00<Wo003o1000o`@0
0P3oool50039o`@0oooo00D00?l40?ooo`3oool0oooo003o10060?ooo`050039o`3oool0oooo0?oo
o`00bOl01`3oool01000bOl0oooo0?ooo`00bOl;0?ooo`03003o103oool0oooo00<0oooo00<00?l4
0?ooo`3oool0103oool00`00o`@0oooo0?ooo`060?ooo`030039o`3oool0oooo00H0oooo00<00<Wo
0?ooo`3oool04@3oool00`00o`@0oooo003o10030?ooo`03003o103oool00?l400h0oooo00<00<Wo
0?ooo`3oool03@3oool20039ob/0oooo00<00<Wo0?ooo`3oool02`3oool01000bOl0oooo0?ooo`00
bOlA0?ooo`030039o`3oool00?l402@0oooo00@00<Wo0?ooo`00o`@00<Wo0`3oool00`00o`@00<Wo
0039o`080?ooo`080039o`3oool00?l4003o103oool00<Wo0?ooo`00bOl30?ooo`05003o103oool0
0?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;0?ooo`80odL06`3oool001h0oooo00<0odL0
0?ooo`3oool0303oool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00o`@00`00bOl0oooo003o
10020?ooo`D00<Wo103oool01@00o`@0oooo0?ooo`3oool00?l400H0oooo00D00<Wo0?ooo`3oool0
oooo0039o`070?ooo`040039o`3oool0oooo0039o`/0oooo00<00?l40?ooo`3oool0103oool2003o
10<0oooo00<00?l40?ooo`3oool01`3oool00`00bOl0oooo0?ooo`050?ooo`030039o`3oool0oooo
0140oooo00@00?l40?ooo`3oool00?l40`3oool00`00o`@0oooo003o100>0?ooo`030039o`3oool0
oooo00`0oooo0P00bOl00`000000oooo0?ooo`0Y0?ooo`030039o`3oool0oooo00/0oooo00@00<Wo
0?ooo`3oool00<Wo4@3oool00`00bOl0oooo003o100T0?ooo`040039o`3oool00?l40039o`<0oooo
00<00?l40039o`00bOl0203oool01@00bOl0oooo003o1000o`@00<Wo0080oooo00T00<Wo0?ooo`3o
ool0oooo003o103oool00?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;0?ooo`80odL06`3o
ool001h0oooo00<0odL00?ooo`3oool0303oool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00
o`@00`00bOl0oooo003o10020?ooo`D00<Wo00D00?l40?ooo`3oool0oooo003o10030?ooo`03003o
103oool0oooo00@0oooo00@00<Wo0?ooo`3oool0oooo0P00bOl50?ooo`030039o`3oool0oooo0080
oooo00<00<Wo0?ooo`3oool01`3oool00`00o`@0oooo0?ooo`070?ooo`<00?l42@3oool00`00bOl0
oooo0?ooo`060?ooo`030039o`3oool0oooo0100oooo00@00?l40?ooo`3oool00?l4103oool00`00
o`@0oooo003o100>0?ooo`030039o`3oool0oooo00`0oooo0P00bOl00`000000oooo0?ooo`0Y0?oo
o`030039o`3oool0oooo00/0oooo00@00<Wo0?ooo`3oool00<Wo4@3oool00`00bOl0oooo003o100T
0?ooo`040039o`3oool00?l40039o`<0oooo00<00?l40039o`3oool0203oool01@00bOl0oooo003o
1000o`@00<Wo0080oooo00@00<Wo0?ooo`3oool00?l40P3oool00`00o`@0oooo003o10040?ooo`03
003o103oool0oooo00/0oooo00<0odL00?ooo`3oool06P3oool001h0oooo00<0odL00?ooo`3oool0
303oool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00o`@00`00bOl0oooo003o10020?ooo`80
0<Wo00@0oooo0039o`00bOl00?l40`3oool01@00o`@0oooo0?ooo`3oool00?l400H0oooo00<00<Wo
0?ooo`3oool00`3oool01000bOl0oooo0?ooo`3oool20039o`@0oooo00<00<Wo0?ooo`3oool01`3o
ool00`00o`@0oooo0?ooo`0C0?ooo`030039o`3oool0oooo00H0oooo00<00<Wo0?ooo`3oool03`3o
ool01@00o`@0oooo0?ooo`3oool00?l400@0oooo00<00?l40?ooo`00o`@03P3oool00`00bOl0oooo
0?ooo`0<0?ooo`800<Wo0P00000Z0?ooo`030039o`3oool0oooo00/0oooo00@00<Wo0?ooo`3oool0
0<Wo4@3oool00`00bOl0oooo003o100T0?ooo`040039o`00o`@0oooo0039o`80oooo00<00?l40?oo
o`00bOl02@3oool01@00bOl0oooo003o1000o`@00<Wo0080oooo00@00<Wo0?ooo`3oool00?l40P3o
ool00`00o`@0oooo003o10040?ooo`03003o103oool0oooo00/0oooo00<0odL00?ooo`3oool06P3o
ool001h0oooo00<0odL00?ooo`3oool0303oool2003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00
o`@00`00bOl0oooo003o10020?ooo`800<Wo00@0oooo0039o`00bOl00?l40`3oool00`00o`@0oooo
0?ooo`020?ooo`03003o103oool0oooo00<0oooo00<00<Wo0?ooo`3oool0103oool30039o`L0oooo
00<00<Wo0?ooo`3oool01@3oool00`00o`@0oooo0?ooo`0D0?ooo`030039o`3oool0oooo00D0oooo
00<00<Wo0?ooo`3oool03P3oool2003o10<0oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo
003o100=0?ooo`030039o`3oool0oooo00`0oooo0P00bOl00`3oool000000?ooo`0Z0?ooo`030039
o`3oool0oooo00/0oooo00@00<Wo0?ooo`3oool00<Wo4P3oool00`00bOl0oooo003o100S0?ooo`04
0039o`00o`@0oooo0039o`80oooo00<00?l40?ooo`00bOl02@3oool01@00bOl0oooo003o1000o`@0
0<Wo0080oooo00@00<Wo0?ooo`3oool00?l40P3oool00`00o`@0oooo003o10040?ooo`03003o103o
ool0oooo00/0oooo00<0odL00?ooo`3oool06P3oool001h0oooo00<0odL00?ooo`3oool0303oool2
003o10@0oooo00@00<Wo0?ooo`3oool0oooo0`00o`@00`00bOl0oooo003o10020?ooo`800<Wo00@0
oooo0039o`00bOl00?l40`3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00<0oooo
00<00<Wo0?ooo`3oool03`3oool00`00bOl0oooo0?ooo`030?ooo`03003o103oool0oooo01D0oooo
00<00<Wo0?ooo`3oool01@3oool00`00bOl0oooo0?ooo`0=0?ooo`03003o103oool0oooo00<0oooo
00<00?l40?ooo`3oool00`3oool00`00o`@0oooo003o100=0?ooo`030039o`3oool0oooo00`0oooo
0P00bOl00`3oool000000?ooo`0[0?ooo`030039o`3oool0oooo00X0oooo00D00<Wo0?ooo`3oool0
oooo0039o`0A0?ooo`030039o`3oool00?l402<0oooo00@00<Wo003o103oool00<Wo0P3oool00`00
o`@00<Wo0039o`090?ooo`050039o`3oool00?l4003o1000bOl00P3oool01P00bOl0oooo0?ooo`00
o`@0oooo003o1080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0;0?ooo`030?m7
003oool0oooo01X0oooo000N0?ooo`030?m7003oool0oooo00`0oooo0P00o`@40?ooo`030039o`3o
ool0oooo0080oooo0P00o`@00`00bOl0oooo003o10020?ooo`800<Wo00@0oooo0039o`00bOl00?l4
103oool01@00o`@0oooo0?ooo`3oool00?l400H0oooo00<00<Wo0?ooo`3oool03P3oool00`00bOl0
oooo0?ooo`030?ooo`03003o103oool0oooo01D0oooo00<00<Wo0?ooo`3oool01@3oool00`00bOl0
oooo0?ooo`0;0?ooo`800?l41@3oool00`00o`@0oooo0?ooo`030?ooo`03003o103oool00?l400h0
oooo00<00<Wo0?ooo`3oool0303oool20039o`030?ooo`000000oooo02/0oooo00<00<Wo0?ooo`3o
ool02`3oool01000bOl0oooo0?ooo`00bOlA0?ooo`030039o`3oool00?l402<0oooo00@00<Wo003o
103oool00<Wo0P3oool00`00o`@00<Wo0039o`080?ooo`030039o`3oool0oooo00800?l400@00<Wo
0?ooo`3oool00<Wo0P3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080oooo00<0
0?l40?ooo`3oool02`3oool00`3oA`00oooo0?ooo`0J0?ooo`007P3oool00`3oA`00oooo0?ooo`0<
0?ooo`800?l4103oool00`00bOl0oooo0?ooo`020?ooo`800?l400<00<Wo0?ooo`00o`@00P3oool2
0039o`040?ooo`00bOl00<Wo003o10@0oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?oo
o`030?ooo`030039o`3oool0oooo00l0oooo00D00<Wo0?ooo`3oool0oooo003o100G0?ooo`030039
o`3oool0oooo00D0oooo00<00<Wo0?ooo`3oool02`3oool00`00o`@0oooo0?ooo`030?ooo`800?l4
1P3oool00`00o`@0oooo003o100=0?ooo`030039o`3oool0oooo00`0oooo0P00bOl20?ooo`030000
003oool0oooo02X0oooo00<00<Wo0?ooo`3oool02`3oool01000bOl0oooo0?ooo`00bOlA0?ooo`04
0039o`3oool0oooo003o1280oooo00@00<Wo0?ooo`3oool00<Wo0P3oool00`00o`@00<Wo0039o`08
0?ooo`030039o`3oool0oooo00800?l400<00<Wo0?ooo`00bOl00`3oool00`00o`@0oooo003o1002
0?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool02`3oool00`3oA`00oooo0?ooo`0J
0?ooo`007P3oool00`3oA`00oooo0?ooo`0<0?ooo`800?l4103oool00`00bOl0oooo0?ooo`020?oo
o`800?l400<00<Wo0?ooo`00o`@00P3oool20039o`050?ooo`00bOl00<Wo0039o`00o`@00`3oool0
0`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00<0oooo00<00<Wo0?ooo`3oool0403oool0
1000bOl0oooo0?ooo`00o`@G0?ooo`030039o`3oool0oooo00D0oooo00<00<Wo0?ooo`3oool02P3o
ool00`00o`@0oooo0?ooo`030?ooo`03003o103oool0oooo00D0oooo00<00?l40?ooo`00o`@03P3o
ool00`00bOl0oooo0?ooo`0<0?ooo`800<Wo0P3oool00`000000oooo0?ooo`0Z0?ooo`030039o`3o
ool0oooo00`0oooo00<00<Wo0?ooo`00bOl04@3oool01000bOl0oooo0?ooo`00o`@Q0?ooo`040039
o`00o`@0oooo0039o`<0oooo00<00?l40039o`00bOl0203oool00`00bOl0oooo0?ooo`02003o1003
0039o`3oool00<Wo00<0oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`020?ooo`03
003o103oool0oooo00/0oooo00<0odL00?ooo`3oool06P3oool001h0oooo00<0odL00?ooo`3oool0
303oool2003o10@0oooo00<00<Wo0?ooo`3oool00P3oool2003o10030039o`3oool00?l400<0oooo
1@00bOl00`00o`@0oooo0?ooo`020?ooo`05003o103oool0oooo0?ooo`00o`@01@3oool00`00bOl0
oooo0?ooo`0@0?ooo`030039o`3oool00?l401P0oooo00<00<Wo0?ooo`3oool0103oool00`00bOl0
oooo0?ooo`0:0?ooo`03003o103oool0oooo00<0oooo00<00?l40?ooo`3oool01P3oool00`00o`@0
oooo003o100>0?ooo`030039o`3oool0oooo00/0oooo0P00bOl30?ooo`030000003oool0oooo02/0
oooo00<00<Wo0?ooo`3oool02`3oool01000bOl0oooo0?ooo`00bOlA0?ooo`030039o`3oool00?l4
0240oooo00@00<Wo003o103oool00<Wo0P3oool01000o`@0oooo0039o`00bOl80?ooo`030039o`3o
ool0oooo00800?l400<00<Wo0?ooo`00bOl00`3oool00`00o`@0oooo003o10020?ooo`03003o103o
ool0oooo0080oooo00<00?l40?ooo`3oool02P3oool20?m701`0oooo000N0?ooo`030?m7003oool0
oooo00`0oooo0P00o`@40?ooo`030039o`3oool0oooo0080oooo0P00o`@00`00bOl0oooo003o1003
0?ooo`D00<Wo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0
oooo0080oooo00<00<Wo0?ooo`3oool04@3oool00`00bOl00?l40?ooo`0F0?ooo`030039o`3oool0
oooo00@0oooo00<00<Wo0?ooo`3oool02P3oool00`00o`@0oooo0?ooo`020?ooo`800?l42@3oool0
0`00o`@0oooo003o100>0?ooo`030039o`3oool0oooo00X0oooo00<00<Wo0?ooo`00bOl00`3oool0
0`000000oooo0?ooo`0[0?ooo`030039o`3oool0oooo00/0oooo00@00<Wo0?ooo`3oool00<Wo4@3o
ool00`00bOl0oooo003o100Q0?ooo`040039o`00o`@0oooo0039o`80oooo00<00?l40?ooo`00bOl0
2@3oool00`00bOl0oooo0?ooo`02003o10030039o`3oool00<Wo00<0oooo00<00?l40?ooo`00o`@0
0P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00X0oooo0P3oA`0L0?ooo`007P3o
ool00`3oA`00oooo0?ooo`0<0?ooo`800?l41@3oool01000bOl0oooo0?ooo`3oool2003o10040039
o`3oool00?l4003o1080oooo1@00bOl00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo0080
oooo00<00?l40?ooo`3oool00`3oool00`00bOl0oooo0?ooo`0?0?ooo`800?l40P00bOlF0?ooo`03
0039o`3oool0oooo0080oooo0P00bOl;0?ooo`800?l40`3oool2003o10/0oooo0P00o`@>0?ooo`03
0039o`3oool0oooo00/0oooo0P00bOl40?ooo`030000003oool0oooo02/0oooo00<00<Wo0?ooo`3o
ool02`3oool01000bOl0oooo0?ooo`00bOlA0?ooo`040039o`3oool0oooo003o1200oooo00@00<Wo
003o103oool00<Wo0P3oool00`00o`@0oooo0039o`090?ooo`080039o`3oool00?l40?ooo`00o`@0
0<Wo0?ooo`00bOl30?ooo`03003o103oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00
o`@0oooo0?ooo`0:0?ooo`80odL0703oool001h0oooo0P3oA`0=0?ooo`800?l41@3oool01000bOl0
oooo0?ooo`3oool2003o10040039o`3oool0oooo003o1080oooo1@00bOl00`00o`@0oooo0?ooo`02
0?ooo`03003o103oool0oooo00<0oooo00<00?l40?ooo`3oool00P3oool00`00bOl0oooo0?ooo`0>
0?ooo`03003o103oool0oooo0080oooo00<00<Wo0?ooo`3oool04`3oool01@00bOl0oooo0?ooo`3o
ool00<Wo00`0oooo00@00?l40?ooo`3oool0oooo0P00o`@<0?ooo`03003o103oool00?l400h0oooo
00<00<Wo0?ooo`3oool02P3oool20039o`D0oooo0P00000]0?ooo`030039o`3oool0oooo00X0oooo
00D00<Wo0?ooo`3oool0oooo0039o`0A0?ooo`030039o`3oool00?l40200oooo00@00<Wo0?ooo`3o
ool00<Wo0P3oool00`00o`@00<Wo0039o`080?ooo`030039o`3oool0oooo00800?l400@0oooo0039
o`3oool00<Wo0`3oool01@00o`@0oooo003o103oool00?l400D0oooo00<00?l40?ooo`3oool02P3o
ool20?m701`0oooo000N0?ooo`80odL03@3oool2003o10D0oooo00X00<Wo0?ooo`3oool0oooo003o
103oool00?l40039o`3oool00?l40P3oool40039o`03003o1000bOl0oooo00@0oooo00<00?l40?oo
o`3oool00`3oool01@00o`@0oooo0?ooo`3oool00<Wo0100oooo00<00?l40?ooo`3oool00`3oool2
0039oa<0oooo00@00<Wo0?ooo`3oool00<Wo303oool01@00o`@0oooo0?ooo`3oool00?l400h0oooo
00<00?l40?ooo`00o`@03@3oool00`00bOl0oooo0?ooo`0:0?ooo`030039o`3oool00<Wo00D0oooo
00<000000?ooo`3oool0;03oool00`00bOl0oooo0?ooo`0;0?ooo`040039o`3oool0oooo0039oa40
oooo00<00<Wo0?ooo`00o`@07`3oool01000bOl00?l40?ooo`00bOl30?ooo`03003o1000bOl00<Wo
00P0oooo00<00<Wo0?ooo`3oool00P00o`@0103oool00<Wo003o1000bOl30?ooo`05003o103oool0
0?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;0?ooo`80odL0703oool001h0oooo0P3oA`0=
0?ooo`800?l41@3oool02P00bOl0oooo0?ooo`3oool00?l40?ooo`00o`@00<Wo0?ooo`00o`@30?oo
o`<00<Wo00<00?l40039o`3oool0103oool00`00o`@0oooo0?ooo`030?ooo`05003o103oool0oooo
0?ooo`00bOl03P3oool2003o10P0oooo0P00bOl@0?ooo`040039o`3oool00<Wo0039o``0oooo00<0
0?l40?ooo`3oool00P00o`@?0?ooo`800?l43P3oool00`00bOl0oooo0?ooo`0:0?ooo`800<Wo1P3o
ool00`000000oooo0?ooo`0/0?ooo`030039o`3oool0oooo00/0oooo00@00<Wo0?ooo`3oool00<Wo
4P3oool00`00bOl00?l40?ooo`0N0?ooo`040039o`00o`@0oooo0039o`80oooo00@00?l40?ooo`00
bOl00<Wo203oool00`00bOl0oooo0?ooo`02003o10040?ooo`00bOl00?l40039o`<0oooo00D00?l4
0?ooo`00o`@0oooo003o10040?ooo`03003o103oool0oooo00/0oooo0P3oA`0L0?ooo`007P3oool2
0?m700d0oooo0P00o`@50?ooo`0:0039o`3oool0oooo0?ooo`00o`@0oooo003o1000bOl0oooo003o
10<0oooo0`00bOl00`00o`@00<Wo003o10040?ooo`03003o103oool0oooo00@0oooo00D00?l40?oo
o`3oool0oooo0039o`0<0?ooo`03003o103oool0oooo00X0oooo0P00bOl=0?ooo`<00<Wo303oool2
003o10030?ooo`00o`@00?l40140oooo0P00o`@=0?ooo`030039o`3oool0oooo00X0oooo0P00bOl7
0?ooo`030000003oool0oooo02d0oooo00<00<Wo0?ooo`3oool02P3oool01@00bOl0oooo0?ooo`3o
ool00<Wo0140oooo00<00<Wo0?ooo`00o`@07P3oool01000bOl00?l40?ooo`00bOl20?ooo`04003o
1000bOl00<Wo0039o`P0oooo00<00<Wo0?ooo`3oool00P00o`@01000bOl0oooo003o1000bOl30?oo
o`05003o103oool00?l40?ooo`00o`@0103oool00`00o`@0oooo0?ooo`0;0?ooo`80odL0703oool0
01h0oooo0P3oA`0=0?ooo`03003o103oool00?l400@0oooo00X00<Wo0?ooo`3oool0oooo003o103o
ool00?l40039o`3oool00?l40`3oool50039o`03003o103oool0oooo00<0oooo00<00?l40?ooo`3o
ool0103oool01000o`@0oooo0?ooo`00bOl:0?ooo`800?l43`3oool>0039o`d0oooo00@00?l40?oo
o`00o`@00?l44P3oool2003o10d0oooo00<00<Wo0?ooo`3oool02`3oool20039o`L0oooo00<00000
0?ooo`3oool0;@3oool00`00bOl0oooo0?ooo`0;0?ooo`040039o`3oool0oooo0039oa40oooo00<0
0<Wo0?ooo`00o`@07P3oool01`00bOl0oooo0?ooo`00bOl0oooo003o103oool00P00bOl90?ooo`03
0039o`3oool0oooo00800?l400<00<Wo0?ooo`00bOl00`3oool00`00o`@0oooo003o10020?ooo`03
003o103oool0oooo0080oooo00<00?l40?ooo`3oool02`3oool20?m701`0oooo000N0?ooo`80odL0
3P3oool2003o10D0oooo00P00<Wo0?ooo`3oool00?l40?ooo`00o`@00<Wo0?ooo`800?l40P3oool5
0039o`03003o103oool0oooo00<0oooo00<00?l40?ooo`3oool01@3oool2003o10030039o`3oool0
oooo00L0oooo00<00?l40?ooo`3oool0703oool00`00bOl0oooo0?ooo`0:0?ooo`<00?l4503oool2
003o10d0oooo00<00<Wo0?ooo`3oool02P3oool20039o`P0oooo00<000000?ooo`3oool0;@3oool0
0`00bOl0oooo0?ooo`0;0?ooo`050039o`3oool0oooo0?ooo`00bOl04@3oool00`00bOl0oooo003o
100L0?ooo`040039o`00o`@0oooo0039o`80oooo00@00?l40?ooo`00bOl00<Wo203oool20039o`80
oooo0P00o`@00`00bOl0oooo0039o`030?ooo`03003o103oool00?l40080oooo00<00?l40?ooo`3o
ool00P3oool00`00o`@0oooo0?ooo`0;0?ooo`80odL0703oool001h0oooo0P3oA`0>0?ooo`800?l4
1@3oool01000bOl0oooo0?ooo`3oool2003o10040039o`3oool0oooo003o1080oooo1000bOl00`00
o`@00<Wo0?ooo`040?ooo`03003o103oool0oooo00L0oooo00<00?l40039o`00o`@00`3oool4003o
11h0oooo00<00<Wo0?ooo`3oool02P3oool2003o11D0oooo0P00o`@=0?ooo`030039o`3oool0oooo
00X0oooo0P00bOl90?ooo`030000003oool0oooo02h0oooo00<00<Wo0?ooo`3oool02`3oool01000
bOl0oooo0?ooo`00bOlA0?ooo`040039o`3oool0oooo003o11/0oooo00H00<Wo003o103oool00<Wo
0?ooo`00o`@20?ooo`800<Wo203oool01000bOl0oooo0?ooo`3oool2003o10030039o`3oool00<Wo
00<0oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo
00/0oooo0P3oA`0L0?ooo`007P3oool20?m700h0oooo0P00o`@50?ooo`070039o`3oool0oooo0?oo
o`00o`@0oooo0039o`020?ooo`04003o103oool0oooo0?ooo`<00<Wo00<00?l40039o`3oool01@3o
ool00`00o`@0oooo0?ooo`070?ooo`030039o`3oool00?l400800?l48@3oool00`00bOl0oooo0?oo
o`0:0?ooo`03003o103oool0oooo01D0oooo0P00o`@=0?ooo`030039o`3oool0oooo00T0oooo0P00
bOl:0?ooo`030000003oool0oooo02h0oooo00<00<Wo0?ooo`3oool02`3oool01000bOl0oooo0?oo
o`00bOlB0?ooo`030039o`3oool00?l401/0oooo00L00<Wo003o103oool00<Wo0?ooo`00o`@0oooo
00<00<Wo203oool02@00bOl0oooo0?ooo`00o`@0oooo003o1000bOl0oooo0039o`030?ooo`03003o
103oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0;0?ooo`80odL0
703oool001h0oooo0P3oA`0>0?ooo`800?l41@3oool01`00bOl0oooo0?ooo`3oool00?l40?ooo`00
bOl00P3oool01000o`@0oooo0?ooo`3oool50039o`H0oooo00<00?l40?ooo`3oool01`3oool00`00
bOl0oooo0?ooo`0S0?ooo`030039o`3oool0oooo00P0oooo0`00o`@F0?ooo`800?l43@3oool00`00
bOl0oooo0?ooo`0:0?ooo`030039o`3oool0oooo00T0oooo00<000000?ooo`3oool0;`3oool00`00
bOl0oooo0?ooo`0;0?ooo`040039o`3oool0oooo0039oa80oooo00<00<Wo0?ooo`00o`@06@3oool0
1P00bOl00?l40?ooo`3oool00<Wo003o1080oooo0P00bOl90?ooo`030039o`3oool0oooo00800?l4
00@00<Wo0?ooo`3oool00<Wo0`3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080
oooo00<00?l40?ooo`3oool02`3oool20?m701`0oooo000N0?ooo`<0odL03@3oool2003o10D0oooo
00L00<Wo0?ooo`3oool0oooo003o103oool00<Wo0080oooo0P00o`@20?ooo`800<Wo00<0oooo0039
o`00bOl01`3oool00`00o`@0oooo0?ooo`070?ooo`030039o`3oool0oooo0240oooo00<00<Wo0?oo
o`3oool0203oool00`00o`@0oooo003o100F0?ooo`03003o103oool00?l400d0oooo00<00<Wo0?oo
o`3oool02@3oool00`00bOl0oooo0?ooo`0:0?ooo`030000003oool0oooo02l0oooo00<00<Wo0?oo
o`3oool02`3oool01000bOl0oooo0?ooo`00bOlB0?ooo`040039o`3oool0oooo003o11P0oooo00D0
0<Wo003o103oool00<Wo003o10030?ooo`800<Wo2@3oool00`00bOl0oooo0?ooo`02003o10040039
o`3oool00<Wo003o10<0oooo00D00?l40?ooo`00o`@0oooo003o10050?ooo`03003o103oool0oooo
00X0oooo0`3oA`0L0?ooo`007P3oool30?m700d0oooo0P00o`@50?ooo`090039o`3oool0oooo0?oo
o`00o`@0oooo003o1000bOl0oooo00800?l40P3oool50039o`L0oooo00<00?l40?ooo`3oool0203o
ool00`00bOl0oooo0?ooo`0O0?ooo`030039o`3oool0oooo00H0oooo1@00o`@G0?ooo`800?l43@3o
ool00`00bOl0oooo0?ooo`090?ooo`800<Wo303oool200000340oooo00<00<Wo0?ooo`3oool02`3o
ool00`00bOl0oooo0039o`0C0?ooo`040039o`3oool0oooo003o11H0oooo00H00<Wo0?ooo`00o`@0
oooo0039o`00o`@20?ooo`<00<Wo2@3oool00`00bOl0oooo0?ooo`02003o10040039o`3oool00<Wo
003o1080oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0
oooo00/0oooo0`3oA`0L0?ooo`007P3oool30?m700d0oooo00<00?l40?ooo`00o`@01@3oool02000
bOl0oooo0?ooo`00o`@0oooo003o1000bOl0oooo0P00o`@30?ooo`<00<Wo00<00?l40039o`3oool0
1P3oool00`00o`@0oooo0?ooo`080?ooo`030039o`3oool0oooo01h0oooo00<00<Wo0?ooo`3oool0
103oool2003o1080oooo00<00?l40?ooo`3oool05P3oool00`00o`@0oooo003o100<0?ooo`030039
o`3oool0oooo00T0oooo0P00bOl=0?ooo`030000003oool0oooo0300oooo00<00<Wo0?ooo`3oool0
2`3oool01000bOl0oooo0?ooo`00bOlC0?ooo`030039o`3oool00?l401H0oooo00D00<Wo003o103o
ool0oooo0039o`030?ooo`<00<Wo203oool01P00bOl0oooo0?ooo`00o`@0oooo0039o`80oooo00L0
0<Wo003o103oool0oooo003o103oool00?l40080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0
oooo0?ooo`0;0?ooo`<0odL0703oool001l0oooo0P3oA`0=0?ooo`03003o103oool00?l400D0oooo
00@00<Wo0?ooo`3oool0oooo0P00o`@01000bOl0oooo003o1000o`@30?ooo`<00<Wo00<00?l40039
o`3oool01`3oool00`00o`@0oooo0?ooo`070?ooo`030039o`3oool0oooo01d0oooo00<00<Wo0?oo
o`3oool0103oool01@00o`@0oooo0?ooo`3oool00?l401P0oooo00<00?l40?ooo`00o`@03@3oool0
0`00bOl0oooo0?ooo`080?ooo`800<Wo3P3oool00`000000oooo0?ooo`0a0?ooo`030039o`3oool0
oooo00X0oooo00@00<Wo0?ooo`3oool00<Wo4`3oool01000bOl0oooo0?ooo`00o`@D0?ooo`060039
o`3oool00?l40?ooo`00bOl00?l40P3oool00`00bOl0oooo0039o`090?ooo`060039o`3oool0oooo
003o103oool00<Wo0P3oool01`00bOl0oooo0?ooo`3oool00?l40?ooo`00o`@00P3oool00`00o`@0
oooo0?ooo`020?ooo`03003o103oool0oooo00/0oooo0`3oA`0L0?ooo`007`3oool20?m700d0oooo
00<00?l40?ooo`00o`@01@3oool01000bOl0oooo0?ooo`3oool2003o10040039o`3oool0oooo003o
10<0oooo00<00<Wo003o1000bOl00P00bOl90?ooo`03003o103oool0oooo00L0oooo00<00<Wo0?oo
o`3oool06`3oool00`00bOl0oooo0?ooo`040?ooo`05003o103oool0oooo0?ooo`00o`@06@3oool2
003o10d0oooo00<00<Wo0?ooo`3oool0203oool20039o`l0oooo00<000000?ooo`3oool0<@3oool0
0`00bOl0oooo0?ooo`0;0?ooo`040039o`3oool0oooo0039oa<0oooo00@00<Wo0?ooo`3oool00?l4
4`3oool01@00bOl00?l40?ooo`3oool00<Wo0080oooo00@00<Wo0?ooo`00bOl00<Wo2@3oool01P00
bOl0oooo0?ooo`00o`@0oooo0039o`80oooo00L00<Wo0?ooo`3oool0oooo003o103oool00?l40080
oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0;0?ooo`80odL07@3oool001l0oooo
0P3oA`0>0?ooo`800?l41@3oool02@00bOl0oooo0?ooo`3oool00?l40?ooo`00o`@00<Wo0?ooo`02
003o10<0oooo1000bOl00`00o`@0oooo0?ooo`060?ooo`03003o103oool0oooo00P0oooo00<00<Wo
0?ooo`3oool06@3oool00`00bOl0oooo0?ooo`040?ooo`05003o103oool0oooo0?ooo`00o`@06@3o
ool00`00o`@0oooo003o100<0?ooo`030039o`3oool0oooo00P0oooo0P00bOl@0?ooo`030000003o
ool0oooo0380oooo00<00<Wo0?ooo`3oool02P3oool01@00bOl0oooo0?ooo`3oool00<Wo0180oooo
00D00<Wo0?ooo`3oool0oooo003o100A0?ooo`060039o`3oool00?l40?ooo`00bOl00?l40P3oool0
1000bOl0oooo0039o`00bOl90?ooo`030039o`3oool0oooo00800?l400@00<Wo0?ooo`3oool00<Wo
0`3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool0
2`3oool20?m701d0oooo000O0?ooo`80odL03P3oool00`00o`@0oooo003o10040?ooo`090039o`3o
ool0oooo0?ooo`00o`@0oooo003o1000bOl0oooo00800?l40`3oool30039o`03003o1000bOl0oooo
00P0oooo00<00?l40?ooo`3oool01`3oool00`00bOl0oooo0?ooo`0G0?ooo`800<Wo1@3oool2003o
10<0oooo00<00?l40?ooo`3oool0603oool2003o10P0oooo4P00bOl@0?ooo`030000003oool0oooo
0380oooo00<00<Wo0?ooo`3oool02`3oool01000bOl0oooo0?ooo`00bOlC0?ooo`050039o`3oool0
oooo0?ooo`00o`@0403oool01@00bOl00?l40?ooo`3oool00<Wo0080oooo00@00<Wo0?ooo`3oool0
0<Wo2@3oool01000bOl0oooo0?ooo`3oool2003o10040039o`3oool00<Wo003o10<0oooo00<00?l4
0?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00/0oooo0P3oA`0M
0?ooo`007`3oool20?m700h0oooo00<00?l40?ooo`00o`@0103oool00`00bOl0oooo0?ooo`020?oo
o`800?l400@00<Wo0?ooo`00o`@00?l40`3oool01@00bOl00?l40039o`00o`@00<Wo00X0oooo00<0
0?l40?ooo`3oool01`3oool00`00bOl0oooo0?ooo`0E0?ooo`030039o`3oool0oooo00<0oooo0P00
o`@40?ooo`03003o103oool0oooo01P0oooo00<00?l40?ooo`00o`@00P3oool60039o`@0oooo00<0
0<Wo0?ooo`3oool01`3oool20039o`80oooo1000bOl<0?ooo`030000003oool0oooo03<0oooo00<0
0<Wo0?ooo`3oool02`3oool01000bOl0oooo0?ooo`00bOlC0?ooo`800<Wo0P3oool2003o10d0oooo
00D00<Wo0?ooo`00o`@00?l40039o`020?ooo`030039o`3oool0oooo00800<Wo2@3oool01P00bOl0
oooo0?ooo`00o`@0oooo0039o`80oooo00<00<Wo003o103oool00P3oool00`00o`@0oooo003o1002
0?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool02`3oool20?m701d0oooo000O0?oo
o`80odL03P3oool00`00o`@0oooo003o10050?ooo`040039o`3oool0oooo0?ooo`800?l400@00<Wo
0?ooo`00o`@00?l40`3oool40039o`03003o1000bOl0oooo00T0oooo00<00?l40?ooo`3oool01`3o
ool20039oa@0oooo00<00<Wo0?ooo`3oool00P3oool2003o10D0oooo00<00?l40?ooo`3oool0603o
ool00`00o`@0oooo003o10030039o`T0oooo00<00<Wo0?ooo`3oool01`3oool20039o`L0oooo1@00
bOl70?ooo`030000003oool0oooo03<0oooo00<00<Wo0?ooo`3oool02`3oool01@00bOl0oooo0?oo
o`3oool00<Wo01@0oooo0P00bOl20?ooo`800?l42`3oool01@00bOl00?l4003o103oool00<Wo0080
oooo00@00<Wo0?ooo`3oool00<Wo2@3oool01`00bOl0oooo0?ooo`3oool00?l40?ooo`00bOl00P3o
ool01`00bOl00?l40?ooo`3oool00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`030?ooo`03
003o103oool0oooo00/0oooo0P3oA`0M0?ooo`007`3oool30?m700d0oooo00<00?l40?ooo`00o`@0
1@3oool00`00bOl0oooo0?ooo`020?ooo`05003o1000bOl0oooo0?ooo`00o`@0103oool30039o`03
003o1000bOl0oooo00X0oooo00<00?l40?ooo`3oool0203oool00`00bOl0oooo0?ooo`0?0?ooo`80
0<Wo0P3oool3003o10H0oooo00<00?l40?ooo`3oool06@3oool30039o`/0oooo00<00<Wo0?ooo`3o
ool01`3oool20039o`d0oooo1000bOl30?ooo`030000003oool0oooo03@0oooo00<00<Wo0?ooo`3o
ool02`3oool01@00bOl0oooo0?ooo`3oool00<Wo01D0oooo00@00<Wo0?ooo`3oool0oooo1000o`@6
0?ooo`06003o1000bOl00?l40?ooo`00bOl0oooo0P00bOl30?ooo`030039o`3oool0oooo00L0oooo
00@00<Wo0?ooo`3oool0oooo0P00o`@01000bOl0oooo0?ooo`00bOl30?ooo`03003o103oool00?l4
0080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0<0?ooo`80odL07@3oool001l0
oooo0`3oA`0=0?ooo`03003o103oool00?l400D0oooo00<00<Wo0?ooo`3oool00P3oool2003o1003
0039o`3oool00?l400@0oooo00<00<Wo0?ooo`00bOl00P00o`@00`00bOl0oooo0?ooo`090?ooo`80
0?l42@3oool30039o``0oooo0P00bOl0103oool00?l4003o1000o`@80?ooo`03003o103oool0oooo
01P0oooo0P00bOl00`00o`@0oooo0?ooo`0;0?ooo`040039o`3oool0oooo0?ooo`X00<Wo3`3oool2
0039o`030?ooo`000000oooo03D0oooo00<00<Wo0?ooo`3oool0303oool01000bOl0oooo0?ooo`00
bOlF0?ooo`030039o`3oool0oooo00@0oooo1P00o`@01000bOl00?l40?ooo`3oool20039o`@0oooo
00<00<Wo0?ooo`3oool01`3oool00`00bOl0oooo0?ooo`020?ooo`800?l400@00<Wo0?ooo`3oool0
0<Wo0`3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080oooo00<00?l40?ooo`3o
ool0303oool20?m701d0oooo000O0?ooo`<0odL03P3oool2003o10D0oooo00<00<Wo0?ooo`3oool0
0P3oool2003o10040039o`3oool00?l4003o10<0oooo0`00bOl00`00o`@0oooo0039o`0=0?ooo`80
0?l42P3oool20039o`P0oooo0P00bOl3003o10T0oooo0P00o`@I0?ooo`800<Wo00<0oooo003o103o
ool0303oool50039o`@0oooo00<00<Wo0?ooo`3oool00`3oool60039o`/0oooo0`00bOlf0?ooo`03
0039o`3oool0oooo00`0oooo00@00<Wo0?ooo`3oool00<Wo5P3oool20039o`T0oooo00D00<Wo003o
103oool0oooo0039o`060?ooo`030039o`3oool0oooo00L0oooo00<00<Wo0?ooo`3oool00P3oool2
003o10040039o`3oool0oooo0039o`<0oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?oo
o`020?ooo`03003o103oool0oooo00`0oooo0P3oA`0M0?ooo`007`3oool30?m700h0oooo0P00o`@6
0?ooo`030039o`3oool0oooo0080oooo00D00?l40039o`3oool0oooo003o10040?ooo`<00<Wo0P00
o`@00`00bOl0oooo0?ooo`0<0?ooo`@00?l4203oool80039o`800?l42`3oool00`00o`@0oooo0?oo
o`0G0?ooo`800<Wo0P3oool2003o10`0oooo0P00bOl70?ooo`030039o`3oool0oooo00X0oooo0P00
bOl:0?ooo`030000003oool00<Wo00<00<Wo<`3oool00`00bOl0oooo0?ooo`0;0?ooo`040039o`3o
ool0oooo0039oaP0oooo0P00bOl60?ooo`030039o`3oool00?l400<00<Wo1P3oool00`00bOl0oooo
0?ooo`060?ooo`800<Wo0`3oool00`00o`@0oooo0039o`020?ooo`030039o`00o`@0oooo0080oooo
00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00/0oooo
0`3oA`0M0?ooo`00803oool20?m700h0oooo00<00?l40?ooo`00o`@01@3oool00`00bOl0oooo0?oo
o`020?ooo`05003o1000bOl0oooo0?ooo`00o`@0103oool00`00bOl0oooo0039o`02003o10030039
o`3oool0oooo0100oooo0`00o`@60?ooo`H00?l43@3oool00`00o`@0oooo0?ooo`0E0?ooo`<00<Wo
0`3oool2003o10/0oooo0P00bOl80?ooo`030039o`3oool0oooo00d0oooo0`00bOl70?ooo`030000
003oool0oooo00<0oooo0`00bOla0?ooo`030039o`3oool0oooo00/0oooo00@00<Wo0?ooo`3oool0
0<Wo6@3oool90039o`030?ooo`00bOl0oooo00D0oooo00<00<Wo0?ooo`3oool01`3oool00`00bOl0
oooo0?ooo`020?ooo`800?l400@00<Wo0?ooo`3oool00<Wo103oool00`00o`@0oooo003o10020?oo
o`03003o103oool0oooo0080oooo00<00?l40?ooo`3oool02`3oool20?m701h0oooo000P0?ooo`80
odL03P3oool00`00o`@0oooo003o10060?ooo`030039o`3oool0oooo0080oooo00@00<Wo003o103o
ool00?l4103oool00`00bOl0oooo0039o`03003o10030039o`3oool0oooo0180oooo1P00o`@A0?oo
o`800?l45P3oool20039o`D0oooo00<00?l40?ooo`00o`@02@3oool30039o`P0oooo00<00<Wo0?oo
o`3oool04@3oool40039o`<0oooo00<000000?ooo`3oool01P3oool30039obh0oooo00<00<Wo0?oo
o`3oool02`3oool01@00bOl0oooo0?ooo`3oool00<Wo01d0oooo00<00<Wo0?ooo`00o`@00P3oool0
0`00bOl0oooo0?ooo`040?ooo`030039o`3oool0oooo00H0oooo0P00bOl40?ooo`800?l400@00<Wo
0?ooo`3oool00<Wo0`3oool01P00o`@0oooo0?ooo`00o`@0oooo003o10D0oooo00<00?l40?ooo`3o
ool02`3oool20?m701h0oooo000P0?ooo`80odL03`3oool2003o10H0oooo00<00<Wo0?ooo`3oool0
0P3oool01@00o`@00<Wo0?ooo`3oool00?l400@0oooo0`00bOl2003o10030039o`3oool0oooo02L0
oooo0P00o`@G0?ooo`030039o`3oool0oooo00@0oooo00<00?l40?ooo`00o`@0203oool20039o`03
0?ooo`00bOl0oooo00H0oooo0P00bOlH0?ooo`800<Wo00<0oooo0000003oool02P3oool20039obd0
oooo00<00<Wo0?ooo`3oool02`3oool01@00bOl0oooo0?ooo`3oool00<Wo01/0oooo00<00<Wo0?oo
o`00o`@00P3oool00`00bOl0oooo0?ooo`040?ooo`030039o`3oool0oooo00L0oooo00<00<Wo0?oo
o`3oool00`3oool01P00o`@00<Wo0?ooo`3oool00?l40039o`<0oooo00<00?l40?ooo`00o`@00P3o
ool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00`0oooo0P3oA`0N0?ooo`00803oool2
0?m700l0oooo0P00o`@60?ooo`030039o`3oool0oooo0080oooo00D00?l40039o`00o`@0oooo003o
10040?ooo`030039o`3oool00<Wo00<00?l400<00<Wo0?ooo`3oool0903oool2003o11L0oooo0P00
bOl60?ooo`03003o103oool00?l400P0oooo00@00<Wo0?ooo`3oool00<Wo1`3oool20039oa/0oooo
0P00bOl=0?ooo`800<Wo;03oool00`00bOl0oooo0?ooo`0;0?ooo`040039o`3oool0oooo0039oaX0
oooo00<00<Wo0?ooo`00o`@00`3oool00`00bOl0oooo0?ooo`040?ooo`030039o`3oool0oooo00H0
oooo0P00bOl40?ooo`800?l400D00<Wo0?ooo`3oool00?l40039o`030?ooo`03003o103oool00?l4
0080oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0<0?ooo`80odL07P3oool00200
oooo0P3oA`0?0?ooo`800?l41P3oool00`00bOl0oooo0?ooo`020?ooo`04003o1000bOl00?l40?oo
o`800?l4103oool30039o`040?ooo`00o`@0oooo0039ob@0oooo00<00?l40?ooo`3oool05@3oool2
0039o`L0oooo00<00?l40?ooo`00o`@01`3oool20039o`80oooo00<00<Wo0?ooo`3oool01@3oool2
0039oad0oooo00<000000039o`3oool03@3oool20039ob/0oooo00<00<Wo0?ooo`3oool02`3oool0
1000bOl0oooo0?ooo`00bOlI0?ooo`030039o`00o`@0oooo0080oooo00<00<Wo0?ooo`3oool0103o
ool00`00bOl0oooo0?ooo`070?ooo`030039o`3oool0oooo00<0oooo00<00?l40039o`3oool00P3o
ool00`00bOl0oooo0?ooo`020?ooo`03003o103oool00?l40080oooo00<00?l40?ooo`3oool00P3o
ool00`00o`@0oooo0?ooo`0<0?ooo`80odL07P3oool00240oooo0P3oA`0>0?ooo`800?l41`3oool0
0`00bOl0oooo0?ooo`020?ooo`030039o`00o`@0oooo00800?l4103oool30039o`<00?l400<00<Wo
0?ooo`3oool0803oool2003o11H0oooo0P00bOl80?ooo`03003o103oool00?l400H0oooo0P00bOl2
0?ooo`800<Wo1P3ooolI0039o`P0oooo00@000000?ooo`00bOl00<Wo3P3oool20039obX0oooo00<0
0<Wo0?ooo`3oool02`3oool01000bOl0oooo0?ooo`00bOlG0?ooo`030039o`3oool00?l40080oooo
00<00<Wo0?ooo`3oool01@3oool00`00bOl0oooo0?ooo`060?ooo`800<Wo1@3oool00`00o`@00<Wo
0?ooo`020?ooo`050039o`3oool0oooo0?ooo`00o`@00P3oool00`00o`@0oooo003o10050?ooo`03
003o103oool0oooo00`0oooo0P3oA`0N0?ooo`008@3oool20?m700h0oooo0P00o`@70?ooo`030039
o`3oool0oooo0080oooo00@00?l40039o`00o`@0oooo0P00o`@30?ooo`050039o`3oool00<Wo0039
o`3oool00P00o`@00`00bOl0oooo0?ooo`0N0?ooo`03003o103oool0oooo01D0oooo00<00<Wo0?oo
o`3oool0203oool2003o10D0oooo0P00bOl30?ooo`030039o`3oool0oooo00<0oooo1000bOl;0?oo
o`800000103oool2000000@0oooo00<000000039o`00bOl00`00bOl30?ooo`050000003oool0oooo
0?ooo`00bOl03`3oool30039obL0oooo00<00<Wo0?ooo`3oool0303oool01000bOl0oooo0?ooo`00
bOlE0?ooo`030039o`3oool00?l40080oooo00<00<Wo0?ooo`3oool01@3oool00`00bOl0oooo0?oo
o`070?ooo`030039o`3oool0oooo00<0oooo00<00?l40039o`3oool00P3oool00`00bOl0oooo0?oo
o`020?ooo`06003o103oool0oooo003o103oool00?l4103oool00`00o`@0oooo0?ooo`0=0?ooo`80
odL07P3oool00240oooo0P3oA`0>0?ooo`03003o103oool00?l400H0oooo00<00<Wo0?ooo`3oool0
0P3oool01000o`@00<Wo003o103oool2003o10@0oooo0`00bOl2003o10030?ooo`00o`@00<Wo01d0
oooo0P00o`@F0?ooo`800<Wo2P3oool00`00o`@0oooo0?ooo`030?ooo`800<Wo103oool00`00bOl0
oooo0039o`060039o`L0oooo2000o`@00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
00<0oooo1000bOl40?ooo`800<Wo403oool30039obD0oooo00<00<Wo0?ooo`3oool0303oool00`00
bOl0oooo0?ooo`020039oa80oooo00<00<Wo0?ooo`00o`@00P3oool00`00bOl0oooo0?ooo`060?oo
o`030039o`3oool0oooo00H0oooo0P00bOl50?ooo`03003o1000bOl0oooo0080oooo00<00<Wo0?oo
o`3oool00P3oool00`00o`@0oooo003o10020?ooo`03003o103oool0oooo0080oooo00<00?l40?oo
o`3oool0303oool20?m701l0oooo000Q0?ooo`80odL03`3oool2003o10H0oooo00<00<Wo0?ooo`3o
ool00P3oool00`00o`@00<Wo0?ooo`02003o10030?ooo`00o`@0oooo0080oooo1000bOl01@3oool0
0?l40?ooo`00bOl00?l401X0oooo0P00o`@E0?ooo`<00<Wo2`3oool00`00o`@0oooo0?ooo`020?oo
o`800<Wo103oool40039o`@0oooo0P00bOl8003o10D0oooo00<000000?ooo`3oool02@00o`@30?oo
o`030000003oool0oooo00@0oooo00@000000039o`00bOl00<Wo0`3oool20039oa40oooo0P00bOlT
0?ooo`030039o`3oool0oooo00/0oooo00<00<Wo0?ooo`3oool00P3oool00`00bOl0oooo0?ooo`0>
0?ooo`030039o`3oool00?l40080oooo00<00<Wo0?ooo`3oool01P3oool00`00bOl0oooo0?ooo`06
0?ooo`800<Wo1P3oool00`00bOl00?l40?ooo`020?ooo`030039o`3oool0oooo0080oooo00<00?l4
0?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00`0oooo0P3oA`0O
0?ooo`008@3oool20?m700l0oooo0P00o`@70?ooo`030039o`3oool0oooo0080oooo00@00?l40039
o`00o`@0oooo0P00o`@40?ooo`D00<Wo0P3oool00`00bOl00?l40?ooo`0E0?ooo`<00?l45@3oool2
0039o`d0oooo00@00?l40?ooo`3oool0oooo0P00bOl30?ooo`@00<Wo1P3oool20039o`03003o103o
ool0oooo00/0oooo00@000000?ooo`3oool00000203oool4003o10H0oooo00@000000?ooo`3oool0
oooo1000bOl00`3oool00<Wo0?ooo`0A0?ooo`800<Wo8P3oool00`00bOl0oooo0?ooo`0<0?ooo`03
0039o`3oool0oooo0080oooo00<00<Wo0?ooo`3oool0303oool00`00bOl00?l4003o10020?ooo`03
0039o`3oool0oooo00H0oooo0P00bOl80?ooo`030039o`3oool0oooo00@0oooo00<00?l40039o`3o
ool00P3oool00`00bOl00?l40?ooo`020?ooo`06003o103oool0oooo003o103oool00?l41@3oool0
0`00o`@0oooo0?ooo`0<0?ooo`80odL07`3oool00240oooo0P3oA`0?0?ooo`800?l41`3oool00`00
bOl0oooo0?ooo`020?ooo`03003o1000bOl0oooo00<00?l4103oool30039o`03003o103oool00<Wo
0080oooo00<00<Wo003o1000o`@04P3oool2003o11H0oooo0P00bOl>0?ooo`800?l40P3oool00`00
bOl0oooo0?ooo`030039o`80oooo00<00<Wo0?ooo`3oool00`3oool20039oa00oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`02003o10@0oooo00<000000?ooo`3oool01@3oool5
0039oa40oooo0P00bOlQ0?ooo`030039o`3oool0oooo00`0oooo00<00<Wo0?ooo`3oool00P3oool0
0`00bOl0oooo0?ooo`090?ooo`800<Wo00<00?l40?ooo`3oool00P3oool00`00bOl0oooo0?ooo`06
0?ooo`030039o`3oool0oooo00H0oooo00<00<Wo0?ooo`3oool01@3oool00`00bOl00?l40?ooo`02
0?ooo`030039o`3oool0oooo0080oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`02
0?ooo`03003o103oool0oooo00d0oooo0P3oA`0O0?ooo`008@3oool20?m700l0oooo00<00?l40?oo
o`00o`@01`3oool00`00bOl0oooo0?ooo`020?ooo`040039o`3oool00?l40?ooo`800?l4103oool3
0039o`03003o103oool00<Wo0080oooo00<00<Wo0?ooo`00o`@00P00o`@<0?ooo`<00?l45`3oool0
0`00bOl0oooo0?ooo`0=0?ooo`800?l40P3oool40039o`<0oooo0P00bOl30?ooo`800?l40P00bOlB
0?ooo`8000002P3oool300000080oooo0`00o`@00`3oool000000?ooo`0:0?ooo`@00<Wo403oool3
0039oal0oooo00<00<Wo0?ooo`3oool0303oool00`00bOl0oooo0?ooo`020?ooo`800<Wo1`3oool2
0039o`030?ooo`00o`@0oooo00<0oooo00<00<Wo0?ooo`3oool01P3oool20039o`L0oooo0P00bOl7
0?ooo`060039o`3oool0oooo0?ooo`00bOl00?l40`3oool01000o`@0oooo0?ooo`00o`@20?ooo`03
003o103oool0oooo0080oooo00<00?l40?ooo`3oool03@3oool00`3oA`00oooo0?ooo`0N0?ooo`00
8P3oool20?m700h0oooo00<00?l40?ooo`00o`@01`3oool00`00bOl0oooo0?ooo`020?ooo`03003o
1000bOl0oooo00<00?l4103oool30039o`030?ooo`00o`@00<Wo00<0oooo00@00<Wo0?ooo`3oool0
oooo3000o`@H0?ooo`800<Wo3`3oool2003o10<00<Wo1P3oool00`00bOl0oooo003o1003003o1003
0?ooo`00bOl0oooo02L0oooo0P00o`@=0?ooo`040039o`3oool00<Wo0039oa40oooo0P00bOlN0?oo
o`030039o`3oool0oooo00`0oooo0P00bOl40?ooo`030039o`3oool0oooo00<0oooo00@00<Wo0?oo
o`00o`@00?l4103oool00`00bOl0oooo0?ooo`060?ooo`800<Wo1`3oool20039o`L0oooo00<00<Wo
003o103oool00P3oool00`00bOl0oooo0?ooo`020?ooo`04003o103oool0oooo003o1080oooo00<0
0?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`0=0?ooo`030?m7003oool0oooo01h0oooo000R
0?ooo`80odL03P3oool00`00o`@0oooo003o10080?ooo`030039o`3oool0oooo0080oooo00D00<Wo
0?ooo`00o`@0oooo003o10050?ooo`<00<Wo00@00?l40?ooo`00bOl00<Wo0P3oool00`00bOl0oooo
0?ooo`0Q0?ooo`<00<Wo3`3oool2003o10<00<Wo1`3oool00`00bOl00?l4003o10030?ooo`800<Wo
:P3oool0100000000?l4003o1000o`@;0?ooo`800<Wo00<0oooo0039o`00bOl04@3oool30039oa`0
oooo00<00<Wo0?ooo`3oool03@3oool00`00bOl0oooo0?ooo`020?ooo`030039o`3oool0oooo0080
0<Wo0P00o`@40?ooo`800<Wo2@3oool00`00bOl0oooo0?ooo`050?ooo`800<Wo203oool00`00bOl0
0?l40?ooo`020?ooo`030039o`3oool0oooo0080oooo00<00?l40?ooo`00o`@00P3oool00`00o`@0
oooo0?ooo`030?ooo`03003o103oool0oooo00`0oooo0P3oA`0P0?ooo`008P3oool20?m700l0oooo
0P00o`@80?ooo`030039o`3oool0oooo0080oooo00<00?l40039o`3oool00`00o`@50?ooo`<00<Wo
00<00?l40?ooo`00o`@00P00bOl00`3oool00<Wo0039o`0N0?ooo`<00<Wo4@3oool30039o`030?oo
o`00bOl0oooo00D0oooo0P00bOl00`00o`@0oooo0?ooo`020?ooo`800<Wo:@3ooolJ0039oa00oooo
0`00bOlJ0?ooo`030039o`3oool0oooo00d0oooo00<00<Wo0?ooo`3oool00P3oool20039o`800?l4
1@3oool00`00bOl0oooo0?ooo`080?ooo`800<Wo1@3oool30039o`P0oooo00<00<Wo003o103oool0
0P3oool00`00bOl0oooo0?ooo`020?ooo`04003o103oool0oooo003o1080oooo00<00?l40?ooo`3o
ool00P3oool00`00o`@0oooo0?ooo`0=0?ooo`80odL0803oool00280oooo0P3oA`0?0?ooo`800?l4
2@3oool00`00bOl0oooo0?ooo`020?ooo`050039o`3oool00?l40?ooo`00o`@01@3oool30039o`03
0?ooo`00o`@00?l40080oooo0P00bOl00`3oool00<Wo0?ooo`0I0?ooo`<00<Wo403oool40039o`04
003o103oool00<Wo0039o`H0oooo00<00<Wo003o103oool0103oool20039oa80oooo2@00o`@;0?oo
o`@00<Wo0P3oool00`000000oooo0?ooo`030?ooo`800?l42`3oool20039o`030?ooo`00bOl00<Wo
00/00<Wo203oool30039oaP0oooo00<00<Wo0?ooo`3oool03@3oool40039o`800?l40P00bOl40?oo
o`030039o`3oool0oooo00P0oooo0P00bOl40?ooo`<00<Wo2P3oool00`00bOl00?l40?ooo`020?oo
o`030039o`3oool0oooo0080oooo00@00?l40?ooo`3oool00?l40P3oool00`00o`@0oooo0?ooo`02
0?ooo`03003o103oool0oooo00d0oooo0P3oA`0P0?ooo`008P3oool30?m700h0oooo00<00?l40?oo
o`00o`@02@3oool01`00bOl0oooo0?ooo`3oool00?l40039o`3oool00`00o`@50?ooo`<00<Wo00<0
oooo003o1000o`@00`3oool01000bOl0oooo0039o`00bOlE0?ooo`<00<Wo3`3oool40039o`<00?l4
0P3oool00`00bOl0oooo0?ooo`030?ooo`800?l400<00<Wo0?ooo`3oool0103oool20039o``0oooo
1`00o`@90?ooo`H00?l41@00bOl60?ooo`030000003oool0oooo00D0oooo0P00o`@;0?ooo`040039
o`3oool0oooo0?ooo`@00<Wo1P3oool=0039oaL0oooo00<00<Wo0?ooo`3oool02`3oool50039o`@0
oooo1000bOl;0?ooo`040039o`3oool0oooo0?ooo`800<Wo00<0oooo0039o`3oool02@3oool00`00
bOl00?l40?ooo`020?ooo`030039o`3oool0oooo00<0oooo00<00?l40?ooo`00o`@00P3oool00`00
o`@0oooo0?ooo`030?ooo`03003o103oool0oooo00d0oooo0P3oA`0P0?ooo`008P3oool30?m700h0
oooo00<00?l40?ooo`00o`@02@3oool02@00bOl0oooo0?ooo`3oool00?l40039o`3oool00?l40?oo
o`02003o10@0oooo00L00<Wo0?ooo`00bOl00<Wo003o103oool00?l400<0oooo1@00bOl@0?ooo`<0
0<Wo403oool20039o`<0oooo0P00o`@20?ooo`800<Wo103oool2003o10800<Wo1@3oool20039o`X0
oooo1000o`@A0?ooo`D00<Wo0`3oool2003o10H0oooo0P0000080?ooo`800?l42P3oool20039o`D0
oooo0`00bOl>0?ooo`H00<Wo503oool00`00bOl0oooo0?ooo`060?ooo`@00<Wo0P00o`@30?ooo`80
0<Wo0P3oool40039o`X0oooo00<00<Wo0?ooo`3oool00P00bOl20?ooo`030039o`3oool0oooo00P0
oooo00<00<Wo003o1000o`@00`3oool00`00bOl0oooo0?ooo`020?ooo`04003o103oool0oooo003o
1080oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo0?ooo`0=0?ooo`030?m7003oool0oooo
01l0oooo000S0?ooo`80odL03`3oool2003o10X0oooo00L00<Wo0?ooo`3oool0oooo003o1000bOl0
oooo00<00?l41@3oool40039o`03003o103oool00?l400D0oooo1P00bOl60?ooo`H00<Wo3`3oool4
0039o`@0oooo0P00o`@20?ooo`030039o`3oool0oooo0080oooo0P00o`@00`3oool00<Wo0?ooo`04
0?ooo`<00<Wo1`3oool4003o1100oooo1@00bOl:0?ooo`@00?l40P3oool00`000000oooo0?ooo`09
0?ooo`03003o103oool0oooo00D0oooo1000o`@00`00bOl00?l4003o1003003o1080oooo0P00bOlB
0?oooad00<Wo0`00o`@60?ooo`@00<Wo103oool=0039o`80oooo0P00bOl;0?ooo`030039o`00o`@0
oooo0080oooo00<00<Wo003o103oool00`3oool01P00o`@0oooo0?ooo`00o`@0oooo003o10D0oooo
00<00?l40?ooo`3oool03@3oool20?m70240oooo000S0?ooo`80odL03`3oool2003o10/0oooo00L0
0<Wo0?ooo`3oool00?l40039o`00o`@0oooo00<00?l41@3oool40039o`03003o103oool00?l400T0
oooo1`00bOlA0?ooo`@00<Wo1P3oool2003o10<0oooo00@00<Wo0?ooo`3oool0oooo0P00o`@20?oo
o`030039o`3oool0oooo0080oooo0`00bOl50?ooo`@00?l4403oool40039oa<0oooo1000o`@80?oo
o`X00?l4103oool00`00o`@00<Wo003o10030?ooo`@00?l40P00bOl?003o10H0oooo0P00bOl@0?oo
o`030039o`00o`@00?l400800?l4203oool20039o`@0oooo0P00bOl90?ooo`800<Wo0P3oool40039
o``0oooo00<00<Wo003o1000o`@00`3oool00`00bOl0oooo0?ooo`020?ooo`04003o103oool0oooo
003o1080oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo0?ooo`0=0?ooo`80odL08@3oool0
02<0oooo0P3oA`0?0?ooo`03003o103oool00?l400/0oooo00D00<Wo0?ooo`3oool00?l40039o`03
003o10030?ooo`00o`@0oooo00<0oooo00<00<Wo0?ooo`00bOl00P00bOl00`00o`@0oooo003o100<
0?ooo`L00<Wo103oool90039o`T0oooo0P00o`@20?ooo`800<Wo0P3oool2003o1080oooo0P00bOl4
0?ooo`800<Wo103oool3003o1180oooo0P00bOlI0?ooo`030000003oool00?l400L00?l41@3oool2
003o10H0oooo0`00o`@20039o`P0oooo0`00bOl<0?ooo`P00?l41000bOl<003o10030?ooo`00bOl0
oooo00H0oooo1000bOl80?ooo`d00<Wo3`3oool00`00bOl00?l4003o10030?ooo`030039o`00o`@0
oooo00<0oooo00H00?l40?ooo`3oool00?l40?ooo`00o`@60?ooo`03003o103oool0oooo00d0oooo
0P3oA`0Q0?ooo`008`3oool20?m70100oooo0P00o`@;0?ooo`070039o`3oool0oooo003o1000bOl0
0?l40?ooo`03003o10D0oooo0P00bOl01@3oool00<Wo0?ooo`00o`@0oooo00800?l44@3oool40039
oa00oooo0P00o`@30?ooo`030039o`3oool0oooo00800?l40`3oool00`00bOl0oooo0?ooo`020?oo
o`800<Wo103oool2003o1140oooo1000bOlJ0?ooo`P00?l42P3oool2003o10<0oooo1P00o`@00`00
bOl0oooo0?ooo`080?ooo`800<Wo5P3ooolE0039oa<0oooo00<00<Wo0?ooo`3oool04@3oool01000
bOl0oooo003o1000o`@30?ooo`030039o`00o`@0oooo00<0oooo00H00?l40?ooo`3oool00?l40?oo
o`00o`@60?ooo`03003o103oool0oooo00d0oooo0P3oA`0Q0?ooo`00903oool20?m700l0oooo0P00
o`@<0?ooo`070039o`3oool0oooo0039o`3oool00?l40?ooo`03003o10D0oooo0P00bOl0103oool0
0<Wo0?ooo`00o`@20?ooo`03003o103oool0oooo0200oooo0P00o`@30?ooo`800<Wo0`00o`@30?oo
o`800<Wo0`3oool20039o`<0oooo0`00o`@?0?ooo`@00<Wo6@3oool5003o10030?ooo`000000oooo
00D0oooo0P00o`@:0?ooo`800?l400<0oooo003o1000o`@01@00o`@20039o`X0oooo0`00bOlR0?oo
o`800<Wo5@3oool20039oa<0oooo00@00<Wo0?ooo`00o`@00?l40`3oool00`00bOl00?l40?ooo`03
0?ooo`04003o103oool0oooo003o1080oooo00<00?l40?ooo`3oool00`3oool00`00o`@0oooo0?oo
o`0>0?ooo`80odL08@3oool002@0oooo0P3oA`0@0?ooo`800?l42`3oool01P00bOl0oooo0?ooo`00
o`@00<Wo003o1080oooo0`00o`@50?ooo`@00<Wo00@0oooo003o1000o`@0oooo0P00o`@N0?ooo`80
0?l40`3oool20039o`800?l4103oool20039o`<0oooo0`00bOl0103oool00?l4003o1000o`@@0?oo
o`800<Wo6@3oool4003o10H0oooo00<000000?ooo`3oool01P3oool2003o10X0oooo2@00o`@00`3o
ool00<Wo0039o`0;0?ooo`<00<Wo8@3oool00`00bOl0oooo0?ooo`0A0?ooo`800<Wo4`3oool01000
bOl0oooo003o1000o`@40?ooo`030039o`00o`@0oooo00<0oooo00H00?l40?ooo`3oool00?l40?oo
o`00o`@60?ooo`03003o103oool0oooo00d0oooo0P3oA`0R0?ooo`00903oool20?m70100oooo0P00
o`@<0?ooo`060039o`3oool0oooo0039o`3oool00?l40P3oool2003o10D0oooo00<00<Wo0?ooo`3o
ool00P00bOl20?ooo`800?l400<0oooo003o103oool06P3oool3003o10<0oooo00<00<Wo003o1000
o`@01@3oool01000bOl0oooo0?ooo`3oool30039o`030?ooo`00o`@00?l40100oooo0`00bOlG0?oo
o`@00?l42P3oool00`000000oooo0?ooo`080?ooo`800?l42P3oool5003o1080oooo00<00?l40?oo
o`3oool00P00bOl<0?ooo`@00<Wo7P3oool00`00bOl0oooo0?ooo`0?0?ooo`030039o`3oool0oooo
0180oooo00<00<Wo0?ooo`3oool00P00o`@30?ooo`030039o`00o`@0oooo00<0oooo00L00?l40?oo
o`3oool0oooo003o103oool00?l400H0oooo00<00?l40?ooo`3oool03@3oool20?m70280oooo000T
0?ooo`80odL04@3oool2003o10`0oooo00H00<Wo0?ooo`00o`@00<Wo0?ooo`00o`@20?ooo`800?l4
1@3oool00`00bOl0oooo0?ooo`020039o`<0oooo1000o`@F0?ooo`@00?l40`3oool20039o`03003o
103oool0oooo00<0oooo0P00bOl20?ooo`<00<Wo0`00o`@@0?ooo`800<Wo603oool2003o10h0oooo
00<000000?ooo`3oool02P3oool3003o10P0oooo0`00o`@30?ooo`03003o103oool0oooo0080oooo
00<00<Wo0?ooo`3oool03@3oool50039oaX0oooo0P00bOl=0?ooo`800<Wo4`3oool20039o`80oooo
0P00o`@40?ooo`030039o`00o`@0oooo00<0oooo00@00?l40?ooo`3oool00?l40P3oool00`00o`@0
oooo0?ooo`040?ooo`03003o103oool0oooo00d0oooo0P3oA`0R0?ooo`00903oool20?m70140oooo
0P00o`@=0?ooo`030039o`3oool00<Wo0080oooo00<00?l40?ooo`3oool00`00o`@40?ooo`030039
o`3oool0oooo00800<Wo103oool5003o1100oooo1000o`@40?ooo`03003o1000bOl00?l400H0oooo
00<00<Wo0?ooo`3oool00P00bOl00`3oool00?l4003o100@0?ooo`<00<Wo5`3oool3003o1100oooo
00<000000?ooo`3oool04@00bOl70?ooo`800?l40P3oool2003o10<0oooo0P00bOlB0?ooo`<00<Wo
6@3oool20039o`P0oooo0`00bOlD0?ooo`070039o`3oool0oooo0?ooo`00o`@0oooo003o10040?oo
o`030039o`3oool0oooo0080oooo00D00?l40?ooo`3oool0oooo003o10020?ooo`03003o103oool0
oooo00<0oooo00<00?l40?ooo`3oool03P3oool20?m70280oooo000U0?ooo`80odL0403oool00`00
o`@0oooo003o100=0?ooo`030039o`00o`@00<Wo0080oooo00H00?l40?ooo`3oool00?l40?ooo`00
o`@40?ooo`030039o`3oool0oooo00<00<Wo103ooolD003o10D0oooo00<00?l40039o`00bOl01P3o
ool20039o`040?ooo`00bOl00<Wo0?ooo`800?l4403oool20039oaP0oooo0P00o`@<0?ooo`X00<Wo
3`3oool2003o10d00<Wo0P00o`@30?ooo`030039o`3oool0oooo0180oooo1000bOlG0?ooo`<00<Wo
00<0oooo0039o`00bOl00`00bOlD0?ooo`800<Wo103oool2003o10@0oooo00<00<Wo0?ooo`3oool0
0`3oool01`00o`@0oooo0?ooo`3oool00?l40?ooo`00o`@01P3oool00`00o`@0oooo0?ooo`0=0?oo
o`80odL08`3oool002D0oooo0P3oA`0A0?ooo`800?l43P3oool00`00bOl00?l40039o`020?ooo`05
003o103oool0oooo003o103oool00P00o`@30?ooo`800<Wo0P3oool30039o`H0oooo3000o`@50?oo
o`<00?l40P00bOl50?ooo`<00<Wo00@0oooo0039o`00bOl0oooo0P00o`@?0?ooo`<00<Wo503oool?
003o10D00<Wo1P00o`@00`3oool000000?ooo`0B0?ooo`800?l42@3oool00`00o`@0oooo0039o`06
0039oaL0oooo1`00bOlB0?ooo`@00<Wo5@3oool20039o`D0oooo00<00?l40?ooo`00o`@0103oool0
0`00bOl0oooo0?ooo`020?ooo`05003o103oool0oooo0?ooo`00o`@00P3oool00`00o`@0oooo0?oo
o`040?ooo`03003o103oool0oooo00d0oooo0P3oA`0S0?ooo`009@3oool20?m70140oooo0P00o`@?
0?ooo`030039o`3oool00<Wo0080oooo00<00?l40?ooo`3oool00P00o`@0103oool00?l4003o1000
o`@20?ooo`040039o`3oool0oooo0?ooo`<00<Wo4@3oool4003o10030?ooo`00bOl00<Wo00@0oooo
0`00bOl0103oool00<Wo0039o`00bOl3003o10l0oooo0P00bOlA0?ooo`H00?l400<0oooo003o1000
o`@01`00o`@50039oa000?l44P3oool2003o10P0oooo0P00o`@30?ooo`03003o103oool00<Wo00D0
0<Wo6@3ooolD0039o`80oooo0`00bOl@0?ooo`800<Wo1`3oool2003o10@0oooo00<00<Wo0?ooo`3o
ool00`3oool01`00o`@0oooo0?ooo`3oool00?l40?ooo`00o`@01`3oool00`00o`@0oooo0?ooo`0=
0?ooo`80odL08`3oool002H0oooo00<0odL00?ooo`3oool03`3oool00`00o`@0oooo003o100?0?oo
o`800<Wo0`3oool2003o10030?ooo`00o`@00?l400<0oooo0`00o`@00`00bOl0oooo0?ooo`020?oo
o`<00<Wo3@3oool2003o1080oooo0`00bOl40?ooo`H00<Wo0P00o`@?0?ooo`@00<Wo3P3oool5003o
1080oooo1@00o`@50?ooo`@00<Wo4@3oool00`0000000?l4003o1008003o10d0oooo0P00o`@80?oo
o`800?l40P3oool01@00o`@0oooo0?ooo`3oool00<Wo0080oooo1P00bOlP0?ooo`@00<Wo203oool3
0039o`X0oooo0`00bOl80?ooo`800?l4103oool00`00bOl0oooo0?ooo`030?ooo`05003o103oool0
oooo0?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`040?ooo`03003o103oool0oooo00h0oooo0P3o
A`0S0?ooo`009P3oool20?m70140oooo0P00o`@@0?ooo`800<Wo103oool01000o`@0oooo003o1000
o`@50?ooo`04003o1000bOl00<Wo003o10<0oooo1000bOl60?ooo`@00?l40P3oool20039o`@0oooo
1@00bOl00`3oool00?l4003o100=0?ooo`D00<Wo3@3oool5003o1080oooo1`00o`@60?ooo`800<Wo
5@3oool00`000000oooo0?ooo`040?ooo`T00?l42P3oool2003o10P0oooo0P00o`@00`3oool00?l4
0?ooo`020?ooo`800<Wo1P3oool>0039o`d0oooo1@00bOl?0?ooo`X00<Wo2P3oool2003o10@0oooo
00<00<Wo0?ooo`3oool0103oool01`00o`@0oooo0?ooo`3oool00?l40?ooo`00o`@01`3oool00`00
o`@0oooo0?ooo`0=0?ooo`<0odL08`3oool002H0oooo0P3oA`0A0?ooo`800?l44@3oool20039o`@0
oooo1000o`@70?ooo`800<Wo1000o`@70039o`03003o103oool0oooo0080oooo2@00bOl20?ooo`<0
0?l43@3oool20039o`d0oooo1@00o`@00`3oool00?l4003o1004003o1080oooo0`00o`@40?ooo`@0
0<Wo5`3oool00`000000oooo0?ooo`090?ooo`P00?l4203oool2003o10P0oooo1000o`@30?ooo`80
0<Wo4P3oool=0039obL0oooo00<00?l40?ooo`00o`@00`3oool00`00bOl00?l40?ooo`040?ooo`05
003o103oool0oooo0?ooo`00o`@00P3oool00`00o`@0oooo0?ooo`050?ooo`03003o103oool0oooo
00d0oooo0P3oA`0T0?ooo`009P3oool20?m70140oooo00<00?l40?ooo`00o`@04@3oool20039o`D0
oooo0`00o`@80?ooo`800<Wo1`3oool<0039o`@0oooo0P00o`@<0?ooo`@00<Wo303oool3003o1080
oooo1000o`@60?ooo`800?l40P3oool50039oa/0oooo00<000000?ooo`3oool03@3oool3003o1004
0?ooo`00o`@00?l4003o10L0oooo00<00?l40?ooo`3oool01`3oool4003o10<0oooo0P00bOm40?oo
o`800?l4103oool00`00bOl0oooo0?ooo`030?ooo`03003o103oool0oooo0080oooo00<00?l40?oo
o`00o`@01`3oool00`00o`@0oooo0?ooo`0>0?ooo`80odL0903oool002L0oooo0P3oA`0A0?ooo`80
0?l44@3oool01000o`@0oooo0039o`00bOl50?ooo`<00?l4203oool20039o`L0oooo0`00bOl70?oo
o`@00?l42P3oool40039o`h0oooo0P00o`@20?ooo`<00?l41`3oool3003o1080oooo0P00bOlP0?oo
o`030000003oool0oooo0100oooo0`00o`@00`3oool00?l4003o1002003o10@0oooo0P00o`@90?oo
o`<00?l4103oool20039od40oooo0P00o`@40?ooo`030039o`3oool0oooo00@0oooo00L00?l40?oo
o`3oool0oooo003o103oool00?l400P0oooo00<00?l40?ooo`3oool03@3oool30?m702@0oooo000W
0?ooo`80odL04@3oool2003o1180oooo00<00?l40039o`3oool00P00bOl40?ooo`D00?l41`3oool3
0039o`80oooo0P00bOl50?ooo`D00?l42`3oool30039o`l0oooo1`00o`@70?ooo`<00?l40P3oool3
0039ob80oooo00<000000?ooo`3oool04`3oool3003o1080oooo1000o`@20?ooo`800?l42@3oool2
003o10D0oooo00<00<Wo0?ooo`3oool0?@3oool2003o10@0oooo00<00<Wo0?ooo`3oool0103oool0
0`00o`@0oooo0?ooo`020?ooo`800?l42@3oool00`00o`@0oooo0?ooo`0=0?ooo`80odL09@3oool0
02L0oooo0P3oA`0A0?ooo`03003o103oool00?l40180oooo00@00?l40039o`3oool0oooo0`00bOl3
0?ooo`03003o103oool00?l400P00?l41P00bOl5003o10L0oooo2@00bOl=0?ooo`P00?l4203oool3
003o1080oooo0`00bOlU0?ooo`030000003oool0oooo01H0oooo1000o`@20?ooo`800?l40P3oool2
003o10T0oooo0P00o`@40?ooo`800<Wo?03oool2003o10@0oooo00<00<Wo003o103oool0103oool0
0`00o`@0oooo0?ooo`020?ooo`03003o103oool00?l400P0oooo00<00?l40?ooo`3oool03P3oool2
0?m702D0oooo000W0?ooo`<0odL04@3oool2003o11<0oooo00<00?l40039o`3oool00`3oool>0039
o`H0oooo3000bOlA0?ooo`P00?l42`3oool2003o10<0oooo0P00bOlX0?ooo`8000006`3oool3003o
10050?ooo`00o`@00?l4003o103oool00P00o`@80?ooo`<00?l4103oool20039ocT0oooo0P00o`@4
0?ooo`030039o`00o`@0oooo00D0oooo00<00?l40?ooo`3oool00P3oool2003o10T0oooo00<00?l4
0?ooo`3oool03@3oool30?m702D0oooo000X0?ooo`80odL04@3oool00`00o`@0oooo003o100C0?oo
o`03003o1000bOl0oooo00P0oooo1P00o`@Q0?ooo`@00?l40P3oool3003o10/0oooo0`00o`@30?oo
o`800<Wo:P3oool00`000000oooo0?ooo`0M0?ooo`T00?l4203oool2003o10D0oooo0P00bOle0?oo
o`<00?l4103oool00`00bOl00?l40?ooo`050?ooo`03003o103oool0oooo0080oooo0P00o`@90?oo
o`03003o103oool0oooo00h0oooo0`3oA`0U0?ooo`00:03oool20?m70180oooo0P00o`@D0?ooo`03
003o1000bOl0oooo00X0oooo0P00o`@00`3oool00?l4003o1002003o11P0oooo1@00o`@20?ooo`@0
0?l4303oool2003o1080oooo1000bOl/0?ooo`030000003oool0oooo0240oooo1`00o`@70?ooo`<0
0?l41@3oool20039oc40oooo0P00o`@00`3oool00?l40?ooo`030?ooo`030039o`00o`@0oooo00H0
oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`080?ooo`03003o103oool0oooo00h0
oooo0P3oA`0V0?ooo`00:@3oool00`3oA`00oooo0?ooo`0@0?ooo`03003o103oool00?l401@0oooo
00<00?l40039o`3oool02`3oool3003o1080oooo1`00o`@90?ooo`l00?l43@3oool3003o10040?oo
o`00bOl00<Wo0039oc00oooo00<000000?ooo`3oool0903oool2003o10040?ooo`00o`@00?l4003o
10L0oooo0`00o`@50?ooo`<00<Wo;@3oool01000o`@0oooo0?ooo`00o`@40?ooo`030039o`00o`@0
oooo00H0oooo00<00?l40?ooo`3oool00P3oool2003o10T0oooo00<00?l40?ooo`3oool03P3oool3
0?m702H0oooo000Y0?ooo`80odL04P3oool2003o11D0oooo00<00?l40039o`3oool03@3ooolH003o
11@0oooo0P00o`@20?ooo`800<Wo<`3oool00`000000oooo0?ooo`0V0?ooo`P00?l41@3oool3003o
10H0oooo0P00bOlZ0?ooo`04003o103oool00?l4003o10@0oooo00<00<Wo003o103oool01`3oool0
0`00o`@0oooo0?ooo`020?ooo`03003o103oool0oooo00P0oooo00<00?l40?ooo`3oool03P3oool3
0?m702H0oooo000Y0?ooo`80odL04P3oool00`00o`@0oooo003o100E0?ooo`03003o1000bOl00<Wo
01D0oooo1@00o`@K0?ooo`<00?l41000bOle0?ooo`030000003oool0oooo02T0oooo1000o`@0103o
ool00?l4003o1000o`@40?ooo`<00?l41P3oool20039obH0oooo0P00o`@00`3oool00?l40?ooo`04
0?ooo`030039o`00o`@0oooo00L0oooo00<00?l40?ooo`3oool00P3oool00`00o`@0oooo0?ooo`08
0?ooo`03003o103oool0oooo00l0oooo0P3oA`0W0?ooo`00:@3oool20?m701<0oooo0P00o`@F0?oo
o`800?l400<00<Wo0?ooo`3oool0;`3oool2003o10@00<Wo>@3oool00`000000oooo0?ooo`0]0?oo
o`P00?l400<0oooo003o103oool00`00o`@50?ooo`<00<Wo8P3oool01000o`@0oooo003o1000o`@3
0?ooo`<00<Wo00<00?l40?ooo`3oool01@3oool2003o10@0oooo0P00o`@:0?ooo`03003o103oool0
oooo00l0oooo0P3oA`0W0?ooo`00:P3oool20?m70180oooo00<00?l40?ooo`00o`@05`3oool00`00
o`@00<Wo0039o`0/0?ooo`<00?l40P00bOlm0?ooo`030000003oool0oooo02l0oooo0P00o`@00`3o
ool00?l4003o1005003o1080oooo0P00o`@60?ooo`800<Wo7P3oool4003o10@0oooo0P00bOl00`00
o`@0oooo0?ooo`060?ooo`03003o103oool0oooo00@0oooo00<00?l40?ooo`3oool0203oool00`00
o`@0oooo0?ooo`0?0?ooo`<0odL09`3oool002X0oooo0P3oA`0C0?ooo`800?l46@3oool00`00o`@0
0<Wo0039o`0X0?ooo`800?l40`00bOlo0?ooo`030000003oool0oooo0340oooo0P00o`@20?ooo`L0
0?l400@0oooo003o1000o`@00?l41@3oool30039oaT0oooo1000o`@40?ooo`800<Wo00<00?l40?oo
o`3oool01`3oool00`00o`@0oooo0?ooo`040?ooo`03003o103oool0oooo00T0oooo00<00?l40?oo
o`3oool03`3oool20?m702P0oooo000Z0?ooo`80odL04`3oool00`00o`@0oooo003o100J0?ooo`03
003o1000bOl00<Wo02<0oooo1@00bOm20?ooo`030000003oool0oooo03<0oooo0`00o`@20?ooo`/0
0?l41@3oool30039oa80oooo1@00o`@50?ooo`800<Wo00<00?l40?ooo`3oool0203oool00`00o`@0
oooo0?ooo`040?ooo`800?l42P3oool00`00o`@0oooo0?ooo`0@0?ooo`80odL0:03oool002/0oooo
0P3oA`0C0?ooo`03003o103oool00?l401/0oooo00<00?l40039o`00bOl00P00bOlJ0?ooo`D00<Wo
A`3oool2000003L0oooo0P00o`@40?ooo`@00?l400<0oooo003o1000o`@01@00o`@30?ooo`@00<Wo
1`3oool:003o10<0oooo1000bOl2003o10X0oooo00<00?l40?ooo`3oool0103oool2003o10/0oooo
00<00?l40?ooo`3oool03`3oool30?m702P0oooo000[0?ooo`80odL0503oool00`00o`@0oooo003o
100N0?ooo`03003o1000bOl00<Wo00800<Wo4P3oool40039o`800?l4BP3oool00`000000oooo0?oo
o`0h0?ooo`800?l4103ooolA003o11@00<Wo1000o`@;0?ooo`03003o103oool0oooo00@0oooo00<0
0?l40?ooo`00o`@02P3oool00`00o`@0oooo0?ooo`0@0?ooo`80odL0:@3oool002/0oooo0`3oA`0C
0?ooo`03003o103oool00?l40240oooo0P00o`@B0039o`800?l4CP3oool00`000000oooo0?ooo`0j
0?ooo`800?l4103oool2003o10D0oooo4P00o`@30?ooo`H00?l43`3oool00`00o`@0oooo0?ooo`04
0?ooo`03003o103oool00?l400X0oooo00<00?l40?ooo`3oool0403oool30?m702T0oooo000/0?oo
o`80odL0503oool00`00o`@0oooo003o100U0?ooo`H00?l4F@3oool00`000000oooo0?ooo`0l0?oo
o`800?l4103oool2003o1100oooo2000o`@C0?ooo`800?l41P3oool00`00o`@0oooo003o100;0?oo
o`03003o103oool0oooo0100oooo0`3oA`0Y0?ooo`00;03oool30?m701@0oooo00<00?l40?ooo`00
o`@0P`3oool00`000000oooo0?ooo`0n0?ooo`<00?l40`3oool3003o12H0oooo0P00o`@70?ooo`03
003o103oool00?l400/0oooo00<00?l40?ooo`3oool04@3oool20?m702X0oooo000]0?ooo`80odL0
503oool01000o`@0oooo0?ooo`00o`B20?ooo`030000003oool0oooo0440oooo1000o`@20?ooo`80
0?l48P3oool2003o10L0oooo0P00o`@00`3oool00?l40?ooo`0;0?ooo`03003o103oool0oooo0100
oooo0`3oA`0Z0?ooo`00;@3oool30?m701@0oooo00<00?l40?ooo`00o`@0PP3oool00`000000oooo
0?ooo`150?ooo`H00?l47@3oool3003o10L0oooo0P00o`@20?ooo`03003o103oool0oooo00X0oooo
00<00?l40?ooo`3oool04@3oool20?m702/0oooo000^0?ooo`80odL05@3oool00`00o`@0oooo003o
101g0?ooo`D000001@3oool00`000000oooo0?ooo`1:0?ooo`@00?l45`3oool3003o10P0oooo0P00
o`@30?ooo`03003o103oool0oooo00/0oooo00<00?l40?ooo`3oool04@3oool20?m702/0oooo000^
0?ooo`<0odL05@3oool00`00o`@0oooo003o101h0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0C@3oool7003o10d0oooo1000o`@90?ooo`800?l4103oool00`00o`@0oooo0?ooo`0;
0?ooo`03003o103oool0oooo0140oooo0P3oA`0/0?ooo`00;`3oool20?m701H0oooo00<00?l40?oo
o`00o`@0M`3oool00`000000oooo0?ooo`050?ooo`<00000D03ooolA003o10/0oooo0P00o`@50?oo
o`03003o103oool0oooo00`0oooo00<00?l40?ooo`3oool04@3oool20?m702`0oooo000_0?ooo`80
odL05`3oool00`00o`@0oooo003o101]0?oooal00?l4B@3oool7003o10/0oooo1P00o`@60?ooo`03
003o103oool0oooo00`0oooo00<00?l40?ooo`3oool04@3oool20?m702d0oooo000`0?ooo`80odL0
5`3oool00`00o`@0oooo003o101U0?ooo`L00?l42@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo1`00o`A90?ooo`/00?l42P3oool2003o10h0oooo00<00?l40?ooo`3oool0
4P3oool20?m702d0oooo000`0?ooo`80odL0603oool00`00o`@0oooo003o101N0?ooo`H00?l43`3o
ool2000000L0oooo00<000000?ooo`3oool04P3oool8003o15H0oooo00<00?l40?ooo`3oool0303o
ool00`00o`@0oooo0?ooo`0C0?ooo`030?m7003oool0oooo02`0oooo000a0?ooo`80odL0603oool0
0`00o`@0oooo003o101H0?ooo`D00?l43P3oool=003o10<0oooo00<000000?ooo`3oool06P3oool5
003o14l0oooo0P00o`@>0?ooo`03003o103oool0oooo01<0oooo0P3oA`0^0?ooo`00<@3oool20?m7
01T0oooo00<00?l40?ooo`00o`@0D`3oool4003o10H0oooo3@00o`@=0?ooo``00?l46@3oool4003o
14T0oooo0P00o`@@0?ooo`03003o103oool0oooo01<0oooo00<0odL00?ooo`3oool0;@3oool00380
oooo0P3oA`0I0?ooo`03003o103oool00?l404l0oooo0`00o`@30?ooo`L00?l47@3oool00`000000
oooo0?ooo`060?ooo`@00?l46@3oool4003o14<0oooo0P00o`@A0?ooo`03003o103oool0oooo01<0
oooo0P3oA`0_0?ooo`00<P3oool20?m701X0oooo1000o`A90?ooo`@00?l400<0oooo003o1000o`@0
0`00o`@T0?ooo`030000003oool0oooo00X0oooo1@00o`@H0?ooo`@00?l4?@3oool2003o1180oooo
00<00?l40?ooo`3oool0503oool20?m702l0oooo000c0?ooo`80odL06`3oool4003o14<0oooo1000
o`@00`3oool00?l4003o1002003o12T0oooo00<000000?ooo`3oool03`3oool5003o11L0oooo1@00
o`@f0?ooo`800?l44`3oool00`00o`@0oooo0?ooo`0D0?ooo`80odL0<03oool003<0oooo0`3oA`0L
0?ooo`03003o103oool00?l403d0oooo1@00o`@00`3oool00?l4003o1002003o12d0oooo00<00000
0?ooo`3oool0503oool4003o11P0oooo1P00o`@]0?ooo`<00?l4503oool00`00o`@0oooo0?ooo`0D
0?ooo`<0odL0<03oool003@0oooo0P3oA`0M0?ooo`@00?l4=`3oool4003o10030?ooo`00o`@00?l4
00<00?l4703oool20?m701<0oooo0P00000I0?ooo`@00?l46P3oool4003o12D0oooo1000o`@F0?oo
o`03003o103oool0oooo01D0oooo0P3oA`0a0?ooo`00=@3oool20?m701h0oooo1000o`@a0?ooo`@0
0?l40P3oool3003o1280oooo103oA`0@0?ooo`030000003oool0oooo01`0oooo1000o`@J0?ooo`H0
0?l46`3oool4003o11P0oooo0P00o`@G0?ooo`<0odL0<@3oool003D0oooo0`3oA`0O0?ooo`D00?l4
:03oool6003o1080oooo1000o`@V0?ooo`H0odL03@3oool00`000000oooo0?ooo`0P0?ooo`@00?l4
703oool8003o10l0oooo1000o`@K0?ooo`03003o103oool0oooo01H0oooo0`3oA`0b0?ooo`00=P3o
ool20?m70240oooo0P00o`@00`3oool00?l4003o100Q0?ooo`D00?l400<0oooo003o1000o`@01@00
o`@[0?ooo`T0odL02@3oool00`000000oooo0?ooo`0T0?ooo`800?l48P3oool?003o11h0oooo00<0
0?l40?ooo`3oool05`3oool30?m70380oooo000f0?ooo`<0odL08P3oool7003o11L0oooo3000o`@c
0?ooo`/0odL01P3oool00`000000oooo0?ooo`0V0?ooo`<00?l4B`3oool00`00o`@0oooo0?ooo`0G
0?ooo`<0odL0<`3oool003L0oooo0`3oA`0U0?ooo`h00?l41`3oool;003o13L0oooo6P3oA`0U0?oo
o`@00?l4A@3oool2003o11T0oooo0`3oA`0d0?ooo`00>03oool20?m702/0oooo5000o`@g0?ooobD0
odL0903oool4003o13l0oooo0P00o`@K0?ooo`<0odL0=03oool003T0oooo0P3oA`1^0?ooobl0odL0
9@3oool4003o13T0oooo0P00o`@L0?ooo`<0odL0=@3oool003T0oooo0`3oA`1X0?oooa`0odL02@3o
ool010000000oooo0?ooo`3oool?0?m702D0oooo1000o`@c0?ooo`800?l47@3oool40?m703D0oooo
000j0?ooo`<0odL0I03oool=0?m700H0oooo1`3oA`0>0?ooo`030000003oool0oooo00T0oooo2`3o
A`0U0?ooo`D00?l4;03oool2003o11l0oooo0`3oA`0f0?ooo`00>`3oool30?m70600oooo2P3oA`0;
0?ooo`<0odL04`3oool200000100oooo2@3oA`0V0?ooo`@00?l49P3oool2003o1200oooo0`3oA`0g
0?ooo`00?03oool30?m705/0oooo2P3oA`0U0?ooo`030000003oool0oooo01<0oooo2@3oA`0V0?oo
o`D00?l47P3oool3003o1240oooo0`3oA`0h0?ooo`00?@3oool30?m705L0oooo2@3oA`0Y0?ooo`03
0000003oool0oooo01H0oooo2P3oA`0W0?ooo`@00?l45P3oool4003o12@0oooo0P3oA`0i0?ooo`00
?P3oool30?m70580oooo2@3oA`0]0?ooo`030000003oool0oooo01T0oooo2@3oA`0Y0?oooaH00?l4
9`3oool30?m703T0oooo000o0?ooo`<0odL0CP3oool90?m70300oooo00<000000?ooo`3oool07@3o
ool70?m706<0oooo0`3oA`0j0?ooo`00@03oool30?m704/0oooo1`3oA`0d0?ooo`030000003oool0
oooo0200oooo1P3oA`1P0?ooo`<0odL0>`3oool00440oooo0`3oA`180?ooo`H0odL0=`3oool00`00
0000oooo0?ooo`0R0?ooo`L0odL0G03oool30?m703`0oooo00120?ooo`@0odL0@`3oool70?m703T0
oooo00<000000?ooo`3oool09@3oool70?m705P0oooo0`3oA`0m0?ooo`00A03oool40?m703d0oooo
2@3oA`0k0?ooo`030000003oool0oooo02P0oooo1`3oA`1D0?ooo`<0odL0?P3oool004D0oooo103o
A`0i0?ooo`T0odL0?P3oool00`000000oooo0?ooo`0Z0?ooo`P0odL0C`3oool40?m703l0oooo0017
0?ooo`@0odL0=03oool80?m70480oooo0P00000^0?ooo`P0odL0B`3oool40?m70400oooo00180?oo
o`D0odL0;P3oool80?m704H0oooo00<000000?ooo`3oool0<03oool80?m700D0oooo0`3oA`0o0?oo
o`@0odL0@@3oool004X0oooo1P3oA`0V0?ooo`X0odL0B@3oool00`000000oooo0?ooo`0c0?ooo`P0
odL000<0oooo0?m7003oA`000`3oA`0m0?ooo`@0odL0@P3oool004`0oooo1`3oA`0P0?ooo`T0odL0
C@3oool00`000000oooo0?ooo`0f0?ooo``0odL0>P3oool40?m704@0oooo001>0?ooo`T0odL0603o
ool90?m70540oooo00<000000?ooo`3oool0>@3oool90?m703T0oooo103oA`150?ooo`00D@3oool<
0?m700L0oooo403oA`1E0?ooo`030000003oool0oooo03/0oooo2@3oA`0e0?ooo`D0odL0AP3oool0
05D0oooo6`3oA`1I0?ooo`030000003oool0oooo03`0oooo303oA`0_0?ooo`D0odL0B03oool005T0
oooo4@3oA`1O0?ooo`030000003oool0oooo03d0oooo0`3oA`020?ooo`X0odL0:@3oool50?m704X0
oooo00390?ooo`030000003oool0oooo04D0oooo2P3oA`0R0?ooo`L0odL0C03oool00<T0oooo0P00
00190?ooo`/0odL0703oool70?m704h0oooo00390?ooo`030000003oool0oooo04`0oooo3P3oA`0A
0?ooo`T0odL0D03oool00<T0oooo00<000000?ooo`3oool0D03ooolR0?m70580oooo00390?ooo`03
0000003oool0oooo05H0oooo603oA`1F0?ooo`00b@3oool00`000000oooo0?ooo`1L0?ooo`d0odL0
F`3oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool0
0<T0oooo00<000000?ooo`3oool0a03oool00;<0oooo1@0000020?ooo`800000103oool2000000L0
oooo00<000000?ooo`3oool0a03oool00;D0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo0<@0oooo002e0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool300000<@0oooo002e0?ooo`030000003oool0oooo00P0oooo0P00
00070?ooo`030000003oool0oooo0<@0oooo002e0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`340?ooo`00]03oool2000000X0oooo0`0000060?oo
o`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000
003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0
oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0
oooo00390?ooo`800000a@3oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3o
ool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03o
ool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0
oooo00<000000?ooo`3oool0a03oool00<T0oooo0P0000350?ooo`00b@3oool00`000000oooo0?oo
o`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?oo
o`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3o
ool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`00
0000oooo0?ooo`340?ooo`00b@3oool200000<D0oooo00390?ooo`030000003oool0oooo0<@0oooo
00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?oo
o`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000
003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0
oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`800000a@3oool00<T0oooo
00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3o
ool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03o
ool00;l0oooo100000060?ooo`030000003oool0oooo0<@0oooo002o0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0a03oool00<00oooo00<000000?ooo`3oool01P3oool300000<@0
oooo00310?ooo`030000003oool0oooo0<`0oooo002o0?ooo`040000003oool0oooo00000<d0oooo
00300?ooo`800000cP3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-2.06156, -2.04617, 0.0102565, \
0.0102565}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{"EquationTrekkerState", "[", 
            
            RowBox[{"\<\"\\!\\({{\\(-x[t]\\) + x[t]\\^3 + \[Gamma]  \
\\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), MultilineFunction->None]\\)[t] \
+  \\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\[Prime]\\), \
MultilineFunction->None]\\)[t] \[Equal] \[Epsilon] Cos[t \[Omega]]}, x, {t, \
0, 100}}\\)\"\>", 
              ",", "\<\"\\!\\({\[Gamma] \[Rule] 0.15`, \[Epsilon] \[Rule] \
0.3`, \[Omega] \[Rule] 1.`}\\)\"\>", ",", 
              InterpretationBox[GridBox[{
                    {
                      InterpretationBox[
                        StyleBox[
                          RowBox[{"TrekData", "[", 
                            
                            RowBox[{"\<\"\\!\\({x[0.`] \[Equal] 0.27`,  \
\\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), \
MultilineFunction->None]\\)[0.`] \[Equal] 0.6399999999999999`}\\)\"\>", ",", 
                              " ", "\<\"<>\"\>"}], "]"}],
                          FontColor->RGBColor[0, 1, 0.0156863]],
                        TrekData[ {
                          Equal[ 
                            x[ 0.`], 0.27`], 
                          Equal[ 
                            Derivative[ 1][ x][ 0.`], 0.6399999999999999`]}, {
                          0.27`, 0.6399999999999999`}, {0.`, {0.`, 100.`}}, {
                          RGBColor[ 0.`, 1.`, 0.01568627543747425`], 
                          "Line"}]]},
                    {
                      InterpretationBox[
                        StyleBox[
                          RowBox[{"TrekData", "[", 
                            
                            RowBox[{"\<\"\\!\\({x[0.`] \[Equal] \
0.6800000000000002`,  \\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), \
MultilineFunction->None]\\)[0.`] \[Equal] 1.3399999999999999`}\\)\"\>", ",", 
                              " ", "\<\"<>\"\>"}], "]"}],
                          FontColor->RGBColor[1, 0.278431, 0]],
                        TrekData[ {
                          Equal[ 
                            x[ 0.`], 0.6800000000000002`], 
                          Equal[ 
                            Derivative[ 1][ x][ 0.`], 1.3399999999999999`]}, {
                          0.6800000000000002`, 1.3399999999999999`}, {0.`, {
                          0.`, 100.`}}, {
                          RGBColor[ 1.`, 0.27843138575553894`, 0.`], 
                          "Line"}]]},
                    {
                      InterpretationBox[
                        StyleBox[
                          RowBox[{"TrekData", "[", 
                            
                            RowBox[{"\<\"\\!\\({x[0.`] \[Equal] \
0.7100000000000004`,  \\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), \
MultilineFunction->None]\\)[0.`] \[Equal] \\(-1.1`\\)}\\)\"\>", ",", 
                              " ", "\<\"<>\"\>"}], "]"}],
                          FontColor->RGBColor[0, 0.788235, 1]],
                        TrekData[ {
                          Equal[ 
                            x[ 0.`], 0.7100000000000004`], 
                          Equal[ 
                            Derivative[ 1][ x][ 0.`], -1.1`]}, {
                          0.7100000000000004`, -1.1`}, {0.`, {0.`, 100.`}}, {
                          RGBColor[ 0.`, 0.7882353067398071`, 1.`], 
                          "Line"}]]}
                    },
                  RowSpacings->1,
                  ColumnSpacings->3,
                  RowAlignments->Baseline,
                  ColumnAlignments->{Left}],
                TableForm[ {
                  TrekData[ {
                    Equal[ 
                      x[ 0.`], 0.27`], 
                    Equal[ 
                      Derivative[ 1][ x][ 0.`], 0.6399999999999999`]}, {0.27`,
                     0.6399999999999999`}, {0.`, {0.`, 100.`}}, {
                    RGBColor[ 0.`, 1.`, 0.01568627543747425`], "Line"}], 
                  TrekData[ {
                    Equal[ 
                      x[ 0.`], 0.6800000000000002`], 
                    Equal[ 
                      Derivative[ 1][ x][ 0.`], 1.3399999999999999`]}, {
                    0.6800000000000002`, 1.3399999999999999`}, {0.`, {0.`, 
                    100.`}}, {
                    RGBColor[ 1.`, 0.27843138575553894`, 0.`], "Line"}], 
                  TrekData[ {
                    Equal[ 
                      x[ 0.`], 0.7100000000000004`], 
                    Equal[ 
                      Derivative[ 1][ x][ 0.`], -1.1`]}, {
                    0.7100000000000004`, -1.1`}, {0.`, {0.`, 100.`}}, {
                    RGBColor[ 0.`, 0.7882353067398071`, 1.`], "Line"}]}]], 
              ",", "\<\" <>\"\>"}], "]"}],
          EquationTrekkerState[ {{
            Equal[ 
              Plus[ 
                Times[ -1, 
                  x[ t]], 
                Power[ 
                  x[ t], 3], 
                Times[ \[Gamma], 
                  Derivative[ 1][ x][ t]], 
                Derivative[ 2][ x][ t]], 
              Times[ \[Epsilon], 
                Cos[ 
                  Times[ t, \[Omega]]]]]}, x, {t, 0, 
            100}}, {\[Gamma] -> .14999999999999999, \[Epsilon] -> \
.29999999999999999, \[Omega] -> 1.0}, {
            TrekData[ {
              Equal[ 
                x[ 0.0], .27000000000000002], 
              Equal[ 
                Derivative[ 1][ x][ 
                0.0], .6399999999999999]}, {.27000000000000002, \
.6399999999999999}, {0.0, {0.0, .1*^3}}, {
              RGBColor[ 0.0, 1.0, .015686275437474251], "Line"}], 
            TrekData[ {
              Equal[ 
                x[ 0.0], .68000000000000016], 
              Equal[ 
                Derivative[ 1][ x][ 0.0], 
                1.3399999999999999]}, {.68000000000000016, 
              1.3399999999999999}, {0.0, {0.0, .1*^3}}, {
              RGBColor[ 1.0, .27843138575553894, 0.0], "Line"}], 
            TrekData[ {
              Equal[ 
                x[ 0.0], .71000000000000041], 
              Equal[ 
                Derivative[ 1][ x][ 
                0.0], -1.1000000000000001]}, {.71000000000000041, \
-1.1000000000000001}, {0.0, {0.0, .1*^3}}, {
              RGBColor[ 0.0, .78823530673980713, 1.0], "Line"}]}, {
            TrekParameters -> {\[Gamma] -> .14999999999999999, \[Epsilon] -> \
.29999999999999999, \[Omega] -> 1.0}, PlotRange -> {{-2.0, 2.0}, {-2.0, 2.0}},
             "CanvasSize" -> {400, 400}}]], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquationTrekker[{\ \(x''\)[t]\  + \ \[Gamma]\ \(x'\)[\ t]\  - \ 
            x[t]\  + \ x[t]^3\  \[Equal] \ \[Epsilon]\ Cos[\[Omega]\ t]}, \ 
      x, \ {t, 0, 
        100}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), 2}, {\(-2\), 
            2}}, \[IndentingNewLine]TrekParameters \[Rule] {\[Gamma] \[Rule]  \
.15, \ \[Epsilon] \[Rule]  .3, \ \[Omega] \[Rule] 1. }, \ 
      TrekGenerator \[Rule] {PoincareSection, \ "\<SectionCondition\>" \
\[Rule] Mod[\[Omega]\ t, \ 2\ \[Pi]], \ "\<SectionVariables\>" \[Rule] {x, \ 
              x'}, MaxSteps \[Rule] \[Infinity]}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.937 1 0 r
.008 w
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.65969 .8354 Mdot
.02 w
.7675 .9525 Mdot
.902 0 1 r
.008 w
.6396 .60779 Mdot
.20174 .71089 Mdot
.66544 .59828 Mdot
.17008 .63127 Mdot
.80161 .44682 Mdot
.80742 .58563 Mdot
.71993 .68911 Mdot
.30799 .75732 Mdot
.14552 .50447 Mdot
.1985 .44523 Mdot
.40377 .63724 Mdot
.48587 .49427 Mdot
.76607 .49698 Mdot
.78509 .66156 Mdot
.17673 .6244 Mdot
.83024 .64165 Mdot
.16993 .56352 Mdot
.30123 .71171 Mdot
.5368 .53387 Mdot
.34441 .38924 Mdot
.29647 .57457 Mdot
.44239 .61264 Mdot
.37677 .40589 Mdot
.28142 .54382 Mdot
.39772 .56848 Mdot
.58506 .61442 Mdot
.22662 .74799 Mdot
.44854 .45483 Mdot
.44089 .57955 Mdot
.6542 .61688 Mdot
.20798 .71612 Mdot
.65261 .59777 Mdot
.17717 .65939 Mdot
.74088 .50853 Mdot
.7036 .67688 Mdot
.2931 .75742 Mdot
.17081 .41288 Mdot
.36254 .68949 Mdot
.31714 .36755 Mdot
.3172 .59701 Mdot
.4514 .67446 Mdot
.19352 .73282 Mdot
.54125 .53222 Mdot
.33243 .3829 Mdot
.3047 .58301 Mdot
.45508 .63412 Mdot
.15999 .45969 Mdot
.33566 .70287 Mdot
.39618 .4162 Mdot
.28406 .51945 Mdot
.36972 .55083 Mdot
.46951 .64927 Mdot
.16736 .67688 Mdot
.69472 .58237 Mdot
.18382 .43982 Mdot
.40007 .66118 Mdot
.28164 .35734 Mdot
.34277 .61235 Mdot
.28246 .39132 Mdot
.33807 .59176 Mdot
.43343 .68925 Mdot
.194 .73595 Mdot
.52016 .51488 Mdot
.58812 .58513 Mdot
.17237 .66429 Mdot
.72396 .54153 Mdot
.51067 .53827 Mdot
.48085 .4945 Mdot
.79555 .46461 Mdot
.81014 .59685 Mdot
.64185 .65284 Mdot
.29724 .76802 Mdot
.14181 .55052 Mdot
.84628 .50077 Mdot
.83135 .55261 Mdot
.81751 .63815 Mdot
.18887 .44472 Mdot
.40407 .65215 Mdot
.33326 .3771 Mdot
.30503 .58668 Mdot
.45746 .64197 Mdot
.14798 .54824 Mdot
.61516 .64018 Mdot
.28292 .76972 Mdot
.14836 .48111 Mdot
.20498 .65366 Mdot
.84908 .53795 Mdot
.81732 .64339 Mdot
.17319 .49848 Mdot
.39469 .68085 Mdot
.17844 .40739 Mdot
.37898 .67804 Mdot
.29509 .35986 Mdot
.33331 .60703 Mdot
.33251 .71688 Mdot
.27681 .35358 Mdot
.34633 .61625 Mdot
.84528 .58389 Mdot
.56016 .58889 Mdot
.1656 .65014 Mdot
.73364 .52028 Mdot
.64565 .64926 Mdot
.28619 .76522 Mdot
.1556 .45148 Mdot
.29752 .70751 Mdot
.58758 .57267 Mdot
.15862 .60568 Mdot
.82834 .45987 Mdot
.81339 .54609 Mdot
.81915 .62576 Mdot
.27587 .3844 Mdot
.34382 .59804 Mdot
.35691 .71322 Mdot
.17292 .41428 Mdot
.37018 .68542 Mdot
.29538 .35959 Mdot
.33315 .60712 Mdot
.33267 .71685 Mdot
.27596 .35345 Mdot
.34691 .61662 Mdot
.84774 .54399 Mdot
.80964 .65639 Mdot
.17347 .60349 Mdot
.22378 .41013 Mdot
.38342 .61738 Mdot
.71325 .59863 Mdot
.18606 .43826 Mdot
.40106 .6578 Mdot
.30464 .36399 Mdot
.32622 .60214 Mdot
.41683 .69543 Mdot
.17278 .69977 Mdot
.6495 .59344 Mdot
.17337 .6488 Mdot
.75551 .48282 Mdot
.76992 .66995 Mdot
.20224 .68856 Mdot
.71904 .55792 Mdot
.39463 .43702 Mdot
.30135 .50762 Mdot
.35328 .53883 Mdot
.43521 .58912 Mdot
.63189 .60726 Mdot
.20522 .71718 Mdot
.64572 .59597 Mdot
.17869 .66551 Mdot
.73225 .52614 Mdot
.62161 .63296 Mdot
.26431 .7629 Mdot
.22167 .35676 Mdot
.37688 .64657 Mdot
.60837 .59058 Mdot
.18277 .68503 Mdot
.7052 .57493 Mdot
.2357 .38393 Mdot
.37362 .61982 Mdot
.72694 .57466 Mdot
.35484 .40995 Mdot
.29022 .55427 Mdot
.412 .57827 Mdot
.74106 .54648 Mdot
.60486 .62141 Mdot
.24347 .75602 Mdot
.34358 .37675 Mdot
.29854 .58375 Mdot
.45294 .63163 Mdot
.17279 .42394 Mdot
.37566 .6833 Mdot
.27252 .35479 Mdot
.34911 .617 Mdot
.83458 .48019 Mdot
.82051 .54196 Mdot
.82417 .61162 Mdot
.42407 .46536 Mdot
.40355 .54483 Mdot
.40204 .70436 Mdot
.16404 .67914 Mdot
.68298 .58915 Mdot
.16319 .52442 Mdot
.32872 .70761 Mdot
.39939 .41841 Mdot
.28641 .51509 Mdot
.36471 .54805 Mdot
.4644 .63232 Mdot
.15037 .51409 Mdot
.19156 .62487 Mdot
.18 .50637 Mdot
.40885 .66996 Mdot
.17291 .41912 Mdot
.3732 .68421 Mdot
.28303 .35648 Mdot
.3419 .61246 Mdot
.24054 .39773 Mdot
.37019 .60907 Mdot
.76355 .49079 Mdot
.78263 .66243 Mdot
.17874 .63246 Mdot
.8471 .51196 Mdot
.8332 .57015 Mdot
.77203 .68719 Mdot
.25803 .73798 Mdot
.48062 .48386 Mdot
.52071 .55649 Mdot
.27193 .36189 Mdot
.349 .61286 Mdot
.8182 .66037 Mdot
.19144 .66228 Mdot
.76468 .47272 Mdot
.78762 .65285 Mdot
.16799 .54654 Mdot
.33003 .70841 Mdot
.38091 .4046 Mdot
.28004 .54188 Mdot
.39553 .56725 Mdot
.20609 .4278 Mdot
.39704 .63101 Mdot
.59179 .58081 Mdot
.1675 .64739 Mdot
.74283 .50293 Mdot
.71912 .68006 Mdot
.28332 .75313 Mdot
.2297 .35449 Mdot
.37382 .64111 Mdot
.65661 .61245 Mdot
.19755 .70105 Mdot
.68936 .59153 Mdot
.16511 .50972 Mdot
.3571 .69967 Mdot
.26255 .35318 Mdot
.3557 .62201 Mdot
.75977 .49591 Mdot
.77333 .67036 Mdot
.20178 .68739 Mdot
.72079 .55454 Mdot
.4247 .46129 Mdot
.39447 .53693 Mdot
.47058 .66664 Mdot
.21386 .75455 Mdot
.38976 .4067 Mdot
.27909 .53295 Mdot
.38539 .56068 Mdot
.40486 .70274 Mdot
.16584 .68392 Mdot
.67651 .59184 Mdot
.16195 .56441 Mdot
.19614 .63837 Mdot
.56403 .59682 Mdot
.18051 .6905 Mdot
.69096 .58769 Mdot
.16994 .48201 Mdot
.38557 .68463 Mdot
.19945 .37921 Mdot
.38494 .65863 Mdot
.44036 .45395 Mdot
.41608 .55417 Mdot
.83734 .61776 Mdot
.23557 .39262 Mdot
.37393 .61537 Mdot
.73567 .55394 Mdot
.53491 .5613 Mdot
.19345 .39792 Mdot
.39045 .65852 Mdot
.39141 .4146 Mdot
.28254 .52477 Mdot
.37557 .55402 Mdot
.46652 .66842 Mdot
.21013 .75132 Mdot
.41791 .42856 Mdot
.31145 .49894 Mdot
.34324 .53324 Mdot
.41084 .56507 Mdot
.80854 .45941 Mdot
.81142 .57528 Mdot
.76888 .68625 Mdot
.25604 .73741 Mdot
.49183 .49353 Mdot
.74986 .53582 Mdot
.68881 .67385 Mdot
.30242 .76115 Mdot
.14482 .50855 Mdot
.24492 .39795 Mdot
.36674 .60594 Mdot
.80314 .45745 Mdot
.81023 .5837 Mdot
.7325 .69111 Mdot
.30061 .75466 Mdot
.16422 .42819 Mdot
.34557 .69794 Mdot
.36908 .39684 Mdot
.28318 .55666 Mdot
.41442 .5826 Mdot
.72773 .5807 Mdot
.32456 .39363 Mdot
.30832 .57819 Mdot
.45266 .62676 Mdot
.1946 .38913 Mdot
.38731 .66052 Mdot
.39937 .42056 Mdot
.28808 .51356 Mdot
.36269 .54671 Mdot
.46082 .625 Mdot
.17232 .42583 Mdot
.37544 .68372 Mdot
.27047 .35455 Mdot
.35048 .61792 Mdot
.81501 .45886 Mdot
.81186 .56534 Mdot
.79555 .66776 Mdot
.19278 .66811 Mdot
.75007 .49444 Mdot
.75061 .67903 Mdot
.24527 .73381 Mdot
.54705 .5396 Mdot
.25866 .3632 Mdot
.358 .61769 Mdot
.77127 .47861 Mdot
.79561 .64393 Mdot
.18308 .45681 Mdot
.4044 .6603 Mdot
.25638 .35536 Mdot
.35961 .62356 Mdot
.74449 .52896 Mdot
.67958 .66915 Mdot
.30088 .76237 Mdot
.14441 .51168 Mdot
.29798 .39549 Mdot
.32618 .58456 Mdot
.46174 .65866 Mdot
.17423 .69598 Mdot
.66495 .59487 Mdot
.16705 .61751 Mdot
.84219 .48888 Mdot
.82609 .54068 Mdot
.8262 .60675 Mdot
.47649 .51172 Mdot
.74516 .54685 Mdot
.62897 .63968 Mdot
.27571 .7654 Mdot
.17554 .40269 Mdot
.36925 .68435 Mdot
.31323 .36611 Mdot
.32006 .59882 Mdot
.44403 .68119 Mdot
.19573 .73696 Mdot
.51658 .51197 Mdot
.62429 .60875 Mdot
.21166 .72643 Mdot
.60738 .57999 Mdot
.16815 .64465 Mdot
.75021 .49022 Mdot
.75392 .67766 Mdot
.23788 .7286 Mdot
.5936 .57331 Mdot
.16018 .61293 Mdot
.81137 .44727 Mdot
.80863 .57057 Mdot
.7808 .67969 Mdot
.22985 .71926 Mdot
.64772 .59873 Mdot
.18148 .67197 Mdot
.72547 .5407 Mdot
.52476 .55124 Mdot
.28606 .36437 Mdot
.33896 .6067 Mdot
.27569 .71532 Mdot
.60828 .58466 Mdot
.17404 .66343 Mdot
.72808 .53363 Mdot
.57084 .59228 Mdot
.17668 .68017 Mdot
.70512 .5737 Mdot
.2401 .38218 Mdot
.37054 .61757 Mdot
.73717 .54944 Mdot
.56657 .58948 Mdot
.17004 .66314 Mdot
.72181 .54514 Mdot
.479 .50915 Mdot
.74512 .54748 Mdot
.62631 .6378 Mdot
.2729 .76502 Mdot
.18421 .38923 Mdot
.37743 .67537 Mdot
.33419 .37656 Mdot
.30452 .58678 Mdot
.45732 .64179 Mdot
.14804 .54561 Mdot
.54427 .57943 Mdot
.15228 .55146 Mdot
.27458 .39228 Mdot
.34389 .59399 Mdot
.39648 .70331 Mdot
.15258 .63577 Mdot
.72546 .5332 Mdot
.55554 .57878 Mdot
.15403 .58339 Mdot
.84551 .59438 Mdot
.40905 .4536 Mdot
.34332 .50739 Mdot
.36246 .52976 Mdot
.43043 .58177 Mdot
.68867 .61938 Mdot
.17914 .65492 Mdot
.75559 .48356 Mdot
.76981 .67015 Mdot
.20289 .68959 Mdot
.71767 .56053 Mdot
.37151 .42015 Mdot
.2864 .53566 Mdot
.38697 .55923 Mdot
.40562 .70259 Mdot
.16701 .68705 Mdot
.67173 .59312 Mdot
.16324 .58802 Mdot
.37836 .43522 Mdot
.29366 .51946 Mdot
.367 .54607 Mdot
.46449 .63169 Mdot
.15092 .50911 Mdot
.20722 .65819 Mdot
.83482 .47374 Mdot
.81869 .53996 Mdot
.82421 .60936 Mdot
.45488 .49211 Mdot
.42389 .70026 Mdot
.20358 .74959 Mdot
.42657 .43537 Mdot
.33698 .50169 Mdot
.34991 .52614 Mdot
.4047 .55815 Mdot
.18687 .46873 Mdot
.4095 .6533 Mdot
.27718 .35695 Mdot
.34583 .61403 Mdot
.74954 .70105 Mdot
.31607 .75418 Mdot
.14348 .52789 Mdot
.64707 .66351 Mdot
.31777 .76966 Mdot
.16261 .68823 Mdot
.65631 .5931 Mdot
.16954 .63243 Mdot
.79342 .44825 Mdot
.80596 .59876 Mdot
.62319 .63947 Mdot
.27816 .7671 Mdot
.16308 .42876 Mdot
.3398 .69981 Mdot
.39587 .41611 Mdot
.28394 .51979 Mdot
.37009 .55103 Mdot
.46965 .6505 Mdot
.17019 .68465 Mdot
.6847 .58944 Mdot
.16381 .51868 Mdot
.34069 .70484 Mdot
.33577 .37602 Mdot
.30358 .58668 Mdot
.45694 .6409 Mdot
.14844 .53473 Mdot
.27863 .39251 Mdot
.34079 .59238 Mdot
.42159 .69458 Mdot
.18119 .7166 Mdot
.604 .57579 Mdot
.16356 .62668 Mdot
.78159 .45351 Mdot
.80203 .61898 Mdot
.3938 .4404 Mdot
.30464 .50683 Mdot
.35189 .53723 Mdot
.43013 .58344 Mdot
.68344 .62005 Mdot
.18526 .6718 Mdot
.73098 .53022 Mdot
.60113 .61742 Mdot
.23508 .75139 Mdot
.40625 .42025 Mdot
.29094 .50839 Mdot
.35702 .54403 Mdot
.44988 .60784 Mdot
.3564 .39249 Mdot
.28941 .56705 Mdot
.42977 .59759 Mdot
.61162 .59562 Mdot
.19082 .69991 Mdot
.68413 .59308 Mdot
.16242 .5407 Mdot
.28913 .71041 Mdot
.59891 .57972 Mdot
.16731 .64438 Mdot
.74842 .49305 Mdot
.74705 .67946 Mdot
.2501 .73699 Mdot
.51103 .50985 Mdot
.66046 .62457 Mdot
.21765 .72577 Mdot
.61451 .58432 Mdot
.17318 .65909 Mdot
.73379 .52175 Mdot
.64259 .64736 Mdot
.2842 .76529 Mdot
.15871 .44136 Mdot
.31921 .70524 Mdot
.49174 .49603 Mdot
.7451 .55016 Mdot
.61572 .63008 Mdot
.26016 .7623 Mdot
.23866 .35083 Mdot
.36932 .63672 Mdot
.69164 .61199 Mdot
.16798 .61077 Mdot
.82781 .64693 Mdot
.17351 .59921 Mdot
.17926 .51459 Mdot
.40698 .67368 Mdot
.16518 .43706 Mdot
.35574 .6949 Mdot
.31795 .36766 Mdot
.31664 .59675 Mdot
.4523 .67337 Mdot
.19249 .73118 Mdot
.54995 .53907 Mdot
.25118 .36406 Mdot
.36298 .62103 Mdot
.7439 .53092 Mdot
.67171 .66536 Mdot
.29999 .76349 Mdot
.14372 .51823 Mdot
.45269 .49556 Mdot
.41353 .70319 Mdot
.18657 .72718 Mdot
.56041 .54677 Mdot
.19147 .40343 Mdot
.39173 .65925 Mdot
.37225 .40075 Mdot
.28217 .55135 Mdot
.40734 .57626 Mdot
.75913 .50223 Mdot
.76842 .67417 Mdot
.21596 .70709 Mdot
.68762 .59519 Mdot
.16278 .53734 Mdot
.30138 .71074 Mdot
.54448 .54019 Mdot
.2652 .36296 Mdot
.35356 .61488 Mdot
.82113 .46273 Mdot
.81336 .55649 Mdot
.81031 .64722 Mdot
.17096 .51241 Mdot
.38413 .68876 Mdot
.18348 .39845 Mdot
.38206 .673 Mdot
.31837 .36888 Mdot
.31616 .59587 Mdot
.45409 .6711 Mdot
.19018 .7274 Mdot
.56848 .55299 Mdot
.16685 .45718 Mdot
.37096 .68993 Mdot
.24927 .35431 Mdot
.36395 .62798 Mdot
.72676 .57325 Mdot
.36193 .41441 Mdot
.28778 .54666 Mdot
.40113 .5693 Mdot
.84601 .57486 Mdot
.654 .66218 Mdot
.30916 .76762 Mdot
.14665 .62257 Mdot
.72766 .52707 Mdot
.59148 .60937 Mdot
.21721 .73852 Mdot
.53097 .52509 Mdot
.44729 .46608 Mdot
.46388 .6103 Mdot
.23253 .36299 Mdot
.37398 .63391 Mdot
.6875 .61368 Mdot
.17254 .63339 Mdot
.80711 .44733 Mdot
.80826 .57708 Mdot
.75986 .68886 Mdot
.26987 .74406 Mdot
.37499 .39815 Mdot
.28088 .55175 Mdot
.40789 .57714 Mdot
.75423 .51249 Mdot
.74642 .68209 Mdot
.25901 .74143 Mdot
.44412 .45237 Mdot
.42221 .55975 Mdot
.76754 .48882 Mdot
.7896 .65493 Mdot
.16845 .56535 Mdot
.27805 .70977 Mdot
.63517 .59831 Mdot
.18777 .68877 Mdot
.70466 .57662 Mdot
.2274 .38808 Mdot
.37933 .62443 Mdot
.7037 .60693 Mdot
.16419 .531 Mdot
.32716 .70817 Mdot
.40512 .42283 Mdot
.29283 .5077 Mdot
.35574 .54293 Mdot
.44628 .60293 Mdot
.4355 .45222 Mdot
.39825 .53852 Mdot
.4619 .67833 Mdot
.22902 .76861 Mdot
.25375 .34744 Mdot
.36096 .6298 Mdot
.72807 .56987 Mdot
.39096 .43487 Mdot
.29716 .51093 Mdot
.35745 .5415 Mdot
.44605 .60223 Mdot
.44427 .45968 Mdot
.44184 .58132 Mdot
.63985 .61145 Mdot
.2085 .71964 Mdot
.63837 .59407 Mdot
.17975 .67024 Mdot
.72587 .53949 Mdot
.5327 .55847 Mdot
.21132 .37959 Mdot
.38537 .64451 Mdot
.56839 .56306 Mdot
.15529 .51874 Mdot
.25112 .69968 Mdot
.70511 .58746 Mdot
.19486 .42086 Mdot
.39835 .64855 Mdot
.42182 .43893 Mdot
.33568 .50215 Mdot
.34998 .52653 Mdot
.40559 .55893 Mdot
.29067 .39223 Mdot
.33189 .58864 Mdot
.45418 .67448 Mdot
.19987 .74109 Mdot
.49293 .49195 Mdot
.75082 .53324 Mdot
.69951 .67777 Mdot
.30026 .75922 Mdot
.15066 .47293 Mdot
.24129 .69288 Mdot
.72253 .55925 Mdot
.41184 .45082 Mdot
.3424 .50649 Mdot
.36033 .52895 Mdot
.42542 .5766 Mdot
.71807 .59931 Mdot
.19576 .4213 Mdot
.39848 .64713 Mdot
.43508 .44999 Mdot
.39119 .53271 Mdot
.47271 .64867 Mdot
.17148 .68743 Mdot
.68111 .59123 Mdot
.16213 .54326 Mdot
.27868 .70917 Mdot
.63696 .59907 Mdot
.1881 .68897 Mdot
.70466 .57669 Mdot
.22716 .38822 Mdot
.3795 .62457 Mdot
.70287 .60754 Mdot
.16378 .53851 Mdot
.30905 .71052 Mdot
.50445 .50669 Mdot
.69622 .62616 Mdot
.18226 .66148 Mdot
.7466 .49884 Mdot
.73655 .68105 Mdot
.26609 .74556 Mdot
.37551 .39837 Mdot
.28071 .5512 Mdot
.40719 .57657 Mdot
.75855 .50334 Mdot
.76634 .67534 Mdot
.2209 .71266 Mdot
.67251 .60007 Mdot
.16793 .61873 Mdot
.84294 .4915 Mdot
.82723 .54237 Mdot
.82574 .61022 Mdot
.43205 .47217 Mdot
.44161 .58296 Mdot
.63178 .60763 Mdot
.20598 .71817 Mdot
.64235 .5951 Mdot
.17926 .66793 Mdot
.729 .53296 Mdot
.5792 .59944 Mdot
.1935 .71133 Mdot
.65298 .59635 Mdot
.17509 .65317 Mdot
.74958 .49247 Mdot
.7507 .67873 Mdot
.24425 .73318 Mdot
.55363 .54477 Mdot
.21269 .3804 Mdot
.38523 .64263 Mdot
.58405 .57473 Mdot
.15946 .61305 Mdot
.80552 .44594 Mdot
.80774 .57952 Mdot
.74976 .69068 Mdot
.2833 .74916 Mdot
.26296 .34997 Mdot
.35547 .62382 Mdot
.75368 .50754 Mdot
.74982 .68096 Mdot
.25216 .73774 Mdot
.4994 .49993 Mdot
.7252 .60238 Mdot
.2065 .40781 Mdot
.39309 .63746 Mdot
.56969 .56443 Mdot
.15449 .53047 Mdot
.21087 .66438 Mdot
.80494 .4498 Mdot
.80863 .58052 Mdot
.74636 .69109 Mdot
.28745 .75053 Mdot
.23323 .35356 Mdot
.37222 .63895 Mdot
.67327 .61482 Mdot
.18657 .67711 Mdot
.72352 .54581 Mdot
.48785 .51735 Mdot
.71226 .61566 Mdot
.16425 .54313 Mdot
.303 .71093 Mdot
.53453 .53206 Mdot
.37102 .40601 Mdot
.28327 .54772 Mdot
.40255 .5718 Mdot
.82102 .46452 Mdot
.81382 .55676 Mdot
.81026 .64747 Mdot
.17068 .51492 Mdot
.3819 .69012 Mdot
.18611 .3945 Mdot
.38319 .67045 Mdot
.33397 .37666 Mdot
.30464 .58677 Mdot
.45736 .64187 Mdot
.14801 .54664 Mdot
.57256 .60475 Mdot
.20089 .72341 Mdot
.61152 .58149 Mdot
.16984 .64932 Mdot
.74485 .49973 Mdot
.72992 .68099 Mdot
.27336 .74892 Mdot
.31018 .36109 Mdot
.32291 .60269 Mdot
.42368 .6924 Mdot
.18002 .71408 Mdot
.61277 .5805 Mdot
.16861 .64453 Mdot
.75182 .48772 Mdot
.75944 .67559 Mdot
.22663 .71897 Mdot
.64922 .59881 Mdot
.1807 .66966 Mdot
.72822 .5349 Mdot
.56695 .58896 Mdot
.16948 .66132 Mdot
.72361 .54148 Mdot
.50853 .53628 Mdot
.51176 .52171 Mdot
.59358 .58855 Mdot
.17867 .67942 Mdot
.70937 .56848 Mdot
.28194 .37898 Mdot
.34003 .59916 Mdot
.37331 .70944 Mdot
.14737 .50843 Mdot
.17918 .52328 Mdot
.40515 .67688 Mdot
.16014 .45174 Mdot
.33435 .70274 Mdot
.40786 .42526 Mdot
.29724 .50459 Mdot
.35157 .54027 Mdot
.43566 .59 Mdot
.62401 .60318 Mdot
.20115 .71336 Mdot
.65606 .59761 Mdot
.17488 .65156 Mdot
.75285 .48713 Mdot
.7622 .67445 Mdot
.22093 .71319 Mdot
.67071 .60025 Mdot
.16909 .62499 Mdot
.82402 .45601 Mdot
.81183 .55196 Mdot
.814 .63898 Mdot
.19105 .43976 Mdot
.40318 .64958 Mdot
.36692 .39753 Mdot
.28416 .55739 Mdot
.4155 .58338 Mdot
.72403 .58818 Mdot
.26273 .3793 Mdot
.35412 .60631 Mdot
.60746 .63305 Mdot
.26894 .76702 Mdot
.18291 .39073 Mdot
.37635 .67676 Mdot
.32939 .37399 Mdot
.30803 .58982 Mdot
.45913 .65094 Mdot
.1552 .63337 Mdot
.73532 .51439 Mdot
.668 .6621 Mdot
.29593 .76343 Mdot
.14708 .49087 Mdot
.18346 .59352 Mdot
.30413 .7129 Mdot
.51052 .51174 Mdot
.65409 .62242 Mdot
.21922 .72853 Mdot
.59948 .57584 Mdot
.16322 .62686 Mdot
.77917 .45518 Mdot
.80083 .62336 Mdot
.34191 .40587 Mdot
.29676 .56355 Mdot
.42745 .5928 Mdot
.65283 .61542 Mdot
.20632 .7143 Mdot
.65805 .5984 Mdot
.17465 .65022 Mdot
.75558 .48291 Mdot
.77004 .66989 Mdot
.20202 .6882 Mdot
.71952 .557 Mdot
.40283 .44341 Mdot
.31665 .50278 Mdot
.34675 .53169 Mdot
.41204 .56553 Mdot
.79409 .46195 Mdot
.80914 .59898 Mdot
.62244 .63905 Mdot
.27756 .76706 Mdot
.16436 .42555 Mdot
.34444 .69812 Mdot
.37636 .40187 Mdot
.28086 .54759 Mdot
.40253 .57252 Mdot
.81392 .46045 Mdot
.81219 .56705 Mdot
.79219 .67122 Mdot
.20228 .68579 Mdot
.72405 .54825 Mdot
.47981 .51007 Mdot
.74189 .55744 Mdot
.56171 .58565 Mdot
.16236 .63673 Mdot
.7498 .48985 Mdot
.75308 .67781 Mdot
.23913 .72957 Mdot
.58606 .56838 Mdot
.15592 .58128 Mdot
.77208 .69899 Mdot
.29879 .74953 Mdot
.19534 .37777 Mdot
.38227 .66459 Mdot
.40265 .42292 Mdot
.29157 .50947 Mdot
.35774 .54391 Mdot
.45062 .60878 Mdot
.34121 .38338 Mdot
.29911 .57989 Mdot
.44966 .62422 Mdot
.22416 .36564 Mdot
.37818 .6393 Mdot
.64633 .6096 Mdot
.2005 .7077 Mdot
.67431 .59734 Mdot
.1649 .59995 Mdot
.71878 .69836 Mdot
.33477 .75932 Mdot
.16701 .6977 Mdot
.63972 .59043 Mdot
.17425 .65466 Mdot
.74431 .50153 Mdot
.72608 .68087 Mdot
.27746 .75065 Mdot
.27552 .35106 Mdot
.34735 .61826 Mdot
.83556 .48215 Mdot
.82138 .54164 Mdot
.82457 .61046 Mdot
.43719 .47656 Mdot
.46331 .6114 Mdot
.22869 .36444 Mdot
.37603 .63613 Mdot
.67128 .61506 Mdot
.18884 .6823 Mdot
.71741 .55788 Mdot
.3838 .42883 Mdot
.29016 .51984 Mdot
.36822 .54786 Mdot
.46718 .63873 Mdot
.14964 .58913 Mdot
.81287 .4467 Mdot
.80859 .56828 Mdot
.78649 .67559 Mdot
.21565 .70458 Mdot
.69409 .5914 Mdot
.16897 .4877 Mdot
.3822 .68722 Mdot
.20104 .37748 Mdot
.38467 .65747 Mdot
.45456 .46612 Mdot
.47723 .63338 Mdot
.15234 .61002 Mdot
.76984 .46186 Mdot
.79384 .64073 Mdot
.19572 .42937 Mdot
.40059 .64491 Mdot
.43843 .4529 Mdot
.40795 .54672 Mdot
.32457 .71952 Mdot
.30578 .36135 Mdot
.32584 .60352 Mdot
.40988 .69797 Mdot
.16463 .67958 Mdot
.68342 .58905 Mdot
.16341 .52205 Mdot
.33373 .70655 Mdot
.37216 .39853 Mdot
.282 .5533 Mdot
.4099 .57864 Mdot
.74477 .53604 Mdot
.66233 .6606 Mdot
.29796 .7647 Mdot
.14365 .51821 Mdot
.46 .50208 Mdot
.17776 .51157 Mdot
.4043 .67552 Mdot
.16679 .43259 Mdot
.36032 .69257 Mdot
.30455 .3623 Mdot
.32653 .60322 Mdot
.40931 .69821 Mdot
.16408 .67804 Mdot
.6854 .58797 Mdot
.16506 .50784 Mdot
.358 .69925 Mdot
.25997 .35317 Mdot
.35734 .62318 Mdot
.75083 .51383 Mdot
.73358 .68278 Mdot
.27457 .74881 Mdot
.3058 .35939 Mdot
.32611 .60475 Mdot
.40055 .70114 Mdot
.1548 .64568 Mdot
.71735 .5493 Mdot
.42754 .46342 Mdot
.40728 .54769 Mdot
.31877 .71987 Mdot
.34269 .37909 Mdot
.29877 .5824 Mdot
.4519 .62905 Mdot
.18687 .39905 Mdot
.38641 .66762 Mdot
.33439 .37701 Mdot
.30432 .58641 Mdot
.45707 .6409 Mdot
.14839 .53572 Mdot
.29607 .39494 Mdot
.32762 .58544 Mdot
.46098 .66235 Mdot
.1817 .71178 Mdot
.62746 .58755 Mdot
.1749 .6603 Mdot
.73485 .51998 Mdot
.65275 .65372 Mdot
.2906 .76496 Mdot
.15001 .47432 Mdot
.23179 .68598 Mdot
.73711 .52613 Mdot
.64876 .65168 Mdot
.28925 .76536 Mdot
.15079 .47055 Mdot
.24379 .69436 Mdot
.71912 .56619 Mdot
.35067 .40687 Mdot
.29211 .55879 Mdot
.41892 .58466 Mdot
.71363 .60367 Mdot
.17646 .46343 Mdot
.3982 .67163 Mdot
.21286 .36906 Mdot
.38216 .64829 Mdot
.56054 .55678 Mdot
.16613 .45787 Mdot
.36823 .69132 Mdot
.25662 .35367 Mdot
.35945 .62448 Mdot
.74247 .53395 Mdot
.65594 .65669 Mdot
.29469 .7652 Mdot
.1453 .50257 Mdot
.19876 .44472 Mdot
.40357 .63695 Mdot
.49035 .49819 Mdot
.74377 .55397 Mdot
.59091 .61053 Mdot
.21957 .74087 Mdot
.51295 .51008 Mdot
.65111 .62151 Mdot
.21997 .72982 Mdot
.5919 .5711 Mdot
.15829 .60073 Mdot
.84327 .49149 Mdot
.8274 .54235 Mdot
.82578 .61019 Mdot
.4321 .47221 Mdot
.44183 .58322 Mdot
.62894 .6062 Mdot
.20469 .7171 Mdot
.64548 .59586 Mdot
.17867 .6655 Mdot
.73221 .52621 Mdot
.62119 .63265 Mdot
.26381 .76279 Mdot
.22401 .35569 Mdot
.37599 .64512 Mdot
.62306 .59897 Mdot
.19392 .70261 Mdot
.68111 .5947 Mdot
.1622 .56162 Mdot
.21105 .66549 Mdot
.79852 .4502 Mdot
.80767 .59068 Mdot
.68898 .67915 Mdot
.31565 .76263 Mdot
.14584 .61464 Mdot
.73562 .51127 Mdot
.6759 .66592 Mdot
.29692 .76232 Mdot
.14812 .48507 Mdot
.19893 .64215 Mdot
.66874 .67648 Mdot
.32953 .76681 Mdot
.1779 .72251 Mdot
.56153 .54705 Mdot
.18877 .40748 Mdot
.39182 .66178 Mdot
.34565 .38358 Mdot
.29637 .57818 Mdot
.44658 .61952 Mdot
.27927 .35901 Mdot
.34422 .61208 Mdot
.36744 .42693 Mdot
.28953 .53316 Mdot
.38351 .55603 Mdot
.44402 .68805 Mdot
.21623 .76029 Mdot
.33608 .37136 Mdot
.30411 .58974 Mdot
.45819 .64759 Mdot
.15037 .60151 Mdot
.78053 .45254 Mdot
.80125 .62058 Mdot
.37436 .4262 Mdot
.28837 .52882 Mdot
.37851 .55347 Mdot
.46398 .6728 Mdot
.21723 .75863 Mdot
.35159 .38053 Mdot
.29317 .57814 Mdot
.44515 .61818 Mdot
.30166 .36482 Mdot
.32812 .60233 Mdot
.40899 .69842 Mdot
.16393 .67764 Mdot
.68588 .58769 Mdot
.16558 .50423 Mdot
.36293 .69727 Mdot
.24317 .35482 Mdot
.36747 .63133 Mdot
.71246 .59712 Mdot
.18792 .43429 Mdot
.40076 .65561 Mdot
.3282 .37434 Mdot
.30876 .5899 Mdot
.45927 .65175 Mdot
.15658 .6401 Mdot
.72885 .52759 Mdot
.59701 .61393 Mdot
.22751 .74656 Mdot
.4611 .46565 Mdot
.48302 .65191 Mdot
.19866 .73544 Mdot
.53358 .52628 Mdot
.42154 .44446 Mdot
.34669 .50648 Mdot
.3636 .52956 Mdot
.43182 .58313 Mdot
.67814 .62039 Mdot
.19126 .68548 Mdot
.71455 .56334 Mdot
.33669 .39867 Mdot
.3002 .57075 Mdot
.43925 .60689 Mdot
.46077 .47368 Mdot
.47803 .67207 Mdot
.24563 .77701 Mdot
.17479 .40154 Mdot
.36636 .68597 Mdot
.32097 .36946 Mdot
.31433 .59489 Mdot
.45629 .66724 Mdot
.1846 .7178 Mdot
.60726 .5779 Mdot
.16583 .6356 Mdot
.76476 .46939 Mdot
.78796 .65148 Mdot
.1684 .5331 Mdot
.35532 .7017 Mdot
.2572 .35307 Mdot
.35909 .62457 Mdot
.743 .53258 Mdot
.66263 .66052 Mdot
.29748 .76457 Mdot
.14409 .51361 Mdot
.34747 .41592 Mdot
.29406 .55357 Mdot
.41181 .57706 Mdot
.7442 .53789 Mdot
.6537 .6556 Mdot
.29415 .76548 Mdot
.14534 .50216 Mdot
.19671 .44902 Mdot
.40513 .63924 Mdot
.45413 .46655 Mdot
.47715 .63333 Mdot
.15224 .60922 Mdot
.77125 .46045 Mdot
.79514 .63797 Mdot
.21055 .4093 Mdot
.39163 .63199 Mdot
.61889 .59763 Mdot
.19284 .70175 Mdot
.68204 .59421 Mdot
.16214 .55538 Mdot
.23651 .69186 Mdot
.725 .55333 Mdot
.461 .49316 Mdot
.33306 .71992 Mdot
.2464 .35289 Mdot
.36551 .63051 Mdot
.71837 .58886 Mdot
.23385 .38606 Mdot
.37496 .62012 Mdot
.72389 .58106 Mdot
.29916 .38383 Mdot
.32699 .59127 Mdot
.45386 .67383 Mdot
.1973 .73777 Mdot
.51381 .5097 Mdot
.64903 .62076 Mdot
.22018 .73042 Mdot
.58823 .5687 Mdot
.15639 .5852 Mdot
.81421 .66885 Mdot
.21351 .69896 Mdot
.70603 .57998 Mdot
.22046 .39279 Mdot
.38399 .62856 Mdot
.67408 .61591 Mdot
.18759 .6791 Mdot
.7214 .55019 Mdot
.4514 .48435 Mdot
.475 .67409 Mdot
.24523 .77719 Mdot
.17448 .40205 Mdot
.36586 .68633 Mdot
.32143 .36966 Mdot
.31399 .59465 Mdot
.45668 .66641 Mdot
.18324 .71531 Mdot
.61571 .58227 Mdot
.17048 .65012 Mdot
.74478 .49997 Mdot
.72944 .68098 Mdot
.2739 .74915 Mdot
.30549 .35924 Mdot
.32634 .60491 Mdot
.3984 .70183 Mdot
.15286 .63678 Mdot
.72478 .53462 Mdot
.54556 .56989 Mdot
.15754 .49112 Mdot
.31198 .70841 Mdot
.50686 .5089 Mdot
.68063 .62787 Mdot
.20267 .70381 Mdot
.68739 .59336 Mdot
.16323 .52838 Mdot
.32307 .70868 Mdot
.42993 .44284 Mdot
.36049 .51213 Mdot
.38969 .5437 Mdot
.46608 .67254 Mdot
.22118 .76185 Mdot
.32012 .36337 Mdot
.31589 .59899 Mdot
.44844 .67707 Mdot
.19414 .73412 Mdot
.53364 .52608 Mdot
.4227 .44542 Mdot
.35108 .50832 Mdot
.37092 .53268 Mdot
.44949 .60421 Mdot
.39435 .41912 Mdot
.28561 .5187 Mdot
.36845 .54971 Mdot
.46852 .64391 Mdot
.15643 .63697 Mdot
.73303 .51921 Mdot
.64513 .64884 Mdot
.28564 .76519 Mdot
.15659 .44812 Mdot
.30526 .7071 Mdot
.55559 .54928 Mdot
.19155 .40275 Mdot
.3915 .65938 Mdot
.37296 .40123 Mdot
.28196 .55048 Mdot
.4062 .57532 Mdot
.76786 .48703 Mdot
.79038 .65354 Mdot
.1681 .5519 Mdot
.31838 .71029 Mdot
.44655 .45672 Mdot
.4404 .57927 Mdot
.65798 .61798 Mdot
.20673 .7138 Mdot
.66029 .59865 Mdot
.17358 .64602 Mdot
.76377 .47164 Mdot
.78646 .65388 Mdot
.16802 .55725 Mdot
.30239 .71147 Mdot
.53296 .53073 Mdot
.3908 .42017 Mdot
.28566 .5208 Mdot
.37051 .55052 Mdot
.46969 .65006 Mdot
.16931 .68231 Mdot
.68792 .58755 Mdot
.16722 .49468 Mdot
.37428 .69185 Mdot
.21391 .36698 Mdot
.38138 .64833 Mdot
.56587 .56092 Mdot
.15751 .49885 Mdot
.30606 .70914 Mdot
.53397 .53173 Mdot
.3769 .41008 Mdot
.28233 .54013 Mdot
.39303 .56469 Mdot
.23782 .69946 Mdot
.7093 .58029 Mdot
.23144 .38636 Mdot
.3766 .62189 Mdot
.71671 .59314 Mdot
.21136 .40174 Mdot
.38998 .63418 Mdot
.61423 .59486 Mdot
.1891 .69624 Mdot
.69075 .58932 Mdot
.16798 .49162 Mdot
.37801 .6898 Mdot
.20694 .37216 Mdot
.38348 .65312 Mdot
.50743 .51233 Mdot
.66464 .62541 Mdot
.21517 .7224 Mdot
.63053 .59169 Mdot
.17961 .67202 Mdot
.72277 .54565 Mdot
.4833 .51315 Mdot
.73051 .58887 Mdot
.29406 .38294 Mdot
.33075 .59319 Mdot
.44424 .68244 Mdot
.19987 .74243 Mdot
.48209 .48257 Mdot
.56405 .59591 Mdot
.17893 .687 Mdot
.69578 .5838 Mdot
.18297 .44198 Mdot
.40005 .66225 Mdot
.27235 .35585 Mdot
.34916 .61641 Mdot
.83956 .49224 Mdot
.82584 .54367 Mdot
.82488 .61305 Mdot
.39928 .44531 Mdot
.31573 .5037 Mdot
.34774 .53222 Mdot
.41437 .5676 Mdot
.76696 .4891 Mdot
.78866 .65606 Mdot
.16912 .57625 Mdot
.23505 .69135 Mdot
.72603 .5509 Mdot
.48078 .51111 Mdot
.73834 .56822 Mdot
.47657 .50815 Mdot
.75292 .52485 Mdot
.72489 .68322 Mdot
.28564 .7529 Mdot
.22233 .35758 Mdot
.37695 .64551 Mdot
.61516 .59463 Mdot
.18856 .69502 Mdot
.6928 .58786 Mdot
.17178 .47478 Mdot
.39038 .6805 Mdot
.19961 .37937 Mdot
.38506 .65835 Mdot
.44211 .45544 Mdot
.42492 .56284 Mdot
.74779 .53043 Mdot
.69195 .6747 Mdot
.30102 .76047 Mdot
.14715 .49154 Mdot
.18361 .59432 Mdot
.30133 .71294 Mdot
.5254 .52433 Mdot
.48935 .50276 Mdot
.73775 .57189 Mdot
.44977 .48406 Mdot
.47801 .66927 Mdot
.23739 .7722 Mdot
.21517 .35865 Mdot
.3785 .65164 Mdot
.55916 .55552 Mdot
.16982 .44621 Mdot
.37765 .68504 Mdot
.24354 .35547 Mdot
.36732 .6307 Mdot
.71435 .59479 Mdot
.1989 .41613 Mdot
.39691 .64435 Mdot
.4771 .48628 Mdot
.32271 .4019 Mdot
.30858 .57332 Mdot
.44735 .61678 Mdot
.29645 .36321 Mdot
.33193 .60461 Mdot
.37163 .70954 Mdot
.14914 .49497 Mdot
.203 .65051 Mdot
.84375 .59931 Mdot
.37019 .42461 Mdot
.2882 .53304 Mdot
.38354 .55647 Mdot
.44194 .68907 Mdot
.21425 .75868 Mdot
.35101 .38004 Mdot
.29358 .57873 Mdot
.44596 .61944 Mdot
.28457 .36002 Mdot
.34049 .60981 Mdot
.191 .63217 Mdot
.4572 .49911 Mdot
.29359 .72037 Mdot
.49738 .49992 Mdot
.72892 .59527 Mdot
.25132 .38117 Mdot
.36246 .61105 Mdot
.79043 .46137 Mdot
.80773 .60515 Mdot
.55934 .58697 Mdot
.16269 .63893 Mdot
.74635 .49569 Mdot
.73876 .6806 Mdot
.2623 .74379 Mdot
.4086 .42317 Mdot
.29543 .50509 Mdot
.35258 .54122 Mdot
.43887 .59377 Mdot
.5771 .57236 Mdot
.1562 .59175 Mdot
.85012 .54636 Mdot
.79438 .67459 Mdot
.21423 .70202 Mdot
.69961 .5868 Mdot
.18417 .43998 Mdot
.40038 .66058 Mdot
.28456 .35797 Mdot
.34071 .61108 Mdot
.17649 .54833 Mdot
.38003 .69397 Mdot
.17516 .41202 Mdot
.37466 .68217 Mdot
.29058 .35838 Mdot
.33657 .60913 Mdot
.26019 .71055 Mdot
.66307 .60418 Mdot
.17892 .66128 Mdot
.74052 .50956 Mdot
.70047 .67598 Mdot
.29442 .75812 Mdot
.16473 .42633 Mdot
.34688 .69735 Mdot
.36463 .39388 Mdot
.28516 .56169 Mdot
.42147 .58929 Mdot
.69255 .61747 Mdot
.17319 .63428 Mdot
.80696 .44736 Mdot
.80826 .57732 Mdot
.75896 .68909 Mdot
.2712 .74461 Mdot
.3634 .39025 Mdot
.02 w
.6575 .5 Mdot
1 0 .545 r
.008 w
.53976 .54011 Mdot
.28599 .36524 Mdot
.33889 .60619 Mdot
.28608 .71722 Mdot
.55972 .5516 Mdot
.17836 .42567 Mdot
.38838 .67321 Mdot
.26578 .35473 Mdot
.35357 .61967 Mdot
.78068 .46804 Mdot
.80362 .62358 Mdot
.33905 .40441 Mdot
.29843 .56578 Mdot
.43142 .59711 Mdot
.6043 .5911 Mdot
.18372 .68804 Mdot
.70082 .58006 Mdot
.20377 .408 Mdot
.39399 .64083 Mdot
.53461 .53612 Mdot
.34011 .38668 Mdot
.29937 .57795 Mdot
.44773 .62051 Mdot
.26297 .35742 Mdot
.35532 .61921 Mdot
.77483 .47412 Mdot
.79934 .6359 Mdot
.22399 .39767 Mdot
.38229 .62282 Mdot
.70076 .60925 Mdot
.16351 .55827 Mdot
.24377 .69678 Mdot
.71408 .5746 Mdot
.27776 .37886 Mdot
.34309 .60061 Mdot
.32967 .71747 Mdot
.29052 .35652 Mdot
.33683 .6103 Mdot
.23234 .6943 Mdot
.72016 .56205 Mdot
.38014 .42638 Mdot
.28834 .5244 Mdot
.37354 .5509 Mdot
.47 .65702 Mdot
.18627 .71865 Mdot
.60726 .57803 Mdot
.16597 .63616 Mdot
.76374 .47062 Mdot
.7865 .65354 Mdot
.16797 .55407 Mdot
.31128 .711 Mdot
.48626 .49093 Mdot
.78041 .47647 Mdot
.80428 .62645 Mdot
.30651 .39016 Mdot
.32092 .58544 Mdot
.46139 .65444 Mdot
.16448 .66974 Mdot
.70167 .575 Mdot
.22235 .39095 Mdot
.38269 .62761 Mdot
.68272 .61542 Mdot
.17878 .65549 Mdot
.75321 .48717 Mdot
.76301 .67413 Mdot
.21932 .71143 Mdot
.67607 .59936 Mdot
.16561 .60384 Mdot
.78577 .69311 Mdot
.27835 .74376 Mdot
.33871 .37529 Mdot
.30182 .5863 Mdot
.45607 .63888 Mdot
.15048 .50973 Mdot
.20022 .64557 Mdot
.785 .69301 Mdot
.27784 .7437 Mdot
.3418 .37704 Mdot
.29961 .58413 Mdot
.4537 .63302 Mdot
.16611 .44029 Mdot
.36151 .69275 Mdot
.29342 .35864 Mdot
.33461 .60821 Mdot
.30144 .71844 Mdot
.47258 .4786 Mdot
.37133 .71412 Mdot
.14476 .54079 Mdot
.74744 .70275 Mdot
.32273 .7549 Mdot
.14336 .58438 Mdot
.77745 .45367 Mdot
.79944 .62595 Mdot
.31299 .39228 Mdot
.31617 .58237 Mdot
.45966 .64271 Mdot
.14825 .57083 Mdot
.84998 .53202 Mdot
.82358 .62912 Mdot
.22565 .39779 Mdot
.38119 .62121 Mdot
.70827 .60347 Mdot
.16984 .4883 Mdot
.38519 .68559 Mdot
.19566 .38305 Mdot
.38508 .66175 Mdot
.4068 .42629 Mdot
.29763 .5048 Mdot
.35163 .5401 Mdot
.43542 .58971 Mdot
.62717 .60486 Mdot
.20298 .71521 Mdot
.65117 .597 Mdot
.177 .65932 Mdot
.74068 .50888 Mdot
.70224 .67649 Mdot
.29367 .75773 Mdot
.16808 .4186 Mdot
.35651 .69293 Mdot
.3317 .37443 Mdot
.30646 .5889 Mdot
.45865 .64772 Mdot
.15086 .6056 Mdot
.77277 .45882 Mdot
.79639 .635 Mdot
.23028 .39346 Mdot
.37775 .61924 Mdot
.72057 .58745 Mdot
.24958 .38086 Mdot
.36374 .61223 Mdot
.7753 .47416 Mdot
.79978 .63507 Mdot
.22983 .3939 Mdot
.37808 .6194 Mdot
.71955 .58916 Mdot
.2375 .38457 Mdot
.37239 .61814 Mdot
.7326 .5614 Mdot
.47319 .50469 Mdot
.78111 .47489 Mdot
.80466 .62468 Mdot
.32585 .39787 Mdot
.30699 .57499 Mdot
.44841 .61911 Mdot
.26912 .35778 Mdot
.35121 .61644 Mdot
.82404 .46521 Mdot
.8143 .55252 Mdot
.81496 .63781 Mdot
.195 .43232 Mdot
.40138 .64521 Mdot
.4281 .44424 Mdot
.35975 .512 Mdot
.38841 .54286 Mdot
.46891 .66796 Mdot
.21405 .75497 Mdot
.38593 .40386 Mdot
.27875 .53862 Mdot
.39191 .56507 Mdot
.25281 .70834 Mdot
.67892 .6027 Mdot
.16688 .61027 Mdot
.84044 .6145 Mdot
.23689 .39213 Mdot
.37295 .61462 Mdot
.73915 .54471 Mdot
.59961 .61711 Mdot
.23443 .75122 Mdot
.40898 .42238 Mdot
.29483 .50523 Mdot
.35291 .54154 Mdot
.43991 .59503 Mdot
.55968 .55888 Mdot
.16324 .46817 Mdot
.35667 .69697 Mdot
.29039 .35759 Mdot
.33679 .60967 Mdot
.24604 .70378 Mdot
.69677 .59404 Mdot
.16876 .48979 Mdot
.38124 .68796 Mdot
.20147 .37702 Mdot
.38459 .65717 Mdot
.45836 .46942 Mdot
.48276 .65439 Mdot
.20484 .74319 Mdot
.48369 .48419 Mdot
.83699 .61751 Mdot
.24063 .39035 Mdot
.37017 .61281 Mdot
.74993 .51748 Mdot
.72522 .6825 Mdot
.2832 .75228 Mdot
.23696 .35234 Mdot
.37034 .63697 Mdot
.6876 .61328 Mdot
.17198 .63116 Mdot
.81421 .44942 Mdot
.80938 .56629 Mdot
.79165 .67123 Mdot
.20217 .68568 Mdot
.72417 .54798 Mdot
.48198 .51205 Mdot
.73471 .57849 Mdot
.38544 .43119 Mdot
.29214 .51701 Mdot
.36479 .54578 Mdot
.4619 .62659 Mdot
.16455 .44582 Mdot
.35704 .69511 Mdot
.30557 .36256 Mdot
.3258 .60282 Mdot
.41431 .69636 Mdot
.16975 .69283 Mdot
.66307 .59431 Mdot
.16743 .62027 Mdot
.83375 .4688 Mdot
.81697 .54017 Mdot
.82346 .61134 Mdot
.43274 .4727 Mdot
.4446 .58648 Mdot
.5902 .58225 Mdot
.16897 .65303 Mdot
.73593 .51649 Mdot
.6664 .6614 Mdot
.29587 .76368 Mdot
.1467 .49322 Mdot
.17987 .5685 Mdot
.36403 .70131 Mdot
.20699 .37128 Mdot
.38316 .65351 Mdot
.5064 .51142 Mdot
.67256 .62697 Mdot
.20992 .71491 Mdot
.65884 .59886 Mdot
.17474 .65025 Mdot
.75575 .48267 Mdot
.77047 .6696 Mdot
.20093 .68641 Mdot
.72188 .55227 Mdot
.44414 .47802 Mdot
.47724 .63694 Mdot
.1567 .63591 Mdot
.73531 .5148 Mdot
.66709 .66164 Mdot
.29575 .76354 Mdot
.14705 .49099 Mdot
.18318 .59205 Mdot
.30901 .71271 Mdot
.48358 .4885 Mdot
.8241 .47027 Mdot
.81568 .55295 Mdot
.81528 .63766 Mdot
.19521 .43197 Mdot
.40128 .64499 Mdot
.43132 .44693 Mdot
.3738 .52029 Mdot
.42896 .57805 Mdot
.70546 .61229 Mdot
.16376 .55467 Mdot
.26142 .70503 Mdot
.68263 .6028 Mdot
.16525 .59771 Mdot
.60689 .63344 Mdot
.26991 .76744 Mdot
.17852 .39733 Mdot
.37251 .68124 Mdot
.31699 .36788 Mdot
.31725 .59683 Mdot
.45169 .67417 Mdot
.19335 .73252 Mdot
.5429 .53353 Mdot
.31499 .37478 Mdot
.31748 .59293 Mdot
.45731 .66647 Mdot
.18473 .71788 Mdot
.6072 .57788 Mdot
.1658 .63551 Mdot
.7649 .46922 Mdot
.78815 .6512 Mdot
.16856 .53024 Mdot
.35973 .70014 Mdot
.24086 .35513 Mdot
.36875 .63264 Mdot
.70605 .60368 Mdot
.16755 .5004 Mdot
.37425 .69237 Mdot
.21063 .36918 Mdot
.38241 .65059 Mdot
.53904 .53932 Mdot
.29453 .36732 Mdot
.33268 .60257 Mdot
.38636 .70572 Mdot
.14561 .58098 Mdot
.80329 .4442 Mdot
.80702 .58293 Mdot
.73358 .69095 Mdot
.29904 .75428 Mdot
.16962 .41583 Mdot
.36045 .69085 Mdot
.3206 .36906 Mdot
.31464 .59523 Mdot
.45575 .66825 Mdot
.18611 .72052 Mdot
.59735 .57222 Mdot
.15985 .60896 Mdot
.82504 .4562 Mdot
.81198 .55051 Mdot
.81532 .63588 Mdot
.20484 .41739 Mdot
.39563 .63603 Mdot
.56285 .55925 Mdot
.16072 .47988 Mdot
.34141 .70255 Mdot
.3541 .38684 Mdot
.29107 .57241 Mdot
.43742 .60705 Mdot
.47558 .48659 Mdot
.20683 .42611 Mdot
.39636 .63057 Mdot
.59945 .58596 Mdot
.17556 .67009 Mdot
.71994 .5501 Mdot
.44151 .47558 Mdot
.4699 .62162 Mdot
.16022 .46134 Mdot
.33756 .70249 Mdot
.3853 .40808 Mdot
.28011 .5354 Mdot
.38786 .56188 Mdot
.37085 .71169 Mdot
.14699 .51096 Mdot
.18505 .48359 Mdot
.41177 .65702 Mdot
.23135 .36046 Mdot
.37419 .63629 Mdot
.67738 .61501 Mdot
.18303 .66803 Mdot
.73457 .52231 Mdot
.64529 .64917 Mdot
.28628 .7653 Mdot
.15521 .45282 Mdot
.29425 .70754 Mdot
.60013 .58079 Mdot
.16871 .64904 Mdot
.74261 .50358 Mdot
.71748 .67984 Mdot
.28462 .75367 Mdot
.22051 .35839 Mdot
.37761 .64669 Mdot
.60311 .58731 Mdot
.17779 .67485 Mdot
.71565 .55837 Mdot
.36951 .41864 Mdot
.28638 .53828 Mdot
.39022 .56143 Mdot
.34942 .71598 Mdot
.18815 .38943 Mdot
.3826 .66946 Mdot
.34921 .38537 Mdot
.29404 .57553 Mdot
.44248 .61356 Mdot
.3671 .3992 Mdot
.28415 .55591 Mdot
.41349 .5814 Mdot
.73187 .57109 Mdot
.41106 .45082 Mdot
.3411 .50615 Mdot
.35888 .52859 Mdot
.42246 .57372 Mdot
.73013 .577 Mdot
.36262 .41508 Mdot
.28764 .54569 Mdot
.39982 .56827 Mdot
.77474 .69606 Mdot
.28831 .74736 Mdot
.25572 .35011 Mdot
.35993 .62713 Mdot
.73546 .55193 Mdot
.54319 .56873 Mdot
.16085 .47394 Mdot
.34279 .70182 Mdot
.35065 .38474 Mdot
.29326 .57541 Mdot
.44202 .61309 Mdot
.3757 .40512 Mdot
.2816 .54526 Mdot
.39951 .56983 Mdot
.83144 .63458 Mdot
.17426 .49521 Mdot
.39765 .67818 Mdot
.17906 .40659 Mdot
.37967 .67728 Mdot
.29672 .36039 Mdot
.33213 .60629 Mdot
.35179 .71384 Mdot
.18987 .38742 Mdot
.38319 .6678 Mdot
.36095 .3928 Mdot
.28701 .56454 Mdot
.42571 .59349 Mdot
.65778 .61677 Mdot
.20458 .71101 Mdot
.66795 .59854 Mdot
.16894 .62539 Mdot
.82108 .45341 Mdot
.81089 .55614 Mdot
.80911 .64862 Mdot
.16981 .52374 Mdot
.37258 .69501 Mdot
.20255 .3755 Mdot
.38421 .65659 Mdot
.46747 .47734 Mdot
.43712 .69669 Mdot
.22605 .76949 Mdot
.24963 .34755 Mdot
.36329 .63195 Mdot
.71927 .58709 Mdot
.24528 .38184 Mdot
.36684 .6143 Mdot
.75421 .50774 Mdot
.75119 .68074 Mdot
.25018 .73653 Mdot
.51485 .51312 Mdot
.62678 .61003 Mdot
.21309 .72751 Mdot
.60238 .57718 Mdot
.16483 .63314 Mdot
.76756 .46607 Mdot
.79149 .64581 Mdot
.17715 .47537 Mdot
.40176 .67051 Mdot
.20057 .3792 Mdot
.38526 .65723 Mdot
.4517 .46368 Mdot
.46847 .61683 Mdot
.17825 .41465 Mdot
.38275 .67622 Mdot
.28207 .35668 Mdot
.34254 .61263 Mdot
.29226 .39276 Mdot
.33066 .58785 Mdot
.4567 .67126 Mdot
.19642 .73618 Mdot
.52382 .51807 Mdot
.54531 .55143 Mdot
.20587 .38535 Mdot
.38782 .6479 Mdot
.52039 .52373 Mdot
.5265 .53518 Mdot
.39653 .42419 Mdot
.29 .51331 Mdot
.3618 .54564 Mdot
.45837 .62054 Mdot
.20076 .38297 Mdot
.38681 .65522 Mdot
.45835 .46949 Mdot
.48276 .65458 Mdot
.20534 .74377 Mdot
.47948 .48057 Mdot
.17872 .58571 Mdot
.29846 .71254 Mdot
.54351 .53927 Mdot
.27475 .36359 Mdot
.3469 .6108 Mdot
.46324 .50394 Mdot
.73313 .69961 Mdot
.3249 .75691 Mdot
.14687 .61963 Mdot
.732 .51858 Mdot
.64132 .64629 Mdot
.2827 .76514 Mdot
.16196 .4321 Mdot
.33557 .70123 Mdot
.41434 .43049 Mdot
.31015 .49991 Mdot
.34433 .53387 Mdot
.41343 .56733 Mdot
.77293 .48044 Mdot
.79744 .64166 Mdot
.19178 .43686 Mdot
.4025 .64905 Mdot
.3786 .40563 Mdot
.28087 .54271 Mdot
.39642 .56766 Mdot
.30214 .39489 Mdot
.32332 .58375 Mdot
.46188 .65349 Mdot
.16341 .66618 Mdot
.70536 .57029 Mdot
.25477 .37852 Mdot
.36004 .61066 Mdot
.81108 .45785 Mdot
.81129 .57128 Mdot
.78111 .67987 Mdot
.23045 .71973 Mdot
.6455 .59818 Mdot
.18199 .67378 Mdot
.7232 .54537 Mdot
.48766 .51715 Mdot
.71322 .61481 Mdot
.16467 .53319 Mdot
.32766 .70819 Mdot
.40117 .41975 Mdot
.2881 .51268 Mdot
.36188 .54646 Mdot
.45959 .62282 Mdot
.18481 .40276 Mdot
.3861 .66942 Mdot
.31926 .36944 Mdot
.31548 .59531 Mdot
.45527 .66925 Mdot
.18775 .72333 Mdot
.58624 .56525 Mdot
.15506 .56396 Mdot
.32829 .4059 Mdot
.30473 .56879 Mdot
.43902 .60529 Mdot
.47791 .48871 Mdot
.76244 .69903 Mdot
.30212 .75113 Mdot
.17569 .40455 Mdot
.37098 .68351 Mdot
.30737 .3638 Mdot
.32439 .60163 Mdot
.42494 .69198 Mdot
.18173 .71715 Mdot
.60283 .57516 Mdot
.16288 .62382 Mdot
.78772 .44987 Mdot
.80434 .60823 Mdot
.52389 .55474 Mdot
.2673 .36174 Mdot
.35219 .61475 Mdot
.83314 .47757 Mdot
.81934 .54277 Mdot
.82343 .61398 Mdot
.39682 .44336 Mdot
.31069 .5047 Mdot
.34899 .53432 Mdot
.42031 .57333 Mdot
.73492 .56473 Mdot
.47158 .5034 Mdot
.80349 .46192 Mdot
.81134 .58344 Mdot
.73449 .69135 Mdot
.29932 .75421 Mdot
.16922 .41668 Mdot
.35959 .69134 Mdot
.3226 .36997 Mdot
.31316 .59416 Mdot
.4574 .66461 Mdot
.18013 .70927 Mdot
.63381 .58986 Mdot
.17587 .66122 Mdot
.73499 .51991 Mdot
.65366 .65427 Mdot
.29109 .7649 Mdot
.14953 .4767 Mdot
.22391 .6788 Mdot
.75409 .49185 Mdot
.76261 .67507 Mdot
.22256 .71477 Mdot
.66549 .60058 Mdot
.17262 .64098 Mdot
.77622 .45861 Mdot
.79921 .62912 Mdot
.28071 .38407 Mdot
.34028 .59656 Mdot
.39546 .70344 Mdot
.15142 .62966 Mdot
.73083 .5222 Mdot
.62514 .63527 Mdot
.26784 .76356 Mdot
.2067 .36591 Mdot
.38099 .65663 Mdot
.49464 .50105 Mdot
.73171 .58873 Mdot
.30197 .3852 Mdot
.32481 .58969 Mdot
.45785 .66796 Mdot
.18984 .72634 Mdot
.57409 .55702 Mdot
.15868 .4947 Mdot
.32004 .70763 Mdot
.4623 .47037 Mdot
.48067 .66789 Mdot
.23883 .77274 Mdot
.2093 .36238 Mdot
.37986 .65566 Mdot
.51327 .51726 Mdot
.61192 .60103 Mdot
.20051 .71501 Mdot
.64902 .59631 Mdot
.17731 .66082 Mdot
.73836 .51346 Mdot
.68415 .66998 Mdot
.29789 .76119 Mdot
.14933 .47886 Mdot
.21996 .67462 Mdot
.76637 .47362 Mdot
.78983 .65043 Mdot
.16926 .52155 Mdot
.37151 .69527 Mdot
.20652 .3721 Mdot
.38343 .65363 Mdot
.50301 .50848 Mdot
.69499 .62628 Mdot
.18373 .66548 Mdot
.74068 .51018 Mdot
.7001 .67591 Mdot
.29469 .75822 Mdot
.16374 .42878 Mdot
.34345 .69868 Mdot
.37844 .40332 Mdot
.28045 .54484 Mdot
.39911 .56987 Mdot
.82168 .65428 Mdot
.18011 .63044 Mdot
.84488 .59526 Mdot
.40785 .45262 Mdot
.33939 .50616 Mdot
.35781 .52854 Mdot
.42076 .57214 Mdot
.73641 .56088 Mdot
.50428 .53339 Mdot
.56199 .56407 Mdot
.15603 .50806 Mdot
.27941 .70817 Mdot
.6406 .60049 Mdot
.18842 .68873 Mdot
.70551 .57573 Mdot
.23392 .38476 Mdot
.37486 .62075 Mdot
.7227 .58325 Mdot
.28077 .37989 Mdot
.34076 .599 Mdot
.36981 .7103 Mdot
.15033 .48743 Mdot
.2276 .68267 Mdot
.74434 .51027 Mdot
.71469 .67996 Mdot
.2883 .75488 Mdot
.19884 .37369 Mdot
.38214 .66204 Mdot
.43035 .44539 Mdot
.36766 .5164 Mdot
.40983 .55961 Mdot
.82005 .65684 Mdot
.18421 .64378 Mdot
.82234 .45562 Mdot
.81157 .55438 Mdot
.81152 .64424 Mdot
.17572 .48443 Mdot
.40045 .67386 Mdot
.18837 .39285 Mdot
.38468 .66776 Mdot
.3481 .38477 Mdot
.29476 .5764 Mdot
.44383 .61545 Mdot
.33741 .38096 Mdot
.30181 .58281 Mdot
.45361 .63172 Mdot
.17048 .42921 Mdot
.37184 .68637 Mdot
.27376 .35479 Mdot
.34829 .61656 Mdot
.84358 .50686 Mdot
.8313 .55759 Mdot
.81016 .6523 Mdot
.16927 .5655 Mdot
.28697 .71106 Mdot
.60194 .58151 Mdot
.16975 .65204 Mdot
.73937 .50992 Mdot
.69503 .6741 Mdot
.29591 .75919 Mdot
.15782 .44545 Mdot
.31441 .70612 Mdot
.51364 .51485 Mdot
.6235 .60808 Mdot
.21068 .72548 Mdot
.61175 .58234 Mdot
.17087 .6527 Mdot
.74064 .50772 Mdot
.70391 .67689 Mdot
.29278 .75732 Mdot
.1721 .41033 Mdot
.36494 .68792 Mdot
.31315 .36591 Mdot
.32015 .59897 Mdot
.44348 .68159 Mdot
.19559 .73683 Mdot
.51719 .51247 Mdot
.61848 .60537 Mdot
.20718 .72237 Mdot
.62443 .58841 Mdot
.17688 .66669 Mdot
.72737 .53576 Mdot
.55803 .58115 Mdot
.1563 .60405 Mdot
.81584 .44881 Mdot
.80933 .56383 Mdot
.79646 .66625 Mdot
.18883 .65922 Mdot
.76852 .46791 Mdot
.79261 .64482 Mdot
.18003 .4655 Mdot
.40367 .66519 Mdot
.22407 .36302 Mdot
.37769 .64086 Mdot
.63997 .60711 Mdot
.20026 .70871 Mdot
.67092 .59779 Mdot
.16672 .61307 Mdot
.84987 .54821 Mdot
.78959 .67856 Mdot
.22647 .71533 Mdot
.66397 .60095 Mdot
.17404 .6464 Mdot
.76425 .47112 Mdot
.78716 .65293 Mdot
.16796 .54767 Mdot
.32732 .70891 Mdot
.39612 .41584 Mdot
.28382 .51979 Mdot
.37014 .5511 Mdot
.46968 .65077 Mdot
.1708 .68624 Mdot
.68242 .59058 Mdot
.16253 .53442 Mdot
.30521 .71054 Mdot
.52614 .52512 Mdot
.47844 .49313 Mdot
.83283 .482 Mdot
.82055 .54434 Mdot
.82316 .61625 Mdot
.36813 .42263 Mdot
.2879 .53603 Mdot
.38725 .55894 Mdot
.40598 .7025 Mdot
.16753 .68838 Mdot
.6696 .59353 Mdot
.16413 .59705 Mdot
.67299 .67916 Mdot
.33191 .76623 Mdot
.18142 .72871 Mdot
.53462 .52615 Mdot
.41604 .44002 Mdot
.32828 .50124 Mdot
.34634 .52769 Mdot
.40341 .55769 Mdot
.18208 .60225 Mdot
.23443 .69168 Mdot
.72539 .55211 Mdot
.47003 .50131 Mdot
.8399 .49885 Mdot
.82783 .54833 Mdot
.82223 .62417 Mdot
.27787 .38466 Mdot
.3423 .59718 Mdot
.37766 .70844 Mdot
.14523 .53554 Mdot
.61376 .63914 Mdot
.28103 .76949 Mdot
.15107 .46801 Mdot
.24813 .69672 Mdot
.71303 .57698 Mdot
.26148 .37847 Mdot
.35512 .60736 Mdot
.78363 .69245 Mdot
.27555 .74319 Mdot
.35797 .38685 Mdot
.28891 .57065 Mdot
.43441 .60361 Mdot
.53218 .53587 Mdot
.356 .396 Mdot
.28947 .56452 Mdot
.42633 .59349 Mdot
.65476 .61594 Mdot
.20567 .71307 Mdot
.66192 .59864 Mdot
.17257 .642 Mdot
.77255 .46192 Mdot
.79647 .6362 Mdot
.22197 .39899 Mdot
.38373 .62414 Mdot
.69224 .61338 Mdot
.16891 .61556 Mdot
.84841 .57291 Mdot
.6401 .65315 Mdot
.2992 .76863 Mdot
.14192 .56985 Mdot
.80161 .44366 Mdot
.80664 .58552 Mdot
.71975 .68902 Mdot
.30793 .75733 Mdot
.14555 .5042 Mdot
.19692 .44854 Mdot
.40496 .63901 Mdot
.45792 .46983 Mdot
.4827 .65426 Mdot
.20434 .74261 Mdot
.48778 .48771 Mdot
.79092 .4675 Mdot
.80908 .60526 Mdot
.55771 .58557 Mdot
.16023 .62814 Mdot
.76162 .47239 Mdot
.78325 .65747 Mdot
.17062 .59245 Mdot
.17788 .54255 Mdot
.39147 .68813 Mdot
.16119 .44662 Mdot
.33902 .70121 Mdot
.38727 .40959 Mdot
.2804 .53248 Mdot
.3845 .55967 Mdot
.41864 .69833 Mdot
.18482 .72354 Mdot
.57727 .55893 Mdot
.15644 .5129 Mdot
.27697 .7079 Mdot
.6474 .60252 Mdot
.18753 .68534 Mdot
.71065 .5686 Mdot
.28813 .38014 Mdot
.33539 .59656 Mdot
.41737 .69584 Mdot
.17503 .70475 Mdot
.63792 .59074 Mdot
.1754 .65866 Mdot
.73881 .51218 Mdot
.68859 .67177 Mdot
.29739 .76042 Mdot
.15182 .46736 Mdot
.25795 .70117 Mdot
.69737 .59531 Mdot
.16803 .49396 Mdot
.37784 .6901 Mdot
.20586 .37301 Mdot
.38372 .65392 Mdot
.49784 .50396 Mdot
.72022 .60918 Mdot
.17686 .46357 Mdot
.39889 .6709 Mdot
.2137 .36854 Mdot
.38188 .64769 Mdot
.56745 .56217 Mdot
.15605 .51081 Mdot
.27546 .70755 Mdot
.65219 .60368 Mdot
.18611 .68123 Mdot
.71605 .55964 Mdot
.36551 .41599 Mdot
.28685 .54311 Mdot
.3964 .56581 Mdot
.18389 .47941 Mdot
.41018 .6587 Mdot
.22938 .36111 Mdot
.37519 .63748 Mdot
.66843 .61474 Mdot
.19097 .6871 Mdot
.71138 .56828 Mdot
.29355 .38139 Mdot
.33133 .59427 Mdot
.43952 .68541 Mdot
.19734 .73976 Mdot
.49859 .4967 Mdot
.73237 .58812 Mdot
.30953 .38777 Mdot
.31918 .58613 Mdot
.46111 .654 Mdot
.16315 .66547 Mdot
.70597 .56944 Mdot
.26112 .37787 Mdot
.35542 .60788 Mdot
.81906 .65899 Mdot
.18868 .65577 Mdot
.78163 .45603 Mdot
.80248 .61936 Mdot
.38932 .43703 Mdot
.29848 .51089 Mdot
.35711 .54089 Mdot
.44447 .60014 Mdot
.47795 .48896 Mdot
.78354 .69174 Mdot
.27299 .74242 Mdot
.37794 .40036 Mdot
.28011 .54778 Mdot
.40284 .573 Mdot
.80631 .4589 Mdot
.81103 .57874 Mdot
.75573 .69007 Mdot
.27669 .74669 Mdot
.31702 .36418 Mdot
.31783 .59919 Mdot
.44589 .6795 Mdot
.19518 .73595 Mdot
.52285 .5172 Mdot
.55723 .56126 Mdot
.16133 .4755 Mdot
.34584 .70104 Mdot
.3345 .37552 Mdot
.30448 .58739 Mdot
.45757 .64302 Mdot
.14792 .55838 Mdot
.80376 .68057 Mdot
.24318 .72659 Mdot
.60088 .57823 Mdot
.16582 .63789 Mdot
.75871 .47709 Mdot
.77769 .66352 Mdot
.18214 .64444 Mdot
.80762 .44817 Mdot
.80853 .57632 Mdot
.76288 .68804 Mdot
.26525 .74203 Mdot
.41514 .42853 Mdot
.30817 .49984 Mdot
.34461 .53472 Mdot
.41549 .5693 Mdot
.75585 .50985 Mdot
.75396 .68044 Mdot
.24674 .73427 Mdot
.54081 .53464 Mdot
.31767 .37581 Mdot
.31551 .59162 Mdot
.45896 .66172 Mdot
.17614 .70074 Mdot
.65484 .59466 Mdot
.172 .64237 Mdot
.76911 .46532 Mdot
.79322 .64299 Mdot
.18617 .44858 Mdot
.40411 .65596 Mdot
.29653 .36135 Mdot
.33213 .60574 Mdot
.35821 .71257 Mdot
.17133 .41762 Mdot
.36755 .68738 Mdot
.2975 .36015 Mdot
.33163 .60625 Mdot
.35603 .713 Mdot
.17711 .40646 Mdot
.37562 .68054 Mdot
.29834 .36075 Mdot
.33098 .60567 Mdot
.36697 .71061 Mdot
.15459 .46653 Mdot
.29032 .70791 Mdot
.61147 .5874 Mdot
.17772 .67244 Mdot
.7194 .55165 Mdot
.42989 .46556 Mdot
.41906 .55864 Mdot
.79408 .46229 Mdot
.80921 .59905 Mdot
.62178 .63856 Mdot
.27676 .76695 Mdot
.16635 .42085 Mdot
.35068 .69552 Mdot
.35277 .38635 Mdot
.29187 .57335 Mdot
.43891 .60891 Mdot
.44446 .45955 Mdot
.44204 .58153 Mdot
.63764 .61047 Mdot
.20803 .71952 Mdot
.63848 .59406 Mdot
.17969 .67007 Mdot
.72607 .53906 Mdot
.53588 .56136 Mdot
.19087 .40146 Mdot
.39062 .66083 Mdot
.36607 .39648 Mdot
.28451 .55875 Mdot
.41738 .58518 Mdot
.71595 .60073 Mdot
.1869 .43695 Mdot
.4011 .6567 Mdot
.31471 .36802 Mdot
.31876 .59728 Mdot
.44944 .67667 Mdot
.1953 .73562 Mdot
.52546 .51939 Mdot
.52572 .53477 Mdot
.40491 .43067 Mdot
.30131 .50415 Mdot
.35004 .53827 Mdot
.42965 .58326 Mdot
.68593 .61973 Mdot
.1823 .66409 Mdot
.74102 .50923 Mdot
.70309 .67679 Mdot
.29346 .75756 Mdot
.16928 .41602 Mdot
.35934 .69139 Mdot
.32413 .3707 Mdot
.31203 .59332 Mdot
.45828 .66178 Mdot
.17497 .69825 Mdot
.65992 .59494 Mdot
.16962 .63141 Mdot
.79817 .44712 Mdot
.80686 .59107 Mdot
.68563 .67763 Mdot
.31542 .76313 Mdot
.14627 .61806 Mdot
.73237 .51768 Mdot
.64553 .64899 Mdot
.28567 .76513 Mdot
.15675 .44759 Mdot
.30645 .707 Mdot
.5504 .5452 Mdot
.2192 .37559 Mdot
.38202 .63846 Mdot
.63181 .60376 Mdot
.19879 .70831 Mdot
.6705 .59765 Mdot
.16681 .61373 Mdot
.84977 .5386 Mdot
.81448 .64889 Mdot
.16903 .54564 Mdot
.34009 .70638 Mdot
.3247 .37024 Mdot
.31173 .59348 Mdot
.45821 .66183 Mdot
.17494 .6982 Mdot
.66 .59494 Mdot
.16957 .63119 Mdot
.79883 .44702 Mdot
.80697 .59002 Mdot
.69287 .68074 Mdot
.31545 .76201 Mdot
.14496 .60727 Mdot
.74317 .49719 Mdot
.72705 .68047 Mdot
.27515 .74985 Mdot
.29321 .35509 Mdot
.33518 .61048 Mdot
.25193 .7069 Mdot
.6844 .60116 Mdot
.1637 .58264 Mdot
.21325 .42111 Mdot
.39187 .62436 Mdot
.66106 .6149 Mdot
.1981 .70096 Mdot
.69015 .59116 Mdot
.1659 .50417 Mdot
.36467 .69661 Mdot
.23708 .35626 Mdot
.37083 .63453 Mdot
.69478 .61095 Mdot
.16559 .59324 Mdot
.37866 .4354 Mdot
.29384 .51912 Mdot
.36661 .54585 Mdot
.46386 .63032 Mdot
.15327 .49227 Mdot
.26353 .7039 Mdot
.68429 .60256 Mdot
.16446 .59029 Mdot
.3597 .42285 Mdot
.29019 .54139 Mdot
.39408 .56307 Mdot
.25365 .70877 Mdot
.67669 .60318 Mdot
.16852 .61992 Mdot
.84206 .48863 Mdot
.82595 .54055 Mdot
.82621 .60651 Mdot
.47967 .51463 Mdot
.73428 .57907 Mdot
.37869 .42628 Mdot
.28826 .52556 Mdot
.37483 .55157 Mdot
.4694 .66119 Mdot
.19606 .73389 Mdot
.53944 .5309 Mdot
.35172 .39372 Mdot
.29189 .56826 Mdot
.43224 .59994 Mdot
.57837 .57297 Mdot
.15685 .59699 Mdot
.84485 .49732 Mdot
.8298 .54776 Mdot
.82266 .62379 Mdot
.27966 .38485 Mdot
.34095 .59645 Mdot
.39257 .70432 Mdot
.14923 .61638 Mdot
.74394 .49693 Mdot
.72988 .68066 Mdot
.27242 .74862 Mdot
.31724 .36411 Mdot
.31769 .59918 Mdot
.44606 .67934 Mdot
.19514 .73586 Mdot
.52336 .51763 Mdot
.55116 .55629 Mdot
.17779 .42559 Mdot
.38739 .67419 Mdot
.26461 .35462 Mdot
.35434 .62023 Mdot
.77355 .47555 Mdot
.79811 .63871 Mdot
.20648 .41417 Mdot
.39434 .63508 Mdot
.57953 .57189 Mdot
.15646 .59266 Mdot
.85008 .54199 Mdot
.80643 .66133 Mdot
.18142 .63737 Mdot
.84046 .48504 Mdot
.82413 .53917 Mdot
.8262 .60437 Mdot
.50878 .54147 Mdot
.46851 .48351 Mdot
.36229 .71577 Mdot
.15125 .48099 Mdot
.24546 .69563 Mdot
.71612 .57167 Mdot
.30334 .38452 Mdot
.32395 .58975 Mdot
.4582 .66708 Mdot
.18821 .72367 Mdot
.58553 .56481 Mdot
.15493 .56064 Mdot
.26581 .39259 Mdot
.3506 .59741 Mdot
.29319 .71829 Mdot
.5188 .51837 Mdot
.57368 .57415 Mdot
.15644 .5963 Mdot
.84423 .49479 Mdot
.82882 .54516 Mdot
.82448 .61687 Mdot
.35118 .41193 Mdot
.29205 .55468 Mdot
.41295 .57869 Mdot
.73828 .55428 Mdot
.5518 .57664 Mdot
.15274 .55869 Mdot
.39852 .45016 Mdot
.32231 .50422 Mdot
.34882 .53022 Mdot
.41168 .56479 Mdot
.80351 .45934 Mdot
.81074 .58322 Mdot
.73528 .69135 Mdot
.29854 .75398 Mdot
.17225 .41053 Mdot
.36556 .68761 Mdot
.31123 .36513 Mdot
.32157 .5999 Mdot
.43826 .68507 Mdot
.19335 .73437 Mdot
.53003 .52306 Mdot
.46907 .48505 Mdot
.32669 .72066 Mdot
.28031 .35398 Mdot
.34397 .61486 Mdot
.6994 .69084 Mdot
.33438 .76217 Mdot
.17436 .71477 Mdot
.59172 .56783 Mdot
.15649 .58337 Mdot
.78308 .69466 Mdot
.28338 .74534 Mdot
.29817 .357 Mdot
.3316 .60805 Mdot
.33376 .71667 Mdot
.2703 .35273 Mdot
.35069 .61911 Mdot
.80241 .45681 Mdot
.80996 .58483 Mdot
.7264 .6904 Mdot
.3048 .75605 Mdot
.1518 .46858 Mdot
.25755 .70105 Mdot
.69797 .59482 Mdot
.1691 .48845 Mdot
.38261 .68707 Mdot
.19981 .37867 Mdot
.38482 .65843 Mdot
.44344 .45656 Mdot
.43154 .56971 Mdot
.7203 .59722 Mdot
.20892 .40461 Mdot
.39154 .63581 Mdot
.59305 .58138 Mdot
.16845 .65038 Mdot
.7395 .50939 Mdot
.69649 .67459 Mdot
.29546 .7589 Mdot
.15968 .43979 Mdot
.32544 .70404 Mdot
.461 .46945 Mdot
.48245 .66196 Mdot
.22536 .76309 Mdot
.30574 .35735 Mdot
.32645 .60604 Mdot
.38912 .70465 Mdot
.14651 .59279 Mdot
.7783 .45356 Mdot
.8 .62452 Mdot
.32873 .39906 Mdot
.30504 .57326 Mdot
.44517 .61432 Mdot
.33635 .38044 Mdot
.30256 .5835 Mdot
.45449 .63363 Mdot
.16248 .45115 Mdot
.34845 .69863 Mdot
.33847 .3778 Mdot
.3016 .58465 Mdot
.45492 .63535 Mdot
.15753 .4692 Mdot
.31807 .70675 Mdot
.48435 .48954 Mdot
.80595 .46231 Mdot
.81181 .57952 Mdot
.75294 .69063 Mdot
.28059 .74809 Mdot
.2852 .35314 Mdot
.34076 .61389 Mdot
.29006 .39237 Mdot
.33232 .58874 Mdot
.45352 .67524 Mdot
.20054 .74203 Mdot
.48654 .48646 Mdot
.8128 .46336 Mdot
.81283 .56892 Mdot
.78826 .67483 Mdot
.21331 .7016 Mdot
.70011 .58619 Mdot
.18649 .43511 Mdot
.40032 .65773 Mdot
.31148 .36663 Mdot
.32117 .59891 Mdot
.44219 .68259 Mdot
.19545 .73683 Mdot
.51695 .51226 Mdot
.62081 .60675 Mdot
.20908 .72418 Mdot
.61721 .58509 Mdot
.17384 .66027 Mdot
.73299 .52353 Mdot
.63339 .64124 Mdot
.27663 .7649 Mdot
.17584 .40224 Mdot
.36971 .68399 Mdot
.31304 .36605 Mdot
.3202 .59891 Mdot
.44359 .68152 Mdot
.19564 .7369 Mdot
.51683 .51217 Mdot
.62198 .60742 Mdot
.20998 .72499 Mdot
.61378 .58338 Mdot
.17203 .65578 Mdot
.73739 .51427 Mdot
.67808 .66723 Mdot
.29779 .76212 Mdot
.14755 .48849 Mdot
.18951 .61775 Mdot
.19409 .63538 Mdot
.47826 .51817 Mdot
.73058 .58759 Mdot
.30188 .3851 Mdot
.32489 .58978 Mdot
.45771 .66822 Mdot
.19024 .72699 Mdot
.57116 .55495 Mdot
.16223 .47542 Mdot
.35132 .69933 Mdot
.30866 .36353 Mdot
.32355 .6015 Mdot
.42768 .69069 Mdot
.18449 .72172 Mdot
.58657 .56524 Mdot
.15509 .56431 Mdot
.33429 .40874 Mdot
.30099 .56462 Mdot
.43095 .59585 Mdot
.61561 .5981 Mdot
.19445 .70512 Mdot
.67473 .59647 Mdot
.16419 .59425 Mdot
.55305 .58721 Mdot
.15955 .62638 Mdot
.76317 .47037 Mdot
.78572 .65435 Mdot
.16815 .56224 Mdot
.28668 .71091 Mdot
.60384 .58266 Mdot
.17133 .6566 Mdot
.73455 .51979 Mdot
.65165 .65303 Mdot
.28994 .76501 Mdot
.15073 .47093 Mdot
.24288 .69381 Mdot
.72039 .56367 Mdot
.37286 .42127 Mdot
.28654 .53379 Mdot
.38468 .55771 Mdot
.43035 .69411 Mdot
.20097 .74562 Mdot
.45728 .46119 Mdot
.47467 .62697 Mdot
.14893 .5415 Mdot
.35272 .41883 Mdot
.29202 .54859 Mdot
.40419 .5707 Mdot
.81637 .46161 Mdot
.81268 .56342 Mdot
.79973 .66312 Mdot
.18204 .64042 Mdot
.82859 .46216 Mdot
.81406 .54594 Mdot
.81959 .62477 Mdot
.28446 .38534 Mdot
.33735 .5946 Mdot
.42155 .69436 Mdot
.18048 .71527 Mdot
.60846 .57823 Mdot
.1662 .63669 Mdot
.76322 .4713 Mdot
.78571 .65461 Mdot
.16825 .56468 Mdot
.27845 .70982 Mdot
.63395 .59784 Mdot
.18759 .68871 Mdot
.70455 .57671 Mdot
.22666 .38851 Mdot
.37984 .62487 Mdot
.70106 .60876 Mdot
.16346 .55407 Mdot
.25976 .70441 Mdot
.68625 .60146 Mdot
.16337 .57694 Mdot
.17926 .51639 Mdot
.40673 .67427 Mdot
.16396 .44036 Mdot
.35158 .69676 Mdot
.33262 .37473 Mdot
.30581 .58845 Mdot
.45836 .64625 Mdot
.14943 .59168 Mdot
.80283 .44468 Mdot
.80708 .58365 Mdot
.73004 .69064 Mdot
.30172 .75515 Mdot
.16001 .43953 Mdot
.32762 .70358 Mdot
.44998 .46001 Mdot
.45713 .59993 Mdot
.36769 .4002 Mdot
.28396 .55471 Mdot
.41186 .5799 Mdot
.73793 .55501 Mdot
.54579 .57126 Mdot
.15597 .5013 Mdot
.28712 .7089 Mdot
.61547 .58944 Mdot
.18026 .67758 Mdot
.71465 .56066 Mdot
.35115 .40683 Mdot
.29187 .55858 Mdot
.41856 .58434 Mdot
.71527 .60174 Mdot
.18314 .44523 Mdot
.40119 .66147 Mdot
.27035 .35568 Mdot
.3505 .61726 Mdot
.82133 .46278 Mdot
.81339 .5562 Mdot
.81066 .64657 Mdot
.17173 .5065 Mdot
.38885 .68557 Mdot
.17965 .40486 Mdot
.37972 .67687 Mdot
.30022 .36155 Mdot
.32959 .60472 Mdot
.38435 .70614 Mdot
.14505 .56864 Mdot
.83383 .46642 Mdot
.81631 .53967 Mdot
.82334 .61115 Mdot
.43608 .47557 Mdot
.45893 .60499 Mdot
.30708 .3674 Mdot
.32403 .59944 Mdot
.43525 .68701 Mdot
.19182 .73252 Mdot
.53927 .53052 Mdot
.35542 .39601 Mdot
.28978 .5648 Mdot
.42679 .59395 Mdot
.6501 .61445 Mdot
.20671 .71536 Mdot
.65444 .59796 Mdot
.1763 .65636 Mdot
.74532 .50008 Mdot
.73113 .6811 Mdot
.2723 .74842 Mdot
.31974 .36526 Mdot
.31583 .59787 Mdot
.45083 .67478 Mdot
.19312 .73231 Mdot
.54382 .53425 Mdot
.30567 .37119 Mdot
.3244 .59741 Mdot
.44172 .6833 Mdot
.19639 .73818 Mdot
.50879 .50538 Mdot
.68655 .62809 Mdot
.19631 .69274 Mdot
.70626 .5764 Mdot
.2343 .38466 Mdot
.3746 .62051 Mdot
.72371 .58133 Mdot
.29667 .38313 Mdot
.32886 .59236 Mdot
.44941 .67837 Mdot
.20012 .74206 Mdot
.48556 .48559 Mdot
.83213 .48102 Mdot
.82009 .54482 Mdot
.82276 .61749 Mdot
.35435 .41379 Mdot
.02 w
.5025 .51 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{400, 400},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00_`3oool400000<d0oooo002o0?ooo`030000003o
ool0oooo0<h0oooo00300?ooo`030000003oool0oooo00H0oooo0`0000340?ooo`00^@3oool40000
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`340?ooo`00_`3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo0<@0oooo00300?ooo`8000001`3oool00`000000
oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?oo
o`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?oo
o`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3o
ool200000<D0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo
0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo
00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?oo
o`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`800000
a@3oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool0
0<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo
00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3o
ool0a03oool00<T0oooo0P0000350?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool0
0`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000
oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?oo
o`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?oo
o`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool200000<D0oooo00390?ooo`030000003o
ool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo
0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo
00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo002c0?oo
o`D000000P3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0<@0oooo002e0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`340?oo
o`00]@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo0`0000340?ooo`00
[@3oool4000000@0oooo00<000000?ooo`3oool0203oool2000000L0oooo00<000000?ooo`3oool0
a03oool00;D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0<@0oooo002d0?ooo`8000002P3oool3000000H0oooo00<000000?ooo`3oool0a03oool0
0<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo
00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo0P0000350?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00
b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool0
0`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000
oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?oo
o`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool200000<D0oooo00390?ooo`03
0000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003o
ool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo
0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo
00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?oo
o`800000a@3oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0
a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool0
0<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo
00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo0P0000350?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00
b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool0
0`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000
oooo0?ooo`340?ooo`00_`3oool5000000D0oooo00<000000?ooo`3oool0a03oool00<40oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`340?ooo`00`@3oool00`000000oooo0?ooo`05
0?ooo`<00000a03oool00;T0oooo100000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0a03oool00<40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`340?ooo`00
`03oool2000000L0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03o
ool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0
oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<0
00000?ooo`3oool0a03oool00<T0oooo0P0000350?ooo`00b@3oool00`000000oooo0?ooo`340?oo
o`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3o
ool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`00
0000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo
0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool200000<D0oooo00390?oo
o`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000
003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0
oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0
oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo0039
0?ooo`800000a@3oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3o
ool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03o
ool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0
oooo00<000000?ooo`3oool0a03oool006L0oooo00<0o`2;0>H0o`3oool00P3oool00`3V0?l0oooo
0?ooo`1J0?ooo`030000003oool0oooo0<@0oooo001R0?ooo`040?l0R`3V0?l0oooo0?ooo`@0o`2;
00@0oooo0>H0o`3V0?l0iP3o0`3oool00`3V0?l0oooo0?ooo`1E0?ooo`800000a@3oool005l0oooo
0P3V0?l30?l0R`030>H0o`3oool0iP3o00@0o`2;0P3V0?l0103o08/0oooo0?l0R`3o08/20>H0o`03
0?l0R`3oool0o`2;0080oooo00<0o`2;0?ooo`3oool0CP3oool00`000000oooo0?ooo`340?ooo`00
G03oool60>H0o`<0o`2;103V0?l00`3o08/0iP3o0>H0o`0?0?l0R`80oooo00<0o`2;0?ooo`3oool0
B@3oool00`000000oooo0?ooo`340?ooo`00F@3oool0103V0?l0oooo0>H0o`3o08/40>H0o`<0o`2;
1`3V0?l60?l0R`80iP3o303o08]:0?ooo`030000003oool0oooo0<@0oooo001G0?ooo`040?l0R`3V
0?l0iP3o0>H0o`<0o`2;00L0oooo0?l0R`3o08/0oooo0?l0R`3oool0iP3o00@0oooo00<0iP3o0?oo
o`3oool0103o08/40>H0o`030?l0R`3V0?l0iP3o00D0o`2;00<0iP3o0?l0R`3V0?l0BP3oool00`00
0000oooo0?ooo`340?ooo`00EP3oool30?l0R`030>H0o`3oool0oooo00H0o`2;1@3oool0103V0?l0
oooo0?ooo`3V0?l20?ooo`<0o`2;00P0iP3o0?l0R`3V0?l0oooo0>H0o`3o08/0oooo0>H0o`P0o`2;
00<0oooo0?l0R`3o08/0AP3oool00`000000oooo0?ooo`340?ooo`00EP3oool20?l0R`040?ooo`3V
0?l0oooo0?ooo`D0o`2;00<0iP3o0?ooo`3oool00P3oool80>H0o`030?l0R`3oool0o`2;0080o`2;
00D0oooo0?l0R`3o08/0o`2;0?ooo`0<0?l0RdD0oooo00<000000?ooo`3oool0a03oool005D0oooo
1@3o08/0103V0?l0oooo0>H0o`3o08/30>H0o`H0oooo00@0iP3o0?ooo`3oool0iP3o0P3oool01@3V
0?l0oooo0?ooo`3oool0o`2;00<0oooo00<0o`2;0?ooo`3o08/00P3o08/00`3oool0iP3o0?l0R`08
0?l0Rd@0oooo00<000000?ooo`3oool0a03oool005H0oooo1@3o08/20?ooo`030>H0o`3oool0oooo
01P0oooo00<0o`2;0?ooo`3oool00P3oool00`3o08/0oooo0?l0R`060?l0R`<0oooo00<0iP3o0?oo
o`3oool0:03oool2000000@0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`340?oo
o`00D`3oool70?l0R`030?ooo`3o08/0oooo01l0oooo0`3o08/00`3oool0o`2;0?ooo`040?l0R`05
0>H0o`3o08/0o`2;0>H0o`3o08/0:03oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0a03oool00580oooo1@3o08/30?ooo`<0o`2;3P3oool0
0`3o08/0oooo0?ooo`0?0?ooo`030?l0R`3oool0o`2;0080o`2;0P3oool00`3o08/0iP3o0?l0R`05
0?l0RbL0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`040?ooo`<00000a03o
ool00540oooo0P3V0?l30?l0R`80oooo00@0iP3o0?ooo`3oool0o`2;3@3oool40?l0R`D0oooo0P3o
08/20?ooo`030?l0R`3oool0oooo00L0oooo0`3o08/30?ooo`030>H0o`3o08/0o`2;00@0o`2;00<0
oooo0>H0o`3V0?l07@3oool400000080oooo00@000000?ooo`3oool000002@3oool2000000L0oooo
00<000000?ooo`3oool0a03oool00580oooo103o08/0103oool0iP3o0>H0o`3V0?l90?ooo`040>H0
o`3oool0o`2;0?ooo`H0o`2;00@0iP3o0?ooo`3oool0oooo2@3o08/70?ooo`030?l0R`3oool0oooo
00<0oooo00<0iP3o0?l0R`3o08/00P3o08/50>H0ob80oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0<@0oooo001A0?ooo`H0o`2;00<0oooo0>H0
o`3oool01`3oool20?l0R`030>H0o`3o08/0o`2;00@0o`2;00<0oooo0?l0R`3V0?l0103oool01@3V
0?l0o`2;0?l0R`3o08/0oooo00L0o`2;2@3oool20>H0o`<0o`2;0P3V0?l20?l0R`030>H0o`3oool0
oooo0280oooo0P00000:0?ooo`<000001P3oool00`000000oooo0?ooo`340?ooo`00D03oool0103o
08/0oooo0?l0R`3oool40?l0R`H0oooo00<0iP3o0?ooo`3o08/00`3o08/01@3oool0o`2;0?ooo`3o
08/0iP3o00L0oooo00<0iP3o0?l0R`3o08/00`3o08/20?ooo`L0o`2;203oool01@3V0?l0oooo0?l0
R`3o08/0iP3o00H0o`2;=`3oool00`000000oooo0?ooo`340?ooo`00C@3oool00`3V0?l0oooo0?l0
R`020?l0R`@0oooo00<0o`2;0?ooo`3oool00`3oool00`3o08/0iP3o0?l0R`020>H0o`<0o`2;3@3o
ool0103V0?l0o`2;0?l0R`3o08/50?ooo`030>H0o`3o08/0o`2;00<0o`2;2@3oool30?l0R`030>H0
o`3o08/0o`2;00@0o`2;00<0iP3o0?ooo`3oool0<`3oool00`000000oooo0?ooo`340?ooo`00C03o
ool20>H0o`<0o`2;0P3V0?l80?ooo`D0o`2;0P3V0?l30?l0R`P0oooo00@0o`2;0?ooo`3oool0oooo
0P3V0?l01@3oool0iP3o0?ooo`3oool0o`2;00@0oooo0`3o08/00`3oool0o`2;0?ooo`080?ooo`05
0?l0R`3V0?l0iP3o0>H0o`3oool0103o08/20>H0oc@0oooo00<000000?ooo`3oool0a03oool004d0
oooo00D0iP3o0?l0R`3o08/0o`2;0>H0o`080?ooo`80iP3o00<0o`2;0?ooo`3o08/01@3o08/80?oo
o`<0o`2;00<0oooo0>H0o`3V0?l0103V0?l30?l0R`80iP3o00@0o`2;0?ooo`3o08/0oooo0`3o08/2
0?ooo`030>H0o`3oool0oooo00D0oooo00<0iP3o0?ooo`3oool01@3o08/00`3V0?l0oooo0?ooo`0b
0?ooo`030000003oool0oooo0<@0oooo001;0?ooo`070?l0R`3oool0iP3o0>H0o`3o08/0oooo0>H0
o`090?ooo`030>H0o`3oool0o`2;00<0o`2;00D0iP3o0?l0R`3V0?l0oooo0>H0o`070?ooo`040?l0
R`3oool0oooo0?ooo`80iP3o00D0oooo0>H0o`3oool0oooo0?l0R`020>H0o`<0o`2;0`3oool00`3o
08/0oooo0?ooo`020>H0o`050?l0R`3oool0oooo0?ooo`3V0?l0103oool50?l0R`040>H0o`3o08/0
iP3o0?ooo`80iP3o<03oool00`000000oooo0?ooo`340?ooo`00BP3oool30?l0R`80iP3o00@0oooo
0>H0o`3V0?l0iP3o2@3oool40?l0R`80oooo1@3V0?lB0?ooo`80iP3o00<0o`2;0?ooo`3oool01P3o
ool30?l0R`040?ooo`3V0?l0iP3o0>H0o`@0oooo0P3o08/20?ooo`<0o`2;0`3V0?l00`3o08/0oooo
0?ooo`0]0?ooo`030000003oool0oooo0<@0oooo001:0?ooo`80o`2;00H0oooo0>H0o`3o08/0iP3o
0?l0R`3V0?l60?ooo`030>H0o`3oool0oooo00@0o`2;103oool00`3V0?l0oooo0>H0o`0M0?ooo`03
0>H0o`3oool0o`2;0080o`2;00<0oooo0>H0o`3oool02@3oool30?l0R`040>H0o`3o08/0o`2;0?l0
Rbh0oooo0P0000350?ooo`00B@3oool90?l0R`D0oooo00<0o`2;0>H0o`3V0?l00P3oool00`3o08/0
oooo0?ooo`0S0?ooo`<0iP3o00<0oooo0?l0R`3oool00P3oool00`3o08/0iP3o0?ooo`080?ooo`03
0?l0R`3V0?l0iP3o00<0o`2;00<0oooo0?l0R`3oool0:`3oool00`000000oooo0?ooo`340?ooo`00
B@3oool60?l0R`030>H0o`3o08/0oooo00<0oooo103o08/Z0?ooo`030>H0o`3oool0o`2;00H0o`2;
00<0iP3o0?ooo`3o08/01P3oool20>H0o`L0o`2;00<0iP3o0?ooo`3oool0:03oool00`000000oooo
0?ooo`340?ooo`00B@3oool40?l0R`040?ooo`3V0?l0iP3o0>H0o`<0oooo103o08/00`3V0?l0oooo
0?ooo`020?ooo`030>H0o`3oool0oooo02H0oooo1@3o08/00`3V0?l0oooo0?l0R`020?l0R`030>H0
o`3oool0oooo00<0oooo00D0iP3o0?ooo`3o08/0o`2;0>H0o`030?l0R`80iP3o:@3oool00`000000
oooo0?ooo`340?ooo`00B03oool40?l0R`<0oooo00<0iP3o0?ooo`3oool00`3oool00`3o08/0iP3o
0>H0o`020>H0o`80oooo0`3V0?lY0?ooo`030?l0R`3oool0oooo00<0oooo00@0o`2;0>H0o`3o08/0
iP3o1@3oool30>H0o`80oooo0`3o08/Z0?ooo`030000003oool0oooo0<@0oooo00170?ooo`050>H0
o`3o08/0o`2;0>H0o`3o08/01`3oool01P3V0?l0oooo0?ooo`3o08/0oooo0>H0o`@0oooo00<0iP3o
0?ooo`3oool0;@3oool50?l0R`030?ooo`3o08/0o`2;00<0oooo00<0iP3o0?ooo`3oool00P3oool0
103o08/0iP3o0?ooo`3o08/X0?ooo`030000003oool0oooo0<@0oooo00170?ooo`H0o`2;1@3oool3
0>H0o`<0o`2;=03oool20>H0o`<0o`2;00<0oooo0?l0R`3o08/00`3o08/60?ooo`80iP3o0`3o08/W
0?ooo`030000003oool0oooo0<@0oooo00160?ooo`@0o`2;00<0iP3o0?l0R`3oool0103oool30>H0
o`<0o`2;0P3oool00`3o08/0oooo0?ooo`0a0?ooo`040>H0o`3o08/0o`2;0?l0R`80oooo1@3o08/6
0?ooo`80iP3o00D0o`2;0>H0o`3o08/0oooo0>H0o`0T0?ooo`030000003oool0oooo0<@0oooo0015
0?ooo`@0o`2;00<0iP3o0?ooo`3oool0103oool40>H0o`040?ooo`3o08/0oooo0?ooo`<0o`2;=03o
ool0103o08/0oooo0?ooo`3o08/20?ooo`@0o`2;103oool30>H0o`@0o`2;00<0iP3o0?l0R`3oool0
8P3oool00`000000oooo0?ooo`340?ooo`00AP3oool00`3o08/0oooo0>H0o`020>H0o`030?l0R`3o
ool0oooo00<0oooo0P3V0?l30?ooo`040?l0R`3oool0oooo0?l0RcL0oooo1`3o08/00`3V0?l0o`2;
0?l0R`030?ooo`030>H0o`3o08/0o`2;0080o`2;00@0iP3o0?l0R`3o08/0o`2;8P3oool00`000000
oooo0?ooo`340?ooo`00A@3oool01@3o08/0iP3o0>H0o`3o08/0iP3o00<0o`2;1@3oool00`3V0?l0
oooo0?ooo`030?l0RcX0oooo00@0o`2;0?ooo`3oool0o`2;0P3V0?l40?l0R`@0oooo00<0o`2;0?oo
o`3oool00`3o08/00`3V0?l0o`2;0>H0o`0P0?ooo`800000a@3oool004@0oooo1P3o08/00`3oool0
o`2;0?ooo`040?ooo`070>H0o`3o08/0iP3o0?ooo`3V0?l0o`2;0>H0o`0l0?ooo`<0iP3o00H0oooo
0>H0o`3o08/0o`2;0>H0o`3o08/60?ooo`80o`2;00D0iP3o0?l0R`3o08/0o`2;0>H0o`0O0?ooo`03
0000003oool0oooo0<@0oooo00150?ooo`040?l0R`3V0?l0iP3o0?l0R`H0oooo00<0iP3o0?ooo`3o
08/00P3o08/20?ooo`030>H0o`3oool0oooo03`0oooo00<0iP3o0?ooo`3oool00`3oool30?l0R`@0
oooo0`3o08/0103oool0o`2;0?l0R`3o08/P0?ooo`030000003oool0oooo0<@0oooo00140?ooo`<0
o`2;0P3V0?l50?ooo`030?l0R`3V0?l0o`2;00<0o`2;A@3oool00`3o08/0oooo0?ooo`020?l0R`80
iP3o0`3oool01@3o08/0oooo0?ooo`3oool0o`2;00@0oooo00<0iP3o0?ooo`3oool06P3oool00`00
0000oooo0?ooo`340?ooo`00A03oool20?l0R`80iP3o1@3oool60?l0RdD0oooo0`3o08/0103oool0
o`2;0?l0R`3o08/20>H0o`T0oooo103V0?lK0?ooo`030000003oool0oooo0<@0oooo00130?ooo`@0
o`2;1P3oool0103V0?l0o`2;0>H0o`3o08]80?ooo`050?l0R`3oool0oooo0?ooo`3o08/00P3V0?l8
0?ooo`030?l0R`3V0?l0iP3o0080iP3o703oool00`000000oooo0?ooo`340?ooo`00@P3oool00`3V
0?l0o`2;0?l0R`030?l0R`@0oooo1P3V0?l00`3oool0iP3o0?ooo`190?ooo`80iP3o00@0o`2;0?oo
o`3oool0iP3o0`3oool30?l0R`040>H0o`3oool0o`2;0>H0oa/0oooo00<000000?ooo`3oool0LP3o
ool20?l0Re00oooo00130?ooo`@0o`2;00<0oooo0>H0o`3oool00`3oool01@3o08/0iP3o0>H0o`3V
0?l0oooo00<0iP3oBP3oool30?l0R`<0iP3o0`3oool00`3o08/0iP3o0>H0o`040?l0RaX0oooo00<0
00000?ooo`3oool0L@3oool40?l0R`030?ooo`3V0?l0iP3o04`0oooo00120?ooo`H0o`2;0P3V0?l2
0?ooo`<0o`2;00@0iP3o0?ooo`3oool0o`2;0P3V0?m;0?ooo`040?l0R`3V0?l0iP3o0>H0o`D0oooo
0`3V0?l40?l0RaT0oooo00<000000?ooo`3oool0K@3oool00`3o08/0oooo0>H0o`050?l0R`80iP3o
0P3o08];0?ooo`00@P3oool50?l0R`030?ooo`3V0?l0oooo00<0oooo0`3o08/0103oool0o`2;0?l0
R`3o08]=0?ooo`030?l0R`3oool0oooo0080oooo00D0o`2;0?ooo`3oool0oooo0>H0o`020?ooo`80
o`2;0P3V0?l20?ooo`030>H0o`3oool0oooo01<0oooo0P00001[0?ooo`030>H0o`3oool0o`2;0080
o`2;0P3V0?l00`3o08/0iP3o0?l0R`060?l0RdX0oooo00110?ooo`030>H0o`3o08/0o`2;00<0o`2;
1`3oool01@3o08/0oooo0?ooo`3oool0o`2;04d0oooo0`3o08/20?ooo`<0o`2;1P3oool70>H0oa@0
oooo00<000000?ooo`3oool0J@3oool01P3o08/0iP3o0>H0o`3oool0o`2;0?ooo`D0iP3o00<0o`2;
0?ooo`3oool00P3o08/00`3oool0o`2;0?ooo`180?ooo`00@@3oool30?l0R`040>H0o`3o08/0oooo
0>H0o`D0oooo00<0iP3o0?ooo`3oool0D@3oool00`3o08/0oooo0?ooo`030?l0R`P0oooo0`3V0?l0
103o08/0iP3o0>H0o`3V0?lC0?ooo`030000003oool0oooo06P0oooo0`3o08/00`3V0?l0oooo0?oo
o`030?ooo`030>H0o`3o08/0iP3o00D0oooo0`3o08]80?ooo`00@P3oool0103o08/0oooo0>H0o`3o
ool30>H0o`<0oooo0`3V0?mF0?ooo`030?l0R`3oool0oooo00P0oooo00H0iP3o0?l0R`3o08/0o`2;
0>H0o`3o08/C0?ooo`030000003oool0oooo06L0oooo1@3o08/50?ooo`@0o`2;00@0iP3o0?l0R`3V
0?l0oooo103o08/00`3V0?l0oooo0?ooo`140?ooo`00@`3oool00`3V0?l0o`2;0>H0o`020>H0o`D0
oooo00<0iP3o0?ooo`3oool0F`3oool00`3V0?l0oooo0?ooo`040?ooo`D0o`2;00<0oooo0?l0R`3o
ool03`3oool00`000000oooo0?ooo`1V0?ooo`D0o`2;0`3oool0103V0?l0o`2;0?ooo`3oool70?l0
R`060?ooo`3o08/0o`2;0>H0o`3o08/0iP3oA@3oool004<0oooo0`3o08/01@3V0?l0oooo0?ooo`3o
ool0o`2;05l0oooo0`3V0?l60?ooo`030?l0R`3oool0o`2;00@0o`2;3`3oool00`000000oooo0?oo
o`1U0?ooo`@0o`2;103oool01@3V0?l0o`2;0?l0R`3o08/0oooo00d0o`2;A@3oool00440oooo0P3o
08/00`3oool0o`2;0?ooo`030?ooo`@0o`2;G@3oool30>H0o`030?l0R`3oool0oooo00@0oooo00<0
iP3o0?l0R`3o08/00P3o08/00`3V0?l0oooo0?ooo`0=0?ooo`030000003oool0oooo06@0oooo103o
08/60?ooo`80o`2;0P3V0?l00`3oool0o`2;0?l0R`040?l0R`030>H0o`3o08/0o`2;0080o`2;00<0
oooo0?l0R`3oool0@`3oool000L0oooo1000000V0?ooo`D000000P3oool2000000@0oooo0P000004
0?l0R`030?ooo`3o08/0oooo00<0oooo103o08/00`3V0?l0oooo0?ooo`0G0?ooo`D000009`3oool2
000000@0oooo0P0000040?ooo`8000002@3oool0103V0?l0o`2;0?l0R`3o08/40?ooo`<0iP3o00<0
o`2;0>H0o`3o08/00P3o08/>0?ooo`030000003oool0oooo02H0oooo0P0000040?ooo`800000103o
ool2000002P0oooo1@0000020?ooo`@0o`2;0`3oool00`3o08/0oooo0?ooo`030?l0R`030>H0o`3o
ool0oooo00<0oooo00H0o`2;0?ooo`3oool0oooo0>H0o`3o08/20?ooo`<0o`2;1P3oool500000080
oooo0P0000040?ooo`800000:03oool400000080oooo00070?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?l0R`070?l0R`D0oooo00@0o`2;0>H0o`3V0?l0
iP3o6P3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000002P3oool20?l0R`D0oooo00<0iP3o0?ooo`3oool01@3o08/=0?ooo`030000003oool0
oooo02D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000Y0?ooo`040000
003oool0oooo0?ooo`@0o`2;0`3oool30?l0R`80oooo00<0o`2;0?ooo`3oool02@3oool30?l0R`04
0?ooo`3o08/0o`2;0?l0R`P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000W
0?ooo`030000003oool0oooo00<0oooo00080?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02@3oool30?l0R`040?ooo`3o08/0o`2;0?l0R`80oooo00@0iP3o0?ooo`3oool0o`2;0P3o
ool00`3V0?l0oooo0?ooo`0I0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`080?ooo`@0o`2;00<0oooo0?l0R`3oool0103oool30?l0R`h0oooo
00<000000?ooo`3oool09@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02L0
oooo00@000000?ooo`3oool0oooo103o08/01@3oool0o`2;0?l0R`3oool0o`2;0100oooo00D0o`2;
0?ooo`3oool0oooo0?l0R`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`020?ooo`0000<0oooo0000000000000P0000040?ooo`030000003oool0
oooo01l0oooo100000040?ooo`030000003oool0oooo00P0oooo00D000000>H0o`3o08/0iP3o0?oo
o`040?l0R`<0iP3o0`3o08/E0?ooo`@00000103oool00`000000oooo0?ooo`0P0?ooo`@000000P3o
ool010000000oooo0?ooo`0000090?ooo`800000303oool60?l0R`@0oooo0`3V0?l00`3oool0o`2;
0?ooo`0;0?ooo`8000009P3oool010000000oooo0?ooo`0000090?ooo`800000:P3oool01@000000
oooo0?ooo`3o08/0oooo00T0o`2;4P3oool00`3o08/0iP3o0>H0o`080?ooo`030000003oool0oooo
00P0oooo0P00000Z0?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool0oooo0000
02P0oooo00<000000?ooo`3oool0203oool010000000o`2;0?l0R`3o08/20?ooo`80o`2;0P3oool0
1P3V0?l0oooo0?ooo`3o08/0oooo0?l0Ra`0oooo00<000000?ooo`3oool09P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00`0oooo00<0iP3o0?l0R`3V0?l00`3o08/40?ooo`03
0>H0o`3oool0o`2;00<0o`2;00<0oooo0?l0R`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?l0R`020?l0
R`040?ooo`3o08/0oooo0>H0o`D0o`2;4@3oool30?l0R`T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0W0?ooo`040000003oool0oooo00000080oooo00080?ooo`800000:03oool2
000000X0oooo00D000000?l0R`3o08/0o`2;0?ooo`030?l0R`80oooo00@0iP3o0?ooo`3oool0oooo
0`3o08/J0?ooo`800000:@3oool2000000X0oooo0`00000=0?ooo`040>H0o`3oool0oooo0?l0R`P0
oooo1P3o08/00`3V0?l0oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo0P00000:0?ooo`<0
0000:03oool2000000030?ooo`3o08/0o`2;00<0oooo00H0iP3o0?l0R`3o08/0o`2;0?ooo`3o08/C
0?ooo`030?l0R`3V0?l0iP3o00L0oooo0P00000:0?ooo`<00000:03oool2000000<0oooo000n0?oo
o`040>H0o`3o08/0o`2;0?l0R`80oooo00<0o`2;0?ooo`3oool00`3V0?l00`3o08/0oooo0?ooo`02
0?l0RfH0oooo0P3V0?l50?ooo`060?l0R`3oool0o`2;0?ooo`3o08/0iP3o0P3o08/50?ooo`030000
003oool0oooo05l0oooo0`3o08/40?ooo`030>H0o`3o08/0oooo01@0oooo0`3o08/00`3V0?l0o`2;
0?ooo`110?ooo`00?P3oool20>H0o`030?l0R`3oool0oooo00@0oooo1@3o08/0103oool0o`2;0?l0
R`3o08]T0?ooo`@0iP3o0`3oool30?l0R`030?ooo`3o08/0iP3o00@0o`2;103oool00`000000oooo
0?ooo`1O0?ooo`80o`2;00D0iP3o0?ooo`3oool0oooo0>H0o`0H0?ooo`030?l0R`3V0?l0o`2;0080
o`2;@@3oool003l0oooo0`3o08/40?ooo`D0o`2;0`3oool00`3o08/0oooo0?ooo`1T0?ooo`80iP3o
1@3oool00`3o08/0oooo0?l0R`020?l0R`030>H0o`3o08/0o`2;0080o`2;0`3oool00`000000oooo
0?ooo`1N0?ooo`<0o`2;0P3oool40>H0oaX0oooo0P3o08]10?ooo`00?P3oool40?l0R`040?ooo`3V
0?l0oooo0?ooo`<0o`2;KP3oool00`3V0?l0oooo0>H0o`050?ooo`H0o`2;0P3V0?l20?ooo`030000
003oool0oooo05d0oooo0P3V0?l20?l0R`030?ooo`3V0?l0iP3o00<0iP3o6P3oool30?l0Rd00oooo
000n0?ooo`H0o`2;00H0iP3o0?ooo`3V0?l0o`2;0>H0o`3o08]/0?ooo`D0iP3o103oool50?l0R`@0
iP3o00<0oooo0000003oool0>P3oool30>H0ob00oooo0`3V0?l30?l0R`80iP3o00<0oooo0>H0o`3o
ool06@3oool20>H0o`80o`2;@03oool003l0oooo00<0o`2;0>H0o`3o08/00`3o08/00`3oool0o`2;
0?l0R`030?l0RfX0oooo0`3V0?l00`3oool0iP3o0?ooo`050?ooo`030?l0R`3V0?l0iP3o00@0iP3o
00<0oooo0?l0R`000000>P3oool50>H0oah0oooo0P3o08/30>H0o`030?l0R`3V0?l0iP3o0080iP3o
703oool0103V0?l0o`2;0?l0R`3o08/o0?ooo`00@03oool0103V0?l0oooo0?ooo`3o08/30?ooo`04
0?l0R`3V0?l0o`2;0>H0oc<0oooo00<0o`2;0>H0o`3oool01@3oool00`3o08/0oooo0?ooo`0]0?oo
o`030>H0o`3oool0iP3o00P0oooo00<0iP3o0?ooo`3V0?l00P3V0?l40?l0RcT0oooo1`3V0?lL0?oo
o`@0o`2;00@0iP3o0?ooo`3oool0oooo103V0?lK0?ooo`@0o`2;?`3oool000H0oooo>00000001@3V
0?l00000000000000000o`2;0080iP3o00D000000?l0R`3o08/0o`2;0>H0o`0c000000<0o`2;0P3V
0?l3000000<0o`2;0P3V0?l]000000<0iP3o0`0000000`3o08/0000000000004000000030>H0o`3o
08/0o`2;0080o`2;00<0iP3o000000000000=`0000070>H0oad000000`3o08/00`3V0?l000000000
00020>H0o`030000003V0?l0000001X00000103o08/20>H0oc/000000`3oool000H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00@0iP3o
0?l0R`3V0?l000000`3o08/20?ooo`80o`2;0P3oool00`000000oooo0>H0o`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00@0o`2;0>H0o`3o08/0o`2;0P3oool20?l0R`<0iP3o00@0o`2;0000003oool0
o`2;0`3V0?l20?l0R`80oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020>H0o`03
0?l0R`3oool0o`2;0080o`2;00@000000?ooo`3oool0oooo0`3V0?l00`3o08/0iP3o0?l0R`020?l0
R`030?ooo`3o08/0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`L0iP3o0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool30?l0R`030>H0o`000000oooo00@0iP3o103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool01@3o08/0oooo0?ooo`3V0?l0
000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0040oooo00060?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0103oool30?l0
R`80oooo00<0o`2;0?ooo`3oool0103o08/20?ooo`<0iP3o6@3oool00`000000oooo0?ooo`0=0?oo
o`H0o`2;00D0oooo0?l0R`3o08/0o`2;0>H0o`030?l0R`<0oooo00<0iP3o0?l0R`3o08/00P3o08/2
0>H0o`T0oooo00<000000?ooo`3oool07P3oool30?l0R`040?ooo`3o08/0o`2;0?l0R`@0oooo00<0
iP3o0?ooo`3oool01`3o08/[0?ooo`030000003oool0oooo00P0oooo1@3V0?lM0?ooo`80o`2;00D0
iP3o0?ooo`000000iP3o0?l0R`020>H0oal0oooo00<0o`2;0?ooo`3oool02P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0040oooo000m0?ooo`030>H0o`3o08/0o`2;00@0o`2;00<0
oooo0>H0o`3o08/00`3o08/20?ooo`030>H0o`3oool0oooo02L0oooo0P3V0?l0103o08/0iP3o0?l0
R`3o08/20>H0o`030?ooo`3o08/0oooo0080oooo00<0o`2;0?ooo`3oool0103oool20?l0R`@0iP3o
:P3oool01@3o08/0oooo0?ooo`3oool0o`2;00<0iP3o103oool70?l0R`80iP3o=P3oool30>H0oa`0
oooo00<0iP3o0?l0R`3o08/00P3o08/00`3oool0iP3o0?l0R`020?l0Ral0oooo0`3o08]00?ooo`00
?P3oool60?l0R`050?ooo`3V0?l0iP3o0>H0o`3o08/00P3oool00`3V0?l0oooo0?ooo`0X0?ooo`80
o`2;00D0iP3o0?l0R`3o08/0o`2;0>H0o`0>0?ooo`040>H0o`3oool0iP3o0>H0o`<0oooo00<0o`2;
0?ooo`3oool0:P3oool20>H0o`030?l0R`3V0?l0oooo0080oooo1`3o08/00`3V0?l0o`2;0?l0R`1C
0?ooo`80iP3o1@3o08/0103V0?l0o`2;0?l0R`3o08/P0?ooo`030?l0R`3oool0iP3o03l0oooo000m
0?ooo`80iP3o0P3o08/01@3V0?l0o`2;0?l0R`3o08/0oooo00D0iP3o00<0o`2;0>H0o`3oool09`3o
ool40?l0R`030>H0o`3o08/0oooo01D0oooo0`3o08/00`3oool0o`2;0?ooo`0W0?ooo`80iP3o0`3o
08/00`3V0?l0oooo0?ooo`0;0?l0Re<0oooo1@3o08/30>H0o`030?l0R`3V0?l0oooo0200oooo0`3V
0?ln0?ooo`00?P3oool02@3V0?l0oooo0>H0o`3oool0iP3o0?l0R`3oool0iP3o0?ooo`030>H0o`<0
o`2;9`3oool20>H0o`<0o`2;6@3oool00`3o08/0oooo0?l0R`020?l0RbP0oooo00H0iP3o0?l0R`3o
08/0o`2;0?ooo`3o08/20?ooo`D0o`2;00<0oooo0?l0R`3o08/0103o08]@0?ooo`@0o`2;0`3oool0
0`3o08/0oooo0>H0o`0S0?ooo`030>H0o`3oool0oooo03d0oooo000m0?ooo`<0iP3o00<0oooo0>H0
o`3V0?l0103V0?l01@3oool0o`2;0?ooo`3oool0o`2;02P0oooo00<0o`2;0>H0o`3o08/00`3o08/K
0?ooo`030?l0R`3oool0o`2;02L0oooo0`3o08/0103oool0o`2;0?l0R`3o08/20?ooo`<0o`2;0P3o
ool70?l0Rdh0oooo103o08/30?ooo`<0o`2;I03oool003h0oooo00D0iP3o0?ooo`3oool0oooo0>H0
o`020?ooo`030>H0o`3oool0o`2;0080o`2;00<0oooo0>H0o`3oool09P3oool30?l0R`040>H0o`3o
08/0o`2;0>H0oa`0oooo0`3o08/W0?ooo`050?l0R`3oool0oooo0?ooo`3o08/0103oool00`000000
oooo0?ooo`020>H0o`030?l0R`3oool0o`2;00@0o`2;CP3oool30?l0R`@0oooo00<0o`2;0?ooo`3o
ool0H`3oool004@0oooo0`3V0?l30?l0R`<0iP3o9`3oool00`3o08/0iP3o0?l0R`020>H0oaD0oooo
00<0iP3o0?ooo`3oool01P3oool00`3o08/0oooo0?ooo`0_0?ooo`060000003oool0oooo0?ooo`3V
0?l0oooo203o08];0?ooo`@0o`2;1@3oool00`3V0?l0oooo0?ooo`1R0?ooo`00?@3oool00`3V0?l0
oooo0?ooo`040?ooo`<0iP3o00D0oooo0?l0R`3oool0oooo0>H0o`0W0?ooo`80iP3o0`3o08/E0?oo
o`060?l0R`3V0?l0iP3o0?ooo`3o08/0iP3o=P3oool2000000D0oooo00<0o`2;0?ooo`3o08/01@3o
08]90?ooo`80iP3o0P3o08/20>H0o`030?ooo`3V0?l0oooo00<0iP3oH`3oool003`0oooo0`3V0?l3
0?ooo`030>H0o`3oool0iP3o0080iP3o00<0o`2;0?ooo`3oool0:P3oool20>H0o`030?l0R`3V0?l0
oooo01<0oooo0`3o08/01@3oool0o`2;0?l0R`3o08/0iP3o03D0oooo00<000000?ooo`3oool01`3o
ool01P3o08/0oooo0>H0o`3o08/0oooo0?l0RdL0oooo103V0?l00`3oool0iP3o0?ooo`030>H0o`03
0?ooo`3V0?l0oooo02@0oooo00<0o`2;0?ooo`3oool0?03oool003d0oooo00@0iP3o0?ooo`3oool0
oooo0`3V0?l00`3oool0o`2;0?l0R`020?l0RbT0oooo00D0iP3o0?l0R`3oool0o`2;0>H0o`0D0?oo
o`030>H0o`3o08/0o`2;0080o`2;00<0oooo0?l0R`3V0?l00P3V0?l00`3oool0iP3o0?ooo`060?oo
o`030>H0o`3oool0oooo02P0oooo00<000000?l0R`3oool0203oool30>H0o`@0o`2;A@3oool50>H0
o`80oooo103V0?lU0?ooo`<0o`2;?@3oool003h0oooo00H0o`2;0>H0o`3oool0oooo0>H0o`3oool4
0?l0R`030>H0o`3oool0oooo02H0oooo00<0iP3o0?l0R`3o08/00`3o08/00`3V0?l0oooo0?ooo`0@
0?ooo`030>H0o`3o08/0o`2;00<0o`2;0`3oool00`3V0?l0oooo0>H0o`020>H0o`D0oooo0`3V0?lY
0?ooo`<0o`2;00<0iP3o0?ooo`3oool0103oool01@3o08/0oooo0?l0R`3o08/0iP3o00@0o`2;@`3o
ool20>H0o`030?l0R`3V0?l0iP3o0080oooo1P3V0?lU0?ooo`030?l0R`3oool0oooo03`0oooo000m
0?ooo`<0o`2;00<0iP3o0?ooo`3oool00P3oool20?l0R`030>H0o`3oool0oooo02P0oooo1P3o08/C
0?ooo`@0o`2;00<0iP3o0?ooo`3oool0103oool00`3V0?l0oooo0?ooo`050?ooo`@0iP3o9`3oool0
0`000000o`2;0>H0o`020>H0o`@0oooo2@3o08/20>H0od<0oooo0`3o08/0103V0?l0oooo0?ooo`3o
ool50>H0oaP0oooo00@0o`2;0?ooo`3oool0o`2;2@3oool00`3o08/0oooo0?ooo`0l0?ooo`00?P3o
ool00`3o08/0iP3o0?l0R`030?ooo`<0iP3o:P3oool70?l0Ra@0oooo103o08/00`3V0?l0o`2;0?oo
o`0<0?ooo`@0iP3o9P3oool010000000oooo0?ooo`3o08/20>H0o`@0oooo00<0o`2;0?ooo`3o08/0
1@3o08/30>H0od80oooo0`3o08/40?ooo`@0iP3o603oool60?l0R`L0oooo0`3o08/m0?ooo`00?@3o
ool50?l0R`80oooo0`3V0?l40?ooo`030?l0R`3oool0oooo02@0oooo0P3o08/00`3V0?l0o`2;0?l0
R`020?l0RaD0oooo1@3o08/:0?ooo`070?l0R`3oool0oooo0?ooo`3V0?l0oooo0>H0o`0U0?ooo`03
0000003oool0o`2;0080o`2;2@3oool30?l0R`@0iP3o@@3oool20>H0o`030?l0R`3oool0oooo0080
oooo00<0o`2;0?ooo`3V0?l06P3oool70?l0R`H0oooo0`3o08/m0?ooo`00?P3oool00`3o08/0iP3o
0?l0R`030?ooo`<0iP3o00<0o`2;0?ooo`3oool00`3o08/U0?ooo`H0o`2;5`3oool0103o08/0iP3o
0?l0R`3V0?l20?l0R`030>H0o`3oool0oooo00@0oooo0`3o08/30?ooo`@0iP3o8`3oool010000000
oooo0?ooo`3o08/;0?ooo`050?l0R`3oool0iP3o0?ooo`3o08/00P3V0?l00`3oool0iP3o0?ooo`0m
0?ooo`030>H0o`3o08/0oooo00<0oooo0`3o08/00`3V0?l0oooo0?ooo`0H0?ooo`L0o`2;1@3oool2
0>H0o`030?l0R`3oool0oooo03`0oooo000n0?ooo`<0iP3o103oool01`3V0?l0o`2;0?l0R`3o08/0
oooo0>H0o`3o08/09P3oool60?l0RaP0oooo0P3V0?l40?l0R`030>H0o`3oool0oooo00@0oooo00<0
o`2;0?ooo`3oool00`3oool40>H0ob80oooo00<000000?ooo`3oool03`3oool30?l0R`@0iP3o>`3o
ool20>H0o`<0o`2;0`3oool00`3V0?l0o`2;0>H0o`020>H0oaP0oooo1@3o08/0103oool0o`2;0?l0
R`3o08/50?ooo`030>H0o`3o08/0iP3o03d0oooo000m0?ooo`D0iP3o103oool30?l0R`<0iP3o9P3o
ool30?l0R`040>H0o`3o08/0o`2;0?l0RaX0oooo0P3o08/0103V0?l0o`2;0?l0R`3o08/:0?ooo`<0
iP3o8`3oool2000000L0oooo00<0iP3o0?ooo`3oool01@3oool00`3o08/0oooo0?l0R`030>H0o`03
0?l0R`3oool0oooo03T0oooo0P3V0?l40?l0R`80oooo00<0o`2;0>H0o`3V0?l00`3V0?lH0?ooo`80
o`2;0`3oool40?l0R`D0oooo0`3o08/m0?ooo`00?03oool70>H0o`80oooo00H0o`2;0>H0o`3o08/0
iP3o0?ooo`3V0?lW0?ooo`070>H0o`3o08/0o`2;0>H0o`3oool0o`2;0>H0o`0K0?ooo`030>H0o`3o
08/0o`2;00<0o`2;2P3oool01@3V0?l0oooo0?ooo`3oool0iP3o0200oooo00<000000?ooo`3oool0
1@3oool00`3V0?l0o`2;0>H0o`050?ooo`<0o`2;0P3oool01`3V0?l0o`2;0?l0R`3o08/0oooo0>H0
o`3o08/0>03oool50?l0R`050>H0o`3o08/0o`2;0?l0R`3oool00`3V0?lG0?ooo`@0o`2;0`3oool2
0?l0R`030>H0o`3oool0oooo00@0oooo00<0o`2;0?ooo`3oool0?03oool003d0oooo00D0iP3o0?oo
o`3oool0oooo0>H0o`020?ooo`D0o`2;:@3oool00`3V0?l0o`2;0?l0R`040?l0R`030>H0o`3oool0
oooo01X0oooo0`3o08/30>H0o`L0oooo00@0o`2;0?ooo`3oool0oooo0`3V0?lO0?ooo`030000003o
ool0oooo00D0oooo0`3o08/60?ooo`030?l0R`3oool0o`2;00<0oooo00<0o`2;0?ooo`3V0?l00`3o
08/h0?ooo`<0o`2;00<0iP3o0?ooo`3V0?l00`3o08/30>H0oaL0oooo1@3o08/30?ooo`030>H0o`3o
08/0iP3o04@0oooo000o0?ooo`030?l0R`3oool0o`2;0080oooo00D0iP3o0?l0R`3V0?l0o`2;0>H0
o`0Z0?ooo`<0o`2;00<0oooo0?l0R`3V0?l07`3oool30>H0o`<0o`2;103oool40?l0R`80oooo00<0
iP3o0?l0R`3V0?l07P3oool00`000000oooo0?ooo`040?ooo`80iP3o00@0o`2;0?ooo`3oool0iP3o
1@3oool30?l0R`060?ooo`3V0?l0o`2;0?l0R`3oool0iP3o103o08/e0?ooo`040?l0R`3V0?l0iP3o
0>H0o`<0oooo00<0iP3o0?l0R`3V0?l00P3V0?lH0?ooo`@0o`2;103oool30?l0Rd@0oooo000n0?oo
o`D0o`2;00<0oooo0?l0R`3o08/00P3o08/[0?ooo`H0o`2;8@3oool50?l0R`<0oooo00<0iP3o0?l0
R`3o08/00P3o08/01@3oool0o`2;0?l0R`3o08/0iP3o01d0oooo00<000000?ooo`3oool01@3oool0
0`3V0?l0oooo0?ooo`020>H0o`030?l0R`3oool0oooo00<0oooo00<0o`2;0?ooo`3oool01@3o08/0
0`3oool0o`2;0?l0R`020?l0Rc<0oooo0`3o08/20>H0o`80oooo00D0o`2;0?ooo`3o08/0oooo0>H0
o`0J0?ooo`80o`2;1P3oool00`3o08/0oooo0?ooo`130?ooo`00?`3oool00`3o08/0oooo0?l0R`02
0?l0R`030>H0o`3o08/0o`2;0080o`2;:`3oool40?l0R`040?ooo`3V0?l0oooo0?l0Ral0oooo1@3o
08/30?ooo`80iP3o0P3o08/20?ooo`030?l0R`3V0?l0iP3o01d0oooo00<000000?ooo`3oool02@3o
ool30?l0R`H0oooo1`3o08/20?ooo`040?l0R`3oool0oooo0?l0Rc00oooo1@3o08/20?ooo`D0o`2;
6P3oool20?l0Rdd0oooo00110?ooo`<0o`2;0P3V0?l30?l0R`030>H0o`3oool0oooo02P0oooo1@3o
08/0103V0?l0o`2;0?l0R`3o08/O0?ooo`030>H0o`3o08/0o`2;0080o`2;103oool30?l0R`80oooo
0`3V0?lL0?ooo`030000003oool0oooo00X0oooo00<0o`2;0?ooo`3oool01P3oool50?l0R`80iP3o
0`3oool40?l0Rbh0oooo00<0iP3o0?l0R`3o08/00P3o08/30?ooo`<0o`2;6P3oool40?l0Rd`0oooo
000m0?ooo`80o`2;0`3oool01@3o08/0oooo0?ooo`3V0?l0oooo00<0o`2;0P3oool00`3o08/0oooo
0?ooo`0V0?ooo`<0o`2;00<0oooo0?l0R`3o08/00P3o08/Q0?ooo`@0o`2;00@0iP3o0?ooo`3oool0
iP3o0`3o08/20?ooo`040>H0o`3oool0oooo0?l0RaX0oooo00<000000?ooo`3oool03@3oool00`3o
08/0iP3o0?ooo`050?ooo`040?l0R`3oool0iP3o0>H0o`D0oooo103o08/[0?ooo`030?l0R`3V0?l0
o`2;0080iP3o00@0o`2;0>H0o`3oool0iP3o0P3oool00`3o08/0iP3o0?ooo`0I0?ooo`@0o`2;1P3o
ool00`3V0?l0oooo0?ooo`130?ooo`00?03oool40?l0R`P0oooo00<0o`2;0?ooo`3oool00`3o08/X
0?ooo`<0o`2;00<0oooo0?l0R`3o08/00P3o08/R0?ooo`@0o`2;0P3oool00`3V0?l0o`2;0?l0R`02
0?l0R`80oooo0`3o08/I0?ooo`030000003oool0oooo00`0oooo0`3o08/00`3V0?l0oooo0?ooo`09
0?ooo`80o`2;0`3V0?l00`3o08/0oooo0?l0R`0Y0?ooo`H0o`2;00<0iP3o0?ooo`3V0?l00P3V0?l0
103o08/0iP3o0>H0o`3V0?lI0?ooo`030>H0o`3o08/0o`2;0080o`2;103oool30>H0o`@0oooo00<0
o`2;0?ooo`3oool0?@3oool003d0oooo103o08/;0?ooo`030?l0R`3oool0oooo02H0oooo103o08/3
0>H0o`80o`2;00<0iP3o0?ooo`3oool0803oool40?l0R`<0oooo103o08/20?ooo`030?l0R`3oool0
oooo01P0oooo00<000000?ooo`3oool03@3oool30?l0R`T0oooo1@3o08/30>H0o`<0o`2;00<0oooo
0?l0R`3oool0903oool0103o08/0iP3o0?l0R`3V0?l40?l0R`80oooo00@0iP3o0?l0R`3o08/0o`2;
0P3V0?lI0?ooo`040>H0o`3o08/0o`2;0?l0R`H0oooo00<0iP3o0?ooo`3oool00P3oool30?l0Rch0
oooo000o0?ooo`030?l0R`3oool0oooo00<0oooo00<0o`2;0?ooo`3V0?l0;P3oool90?l0R`030>H0
o`3oool0oooo0200oooo00<0iP3o0?l0R`3V0?l00P3V0?l00`3oool0o`2;0?l0R`020?l0R`030?oo
o`3o08/0oooo01X0oooo0P00000?0?ooo`040?l0R`3oool0oooo0?l0R`H0oooo1@3o08/50>H0o`03
0?l0R`3V0?l0o`2;0080o`2;8`3oool40?l0R`040>H0o`3o08/0o`2;0?l0R`80oooo0P3V0?l20?l0
R`030?ooo`3V0?l0oooo01X0oooo0P3o08/00`3V0?l0oooo0?ooo`080?ooo`80iP3o00<0o`2;0?oo
o`3oool0?@3oool004@0oooo0`3o08/20>H0obh0oooo1`3o08/20>H0ob<0oooo0`3V0?l20?l0R`04
0?ooo`3o08/0o`2;0>H0o`<0o`2;0P3oool00`3V0?l0oooo0?ooo`0E0?ooo`030000003oool0oooo
00h0oooo00<0iP3o0?ooo`3o08/00P3o08/60?ooo`050?l0R`3oool0oooo0?ooo`3V0?l00`3oool2
0>H0o`D0o`2;00<0iP3o0?ooo`3oool0803oool70?l0R`<0oooo103o08/K0?ooo`<0o`2;303oool0
0`3V0?l0oooo0?ooo`0n0?ooo`00?P3oool01@3o08/0oooo0?ooo`3oool0iP3o0080oooo00<0o`2;
0?ooo`3V0?l0;`3oool00`3V0?l0o`2;0>H0o`020?l0R`030>H0o`3oool0iP3o0080oooo00<0o`2;
0?ooo`3oool0803oool00`3V0?l0o`2;0?l0R`020?l0R`80oooo00D0iP3o0?ooo`3o08/0iP3o0?oo
o`020>H0o`030?l0R`3oool0oooo01@0oooo00<000000?ooo`3oool03@3oool30>H0o`040?ooo`3o
08/0iP3o0?l0R``0oooo0P3o08/00`3V0?l0o`2;0?l0R`040?l0R`80iP3o7@3oool00`3V0?l0oooo
0?l0R`030?l0R`80iP3o00<0o`2;0?ooo`3oool00P3o08/00`3V0?l0o`2;0?l0R`020?l0RaX0oooo
103o08]<0?ooo`00?@3oool30?l0R`030?ooo`3V0?l0iP3o00@0o`2;103oool00`3o08/0oooo0?oo
o`0Z0?ooo`80iP3o0`3o08/00`3V0?l0oooo0?ooo`050?l0R`030>H0o`3oool0oooo01d0oooo00<0
iP3o0?l0R`3o08/00P3o08/20?ooo`<0o`2;00<0iP3o0?ooo`3o08/00P3o08/E0?ooo`030000003o
ool0oooo00h0oooo00@0iP3o0?ooo`3oool0oooo0`3o08/00`3V0?l0oooo0?ooo`070?ooo``0o`2;
00<0iP3o0?ooo`3oool06@3oool30>H0o`030?ooo`3o08/0oooo0080iP3o0`3oool40?l0R`80oooo
00<0o`2;0?ooo`3oool0603oool50?l0R`/0oooo00<0iP3o0?ooo`3oool0?P3oool003`0oooo0`3o
08/20?ooo`030>H0o`3o08/0o`2;0080o`2;103oool30?l0Rb`0oooo1@3o08/30?ooo`H0o`2;803o
ool40?l0R`040?ooo`3V0?l0o`2;0>H0o`<0oooo0P3o08/E0?ooo`030000003oool0oooo0140oooo
103o08/20>H0o`L0oooo0P3V0?l20?l0R`040?ooo`3o08/0o`2;0?l0R`80iP3o103o08/00`3oool0
o`2;0>H0o`0F0?ooo`H0iP3o00<0o`2;0>H0o`3oool0103oool30?l0R`030?ooo`3o08/0o`2;01/0
oooo1@3o08/:0?ooo`<0iP3o?`3oool003d0oooo00L0o`2;0?ooo`3oool0iP3o0?ooo`3V0?l0o`2;
0080iP3o00<0o`2;0?ooo`3oool00P3oool00`3o08/0oooo0?ooo`0/0?ooo`D0o`2;0P3oool70?l0
Rb00oooo0P3o08/01P3V0?l0oooo0?ooo`3V0?l0oooo0?l0R`80oooo0`3o08/D0?ooo`030000003o
ool0oooo0100oooo103o08/40>H0o`L0oooo00<0iP3o0?ooo`3V0?l02@3o08/01P3oool0o`2;0?l0
R`3o08/0iP3o0?ooo`80o`2;00<0iP3o0?ooo`3oool03P3oool00`3o08/0iP3o0>H0o`030>H0o`<0
o`2;00@0iP3o0?ooo`3oool0oooo203o08/K0?ooo`<0o`2;303oool00`3V0?l0oooo0?ooo`0n0?oo
o`00?`3oool20?l0R`80iP3o00<0o`2;0?ooo`3o08/00`3o08/40?ooo`030?l0R`3oool0oooo02/0
oooo1@3o08/00`3oool0o`2;0?l0R`060?l0R`80iP3o7P3oool30>H0o`030?l0R`3oool0o`2;0080
o`2;0P3oool00`3o08/0oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo00<0o`2;0?ooo`3V
0?l01@3V0?l70?ooo`<0iP3o00<0o`2;0?ooo`3o08/00P3V0?l40?l0R`040?ooo`3o08/0iP3o0>H0
o`@0o`2;00H0iP3o0?ooo`3oool0iP3o0?ooo`3V0?l50?ooo`040?l0R`3oool0iP3o0?ooo`<0o`2;
00L0iP3o0?l0R`3V0?l0oooo0>H0o`3o08/0iP3o00@0oooo0`3o08/20>H0o`<0o`2;6P3oool30?l0
Rdh0oooo000n0?ooo``0o`2;0P3oool30?l0Rbd0oooo00<0iP3o0?l0R`3o08/0103o08/00`3oool0
o`2;0?l0R`020?l0R`030>H0o`3o08/0iP3o0080iP3o7@3oool00`3V0?l0o`2;0?l0R`030?l0R`03
0?ooo`3o08/0oooo01H0oooo00<000000?ooo`3oool0503oool60>H0o`L0oooo00<0iP3o0?ooo`3o
ool00`3o08/30>H0o`040?l0R`3oool0oooo0?ooo`<0iP3o0`3o08/50>H0o`050?l0R`3V0?l0o`2;
0?l0R`3V0?l00`3o08/30>H0o`030?l0R`3V0?l0o`2;00@0o`2;1@3oool20>H0o`060?l0R`3oool0
oooo0?ooo`3V0?l0o`2;6`3oool30?l0R`d0oooo00<0o`2;0?ooo`3oool0?P3oool003l0oooo0P3o
08/0103oool0iP3o0?l0R`3oool40?l0R`<0oooo00<0iP3o0?l0R`3V0?l0<03oool40?l0R`030?oo
o`3o08/0iP3o00H0o`2;0P3V0?l00`3o08/0oooo0?ooo`0J0?ooo`P0o`2;5P3oool00`000000oooo
0?ooo`0D0?ooo`<0iP3o00<0oooo0>H0o`3oool02`3oool00`3o08/0oooo0>H0o`020>H0o`030?l0
R`3V0?l0oooo0080oooo00<0iP3o0?ooo`3o08/0103o08/00`3V0?l0o`2;0?l0R`070?l0R`030>H0
o`3o08/0iP3o00@0iP3o1@3o08/30?ooo`<0iP3o00<0o`2;0?ooo`3oool00`3V0?lL0?ooo`030?l0
R`3V0?l0oooo00/0oooo0`3o08/o0?ooo`00@P3oool60?l0R`030?ooo`3V0?l0oooo0080oooo00<0
iP3o0?ooo`3oool0<03oool60?l0R`030?ooo`3o08/0o`2;00L0o`2;703oool40?l0R`040?ooo`3o
08/0oooo0?l0R`@0oooo00<0o`2;0?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`<0iP3o
103oool00`3V0?l0oooo0?ooo`0:0?ooo`@0o`2;00@0iP3o0?ooo`3oool0oooo4`3o08/0103V0?l0
o`2;0?ooo`3V0?l20?ooo`80o`2;0`3oool30>H0o`<0o`2;0P3oool00`3V0?l0oooo0?ooo`0K0?oo
o`030>H0o`3o08/0iP3o00`0oooo00<0o`2;0?ooo`3oool0?P3oool00400oooo00@0iP3o0?ooo`3V
0?l0o`2;0P3V0?l00`3o08/0iP3o0>H0o`020>H0o`80oooo00<0o`2;0?ooo`3oool0<03oool60?l0
R`030?ooo`3o08/0o`2;00@0o`2;00<0oooo0?l0R`3oool07@3oool30?l0R`80oooo0`3o08/20?oo
o`<0o`2;3`3oool2000001H0oooo00<0iP3o0?ooo`3oool00P3oool30>H0o`X0oooo103o08/30>H0
o`80oooo5P3o08/70?ooo`80o`2;00@0iP3o0?l0R`3o08/0o`2;0P3V0?lN0?ooo`040>H0o`3o08/0
o`2;0?l0R`/0oooo0`3V0?lo0?ooo`00?`3oool01P3V0?l0o`2;0>H0o`3o08/0iP3o0?ooo`<0o`2;
0`3V0?l0103oool0o`2;0?l0R`3o08/b0?ooo`P0o`2;00<0oooo0?l0R`3o08/0103oool00`3V0?l0
oooo0?ooo`020?ooo`030>H0o`3oool0oooo01H0oooo103o08/0103V0?l0o`2;0>H0o`3V0?l20?oo
o`030?l0R`3oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`3V0?l0oooo0>H0o`0<0?oo
o`040?l0R`3oool0oooo0?l0R`80iP3o103o08/00`3V0?l0o`2;0?ooo`060?l0R`050?ooo`3o08/0
o`2;0?ooo`3V0?l01`3o08/50?ooo`H0o`2;103V0?lN0?ooo`030>H0o`3o08/0oooo00D0oooo00<0
o`2;0?ooo`3oool0103oool00`3V0?l0oooo0?ooo`0n0?ooo`00?P3oool70?l0R`050?ooo`3o08/0
oooo0?ooo`3V0?l00`3oool00`3o08/0oooo0?ooo`0c0?ooo`030>H0o`3o08/0o`2;00H0o`2;0`3o
ool00`3V0?l0o`2;0>H0o`020?ooo`<0iP3o603oool40?l0R`@0iP3o0`3o08/?0?ooo`030000003o
ool0oooo01P0oooo0`3V0?l?0?ooo`L0o`2;0P3oool01P3o08/0oooo0?ooo`3o08/0oooo0?l0R`80
oooo0`3V0?l30?ooo`80o`2;00<0oooo0?l0R`3o08/01@3oool01P3o08/0iP3o0?l0R`3o08/0oooo
0?l0R`<0oooo00<0iP3o0?ooo`3oool0703oool40?l0R`@0oooo0`3o08]60?ooo`00?@3oool40?l0
R`030>H0o`3o08/0o`2;0080o`2;00<0oooo0?l0R`3oool0?03oool60?l0R`040>H0o`3oool0o`2;
0?ooo`@0o`2;00@0iP3o0?ooo`3V0?l0iP3o603oool40?l0R`080?ooo`3V0?l0iP3o0>H0o`3oool0
o`2;0?ooo`3V0?l>0?ooo`030000003oool0oooo01T0oooo00<0iP3o0?ooo`3oool0103oool00`3V
0?l0oooo0?ooo`080?ooo`@0o`2;0`3V0?l30?l0R`030?ooo`3V0?l0oooo00@0oooo00<0iP3o0?oo
o`3oool02@3oool00`3o08/0oooo0?l0R`020?l0R`030>H0o`3oool0oooo0080oooo00<0o`2;0?oo
o`3oool07@3oool40?l0R`D0oooo0`3o08]60?ooo`00?P3oool00`3o08/0oooo0>H0o`020>H0o`03
0?ooo`3o08/0oooo00<0o`2;?P3oool80?l0R`030?ooo`3o08/0o`2;0080o`2;0P3V0?l00`3o08/0
iP3o0?ooo`0G0?ooo`<0o`2;0P3oool0103V0?l0oooo0?ooo`3oool30>H0o`d0oooo00<000000?oo
o`3oool07`3oool40>H0o`T0oooo103o08/0103V0?l0o`2;0?l0R`3o08/40>H0o`80oooo00<0iP3o
0?ooo`3oool02@3oool80?l0R`<0oooo0`3o08/O0?ooo`030?l0R`3oool0oooo00@0oooo0`3o08/0
0`3V0?l0oooo0?ooo`140?ooo`00?P3oool01@3V0?l0oooo0?l0R`3V0?l0oooo00<0iP3o0`3o08/o
0?ooo`P0o`2;0P3oool60?l0RaT0oooo0`3o08/60?ooo`030>H0o`3oool0oooo00`0oooo00<00000
0?ooo`3oool07P3oool00`3V0?l0oooo0>H0o`030>H0o`X0oooo00H0o`2;0?ooo`3oool0oooo0?l0
R`3V0?l20?ooo`060>H0o`3o08/0iP3o0?l0R`3V0?l0o`2;0P3oool01P3o08/0iP3o0>H0o`3oool0
o`2;0?ooo`D0o`2;0P3oool40?l0R`040>H0o`3o08/0oooo0?l0RbL0oooo0`3o08/40?ooo`030?l0
R`3oool0oooo0400oooo000m0?ooo`80iP3o0`3o08/20?ooo`030>H0o`3oool0o`2;0080o`2;1P3o
ool00`3o08/0oooo0?ooo`0h0?ooo`L0o`2;00<0iP3o0?ooo`3o08/01@3o08/20?ooo`030>H0o`3o
ool0oooo01@0oooo0`3o08/70?ooo`030?l0R`3oool0oooo00X0oooo00<000000?ooo`3oool07@3o
ool30>H0o`80oooo00<0iP3o0?l0R`3V0?l04@3oool:0?l0R`030>H0o`3o08/0o`2;00D0o`2;00<0
iP3o0?ooo`3oool00P3oool00`3o08/0iP3o0?l0R`020?l0Rb00oooo00<0iP3o0?ooo`3oool01@3o
ool30?l0R`<0oooo0`3o08]10?ooo`00?P3oool30?l0R`D0oooo00<0iP3o0?l0R`3V0?l01@3oool3
0?l0Rc/0oooo1P3o08/20>H0o`030?ooo`3o08/0o`2;00@0o`2;0P3V0?lE0?ooo`040>H0o`3o08/0
o`2;0?l0R`80oooo00<0o`2;0?ooo`3oool00`3o08/;0?ooo`030000003oool0oooo01h0oooo00@0
iP3o0?ooo`3oool0oooo0`3o08/00`3V0?l0oooo0?ooo`0?0?ooo`030?l0R`3V0?l0o`2;0080o`2;
0P3oool01P3o08/0iP3o0>H0o`3oool0o`2;0?ooo`80o`2;103V0?l50?ooo`030>H0o`3o08/0oooo
01l0oooo00<0iP3o0?l0R`3V0?l01@3oool40?l0R`80oooo0`3o08]20?ooo`00?P3oool30?l0R`@0
oooo103o08/60?ooo`030?l0R`3oool0oooo03/0oooo00<0iP3o0?l0R`3o08/00P3o08/30>H0o`03
0?ooo`3V0?l0o`2;00@0o`2;0P3oool00`3o08/0oooo0?ooo`0A0?ooo`050>H0o`3o08/0o`2;0?l0
R`3oool00`3o08/2000000<0o`2;00<0oooo0000000000001`3oool00`000000oooo0?ooo`0S0?oo
o`040?l0R`3V0?l0iP3o0>H0o`l0oooo103V0?l00`3o08/0oooo0?ooo`040?ooo`<0iP3o0`3o08/2
0>H0obP0oooo0`3o08/60?ooo`80o`2;103oool00`3o08/0oooo0?ooo`110?ooo`00?P3oool00`3V
0?l0o`2;0>H0o`030?ooo`@0o`2;0P3oool00`3V0?l0oooo0?ooo`030?ooo`030>H0o`3oool0oooo
03`0oooo0P3o08/30>H0o`<0oooo00<0iP3o0?l0R`3o08/01P3o08/C0?ooo`050>H0o`3o08/0iP3o
0>H0o`3oool00`3o08/20?ooo`030?l0R`3oool000000080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0U0?ooo`030>H0o`3oool0oooo00l0oooo1@3V0?l00`3oool0iP3o0?ooo`03
0?ooo`050>H0o`3oool0iP3o0?l0R`3V0?l00P3oool00`3o08/0oooo0?ooo`0U0?ooo`@0o`2;103o
ool30?l0RdP0oooo000o0?ooo`040>H0o`3oool0oooo0?ooo`H0o`2;0`3V0?l30?ooo`<0iP3o?P3o
ool20>H0o`030?l0R`3V0?l0oooo00<0oooo00@0iP3o0?l0R`3o08/0o`2;0P3oool00`3o08/0oooo
0?ooo`0B0?ooo`030000003oool0iP3o00<0iP3o0`3o08/30?ooo`040?l0R`3oool0oooo000000H0
oooo0`00000i0?ooo`H0iP3o00L0oooo0?l0R`3oool0oooo0>H0o`3oool0o`2;0080oooo0`3o08/U
0?ooo`D0o`2;0`3oool40?l0RdP0oooo00110?ooo`030?l0R`3oool0o`2;0080o`2;00L0oooo0?l0
R`3o08/0o`2;0>H0o`3oool0o`2;00<0oooo00<0iP3o0?ooo`3oool0?P3oool30?l0R`80iP3o0`3o
ool0203V0?l0o`2;0?l0R`3o08/0oooo0>H0o`3oool0o`2;4P3oool02@000000oooo0>H0o`3o08/0
iP3o0?ooo`3V0?l0o`2;0>H0o`020?ooo`<0o`2;00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0Z0?ooo`030>H0o`3oool0oooo00h0oooo00@0iP3o0?ooo`3V0?l0oooo0`3o08/20>H0o`<0
o`2;0P3oool00`3o08/0oooo0?ooo`0T0?ooo`@0o`2;1@3oool40?l0RdL0oooo00100?ooo`<0o`2;
00<0oooo0?l0R`3oool0203o08/20?ooo`030>H0o`3oool0oooo03h0oooo00<0iP3o0?l0R`3o08/0
0`3o08/01P3V0?l0oooo0?ooo`3oool0o`2;0?ooo`80iP3o0`3o08/A0?ooo`030000003oool0o`2;
0080o`2;00D0oooo0?l0R`3o08/0o`2;0>H0o`020?ooo`030?l0R`3V0?l0oooo00L0oooo00<00000
0?ooo`3oool09P3oool00`3o08/0oooo0?ooo`040>H0oa<0oooo00H0o`2;0?ooo`3oool0iP3o0?oo
o`3o08/[0?ooo`030?l0R`3oool0oooo00L0oooo00@0o`2;0?ooo`3oool0o`2;A@3oool00440oooo
00@0o`2;0>H0o`3o08/0oooo1@3o08/20>H0o`030?l0R`3oool0oooo0080iP3o00<0o`2;0?ooo`3o
ool0?P3oool00`3V0?l0o`2;0?l0R`030?l0R`030>H0o`3oool0oooo0080oooo00@0iP3o0?l0R`3o
08/0o`2;0P3oool00`3V0?l0oooo0?ooo`0>0?ooo`030000003o08/0o`2;0080o`2;00@0oooo0?l0
R`3V0?l0iP3o0P3oool0103V0?l0o`2;0>H0o`0000060?ooo`030000003oool0oooo02D0oooo0`3o
08/20?ooo`<0iP3o00<0o`2;0?ooo`3oool0@03oool20?l0R`D0oooo00<0o`2;0?ooo`3oool00`3o
ool30?l0Rd@0oooo00100?ooo`80iP3o1P3o08/20>H0o`030?ooo`3V0?l0o`2;00<0oooo0`3o08]2
0?ooo`@0o`2;00@0iP3o0?l0R`3oool0oooo1@3o08/00`3V0?l0o`2;0>H0o`0A0?ooo`<0o`2;0P3o
ool20>H0o`80oooo0`3o08/70?ooo`030000003oool0oooo02H0oooo00@0o`2;0?ooo`3oool0o`2;
0P3oool30?l0R`030>H0o`3oool0oooo03d0oooo103o08/30?ooo`<0o`2;1@3oool00`3o08/0oooo
0?ooo`130?ooo`00@@3oool0103V0?l0oooo0?l0R`3V0?l30?l0R`030?ooo`3o08/0oooo00<0o`2;
0`3oool00`3o08/0iP3o0>H0o`120?ooo`H0o`2;0P3oool30?l0R`050?ooo`3o08/0o`2;0?l0R`3V
0?l0403oool30?l0R`80oooo0`3V0?l20?ooo`030?l0R`3oool0oooo00H0oooo00<000000?ooo`3o
ool0:03oool60?l0R`<0iP3o00<0o`2;0?ooo`3oool0>`3oool0103V0?l0o`2;0?l0R`3o08/30?oo
o`<0o`2;00D0iP3o0?ooo`3oool0oooo0>H0o`160?ooo`00@P3oool40>H0o`030?l0R`3V0?l0o`2;
00D0o`2;103oool30>H0od40oooo0P3V0?l30?l0R`030?ooo`3V0?l0oooo00<0o`2;0P3oool00`3o
08/0iP3o0?ooo`0A0?ooo`<0o`2;0P3oool00`3V0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo
02P0oooo00D0iP3o0?l0R`3V0?l0oooo0?l0R`030>H0o`<0o`2;>`3oool00`3V0?l0o`2;0?l0R`02
0?l0R`<0oooo0P3o08/0103V0?l0oooo0?ooo`3oool30>H0odD0oooo00120?ooo`80iP3o0P3oool2
0>H0o`<0o`2;00@0oooo0?l0R`3o08/0o`2;103oool00`3V0?l0o`2;0?ooo`110?ooo`80iP3o00<0
o`2;0?ooo`3V0?l00P3V0?l01@3oool0o`2;0>H0o`3V0?l0o`2;01@0oooo103o08/30>H0o`/0oooo
00<000000?ooo`3oool0:@3oool00`3V0?l0oooo0?ooo`050?ooo`040?l0R`3oool0oooo0?l0RcT0
oooo103o08/30?ooo`<0o`2;0P3V0?l20?ooo`80iP3oAP3oool00440oooo0`3V0?l20?ooo`030>H0
o`3o08/0o`2;0080o`2;0P3oool00`3o08/0oooo0?ooo`030?ooo`<0o`2;@@3oool0103V0?l0o`2;
0?l0R`3o08/20>H0o`040?l0R`3oool0oooo0>H0o`<0o`2;4`3oool30?l0R`80oooo0`3V0?l:0?oo
o`030000003oool0oooo03<0oooo0`3o08/g0?ooo`<0o`2;00<0iP3o0?ooo`3oool00P3oool30?l0
R`030>H0o`3oool0oooo00<0iP3oAP3oool00480oooo00@0iP3o0?ooo`3oool0oooo1@3o08/90?oo
o`030?l0R`3V0?l0oooo0440oooo00<0iP3o0?l0R`3o08/0103o08/00`3oool0iP3o0?l0R`020?l0
R`030>H0o`3oool0oooo0100oooo0`3o08/20?ooo`040>H0o`3o08/0iP3o0>H0o`80oooo00<0iP3o
0?ooo`3oool0103oool2000003D0oooo0`3o08/00`3V0?l0oooo0?ooo`0c0?ooo`80o`2;1@3oool5
0?l0R`<0oooo00<0iP3o0?ooo`3oool0A@3oool004D0oooo00<0iP3o0?l0R`3o08/0103o08/80?oo
o`<0iP3o@@3oool20>H0o`@0o`2;0`3oool00`3V0?l0o`2;0>H0o`020>H0oa80oooo0`3o08/0103o
ool0o`2;0?l0R`3o08/20?ooo`030>H0o`3o08/0iP3o00D0oooo00<000000?ooo`3oool0<`3oool0
0`3o08/0iP3o0?l0R`020>H0o`030?l0R`3oool0oooo0340oooo103o08/40?ooo`@0o`2;0P3oool0
0`3o08/0oooo0?ooo`170?ooo`00AP3oool60?l0R`040>H0o`3oool0oooo0?l0R`@0oooo0`3V0?m2
0?ooo`040>H0o`3o08/0o`2;0?l0R`D0oooo0P3o08/20>H0o`030?l0R`3oool0oooo00l0oooo103o
08/00`3oool0o`2;0?ooo`020?ooo`<0o`2;1@3oool00`000000oooo0?ooo`0b0?ooo`<0o`2;00<0
iP3o0?ooo`3o08/00P3o08/a0?ooo`@0o`2;00<0iP3o0?ooo`3oool00`3oool0103o08/0oooo0?oo
o`3oool30?l0RdP0oooo00170?ooo`H0o`2;00@0oooo0?l0R`3o08/0o`2;103oool20>H0od80oooo
1@3o08/00`3V0?l0oooo0?ooo`070?l0Ra40oooo0P3o08/0103oool0o`2;0?l0R`3o08/30?ooo`03
0?l0R`3oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01P3o08/0iP3o0?ooo`3oool0iP3o
0?l0R`80iP3o;`3oool30?l0R`80iP3o1@3oool30>H0o`040?ooo`3o08/0o`2;0?l0RdT0oooo0018
0?ooo`D0o`2;00@0iP3o0?l0R`3o08/0o`2;103oool30>H0od80oooo1@3o08/00`3V0?l0oooo0?l0
R`050?l0Ra40oooo00H0o`2;0>H0o`3V0?l0iP3o0?ooo`3o08/40?ooo`030?l0R`3oool0oooo00@0
oooo00<000000?ooo`3oool0>03oool20>H0o`80oooo00<0iP3o0?l0R`3o08/0;03oool00`3o08/0
iP3o0>H0o`060?ooo`040?l0R`3V0?l0oooo0?ooo`<0o`2;B@3oool004L0oooo00<0iP3o0?l0R`3o
08/0103o08/0103V0?l0o`2;0>H0o`3V0?l40?ooo`030>H0o`3oool0iP3o0440oooo1P3o08/01P3o
ool0o`2;0?l0R`3o08/0iP3o0?l0Ra40oooo0`3o08/00`3V0?l0oooo0?l0R`020?l0R`80oooo0`3o
08/50?ooo`030000003oool0oooo03H0oooo00<0iP3o0?ooo`3V0?l00`3V0?l40?l0RbT0oooo00<0
o`2;0>H0o`3V0?l00P3V0?l30?ooo`030?l0R`3oool0o`2;0080o`2;0P3oool00`3V0?l0o`2;0>H0
o`190?ooo`00A@3oool0103o08/0oooo0>H0o`3V0?l60?l0R`030?ooo`3V0?l0oooo00D0oooo0`3V
0?m00?ooo`050>H0o`3o08/0o`2;0>H0o`3o08/00`3oool30?l0Ra80oooo0`3o08/30?ooo`040?l0
R`3oool0oooo0?ooo`80o`2;1P3oool00`000000oooo0?ooo`0e0?ooo`<0iP3o00D0oooo0>H0o`3o
ool0oooo0>H0o`020?l0R`<0iP3o00<0o`2;0?ooo`3oool08`3oool30?l0R`80iP3o0`3oool30?l0
R`030?ooo`3o08/0oooo00<0oooo00<0iP3o0?ooo`3oool0B03oool004@0oooo0`3o08/00`3oool0
iP3o0?l0R`050?l0R`80oooo00<0iP3o0?ooo`3oool00`3oool30>H0od00oooo103o08/40?ooo`80
o`2;00<0oooo0>H0o`3oool03`3oool01`3V0?l0o`2;0?l0R`3o08/0oooo0>H0o`3o08/00P3V0?l0
103oool0o`2;0?l0R`3o08/60?ooo`030000003oool0oooo03H0oooo00<0iP3o0?ooo`3oool01P3o
ool20>H0o`@0o`2;8@3oool0103o08/0iP3o0?ooo`3o08/50?ooo`<0o`2;1@3oool00`3V0?l0oooo
0?ooo`1:0?ooo`00A@3oool30?l0R`030?ooo`3o08/0o`2;00@0o`2;00@0oooo0>H0o`3V0?l0iP3o
1@3oool00`3V0?l0oooo0?ooo`0o0?ooo`@0o`2;0`3oool30?l0R`<0iP3o3`3oool40?l0R`050>H0
o`3o08/0o`2;0?l0R`3oool00P3V0?l00`3o08/0oooo0?ooo`050?ooo`030000003oool0oooo0440
oooo00<0iP3o0?l0R`3o08/00`3o08/N0?ooo`<0o`2;00<0iP3o0?ooo`3oool00`3oool00`3o08/0
oooo0?l0R`050?ooo`<0iP3oB`3oool004H0oooo00@0o`2;0?ooo`3oool0oooo103o08/20>H0o`03
0?ooo`3V0?l0oooo00P0oooo00<0o`2;0?ooo`3oool0>`3oool20>H0o`<0o`2;0P3oool30?l0R`03
0>H0o`3o08/0iP3o00l0oooo1@3o08/20>H0o`030?l0R`3oool0oooo00<0iP3o1`3oool00`000000
oooo0?ooo`130?ooo`030>H0o`3o08/0o`2;0080o`2;00<0oooo0?l0R`3oool05`3oool01P3V0?l0
o`2;0>H0o`3V0?l0o`2;0>H0o`@0oooo00@0iP3o0?l0R`3o08/0o`2;1`3oool00`3V0?l0oooo0?oo
o`1:0?ooo`00A@3oool00`3V0?l0oooo0>H0o`020?ooo`@0o`2;00<0iP3o0?ooo`3oool02@3oool3
0?l0Rc/0oooo0P3V0?l50?l0R`80oooo1@3o08/>0?ooo`D0o`2;00<0oooo0>H0o`3V0?l00P3oool3
0>H0o`P0oooo0P00000o0?ooo`030>H0o`3oool0oooo00@0oooo0P3o08/00`3V0?l0o`2;0?l0R`03
0?l0Ra80oooo0`3V0?l30?l0R`80iP3o103oool0103V0?l0o`2;0?l0R`3o08/20>H0oe<0oooo0014
0?ooo`D0iP3o00<0oooo0>H0o`3o08/00P3o08/20>H0o`/0oooo00<0o`2;0?ooo`3o08/0>@3oool0
0`3V0?l0o`2;0?l0R`040?l0R`030>H0o`3oool0o`2;0080o`2;00<0iP3o0?l0R`3V0?l03@3oool4
0?l0R`040>H0o`3oool0oooo0>H0o`@0oooo00<0iP3o0?ooo`3oool01`3oool00`000000oooo0?oo
o`0m0?ooo`<0iP3o00@0o`2;0?ooo`3oool0oooo0`3o08/00`3V0?l0o`2;0?l0R`040?l0R`80oooo
0P3o08/00`3V0?l0oooo0?ooo`020?l0R`<0oooo00L0iP3o0?ooo`3oool0iP3o0?l0R`3V0?l0o`2;
0080iP3o00<0o`2;0>H0o`3V0?l0103oool01P3o08/0oooo0>H0o`3o08/0oooo0>H0o`<0oooo00<0
o`2;0?ooo`3oool0CP3oool004@0oooo203V0?l00`3o08/0oooo0?l0R`020>H0o`/0oooo0`3o08/h
0?ooo`D0o`2;00H0oooo0>H0o`3V0?l0iP3o0?ooo`3o08/20?ooo`030>H0o`3oool0oooo00/0oooo
1@3o08/20?ooo`<0iP3o3@3oool00`000000oooo0?ooo`0n0?ooo`040>H0o`3o08/0o`2;0?l0R`<0
oooo00<0o`2;0>H0o`3o08/00P3o08/00`3V0?l0o`2;0?l0R`020?ooo`@0o`2;00<0iP3o0?l0R`3o
08/00P3o08/50>H0o`D0o`2;1`3oool60?l0R`<0oooo0`3o08]?0?ooo`00A@3oool70>H0o`050?oo
o`3o08/0o`2;0?l0R`3V0?l00`3oool00`3o08/0oooo0?ooo`060?ooo`<0o`2;=P3oool30?l0R`03
0>H0o`3oool0oooo0080o`2;0`3V0?l?0?ooo`H0o`2;103oool00`3V0?l0oooo0?ooo`0<0?ooo`03
0000003oool0oooo0400oooo00<0o`2;0?ooo`3oool00`3oool00`3V0?l0oooo0?l0R`070?ooo`80
o`2;00<0iP3o0?l0R`3o08/0103o08/20>H0o`060?ooo`3V0?l0iP3o0?l0R`3V0?l0o`2;2@3oool0
103o08/0oooo0?ooo`3o08/50?ooo`030?l0R`3oool0oooo04h0oooo00150?ooo`80iP3o0P3o08/0
103V0?l0oooo0>H0o`3V0?l40?l0R`030>H0o`3oool0o`2;0080o`2;203oool00`3o08/0oooo0>H0
o`0c0?ooo`@0o`2;0P3V0?l50?l0R`030>H0o`3oool0oooo00d0oooo1@3o08/E0?ooo`030000003o
ool0oooo05@0oooo00@0o`2;0>H0o`3V0?l0o`2;0P3V0?l30?ooo`80iP3o103oool01@3o08/0oooo
0>H0o`3oool0iP3o05`0oooo00140?ooo`80iP3o103o08/20>H0o`H0o`2;00@0oooo0?l0R`3o08/0
o`2;2@3oool30>H0oc00oooo3P3o08/<0?ooo`030?l0R`3oool0o`2;00<0o`2;0`3V0?lD0?ooo`03
0000003oool0oooo04X0oooo00<0o`2;0?ooo`3oool01@3oool00`3o08/0oooo0?ooo`020?l0R`03
0?ooo`3o08/0oooo00@0oooo00@0iP3o0?l0R`3o08/0iP3o0`3o08/40>H0oe/0oooo00150?ooo`04
0>H0o`3oool0o`2;0?l0R`80oooo0P3V0?l40?l0R`040?ooo`3o08/0iP3o0?l0R`80iP3o2@3oool0
1@3V0?l0o`2;0>H0o`3oool0iP3o02`0oooo1@3o08/00`3V0?l0o`2;0?l0R`030?l0R`030>H0o`3o
ool0o`2;00`0oooo0`3o08/00`3V0?l0o`2;0>H0o`030>H0oaD0oooo00<000000?ooo`3oool0B@3o
ool30?l0R`D0oooo2@3o08/30?ooo`030>H0o`3o08/0o`2;0080o`2;00H0iP3o0?l0R`3oool0iP3o
0?ooo`3V0?l30?ooo`80o`2;E`3oool004L0oooo0`3o08/20?ooo`050>H0o`3oool0oooo0?l0R`3o
ool00`3o08/20>H0o`X0oooo0`3o08/00`3V0?l0o`2;0?l0R`0X0?ooo`030?l0R`3oool0o`2;00<0
o`2;0P3V0?l40?l0R`80iP3o303oool00`3o08/0oooo0?l0R`030?l0R`050?ooo`3V0?l0oooo0?oo
o`3V0?l05P3oool00`000000oooo0?ooo`1:0?ooo`030?l0R`3oool0oooo00D0oooo00<0o`2;0?oo
o`3oool01@3o08/20?ooo`<0iP3o0P3o08/20>H0o`D0oooo00<0o`2;0?ooo`3o08/00`3o08]F0?oo
o`00A`3oool0103V0?l0o`2;0>H0o`3o08/30?ooo`<0iP3o00<0oooo0?l0R`3oool02`3oool30?l0
R`030>H0o`3o08/0o`2;0080o`2;903oool00`3o08/0iP3o0?l0R`050?l0R`030>H0o`3o08/0o`2;
00<0o`2;0`3V0?l90?ooo`030>H0o`3oool0o`2;00L0o`2;00<0oooo0?l0R`3oool05`3oool00`00
0000oooo0?ooo`1B0?ooo`030>H0o`3oool0oooo0080oooo00<0iP3o0?l0R`3oool00`3oool00`3V
0?l0oooo0?ooo`070?ooo`H0o`2;E`3oool004H0oooo0`3V0?l30?l0R`80oooo0`3V0?l20?ooo`03
0?l0R`3oool0oooo00<0oooo00<0iP3o0?ooo`3oool0103oool0103o08/0oooo0>H0o`3oool40?l0
R`80oooo00<0o`2;0?ooo`3oool06`3oool00`3o08/0oooo0?l0R`0=0?l0R`80oooo00<0iP3o0?oo
o`3oool01@3oool0103V0?l0oooo0>H0o`3V0?l50?l0R`040>H0o`3oool0o`2;0?ooo`<0o`2;5`3o
ool00`000000oooo0?ooo`1A0?ooo`<0iP3o0`3oool00`3o08/0oooo0?ooo`040?ooo`030>H0o`3o
ool0oooo0080oooo00H0o`2;0?ooo`3oool0oooo0>H0o`3o08/20?ooo`030?l0R`3oool0oooo05H0
oooo00170?ooo`80iP3o0`3o08/30?ooo`<0iP3o0`3o08/01P3V0?l0oooo0?ooo`3V0?l0o`2;0>H0
o`H0oooo0`3V0?l00`3oool0o`2;0?l0R`020>H0o`<0o`2;6@3oool00`3o08/0oooo0?l0R`0=0?l0
R`/0oooo00X0o`2;0>H0o`3V0?l0iP3o0?l0R`3V0?l0oooo0?l0R`3oool0o`2;0`3V0?l30?ooo`03
0?l0R`3oool0oooo01H0oooo0P00001C0?ooo`040>H0o`3oool0oooo0?ooo`<0o`2;103oool00`3o
08/0iP3o0>H0o`020?ooo`<0o`2;00@0oooo0>H0o`3V0?l0iP3oF`3oool004T0oooo00<0iP3o0?l0
R`3oool0103oool0103V0?l0o`2;0>H0o`3o08/30>H0o`040?ooo`3o08/0o`2;0?l0R`L0oooo00<0
iP3o0?ooo`3o08/00P3o08/00`3V0?l0oooo0?ooo`030?l0Ra<0oooo00@0o`2;0?ooo`3V0?l0oooo
0`3o08/00`3V0?l0o`2;0?l0R`030?l0R`80oooo00<0o`2;0>H0o`3V0?l00`3o08/60?ooo`<0o`2;
00D0oooo0?l0R`3o08/0o`2;0>H0o`030?l0R`<0iP3o0P3oool00`3V0?l0oooo0?ooo`0K0?ooo`03
0000003oool0oooo05L0oooo00<0o`2;0?ooo`3oool00P3oool30?l0R`@0oooo00D0o`2;0?ooo`3o
ool0oooo0>H0o`1L0?ooo`00B@3oool30?l0R`@0oooo1@3o08/01@3V0?l0oooo0?ooo`3oool0o`2;
0080iP3o2@3oool01@3o08/0oooo0?ooo`3o08/0oooo00@0o`2;0`3oool20?l0R`80oooo00H0o`2;
0?ooo`3o08/0o`2;0?ooo`3V0?l20?ooo`030?l0R`3oool0o`2;00H0o`2;00<0iP3o0?ooo`3V0?l0
0`3o08/40?ooo`040>H0o`3oool0oooo0?l0R`D0oooo203o08/30>H0o`040?l0R`3oool0oooo0>H0
ob40oooo00<000000?ooo`3oool0G@3oool00`3o08/0oooo0?ooo`1T0?ooo`00BP3oool00`3o08/0
oooo0?l0R`040?ooo`D0o`2;0`3oool20>H0o`030?l0R`3oool0oooo00T0oooo0`3o08/00`3oool0
o`2;0?l0R`030?ooo`X0o`2;0P3V0?l;0?l0R`<0iP3o00<0o`2;0?ooo`3oool0203oool20?l0R`03
0>H0o`3o08/0o`2;00@0o`2;00D0oooo0?l0R`3oool0oooo0>H0o`0V0?ooo`030000003oool0oooo
0<@0oooo001;0?ooo`<0o`2;0P3oool30>H0o`@0o`2;0`3oool30?l0R`/0oooo00<0o`2;0?ooo`3V
0?l00P3V0?l40?ooo`P0o`2;00<0oooo0?l0R`3V0?l01@3o08/0203V0?l0o`2;0>H0o`3oool0o`2;
0>H0o`3oool0iP3o1P3oool30?l0R`80oooo103o08/00`3V0?l0o`2;0?ooo`0^0?ooo`030000003o
ool0oooo0<@0oooo001:0?ooo`040?l0R`3V0?l0o`2;0>H0o`<0oooo00<0iP3o0?ooo`3V0?l0103o
08/30?ooo`80o`2;00<0iP3o0?l0R`3oool02`3oool00`3V0?l0oooo0?ooo`030?ooo`060>H0o`3o
08/0oooo0?ooo`3o08/0iP3o0P3oool30?l0R`040>H0o`3o08/0o`2;0?l0R`80oooo00<0iP3o0?oo
o`3oool00`3oool00`3o08/0oooo0?ooo`030?ooo`H0o`2;00@0oooo0?l0R`3o08/0o`2;<@3oool0
0`000000oooo0?ooo`340?ooo`00B@3oool60?l0R`@0oooo1P3o08/20?ooo`D0o`2;403oool30>H0
o`80oooo00D0o`2;0?ooo`3oool0o`2;0?ooo`020?l0R`030>H0o`3oool0o`2;00L0oooo103o08/3
0?ooo`/0o`2;<@3oool00`000000oooo0?ooo`340?ooo`00BP3oool60?l0R`@0oooo103o08/40?oo
o`040?l0R`3V0?l0o`2;0?l0Ra40oooo00<0iP3o0?ooo`3oool02@3o08/50?ooo`030>H0o`3oool0
iP3o00@0o`2;1@3oool00`3o08/0oooo0?ooo`020?ooo`040?l0R`3oool0oooo0?l0Rc80oooo00<0
00000?ooo`3oool0a03oool004/0oooo00<0iP3o0?l0R`3o08/00P3o08/40?ooo`80iP3o0`3o08/0
0`3V0?l0oooo0?ooo`020?ooo`<0o`2;503oool01`3o08/0oooo0>H0o`3o08/0iP3o0?ooo`3o08/0
1@3oool30>H0o`<0o`2;0P3V0?m00?ooo`030000003oool0oooo0<@0oooo001:0?ooo`<0iP3o103o
08/20?ooo`80iP3o103o08/20>H0o`@0oooo00<0o`2;0?ooo`3oool00P3oool00`3o08/0oooo0?oo
o`0A0?ooo`030>H0o`3oool0oooo00L0oooo00H0iP3o0?ooo`3V0?l0o`2;0?ooo`3V0?m10?ooo`03
0000003oool0oooo0<@0oooo001;0?ooo`030>H0o`3o08/0oooo00@0o`2;0P3oool00`3V0?l0oooo
0?l0R`030?l0R`80iP3o1P3oool0103V0?l0o`2;0?l0R`3o08]S0?ooo`800000a@3oool004/0oooo
0`3o08/0103V0?l0o`2;0?l0R`3o08/50?ooo`@0o`2;0P3V0?l40?ooo`<0iP3o00<0o`2;0?ooo`3o
ool0HP3oool00`000000oooo0?ooo`340?ooo`00C03oool0103o08/0oooo0>H0o`3oool30?l0R`H0
oooo00@0o`2;0>H0o`3V0?l0iP3o1@3oool40>H0o`030?l0R`3oool0oooo0600oooo00<000000?oo
o`3oool0a03oool004l0oooo1@3o08/70?ooo`030>H0o`3oool0oooo00D0oooo0P3V0?l30?l0Rf40
oooo00<000000?ooo`3oool0a03oool00500oooo103o08/00`3V0?l0oooo0?ooo`030?ooo`030>H0
o`3oool0oooo00P0oooo00@0iP3o0?l0R`3o08/0o`2;0P3V0?mN0?ooo`030000003oool0oooo0<@0
oooo001A0?ooo`@0o`2;103oool30>H0o`/0oooo00<0o`2;0>H0o`3V0?l00P3V0?l00`3oool0o`2;
0?ooo`1J0?ooo`030000003oool0oooo0<@0oooo001A0?ooo`H0o`2;0`3oool30>H0o`/0oooo103V
0?l30?l0R`040>H0o`3o08/0o`2;0?l0ReH0oooo00<000000?ooo`3oool0a03oool00580oooo00<0
o`2;0>H0o`3o08/00`3o08/30?ooo`040>H0o`3oool0oooo0>H0o``0oooo0P3V0?l00`3o08/0iP3o
0?l0R`050?l0R`030?ooo`3o08/0oooo04L0oooo1@0000050?ooo`030000003oool0oooo0<@0oooo
001C0?ooo`@0o`2;1P3oool30>H0o``0oooo103V0?l80?l0R`80oooo00<0iP3o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<@0oooo001D0?ooo`040?l0R`3V0?l0
iP3o0>H0o`D0oooo0`3V0?l00`3oool0o`2;0?ooo`0:0?ooo`030>H0o`3oool0o`2;00D0o`2;00@0
iP3o0?l0R`3oool0oooo0P3V0?l00`3o08/0oooo0?ooo`130?ooo`030000003oool0oooo00D0oooo
0`0000340?ooo`00E@3oool40>H0o`030?l0R`3oool0oooo0080oooo00<0iP3o0?ooo`3o08/00P3o
08/=0?ooo`80o`2;00<0iP3o0?l0R`3o08/00P3o08/00`3V0?l0oooo0?ooo`030?l0R`@0oooo00<0
iP3o0?ooo`3o08/0?@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<@0oooo001G
0?ooo`040>H0o`3o08/0o`2;0?l0R`H0oooo00@0o`2;0?ooo`3oool0iP3o3@3oool20>H0o`T0o`2;
00<0oooo0?l0R`3oool00P3V0?l30?l0Rc`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`340?ooo`00F@3oool00`3o08/0iP3o0?ooo`070?ooo`<0iP3o3P3oool00`3V0?l0o`2;0?l0
R`090?l0R`030?ooo`3V0?l0oooo00<0o`2;0P3oool00`3V0?l0oooo0?ooo`0e0?ooo`8000001`3o
ool00`000000oooo0?ooo`340?ooo`00F03oool50>H0o`L0oooo00<0iP3o0?ooo`3oool0103oool2
0>H0o`X0oooo1P3o08/01@3oool0o`2;0?ooo`3oool0o`2;0080oooo00H0o`2;0?ooo`3oool0iP3o
0?l0R`3V0?lo0?ooo`030000003oool0oooo0<@0oooo001I0?ooo`@0iP3o00<0o`2;0?ooo`3oool0
2P3oool40>H0o`040?l0R`3oool0iP3o0?l0R`80oooo0P3o08/00`3V0?l0o`2;0?l0R`030?l0R`04
0>H0o`3oool0oooo0?ooo`<0o`2;103oool30?l0Rcl0oooo00<000000?ooo`3oool0a03oool005X0
oooo00<0iP3o0?ooo`3o08/00P3o08/<0?ooo`80iP3o3P3o08/01@3V0?l0oooo0?ooo`3V0?l0oooo
00<0o`2;0`3oool00`3V0?l0o`2;0?l0R`100?ooo`030000003oool0oooo0<@0oooo001M0?ooo`80
o`2;00<0iP3o0?ooo`3oool02`3oool00`3V0?l0o`2;0?l0R`060?l0R`030>H0o`3o08/0iP3o0080
o`2;0P3oool30>H0o`030?ooo`3o08/0oooo0080oooo00@0iP3o0?l0R`3o08/0o`2;@03oool00`00
0000oooo0?ooo`340?ooo`00G@3oool30?l0R`040>H0o`3oool0iP3o0?l0R`X0oooo00<0iP3o0?l0
R`3oool0103o08/0103V0?l0oooo0?ooo`3V0?l30?l0R`80oooo00<0iP3o0?ooo`3V0?l00P3V0?l3
0?ooo`030>H0o`3o08/0oooo0400oooo00<000000?ooo`3oool0a03oool005h0oooo00@0o`2;0>H0
o`3oool0iP3o0`3o08/>0?ooo`030?l0R`3V0?l0oooo00<0oooo00<0iP3o0?l0R`3oool01@3oool0
0`3V0?l0oooo0?ooo`150?ooo`030000003oool0oooo0<@0oooo001R0?ooo`040>H0o`3o08/0oooo
0>H0of<0oooo0P0000350?ooo`00I03oool30>H0of80oooo00<000000?ooo`3oool0a03oool006D0
oooo00<0iP3o0?ooo`3oool0H@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo
0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`34
0?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00
b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool2
00000<D0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0
oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo0039
0?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`03
0000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003o
ool0oooo0<@0oooo00390?ooo`800000a@3oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0
oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0>`3oool00`3_o`00oooo
0?ooo`260?ooo`00b@3oool00`000000oooo0?ooo`0j0?ooo`<0kol0Q`3oool00<T0oooo00<00000
0?ooo`3oool0>`3oool00`3_o`00oooo0?ooo`260?ooo`00b@3oool00`000000oooo0?ooo`340?oo
o`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3o
ool200000<D0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo
0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo
00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?oo
o`030000003oool0oooo0<@0oooo002c0?ooo`D000000P3oool2000000@0oooo0P0000070?ooo`03
0000003oool0oooo0<@0oooo002e0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`340?ooo`00]@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo0`0000340?ooo`00]@3oool00`000000oooo0?ooo`080?ooo`8000001`3o
ool00`000000oooo0?ooo`340?ooo`00]@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0a03oool00;@0oooo0P00000:0?ooo`<000001P3oool00`00
0000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo
0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`34
0?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00
b@3oool200000<D0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0
oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0
oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo0039
0?ooo`030000003oool0oooo0<@0oooo00390?ooo`030000003oool0oooo0<@0oooo00390?ooo`03
0000003oool0oooo0<@0oooo00390?ooo`800000a@3oool00<T0oooo00<000000?ooo`3oool0a03o
ool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0
oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<0
00000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<000000?oo
o`3oool0H`3oool30>oo05h0oooo00390?ooo`800000H`3oool50>oo05d0oooo00390?ooo`030000
003oool0oooo0640oooo1`3_o`1L0?ooo`00b@3oool00`000000oooo0?ooo`1Q0?ooo`L0kol0G03o
ool00<T0oooo00<000000?ooo`3oool0H@3oool70>oo05`0oooo00390?ooo`030000003oool0oooo
0680oooo1@3_o`1M0?ooo`00b@3oool00`000000oooo0?ooo`1S0?ooo`<0kol0GP3oool00<T0oooo
00<000000?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo00<00000
0?ooo`3oool0a03oool00<T0oooo00<000000?ooo`3oool0a03oool00<T0oooo0P0000350?ooo`00
b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool0
0`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000
oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?oo
o`340?ooo`00_`3oool4000000H0oooo00<000000?ooo`3oool0a03oool00;l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`340?ooo`00`03oool00`000000oooo0?ooo`060?ooo`<0
0000a03oool00<40oooo00<000000?ooo`3oool0c03oool00;l0oooo00@000000?ooo`3oool00000
c@3oool00<00oooo0P00003>0?ooo`00o`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-2.06156, -2.04617, 0.0102565, \
0.0102565}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{"EquationTrekkerState", "[", 
            
            RowBox[{"\<\"\\!\\({{\\(-x[t]\\) + x[t]\\^3 + \[Gamma]  \
\\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), MultilineFunction->None]\\)[t] \
+  \\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\[Prime]\\), \
MultilineFunction->None]\\)[t] \[Equal] \[Epsilon] Cos[t \[Omega]]}, x, {t, \
0, 100}}\\)\"\>", 
              ",", "\<\"\\!\\({\[Gamma] \[Rule] 0.15`, \[Epsilon] \[Rule] \
0.3`, \[Omega] \[Rule] 1.`}\\)\"\>", ",", 
              InterpretationBox[GridBox[{
                    {
                      InterpretationBox[
                        StyleBox[
                          RowBox[{"TrekData", "[", 
                            
                            RowBox[{"\<\"\\!\\({x[0.`] \[Equal] \
1.0699999999999998`,  \\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), \
MultilineFunction->None]\\)[0.`] \[Equal] 1.81`}\\)\"\>", ",", 
                              " ", "\<\"<>\"\>"}], "]"}],
                          FontColor->RGBColor[0.937255, 1, 0]],
                        TrekData[ {
                          Equal[ 
                            x[ 0.`], 1.0699999999999998`], 
                          Equal[ 
                            Derivative[ 1][ x][ 0.`], 1.81`]}, {
                          1.0699999999999998`, 1.81`}, {0.`, {1000.`, 
                          10000.`}}, {
                          RGBColor[ 0.9372549057006836`, 1.`, 0.`], 
                          "Points"}]]},
                    {
                      InterpretationBox[
                        StyleBox[
                          RowBox[{"TrekData", "[", 
                            
                            RowBox[{"\<\"\\!\\({x[0.`] \[Equal] \
0.6299999999999999`,  \\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), \
MultilineFunction->None]\\)[0.`] \[Equal] 0.`}\\)\"\>", ",", 
                              " ", "\<\"<>\"\>"}], "]"}],
                          FontColor->RGBColor[0.901961, 0, 1]],
                        TrekData[ {
                          Equal[ 
                            x[ 0.`], 0.6299999999999999`], 
                          Equal[ 
                            Derivative[ 1][ x][ 0.`], 0.`]}, {
                          0.6299999999999999`, 0.`}, {0.`, {1000.`, 
                          10000.`}}, {
                          RGBColor[ 0.9019607901573181`, 0.`, 1.`], 
                          "Points"}]]},
                    {
                      InterpretationBox[
                        StyleBox[
                          RowBox[{"TrekData", "[", 
                            
                            RowBox[{"\<\"\\!\\({x[0.`] \[Equal] \
0.009999999999999787`,  \\(\\*SuperscriptBox[\\(x\\),  \\(\[Prime]\\), \
MultilineFunction->None]\\)[0.`] \[Equal] 0.040000000000000036`}\\)\"\>", ",",
                               " ", "\<\"<>\"\>"}], "]"}],
                          FontColor->RGBColor[1, 0, 0.545098]],
                        TrekData[ {
                          Equal[ 
                            x[ 0.`], 0.009999999999999787`], 
                          Equal[ 
                            Derivative[ 1][ x][ 0.`], 
                            0.040000000000000036`]}, {0.009999999999999787`, 
                          0.040000000000000036`}, {0.`, {1000.`, 10000.`}}, {
                          RGBColor[ 1.`, 0.`, 0.545098066329956`], 
                          "Points"}]]}
                    },
                  RowSpacings->1,
                  ColumnSpacings->3,
                  RowAlignments->Baseline,
                  ColumnAlignments->{Left}],
                TableForm[ {
                  TrekData[ {
                    Equal[ 
                      x[ 0.`], 1.0699999999999998`], 
                    Equal[ 
                      Derivative[ 1][ x][ 0.`], 1.81`]}, {1.0699999999999998`,
                     1.81`}, {0.`, {1000.`, 10000.`}}, {
                    RGBColor[ 0.9372549057006836`, 1.`, 0.`], "Points"}], 
                  TrekData[ {
                    Equal[ 
                      x[ 0.`], 0.6299999999999999`], 
                    Equal[ 
                      Derivative[ 1][ x][ 0.`], 0.`]}, {0.6299999999999999`, 
                    0.`}, {0.`, {1000.`, 10000.`}}, {
                    RGBColor[ 0.9019607901573181`, 0.`, 1.`], "Points"}], 
                  TrekData[ {
                    Equal[ 
                      x[ 0.`], 0.009999999999999787`], 
                    Equal[ 
                      Derivative[ 1][ x][ 0.`], 0.040000000000000036`]}, {
                    0.009999999999999787`, 0.040000000000000036`}, {0.`, {
                    1000.`, 10000.`}}, {
                    RGBColor[ 1.`, 0.`, 0.545098066329956`], "Points"}]}]], 
              ",", "\<\" <>\"\>"}], "]"}],
          EquationTrekkerState[ {{
            Equal[ 
              Plus[ 
                Times[ -1, 
                  x[ t]], 
                Power[ 
                  x[ t], 3], 
                Times[ \[Gamma], 
                  Derivative[ 1][ x][ t]], 
                Derivative[ 2][ x][ t]], 
              Times[ \[Epsilon], 
                Cos[ 
                  Times[ t, \[Omega]]]]]}, x, {t, 0, 
            100}}, {\[Gamma] -> .14999999999999999, \[Epsilon] -> \
.29999999999999999, \[Omega] -> 1.0}, {
            TrekData[ {
              Equal[ 
                x[ 0.0], 1.0699999999999998], 
              Equal[ 
                Derivative[ 1][ x][ 0.0], 1.8100000000000001]}, {
              1.0699999999999998, 1.8100000000000001}, {
              0.0, {.1*^4, .1*^5}}, {
              RGBColor[ .93725490570068359, 1.0, 0.0], "Points"}], 
            TrekData[ {
              Equal[ 
                x[ 0.0], .62999999999999989], 
              Equal[ 
                Derivative[ 1][ x][ 0.0], 0.0]}, {.62999999999999989, 0.0}, {
              0.0, {.1*^4, .1*^5}}, {
              RGBColor[ .90196079015731812, 0.0, 1.0], "Points"}], 
            TrekData[ {
              Equal[ 
                x[ 0.0], .0099999999999997868], 
              Equal[ 
                Derivative[ 1][ x][ 
                0.0], .040000000000000036]}, {.0099999999999997868, \
.040000000000000036}, {0.0, {.1*^4, .1*^5}}, {
              RGBColor[ 1.0, 0.0, .54509806632995605], "Points"}]}, {
            TrekParameters -> {\[Gamma] -> .14999999999999999, \[Epsilon] -> \
.29999999999999999, \[Omega] -> 1.0}, PlotRange -> {{-2.0, 2.0}, {-2.0, 2.0}},
             "CanvasSize" -> {400, 400}, TrekGenerator -> {PoincareSection, 
            "SectionCondition" -> Mod[ 
              Times[ t, \[Omega]], 
              Times[ 2, Pi]], "SectionVariables" -> {x, 
            Derivative[ 1][ x]}, MaxSteps -> DirectedInfinity[ 1]}}]], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[57]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["webMathematica",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"web", 
          StyleBox[
            AdjustmentBox["Mathematica",
              BoxMargins->{{-0.175, 0}, {0, 0}}],
            FontSlant->"Italic"]}], TextForm]]],
  " allows you to show results on the web, and more importantly to allow \
others to do interact with your computations."
}], "Text"],

Cell[TextData[{
  ButtonBox["Here",
    ButtonData:>{
      URL[ "http://localhost:8080/webMathematica/Demos/RegressTable.jsp"], 
      None},
    ButtonStyle->"Hyperlink"],
  " is a simple example that shows how it works."
}], "Text"],

Cell["Display the source file for the webMathematica page.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(!! "\<C:\\Program Files\\Tomcat \
5.5\\webapps\\webMathematica\\Demos\\RegressTable.jsp\>"\)\)], "Input",
  CellLabel->"In[69]:="],

Cell["\<\
<%@ page language=\"java\"  %>
<%@ taglib uri=\"/webMathematica-taglib\" prefix=\"msp\" %>

<!--

    webMathematica source code (c) 1999-2003, 
    Wolfram Research, Inc. All rights reserved.

    This is an example of webMathematica, that shows 
    how to embed Mathematica code inside of a JSP.

    The example can be run directly via a URL such as 
    http://localhost:8080/webMathematica/Examples/HTML/RegressTable.jsp 
    
    It can also be loaded from a template by
    http://localhost:8080/webMathematica/BrowseExamples/HTML/RegressTable.\
html

-->

<html>
<head>
<title>Regress Table</title>
</head>
<body bgcolor=\"#ffffff\" >

<h1>Regress Table</h1>

<form action=\"RegressTable.jsp\" method=\"post\">

<msp:allocateKernel>

<msp:evaluate>
   Needs[\"Statistics`LinearRegression`\"];
   Needs[\"Statistics`Common`RegressionCommon`\"];
</msp:evaluate>

Fit data against 
<input type=\"text\" name=\"FitTo\" size=\"10\" \
value=\"<msp:evaluate>MSPValue[ $$FitTo,  \"x^2\"]</msp:evaluate>\"
/>
<input type=\"submit\" name=\"btnSubmit\" value=\"Refit\"> 

<br/>

<msp:evaluate> 
    nterms = 5;
    If[ MSPValueQ[ $$nterms],
        nterms = MSPToExpression[ $$nterms]];
</msp:evaluate> 



<msp:evaluate> 
MSPBlock[{$$FitTo},
   data = {{0.055, 90}, {0.091, 97}, {0.138, 107},
        {0.167, 124}, {0.182, 142}, {0.211, 150},
        {0.232, 172}, {0.248, 189}, {0.284, 209},
        {0.351, 253}};
   regress = Chop[ Regress[data, {1, $$FitTo}, x], 10^-6];
   pTable = ParameterTable /. regress ;
   aTable = ANOVATable /. regress ;
   rSq = RSquared /. regress ;
   aSq = AdjustedRSquared /. regress ;
   eVar = EstimatedVariance /. regress ;
]
</msp:evaluate>

<br/>

<msp:evaluate>
MSPBlock[{$$FitTo},
    HTMLTableForm[ MSPShow[Show[{Plot[Evaluate[pTable[[1, \
All,1]].{1,$$FitTo}], {x,.05, .35}],ListPlot[ data]},Frame -> True, Axes \
->False]], 
            TableHeadings -> {\"Data to be fitted\"}]
]
</msp:evaluate>

<br/>

<msp:evaluate>
    HTMLTableForm[ HTMLTableForm[ pTable], TableAttributes -> {}, \
TableHeadings->{\"ParameterTable\"}]
</msp:evaluate> 

<br/>


<msp:evaluate>
    HTMLTableForm[ {{rSq, aSq, eVar}}, TableHeadings -> {RSquared , \
AdjustedRSquared , EstimatedVariance }]
</msp:evaluate> 


<br/>

<msp:evaluate>
    HTMLTableForm[ HTMLTableForm[ aTable], TableAttributes -> {}, \
TableHeadings->{\"ANOVATable\"}]
</msp:evaluate> 


</msp:allocateKernel>
</form>

</body>
</html>
\
\>", "Print",
  CellLabel->"From In[69]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Mathematica\ in\ education\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is being used to assist in teaching mathematics and other technical \
disciplines in universities throughout the world.  Increasingly, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is being used in secondary schools."
}], "Text"],

Cell["\<\
Create a simple animation that can be used to illustrate the \
correspondence between the unit circle and the sine and cosine \
functions.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[\[IndentingNewLine]Show[
        Block[{$DisplayFunction\  = \ Identity, \ 
            size\  = \ 
              PointSize[ .05]}, \[IndentingNewLine]GraphicsArray[{\
\[IndentingNewLine]Graphics[{Circle[{0, 0}, 1], \ {Blue, size, \ 
                    Point[{Cos[\[Theta]], \ Sin[\[Theta]]}], \ 
                    Line[{{0, 0}, {Cos[\[Theta]], \ 
                          Sin[\[Theta]]}}]}, \ {Green, \ 
                    Line[{{0, 0}, \ {Cos[\[Theta]], \ 0}}]}, \ {Red, \ 
                    Line[{{Cos[\[Theta]], \ 
                          Sin[\[Theta]]}, \ {Cos[\[Theta]], \ 0}}]}}, \ 
                AspectRatio \[Rule] 1], \[IndentingNewLine]Plot[{Cos[t], \ 
                  Sin[t]}, \ {t, \ 0, \ 2\ \[Pi]}, \ 
                Epilog \[Rule] {size, {Green, \ 
                      Point[{\[Theta], Cos[\[Theta]]}]}, \ {Red, \ 
                      Point[{\[Theta], \ Sin[\[Theta]]}]}}]}]]], {\[Theta], \ 
        0, \ 2\ \[Pi], \ \[Pi]/12}]\)], "Input",
  CellLabel->"In[70]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.97619 .5 Mdot
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 1 0 r
.5 .5 m
.97619 .5 L
s
1 0 0 r
.97619 .5 m
.97619 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.02381 .60332 Mdot
1 0 0 r
.02381 .30902 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2e0?ooo`<0003o?@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0100oooo000?0?ooo`030000003oool0oooo0;<0oooo1`000?lj0?ooo`80o`009`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`2c0?ooo`L0003o>03oool60?l002@0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0/P3oool90000ocL0oooo
1P3o000T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo05X0ooooG@00
o`00103o0000003o0000o`000?lf0?ooo`P0o`00VP00000;0?ooo`003`3oool00`000000oooo0?oo
o`2b0?ooo`T0003o=P3oool80?l000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000
oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
00l0oooo00<000000?ooo`3oool0/`3oool70000ocP0oooo1P3o000R0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3oool00`000000
oooo0?ooo`2c0?ooo`L0003o>03oool60?l00240oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo0;D0oooo
0`000?ll0?ooo`80o`0000<0oooo0000003oool0803oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool000000200oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000?0?ooo`030000003oool0
oooo0;H0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000O0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007P3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0
oooo0?ooo`0000007@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l
0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool0]P3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool0
0100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo
00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0:`3oool00140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3o
ool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000001P3oool2
000000H0oooo100000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:@3oool0
0140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0:@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool00180oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0W0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo02H0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo02D0oooo000C0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0
9@3oool4000000h0oooo1@0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
903oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool08`3oool001@0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
000U0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001@0oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool000009P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000E
0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0Q
0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool03`3oool2000002H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0P0?oo
o`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03`3oool2000002D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`00
5@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
3P3oool010000000oooo0?ooo`00000S0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool07`3oool001H0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool07P3oool001H0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool07P3oool001L0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool07@3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0703oool001P0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool06`3oool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
6@3oool001T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0FP3o
ool2000001T0oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?@3oool7
00000080oooo0P00o`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0@03oool010000000oooo0?ooo`3oool6003o00D0oooo00<00000
0?ooo`3oool04P3oool2000000l0oooo0P00001Q0?ooo`030000003oool0oooo01D0oooo000J0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0@@3oool010000000oooo0?ooo`3oool6
003o00<0oooo0P00000G0?ooo`8000002P3oool3000006@0oooo0P00000E0?ooo`006`3oool00`00
0000oooo0?ooo`2N0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02000o`020000
01/0oooo2P00001Y0?ooo`H000003`3oool001`0oooo00<000000?ooo`3oool0W03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00P00?l0Y@3oool001d0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`120?ooo`040000003oool0oooo0?ooo`H00?l0YP3oool001d0oooo
00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo0?ooo`H0
0?l0YP3oool001h0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`110?ooo`<00000
[`3oool001l0oooo00<000000?ooo`3oool0UP3oool2000004H0oooo00<000000?ooo`3oool0[@3o
ool001l0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`00803oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`3g0?ooo`008P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0?P0oooo000S
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0n@3oool002@0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
n`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`3l0?ooo`009`3oool2
000008L0oooo00<000000?ooo`3oool0o@3oool002P0oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`3n0?ooo`00:@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0
oooo000Z0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3oool10?ooo`00:`3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0oooo0@3oool002`0oooo0P00001m
0?ooo`800000o`3oool40?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0?l0oooo103oool002h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`3o0?ooo`D0
oooo000_0?ooo`800000MP3oool200000?l0oooo203oool00340oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`3o0?ooo`P0oooo000b0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool0o`3oool80?ooo`00<`3oool2000006l0oooo0P00003o0?ooo`/0oooo000e0?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3oool;0?ooo`00=P3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo0?l0oooo303oool003L0oooo00<000000?ooo`3oool0IP3o
ool200000?l0oooo3`3oool003P0oooo0P00001T0?ooo`800000o`3ooolA0?ooo`00>P3oool20000
0600oooo0P00003o0?oooa<0oooo000l0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`00?@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo
503oool003h0oooo0P00001H0?ooo`800000o`3ooolG0?ooo`00@03oool3000005<0oooo0P00003o
0?oooaT0oooo00130?ooo`800000C`3oool200000?l0oooo6`3oool004D0oooo0P00001;0?ooo`80
0000o`3ooolM0?ooo`00A`3oool2000004L0oooo0P00003o0?oooal0oooo00190?ooo`@00000?P3o
ool500000?l0oooo8@3oool004d0oooo0P00000j0?ooo`800000o`3ooolV0?ooo`00C`3oool30000
03D0oooo0P00003o0?ooobP0oooo001B0?ooo`@00000;03oool500000?l0oooo:P3oool005H0oooo
1@00000S0?ooo`@00000o`3oool_0?ooo`00F`3oool7000001D0oooo1`00003o0?oooc<0oooo001R
0?oooaD00000o`3ooolj0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.95996 .62325 Mdot
.5 Mabswid
.5 .5 m
.95996 .62325 L
s
0 1 0 r
.5 .5 m
.95996 .5 L
s
1 0 0 r
.95996 .62325 m
.95996 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.06349 .59329 Mdot
1 0 0 r
.06349 .38519 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`1J0?oooeT00?l000D0o`000?ooo`3oool0oooo0000000i0?oooj8000002`3oool000l0oooo00<0
00000?ooo`3oool0G03oool40000oe<0oooo00D0o`000?ooo`3oool0oooo0000000m0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000
oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?oo
o`1P0?ooo`@0003oC`3oool01@3o0000oooo0?ooo`3oool0000003d0oooo0P00000S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3o
ool00`000000oooo0?ooo`1T0?ooo`<0003oC03oool01@3o0000oooo0?ooo`3oool0000003d0oooo
0P00000R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`1W0?ooo`@0003oB03oool0103o0000oooo0?oo
o`00000n0?ooo`030000003oool000000240oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0340oooo000?0?ooo`030000003oool0oooo06/0oooo1000
0?m40?ooo`040?l0003oool0oooo000003h0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0<@3oool000l0oooo00<0
00000?ooo`3oool0K`3oool40000od00oooo00@0o`000?ooo`3oool00000?P3oool010000000oooo
0?ooo`00000O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`1c0?ooo`<0003o?@3oool0103o0000oooo
0?ooo`00000n0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003oool0oooo07H0
oooo10000?li0?ooo`040?l0003oool0oooo000003h0oooo00D000000?ooo`3oool0oooo0000000M
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0_
0?ooo`003`3oool00`000000oooo0?ooo`1j0?ooo`@0003o=@3oool0103o0000oooo0?ooo`00000n
0?ooo`060000003oool0oooo0?ooo`000000oooo0P3o000I0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?oo
o`1n0?ooo`<0003o<P3oool0103o0000oooo0?ooo`00000n0?ooo`040000003oool0oooo0?ooo`H0
o`005`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0;P3oool00100oooo00<000000?ooo`3oool0P03oool40000obh0oooo00@0o`000?ooo`3oool0
0000?P3oool010000000oooo0?ooo`3oool60?l001H0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo000@0?ooo`030000003oool0oooo08@0
oooo10000?lZ0?ooo`040?l0003oool0oooo000003h0oooo00<000000?ooo`3oool0203o000E0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?oo
o`00403oool00`000000oooo0?ooo`280?ooo`@0003o9P3oool0103o0000oooo0?ooo`00000n0?oo
o`030000003oool0oooo00P0o`00503oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0S03oool30000ob<0
oooo00@0o`000?ooo`3oool00000?P3oool010000000oooo0?ooo`3oool60?l001D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02`0oooo000@0?oo
o`030000003oool0oooo08l0oooo10000?lO0?ooo`030?l0003oool0000003l0oooo00@000000?oo
o`3oool0oooo1P3o000D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`2C0?ooo`@0003o6`3oool00`3o
0000oooo0000000o0?ooo`030000003oool0oooo00<0oooo0P3o00000`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0[0?oo
o`00403oool00`000000oooo0?ooo`2G0?ooo`<0003o603oool00`3o0000oooo0000000o0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?ooo`3oool0
V@3oool40000oa@0oooo00<0o`000?ooo`000000?`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo02X0oooo000A0?ooo`030000003oool0oooo09d0oooo10000?l@0?ooo`030?l0003o
ool0000003l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool0
0`000000oooo0?ooo`2Q0?ooo`@0003o2`3oool00`000?l0o`000000o`0U0?ooo`@000001P3oool2
000000H0oooo100000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:@3oool0
0140oooo00<000000?ooo`3oool0Y@3oool30000o`H0oooo0`000?l0103o0000003o0000o`000?lR
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0Z03oool40000o`80oooo0`000?l0103o
0000003o0000o`000?lR0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool0
0180oooo00<000000?ooo`3oool0Z`3oool50000o`030?l000000?l0003o0080003o8@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo000B0?ooo`030000003oool0oooo0:`0
oooo10000?l00`3o0000003o0000o`020000ob40oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02L0
oooo000B0?ooo`030000003oool0oooo0:`0oooo2@000?lQ0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0V0?ooo`004P3oool00`000000oooo0?ooo`2]0?ooo`L0003o8P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:`0oooo1`000?lR
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?oo
o`3oool0[P3oool30000obD0oooo1000000>0?ooo`D00000103oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo02@0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo000D0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`050000
003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280
oooo000D0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0R0?ooo`005@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool03`3oool00`000000oooo0000000U0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00l0oooo0P00000V0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00l0oooo0P00000U0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool07`3oool001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000008@3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01h0oooo000F0?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
01h0oooo000G0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo01d0oooo000G0?ooo`030000003oool0oooo0:D0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01`0oooo
000H0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo01/0oooo000H0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo000I0?oo
o`030000003oool0oooo0:80oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`030?oo
o`800?l0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo04H0oooo00@000000?ooo`3oool0oooo1P00o`02000000l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1J0?ooo`8000006@3oool001X0oooo00<000000?ooo`3o
ool0X03oool00`000000oooo0?ooo`0m0?ooo`L000000`3oool010000000oooo0?ooo`3oool6003o
0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
01H0oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00P00?l04P3oool2000000l0oooo0P00001Q0?ooo`03
0000003oool0oooo01D0oooo000J0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P00?l0503oool2000000X0oooo
0`00001T0?ooo`8000005@3oool001/0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00@0oooo10000006003o01L0oooo2P00001Y0?ooo`H000003`3o
ool001`0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool0oooo1P00o`2O0?ooo`007@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`800?l0X@3oool001d0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001h0oooo00<000000?ooo`3o
ool0V@3oool00`000000oooo0?ooo`110?ooo`<00000[`3oool001l0oooo00<000000?ooo`3oool0
UP3oool2000004H0oooo00<000000?ooo`3oool0[@3oool001l0oooo00<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`3f0?ooo`00803oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo0?H0oooo000Q0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0m`3oool00280
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`3g0?ooo`008P3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo0?P0oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0n@3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0?X0oooo000U0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool0n`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`3l0?ooo`009`3oool2000008L0oooo00<000000?ooo`3oool0o@3o
ool002P0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`3n0?ooo`00:@3oool00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo0?l0oooo000Z0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0o`3oool10?ooo`00:`3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo0?l0oooo0@3oool002`0oooo0P00001m0?ooo`800000o`3oool40?ooo`00;@3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0?l0oooo103oool002h0oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`3o0?ooo`D0oooo000_0?ooo`800000MP3oool200000?l0
oooo203oool00340oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?ooo`P0oooo
000b0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3oool80?ooo`00<`3oool2
000006l0oooo0P00003o0?ooo`/0oooo000e0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0o`3oool;0?ooo`00=P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0
oooo303oool003L0oooo00<000000?ooo`3oool0IP3oool200000?l0oooo3`3oool003P0oooo0P00
001T0?ooo`800000o`3ooolA0?ooo`00>P3oool200000600oooo0P00003o0?oooa<0oooo000l0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00?@3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo503oool003h0oooo0P00001H0?ooo`800000
o`3ooolG0?ooo`00@03oool3000005<0oooo0P00003o0?oooaT0oooo00130?ooo`800000C`3oool2
00000?l0oooo6`3oool004D0oooo0P00001;0?ooo`800000o`3ooolM0?ooo`00A`3oool2000004L0
oooo0P00003o0?oooal0oooo00190?ooo`@00000?P3oool500000?l0oooo8@3oool004d0oooo0P00
000j0?ooo`800000o`3ooolV0?ooo`00C`3oool3000003D0oooo0P00003o0?ooobP0oooo001B0?oo
o`@00000;03oool500000?l0oooo:P3oool005H0oooo1@00000S0?ooo`@00000o`3oool_0?ooo`00
F`3oool7000001D0oooo1`00003o0?oooc<0oooo001R0?oooaD00000o`3ooolj0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.91239 .7381 Mdot
.5 Mabswid
.5 .5 m
.91239 .7381 L
s
0 1 0 r
.5 .5 m
.91239 .5 L
s
1 0 0 r
.91239 .7381 m
.91239 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.10317 .56389 Mdot
1 0 0 r
.10317 .45617 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`1J0?oooe000?l000<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0g0?oooj8000002`3o
ool000l0oooo00<000000?ooo`3oool0F`3oool20000odd0oooo00<0o`000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo
0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`003`3oool00`000000oooo0?ooo`1M0?ooo`80003oB`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000003oool0oooo03/0oooo0P00000S0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`1O0?ooo`03
0000o`3oool0oooo04P0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0k0?ooo`80
00008P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0<P3oool000l0oooo00<000000?ooo`3oool0H03oool20000odP0oooo00<0o`000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000?0?ooo`030000003o
ool0oooo0680oooo0P000?m60?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0000000P0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`1T0?ooo`80003oA03oool0
0`3o0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03o
ool000l0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`110?ooo`030?l0003oool0
oooo00T0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000N0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool0
0`000000oooo0?ooo`1W0?ooo`80003o@@3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0
oooo03`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`1Y
0?ooo`80003o?`3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00D00000
0?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0
oooo03`0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0J`3oool20000
oc`0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0K@3oool20000ocX0
oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0K`3oool00`000?l0oooo
0?ooo`0g0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo02d0oooo000@0?ooo`030000003oool0oooo0700oooo0P00
0?lg0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo02`0oooo000@0?ooo`030000003oool0oooo0780oooo0P000?le
0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02`0oooo000@0?ooo`030000003oool0oooo07@0oooo0P000?lc0?oo
o`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02/0oooo000@0?ooo`030000003oool0oooo07H0oooo00<0003o0?ooo`3o
ool0<03oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0[0?ooo`004@3oool00`000000oooo0?ooo`1f0?ooo`80003o
<03oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`1h0?ooo`80003o;P3o
ool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`1j0?ooo`030000o`3oool0
oooo02/0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`@000001P3oool2
000000H0oooo100000050?ooo`030000003oool0oooo00P0oooo00<000000?l0003o00003@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:@3oool0
0140oooo00<000000?ooo`3oool0N`3oool20000ob/0oooo00<0o`000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo1P3o000;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`1m0?ooo`80003o:@3oool00`3o0000
oooo0?ooo`070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool60?l000X0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0
oooo000B0?ooo`030000003oool0oooo07h0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo
0?ooo`070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool80?l000T0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo
000B0?ooo`030000003oool0oooo07l0oooo0P000?lV0?ooo`030?l0003oool0oooo00H0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool2000000L0oooo203o00080?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo0?ooo`21
0?ooo`80003o903oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`07
0?ooo`H0o`00203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool09P3oool00180oooo00<000000?ooo`3oool0P`3oool20000ob80oooo00<0o`000?oo
o`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo1P3o00080?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0U0?oo
o`004`3oool00`000000oooo0?ooo`240?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo0P3o00000`3oool0
00000?ooo`060?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`250?ooo`80003o7`3oool00`3o0000oooo
0?ooo`050?ooo`030000003oool0oooo02D0oooo1000000>0?ooo`D00000103oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo02@0oooo000C0?ooo`030000003oool0oooo08L0oooo0P00
0?lM0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo02<0oooo000D0?ooo`030000003oool0oooo08P0oooo00<0003o
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`290?ooo`80003o6P3oool0
0`3o0000oooo0?ooo`040?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
10000000oooo0?ooo`00000V0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3o
ool001D0oooo00<000000?ooo`3oool0RP3oool20000oaP0oooo00<0o`000?ooo`3oool0103oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000009@3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo0240oooo000E0?ooo`030000003oool0oooo
08`0oooo0P000?lF0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0?0?ooo`8000009P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0200oooo000E0?ooo`030000003oool0oooo08h0oooo00<0003o0?ooo`3oool04`3oool00`3o0000
oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo
0?ooo`2?0?ooo`80003o4`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0T03oool20000oa40oooo
00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo
00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool07P3oool001H0oooo00<000000?ooo`3oool0TP3oool00`000?l0oooo0?ooo`0>0?ooo`050?l0
003oool0oooo0?ooo`000000AP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01h0
oooo000G0?ooo`030000003oool0oooo0980oooo0P000?l>0?ooo`050?l0003oool0oooo0?ooo`00
0000AP3oool00`000000oooo0?ooo`090?ooo`800?l000<0oooo0000003oool01@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo
00<000000?ooo`3oool0U03oool20000o``0oooo00@0o`000?ooo`3oool00000A`3oool00`000000
oooo0?ooo`070?ooo`H00?l01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool0703oool001P0oooo00<000000?ooo`3oool0U@3oool00`000?l0oooo
0?ooo`090?ooo`040?l0003oool0oooo000004L0oooo00<000000?ooo`3oool01`3oool6003o00P0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01/0
oooo000H0?ooo`030000003oool0oooo09H0oooo0P000?l90?ooo`040?l0003oool0oooo000004L0
oooo00<000000?ooo`3oool01P3oool8003o00P0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo09L0oooo
0P000?l70?ooo`030?l0003oool0000004P0oooo00<000000?ooo`3oool01P3oool8003o00T0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01T0oooo
000I0?ooo`030000003oool0oooo09T0oooo0P000?l40?ooo`040000o`3o0000003o000004P0oooo
00<000000?ooo`3oool01`3oool6003o00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`1J0?ooo`8000006@3oool001X0oooo00<000000?ooo`3oool0VP3oool00`000?l0oooo0000
o`020000o`040?l000000?l0003o0000ocd0oooo1`0000030?ooo`030000003oool0oooo00H0oooo
00<00000003o0000o`001000o`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`2K0?ooo`@0003o00@0
o`000000o`000?l0003o@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool0oooo0P00o`0?0?ooo`8000003`3oool200000640oooo00<000000?ooo`3o
ool05@3oool001X0oooo00<000000?ooo`3oool0V`3oool40000o`030?l000000?l0003o0080003o
?`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`800000
2P3oool3000006@0oooo0P00000E0?ooo`006`3oool00`000000oooo0?ooo`2J0?ooo`@0003o00<0
o`000000o`000?l00P000?lo0?ooo`030000003oool0oooo00@0oooo1P00000K0?ooo`X00000J@3o
ool6000000l0oooo000L0?ooo`030000003oool0oooo09T0oooo2@000?lo0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0YP3oool001d0oooo00<000000?ooo`3oool0V@3oool70000
od00oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool00`000000
oooo0?ooo`2I0?ooo`L0003o@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0
oooo000N0?ooo`030000003oool0oooo09T0oooo00@000000000o`000?l0003o@03oool300000:l0
oooo000O0?ooo`030000003oool0oooo09H0oooo0P0000160?ooo`030000003oool0oooo0:d0oooo
000O0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0mP3oool00200oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0?L0oooo000R0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0m`3oool00280oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?/0
oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0o03oool002L0oooo0P00
00270?ooo`030000003oool0oooo0?d0oooo000X0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0oP3oool002T0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?oo
o`00:P3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000O@3o
ool200000?l0oooo103oool002d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o
0?ooo`@0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0o`3oool50?oo
o`00;`3oool2000007H0oooo0P00003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0o`3oool80?ooo`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo0?l0oooo203oool003<0oooo0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`3o0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo
0P00003o0?ooo`l0oooo000h0?ooo`800000I03oool200000?l0oooo4@3oool003X0oooo0P00001P
0?ooo`800000o`3ooolC0?ooo`00?03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
0?l0oooo4`3oool003d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0
oooo000n0?ooo`800000F03oool200000?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3o
oolI0?ooo`00@`3oool2000004l0oooo0P00003o0?oooa/0oooo00150?ooo`800000B`3oool20000
0?l0oooo7@3oool004L0oooo0P0000170?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo
1@00003o0?ooob40oooo001=0?ooo`800000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e
0?ooo`800000o`3ooolX0?ooo`00DP3oool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D0
00008`3oool400000?l0oooo;`3oool005/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3o
oolE00000?l0oooo>P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.83672 .83672 Mdot
.5 Mabswid
.5 .5 m
.83672 .83672 L
s
0 1 0 r
.5 .5 m
.83672 .5 L
s
1 0 0 r
.83672 .83672 m
.83672 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.14286 .51712 Mdot
1 0 0 r
.14286 .51712 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`1J0?oood400?l000<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0g0?oooj8000002`3o
ool000l0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0m0?ooo`030?l0003oool0
oooo01T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool0
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P00
0000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool000l0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0l0?oo
o`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool0>`3oool2000002<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`03
0000003oool0oooo05d0oooo00<0003o0?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0I0?ooo`03
0000003oool0oooo03/0oooo0P00000R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`1N0?ooo`030000
o`3oool0oooo03X0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0l0?ooo`030000
003oool000000240oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0340oooo000?0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool0>@3o
ool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`000000803o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0<@3o
ool000l0oooo00<000000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0h0?ooo`030?l0003oool0
oooo01P0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000O0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool0
0`000000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo03L0oooo00<0o`000?ooo`3oool0603oool0
0`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003oool0
oooo0680oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0
oooo03`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`1S
0?ooo`030000o`3oool0oooo03D0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0l
0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool0I03oool0
0`000?l0oooo0?ooo`0d0?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo000@0?ooo`030000003oool0oooo
06@0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000
oooo0?ooo`1U0?ooo`030000o`3oool0oooo0380oooo00<0o`000?ooo`3oool0603oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo
00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo01P0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02d0oooo
000@0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?oo
o`0H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0/0?ooo`00403oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo02l0oooo00<0o`00
0?ooo`3oool05`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0^0?oo
o`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02/0oooo000@0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3o
ool0;@3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0[0?ooo`004@3oool00`000000oooo0?ooo`1Z0?ooo`030000
o`3oool0oooo02`0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000003oool0
oooo06`0oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0
oooo02<0oooo100000060?ooo`8000001P3oool4000000D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo
02T0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0:@3oool00140
oooo00<000000?ooo`3oool0KP3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo01H0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0
oooo000B0?ooo`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo
0?ooo`0F0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`1_0?ooo`030000o`3oool0oooo02H0oooo00<0
o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0W0?ooo`004P3oool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo02D0oooo00<0o`00
0?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0V
0?ooo`004P3oool00`000000oooo0?ooo`1a0?ooo`030000o`3oool0oooo02@0oooo00<0o`000?oo
o`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool09@3oool001<0oooo00<000000?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo01@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0780oooo00<0003o0?ooo`3oool0
8P3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo02D0oooo1000000>0?ooo`D00000
103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02@0oooo000C0?ooo`030000003o
ool0oooo07<0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0S0?ooo`00503oool0
0`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool0503oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo00D000000?l0003o0000oooo0000
000U0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001@0oooo00<00000
0?ooo`3oool0M03oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo01<0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0=0?ooo`H0o`009@3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo07@0oooo00<0003o0?oo
o`3oool07P3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool03@3oool60?l002@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0Q0?oo
o`005@3oool00`000000oooo0?ooo`1d0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3o
ool04P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00`0oooo203o000S0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0
M@3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0<0?ooo`P0o`008P3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo01l0oooo000E0?ooo`030000003oool0oooo07H0oooo00<0003o0?ooo`3oool0703o
ool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03@3o
ool60?l00280oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0O0?ooo`005P3oool0
0`000000oooo0?ooo`1f0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool04@3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00d0oooo1P3o000Q0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool07P3oool001H0oooo00<000000?ooo`3oool0M`3oool00`00
0?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0=0?ooo`040000003oool0o`000?l00080oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01h0oooo000G0?ooo`030000003oool0oooo
07L0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0M0?ooo`005`3oool00`000000
oooo0?ooo`1h0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool03`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0703oool001P0oooo
00<000000?ooo`3oool0N03oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo00l0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01/0oooo
000H0?ooo`030000003oool0oooo07T0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?oo
o`0?0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0J0?ooo`006@3oool00`000000oooo0?ooo`1i0?ooo`030000o`3oool0oooo01D0oooo00<0o`00
0?ooo`3oool03P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0NP3oool00`000?l0oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`070?oo
o`8000003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo0P00000I0?oo
o`006P3oool00`000000oooo0?ooo`1j0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0m0?ooo`L000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo01H0oooo000J0?ooo`030000003oool0oooo07/0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo0P00000?0?ooo`800000
H@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`000000oooo0?ooo`1l0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000001L0oooo0P00000:0?ooo`<00000I03o
ool2000001D0oooo000K0?ooo`030000003oool0oooo07`0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool6
000001/0oooo2P00001Y0?ooo`H000003`3oool001`0oooo00<000000?ooo`3oool0O03oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo07`0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool00`000000oooo
0?ooo`1m0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001h0oooo00<0
00000?ooo`3oool0O@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0
00000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`030000003oool0oooo07d0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`080?ooo`800000AP3oool00`000000oooo0?ooo`2]
0?ooo`007`3oool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool01`3oool00`000000oooo0?ooo`3f0?ooo`00803oool00`000000oooo0?ooo`1n0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`3f0?ooo`00
8@3oool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
1P3oool00`000000oooo0?ooo`3g0?ooo`008P3oool00`000000oooo0?ooo`1n0?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`3g0?ooo`008P3oool0
0`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`3i0?ooo`00903oool00`000000
oooo0?ooo`1o0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000000
oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?oo
o`200?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?oo
o`3k0?ooo`009P3oool00`000000oooo0?ooo`200?ooo`060000o`3oool0oooo0000o`3o0000003o
0P3oool00`000000oooo0?ooo`3l0?ooo`009`3oool200000840oooo0`000?l0103o0000003o0000
o`000?oo0?ooo`00:03oool00`000000oooo0?ooo`1o0?ooo`<0003o00@0o`000000o`000?l0003o
o`3oool002T0oooo00<000000?ooo`3oool0O@3oool40000o`030?l000000?l0003o0080003ooP3o
ool002X0oooo00<000000?ooo`3oool0O03oool40000o`030?l000000?l0003o0080003ooP3oool0
02/0oooo00<000000?ooo`3oool0N`3oool90000ooh0oooo000/0?ooo`800000O03oool70000ool0
oooo000]0?ooo`030000003oool0oooo07X0oooo1`000?oo0?ooo`00;P3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00<0003oo`3oool20?ooo`00;`3oool2000007H0oooo0P00003o
0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3oool80?oo
o`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool003<0oooo
0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3o
0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo0P00003o0?ooo`l0oooo000h0?ooo`80
0000I03oool200000?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000o`3ooolC0?ooo`00?03o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3oool003d0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?ooo`800000F03oool20000
0?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00@`3oool2000004l0oooo
0P00003o0?oooa/0oooo00150?ooo`800000B`3oool200000?l0oooo7@3oool004L0oooo0P000017
0?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo1@00003o0?ooob40oooo001=0?ooo`80
0000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000o`3ooolX0?ooo`00DP3o
ool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool400000?l0oooo;`3oool0
05/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0oooo>P3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.7381 .91239 Mdot
.5 Mabswid
.5 .5 m
.7381 .91239 L
s
0 1 0 r
.5 .5 m
.7381 .5 L
s
1 0 0 r
.7381 .91239 m
.7381 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.18254 .45617 Mdot
1 0 0 r
.18254 .56389 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`1J0?ooobh00?l000<0o`000?ooo`3oool0;03oool00`000000oooo0?ooo`0g0?oooj8000002`3o
ool000l0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0
oooo02`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool0
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P00
0000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool000l0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0Z0?oo
o`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0>`3oool2000002<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`03
0000003oool0oooo05`0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0/0?ooo`03
0000003oool0oooo03/0oooo0P00000R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`1L0?ooo`030000
o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool000000240oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0340oooo000?0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`000000803o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0<@3o
ool000l0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0
oooo02/0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000O0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool0
0`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003oool0
oooo05l0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0
oooo03`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`1O
0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0l
0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool0H03oool0
0`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo000@0?ooo`030000003oool0oooo
05l0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000
oooo0?ooo`1P0?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo
00<000000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo02/0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02d0oooo
000@0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`3oool08`3oool00`3o0000oooo0?oo
o`0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0/0?ooo`00403oool00`000000oooo0?ooo`1R0?ooo`030000o`3oool0oooo0280oooo00<0o`00
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0R0?oo
o`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02/0oooo000@0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0[0?ooo`004@3oool00`000000oooo0?ooo`1R0?ooo`030000
o`3oool0oooo0240oooo00<0o`000?ooo`3oool0:P3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0H`3o
ool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000003oool0
oooo06<0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02<0oooo100000060?ooo`8000001P3oool4000000D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0;0?ooo`800?l000<000000?ooo`3oool0903oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo02T0oooo000A0?ooo`030000003oool0oooo06@0oooo00<0003o0?oo
o`3oool07`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`H00?l0903oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02T0oooo000A0?ooo`03
0000003oool0oooo06@0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`H0
0?l08`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo000B0?ooo`030000
003oool0oooo06@0oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`P00?l0
8P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo000B0?ooo`030000003o
ool0oooo06D0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00H0oooo2000o`0Q0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool09`3oool00180oooo00<000000?ooo`3oool0I@3oool0
0`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo02P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo100000050?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01P3oool6003o0240oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0V0?ooo`004P3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo
01`0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01P3oool6003o0240oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo01`0
oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool010000000oooo003o0000o`0R0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool0IP3oool00`000?l0
oooo0?ooo`0K0?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool09@3oool4000000h0
oooo1@0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo
00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo02L0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo
000D0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?oo
o`0W0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool01@000000oooo0?oo
o`3oool0000002D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0R0?ooo`00503o
ool00`000000oooo0?ooo`1W0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool09P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000
9P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003o
ool0oooo06H0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000U0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool0I`3oool0
0`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0?0?ooo`8000009P3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0200oooo000E0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`0U0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool20000
02D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000
oooo0?ooo`1X0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0903oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000008`3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003oool0oooo06L0
oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000240oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`1X0?ooo`03
0000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0
J03oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3o000K0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo00<0
00000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo0280oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo1P3o
000H0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0703oool001P0oooo00<00000
0?ooo`3oool0J03oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0280oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo1P3o000G
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06`3oool001P0oooo00<000000?oo
o`3oool0J03oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0280oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo203o000E0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3o
ool0J03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo203o000D0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0
J03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`070?ooo`8000002`3oool60?l001@0oooo00<000000?ooo`3oool0
FP3oool2000001T0oooo000J0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo03d0oooo1`0000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02`3oool60?l001<0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0803oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`80o`000P3oool2
000000l0oooo0P00001Q0?ooo`030000003oool0oooo01D0oooo000J0?ooo`030000003oool0oooo
06T0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000005`3oool20000
00X0oooo0`00001T0?ooo`8000005@3oool001/0oooo00<000000?ooo`3oool0J@3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`040?ooo`H000006`3oool:000006T0oooo1P00000?0?ooo`00703oool00`000000oooo
0?ooo`1X0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool07P3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001d0oooo00<0
00000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01h0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M
0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0M
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V
0?ooo`007P3oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool07@3oool00`000000oooo0?ooo`110?ooo`<00000[`3oool001l0oooo00<000000?ooo`3o
ool0J03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01/0oooo0P0000160?ooo`03
0000003oool0oooo0:d0oooo000O0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo0?H0oooo000P0?ooo`030000003o
ool0oooo06P0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000003oool0oooo
06L0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo
0?L0oooo000R0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0H0?ooo`030000003oool0oooo0?P0oooo000S0?ooo`030000003oool0oooo06L0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo0?T0oooo
000T0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0F0?ooo`030000003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo06H0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo0?X0oooo000U0?oo
o`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0E0?oo
o`030000003oool0oooo0?/0oooo000V0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo0?`0oooo000W0?ooo`800000
I`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool0
o@3oool002P0oooo00<000000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo0180oooo00<000000?ooo`3oool0oP3oool002T0oooo00<000000?ooo`3oool0I@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool0o`3oool0
02X0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
0100oooo00<000000?ooo`3oool0o`3oool10?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooo`40
oooo000/0?ooo`800000I@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00h0oooo
0P00003o0?ooo`@0oooo000]0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo103oool002h0oooo00<00000
0?ooo`3oool0H`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`00;`3oool2000006<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0:0?ooo`800000o`3oool80?ooo`00<@3oool00`000000oooo0?ooo`1Q0?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`P0
oooo000b0?ooo`030000003oool0oooo0600oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`090?ooo`030000003oool0oooo0?l0oooo203oool003<0oooo0P00001Q0?ooo`050000o`3o
ool0oooo0?ooo`3o00002@3oool200000?l0oooo2`3oool003D0oooo00<000000?ooo`3oool0G`3o
ool010000?l0oooo0?ooo`3o00080?ooo`030000003oool0oooo0?l0oooo2`3oool003H0oooo00<0
00000?ooo`3oool0GP3oool010000?l0oooo0?ooo`3o00070?ooo`030000003oool0oooo0?l0oooo
303oool003L0oooo00<000000?ooo`3oool0GP3oool20000o`030?l000000?l0oooo00<0oooo0P00
003o0?ooo`l0oooo000h0?ooo`800000G@3oool30000o`040?l000000?l0003o0000o`800000o`3o
oolA0?ooo`00>P3oool2000005/0oooo0`000?l0103o0000003o0000o`000?oo0?oooa<0oooo000l
0?ooo`030000003oool0oooo05L0oooo10000?l00`3o0000003o0000o`020000ool0oooo4P3oool0
03d0oooo00<000000?ooo`3oool0EP3oool40000o`030?l000000?l0003o0080003oo`3ooolB0?oo
o`00?P3oool2000005H0oooo2@000?oo0?oooa80oooo00100?ooo`<00000D`3oool00`000000003o
0000o`050000ool0oooo4`3oool004<0oooo0P00001?0?ooo`80000000<0oooo0000o`000?l01@00
0?oo0?oooa<0oooo00150?ooo`800000B`3oool2000000D0oooo0`000?oo0?oooaD0oooo00170?oo
o`800000A`3oool200000?l0oooo7`3oool004T0oooo1000000n0?ooo`D00000o`3ooolQ0?ooo`00
C@3oool2000003X0oooo0P00003o0?ooobH0oooo001?0?ooo`<00000=@3oool200000?l0oooo:03o
ool00580oooo1000000/0?ooo`D00000o`3ooolZ0?ooo`00EP3oool5000002<0oooo1000003o0?oo
obl0oooo001K0?ooo`L000005@3oool700000?l0oooo<`3oool00680oooo5@00003o0?ooocX0oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.62325 .95996 Mdot
.5 Mabswid
.5 .5 m
.62325 .95996 L
s
0 1 0 r
.5 .5 m
.62325 .5 L
s
1 0 0 r
.62325 .95996 m
.62325 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.22222 .38519 Mdot
1 0 0 r
.22222 .59329 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`1J0?oooaP00?l000<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0g0?oooj8000002`3o
ool000l0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0
oooo0480oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool0
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P00
0000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool000l0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0D0?oo
o`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0>`3oool2000002<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`03
0000003oool0oooo05/0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`120?ooo`03
0000003oool0oooo03/0oooo0P00000R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`1K0?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool000000240oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0340oooo000?0?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo03`0oooo00<000000?ooo`000000803o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0<@3o
ool000l0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo0440oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000O0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool0
0`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003oool0
oooo05`0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0
oooo03`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`1L
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l
0?ooo`050000003oool0oooo0?ooo`0000006P3oool2003o00030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`1M
0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool6003o02@0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000oooo0?ooo`1L0?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool6003o02@0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000oooo0?ooo`1L0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool8003o0280oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`1L0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool8003o0280oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`1M0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04`3oool6003o0280oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool04P3oool6003o0280oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04`3oool00`0000000?l0003o000S0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3oool0GP3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo02/0oooo000A0?ooo`030000003oool0oooo05d0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?oo
o`1M0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<00000
0?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo03l0oooo00<00000
0?ooo`3oool08`3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo02T0oooo000A0?ooo`030000003oool0oooo05h0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Y0?oo
o`004@3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0:03oool00180oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo03l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo02P0oooo000B0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo02L0oooo000B0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo02H0oooo000B0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0n0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool09@3oool4000000h0oooo
1@0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo00<0
00000?ooo`3oool0GP3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo03d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo000D
0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0m
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3o
ool0000002D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0R0?ooo`00503oool0
0`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0?03oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000009P3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0
oooo05d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000U0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool0G@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0?0?ooo`8000009P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0200oooo000E0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0k0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo
0?ooo`1M0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000008`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003oool0oooo05d0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`1M0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0G03o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01d0oooo000G0?ooo`030000003oool0
oooo05`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0L0?ooo`00603oool00`00
0000oooo0?ooo`1L0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0>03oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06`3oool001P0
oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo03P0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0
oooo000I0?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0g0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P3o000A0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo03L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`070?ooo`8000003`3oool00`000000oooo0?l000050?l000h0oooo00<000000?ooo`3oool0FP3o
ool2000001T0oooo000J0?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo03d0oooo1`0000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0403oool00`000000o`000?l000040?l000d0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`1K0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?oo
o`P0o`002P3oool200000640oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?ooo`3o
ool0F`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000D0?ooo`P0
o`001`3oool3000006@0oooo0P00000E0?ooo`006`3oool00`000000oooo0?ooo`1K0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0=@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00@0oooo1P00000G0?ooo`H0o`002000001Y0?ooo`H000003`3oool001`0oooo00<0
00000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo03@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo1P3o
00260?ooo`007@3oool00`000000oooo0?ooo`1I0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0=03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0703oool20?l008P0oooo000M0?ooo`030000003oool0oooo05T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007P3oool00`000000oooo0?ooo`1I0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`110?ooo`<0
0000[`3oool001l0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo0340oooo0P0000160?ooo`030000003oool0oooo0:d0oooo000O0?ooo`030000003o
ool0oooo05P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0`0?ooo`030000003o
ool0oooo0?H0oooo000P0?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo
05L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo
0?L0oooo000R0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0_0?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000003oool0oooo05H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo0?P0oooo
000S0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0]0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo05D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0/0?ooo`030000003oool0oooo0?X0oooo000U0?oo
o`030000003oool0oooo05@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0/0?oo
o`030000003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo05@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo0?/0oooo000V0?ooo`030000
003oool0oooo05@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0?`0oooo000W0?ooo`800000E03oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo02T0oooo00<000000?ooo`3oool0o@3oool002P0oooo00<000000?ooo`3oool0DP3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo02P0oooo00<000000?ooo`3oool0oP3oool0
02T0oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
02L0oooo00<000000?ooo`3oool0o`3oool002X0oooo00<000000?ooo`3oool0D@3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool0o`3oool10?ooo`00
:`3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
9P3oool00`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000D03oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo02@0oooo0P00003o0?ooo`@0oooo000]0?ooo`030000003oool0
oooo04h0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0
oooo0?l0oooo103oool002h0oooo00<000000?ooo`3oool0CP3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0280oooo00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool2000004h0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0P0?ooo`800000o`3oool80?ooo`00
<@3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
7`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000b0?ooo`030000003oool0oooo04X0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo203o
ool003<0oooo0P00001;0?ooo`050000o`3oool0oooo0?ooo`3o00007`3oool200000?l0oooo2`3o
ool003D0oooo00<000000?ooo`3oool0B03oool01@000?l0oooo0?ooo`3oool0o`0001h0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`00=P3oool00`000000oooo0?ooo`170?ooo`050000o`3oool0
oooo0?ooo`3o00007@3oool00`000000oooo0?ooo`3o0?ooo``0oooo000g0?ooo`030000003oool0
oooo04L0oooo00@0003o0?ooo`3oool0o`006`3oool200000?l0oooo3`3oool003P0oooo0P000017
0?ooo`040000o`3oool0oooo0?l001T0oooo0P00003o0?oooa40oooo000j0?ooo`800000A@3oool0
10000?l0oooo0?ooo`3o000G0?ooo`800000o`3ooolC0?ooo`00?03oool00`000000oooo0?ooo`12
0?ooo`040000o`3oool0oooo0?l001H0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00?@3oool0
0`000000oooo0?ooo`120?ooo`030000o`3oool0o`0001D0oooo00<000000?ooo`3oool0o`3ooolD
0?ooo`00?P3oool200000480oooo00<0003o0?ooo`3o00004`3oool200000?l0oooo5`3oool00400
oooo0`00000o0?ooo`030000o`3oool0o`000140oooo0P00003o0?oooaT0oooo00130?ooo`800000
?@3oool00`000?l0oooo0?l0000?0?ooo`800000o`3ooolK0?ooo`00A@3oool2000003`0oooo00<0
003o0?l0003oool0303oool200000?l0oooo7@3oool004L0oooo0P00000i0?ooo`80003o00<0o`00
0?ooo`3oool02@3oool200000?l0oooo7`3oool004T0oooo1000000c0?ooo`@0003o00<0o`000000
o`000?l0103oool500000?l0oooo8@3oool004d0oooo0P00000a0?ooo`@0003o00<0o`000000o`00
0?l00P3oool200000?l0oooo9P3oool004l0oooo0`00000]0?ooo`D0003o00D0o`000000o`000?l0
003o0000003o0?ooobP0oooo001B0?ooo`@00000:@3oool50000o`040?l000000?l0003o0000ool0
oooo:@3oool005H0oooo1@00000S0?ooo`03000000000?l0003o00L0003oo`3ooolY0?ooo`00F`3o
ool7000001D0oooo1`0000020?ooo`L0003oo`3ooolZ0?ooo`00HP3ooolE000000T0oooo1`000?oo
0?ooobX0oooo00220?ooo`<0003oo`3oool/0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.5 .97619 Mdot
.5 Mabswid
.5 .5 m
.5 .97619 L
s
0 1 0 r
.5 .5 m
.5 .5 L
s
1 0 0 r
.5 .97619 m
.5 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.2619 .30902 Mdot
1 0 0 r
.2619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool08P3oool2003o00030?ooo`000000oooo02@0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo000?0?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0P0?ooo`H0
0?l09@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool03`3oool000l0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0200oooo1P00o`0T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`1J0?ooo`030?l0003o
ool0oooo05X0oooo00<000000?ooo`3oool0=`3ooolV000000P00?l0M000000;0?ooo`003`3oool0
0`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo05X0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`P00?l00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool000l0oooo00<000000?ooo`3oool0FP3oool00`3o0000oooo
0?ooo`1J0?ooo`030000003oool0oooo03/0oooo0P00000Q0?ooo`H00?l08P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo05X0oooo00<0
o`000?ooo`3oool0FP3oool00`000000oooo0?ooo`0k0?ooo`8000008@3oool6003o0280oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`1J
0?ooo`030?l0003oool0oooo05T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0000000Q
0?ooo`0300000000o`000?l002<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0a
0?ooo`003`3oool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo05T0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0000000P0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`1J0?ooo`03
0?l0003oool0oooo05T0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000O0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?oo
o`003`3oool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo05T0oooo00<000000?ooo`3o
ool0?03oool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`1J0?ooo`03
0?l0003oool0oooo05T0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool00000
01d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
02l0oooo000?0?ooo`030000003oool0oooo05X0oooo00<0o`000?ooo`3oool0F@3oool00`000000
oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3o
ool0FP3oool00`3o0000oooo0?ooo`1I0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000oooo0?ooo`1I0?ooo`030?l0
003oool0oooo05T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02h0oooo000@0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3o
ool00100oooo00<000000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`1I0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?ooo`00403oool00`00
0000oooo0?ooo`1I0?ooo`030?l0003oool0oooo05T0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo02`0oooo000@0?ooo`030000003oool0oooo05T0
oooo00<0o`000?ooo`3oool0F03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0F@3oool00`3o0000oooo
0?ooo`1H0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0[0?ooo`00403oool00`000000oooo0?ooo`1I0?ooo`030?l0003oool0oooo05P0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02/0oooo000A
0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool0F03oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?oo
o`3oool0F03oool00`3o0000oooo0?ooo`1H0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`1H0?ooo`03
0?l0003oool0oooo05L0oooo00<000000?ooo`3oool08`3oool4000000H0oooo0P0000060?ooo`@0
00001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02T0oooo000A0?ooo`030000
003oool0oooo05P0oooo00<0o`000?ooo`3oool0E`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
:@3oool00140oooo00<000000?ooo`3oool0F03oool00`3o0000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0X0?ooo`004P3oool0
0`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo05L0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo000B0?ooo`030000003oool0oooo
05L0oooo00<0o`000?ooo`3oool0EP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo05H0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo100000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool09P3oool00180oooo
00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`1F0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0U0?ooo`@000003P3oool5000000@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0T0?ooo`004`3oool00`000000oooo0?ooo`1F0?oo
o`030?l0003oool0oooo05D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo02<0oooo000D0?ooo`030000003oool0oooo05D0oooo00<0o`000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3o
ool0oooo0000000U0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001@0
oooo00<000000?ooo`3oool0E@3oool00`3o0000oooo0?ooo`1D0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?ooo`3oool0E03oool00`3o0000
oooo0?ooo`1D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03`3oool00`000000
oooo0000000U0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool08@3oool001D0oooo
00<000000?ooo`3oool0E03oool00`3o0000oooo0?ooo`1C0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03`3oool2000002H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`1D0?ooo`030?l0003oool0oooo05<0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`8000009@3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo01l0oooo000E0?ooo`030000003oool0oooo05@0oooo00<0o`00
0?ooo`3oool0DP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool000008`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01l0oooo000F
0?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0DP3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool07P3oool001H0oooo00<000000?ooo`3oool0D`3oool0
0`3o0000oooo0?ooo`1A0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0N0?ooo`005`3oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo
0540oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
01d0oooo000G0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0D03oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0703oool001P0oooo
00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`1@0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0K0?ooo`00603oool00`000000oooo0?oo
o`1A0?ooo`030?l0003oool0oooo0500oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo0500oooo00<0o`00
0?ooo`3oool0C`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`1?0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1J0?ooo`8000006@3oool001X0oooo00<000000?ooo`3o
ool0C`3oool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo03d0oooo1`0000030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`80
o`002@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000
003oool0oooo04l0oooo00<0o`000?ooo`3oool0CP3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`800000
103oool60?l000D0oooo0P00001Q0?ooo`030000003oool0oooo01D0oooo000J0?ooo`030000003o
ool0oooo04l0oooo00<0o`000?ooo`3oool0C@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000001L0oooo0P0000020?ooo`H0o`000P3o
ool3000006@0oooo0P00000E0?ooo`006`3oool00`000000oooo0?ooo`1>0?ooo`030?l0003oool0
oooo04d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`H000006`3oool0
0`000000o`000?l000060?l000030000003oool0oooo06L0oooo1P00000?0?ooo`00703oool00`00
0000oooo0?ooo`1=0?ooo`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo203o001o0?ooo`007@3oool00`000000
oooo0?ooo`1<0?ooo`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0200oooo1P3o00200?ooo`007@3oool00`000000oooo
0?ooo`1<0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0200oooo1P3o00200?ooo`007P3oool00`000000oooo0?oo
o`1;0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O
0?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3oool0B@3oool2000004H0oooo00<00000
0?ooo`3oool0[@3oool001l0oooo00<000000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`180?oo
o`030000003oool0oooo0?H0oooo000P0?ooo`030000003oool0oooo04T0oooo00<0o`000?ooo`3o
ool0B03oool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`180?ooo`030?l0
003oool0oooo04L0oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?ooo`3oool0A`3o
ool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000003oool0
oooo04L0oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`00
0000oooo0?ooo`160?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0n@3oool002@0
oooo00<000000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo0?X0
oooo000U0?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo
0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo04<0oooo00<0
00000?ooo`3oool0n`3oool002H0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`12
0?ooo`030000003oool0oooo0?`0oooo000W0?ooo`800000@`3oool00`3o0000oooo0?ooo`110?oo
o`030000003oool0oooo0?d0oooo000X0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3o
ool0@03oool00`000000oooo0?ooo`3n0?ooo`00:@3oool00`000000oooo0?ooo`100?ooo`030?l0
003oool0oooo03l0oooo00<000000?ooo`3oool0o`3oool002X0oooo00<000000?ooo`3oool0?`3o
ool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo00<00000
0?ooo`3oool0?P3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0oooo0@3oool0
02`0oooo0P00000n0?ooo`030?l0003oool0oooo03`0oooo0P00003o0?ooo`@0oooo000]0?ooo`03
0000003oool0oooo03`0oooo00<0o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`@0
oooo000^0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo
0?ooo`3o0?ooo`D0oooo000_0?ooo`800000>`3oool00`3o0000oooo0?ooo`0h0?ooo`800000o`3o
ool80?ooo`00<@3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo03L0oooo00<00000
0?ooo`3oool0o`3oool80?ooo`00<P3oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo
03L0oooo00<000000?ooo`3oool0o`3oool80?ooo`00<`3oool2000003L0oooo00<0o`000?ooo`3o
ool0=@3oool200000?l0oooo2`3oool003D0oooo00<000000?ooo`3oool0=03oool00`3o0000oooo
0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0<`3o
ool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo303oool003L0oooo00<00000
0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0a0?ooo`800000o`3oool?0?ooo`00>03oool20000
0380oooo00<0o`000?ooo`3oool0;`3oool200000?l0oooo4@3oool003X0oooo0P00000`0?ooo`03
0?l0003oool0oooo02d0oooo0P00003o0?oooa<0oooo000l0?ooo`030000003oool0oooo02d0oooo
00<0o`000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?oooa<0oooo000m0?ooo`030000003o
ool0oooo02`0oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n
0?ooo`800000;03oool00`3o0000oooo0?ooo`0Y0?ooo`800000o`3ooolG0?ooo`00@03oool30000
02T0oooo00<0o`000?ooo`3oool09`3oool200000?l0oooo6@3oool004<0oooo0P00000W0?ooo`03
0?l0003oool0oooo02D0oooo0P00003o0?oooa/0oooo00150?ooo`8000009@3oool00`3o0000oooo
0?ooo`0S0?ooo`800000o`3ooolM0?ooo`00A`3oool2000002<0oooo00<0o`000?ooo`3oool08@3o
ool200000?l0oooo7`3oool004T0oooo1000000O0?ooo`030?l0003oool0oooo01`0oooo1@00003o
0?ooob40oooo001=0?ooo`8000007@3oool00`3o0000oooo0?ooo`0J0?ooo`800000o`3ooolV0?oo
o`00C`3oool3000001P0oooo0P000?l00`3o0000oooo0?ooo`0H0?ooo`800000o`3ooolX0?ooo`00
DP3oool400000180oooo10000?l00`3o0000003o0000o`0C0?ooo`D00000o`3ooolZ0?ooo`00EP3o
ool5000000d0oooo10000?l00`3o0000003o0000o`0?0?ooo`@00000o`3oool_0?ooo`00F`3oool7
000000D0oooo1@000?l0103o0000003o0000o`000?l70?ooo`L00000o`3ooolc0?ooo`00HP3oool5
000000D0003o00@0o`000000o`000?l0003o1`00003o0?ooocX0oooo001W0?ooo`T0003oo`3ooom1
0?ooo`00J03oool70000ool0oooo@P3oool006P0oooo1`000?oo0?oood80oooo001Z0?ooo`<0003o
o`3ooom40?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.37675 .95996 Mdot
.5 Mabswid
.5 .5 m
.37675 .95996 L
s
0 1 0 r
.5 .5 m
.37675 .5 L
s
1 0 0 r
.37675 .95996 m
.37675 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.30159 .23285 Mdot
1 0 0 r
.30159 .59329 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0:@3oool2003o00030?ooo`000000oooo02@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0
oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0W0?ooo`H00?l0903oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo0180oooo1`00000>0?ooo`H00?l00`00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo2000o`000`3oool000000?ooo`0A
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B
0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`P00?l06@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0140oooo00H000000?ooo`3oool000000?ooo`00000D0?ooo`00403oool0
0`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0?0?ooo`H00?l06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo1P0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool2
00000080oooo0P00000D0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`H00?l000<000000?oo
o`3oool05@3oool2000000P0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo00000002
000001D0oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<00000003o0000o`000`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo00H0oooo1000000D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0]P3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000503oool000l0oooo00<00000
0?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01<0oooo0`00000A
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?oo
o`3oool0000001<0oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3o
ool4000001@0oooo100000060?ooo`030000003oool0oooo00h0oooo0P00000<0?ooo`030000003o
ool0oooo00D0oooo1@00000F0?ooo`@000004`3oool000l0oooo00<000000?ooo`3oool0]P3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool0
00l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool000l0oooo
00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool000l0oooo00<00000
0?ooo`3oool0@P3oool00`3o00000?l0003o000F003o05`0oooo00<000000?ooo`3oool0=`3ooonR
000000/0oooo000?0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`1J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`00
0000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo000?0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo03/0oooo0P00000S0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`00
3`3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
F`3oool00`000000oooo0?ooo`0k0?ooo`8000008P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0<P3oool000l0oooo00<000000?ooo`3oool0@P3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0000000Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
00000200oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0340oooo000?0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`1K0?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool0
00l0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
05/0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`00
0000oooo0?ooo`120?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?oo
o`3oool0@P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo05/0oooo00<000000?oo
o`3oool0?03oool01@000000oooo0?ooo`3oool0000001`0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo000?0?ooo`030000003oool0oooo
0480oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000
oooo0?ooo`110?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0G03oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo
00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo05`0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02d0oooo
000@0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`1L0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0]0?ooo`00403oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02`0oooo000@0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0[0?ooo`00403oool00`000000oooo0?ooo`110?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?ooo`3oool0@03o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000003oool0
oooo0400oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`00
0000oooo0?ooo`100?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0G03oool00`00
0000oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0@03oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02T0
oooo000A0?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`1M0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool2000000/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool09`3oool00180oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo100000050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool09P3oool00180oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo05d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`0n0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0U0?ooo`@000003P3o
ool5000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0T0?ooo`004`3oool0
0`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0G@3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool08`3oool0
01@0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
05d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`0000009@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000D0?oo
o`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1L0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000V
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0?03oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo05d0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002D0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`0l0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00l0oooo0P00000V0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0803oool001D0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo05`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`800000
9@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01l0oooo000E0?ooo`030000003o
ool0oooo03`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1K0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0>`3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo01h0oooo000F0?ooo`030000003oool0oooo03/0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0N0?ooo`005`3oool00`000000oooo0?ooo`0j
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo00<000000?oo
o`3oool0>P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo05X0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01`0oooo000H0?ooo`03
0000003oool0oooo03T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`1K0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0K0?ooo`00
603oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
F`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
6P3oool001T0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo05X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool03`3oool20?l000@0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00L0oooo0P00000?0?ooo`030000003oool0oooo00`0oooo1P3o00000`3oool000000?ooo`1K
0?ooo`8000006@3oool001X0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0?@3oool7000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo1P3o00000`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000003oool0oooo03L0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180
oooo0P00000:0?ooo`P0o`00H03oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`000000oooo
0?ooo`0g0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000001L0oooo
0P0000080?ooo`P0o`00H@3oool2000001D0oooo000K0?ooo`030000003oool0oooo03H0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0103oool6000001/0oooo2@0000060?l006@0oooo1P00000?0?ooo`00703oool0
0`000000oooo0?ooo`0e0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0F@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool6
0?l007T0oooo000M0?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`1I0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Y0?ooo`80o`00N`3oool001d0oooo00<000000?ooo`3oool0=03oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000N0?ooo`030000003oool0oooo03<0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0oooo0440oooo
0`00002_0?ooo`007`3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool0E`3oool2000004H0oooo00<000000?ooo`3oool0[@3oool001l0oooo00<00000
0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo05H0oooo00<00000
0?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0mP3oool00240oooo00<000000?ooo`3o
ool0<03oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3o
ool0m`3oool00280oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo05H0oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?ooo`3oool0;`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool0n03o
ool002<0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo05@0oooo00<000000?ooo`3oool0n@3oool002@0oooo00<000000?ooo`3oool0;@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool0nP3oool002D0
oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo05@0
oooo00<000000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0;03oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0n`3oool002H0oooo00<0
00000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo05<0oooo00<0
00000?ooo`3oool0o03oool002L0oooo0P00000[0?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0DP3oool00`000000oooo0?ooo`3m0?ooo`00:03oool00`000000oooo0?ooo`0Y0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`3n0?oo
o`00:@3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0D03oool00`000000oooo0?ooo`3o0?ooo`00:P3oool00`000000oooo0?ooo`0W0?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?ooo`40oooo
000[0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`1@0?ooo`030000003oool0oooo0?l0oooo0@3oool002`0oooo0P00000V0?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0CP3oool200000?l0oooo103oool002d0oooo00<000000?oo
o`3oool0903oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo04d0oooo00<000000?oo
o`3oool0o`3oool40?ooo`00;P3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo000_0?ooo`800000
8`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo04/0oooo0P00003o0?ooo`P0oooo
000a0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1:0?ooo`030000003oool0oooo0?l0oooo203oool00380oooo00<000000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0o`3oool8
0?ooo`00<`3oool2000001l0oooo00D0o`000?ooo`3oool0oooo0000o`1;0?ooo`800000o`3oool;
0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`050?l0003oool0oooo0?ooo`000?l0BP3oool0
0`000000oooo0?ooo`3o0?ooo`/0oooo000f0?ooo`030000003oool0oooo01/0oooo00D0o`000?oo
o`3oool0oooo0000o`190?ooo`030000003oool0oooo0?l0oooo303oool003L0oooo00<000000?oo
o`3oool06P3oool0103o0000oooo0?ooo`000?m80?ooo`800000o`3oool?0?ooo`00>03oool20000
01X0oooo00@0o`000?ooo`3oool0003oAP3oool200000?l0oooo4@3oool003X0oooo0P00000H0?oo
o`040?l0003oool0oooo0000od@0oooo0P00003o0?oooa<0oooo000l0?ooo`030000003oool0oooo
01D0oooo00@0o`000?ooo`3oool0003o@`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000m0?oo
o`030000003oool0oooo01@0oooo00<0o`000?ooo`000?l0@`3oool00`000000oooo0?ooo`3o0?oo
oa@0oooo000n0?ooo`800000503oool00`3o0000oooo0000o`110?ooo`800000o`3ooolG0?ooo`00
@03oool300000140oooo00<0o`000?ooo`000?l0?`3oool200000?l0oooo6@3oool004<0oooo0P00
000?0?ooo`030?l0003oool0003o03d0oooo0P00003o0?oooa/0oooo00150?ooo`8000003@3oool0
0`3o0000003o0?ooo`0k0?ooo`800000o`3ooolM0?ooo`00A`3oool2000000T0oooo0P000?l00`3o
0000003o0?ooo`0i0?ooo`800000o`3ooolO0?ooo`00B@3oool4000000<0oooo10000?l00`3o0000
003o0000o`0d0?ooo`D00000o`3ooolQ0?ooo`00C@3oool2000000030?ooo`000?l0003o0080003o
00<0o`000000o`000?l0<P3oool200000?l0oooo9P3oool004l0oooo1@000?l0103o0000003o0000
o`000?l_0?ooo`800000o`3ooolX0?ooo`00C`3oool50000o`040?l000000?l0003o0000obX0oooo
1@00003o0?ooobX0oooo001?0?ooo`T0003o0`00000S0?ooo`@00000o`3oool_0?ooo`00D03oool7
0000o`@0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00D03oool70000o`/0oooo5@00003o0?oo
ocX0oooo001B0?ooo`<0003oo`3ooomL0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.2619 .91239 Mdot
.5 Mabswid
.5 .5 m
.2619 .91239 L
s
0 1 0 r
.5 .5 m
.2619 .5 L
s
1 0 0 r
.2619 .91239 m
.2619 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.34127 .16186 Mdot
1 0 0 r
.34127 .56389 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0_0?oo
o`800?l000<0oooo0000003oool0903oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0703oool00180oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0
oooo1P00o`0T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0;@3oool6003o02@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool2000002d0oooo2000o`0R0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`004P3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo01T0oooo1P0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02`0oooo2000o`0Q
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0J
0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0]0?oo
o`H00?l08P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02d0oooo1P00o`0Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`0000000?l0003o000S0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3o
ool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02<0oooo1000000>0?ooo`D00000103o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0
oooo0;<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01L0oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0
oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0B0?ooo`L000004@3oool6000001<0oooo1000
000:0?ooo`030000003oool0oooo00T0oooo100000070?ooo`030000003oool0oooo00T0oooo1000
000E0?ooo`@000005@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo00000002
0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`0000006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00H000000?oo
o`3oool000000?ooo`00000D0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0
oooo000001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`H000002@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo0P0000020?ooo`800000503o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01D0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P00
000E0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`060?ooo`@00000503oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003oool0oooo0;H0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000001@0oooo000?0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`<000004@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0
oooo0000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
1000000D0?ooo`@000001P3oool00`000000oooo0?ooo`0>0?ooo`800000303oool00`000000oooo
0?ooo`050?ooo`D000005P3oool4000001<0oooo000?0?ooo`030000003oool0oooo0;H0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo000?0?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003o
ool0oooo02/0oooo00<0o`00003o0000o`00;@00o`1L0?ooo`030000003oool0oooo03L0ooooXP00
000;0?ooo`003`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02/0oooo00<0003o
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo
02/0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`8000008`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<P3oool000l0
oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo05`0
oooo00<000000?ooo`3oool0>`3oool200000280oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo02/0oooo
00<0o`000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0000
000P0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0a0?ooo`003`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02T0oooo00<0003o
0?ooo`3oool0G03oool00`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000001l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?
0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?ooo`1M
0?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<00000
0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo05h0oooo00<00000
0?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo000?0?ooo`030000003oool0
oooo02/0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0
oooo03`0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`0[
0?ooo`030?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool0G`3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo05l0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo000@0?ooo`03
0000003oool0oooo02X0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`1P0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?ooo`00
403oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0
H@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
;@3oool00100oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3o
ool0oooo0640oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo02`0oooo000@0?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo
02<0oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3oool0:P3oool00`3o0000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo02/0oooo000A0?ooo`030000003oool0oooo02T0oooo
00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<00000
0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo06<0oooo00<00000
0?ooo`3oool08`3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo02T0oooo000A0?ooo`030000003oool0oooo02T0oooo00<0o`000?oo
o`3oool0803oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Y0?oo
o`004@3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3o
ool0I03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0:03oool00180oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo06@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo02P0oooo000B0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo02L0oooo000B0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo02H0oooo000B0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo01`0
oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo06D0oooo00<000000?ooo`3oool09@3oool4000000h0oooo
1@0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo00<0
00000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo06H0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo000D
0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`1V
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3o
ool0000002D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0R0?ooo`00503oool0
0`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool0IP3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000009P3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0
oooo02D0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000U0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool09@3oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0?0?ooo`8000009P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0200oooo000E0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0603oool00`000?l0
oooo0?ooo`1W0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo
0?ooo`0U0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000008`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003oool0oooo02@0oooo
00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`0T0?ooo`030?l0
003oool0oooo01L0oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool08`3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool20?l00080oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0M0?ooo`005`3oool0
0`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0I`3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0F0?ooo`H0o`00E03oool00`000000oooo0?ooo`0L0?ooo`00603oool00`00
0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0I`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0E0?ooo`H0o`00E@3oool00`000000oooo0?ooo`0K0?ooo`00603oool00`000000
oooo0?ooo`0R0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0J03oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0C0?ooo`P0o`00E@3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0B0?ooo`P0o`00EP3oool00`000000oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?oo
o`0Q0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo0180oooo1P3o
001H0?ooo`8000006@3oool001X0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool0?@3oool7000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo1P3o001J
0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000003oool0oooo0200oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo0P00000?0?oo
o`8000000P3oool20?l005d0oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?ooo`3o
ool0803oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`80
00002P3oool3000006@0oooo0P00000E0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00@0oooo1P00000K0?ooo`X00000J@3oool6000000l0oooo000L0?ooo`030000003o
ool0oooo01h0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1X0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool0
0`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0J03oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool0
01d0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
06P0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0:H0oooo000N0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`1Y0?ooo`030000003oool0oooo0440oooo0`00002_0?ooo`007`3oool00`000000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0I`3oool2000004H0oooo
00<000000?ooo`3oool0[@3oool001l0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0mP3oool00200oooo00<00000
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo06L0oooo00<00000
0?ooo`3oool0mP3oool00240oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?ooo`3o
ool0603oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3o
ool0m`3oool00280oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo06L0oooo00<000000?ooo`3oool0n03oool002<0oooo00<000000?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0n@3o
ool002@0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo06H0oooo00<000000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool05@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0nP3oool002D0
oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo06H0
oooo00<000000?ooo`3oool0n`3oool002H0oooo00<000000?ooo`3oool0503oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0o03oool002L0oooo0P00
000D0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?oo
o`3m0?ooo`00:03oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3n0?ooo`00:@3oool00`000000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`3o0?oo
o`00:P3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0I03oool00`000000oooo0?ooo`3o0?ooo`40oooo000[0?ooo`030000003oool0oooo00l0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo0?l0oooo
0@3oool002`0oooo0P00000?0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0H`3o
ool200000?l0oooo103oool002d0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3oool0o`3oool40?ooo`00;P3oool00`00
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0H`3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo000_0?ooo`800000303oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0640oooo0P00003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo00T0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0oooo
203oool00380oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo0640oooo00<000000?ooo`3oool0o`3oool80?ooo`00<`3oool2000000P0oooo00D0o`00
0?ooo`3oool0oooo0000o`1R0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`05
0?ooo`040?l0003oool0oooo0000of80oooo00<000000?ooo`3oool0o`3oool;0?ooo`00=P3oool0
0`000000oooo0?ooo`040?ooo`040?l0003oool0oooo0000of40oooo00<000000?ooo`3oool0o`3o
ool<0?ooo`00=`3oool00`000000oooo0?ooo`020?ooo`040000o`3o0000003o0000of00oooo0P00
003o0?ooo`l0oooo000h0?ooo`8000000`000?l0103o0000003o0000o`000?mM0?ooo`800000o`3o
oolA0?ooo`00>P3oool30000o`040?l000000?l0003o0000oe/0oooo0P00003o0?oooa<0oooo000i
0?ooo`@0003o00<0o`000000o`000?l00P000?mI0?ooo`030000003oool0oooo0?l0oooo4`3oool0
03T0oooo10000?l00`3o0000003o0000o`020000oeP0oooo00<000000?ooo`3oool0o`3ooolD0?oo
o`00>@3oool90000oeH0oooo0P00003o0?oooaL0oooo000j0?ooo`L0003o0P00001C0?ooo`800000
o`3ooolI0?ooo`00>P3oool70000o`80oooo0P00001?0?ooo`800000o`3ooolK0?ooo`00?03oool3
0000o`H0oooo0P00001;0?ooo`800000o`3ooolM0?ooo`00A`3oool2000004L0oooo0P00003o0?oo
oal0oooo00190?ooo`@00000?P3oool500000?l0oooo8@3oool004d0oooo0P00000j0?ooo`800000
o`3ooolV0?ooo`00C`3oool3000003D0oooo0P00003o0?ooobP0oooo001B0?ooo`@00000;03oool5
00000?l0oooo:P3oool005H0oooo1@00000S0?ooo`@00000o`3oool_0?ooo`00F`3oool7000001D0
oooo1`00003o0?oooc<0oooo001R0?oooaD00000o`3ooolj0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.16328 .83672 Mdot
.5 Mabswid
.5 .5 m
.16328 .83672 L
s
0 1 0 r
.5 .5 m
.16328 .5 L
s
1 0 0 r
.16328 .83672 m
.16328 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.38095 .10091 Mdot
1 0 0 r
.38095 .51712 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0=P3oool2
003o00030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0d0?ooo`H00?l0803oool01@000000oooo0?ooo`3oool0
00000240oooo00<000000?ooo`3oool08`3oool001D0oooo00<000000?ooo`3oool0Z@3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo03@0oooo1P00o`0P0?ooo`040000003oool0oooo
000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo03<0oooo2000o`0P0?ooo`030000003oool00000
02@0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo03<0oooo2000o`0Q0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo03@0oooo1P00o`0Q0?ooo`030000003oool0000002D0oooo
00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo03@0oooo1P00o`0Q0?ooo`040000003oool0oooo000002D0oooo
00<000000?ooo`3oool07`3oool001@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo03@0oooo00@000000?ooo`00o`000?l08P3oool01@000000oooo
0?ooo`3oool0000002H0oooo00<000000?ooo`3oool07P3oool001@0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
7P3oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool07@3oool001<0oooo00<000000?ooo`3oool0[P3oool0
0`000000oooo0?ooo`0U0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0703oool00180oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool06`3oool00180oooo00<000000?ooo`3oool0/03oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06`3oool00180oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0J0?ooo`004P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01T0oooo1P00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00140oooo00<00000
0?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I
0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`00
4@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02<0oooo1000000>0?ooo`D00000
103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01L0oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo
0;@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01H0oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0B0?ooo`L000004@3oool6000001<0oooo
1000000:0?ooo`030000003oool0oooo00T0oooo100000070?ooo`030000003oool0oooo00T0oooo
1000000E0?ooo`@000005@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0;D0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`0000006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00H00000
0?ooo`3oool000000?ooo`00000D0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`040000003o
ool0oooo000001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`H00000
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo0P0000020?ooo`800000
503oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01D0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`000000
0P00000E0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`060?ooo`@00000503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003oool0oooo0;H0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000001@0oooo000?0?ooo`030000
003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`<00000
4@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
0000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080
oooo1000000D0?ooo`@000001P3oool00`000000oooo0?ooo`0>0?ooo`800000303oool00`000000
oooo0?ooo`050?ooo`D000005P3oool4000001<0oooo000?0?ooo`030000003oool0oooo0;H0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo
000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo0;H0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo000?0?oo
o`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000
003oool0oooo01P0oooo00<0o`00003o0000o`00@000o`1L0?ooo`030000003oool0oooo03L0oooo
XP00000;0?ooo`003`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo03h0oooo00<0
003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0
00000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0
oooo03d0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0k0?ooo`8000008`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<P3oool0
00l0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`0l0?ooo`030000o`3oool0oooo
05d0oooo00<000000?ooo`3oool0>`3oool200000280oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo01P0
oooo00<0o`000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0603oool00`3o0000oooo
0?ooo`0j0?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0000000P0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo03T0oooo00<0
003o0?ooo`3oool0G`3oool00`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000001l0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo
000?0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0>03oool00`000?l0oooo0?oo
o`1P0?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<0
00000?ooo`3oool0603oool00`3o0000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0640oooo00<0
00000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo000?0?ooo`030000003o
ool0oooo01P0oooo00<0o`000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1R0?ooo`030000003o
ool0oooo03`0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?oo
o`0H0?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<00000
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo06@0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo000@0?oo
o`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`1U0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?oo
o`00403oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3o
ool0IP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0;@3oool00100oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0a0?ooo`030000
o`3oool0oooo06L0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo02`0oooo000@0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0<03o
ool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0
oooo02l0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3oool05`3oool00`3o
0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo02/0oooo000A0?ooo`030000003oool0oooo01H0
oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo
0?ooo`0F0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0J`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<0
00000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo06/0oooo00<0
00000?ooo`3oool08`3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo02T0oooo000A0?ooo`030000003oool0oooo01H0oooo00<0o`00
0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`1/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Y
0?ooo`004@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?oo
o`3oool0K@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0:03oool00180oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo06h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo02P0oooo000B0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo02L0oooo000B0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool09P3o
ool00`000?l0oooo0?ooo`1_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo02H0oooo000B0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo
02@0oooo00<0003o0?ooo`3oool0L03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool0503oool00`3o0000
oooo0?ooo`0S0?ooo`030000o`3oool0oooo0740oooo00<000000?ooo`3oool09@3oool4000000h0
oooo1@0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo
00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0780oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo
000D0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?oo
o`1c0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool01@000000oooo0?oo
o`3oool0000002<0oooo0P3o00000`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo
000D0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?oo
o`1c0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`00000R0?ooo`H0o`00A`3oool00`000000oooo0?ooo`0R0?ooo`005@3oool00`000000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0M03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000008P3oool60?l004P0oooo00<0
00000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0N
0?ooo`030000o`3oool0oooo07@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?
0?ooo`8000008P3oool80?l004P0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo07D0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`8000008P3oool80?l004T0oooo00<000000?oo
o`3oool07`3oool001D0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo07D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`04
0000003oool0oooo00000280oooo1P3o001:0?ooo`030000003oool0oooo01l0oooo000F0?ooo`03
0000003oool0oooo0140oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`1f0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
0240oooo1P3o001;0?ooo`030000003oool0oooo01h0oooo000F0?ooo`030000003oool0oooo0140
oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`1f0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool00P3o001=0?ooo`030000003oool0oooo01h0oooo000G0?ooo`030000
003oool0oooo0100oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`1g0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0M0?ooo`005`3o
ool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0M`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0703o
ool001P0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo07P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo01/0oooo000H0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`1i0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool0N@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo
0P00000I0?ooo`006P3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01<0oooo00<0
003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0m0?ooo`L000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000003oool0oooo00d0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo0P00000?
0?ooo`800000H@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`000000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000001L0oooo0P00000:0?oo
o`<00000I03oool2000001D0oooo000K0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`1l0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0103oool6000001/0oooo2P00001Y0?ooo`H000003`3oool001`0oooo00<000000?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo07`0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000003o
ool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1m0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool0
0`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0O@3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool0
01h0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
07h0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`030000003oool0oooo00P0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1m0?ooo`800000AP3oool00`000000
oooo0?ooo`2]0?ooo`007`3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool0O@3oool00`000000oooo0?ooo`3f0?ooo`00803oool00`000000oooo0?oo
o`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0OP3oool00`000000oooo0?oo
o`3f0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0OP3oool00`000000oooo0?ooo`3g0?ooo`008P3oool00`000000oooo0?ooo`050?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0O`3oool00`000000oooo0?ooo`3g0?oo
o`008P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0O`3oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0O`3oool00`000000oooo0?ooo`3i0?ooo`00903o
ool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0O`3o
ool00`000000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0P03oool00`000000oooo0?ooo`3j0?ooo`009@3oool00`00
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0P03oool00`00
0000oooo0?ooo`3k0?ooo`009P3oool01P000000oooo0?ooo`000?l0o`000000o`80oooo00<0003o
0?ooo`3oool0P03oool00`000000oooo0?ooo`3l0?ooo`009`3oool30000o`040?l000000?l0003o
0000oh80oooo00<000000?ooo`3oool0o@3oool002L0oooo0`000?l0103o0000003o0000o`000?n1
0?ooo`030000003oool0oooo0?h0oooo000V0?ooo`@0003o00<0o`000000o`000?l00P000?mo0?oo
o`030000003oool0oooo0?l0oooo000V0?ooo`@0003o00<0o`000000o`000?l00P000?mn0?ooo`03
0000003oool0oooo0?l0oooo0@3oool002H0oooo2@000?mn0?ooo`030000003oool0oooo0?l0oooo
0@3oool002L0oooo1`000?mm0?ooo`800000o`3oool40?ooo`009`3oool70000og`0oooo00<00000
0?ooo`3oool0o`3oool40?ooo`00:@3oool30000o`80oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo000_0?ooo`800000MP3oool200000?l0oooo203oool00340oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000b0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0o`3oool80?ooo`00<`3oool2000006l0oooo0P00003o
0?ooo`/0oooo000e0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3oool;0?oo
o`00=P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0oooo303oool003L0oooo
00<000000?ooo`3oool0IP3oool200000?l0oooo3`3oool003P0oooo0P00001T0?ooo`800000o`3o
oolA0?ooo`00>P3oool200000600oooo0P00003o0?oooa<0oooo000l0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00?@3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo0?l0oooo503oool003h0oooo0P00001H0?ooo`800000o`3ooolG0?ooo`00@03o
ool3000005<0oooo0P00003o0?oooaT0oooo00130?ooo`800000C`3oool200000?l0oooo6`3oool0
04D0oooo0P00001;0?ooo`800000o`3ooolM0?ooo`00A`3oool2000004L0oooo0P00003o0?oooal0
oooo00190?ooo`@00000?P3oool500000?l0oooo8@3oool004d0oooo0P00000j0?ooo`800000o`3o
oolV0?ooo`00C`3oool3000003D0oooo0P00003o0?ooobP0oooo001B0?ooo`@00000;03oool50000
0?l0oooo:P3oool005H0oooo1@00000S0?ooo`@00000o`3oool_0?ooo`00F`3oool7000001D0oooo
1`00003o0?oooc<0oooo001R0?oooaD00000o`3ooolj0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.08761 .7381 Mdot
.5 Mabswid
.5 .5 m
.08761 .7381 L
s
0 1 0 r
.5 .5 m
.08761 .5 L
s
1 0 0 r
.08761 .7381 m
.08761 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.42063 .05414 Mdot
1 0 0 r
.42063 .45617 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0?03oool2003o0080oooo0P00000?0?ooo`8000004`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo02/0oooo000I0?ooo`030000003oool0oooo0:40oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03X0oooo1P00
o`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0>P3oool6003o01@0oooo0P00000>0?ooo`030000003oool0oooo01<0oooo0P00000Z
0?ooo`00603oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0>@3oool8003o01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo02L0oooo000H0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0i0?ooo`P00?l05P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool09P3oool001L0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03X0oooo1P00o`0G0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0U0?ooo`005`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>@3o
ool00`0000000?l0003o0004003o01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003oool0oooo0:L0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0h0?ooo`040000003oool0oooo0?ooo`800?l06`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0903o
ool001H0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool000000240oooo00<0
00000?ooo`3oool08`3oool001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`00
000S0?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`000000903oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0000000U0?ooo`030000003oool0oooo0200oooo000E0?ooo`030000
003oool0oooo0:/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo02@0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`0O0?ooo`00
503oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000
oooo0?ooo`0N0?ooo`00503oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo0?oo
o`2^0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0M0?ooo`004`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo02D0oooo10000006
0?ooo`8000001P3oool4000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0L
0?ooo`004P3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0K0?oo
o`004P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo0P00000a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000B0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool06@3oool6000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0J0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01T0oooo000A0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool08`3oool4000000h0oooo1@0000040?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0603oool00140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool00100oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool05`3oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool05P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0180oooo1`00000A0?ooo`H000004`3oool4000000X0oooo00<000000?ooo`3oool0
2@3oool4000000L0oooo00<000000?ooo`3oool02@3oool4000001D0oooo1000000E0?ooo`00403o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool000000080oooo00<000000?ooo`3oool04P3o
ool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000K0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool04@3oool01P000000oooo0?ooo`000000oooo000001@0oooo
000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000006P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo1P0000090?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool04@3oool200000080oooo0P00000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool2000000P0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo00000002000001D0oooo000?0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00H0oooo1000000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
4P3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`050000
003oool0oooo0?ooo`000000503oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo01<0oooo0`00000A0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0000001<0oooo000?0?ooo`03
0000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool4000001@0oooo100000060?ooo`03
0000003oool0oooo00h0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo1@00000F0?ooo`@0
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0403o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0]`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool000l0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool02@3oool00`3o00000?l0
003o001?003o05`0oooo00<000000?ooo`3oool0=`3ooonR000000/0oooo000?0?ooo`030000003o
ool0oooo00T0oooo00<0o`000?ooo`3oool0C03oool20000oed0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3o
ool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool000l0oooo00<00000
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`1:0?ooo`80003oG`3oool00`000000oooo0?ooo`0k
0?ooo`8000008`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0<P3oool000l0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`180?oo
o`80003oH@3oool00`000000oooo0?ooo`0k0?ooo`8000008P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<P3oool000l0oooo00<000000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`170?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0000000Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030?l0
003oool0oooo04D0oooo0P000?mS0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`000000
803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
<@3oool000l0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`130?ooo`80003oI@3o
ool00`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003o
ool0oooo00T0oooo00<0o`000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`1U0?ooo`030000003o
ool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<000000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`100?ooo`80003oJ03oool00`000000oooo0?ooo`0l0?ooo`050000003o
ool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0n0?ooo`80003oJP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
;`3oool000l0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0l0?ooo`80003oK03o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3o
ool00100oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0k0?ooo`030000o`3oool0
oooo06`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo02h0oooo000@0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0>@3oool20000
ofl0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
02d0oooo000@0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0=`3oool20000og40
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02d0
oooo000@0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0=P3oool00`000?l0oooo
0?ooo`1a0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo03@0oooo0P00
0?mc0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0/0?ooo`00403oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0380oooo0P000?me
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0[
0?ooo`00403oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0300oooo0P000?mg0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0[0?oo
o`004@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0:P3oool00140oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0]0?ooo`80003o
NP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
:P3oool00140oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0[0?ooo`80003oN`3o
ool00`000000oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`80o`0000<0
oooo0000003oool0>@3oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`07
0?ooo`030?l0003oool0oooo02T0oooo0P000?mm0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01l0oooo1P3o000j0?ooo`030000003oool0oooo02T0oooo000A0?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?ooo`1m0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0200oooo1P3o000k0?ooo`030000003oool0oooo02P0oooo000B0?ooo`03
0000003oool0oooo00H0oooo00<0o`000?ooo`3oool09P3oool20000oh00oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool07`3oool80?l003X0oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0T0?ooo`80003oP@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`800000
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo203o000k0?ooo`030000
003oool0oooo02L0oooo000B0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`210?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08P3oool60?l003d0oooo00<000000?ooo`3oool09P3o
ool00180oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0Q0?ooo`80003oQ03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0R0?ooo`H0o`00?P3oool00`000000oooo0?ooo`0U0?ooo`004`3oool00`00
0000oooo0?ooo`050?ooo`030?l0003oool0oooo01l0oooo0P000?n50?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02<0oooo00@000000?ooo`3o0000o`00@03oool00`000000oooo0?ooo`0U0?ooo`004`3oool00`00
0000oooo0?ooo`050?ooo`030?l0003oool0oooo01d0oooo0P000?n70?ooo`030000003oool0oooo
02D0oooo1000000>0?ooo`D00000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
02@0oooo000C0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0703oool00`000?l0
oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0S0?ooo`00503oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01X0oooo
0P000?n:0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool01@000000oooo
0?ooo`3oool0000002D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0R0?ooo`00
503oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01P0oooo0P000?n;0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000V0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0F0?ooo`80003oS@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`0000009@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo0240oooo000E0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`2<0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3o
ool2000002H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool0
0`000000oooo0?ooo`030?ooo`030?l0003oool0oooo01<0oooo0P000?n?0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo
0140oooo0P000?n@0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool01000
0000oooo0?ooo`00000S0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool07`3oool0
01H0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0900oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01h0oooo000F0?oo
o`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03P3oool20000oi80oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01h0oooo000G0?ooo`05
0000003oool0oooo0?ooo`3o00003P3oool20000oi@0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo01d0oooo000G0?ooo`050000003oool0oooo0?oo
o`3o0000303oool20000oiD0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo01`0oooo000H0?ooo`040000003oool0oooo0?l000/0oooo00<0003o0?oo
o`3oool0U@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool06`3oool001P0oooo00@000000?ooo`3oool0o`002@3oool20000oiP0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo000I0?ooo`03
0000003oool0o`0000L0oooo0P000?nI0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0I0?ooo`006@3oool010000000003o0?l000000?l50?ooo`03
0000o`3oool0oooo09T0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`070?ooo`80
00003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo0P00000I0?ooo`00
603oool30000o`050?l000000?l0003o0000o`3oool00P000?nK0?ooo`030000003oool0oooo03d0
oooo1`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool05P3oool001P0oooo
0`000?l00`3o0000003o0000o`020000oid0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool2000000l0oooo
0P00001Q0?ooo`030000003oool0oooo01D0oooo000G0?ooo`@0003o00<0o`000000o`000?l00P00
0?nL0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`8000005`3oool2000000X0oooo0`00001T0?ooo`8000005@3oool001L0oooo10000?l0
0`3o0000003o0000o`020000oi`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`04
0?ooo`H000006`3oool:000006T0oooo1P00000?0?ooo`005`3oool90000oi/0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000H0?ooo`L0
003oW03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0YP3oool001P0oooo1`000?nK0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2V0?ooo`006P3oool30000o`030?ooo`000000oooo09X0oooo00<0
00000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`030000003oool0oooo09H0oooo0P000016
0?ooo`030000003oool0oooo0:d0oooo000O0?ooo`030000003oool0oooo09D0oooo00<000000?oo
o`3oool0mP3oool00200oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`3f0?ooo`00
8@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000003o
ool0oooo0940oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
0?T0oooo000T0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0nP3oool002D0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo0?/0oooo000V0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0o03oool002L0oooo0P0000270?ooo`030000003oool0oooo0?d0oooo000X0?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool0oP3oool002T0oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`3o0?ooo`00:P3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0?l0oooo0@3oool002/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o
0?ooo`40oooo000/0?ooo`800000O@3oool200000?l0oooo103oool002d0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000^0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool2000007H0oooo0P00003o0?ooo`P0oooo000a
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3oool80?ooo`00<P3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool003<0oooo0P00001_0?ooo`80
0000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0?l0oooo
2`3oool003H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3o0?ooo``0oooo000g
0?ooo`030000003oool0oooo06H0oooo0P00003o0?ooo`l0oooo000h0?ooo`800000I03oool20000
0?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000o`3ooolC0?ooo`00?03oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3oool003d0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?ooo`800000F03oool200000?l0oooo5`3oool0
0400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00@`3oool2000004l0oooo0P00003o0?oooa/0
oooo00150?ooo`800000B`3oool200000?l0oooo7@3oool004L0oooo0P0000170?ooo`800000o`3o
oolO0?ooo`00B@3oool4000003h0oooo1@00003o0?ooob40oooo001=0?ooo`800000>P3oool20000
0?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000o`3ooolX0?ooo`00DP3oool4000002`0oooo
1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool400000?l0oooo;`3oool005/0oooo1`00000E
0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0oooo>P3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.04004 .62325 Mdot
.5 Mabswid
.5 .5 m
.04004 .62325 L
s
0 1 0 r
.5 .5 m
.04004 .5 L
s
1 0 0 r
.04004 .62325 m
.04004 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.46032 .02474 Mdot
1 0 0 r
.46032 .38519 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0480oooo0P00o`1R0?ooo`007@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`100?ooo`H00?l0H03o
ool001`0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0f0?ooo`H000001P3oool0
0`000000oooo0?ooo`040?ooo`800000@@3oool6003o00P000007P3oool800000380oooo000K0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03l0oooo2000o`070?ooo`030000003oool0oooo01P0oooo0`0000080?oo
o`<00000;`3oool001X0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool8003o00P0oooo0P00000F0?ooo`80
00003P3oool2000002d0oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0
?P3oool3000000H0oooo00<000000?ooo`3oool0@03oool6003o00/0oooo0P00000C0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3o
ool00`0000000?l0003o0004003o00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02X0oooo000I0?ooo`030000003oool0oooo0:80oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0n0?ooo`040000003oool0oooo0?ooo`800?l0403o
ool2000000h0oooo00<000000?ooo`3oool04`3oool2000002X0oooo000H0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02L0oooo000H0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo000G0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0j0?ooo`8000006`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09@3oool001L0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0903oool001H0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0903oool001H0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0803oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool08`3o
ool001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`00000S0?ooo`030000003o
ool0oooo0280oooo000E0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000903oool0
0`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0000000U0?ooo`030000003oool0oooo0200oooo000E0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02@0oooo
00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`0O0?ooo`00503oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`0N0?ooo`00
503oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo0?ooo`2^0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`004`3oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo02D0oooo100000060?ooo`8000001P3oool4
000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`00
0000oooo0?ooo`2_0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
0P00000a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000B0?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool06@3oool6000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0J0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01T0oooo000A0?ooo`030000003oool0oooo0;80oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo000A0?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0
8`3oool4000000h0oooo1@0000040?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
603oool00140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool05`3oool00100oooo00<000000?ooo`3oool0]03oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool0
0100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05P3oool00100oooo
00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0180oooo
1`00000A0?ooo`H000004`3oool4000000X0oooo00<000000?ooo`3oool02@3oool4000000L0oooo
00<000000?ooo`3oool02@3oool4000001D0oooo1000000E0?ooo`00403oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool000000080oooo00<000000?ooo`3oool04P3oool00100oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0000000K0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04@3oool01P000000oooo0?ooo`000000oooo000001@0oooo000@0?ooo`030000003o
ool0oooo0;D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0140oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo1P0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
4@3oool200000080oooo0P00000D0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05@3oool2000000P0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo00000002000001D0oooo000?0?ooo`030000003oool0oooo0;H0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00H0oooo
1000000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool000l0oooo00<0
00000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool03`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`00
0000503oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01<0oooo0`00000A0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool05`3oool01@000000oooo0?ooo`3oool0000001<0oooo000?0?ooo`030000003oool0oooo0;H0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool4000001@0oooo100000060?ooo`030000003oool0oooo00h0
oooo0P00000<0?ooo`030000003oool0oooo00D0oooo1@00000F0?ooo`@000004`3oool000l0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0403oool000l0oooo00<00000
0?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool03P3oool000l0oooo00@000000?ooo`3oool0o`00FP00o`1L0?ooo`030000003oool0oooo03L0
ooooXP00000;0?ooo`003`3oool010000000oooo0?ooo`3o001D0?ooo`@0003oGP3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003o
ool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00
3`3oool010000000oooo0?ooo`3o001@0?ooo`@0003oHP3oool00`000000oooo0?ooo`0k0?ooo`80
00008`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0<P3oool000l0oooo00@000000?ooo`3oool0o`00C03oool40000ofH0oooo00<000000?ooo`3o
ool0>`3oool200000280oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0380oooo000?0?ooo`040000003oool0oooo0?l004T0oooo0`000?mY0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0<@3oool000l0oooo00@000000?ooo`3oool0
o`00A@3oool40000of`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0000000P0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0a0?ooo`00
3`3oool010000000oooo0?ooo`3o00110?ooo`@0003oL03oool00`000000oooo0?ooo`0l0?ooo`04
0000003oool0oooo000001l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0300oooo000?0?ooo`040000003oool0oooo0?l003d0oooo10000?md0?oo
o`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00@000000?oo
o`3oool0o`00>P3oool30000ogP0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3o
ool0000001d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000?0?ooo`040000003oool0oooo0?l003H0oooo10000?mk0?ooo`030000003o
ool0oooo03`0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo0240oooo
0P3o00000`3oool000000?ooo`0]0?ooo`030000003oool0oooo02l0oooo000?0?ooo`040000003o
ool0oooo0?l00380oooo10000?mo0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01l0oooo1P3o000_0?ooo`030000
003oool0oooo02h0oooo000@0?ooo`030000003oool0o`0002h0oooo10000?n30?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0200oooo1P3o000_0?ooo`030000003oool0oooo02h0oooo000@0?ooo`030000003oool0
o`0002/0oooo0`000?n70?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01l0oooo203o000_0?ooo`030000003oool0
oooo02d0oooo000@0?ooo`030000003oool0o`0002L0oooo10000?n:0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0200oooo203o000_0?ooo`030000003oool0oooo02d0oooo000@0?ooo`030000003oool0o`0002<0
oooo10000?n>0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo1P3o000a0?ooo`030000003oool0oooo02`0
oooo000@0?ooo`030000003oool0o`0001l0oooo10000?nA0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0280oooo
1P3o000a0?ooo`030000003oool0oooo02`0oooo000@0?ooo`030000003oool0o`0001`0oooo0`00
0?nE0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo02<0oooo00<000000?l0003o0000=03oool00`000000oooo0?oo
o`0[0?ooo`00403oool00`000000oooo0?l0000H0?ooo`@0003oV03oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?l0
003oool04`3oool40000oi`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo02X0oooo000A0?ooo`030000003o0000oooo00l0oooo10000?nP0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`00
4@3oool00`000?l0o`000000o`0<0?ooo`<0003oX`3oool00`000000oooo0?ooo`0S0?ooo`@00000
1P3oool2000000H0oooo100000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
:@3oool000l0oooo0`000?l0103o0000003o0000o`000?l60?ooo`@0003oYP3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0:@3oool000l0oooo0`000?l0103o0000003o0000o`000?l20?ooo`@0003o
ZP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
:03oool000h0oooo10000?l00`3o0000003o0000o`030000ojh0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo000>0?ooo`@0003o00<0o`00
0000o`000?l00P000?n^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo02L0oooo000>0?ooo`T0003o[P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0V0?ooo`003`3oool70000ojl0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo02D0oooo000?0?ooo`L0003o[P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09@3oool00140oooo0`00
0?n`0?ooo`030000003oool0oooo02D0oooo1000000>0?ooo`D00000103oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo02@0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo000D0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo0280oooo000D0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0>0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0R0?ooo`005@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000U0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo0P00000V0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00l0oooo0P00000U0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool07`3oool001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000008`3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000
8@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01h0oooo000F0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo01h0oooo000G0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01d0oooo000G0?ooo`030000003oool0oooo
0:D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
01`0oooo000H0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo01/0oooo000H0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo
000I0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01T0oooo000I0?ooo`030000003oool0oooo0:80oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo05X0oooo0P00000I0?ooo`006P3oool00`000000oooo0?ooo`2P0?oo
o`030000003oool0oooo03d0oooo1`0000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool05P3oool001X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`80
00003`3oool200000640oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?ooo`3oool0
W`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool2000001L0oooo0P00000:0?ooo`<00000I03oool2000001D0oooo000K0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`H000006`3o
ool:000006T0oooo1P00000?0?ooo`00703oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2V0?ooo`007@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007P3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0440oooo0`00002_0?ooo`007`3oool00`000000oooo0?oo
o`2F0?ooo`800000AP3oool00`000000oooo0?ooo`2]0?ooo`007`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0?H0oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool0mP3oool00240oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`3g0?ooo`00
8P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0n03oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`3i0?ooo`00903oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0?X0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0nP3oool002D0oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3k0?ooo`009P3oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo0?`0oooo000W0?ooo`800000Q`3oool00`000000oooo0?ooo`3m
0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo000Y0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0o`3oool002X0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`3o0?ooo`40oooo000[0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`00;03oool2000007d0oooo0P00003o0?ooo`@0oooo000]0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3oool40?ooo`00;P3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo1@3oool002l0oooo0P00001f0?ooo`800000
o`3oool80?ooo`00<@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo203o
ool00380oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000c0?oo
o`800000K`3oool200000?l0oooo2`3oool003D0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo000f0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
o`3oool<0?ooo`00=`3oool00`000000oooo0?ooo`1V0?ooo`800000o`3oool?0?ooo`00>03oool2
000006@0oooo0P00003o0?oooa40oooo000j0?ooo`800000H03oool200000?l0oooo4`3oool003`0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oooa<0oooo000m0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00?P3oool2000005P0oooo0P00
003o0?oooaL0oooo00100?ooo`<00000D`3oool200000?l0oooo6@3oool004<0oooo0P00001?0?oo
o`800000o`3ooolK0?ooo`00A@3oool2000004/0oooo0P00003o0?oooad0oooo00170?ooo`800000
A`3oool200000?l0oooo7`3oool004T0oooo1000000n0?ooo`D00000o`3ooolQ0?ooo`00C@3oool2
000003X0oooo0P00003o0?ooobH0oooo001?0?ooo`<00000=@3oool200000?l0oooo:03oool00580
oooo1000000/0?ooo`D00000o`3ooolZ0?ooo`00EP3oool5000002<0oooo1000003o0?ooobl0oooo
001K0?ooo`L000005@3oool700000?l0oooo<`3oool00680oooo5@00003o0?ooocX0oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.02381 .5 Mdot
.5 Mabswid
.5 .5 m
.02381 .5 L
s
0 1 0 r
.5 .5 m
.02381 .5 L
s
1 0 0 r
.02381 .5 m
.02381 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.5 .01471 Mdot
1 0 0 r
.5 .30902 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo1P00o`1I0?ooo`00
7@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`170?ooo`H00?l0F@3oool001d0oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0AP3o
ool8003o05P0oooo000L0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0=P3oool6
000000H0oooo00<000000?ooo`3oool0103oool2000004L0oooo2000o`0N0?ooo`P00000<P3oool0
01/0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0@`3oool3000000030?ooo`00o`000?l000@00?l000<0oooo0000
003oool06@3oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0080oooo1P00o`020?ooo`8000005P3oool2000000h0oooo0P00000]0?ooo`00
6P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo03h0oooo0`0000060?ooo`030000
003oool0oooo0400oooo0P0000070?ooo`800?l01P3oool2000001<0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0[0?ooo`006@3oool00`000000oooo0?ooo`2Q0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo02X0oooo000I0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01<0oooo0P00000>0?ooo`030000003oool0
oooo01<0oooo0P00000Z0?ooo`00603oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0W0?ooo`00603oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0V0?ooo`005`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0>P3oool2000001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo02D0oooo000G0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02@0oooo000F
0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo00D000000?oo
o`3oool0oooo0000000Q0?ooo`030000003oool0oooo02<0oooo000E0?ooo`030000003oool0oooo
0:T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0200oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0R0?ooo`005@3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0000002@0oooo00<000000?ooo`3oool08@3oool001D0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0200
oooo000E0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`0000009@3oool00`000000oooo
0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo000002D0oooo
00<000000?ooo`3oool07`3oool001@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?oo
o`3oool0000002H0oooo00<000000?ooo`3oool07P3oool001@0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07P3o
ool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool07@3oool001<0oooo00<000000?ooo`3oool0[P3oool00`00
0000oooo0?ooo`0U0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0703oool00180oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool06`3oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06`3oool00180oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0J0?ooo`004P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01T0oooo1P000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00140oooo00<000000?oo
o`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool4000000D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?oo
o`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3o
ool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02<0oooo1000000>0?ooo`D00000103o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0
oooo0;<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01L0oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0
oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0B0?ooo`L000004@3oool6000001<0oooo1000
000:0?ooo`030000003oool0oooo00T0oooo100000070?ooo`030000003oool0oooo00T0oooo1000
000E0?ooo`@000005@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo00000002
0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`0000006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00H000000?oo
o`3oool000000?ooo`00000D0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0
oooo000001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`H000002@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo0P0000020?ooo`800000503o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01D0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P00
000E0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`060?ooo`@00000503oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003oool0oooo0;H0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000001@0oooo000?0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`<000004@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0
oooo0000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
1000000D0?ooo`@000001P3oool00`000000oooo0?ooo`0>0?ooo`800000303oool00`000000oooo
0?ooo`050?ooo`D000005P3oool4000001<0oooo000?0?ooo`030000003oool0oooo0;H0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo000>
0?ooo`<0003o]`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0403oool000`0oooo1`000?ne0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`80o`0000<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo000<0?ooo`L0003o]P3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool60?l00280
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0?0?ooo`002`3oool90000okD0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0200oooo
1P3o000R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool000/0oooo1000
0?l00`3o00000?l0003o001K003o05`0oooo00<000000?ooo`3oool0=`3ooom=000000P0o`00C@00
000;0?ooo`002`3oool90000okD0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003o
ool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool80?l00080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool000`0oooo1`000?nf0?ooo`030000003oool0oooo03/0oooo0P00000S0?ooo`030000
003oool0oooo0280oooo1P3o000T0?ooo`030000003oool0oooo0380oooo000<0?ooo`L0003o]P3o
ool00`000000oooo0?ooo`0k0?ooo`8000008P3oool00`000000oooo0?ooo`0S0?ooo`H0o`00903o
ool00`000000oooo0?ooo`0b0?ooo`003P3oool30000okL0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0000000Q0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3o0000o`009`3o
ool00`000000oooo0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0]P3oool00`00
0000oooo0?ooo`0l0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003oool0oooo
0;H0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`00
0000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo0000000M
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0_
0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00D000000?oo
o`3oool0oooo0000000L0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0^0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0]0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0/0?oo
o`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0[0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0[0?ooo`004@3o
ool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo02<0oooo100000060?ooo`8000001P3oool40000
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo
0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02L0oooo000B0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo100000050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool09P3oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
9@3oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0U0?ooo`@000003P3o
ool5000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0T0?ooo`004`3oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0S0?ooo`00503oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000002D0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`2/0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000V
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`0000009@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`80
00009P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0200oooo000E0?ooo`030000
003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`800000
9@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01l0oooo000E0?ooo`030000003o
ool0oooo0:T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`040000003o
ool0oooo000002<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0O0?ooo`005P3o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0N0?ooo`005`3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0M
0?ooo`005`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0L0?ooo`00603oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0K0?ooo`00
603oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0I0?ooo`006@3oool0
0`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool01`3oool2
000000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1J0?ooo`8000006@3oool0
01X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0m0?ooo`L000000`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000003oool0oooo0:00
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04P3oool2000000l0oooo0P00001Q0?ooo`030000003oool0oooo01D0
oooo000J0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`8000002P3oool3000006@0oooo
0P00000E0?ooo`006`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0103oool6000001/0oooo2P00001Y0?ooo`H000003`3oool001`0oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0YP3oool001d0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001d0oooo00<000000?ooo`3o
ool0VP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0YP3oool001h0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`110?ooo`<00000
[`3oool001l0oooo00<000000?ooo`3oool0UP3oool2000004H0oooo00<000000?ooo`3oool0[@3o
ool001l0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`00803oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`3g0?ooo`008P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0?P0oooo000S
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0n@3oool002@0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
n`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`3l0?ooo`009`3oool2
000008L0oooo00<000000?ooo`3oool0o@3oool002P0oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`3n0?ooo`00:@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0
oooo000Z0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3oool10?ooo`00:`3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0oooo0@3oool002`0oooo0P00001m
0?ooo`800000o`3oool40?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0?l0oooo103oool002h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`3o0?ooo`D0
oooo000_0?ooo`800000MP3oool200000?l0oooo203oool00340oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`3o0?ooo`P0oooo000b0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool0o`3oool80?ooo`00<`3oool2000006l0oooo0P00003o0?ooo`/0oooo000e0?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3oool;0?ooo`00=P3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo0?l0oooo303oool003L0oooo00<000000?ooo`3oool0IP3o
ool200000?l0oooo3`3oool003P0oooo0P00001T0?ooo`800000o`3ooolA0?ooo`00>P3oool20000
0600oooo0P00003o0?oooa<0oooo000l0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`00?@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo
503oool003h0oooo0P00001H0?ooo`800000o`3ooolG0?ooo`00@03oool3000005<0oooo0P00003o
0?oooaT0oooo00130?ooo`800000C`3oool200000?l0oooo6`3oool004D0oooo0P00001;0?ooo`80
0000o`3ooolM0?ooo`00A`3oool2000004L0oooo0P00003o0?oooal0oooo00190?ooo`@00000?P3o
ool500000?l0oooo8@3oool004d0oooo0P00000j0?ooo`800000o`3ooolV0?ooo`00C`3oool30000
03D0oooo0P00003o0?ooobP0oooo001B0?ooo`@00000;03oool500000?l0oooo:P3oool005H0oooo
1@00000S0?ooo`@00000o`3oool_0?ooo`00F`3oool7000001D0oooo1`00003o0?oooc<0oooo001R
0?oooaD00000o`3ooolj0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.04004 .37675 Mdot
.5 Mabswid
.5 .5 m
.04004 .37675 L
s
0 1 0 r
.5 .5 m
.04004 .5 L
s
1 0 0 r
.04004 .37675 m
.04004 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.53968 .02474 Mdot
1 0 0 r
.53968 .23285 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo04l0oooo0P00o`1E0?ooo`007@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1=0?ooo`H00?l0D`3o
ool001`0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0f0?ooo`H000001P3oool0
0`000000oooo0?ooo`040?ooo`800000A`3oool7000000H00?l06@3oool800000380oooo000K0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo04<0oooo0`0000060?ooo`P00?l05@3oool3000000P0oooo0`00000_0?oo
o`006P3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00L0oooo2000o`0C0?ooo`80
00003P3oool2000002d0oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0
?P3oool3000000H0oooo00<000000?ooo`3oool0@03oool2000000/0oooo1P00o`0C0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0;0?ooo`H00?l000<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02X0oooo000I0?ooo`030000003oool0oooo0:80oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00h0oooo0P00o`03
0?ooo`8000003P3oool00`000000oooo0?ooo`0C0?ooo`800000:P3oool001P0oooo00<000000?oo
o`3oool0X`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool09`3oool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool09P3oool001L0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03X0oooo0P00000K0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0U0?ooo`005`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0T0?ooo`005P3oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000oooo0?ooo`0S
0?ooo`005@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000002<0oooo00<00000
0?ooo`3oool08P3oool001D0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0000000T0?oo
o`030000003oool0oooo0240oooo000E0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0000002D0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`00000U0?ooo`030000003oool0oooo01l0oooo000D0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`030000003oool0oooo01h0oooo
000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo01h0oooo000A0?ooo`<0003o/03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool000l0oooo1`000?n^0?oo
o`030000003oool0oooo02D0oooo100000060?ooo`8000001P3oool4000000D0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0L0?ooo`003`3oool70000ojh0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000>0?ooo`T0003o[P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool06`3oool000h0oooo10000?l00`3o0000003o0000
o`020000ojh0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool000h0oooo10000?l00`3o0000003o0000o`030000ojh0oooo00<000000?ooo`3oool06@3oool6
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`003`3oool30000
o`040?l000000?l0003o0000o`80oooo10000?nZ0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01T0oooo000?0?ooo`<0003o00@0o`000000o`000?l0003o1P3oool4
0000ojH0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01T0oooo000A0?ooo`030000o`3o0000003o00`0oooo0`000?nS0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000
o`000?ooo`0?0?ooo`@0003oW`3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000o`00
0?ooo`0C0?ooo`@0003oW03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool05`3oool00100oooo00<000000?ooo`3o0000603oool40000oiP0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@
0?ooo`030000003oool0o`0001`0oooo0`000?nE0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0P0?ooo`80o`0000<0oooo0000003oool04`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0o`00
01l0oooo10000?nA0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0O0?ooo`H0o`00503oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01H0oooo000@0?ooo`030000003oool0o`0002<0oooo10000?n>0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000001P3oool60?l000X0
oooo100000070?ooo`030000003oool0oooo00T0oooo1000000E0?ooo`@000005@3oool00100oooo
00<000000?ooo`3o00009`3oool40000ohX0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool80?l000/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool00`000000oooo000000020?ooo`030000003oool0oooo0180oooo
000@0?ooo`030000003oool0o`0002/0oooo0`000?n70?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000001/0oooo00<0
00000?ooo`3oool00P3oool80?l000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0140oooo00H000000?ooo`3oool000000?ooo`00000D0?ooo`00
403oool00`000000oooo0?l0000^0?ooo`@0003oP`3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000J0?ooo`03
0000003oool0oooo00<0oooo1P3o00080?ooo`H000002@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0140oooo0P0000020?ooo`800000503oool000l0oooo00@000000?ooo`3oool0
o`00<P3oool40000ogl0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`80
00001P3oool60?l000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`0000000P00000E0?ooo`003`3oool010000000
oooo0?ooo`3o000f0?ooo`@0003oN`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0103oool00`000000o`000?l0000;0?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0B0?ooo`003`3oool010000000oooo0?ooo`3o000j0?ooo`<0003oN03oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000503oool000l0oooo00@0
00000?ooo`3oool0o`00?@3oool40000og@0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0C0?ooo`<000004@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`003`3oool010000000oooo0?ooo`3o00110?oo
o`@0003oL03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000503oool4000000H0oooo00<000000?oo
o`3oool03P3oool2000000`0oooo00<000000?ooo`3oool01@3oool5000001H0oooo1000000C0?oo
o`003`3oool010000000oooo0?ooo`3o00150?ooo`@0003oK03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool000l0oooo00@000000?ooo`3o
ool0o`00B@3oool30000ofT0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0100oooo000?0?ooo`040000003oool0oooo0?l004`0oooo10000?mU0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?oo
o`003`3oool010000000oooo0?ooo`3o001@0?ooo`@0003oHP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool000l0oooo00@000000?ooo`3o
ool0o`00E03oool40000oeh0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00h0oooo000?0?ooo`040000003oool0oooo0?l005X00?l0G03oool00`00
0000oooo0?ooo`0g0?oooj8000002`3oool000l0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003o
ool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00
3`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo0P00000S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo0P00000R0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`0000008@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0<@3oool0
00l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool00000
0200oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0340oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0
oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000
oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3o
ool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000703oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0
oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?oo
o`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0;03oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
:`3oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:P3oool0
0140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool00180oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`8000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@0
00001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02H0oooo000B0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0
oooo0:h0oooo00<000000?ooo`3oool09@3oool4000000h0oooo1@0000040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool0[P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool08`3oool001@0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool08P3oool001@0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo00h0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002D0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
000Q0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool07P3oool001H0oooo00<00000
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0703oool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool06`3oool001P0oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool06P3o
ool001T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0XP3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0FP3oool2000001T0oooo000J0?ooo`030000003oool0oooo0:00
oooo00<000000?ooo`3oool0?@3oool7000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo
0P00000?0?ooo`800000H@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`8000005`3oool2000000X0oooo0`00001T0?ooo`8000005@3oool001/0oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo1P00000K
0?ooo`X00000J@3oool6000000l0oooo000L0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000N0?ooo`030000003o
ool0oooo09T0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`030000003oool0
oooo09H0oooo0P0000160?ooo`030000003oool0oooo0:d0oooo000O0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0oooo
000R0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0m`3oool00280oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0nP3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3j0?ooo`009@3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?/0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0o03oool002L0oooo0P0000270?ooo`030000003oool0oooo
0?d0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0oP3oool002T0oooo
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?ooo`00:P3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000O@3oool200000?l0oooo103oool002d0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000^0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool2000007H0oooo0P00
003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3oool8
0?ooo`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool003<0
oooo0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`3o0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo0P00003o0?ooo`l0oooo000h0?oo
o`800000I03oool200000?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000o`3ooolC0?ooo`00
?03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3oool003d0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?ooo`800000F03oool2
00000?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00@`3oool2000004l0
oooo0P00003o0?oooa/0oooo00150?ooo`800000B`3oool200000?l0oooo7@3oool004L0oooo0P00
00170?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo1@00003o0?ooob40oooo001=0?oo
o`800000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000o`3ooolX0?ooo`00
DP3oool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool400000?l0oooo;`3o
ool005/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0oooo>P3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.08761 .2619 Mdot
.5 Mabswid
.5 .5 m
.08761 .2619 L
s
0 1 0 r
.5 .5 m
.08761 .5 L
s
1 0 0 r
.08761 .2619 m
.08761 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.57937 .05414 Mdot
1 0 0 r
.57937 .16186 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000J0?ooo`<0003o00<0oooo0000003oool0VP3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001P0oooo
1`000?nK0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2V0?ooo`00603oool70000oi`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0:H0oooo000G0?ooo`T0003oV`3oool00`000000oooo0?ooo`0f
0?ooo`H000001P3oool00`000000oooo0?ooo`040?ooo`800000A`3oool8000001h0oooo2000000b
0?ooo`005`3oool40000o`030?l000000?l0003o0080003oW03oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool3000000P0oooo00<000000?oo
o`3oool0603oool3000000P0oooo0`00000_0?ooo`005`3oool40000o`030?l000000?l0003o0080
003oW03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0:0?ooo`8000005P3oool2000000h0oooo0P00000]0?ooo`00
603oool30000o`030?l000000?l0003o0080003oW@3oool00`000000oooo0?ooo`0n0?ooo`<00000
1P3oool00`000000oooo0?ooo`100?ooo`8000003`3oool2000000<0oooo0P00o`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0:`3oool001P0oooo0`000?l01@3o0000003o0000
o`000?l0oooo0080003oV`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0A0?ooo`0300000000o`000?l000@00?l0
2`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02X0oooo000I0?ooo`0400000000
0?l0o`000000o`D0oooo00<0003o0?ooo`3oool0V@3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool04`3oool6003o00X0oooo00<000000?ooo`3oool0
4`3oool2000002X0oooo000H0?ooo`040000003oool0oooo0?l000L0oooo0P000?nI0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`P00?l0
203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02L0oooo000H0?ooo`040000003o
ool0oooo0?l000T0oooo0P000?nH0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0D0?ooo`P00?l01`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo02H0oooo000G0?ooo`050000003oool0oooo0?ooo`3o00002`3oool20000oiH0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0j0?ooo`800000603oool6003o00L0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool01@000000oooo0?oo
o`3oool0o`0000d0oooo00<0003o0?ooo`3oool0U03oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0603oool6003o00H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00`0oooo0P000?nD0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0K0?ooo`800?l000<0oooo0000003oool0103oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003oool0oooo0080oooo00<0o`00
0?ooo`3oool03P3oool20000oi<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003o
ool0oooo02<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0403oool2
0000oi40oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0200oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0R0?ooo`005@3oool0
0`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0180oooo0P000?n@0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
000002@0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo08d0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo01D0
oooo0P000?n>0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0803oool001D0oooo
00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0G0?ooo`80003oS03oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo
0?ooo`00000U0?ooo`030000003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo00@0oooo
00<0o`000?ooo`3oool06@3oool20000oh/0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`03
0000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`280?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo01`0oooo0P000?n80?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0M0?ooo`004`3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo01h0oooo0P000?n60?ooo`030000003oool0oooo02D0oooo100000060?ooo`8000001P3oool4
000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`80o`0000<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01`0oooo000B0?oo
o`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0803oool20000oh@0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0200oooo1P3o00070?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool06`3oool00180oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0R0?ooo`03
0000o`3oool0oooo0880oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo0200oooo1P3o00080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool06`3oool00180oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0S0?ooo`80003o
PP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo0?ooo`0P0?ooo`P0o`00
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<0o`000?ooo`3oool09@3oool20000oh40oooo00<000000?ooo`3oool06@3o
ool6000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Q0?ooo`P0o`00203o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0
oooo00L0oooo00<0o`000?ooo`3oool09`3oool20000ogl0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo100000050?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool08P3oool60?l000X0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo
02T0oooo00<0003o0?ooo`3oool0O03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool08`3oool60?l000X0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo02X0
oooo0P000?ml0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0S0?ooo`040000003oool0o`000?l000d0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo02`0
oooo0P000?mj0?ooo`030000003oool0oooo02<0oooo1000000>0?ooo`D00000103oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo00L0oooo
00<0o`000?ooo`3oool0;P3oool20000ogT0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo00P0oooo00<0
o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`1f0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`08
0?ooo`030?l0003oool0oooo0340oooo0P000?mf0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`080?oo
o`030?l0003oool0oooo03<0oooo0P000?md0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`080?ooo`03
0?l0003oool0oooo03D0oooo0P000?mc0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool04P3oool700000140oooo1P00000C0?ooo`@000002P3oool00`000000oooo0?ooo`090?ooo`@0
00001`3oool00`000000oooo0?ooo`090?ooo`@000005@3oool4000001D0oooo000@0?ooo`030000
003oool0oooo00P0oooo00<0o`000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`1`0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool000000080oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0h0?ooo`80003oL03oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000K0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04@3oool01P000000oooo0?ooo`000000oooo000001@0
oooo000@0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0>P3oool20000ofh0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo1P0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool200000080
oooo0P00000D0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo03`0oooo
0P000?m/0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool2000000P0oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool04@3oool00`000000oooo00000002000001D0oooo000?0?ooo`030000
003oool0oooo00T0oooo00<0o`000?ooo`3oool0?P3oool20000ofX0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00H0oooo1000000D0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`100?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool05P3oool01@000000oooo0?ooo`3oool0000001@0oooo000?0?ooo`030000003oool0oooo00T0
oooo00<0o`000?ooo`3oool0@@3oool20000ofL0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0C0?ooo`<000004@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01L0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`003`3oool00`000000oooo0?ooo`090?oo
o`030?l0003oool0oooo04<0oooo0P000?mU0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo1000000D0?oo
o`@000001P3oool00`000000oooo0?ooo`0>0?ooo`800000303oool00`000000oooo0?ooo`050?oo
o`D000005P3oool4000001<0oooo000?0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3o
ool0A@3oool20000of<0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0
A`3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030?l0003o
ool0oooo04P0oooo0P000?mP0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0
oooo04X0oooo0P000?mO0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo
04`0oooo0P000?mM0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030?l00000o`000?l004l0
0?l0G03oool00`000000oooo0?ooo`0g0?oooj8000002`3oool000l0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`000004
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003o
ool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo0P00
000S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo0P00000R
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b
0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`0000008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0<@3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool000000200oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0340oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0
?03oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000
003oool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<000000?ooo`3oool0
]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`00
0000703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0;`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3o
ool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<0
00000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0:P3oool00140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool0
0180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0/03oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02H0oooo
000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo000C0?oo
o`030000003oool0oooo0:h0oooo00<000000?ooo`3oool09@3oool4000000h0oooo1@0000040?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool08`3oool001@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool08P3oool001@0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002D0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2Z
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo0000000Q0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool07P3oool0
01H0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0703oool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06`3oool001P0oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool2000001T0oooo000J0?ooo`030000
003oool0oooo0:00oooo00<000000?ooo`3oool0?@3oool7000000<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0180oooo0P00000?0?ooo`800000H@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`8000005`3oool2000000X0oooo0`00001T0?ooo`8000005@3oool0
01/0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00@0oooo1P00000K0?ooo`X00000J@3oool6000000l0oooo000L0?ooo`030000003oool0oooo09`0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0
oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000N
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O0?oo
o`030000003oool0oooo09H0oooo0P0000160?ooo`030000003oool0oooo0:d0oooo000O0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0
U03oool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0?L0oooo000R0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0m`3oool0
0280oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`3j0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?/0oooo000V0?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0o03oool002L0oooo0P0000270?ooo`03
0000003oool0oooo0?d0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
oP3oool002T0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?ooo`00:P3oool0
0`000000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000O@3oool200000?l0
oooo103oool002d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo
000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool2
000007H0oooo0P00003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool0o`3oool80?ooo`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0
oooo203oool003<0oooo0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`3o0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo0P00003o0?oo
o`l0oooo000h0?ooo`800000I03oool200000?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000
o`3ooolC0?ooo`00?03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3o
ool003d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?oo
o`800000F03oool200000?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00
@`3oool2000004l0oooo0P00003o0?oooa/0oooo00150?ooo`800000B`3oool200000?l0oooo7@3o
ool004L0oooo0P0000170?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo1@00003o0?oo
ob40oooo001=0?ooo`800000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000
o`3ooolX0?ooo`00DP3oool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool4
00000?l0oooo;`3oool005/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0
oooo>P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.16328 .16328 Mdot
.5 Mabswid
.5 .5 m
.16328 .16328 L
s
0 1 0 r
.5 .5 m
.16328 .5 L
s
1 0 0 r
.16328 .16328 m
.16328 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.61905 .10091 Mdot
1 0 0 r
.61905 .10091 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000Y0?ooo`<0003o0P3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo0?l0oooo1@3oool002L0oooo1`000?ml0?ooo`800000o`3oool50?ooo`009`3oool7
0000ogh0oooo00<000000?ooo`3oool0o`3oool20?ooo`009P3oool90000ogh0oooo00<000000?oo
o`3oool0o`3oool10?ooo`009P3oool40000o`030?l000000?l0003o0080003oO`3oool00`000000
oooo0?ooo`3o0?ooo`009P3oool40000o`030?l000000?l0003o0080003oP03oool00`000000oooo
0?ooo`3n0?ooo`009`3oool30000o`040?l000000?l0003o0000oh80oooo00<000000?ooo`3oool0
o@3oool002L0oooo0`000?l0103o0000003o0000o`000?n20?ooo`030000003oool0oooo0?d0oooo
000V0?ooo`060000003oool0oooo0000o`3o0000003o0P3oool00`000?l0oooo0?ooo`200?ooo`03
0000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`200?ooo`030000003oool0oooo0?/0oooo000T0?ooo`030000003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`200?ooo`030000003o
ool0oooo0?X0oooo000S0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`200?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`200?ooo`030000003oool0oooo
0?P0oooo000R0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`200?ooo`030000003oool0oooo0?L0oooo000Q0?ooo`030000003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1o0?ooo`030000003oool0oooo0?L0oooo
000P0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`1o0?ooo`030000003oool0oooo0?H0oooo000O0?ooo`030000003oool0oooo00P0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1n0?ooo`030000003oool0oooo0?H0oooo000O0?oo
o`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`1n0?oo
o`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`1n0?ooo`030000003oool0oooo0440oooo1`00002/0?ooo`00
7P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
OP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
YP3oool001d0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo07d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0:H0oooo000M0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`1m0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2V0?ooo`00703oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool0O03oool00`000000oooo0?ooo`0f0?ooo`H000001P3oool00`00
0000oooo0?ooo`040?ooo`800000A`3oool8000001h0oooo2000000b0?ooo`006`3oool00`000000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0O03oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool3000000P0
oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0:0?ooo`8000005P3oool2000000h0oooo0P00000]0?ooo`006P3oool00`000000oooo0?oo
o`0=0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?oo
o`0n0?ooo`<000001P3oool00`000000oooo0?ooo`100?ooo`8000003`3oool2000001<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0[0?ooo`006@3oool00`000000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Z
0?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool0NP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool04`3oool2000000h0oooo00<000000?ooo`3oool04`3oool2000002X0oooo000H0?ooo`03
0000003oool0oooo00l0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`1i0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0W0?ooo`00
603oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0
N@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
9P3oool001L0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3o
ool0oooo07P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0j0?ooo`8000006`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09@3o
ool001L0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
oooo07P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02@0oooo000F0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`1g0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0080o`0000<0oooo0000003oool07P3oool00`00
0000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool0M`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0803oool60?l00200oooo00<000000?ooo`3oool08`3oool001D0oooo
00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo07H0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo
1P3o000Q0?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0180oooo00<0
o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`1f0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0P0?ooo`P0o`008@3oool00`000000oooo0?oo
o`0Q0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo01d0oooo00<0003o
0?ooo`3oool0M@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool08@3oool80?l00280oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0N0?ooo`80003oMP3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool08P3oool60?l002<0oooo00<000000?oo
o`3oool0803oool001D0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0P0?ooo`03
0000o`3oool0oooo07<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo02<0oooo1P3o000T0?ooo`030000003oool0oooo01l0oooo000D0?ooo`030000
003oool0oooo01<0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`1c0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0S0?ooo`050000
003oool0o`000?l0000000009P3oool00`000000oooo0?ooo`0N0?ooo`00503oool00`000000oooo
0?ooo`0C0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0LP3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool001<0oooo00<0
00000?ooo`3oool0503oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0740oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01d0oooo000C
0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`1`
0?ooo`030000003oool0oooo02D0oooo100000060?ooo`8000001P3oool4000000D0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool06`3oool00180oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0V0?ooo`03
0000o`3oool0oooo06l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000a0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01X0oooo000B0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0oooo01T0oooo1P0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool06P3oool00140oooo00<000000?ooo`3oool05P3oool0
0`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo06d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo100000050?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo06`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo000A0?ooo`030000003oool0oooo01H0
oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`1[0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo
0?ooo`0F0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0JP3oool00`000000oooo
0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo02d0oooo00<0
003o0?ooo`3oool0JP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool05`3oool00100oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0^
0?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo01L0oooo00<0o`000?oo
o`3oool0;`3oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo0300oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`0a0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0B0?ooo`L000004@3oool6000001<0oooo1000000:0?ooo`030000
003oool0oooo00T0oooo100000070?ooo`030000003oool0oooo00T0oooo1000000E0?ooo`@00000
5@3oool00100oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3o
ool0oooo06H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`00403oool0
0`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo03<0oooo00<0003o0?ooo`3oool0I@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0000000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool0
1P000000oooo0?ooo`000000oooo000001@0oooo000@0?ooo`030000003oool0oooo01L0oooo00<0
o`000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000001X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`H000002@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0140oooo0P0000020?ooo`800000503oool000l0oooo00<0
00000?ooo`3oool0603oool00`3o0000oooo0?ooo`0e0?ooo`030000o`3oool0oooo06<0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`800000203oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool00000008000005@3oool000l0oooo00<000000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00H0oooo1000000D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
5P3oool01@000000oooo0?ooo`3oool0000001@0oooo000?0?ooo`030000003oool0oooo01P0oooo
00<0o`000?ooo`3oool0>03oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool04`3oool300000140oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`0000004`3oool000l0oooo00<000000?ooo`3o
ool0603oool00`3o0000oooo0?ooo`0i0?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool4000001@0oooo100000060?ooo`030000003oool0oooo00h0oooo0P00000<0?ooo`03
0000003oool0oooo00D0oooo1@00000F0?ooo`@000004`3oool000l0oooo00<000000?ooo`3oool0
603oool00`3o0000oooo0?ooo`0j0?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003o
ool0oooo01P0oooo00<0o`000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`1M0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo03`0oooo00<0003o0?ooo`3oool0G03oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool0
00l0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`0m0?ooo`030000o`3oool0oooo
05`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00l0oooo000?0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0?P3oool00`000?l0
oooo0?ooo`1K0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0H0?ooo`030?l00000o`000?l004000?l0
G03oool00`000000oooo0?ooo`0g0?oooj8000002`3oool000l0oooo00<000000?ooo`3oool0]`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0
oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo0P00000S
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b
0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo0P00000R0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?oo
o`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0<@3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool000000200oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0340oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03o
ool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<0
00000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
;`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool0
0100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo
00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0:`3oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?ooo`3o
ool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0:P3oool00140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool00180
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02H0oooo000B
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo000C0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool09@3oool4000000h0oooo1@0000040?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
8`3oool001@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool08P3oool001@0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000009P3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002D0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`2Z
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3o
ool0oooo0000000Q0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool07P3oool001H0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo00<0
00000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0703oool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06`3oool001P0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool06P3oool001T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool2000001T0oooo000J0?ooo`030000003o
ool0oooo0:00oooo00<000000?ooo`3oool0?@3oool7000000<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0180oooo0P00000?0?ooo`800000H@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`8000005`3oool2000000X0oooo0`00001T0?ooo`8000005@3oool001/0
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0
oooo1P00000K0?ooo`X00000J@3oool6000000l0oooo000L0?ooo`030000003oool0oooo09`0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo
000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000N0?oo
o`030000003oool0oooo09T0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`03
0000003oool0oooo09H0oooo0P0000160?ooo`030000003oool0oooo0:d0oooo000O0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo0?L0oooo000R0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0m`3oool00280
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3j
0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?/0oooo000V0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0o03oool002L0oooo0P0000270?ooo`030000
003oool0oooo0?d0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0oP3o
ool002T0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?ooo`00:P3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000O@3oool200000?l0oooo
103oool002d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000^
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool20000
07H0oooo0P00003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0o`3oool80?ooo`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo
203oool003<0oooo0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`3o0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo0P00003o0?ooo`l0
oooo000h0?ooo`800000I03oool200000?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000o`3o
oolC0?ooo`00?03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3oool0
03d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?ooo`80
0000F03oool200000?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00@`3o
ool2000004l0oooo0P00003o0?oooa/0oooo00150?ooo`800000B`3oool200000?l0oooo7@3oool0
04L0oooo0P0000170?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo1@00003o0?ooob40
oooo001=0?ooo`800000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000o`3o
oolX0?ooo`00DP3oool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool40000
0?l0oooo;`3oool005/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0oooo
>P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.2619 .08761 Mdot
.5 Mabswid
.5 .5 m
.2619 .08761 L
s
0 1 0 r
.5 .5 m
.2619 .5 L
s
1 0 0 r
.2619 .08761 m
.2619 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.65873 .16186 Mdot
1 0 0 r
.65873 .05414 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo000l0?ooo`<0003o1`3oool2000004T0oooo0P00003o0?oooah0oooo
000j0?ooo`L0003o0P3oool3000004d0oooo0P00003o0?oooa`0oooo000j0?ooo`L0003o0P00001B
0?ooo`800000o`3ooolJ0?ooo`00>@3oool90000oeD0oooo0P00003o0?oooaP0oooo000i0?ooo`@0
003o00<0o`000000o`000?l00P000?mG0?ooo`800000o`3ooolF0?ooo`00>@3oool40000o`030?l0
00000?l0003o0080003oF@3oool200000?l0oooo503oool003T0oooo00D000000000o`000?l0003o
0?l000030000oe`0oooo0P00003o0?oooa80oooo000h0?ooo`030000003oool0003o0080003o00@0
o`000000o`000?l0003oGP3oool200000?l0oooo403oool003L0oooo00<000000?ooo`3oool00P3o
ool010000?l0o`000000o`000?mQ0?ooo`030000003oool0oooo0?l0oooo3@3oool003H0oooo00<0
00000?ooo`3oool0103oool0103o0000oooo0?ooo`000?mQ0?ooo`030000003oool0oooo0?l0oooo
303oool003@0oooo0P0000070?ooo`050?l0003oool0oooo0?ooo`000?l0H@3oool200000?l0oooo
303oool003<0oooo00<000000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o06<0oooo
00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool00`000000oooo0?ooo`080?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000`
0?ooo`8000002`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0680oooo00<00000
0?ooo`3oool0o`3oool70?ooo`00;`3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`03
0000003oool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1S0?ooo`03
0000003oool0oooo0?l0oooo1@3oool002d0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo06<0oooo0P00003o0?ooo`D0oooo000/0?ooo`030000003o
ool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1T0?ooo`030000003o
ool0oooo0?l0oooo0P3oool002/0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo06D0oooo00<000000?ooo`3oool0o`3oool10?ooo`00:@3oool20000
0180oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo
0?l0oooo000X0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`1V0?ooo`030000003oool0oooo0?h0oooo000X0?ooo`030000003oool0oooo0180oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo0?d0oooo
000W0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`1U0?ooo`030000003oool0oooo0?d0oooo000V0?ooo`030000003oool0oooo01@0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo0?`0oooo000U0?oo
o`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1V0?oo
o`030000003oool0oooo0?/0oooo000T0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo0?X0oooo000S0?ooo`030000
003oool0oooo01L0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`1W0?ooo`030000
003oool0oooo0?T0oooo000R0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo0?P0oooo000R0?ooo`030000003oool0
oooo01P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0
oooo0?L0oooo000Q0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`1W0?ooo`030000003oool0oooo0?L0oooo000P0?ooo`030000003oool0oooo01X0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo0?H0
oooo000O0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`1W0?ooo`030000003oool0oooo0?H0oooo000O0?ooo`030000003oool0oooo01/0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo0?D0oooo000N
0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1X
0?ooo`030000003oool0oooo0440oooo1`00002/0?ooo`007P3oool00`000000oooo0?ooo`0L0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001d0oooo00<000000?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo01d0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1X0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`00703o
ool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0J03o
ool00`000000oooo0?ooo`0f0?ooo`H000001P3oool00`000000oooo0?ooo`040?ooo`800000A`3o
ool8000001h0oooo2000000b0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0@`3oool3000000P0oooo00<000000?ooo`3oool0603oool3
000000P0oooo0`00000_0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0:0?ooo`8000005P3oool20000
00h0oooo0P00000]0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`0n0?ooo`<000001P3oool00`000000
oooo0?ooo`100?ooo`8000003`3oool2000000l0oooo0P3o00020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0:0?ooo`H0o`004`3oool00`000000oooo0?ooo`0Z0?ooo`006@3oool00`000000oooo0?oo
o`0Q0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04`3oool2000000X0oooo1P3o
000D0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool80?l001D0oooo00<00000
0?ooo`3oool09`3oool001P0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool80?l001H0oooo00<000000?oo
o`3oool09P3oool001L0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo06L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0j0?ooo`80
00006`3oool00`000000oooo0?ooo`060?ooo`H0o`00603oool00`000000oooo0?ooo`0U0?ooo`00
5`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0
I`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`050?ooo`H0o`006@3oool00`000000oooo0?ooo`0T0?ooo`005P3o
ool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0I`3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080o`006`3oool00`000000oooo0?oo
o`0T0?ooo`005P3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01L0oooo00<0003o
0?ooo`3oool0I`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0803oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool08`3o
ool001D0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo06L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0200oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0R0?ooo`005@3oool0
0`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0I`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`030000003oool0oooo
02D0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool09@3oool00`3o0000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`0000009@3oool00`000000
oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo01X0oooo
00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000003oool0oooo01l0
oooo000D0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`1W0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`0N0?ooo`00
503oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0
IP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
7P3oool001<0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3o
ool0oooo06D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01d0oooo000C0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0703oool0
0`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo02D0oooo100000060?ooo`8000001P3oool4
000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00H0oooo00<00000003o0000o`008`3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`00
0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool0I03oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`H00?l08P3oool00`00
0000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo01d0
oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`H00?l08P3oool00`000000
oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo01h0oooo
00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00H0oooo2000o`0R0?ooo`030000003oool0oooo01X0oooo
000B0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?oo
o`1U0?ooo`030000003oool0oooo01T0oooo1P0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`070?ooo`P00?l08P3oool00`000000oooo0?oo
o`0J0?ooo`004@3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01l0oooo00<0003o
0?ooo`3oool0I03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00P0oooo1P00o`0T0?ooo`030000003oool0oooo01T0oooo000A0?oo
o`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`1S0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00T0oooo1P00o`0T0?ooo`030000003oool0oooo01T0oooo000A0?ooo`03
0000003oool0oooo02T0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`1S0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00/0oooo0P00o`000`3oool000000?ooo`0T0?ooo`030000003oool0oooo01P0
oooo000A0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`1R0?ooo`030000003oool0oooo02<0oooo1000000>0?ooo`D00000103oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo02T0oooo00<0
o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool00100oooo00<000000?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0640oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo000@0?ooo`03
0000003oool0oooo02X0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`1Q0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0
H@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0180oooo1`00000A0?ooo`H00000
4`3oool4000000X0oooo00<000000?ooo`3oool02@3oool4000000L0oooo00<000000?ooo`3oool0
2@3oool4000001D0oooo1000000E0?ooo`00403oool00`000000oooo0?ooo`0Z0?ooo`030?l0003o
ool0oooo02@0oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0180oooo000@0?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0A0?ooo`060000003oool0oooo0000003oool00000503oool00100oooo00<0
00000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo05l0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`3oool000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
1P0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool200000080oooo
0P00000D0?ooo`003`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02H0oooo00<0
003o0?ooo`3oool0G`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo0P00
00080?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P00000E0?ooo`003`3o
ool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
1P3oool4000001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`003`3o
ool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000503oool000l0oooo
00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo05d0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`<000004@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000303oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0000000C0?oo
o`003`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`020?ooo`@00000503oool4000000H0oooo00<000000?ooo`3o
ool03P3oool2000000`0oooo00<000000?ooo`3oool01@3oool5000001H0oooo1000000C0?ooo`00
3`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0
G03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
403oool000l0oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3o
ool0oooo05/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0100oooo000?0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool0:P3oool0
0`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo
02/0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0:`3oool00`3o0000
oooo0?ooo`0[0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo02/0oooo
00<0o`00003o0000o`00;@00o`1L0?ooo`030000003oool0oooo03L0ooooXP00000;0?ooo`003`3o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo
0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo000?0?ooo`030000003oool0oooo0;L0oooo00<00000
0?ooo`3oool0>`3oool2000002<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0>`3oool200000280oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0000000Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`0l0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000N0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo
0000000M0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00D0
00000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool0
0`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0^0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?ooo`00403oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?oo
o`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0/0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0[0?ooo`00403oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0[0?oo
o`004@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`2c0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`004@3o
ool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02<0oooo100000060?ooo`8000001P3o
ool4000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0Y0?ooo`004@3oool0
0`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0X0?ooo`004P3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02L0oooo
000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo100000050?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool09P3oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?oo
o`3oool0[P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool09@3oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0U0?ooo`@0
00003P3oool5000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0T0?ooo`00
4`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0S0?ooo`00503oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000002D0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`00000V0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001D0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`0000009@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0240oooo000E
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?
0?ooo`8000009P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0200oooo000E0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?oo
o`8000009@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01l0oooo000E0?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`04
0000003oool0oooo000002<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0O0?oo
o`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0N0?ooo`005P3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0N0?ooo`005`3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0M0?ooo`005`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0L0?ooo`00603oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0K
0?ooo`00603oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0J0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0I0?ooo`00
6@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
1`3oool2000000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1J0?ooo`800000
6@3oool001X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0m0?ooo`L000000`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000003oool0
oooo0:00oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool04P3oool2000000l0oooo0P00001Q0?ooo`030000003oool0
oooo01D0oooo000J0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`8000002P3oool30000
06@0oooo0P00000E0?ooo`006`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0103oool6000001/0oooo2P00001Y0?ooo`H000003`3oool001`0oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0YP3oool001d0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001d0oooo00<00000
0?ooo`3oool0VP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0YP3oool001h0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`110?oo
o`<00000[`3oool001l0oooo00<000000?ooo`3oool0UP3oool2000004H0oooo00<000000?ooo`3o
ool0[@3oool001l0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`00803o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0?P0
oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0n@3oool002@0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0n`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`3l0?ooo`00
9`3oool2000008L0oooo00<000000?ooo`3oool0o@3oool002P0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`3n0?ooo`00:@3oool00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0?l0oooo000Z0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3oool10?oo
o`00:`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0oooo0@3oool002`0oooo
0P00001m0?ooo`800000o`3oool40?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0?l0oooo103oool002h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`3o
0?ooo`D0oooo000_0?ooo`800000MP3oool200000?l0oooo203oool00340oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000b0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool0o`3oool80?ooo`00<`3oool2000006l0oooo0P00003o0?ooo`/0oooo000e
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3oool;0?ooo`00=P3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0oooo303oool003L0oooo00<000000?ooo`3o
ool0IP3oool200000?l0oooo3`3oool003P0oooo0P00001T0?ooo`800000o`3ooolA0?ooo`00>P3o
ool200000600oooo0P00003o0?oooa<0oooo000l0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`00?@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
0?l0oooo503oool003h0oooo0P00001H0?ooo`800000o`3ooolG0?ooo`00@03oool3000005<0oooo
0P00003o0?oooaT0oooo00130?ooo`800000C`3oool200000?l0oooo6`3oool004D0oooo0P00001;
0?ooo`800000o`3ooolM0?ooo`00A`3oool2000004L0oooo0P00003o0?oooal0oooo00190?ooo`@0
0000?P3oool500000?l0oooo8@3oool004d0oooo0P00000j0?ooo`800000o`3ooolV0?ooo`00C`3o
ool3000003D0oooo0P00003o0?ooobP0oooo001B0?ooo`@00000;03oool500000?l0oooo:P3oool0
05H0oooo1@00000S0?ooo`@00000o`3oool_0?ooo`00F`3oool7000001D0oooo1`00003o0?oooc<0
oooo001R0?oooaD00000o`3ooolj0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.37675 .04004 Mdot
.5 Mabswid
.5 .5 m
.37675 .04004 L
s
0 1 0 r
.5 .5 m
.37675 .5 L
s
1 0 0 r
.37675 .04004 m
.37675 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.69841 .23285 Mdot
1 0 0 r
.69841 .02474 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00DP3oool30000oa80oooo2`00
003o0?ooocl0oooo001@0?ooo`L0003o1`3oool9000000/0oooo2@00003o0?ooocH0oooo001@0?oo
o`L0003o0P3oool5000001d0oooo1000003o0?oooc80oooo001?0?ooo`D0003o00D0o`000000o`00
0?l0003o0000000V0?ooo`D00000o`3oool]0?ooo`00C`3oool50000o`040?l000000?l0003o0000
ob`0oooo1000003o0?ooobT0oooo001>0?ooo`03000000000?l0003o00<0003o00@0o`000000o`00
0?l0003o<03oool300000?l0oooo9P3oool004`0oooo0P0000020?ooo`@0003o00<0o`000000o`00
0?l0=03oool200000?l0oooo903oool004X0oooo0P0000040?ooo`@0003o00<0o`000000o`000?l0
=P3oool200000?l0oooo8P3oool004P0oooo0P0000080?ooo`80003o00<0o`000000o`3oool0>03o
ool200000?l0oooo803oool004H0oooo0P00000<0?ooo`030?l0003oool0003o03X0oooo0P00003o
0?oooah0oooo00130?ooo`<000003P3oool00`3o0000oooo0000o`0l0?ooo`800000o`3ooolL0?oo
o`00@@3oool200000140oooo00<0o`000?ooo`000?l0?P3oool200000?l0oooo6P3oool003l0oooo
0P00000C0?ooo`030?l0003oool0003o0400oooo0P00003o0?oooaP0oooo000m0?ooo`8000005@3o
ool0103o0000oooo0?ooo`000?m10?ooo`800000o`3ooolF0?ooo`00>`3oool2000001L0oooo00@0
o`000?ooo`3oool0003o@`3oool200000?l0oooo503oool003T0oooo0P00000I0?ooo`040?l0003o
ool0oooo0000odD0oooo0P00003o0?oooa80oooo000h0?ooo`030000003oool0oooo01T0oooo00@0
o`000?ooo`3oool0003oA`3oool200000?l0oooo403oool003L0oooo00<000000?ooo`3oool06P3o
ool01@3o0000oooo0?ooo`3oool0003o04P0oooo00<000000?ooo`3oool0o`3oool=0?ooo`00=P3o
ool00`000000oooo0?ooo`0K0?ooo`050?l0003oool0oooo0?ooo`000?l0B@3oool00`000000oooo
0?ooo`3o0?ooo``0oooo000d0?ooo`8000007P3oool01@3o0000oooo0?ooo`3oool0003o04X0oooo
0P00003o0?ooo``0oooo000c0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo2@3oool00380oooo00<00000
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo04X0oooo00<00000
0?ooo`3oool0o`3oool80?ooo`00<03oool200000280oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3o
ool08P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3o
ool0o`3oool60?ooo`00;P3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooo`D0oooo000]0?ooo`030000003o
ool0oooo02@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1=0?ooo`800000o`3o
ool50?ooo`00;03oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?ooo`80oooo000[0?ooo`030000003oool0oooo
02H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo
0?l0oooo0@3oool002T0oooo0P00000Y0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0D03oool00`000000oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`3n0?ooo`00:03o
ool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0DP3o
ool00`000000oooo0?ooo`3m0?ooo`009`3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`00
0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0DP3oool00`00
0000oooo0?ooo`3l0?ooo`009@3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`3k0?ooo`00903oool00`000000oooo
0?ooo`0]0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo
0?ooo`3j0?ooo`008`3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0E03oool00`000000oooo0?ooo`3i0?ooo`008P3oool00`000000oooo0?ooo`0_
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0E@3oool00`000000oooo0?ooo`3h
0?ooo`008P3oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0EP3oool00`000000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`3g0?ooo`00
803oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
EP3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`0b0?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`3f0?ooo`007`3oool0
0`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0E`3oool0
0`000000oooo0?ooo`3e0?ooo`007P3oool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`110?ooo`L00000[03oool001h0
oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo05P0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0
oooo000M0?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`1H0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1Y0?ooo`80o`00>`3oool001d0oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06L0oooo1P3o000i0?ooo`00703oool00`000000oooo0?ooo`0e
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`0f
0?ooo`H000001P3oool00`000000oooo0?ooo`040?ooo`800000A`3oool8000001T0oooo1P3o0007
00000380oooo000K0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`1I0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`130?ooo`<00000203oool00`000000oooo0?ooo`0E0?ooo`P0o`001P3oool30000
02l0oooo000J0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`1I0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`P0o`002@3oool2000002d0
oooo000J0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`1J0?ooo`030000003oool0oooo03h0oooo0`0000060?ooo`030000003oool0oooo0400oooo
0P00000?0?ooo`8000004`3oool00`000000o`000?l000040?l000/0oooo00<000000?ooo`3oool0
:`3oool001T0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo05T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0o`0000D0o`00303oool00`000000oooo0?ooo`0Z0?ooo`006@3oool00`000000oooo0?ooo`0h
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04`3oool2000000h0oooo00<00000
0?ooo`3oool00P3oool20?l000l0oooo0P00000Z0?ooo`00603oool00`000000oooo0?ooo`0i0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0>@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo000G0?ooo`030000
003oool0oooo03X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1J0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0>P3oool2000001/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02D0oooo000G0?ooo`030000003o
ool0oooo03X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1K0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0F`3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0903oool0
01H0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
05`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0200oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo02<0oooo000E0?oo
o`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1K0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0?03oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo05`0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`000000903oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`0l0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0200oooo000E0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo05`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02@0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`0O0?ooo`00503o
ool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0G@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08`3o
ool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool07P3oool001@0oooo00<0
00000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo05d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1L
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0M
0?ooo`004`3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool0G03oool00`000000oooo0?ooo`0U0?ooo`@000001P3oool2000000H0oooo100000050?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0703oool00180oooo00<000000?ooo`3o
ool0?`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`800000<@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0J0?ooo`004P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0400oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo000A0?ooo`030000003oool0oooo0400
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo
0?ooo`100?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0G03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0@03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05`0oooo00<0
00000?ooo`3oool08`3oool4000000h0oooo1@0000040?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0603oool00140oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo0440oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`110?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`04
0000003oool00?l0003o0280oooo00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3o
ool0@@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool04`3oool6003o0200oooo00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3oool0
@@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0B0?ooo`L000004@3oool6000001<0oooo1000000:0?ooo`030000
003oool0oooo00T0oooo100000060?ooo`H00?l01`3oool4000001D0oooo1000000E0?ooo`00403o
ool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0G03o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool8003o00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0@@3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000006`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool8
003o00X0oooo00<000000?ooo`3oool04@3oool01P000000oooo0?ooo`000000oooo000001@0oooo
000@0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`1L0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`H000001P3oool6003o00/0oooo00<000000?ooo`3oool04@3oool200000080oooo
0P00000D0?ooo`003`3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo0P00
00080?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000001`3oool6003o00/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo00000002000001D0oooo000?0?ooo`030000003o
ool0oooo0480oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`1K0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool000002@3oool2003o00030000003oool0oooo00H0oooo
1000000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool000l0oooo00<0
00000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo05/0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000001@0oooo000?0?ooo`030000
003oool0oooo0480oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`1K0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`0000004`3oool000l0
oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo05/0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool4000001@0oooo100000060?ooo`030000003oool0oooo00h0
oooo0P00000<0?ooo`030000003oool0oooo00D0oooo1@00000F0?ooo`@000004`3oool000l0oooo
00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo05X0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo
000?0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`1J0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0@0?ooo`003`3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo01@0oooo00<0003o
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`120?ooo`030?l0
0000o`000?l001H00?l0G03oool00`000000oooo0?ooo`0g0?oooj8000002`3oool000l0oooo00<0
00000?ooo`3oool0]`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0
00000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo03/0oooo0P00000S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo
03/0oooo0P00000R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool000000200oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0340oooo000?0?ooo`030000003oool0oooo0;H0oooo00<0
00000?ooo`3oool0?03oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<0
00000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
7@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
;`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003o
ool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0;03o
ool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140
oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0/`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo1000
00050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:@3oool00140oooo00<00000
0?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?oo
o`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0:03oool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`004P3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo02H0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo
0:h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool09@3oool4000000h0
oooo1@0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool08`3oool001@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool001@0oooo00<000000?ooo`3oool0[03o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000
9P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0000002D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2
000002H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool20000
02D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool010000000
oooo0?ooo`00000S0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool07`3oool001H0
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool07P3oool001H0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
7@3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0703oool001P0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06`3oool0
01P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool06P3oool001T0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool06@3oool001T0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo
0P00000?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool2000001T0oooo
000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?@3oool7000000<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`2P
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0180oooo0P00000?0?ooo`800000H@3oool00`000000oooo0?ooo`0E
0?ooo`006P3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`8000005`3oool2000000X0oooo0`00001T0?oo
o`8000005@3oool001/0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo00@0oooo1P00000K0?ooo`X00000J@3oool6000000l0oooo000L0?ooo`030000
003oool0oooo09`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:H0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0@@3oool30000
0:l0oooo000O0?ooo`030000003oool0oooo09H0oooo0P0000160?ooo`030000003oool0oooo0:d0
oooo000O0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0mP3oool00200oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000003oool0oooo0940oooo00<000000?oo
o`3oool0m`3oool00280oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`00
8`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo
0?/0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0o03oool002L0oooo
0P0000270?ooo`030000003oool0oooo0?d0oooo000X0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool0oP3oool002T0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o
0?ooo`00:P3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo0@3oool002/0
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000
O@3oool200000?l0oooo103oool002d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0o`3oool5
0?ooo`00;`3oool2000007H0oooo0P00003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0o`3oool80?ooo`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0?l0oooo203oool003<0oooo0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`3o0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0
oooo0P00003o0?ooo`l0oooo000h0?ooo`800000I03oool200000?l0oooo4@3oool003X0oooo0P00
001P0?ooo`800000o`3ooolC0?ooo`00?03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo0?l0oooo4`3oool003d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oo
oa@0oooo000n0?ooo`800000F03oool200000?l0oooo5`3oool00400oooo0`00001C0?ooo`800000
o`3ooolI0?ooo`00@`3oool2000004l0oooo0P00003o0?oooa/0oooo00150?ooo`800000B`3oool2
00000?l0oooo7@3oool004L0oooo0P0000170?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0
oooo1@00003o0?ooob40oooo001=0?ooo`800000>P3oool200000?l0oooo9P3oool004l0oooo0`00
000e0?ooo`800000o`3ooolX0?ooo`00DP3oool4000002`0oooo1@00003o0?ooobX0oooo001F0?oo
o`D000008`3oool400000?l0oooo;`3oool005/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00
HP3ooolE00000?l0oooo>P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.5 .02381 Mdot
.5 Mabswid
.5 .5 m
.5 .02381 L
s
0 1 0 r
.5 .5 m
.5 .5 L
s
1 0 0 r
.5 .02381 m
.5 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.7381 .30902 Mdot
1 0 0 r
.7381 .01471 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00JP3oool30000ool0ooooA03oool006P0oooo1`000?oo0?oood80oooo001X0?ooo`L0003o
o`3ooom20?ooo`00I`3oool50000o`040?l000000?l0003o0000o`800000o`3ooolo0?ooo`00GP3o
ool9000000D0003o00@0o`000000o`000?l0003o0P3oool900000?l0oooo=P3oool005T0oooo1@00
00090?ooo`D0003o00@0o`000000o`000?l0003o2`3oool400000?l0oooo<P3oool005D0oooo1000
000?0?ooo`@0003o00<0o`000000o`000?l0403oool500000?l0oooo;@3oool00500oooo1@00000C
0?ooo`@0003o00<0o`000000o`000?l05@3oool400000?l0oooo:@3oool004h0oooo0P00000J0?oo
o`80003o00<0o`000?ooo`3oool06@3oool300000?l0oooo9P3oool004`0oooo0P00000N0?ooo`03
0?l0003oool0oooo01`0oooo0P00003o0?ooob@0oooo001:0?ooo`800000803oool00`3o0000oooo
0?ooo`0N0?ooo`800000o`3ooolR0?ooo`00B03oool200000280oooo00<0o`000?ooo`3oool0803o
ool200000?l0oooo803oool004H0oooo0P00000T0?ooo`030?l0003oool0oooo0280oooo0P00003o
0?oooah0oooo00130?ooo`<000009P3oool00`3o0000oooo0?ooo`0T0?ooo`800000o`3ooolL0?oo
o`00@@3oool2000002T0oooo00<0o`000?ooo`3oool09P3oool200000?l0oooo6P3oool003l0oooo
0P00000[0?ooo`030?l0003oool0oooo02P0oooo0P00003o0?oooaP0oooo000m0?ooo`800000;@3o
ool00`3o0000oooo0?ooo`0Z0?ooo`800000o`3ooolF0?ooo`00>`3oool2000002l0oooo00<0o`00
0?ooo`3oool0;03oool200000?l0oooo503oool003T0oooo0P00000a0?ooo`030?l0003oool0oooo
02h0oooo0P00003o0?oooa80oooo000h0?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3o
ool0<03oool200000?l0oooo403oool003L0oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo
0?ooo`0b0?ooo`030000003oool0oooo0?l0oooo3@3oool003H0oooo00<000000?ooo`3oool0<`3o
ool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo303oool003@0oooo0P00000f
0?ooo`030?l0003oool0oooo03@0oooo0P00003o0?ooo``0oooo000c0?ooo`030000003oool0oooo
03H0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000b0?ooo`03
0000003oool0oooo03L0oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooo`P0
oooo000`0?ooo`800000>P3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0oooo
1`3oool002l0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0?l0oooo1P3oool002h0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0j
0?ooo`030000003oool0oooo0?l0oooo1@3oool002d0oooo00<000000?ooo`3oool0?03oool00`3o
0000oooo0?ooo`0k0?ooo`800000o`3oool50?ooo`00;03oool00`000000oooo0?ooo`0m0?ooo`03
0?l0003oool0oooo03d0oooo00<000000?ooo`3oool0o`3oool20?ooo`00:`3oool00`000000oooo
0?ooo`0n0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool0o`3oool10?ooo`00:@3o
ool200000440oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?ooo`00:03oool0
0`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0oP3oool0
02P0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo
0?d0oooo000W0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0480oooo
00<000000?ooo`3oool0o03oool002D0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?oo
o`130?ooo`030000003oool0oooo0?/0oooo000T0?ooo`030000003oool0oooo04D0oooo00<0o`00
0?ooo`3oool0A03oool00`000000oooo0?ooo`3j0?ooo`008`3oool00`000000oooo0?ooo`160?oo
o`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0n@3oool00280oooo00<000000?ooo`3o
ool0A`3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo0?P0oooo000R0?ooo`030000
003oool0oooo04L0oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`3g0?ooo`008@3o
ool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool0m`3o
ool00200oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`180?ooo`030000003oool0
oooo0?H0oooo000O0?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3oool0B03oool00`00
0000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo04T0
oooo00<000000?ooo`3oool0m@3oool001h0oooo00<000000?ooo`3oool0B`3oool00`3o0000oooo
0?ooo`1:0?ooo`030000003oool0oooo0440oooo1`00002/0?ooo`007P3oool00`000000oooo0?oo
o`1;0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06d0oooo1P3o000c0?ooo`007@3oool00`000000oooo0?ooo`1<
0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo06d0oooo1P3o000c0?ooo`007@3oool00`000000oooo0?ooo`1<0?oo
o`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo06`0oooo203o000b0?ooo`00703oool00`000000oooo0?ooo`1=0?ooo`03
0?l0003oool0oooo04`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3o
ool0103oool2000004L0oooo2000000N0?ooo`P0o`00<P3oool001/0oooo00<000000?ooo`3oool0
CP3oool00`3o0000oooo0?ooo`1=0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`130?ooo`<00000203oool00`000000oooo0?ooo`0H0?ooo`<00000
00<0oooo0?l0003o0000103o0000103oool0000000000000000_0?ooo`006P3oool00`000000oooo
0?ooo`1?0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02P3oool2000001H0oooo
0P0000040?ooo`H0o`00103oool2000002d0oooo000J0?ooo`030000003oool0oooo04l0oooo00<0
o`000?ooo`3oool0CP3oool00`000000oooo0?ooo`0n0?ooo`<000001P3oool00`000000oooo0?oo
o`100?ooo`8000003`3oool2000001<0oooo00<000000?ooo`3oool01P3oool20?l000L0oooo00<0
00000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`1>
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo02X0oooo000I0?ooo`030000003oool0oooo0500oooo00<0o`000?oo
o`3oool0C`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool04`3oool2000000h0oooo00<000000?ooo`3oool04`3oool2000002X0oooo000H0?ooo`03
0000003oool0oooo0540oooo00<0o`000?ooo`3oool0C`3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3oool0
D@3oool00`3o0000oooo0?ooo`1@0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0V0?ooo`005`3oool00`000000oooo0?ooo`1B0?ooo`030?l0003o
ool0oooo0500oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0j0?ooo`8000006`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09@3o
ool001L0oooo00<000000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`1A0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool00`00
0000oooo0?ooo`1C0?ooo`030?l0003oool0oooo0540oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003oool0oooo05<0
oooo00<0o`000?ooo`3oool0DP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool000000240oooo00<000000?oo
o`3oool08`3oool001D0oooo00<000000?ooo`3oool0E03oool00`3o0000oooo0?ooo`1B0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`04
0000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?ooo`3o
ool0E03oool00`3o0000oooo0?ooo`1C0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000002@0oooo00<000000?ooo`3o
ool08@3oool001D0oooo00<000000?ooo`3oool0E03oool00`3o0000oooo0?ooo`1C0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0E03o
ool00`3o0000oooo0?ooo`1D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0803o
ool001D0oooo00<000000?ooo`3oool0E03oool00`3o0000oooo0?ooo`1D0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0T0?ooo`040000003oool0
oooo000002D0oooo00<000000?ooo`3oool07`3oool001@0oooo00<000000?ooo`3oool0E@3oool0
0`3o0000oooo0?ooo`1E0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?oo
o`0N0?ooo`00503oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo05D0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C0?oo
o`030000003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool001<0oooo00<000000?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`030000003oool0oooo02D0oooo100000060?ooo`80
00001P3oool4000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0L0?ooo`00
4P3oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo05D0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo05L0oooo00<0o`000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06`3o
ool00180oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`1F0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0080oooo0P00000a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000B0?ooo`030000003oool0oooo
05L0oooo00<0o`000?ooo`3oool0E`3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo05P0
oooo00<0o`000?ooo`3oool0E`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`1H0?ooo`030?l0003oool0oooo05L0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo
000A0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<00000
0?ooo`3oool0F03oool00`3o0000oooo0?ooo`1G0?ooo`030000003oool0oooo02<0oooo1000000>
0?ooo`D00000103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?oo
o`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool0F03oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool00100oooo00<000000?ooo`3o
ool0F@3oool00`3o0000oooo0?ooo`1H0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`1I0?ooo`030?l0
003oool0oooo05P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05P3o
ool00100oooo00<000000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`1I0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3oool0
0`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3oool4
000001D0oooo000@0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo05T0
oooo00<0o`000?ooo`3oool0F@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000K0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04@3oool01P000000oooo0?ooo`000000oooo000001@0oooo000@0?oo
o`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool0F@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000J
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?0?oo
o`030000003oool0oooo05X0oooo00<0o`000?ooo`3oool0F@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01D0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`0000000P00000E0?ooo`003`3oool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo
05T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo00H0oooo1000000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool0
00l0oooo00<000000?ooo`3oool0FP3oool00`3o0000oooo0?ooo`1I0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?ooo`1J
0?ooo`030?l0003oool0oooo05T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C
0?ooo`<000004@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00D0
00000?ooo`3oool0oooo0000000C0?ooo`003`3oool00`000000oooo0?ooo`1J0?ooo`030?l0003o
ool0oooo05T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00P3oool4000001@0oooo100000060?ooo`030000003o
ool0oooo00h0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo1@00000F0?ooo`@000004`3o
ool000l0oooo00<000000?ooo`3oool0FP3oool00`3o0000oooo0?ooo`1I0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`00
0000oooo0?ooo`1J0?ooo`030?l0003oool0oooo05T0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo05X0
oooo00<0o`000?ooo`3oool0F@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`0300000000o`000?l002<0
oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0FP3oool00`3o0000oooo
0?ooo`1J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo01l0oooo1P00o`0Q0?ooo`030000003oool0oooo00l0oooo
000?0?ooo`030000003oool0oooo05X0oooo00<0o`000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0P0?ooo`H00?l08P3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`1J
0?ooo`030?l0003oool0oooo05X0oooo00<000000?ooo`3oool0=`3ooomc000000P00?l09`00000;
0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3oool8003o00<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo
0P00000S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool6003o03<0oooo
000?0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool200000280oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0R0?ooo`H00?l0<`3oool000l0oooo00<00000
0?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool000000240oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0U0?ooo`800?l000<0oooo0000003oool0<P3oool0
00l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool00000
0200oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0340oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0
oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000
oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3o
ool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000703oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0
oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?oo
o`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0;03oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
:`3oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:P3oool0
0140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool00180oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`8000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@0
00001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02H0oooo000B0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0
oooo0:h0oooo00<000000?ooo`3oool09@3oool4000000h0oooo1@0000040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool0[P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool08`3oool001@0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool08P3oool001@0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo00h0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002D0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
000Q0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool07P3oool001H0oooo00<00000
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0703oool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool06`3oool001P0oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool06P3o
ool001T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0XP3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0FP3oool2000001T0oooo000J0?ooo`030000003oool0oooo0:00
oooo00<000000?ooo`3oool0?@3oool7000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo
0P00000?0?ooo`800000H@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`8000005`3oool2000000X0oooo0`00001T0?ooo`8000005@3oool001/0oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo1P00000K
0?ooo`X00000J@3oool6000000l0oooo000L0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000N0?ooo`030000003o
ool0oooo09T0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`030000003oool0
oooo09H0oooo0P0000160?ooo`030000003oool0oooo0:d0oooo000O0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0oooo
000R0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0m`3oool00280oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0nP3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3j0?ooo`009@3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?/0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0o03oool002L0oooo0P0000270?ooo`030000003oool0oooo
0?d0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0oP3oool002T0oooo
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?ooo`00:P3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000O@3oool200000?l0oooo103oool002d0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000^0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool2000007H0oooo0P00
003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3oool8
0?ooo`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool003<0
oooo0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`3o0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo0P00003o0?ooo`l0oooo000h0?oo
o`800000I03oool200000?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000o`3ooolC0?ooo`00
?03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3oool003d0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?ooo`800000F03oool2
00000?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00@`3oool2000004l0
oooo0P00003o0?oooa/0oooo00150?ooo`800000B`3oool200000?l0oooo7@3oool004L0oooo0P00
00170?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo1@00003o0?ooob40oooo001=0?oo
o`800000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000o`3ooolX0?ooo`00
DP3oool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool400000?l0oooo;`3o
ool005/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0oooo>P3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.62325 .04004 Mdot
.5 Mabswid
.5 .5 m
.62325 .04004 L
s
0 1 0 r
.5 .5 m
.62325 .5 L
s
1 0 0 r
.62325 .04004 m
.62325 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.77778 .38519 Mdot
1 0 0 r
.77778 .02474 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000100oooo0`00
0?oo0?ooob`0oooo001N0?ooo`T000002`3oool9000000D0oooo1`000?oo0?ooobX0oooo001I0?oo
o`D000007@3oool4000000030?ooo`000?l0003o00D0003oo`3ooolZ0?ooo`00E@3oool4000002H0
oooo1@000?l0103o0000003o0000o`000?oo0?ooobT0oooo001@0?ooo`D00000:P3oool50000o`04
0?l000000?l0003o0000ool0oooo:@3oool004h0oooo0P00000_0?ooo`D0003o00@0o`000000o`00
0?l0003o0`00003o0?ooobH0oooo001<0?ooo`800000<P3oool40000o`030?l000000?l0003o00@0
oooo0P00003o0?ooob@0oooo001:0?ooo`800000=03oool40000o`030?l000000?l0003o00H0oooo
0P00003o0?ooob80oooo00180?ooo`800000>03oool20000o`030?l0003oool0oooo00P0oooo0P00
003o0?ooob00oooo00160?ooo`800000>P3oool00`000?l0oooo0?l0000<0?ooo`800000o`3ooolN
0?ooo`00@`3oool3000003`0oooo00<0003o0?ooo`3o00003P3oool200000?l0oooo703oool00440
oooo0P00000o0?ooo`030000o`3oool0o`000100oooo0P00003o0?oooaX0oooo000o0?ooo`800000
@@3oool00`000?l0oooo0?l0000B0?ooo`800000o`3ooolH0?ooo`00?@3oool200000480oooo00@0
003o0?ooo`3oool0o`00503oool200000?l0oooo5P3oool003/0oooo0P0000140?ooo`040000o`3o
ool0oooo0?l001H0oooo0P00003o0?oooa@0oooo000i0?ooo`800000AP3oool010000?l0oooo0?oo
o`3o000H0?ooo`800000o`3ooolB0?ooo`00>03oool00`000000oooo0?ooo`160?ooo`040000o`3o
ool0oooo0?l001X0oooo0P00003o0?oooa00oooo000g0?ooo`030000003oool0oooo04H0oooo00D0
003o0?ooo`3oool0oooo0?l0000L0?ooo`030000003oool0oooo0?l0oooo3@3oool003H0oooo00<0
00000?ooo`3oool0A`3oool01@000?l0oooo0?ooo`3oool0o`0001d0oooo00<000000?ooo`3oool0
o`3oool<0?ooo`00=03oool2000004X0oooo00D0003o0?ooo`3oool0oooo0?l0000N0?ooo`800000
o`3oool<0?ooo`00<`3oool00`000000oooo0?ooo`190?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000b0?ooo`030000003oool0
oooo04X0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0
oooo0?l0oooo203oool00300oooo0P00001=0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0803oool00`000000oooo0?ooo`3o0?ooo`L0oooo000_0?ooo`030000003oool0oooo04d0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0
oooo1P3oool002h0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0280oooo00<000000?ooo`3oool0o`3oool50?ooo`00;@3oool00`000000oooo0?oo
o`1>0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool08`3oool200000?l0oooo1@3o
ool002`0oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo02D0oooo00<000000?ooo`3oool0o`3oool20?ooo`00:`3oool00`000000oooo0?ooo`1@0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?oo
o`40oooo000Y0?ooo`800000DP3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo02L0
oooo00<000000?ooo`3oool0o`3oool002P0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo02P0oooo00<000000?ooo`3oool0oP3oool002P0oooo00<0
00000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo02T0oooo00<0
00000?ooo`3oool0o@3oool002L0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0o@3oool002H0oooo00<000000?oo
o`3oool0D`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo02X0oooo00<000000?oo
o`3oool0o03oool002D0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo02/0oooo00<000000?ooo`3oool0n`3oool002@0oooo00<000000?ooo`3oool0
E@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0
nP3oool002<0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo02d0oooo00<000000?ooo`3oool0n@3oool00280oooo00<000000?ooo`3oool0EP3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0n03oool0
0280oooo00<000000?ooo`3oool0EP3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
02l0oooo00<000000?ooo`3oool0m`3oool00240oooo00<000000?ooo`3oool0E`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool0m`3oool00200oooo
00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0300oooo
00<000000?ooo`3oool0mP3oool001l0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool0mP3oool001l0oooo00<00000
0?ooo`3oool0F03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0340oooo00<00000
0?ooo`3oool0m@3oool001h0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo0380oooo00<000000?ooo`3oool0@@3oool700000:`0oooo000N0?ooo`03
0000003oool0oooo05P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0c0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`00
7@3oool00`000000oooo0?ooo`1I0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
<`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
M@3oool20?l002l0oooo000M0?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0d0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1c0?ooo`H0o`00;@3oool001`0oooo00<000000?ooo`3oool0FP3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool0=P3oool6
000000H0oooo00<000000?ooo`3oool0103oool2000004L0oooo2000000N0?ooo`L000001P3o000]
0?ooo`006`3oool00`000000oooo0?ooo`1J0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0=@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0@`3oool3000000P0oooo00<000000?ooo`3oool0603oool3000000H0oooo203o000/0?oo
o`006P3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0:0?ooo`8000005P3oool2000000T0oooo203o000/0?ooo`00
6P3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0n0?ooo`<000001P3oool00`000000oooo0?ooo`100?ooo`800000
3`3oool2000001<0oooo00<000000?ooo`3oool02P3oool60?l002d0oooo000I0?ooo`030000003o
ool0oooo05/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`H0o`0000<0
00000?ooo`3oool0:P3oool001T0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo03L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo01<0oooo0P00000>0?ooo`030000003oool0oooo00h0oooo0P3o0003
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo03L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo02L0oooo000H0?ooo`030000003oool0oooo05`0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0V0?ooo`005`3oool00`000000oooo0?ooo`1L0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`1L0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0903oool001H0oooo00<000000?ooo`3oool0G@3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003oool0oooo
05d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`1M0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`00000S
0?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo05d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000002@0oooo00<000000?oo
o`3oool08@3oool001D0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo03/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
?03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0000000U0?ooo`030000003oool0oooo0200oooo000E0?ooo`030000003o
ool0oooo05`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0T0?ooo`040000003o
ool0oooo000002D0oooo00<000000?ooo`3oool07`3oool001@0oooo00<000000?ooo`3oool0G@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo05d0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo0?ooo`1M
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool001<0oooo00<000000?oo
o`3oool0G@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo03d0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0K0?ooo`00
4P3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
6`3oool00180oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo03h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo03l0oooo00<000000?ooo`3oool06@3oool6000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0J0?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo05d0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo02<0oooo1000
000>0?ooo`D00000103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A
0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`10
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0@03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool05`3oool00100oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0400oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`1M0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0180oooo1`00000A0?ooo`H000004`3oool4000000X0oooo00<000000?ooo`3oool02@3o
ool4000000L0oooo00<000000?ooo`3oool02@3oool4000001D0oooo1000000E0?ooo`00403oool0
0`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool0
0`000000oooo000000020?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool0oooo
05`0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00T0oooo1P0000090?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool04@3oool200000080oooo0P00000D0?ooo`003`3oool00`000000oooo0?ooo`1M
0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01D0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`0000000P00000E0?ooo`003`3oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`050000003o
ool0oooo0?ooo`000000503oool000l0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0C0?ooo`<000004@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo
00D000000?ooo`3oool0oooo0000000C0?ooo`003`3oool00`000000oooo0?ooo`1L0?ooo`030000
o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`1K0?ooo`030000o`3o
ool0oooo01@0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0F`3oool0
0`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo
05/0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000
oooo0?ooo`1K0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool000l0oooo
00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo0480oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo
000?0?ooo`030000003oool0oooo05X0oooo6000o`000`3o0000oooo0?ooo`120?ooo`030000003o
ool0oooo03L0ooooXP00000;0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000
003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo000?0?oo
o`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool2000002<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool200000280oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`030000
003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0000000Q0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0a0?ooo`003`3o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`000000803o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0<@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`040000003oool0
oooo000001l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0300oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool0
10000000oooo0?ooo`00000N0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`2f
0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0;03oool00`0000000?l0003o000_0?ooo`003`3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool6
003o02d0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0/0?ooo`H00?l0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo2000o`0/0?ooo`00403oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;03oool8003o02`0oooo
000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0^0?ooo`H00?l0;@3oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02h0oooo1P00o`0]0?ooo`00403oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<@3oool2003o00030?ooo`000000oooo
02`0oooo000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo02/0oooo000A0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02X0oooo
000A0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000003oool0oooo0;80oooo00<00000
0?ooo`3oool08`3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo02T0oooo000A0?ooo`030000003oool0oooo0;80oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo02T0oooo000A0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo000B0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo02P0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o
ool2000000/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool09`3oool00180oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4
000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0V0?ooo`004P3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo02D0oooo1000000>0?ooo`D00000103oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo02@0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo000D
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>
0?ooo`050000003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0280oooo000D0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0R0?ooo`005@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000U0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo0P00000V0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo0P00000U0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool07`3oool001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000008`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo01l0oooo000F0?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00008@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01h0oooo000F0?ooo`030000
003oool0oooo0:L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo01h0oooo000G0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01d0oooo000G0?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo01`0oooo000H0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo01/0oooo000H0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0
oooo000I0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01T0oooo000I0?ooo`030000003oool0oooo0:80oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo05X0oooo0P00000I0?ooo`006P3oool00`000000oooo0?ooo`2P
0?ooo`030000003oool0oooo03d0oooo1`0000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool05P3oool001X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?oo
o`8000003`3oool200000640oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool2000001L0oooo0P00000:0?ooo`<00000I03oool2000001D0oooo000K0?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`H00000
6`3oool:000006T0oooo1P00000?0?ooo`00703oool00`000000oooo0?ooo`2L0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2V0?ooo`007@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007P3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo0440oooo0`00002_0?ooo`007`3oool00`000000oooo
0?ooo`2F0?ooo`800000AP3oool00`000000oooo0?ooo`2]0?ooo`007`3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0?H0oooo000P0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0mP3oool00240oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`3g0?oo
o`008P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0n03oool002<0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`3i0?ooo`00903oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0?X0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0nP3oool002D0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3k0?ooo`009P3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo0?`0oooo000W0?ooo`800000Q`3oool00`000000oooo0?oo
o`3m0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo000Y0?oo
o`030000003oool0oooo0880oooo00<000000?ooo`3oool0o`3oool002X0oooo00<000000?ooo`3o
ool0P03oool00`000000oooo0?ooo`3o0?ooo`40oooo000[0?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool0o`3oool10?ooo`00;03oool2000007d0oooo0P00003o0?ooo`@0oooo000]
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3oool40?ooo`00;P3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo1@3oool002l0oooo0P00001f0?ooo`80
0000o`3oool80?ooo`00<@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo
203oool00380oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000c
0?ooo`800000K`3oool200000?l0oooo2`3oool003D0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`3o0?ooo`/0oooo000f0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool0o`3oool<0?ooo`00=`3oool00`000000oooo0?ooo`1V0?ooo`800000o`3oool?0?ooo`00>03o
ool2000006@0oooo0P00003o0?oooa40oooo000j0?ooo`800000H03oool200000?l0oooo4`3oool0
03`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oooa<0oooo000m0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00?P3oool2000005P0oooo
0P00003o0?oooaL0oooo00100?ooo`<00000D`3oool200000?l0oooo6@3oool004<0oooo0P00001?
0?ooo`800000o`3ooolK0?ooo`00A@3oool2000004/0oooo0P00003o0?oooad0oooo00170?ooo`80
0000A`3oool200000?l0oooo7`3oool004T0oooo1000000n0?ooo`D00000o`3ooolQ0?ooo`00C@3o
ool2000003X0oooo0P00003o0?ooobH0oooo001?0?ooo`<00000=@3oool200000?l0oooo:03oool0
0580oooo1000000/0?ooo`D00000o`3ooolZ0?ooo`00EP3oool5000002<0oooo1000003o0?ooobl0
oooo001K0?ooo`L000005@3oool700000?l0oooo<`3oool00680oooo5@00003o0?ooocX0oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.7381 .08761 Mdot
.5 Mabswid
.5 .5 m
.7381 .08761 L
s
0 1 0 r
.5 .5 m
.7381 .5 L
s
1 0 0 r
.7381 .08761 m
.7381 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.81746 .45617 Mdot
1 0 0 r
.81746 .05414 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool2000000H0oooo0`000?oo0?oooaD0oooo
00130?ooo`<00000C@3oool200000080oooo1`000?oo0?oooa<0oooo00110?ooo`800000DP3oool2
000000L0003oo`3ooolC0?ooo`00?`3oool2000005D0oooo2@000?oo0?oooa80oooo000m0?ooo`80
0000E`3oool40000o`030?l000000?l0003o0080003oo`3ooolB0?ooo`00>`3oool2000005T0oooo
10000?l00`3o0000003o0000o`020000ool0oooo4P3oool003T0oooo0P00001L0?ooo`<0003o00D0
o`000000o`000?l0003o0000003o0?oooa80oooo000h0?ooo`030000003oool0oooo05`0oooo0`00
0?l01@3o0000003o0000o`000?l0oooo00800000o`3oool@0?ooo`00=`3oool00`000000oooo0?oo
o`1N0?ooo`80003o00<0o`000000o`3oool0103oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f
0?ooo`030000003oool0oooo05h0oooo00@0003o0?ooo`3oool0o`001`3oool00`000000oooo0?oo
o`3o0?ooo``0oooo000d0?ooo`800000H@3oool010000?l0oooo0?ooo`3o00080?ooo`800000o`3o
ool<0?ooo`00<`3oool00`000000oooo0?ooo`1P0?ooo`050000o`3oool0oooo0?ooo`3o00002P3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo000b0?ooo`030000003oool0oooo0600oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo203oool0
0300oooo0P00001S0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo000_0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo1P3oool002h0oooo
00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1S0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool03@3oool200000?l0oooo1@3oool002`0oooo00<00000
0?ooo`3oool0I03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<00000
0?ooo`3oool0o`3oool20?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`80
0000IP3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3o
ool0o`3oool002P0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo0180oooo00<000000?ooo`3oool0oP3oool002P0oooo00<000000?ooo`3oool0I@3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool0o@3o
ool002L0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo01<0oooo00<000000?ooo`3oool0o@3oool002H0oooo00<000000?ooo`3oool0IP3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0o03oool002D0
oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo01D0
oooo00<000000?ooo`3oool0n`3oool002@0oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0nP3oool002<0oooo00<0
00000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo01L0oooo00<0
00000?ooo`3oool0n@3oool00280oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo01P0oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?oo
o`3oool0I`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo01T0oooo00<000000?oo
o`3oool0m`3oool00240oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo01T0oooo00<000000?ooo`3oool0m`3oool00200oooo00<000000?ooo`3oool0
J03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool0
mP3oool001l0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo01X0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<000000?ooo`3oool0J03oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool0m@3oool0
01h0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
01`0oooo00<000000?ooo`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo06P0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool00`000000oooo
0?ooo`1X0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool07@3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool001d0oooo00<0
00000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01h0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L
0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0N
0?ooo`030000003oool0oooo03H0oooo1P0000060?ooo`030000003oool0oooo00@0oooo0P000017
0?ooo`P000007P3oool800000380oooo000K0?ooo`030000003oool0oooo06P0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`130?ooo`<00000203oool00`000000oooo0?ooo`0H0?oo
o`<00000203oool3000002l0oooo000J0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`80
00003P3oool2000002d0oooo000J0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo03h0oooo0`0000060?ooo`030000
003oool0oooo0400oooo0P00000?0?ooo`8000004`3oool00`000000oooo0?ooo`0?0?ooo`040000
003oool0oooo0?ooo`80o`00:03oool001T0oooo00<000000?ooo`3oool0J@3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo0200oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?l0003o0000103o000V0?ooo`006@3o
ool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool08@3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04`3o
ool2000000h0oooo00<000000?ooo`3oool04`3oool60?l002H0oooo000H0?ooo`030000003oool0
oooo06T0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool04`3oool80?l002D0oooo000H0?ooo`030000003oool0oooo
06P0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0503oool80?l002D0oooo000G0?ooo`030000003oool0oooo06P0
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0>P3oool2000001/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0F0?ooo`H0o`009P3oool001L0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo
0?ooo`0E0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0G0?ooo`H0o`009P3oool001H0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?oo
o`0F0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0J0?ooo`80o`0000<0oooo0000003oool09@3oool001H0oooo00<000000?ooo`3oool0J03oool0
0`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo0000
000Q0?ooo`030000003oool0oooo02<0oooo000E0?ooo`030000003oool0oooo06P0oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000002<0oooo00<0
00000?ooo`3oool08P3oool001D0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0G
0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`0Q
0?ooo`005@3oool00`000000oooo0?ooo`1W0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool09@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0200oooo000E0?ooo`03
0000003oool0oooo06H0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0000002D0oooo00<000000?ooo`3oool0803oool001D0oooo00<000000?ooo`3oool0
IP3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool0
00009@3oool00`000000oooo0?ooo`0O0?ooo`00503oool00`000000oooo0?ooo`1V0?ooo`030000
o`3oool0oooo01X0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00<000000?ooo`3oool07P3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo
0?ooo`0J0?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C0?ooo`030000003oool0oooo06H0oooo00<0
003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0W0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`004`3oool00`000000oooo0?ooo`1V
0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`0U
0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0703oool00180oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0L0?oo
o`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01/0oooo000B0?ooo`03
0000003oool0oooo06D0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0K0?ooo`00
4P3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0
:03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`004P3o
ool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0I0?ooo`H000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01X0oooo000A0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo01T0oooo000A0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool07`3oool00`3o
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo0200
oooo00<0o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0603oool00140oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo
0?ooo`0P0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool08`3oool4000000h0oooo
1@0000040?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo02X0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@
0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0Z
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`1R0?ooo`030000o`3oool0oooo0280oooo00<0o`000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool05P3oool00100oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0R0?ooo`03
0?l0003oool0oooo02X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
4P3oool700000140oooo1P00000C0?ooo`@000002P3oool00`000000oooo0?ooo`090?ooo`@00000
1`3oool00`000000oooo0?ooo`090?ooo`@000005@3oool4000001D0oooo000@0?ooo`030000003o
ool0oooo0600oooo00<0003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`0[0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool0H03oool0
0`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000006`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00H000000?ooo`3oool000000?oo
o`00000D0?ooo`00403oool00`000000oooo0?ooo`1O0?ooo`030000o`3oool0oooo02D0oooo00<0
o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool04@3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool6000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?0?ooo`030000003oool0oooo0600oooo00<0
003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05@3oool2000000P0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo
00000002000001D0oooo000?0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`060?ooo`@00000503oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0180oooo000?0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0
oooo0000000D0?ooo`003`3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo02L0oooo
00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01<0oooo
0`00000A0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool01@000000
oooo0?ooo`3oool0000001<0oooo000?0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3o
ool0:03oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo1000000D0?ooo`@0
00001P3oool00`000000oooo0?ooo`0>0?ooo`800000303oool00`000000oooo0?ooo`050?ooo`D0
00005P3oool4000001<0oooo000?0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0
:03oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`1L0?ooo`030000o`3o
ool0oooo02T0oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0G03oool0
0`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo
05/0oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0/0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000
oooo0?ooo`1K0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0;03oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool000l0oooo
00<000000?ooo`3oool0FP3oool^003o00030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0
=`3ooonR000000/0oooo000?0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3o
ool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool000l0oooo00<00000
0?ooo`3oool0]`3oool00`000000oooo0?ooo`0k0?ooo`8000008`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<P3oool000l0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0k0?ooo`8000008P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<P3oool000l0oooo00<000000?ooo`3o
ool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool000000240oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000?0?ooo`030000
003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0000000P0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0a0?ooo`003`3o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00@000000?ooo`3oool00000
7`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
<03oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000001h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0300oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03o
ool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo02l0oooo000?0?ooo`030000003oool0oooo0;H0oooo00<0
00000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000001`0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo000?0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02h0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo000@0?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
02d0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo02d0oooo000@0?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02`0oooo
000@0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo02`0oooo000@0?ooo`030000003oool0oooo0;@0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02/0oooo000@0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02/0oooo000A0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000
003oool0oooo0;<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo02X0oooo000A0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool08`3o
ool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0h0?ooo`040000003o
ool00?l0003o02P0oooo000A0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0i0?ooo`H00?l09P3o
ool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo03X0oooo1P00o`0V0?ooo`004P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0>@3oool8003o02D0oooo000B0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo03X0oooo2000o`0U0?ooo`004P3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0l0?ooo`H00?l09P3oool00180oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03`0oooo1P00
o`0V0?ooo`004`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0?`3oool2003o00030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo
0:h0oooo00<000000?ooo`3oool09@3oool4000000h0oooo1@0000040?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool08`3oool001@0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo
00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool08P3oool001@0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00h0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000Q
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool07P3oool001H0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool07P3oool001L0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
703oool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool06`3oool001P0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool06P3oool0
01T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0FP3oool2000001T0oooo000J0?ooo`030000003oool0oooo0:00oooo
00<000000?ooo`3oool0?@3oool7000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo0P00
000?0?ooo`800000H@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`8000005`3oool2000000X0oooo0`00001T0?ooo`8000005@3oool001/0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo1P00000K0?oo
o`X00000J@3oool6000000l0oooo000L0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000N0?ooo`030000003oool0
oooo09T0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`030000003oool0oooo
09H0oooo0P0000160?ooo`030000003oool0oooo0:d0oooo000O0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0oooo000R
0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0m`3oool00280oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
nP3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3j0?ooo`009@3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?/0oooo000V0?ooo`030000003oool0oooo
08P0oooo00<000000?ooo`3oool0o03oool002L0oooo0P0000270?ooo`030000003oool0oooo0?d0
oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0oP3oool002T0oooo00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?ooo`00:P3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo00<000000?ooo`3oool0O`3oool00`00
0000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000O@3oool200000?l0oooo103oool002d0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000^0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool2000007H0oooo0P00003o
0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3oool80?oo
o`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool003<0oooo
0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3o
0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo0P00003o0?ooo`l0oooo000h0?ooo`80
0000I03oool200000?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000o`3ooolC0?ooo`00?03o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3oool003d0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?ooo`800000F03oool20000
0?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00@`3oool2000004l0oooo
0P00003o0?oooa/0oooo00150?ooo`800000B`3oool200000?l0oooo7@3oool004L0oooo0P000017
0?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo1@00003o0?ooob40oooo001=0?ooo`80
0000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000o`3ooolX0?ooo`00DP3o
ool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool400000?l0oooo;`3oool0
05/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0oooo>P3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.83672 .16328 Mdot
.5 Mabswid
.5 .5 m
.83672 .16328 L
s
0 1 0 r
.5 .5 m
.83672 .5 L
s
1 0 0 r
.83672 .16328 m
.83672 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.85714 .51712 Mdot
1 0 0 r
.85714 .10091 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
0`000?oo0?ooo`80oooo000]0?ooo`030000003oool0oooo07X0oooo1`000?oo0?ooo`00;03oool0
0`000000oooo0?ooo`1k0?ooo`L0003oo`3oool002/0oooo00<000000?ooo`3oool0N`3oool90000
ooh0oooo000Y0?ooo`800000OP3oool40000o`030?l000000?l0003o0080003ooP3oool002P0oooo
00<000000?ooo`3oool0OP3oool40000o`030?l000000?l0003o0080003ooP3oool002P0oooo00<0
00000?ooo`3oool0O`3oool30000o`040?l000000?l0003o0000ool0oooo000W0?ooo`030000003o
ool0oooo0800oooo0`000?l0103o0000003o0000o`000?oo0?ooo`009P3oool00`000000oooo0?oo
o`200?ooo`060000o`3oool0oooo0000o`3o0000003o0P3oool00`000000oooo0?ooo`3l0?ooo`00
9@3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3k0?ooo`00903oool00`000000oooo0?ooo`200?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`3j0?ooo`008`3oool0
0`000000oooo0?ooo`200?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000000oooo0?ooo`3i0?ooo`008P3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`3h0?ooo`008P3oool00`000000
oooo0?ooo`1o0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000000
oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`3g0?ooo`00803oool00`000000oooo0?oo
o`1o0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?oo
o`3f0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool01`3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`1n0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`3e0?oo
o`007P3oool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool02@3oool00`000000oooo0?ooo`110?ooo`L00000[03oool001h0oooo00<000000?ooo`3oool0
O@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000003o
ool0oooo07d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool0
0`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0YP3oool0
01`0oooo00<000000?ooo`3oool0O03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00/0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool20000
04L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0O03oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04<0oooo0`0000080?ooo`030000003oool0oooo01P0
oooo0`0000080?ooo`<00000;`3oool001X0oooo00<000000?ooo`3oool0O03oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02P3oool2000001H0oooo
0P00000>0?ooo`800000;@3oool001X0oooo00<000000?ooo`3oool0N`3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0?P3oool3000000H0oooo00<0
00000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0N`3oool00`000?l0oooo0?ooo`0C
0?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:P3oool001T0oooo00<000000?oo
o`3oool0NP3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00h0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01<0oooo0P00000>0?oo
o`030000003oool0oooo01<0oooo0P00000Z0?ooo`00603oool00`000000oooo0?ooo`1j0?ooo`03
0000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3oool0
N@3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo000G0?ooo`030000003o
ool0oooo07T0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0?0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0>P3oool2000001/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02D0oooo000G0?ooo`030000003oool0
oooo07P0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool00`00
0000oooo0?ooo`1h0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0403oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3o000R0?oo
o`005P3oool00`000000oooo0?ooo`1g0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3o
ool04@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0803oool01@000000oooo0?ooo`3oool000000240oooo1P3o000P0?ooo`005@3oool00`000000
oooo0?ooo`1g0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool04@3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0803oool010000000
oooo0?ooo`00000R0?ooo`H0o`00803oool001D0oooo00<000000?ooo`3oool0MP3oool00`000?l0
oooo0?ooo`0L0?ooo`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0280oooo00<000000?ooo`0000008@3oool80?l001l0
oooo000E0?ooo`030000003oool0oooo07D0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo
0?ooo`0B0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0200oooo203o000O0?ooo`005@3oool00`000000oooo0?oo
o`1d0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0000
000R0?ooo`H0o`00803oool001D0oooo00<000000?ooo`3oool0L`3oool00`000?l0oooo0?ooo`0O
0?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool000008@3oool60?l00200oooo000D
0?ooo`030000003oool0oooo07<0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`0D
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0S
0?ooo`050000003oool0oooo0?ooo`0000008`3oool20?l000030?ooo`000000oooo01l0oooo000D
0?ooo`030000003oool0oooo0780oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0D
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N
0?ooo`004`3oool00`000000oooo0?ooo`1b0?ooo`030000o`3oool0oooo0280oooo00<0o`000?oo
o`3oool0503oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool07@3oool001<0oooo00<000000?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo01@0oooo00<000000?ooo`3oool09@3oool4000000H0oooo0P0000060?ooo`@0
00001@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01`0oooo000B0?ooo`030000
003oool0oooo0740oooo00<0003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`0D0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`1`0?ooo`030000o`3o
ool0oooo02D0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool06`3oool00180oooo00<000000?ooo`3oool0K`3oool0
0`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool2
00000340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool06P3oool00180oooo00<000000?ooo`3oool0KP3oool00`00
0?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool06@3oool60000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`004@3oool00`000000
oooo0?ooo`1^0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool05P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4000000D0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`004@3oool00`000000oooo
0?ooo`1]0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140oooo00<0
00000?ooo`3oool0K03oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo01H0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A
0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0F
0?ooo`030000003oool0oooo02<0oooo1000000>0?ooo`D00000103oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo06X0oooo00<0003o0?oo
o`3oool0;03oool00`3o0000oooo0?ooo`0G0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`1Z0?ooo`03
0000o`3oool0oooo02d0oooo00<0o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool00100oooo00<000000?ooo`3oool0
J@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003o
ool0oooo06P0oooo00<0003o0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0G0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00403oool0
0`000000oooo0?ooo`1W0?ooo`030000o`3oool0oooo0300oooo00<0o`000?ooo`3oool0603oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0180oooo1`00000A0?ooo`H000004`3oool4
000000X0oooo00<000000?ooo`3oool02@3oool4000000L0oooo00<000000?ooo`3oool02@3oool4
000001D0oooo1000000E0?ooo`00403oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo
0340oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool04@3oool00`000000oooo000000020?ooo`030000003oool0oooo
0180oooo000@0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0<P3oool00`3o0000
oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0A0?ooo`060000003oool0oooo0000003oool00000503oool00100oooo00<000000?oo
o`3oool0I03oool00`000?l0oooo0?ooo`0c0?ooo`030?l0003oool0oooo01P0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00@000000?oo
o`3oool000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo1P000009
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool200000080oooo0P00000D
0?ooo`003`3oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo03@0oooo00<0o`000?oo
o`3oool0603oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo0P0000080?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P00000E0?ooo`003`3oool00`00
0000oooo0?ooo`1S0?ooo`030000o`3oool0oooo03D0oooo00<0o`000?ooo`3oool0603oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool01P3oool4
000001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`003`3oool00`00
0000oooo0?ooo`1R0?ooo`030000o`3oool0oooo03H0oooo00<0o`000?ooo`3oool0603oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000503oool000l0oooo00<00000
0?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0oooo01P0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`<000004@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000303oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`003`3o
ool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo03P0oooo00<0o`000?ooo`3oool0603o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`020?ooo`@00000503oool4000000H0oooo00<000000?ooo`3oool03P3o
ool2000000`0oooo00<000000?ooo`3oool01@3oool5000001H0oooo1000000C0?ooo`003`3oool0
0`000000oooo0?ooo`1O0?ooo`030000o`3oool0oooo03T0oooo00<0o`000?ooo`3oool0603oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool0
00l0oooo00<000000?ooo`3oool0GP3oool00`000?l0oooo0?ooo`0j0?ooo`030?l0003oool0oooo
01P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0100oooo000?0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0>`3oool00`3o0000
oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo03`0oooo
00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?oo
o`0m0?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo05X0oooo@@00o`00
0`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo03L0ooooXP00000;0?ooo`003`3oool00`00
0000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`00
0000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo000?0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3o
ool0>`3oool2000002<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0
>`3oool200000280oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0380oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0000000Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0a0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0]P3oool00`00
0000oooo0?ooo`0l0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003oool0oooo
0;H0oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`00
0000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo0000000M
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0_
0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00D000000?oo
o`3oool0oooo0000000L0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0^0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0]0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0/0?oo
o`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0[0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0[0?ooo`004@3o
ool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo02<0oooo100000060?ooo`8000001P3oool40000
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo
0?ooo`2b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02L0oooo000B0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo100000050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool09P3oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
9@3oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0U0?ooo`@000003P3o
ool5000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0T0?ooo`004`3oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0S0?ooo`00503oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000002D0oooo00<00000
0?ooo`3oool0AP3oool00`0000000?l0003o000R0?ooo`00503oool00`000000oooo0?ooo`2/0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000V
0?ooo`030000003oool0oooo04D0oooo1P00o`0P0?ooo`005@3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000U0?oo
o`030000003oool0oooo04H0oooo1P00o`0P0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0oooo00<000000?ooo`3o
ool0A@3oool8003o01l0oooo000E0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0?0?ooo`8000009@3oool00`000000oooo0?ooo`160?ooo`P00?l0
7`3oool001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00h0oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`180?ooo`H00?l0
803oool001H0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo04T0oooo
1P00o`0P0?ooo`005P3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0C03oool2003o00030?ooo`000000oooo01l0oooo000G0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo01d0oooo000G0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo01`0oooo000H0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01/0
oooo000H0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo0:80oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01T0oooo000I
0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`07
0?ooo`8000003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo0P00000I
0?ooo`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo03d0oooo1`0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool05P3oool001X0oooo00<000000?ooo`3o
ool0X03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0B0?ooo`8000003`3oool200000640oooo00<000000?ooo`3o
ool05@3oool001X0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000001L0oooo0P00000:0?ooo`<00000
I03oool2000001D0oooo000K0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`040?ooo`H000006`3oool:000006T0oooo1P00000?0?ooo`00703oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2V0?ooo`007@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2V0?ooo`007P3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0440oooo
0`00002_0?ooo`007`3oool00`000000oooo0?ooo`2F0?ooo`800000AP3oool00`000000oooo0?oo
o`2]0?ooo`007`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?H0oooo000P0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool00240oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`3g0?ooo`008P3oool00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo0?L0oooo000R0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0n03o
ool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`3i0?ooo`00903oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`3k0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0?`0oooo000W
0?ooo`800000Q`3oool00`000000oooo0?ooo`3m0?ooo`00:03oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo0?h0oooo000Y0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3o
ool0o`3oool002X0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3o0?ooo`40oooo
000[0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3oool10?ooo`00;03oool2
000007d0oooo0P00003o0?ooo`@0oooo000]0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0o`3oool40?ooo`00;P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0
oooo1@3oool002l0oooo0P00001f0?ooo`800000o`3oool80?ooo`00<@3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo0?l0oooo203oool00380oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo000c0?ooo`800000K`3oool200000?l0oooo2`3oool003D0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo000f0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=`3oool00`000000oooo0?oo
o`1V0?ooo`800000o`3oool?0?ooo`00>03oool2000006@0oooo0P00003o0?oooa40oooo000j0?oo
o`800000H03oool200000?l0oooo4`3oool003`0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`3o0?oooa<0oooo000m0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
o`3ooolD0?ooo`00?P3oool2000005P0oooo0P00003o0?oooaL0oooo00100?ooo`<00000D`3oool2
00000?l0oooo6@3oool004<0oooo0P00001?0?ooo`800000o`3ooolK0?ooo`00A@3oool2000004/0
oooo0P00003o0?oooad0oooo00170?ooo`800000A`3oool200000?l0oooo7`3oool004T0oooo1000
000n0?ooo`D00000o`3ooolQ0?ooo`00C@3oool2000003X0oooo0P00003o0?ooobH0oooo001?0?oo
o`<00000=@3oool200000?l0oooo:03oool00580oooo1000000/0?ooo`D00000o`3ooolZ0?ooo`00
EP3oool5000002<0oooo1000003o0?ooobl0oooo001K0?ooo`L000005@3oool700000?l0oooo<`3o
ool00680oooo5@00003o0?ooocX0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.91239 .2619 Mdot
.5 Mabswid
.5 .5 m
.91239 .2619 L
s
0 1 0 r
.5 .5 m
.91239 .5 L
s
1 0 0 r
.91239 .2619 m
.91239 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.89683 .56389 Mdot
1 0 0 r
.89683 .16186 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00@000000000o`00
0?l0003o@P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`03
0000003oool0oooo09T0oooo1`000?m00?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0YP3oool001d0oooo00<000000?ooo`3oool0V@3oool70000od00oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2V0?ooo`00703oool00`000000oooo0?ooo`2I0?ooo`T0003o<`3o
ool6000000H0oooo00<000000?ooo`3oool0103oool2000004L0oooo2000000N0?ooo`P00000<P3o
ool001/0oooo00<000000?ooo`3oool0VP3oool40000o`030?l000000?l0003o0080003o?`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo04<0oooo0`0000080?ooo`030000003oool0
oooo01P0oooo0`0000080?ooo`<00000;`3oool001X0oooo00<000000?ooo`3oool0V`3oool40000
o`030?l000000?l0003o0080003o?`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool02P3oool2000001H0oooo0P00000>0?ooo`800000;@3oool001X0
oooo00<000000?ooo`3oool0V`3oool40000o`040?l000000?l0003o0000och0oooo0`0000060?oo
o`030000003oool0oooo0400oooo0P00000?0?ooo`8000004`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo02/0oooo000I0?ooo`030000003oool0oooo09X0oooo0P000?l01@3oool0
003o0000o`000?l0o`0000<0003o@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0:P3oool001T0oooo00<000000?ooo`3oool0V@3oool00`000?l0
oooo0?ooo`030?ooo`040000o`3o0000003o000004P0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C0?ooo`800000:P3oool001P0
oooo00<000000?ooo`3oool0V03oool20000o`L0oooo00<0o`000?ooo`000000B03oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo02L0oooo000H0?ooo`030000003oool0oooo09H0oooo
0P000?l90?ooo`040?l0003oool0oooo000004L0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0V0?ooo`005`3oool00`000000oooo0?ooo`2E0?ooo`80003o2`3oool0103o0000oooo
0?ooo`0000170?ooo`030000003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo
0?ooo`2D0?ooo`030000o`3oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo000000160?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0903oool001H0oooo00<000000?ooo`3oool0
T`3oool20000o`h0oooo00D0o`000?ooo`3oool0oooo000000160?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0903oool001H0oooo00<000000?ooo`3oool0T@3oool20000oa00oooo
00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3o
ool08`3oool001D0oooo00<000000?ooo`3oool0T@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo0080oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0200oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0R0?ooo`00
5@3oool00`000000oooo0?ooo`2?0?ooo`80003o4`3oool00`3o0000oooo0?ooo`030?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0000002@0oooo00<000000?ooo`3oool08@3oool001D0oooo00<000000?ooo`3oool0S@3o
ool20000oaD0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0200oooo000E0?ooo`030000003oool0oooo08/0oooo0P000?lG0?ooo`030?l0003oool0
oooo00@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`0000009@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`00
0000oooo0?ooo`2:0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0103oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0903oool01000
0000oooo0?ooo`00000U0?ooo`030000003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo
08T0oooo0P000?lJ0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000V
0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo08L0oooo0P000?lL0?oo
o`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01h0oooo000C0?ooo`030000003oool0oooo08H0oooo0P000?lN0?ooo`03
0?l0003oool0oooo00D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo08D0oooo00<0003o0?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo100000060?ooo`800000
1P3oool4000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool010000000oooo0?l0003o000K0?ooo`00
4P3oool00`000000oooo0?ooo`240?ooo`80003o8@3oool00`3o0000oooo0?ooo`050?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
8`3oool60?l001T0oooo000B0?ooo`030000003oool0oooo0880oooo0P000?lS0?ooo`030?l0003o
ool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`H0o`006@3o
ool00180oooo00<000000?ooo`3oool0P03oool20000obD0oooo00<0o`000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0803oool80?l001P0oooo000B0?ooo`030000003oool0oooo
07l0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo
01T0oooo1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0200oooo203o000H0?ooo`004@3oool00`000000
oooo0?ooo`1n0?ooo`80003o:03oool00`3o0000oooo0?ooo`070?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0P0?ooo`H0o`006@3oool00140oooo00<000000?ooo`3oool0O03oool20000obX0oooo
00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0200oooo
1P3o000I0?ooo`004@3oool00`000000oooo0?ooo`1j0?ooo`80003o;03oool00`3o0000oooo0?oo
o`070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3oool20?l000030000003o
ool0oooo01P0oooo000A0?ooo`030000003oool0oooo07T0oooo00<0003o0?ooo`3oool0;03oool0
0`3o0000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo1000000>0?ooo`D00000103oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo
07L0oooo0P000?l_0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo07H0
oooo0P000?la0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo07@0oooo
0P000?lc0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo07<0oooo00<0
003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`1a
0?ooo`80003o=P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3oool00`000000oooo0?ooo`09
0?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3oool4000001D0oooo000@0?oo
o`030000003oool0oooo06l0oooo0P000?lh0?ooo`030?l0003oool0oooo00T0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`1^0?ooo`03
0000o`3oool0oooo03P0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000K0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool01P000000oooo0?ooo`000000oooo
000001@0oooo000@0?ooo`030000003oool0oooo06`0oooo0P000?lk0?ooo`030?l0003oool0oooo
00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0140oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo1P0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool2
00000080oooo0P00000D0?ooo`003`3oool00`000000oooo0?ooo`1[0?ooo`80003o?@3oool00`3o
0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool20000
00P0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo00000002000001D0oooo000?0?oo
o`030000003oool0oooo06T0oooo0P000?lo0?ooo`030?l0003oool0oooo00T0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00H0oooo1000000D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool000l0oooo00<000000?oo
o`3oool0J03oool00`000?l0oooo0?ooo`0o0?ooo`030?l0003oool0oooo00T0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000001@0oooo000?0?ooo`030000003oool0
oooo06H0oooo0P000?m20?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0C0?ooo`<000004@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01L0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`003`3oool00`000000oooo0?oo
o`1T0?ooo`80003oA03oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo1000
000D0?ooo`@000001P3oool00`000000oooo0?ooo`0>0?ooo`800000303oool00`000000oooo0?oo
o`050?ooo`D000005P3oool4000001<0oooo000?0?ooo`030000003oool0oooo0680oooo0P000?m6
0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo0640oooo00<0003o0?oo
o`3oool0AP3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`1O0?ooo`80
003oB@3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`1M0?ooo`80003o
B`3oool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`1K0?ooo`80003oC@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`1J0?oooe000?l000<0o`00
0?ooo`3oool02P3oool00`000000oooo0?ooo`0g0?oooj8000002`3oool000l0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`06
0000003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0
oooo0P00000S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo03/0oooo
0P00000R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0b0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0<@3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool000000200oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0340oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?oo
o`3oool0?03oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?oo
o`030000003oool0oooo03`0oooo00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool000l0oooo00<000000?oo
o`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000007@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
00l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo
0?ooo`000000703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0;P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3o
ool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00100
oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<0
00000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00140oooo00<000000?oo
o`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000001P3oool2000000H0oooo100000050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
:03oool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`004P3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
02H0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo
000C0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool09@3oool4000000h0oooo1@00
00040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0903oool001<0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool08`3oool001@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool08P3oool001@0oooo00<000000?ooo`3oool0[03oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000009P3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool00000
02D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?oo
o`2Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`00000S0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00D0
00000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
7P3oool001H0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool00P00o`0K
0?ooo`005`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0DP3oool6003o01T0oooo000H0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1C0?ooo`H00?l06@3oool001P0oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05<0oooo2000o`0H0?ooo`006@3o
ool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E03o
ool8003o01P0oooo000I0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo05H0oooo1P00o`0I0?ooo`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo
03d0oooo1`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo05L0oooo1P00o`000`000000oooo0?ooo`0F0?oo
o`006P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo0P00000?0?ooo`80
0000G03oool2003o00<0oooo00<000000?ooo`3oool05@3oool001X0oooo00<000000?ooo`3oool0
W`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool2000001L0oooo0P00000:0?ooo`<00000I03oool2000001D0oooo000K0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`H000006`3o
ool:000006T0oooo1P00000?0?ooo`00703oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007@3oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2V0?ooo`007@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V0?ooo`007P3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0440oooo0`00002_0?ooo`007`3oool00`000000oooo0?oo
o`2F0?ooo`800000AP3oool00`000000oooo0?ooo`2]0?ooo`007`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0?H0oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool0mP3oool00240oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`3g0?ooo`00
8P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?L0oooo000R0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0n03oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`3i0?ooo`00903oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0?X0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0nP3oool002D0oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3k0?ooo`009P3oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo0?`0oooo000W0?ooo`800000Q`3oool00`000000oooo0?ooo`3m
0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo000Y0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0o`3oool002X0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`3o0?ooo`40oooo000[0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`00;03oool2000007d0oooo0P00003o0?ooo`@0oooo000]0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3oool40?ooo`00;P3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo1@3oool002l0oooo0P00001f0?ooo`800000
o`3oool80?ooo`00<@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo203o
ool00380oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000c0?oo
o`800000K`3oool200000?l0oooo2`3oool003D0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo000f0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
o`3oool<0?ooo`00=`3oool00`000000oooo0?ooo`1V0?ooo`800000o`3oool?0?ooo`00>03oool2
000006@0oooo0P00003o0?oooa40oooo000j0?ooo`800000H03oool200000?l0oooo4`3oool003`0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oooa<0oooo000m0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00?P3oool2000005P0oooo0P00
003o0?oooaL0oooo00100?ooo`<00000D`3oool200000?l0oooo6@3oool004<0oooo0P00001?0?oo
o`800000o`3ooolK0?ooo`00A@3oool2000004/0oooo0P00003o0?oooad0oooo00170?ooo`800000
A`3oool200000?l0oooo7`3oool004T0oooo1000000n0?ooo`D00000o`3ooolQ0?ooo`00C@3oool2
000003X0oooo0P00003o0?ooobH0oooo001?0?ooo`<00000=@3oool200000?l0oooo:03oool00580
oooo1000000/0?ooo`D00000o`3ooolZ0?ooo`00EP3oool5000002<0oooo1000003o0?ooobl0oooo
001K0?ooo`L000005@3oool700000?l0oooo<`3oool00680oooo5@00003o0?ooocX0oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.95996 .37675 Mdot
.5 Mabswid
.5 .5 m
.95996 .37675 L
s
0 1 0 r
.5 .5 m
.95996 .5 L
s
1 0 0 r
.95996 .37675 m
.95996 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.93651 .59329 Mdot
1 0 0 r
.93651 .23285 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo0`000?m00?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool07@3oool001<0oooo00<000000?ooo`3oool0[03oool70000ob<0oooo100000060?oo
o`8000001P3oool4000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0L0?oo
o`004P3oool00`000000oooo0?ooo`2]0?ooo`L0003o8P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000
003oool0oooo0:`0oooo2@000?lQ0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
6`3oool00180oooo00<000000?ooo`3oool0[03oool40000o`030?l000000?l0003o0080003o8@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o
ool200000340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool06P3oool00180oooo00<000000?ooo`3oool0Z`3oool5
0000o`030?l000000?l0003o0080003o603oool6000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0J0?ooo`004@3oool00`000000oooo0?ooo`2X0?ooo`@0003o0P3oool30000
o`040?l000000?l0003o0000ob80oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`@000001@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo000A0?oo
o`030000003oool0oooo0:D0oooo0`000?l60?ooo`<0003o00@0o`000000o`000?l0003o8P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo000A0?ooo`030000003oool0oooo
0:40oooo10000?l;0?ooo`030000o`3o0000003o02@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2M0?ooo`@0003o403oool00`3o0000
00000?ooo`0T0?ooo`@000003P3oool5000000@0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2I0?ooo`@0003o503oool00`3o0000oooo
0000000o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3oool00100oooo00<0
00000?ooo`3oool0U`3oool30000oaP0oooo00<0o`000?ooo`000000?`3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo01L0oooo000@0?ooo`030000003oool0oooo09<0oooo10000?lK
0?ooo`030?l0003oool0000003l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool010000000oooo0?l0003o
000E0?ooo`00403oool00`000000oooo0?ooo`2?0?ooo`@0003o7`3oool00`3o0000oooo0000000o
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02<0oooo1P3o000C0?ooo`00403oool00`000000oooo0?ooo`2<0?oo
o`<0003o8`3oool0103o0000oooo0?ooo`00000n0?ooo`030000003oool0oooo0180oooo1`00000A
0?ooo`H000004`3oool4000000X0oooo00<000000?ooo`3oool02@3oool4000000L0oooo00<00000
0?ooo`3oool02@3oool4000001D0oooo1P3o000C0?ooo`00403oool00`000000oooo0?ooo`280?oo
o`@0003o9P3oool0103o0000oooo0?ooo`00000n0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04@3oool80?l00180oooo000@0?ooo`030000003oool0oooo08@0oooo10000?lZ0?oo
o`040?l0003oool0oooo000003h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A
0?ooo`P0o`004P3oool00100oooo00<000000?ooo`3oool0P03oool40000obh0oooo00@0o`000?oo
o`3oool00000?P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00@00000
0?ooo`3oool000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo1P00
00090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000o`000?l0
00040?l001<0oooo000?0?ooo`030000003oool0oooo07h0oooo0`000?lb0?ooo`040?l0003oool0
oooo000003h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05@3oool2000000P0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
4@3oool00`000000o`000?l000040?l001<0oooo000?0?ooo`030000003oool0oooo07X0oooo1000
0?le0?ooo`040?l0003oool0oooo000003h0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`060?ooo`@00000503oool00`000000oooo0?ooo`020?l000030000003oool0oooo0180
oooo000?0?ooo`030000003oool0oooo07H0oooo10000?li0?ooo`040?l0003oool0oooo000003h0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?ooo`1c0?oo
o`<0003o?@3oool0103o0000oooo0?ooo`00000n0?ooo`030000003oool0oooo01<0oooo0`00000A
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?oo
o`3oool0000001<0oooo000?0?ooo`030000003oool0oooo06l0oooo10000?m00?ooo`040?l0003o
ool0oooo000003h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0080oooo1000000D0?ooo`@000001P3oool00`000000oooo0?ooo`0>0?ooo`800000
303oool00`000000oooo0?ooo`050?ooo`D000005P3oool4000001<0oooo000?0?ooo`030000003o
ool0oooo06/0oooo10000?m40?ooo`040?l0003oool0oooo000003h0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`1W0?ooo`@0003oB03o
ool0103o0000oooo0?ooo`00000n0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
403oool000l0oooo00<000000?ooo`3oool0I03oool30000od`0oooo00@0o`000?ooo`3oool00000
?P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003o
ool0oooo0600oooo10000?m?0?ooo`050?l0003oool0oooo0?ooo`000000?@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo05`0oooo1000
0?mC0?ooo`050?l0003oool0oooo0?ooo`000000?@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo05X0ooooF@00o`001@3o0000oooo0?oo
o`3oool0000003T0ooooXP00000;0?ooo`003`3oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`06
0000003oool0oooo0000003oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo000?
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool2000002<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?oo
o`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0>`3oool200000280oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo000?0?ooo`03
0000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0000000Q0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0a0?ooo`00
3`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`000000
803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
<@3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000001l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0300oooo000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03o
ool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`003`3o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0^0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`00403oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?ooo`00403oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0[
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0[0?ooo`004@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0Z0?ooo`00
4@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003o
ool0oooo02<0oooo100000060?ooo`8000001P3oool4000000D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0X0?ooo`004P3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0X0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
0P00000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo02L0oooo000B0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000
00050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool09P3oool00180oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0U0?ooo`@000003P3oool5000000@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0T0?ooo`004`3oool00`000000oooo0?ooo`2^0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0S0?ooo`00503o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool03P3oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool08P3oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000009@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo0240oooo000E0?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`8000009P3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0200oooo000E0?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`8000009@3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo01l0oooo000E0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000002<0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0O0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
0240oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0N0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0M0?ooo`005`3oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0L0?ooo`00603oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0K0?ooo`00603oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0J0?oo
o`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`020?ooo`800?l05@3oool001T0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool2000000H00?l04`3oool001X0oooo00<0
00000?ooo`3oool0X03oool00`000000oooo0?ooo`0m0?ooo`L000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1M0?ooo`H00?l04`3oool001X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B
0?ooo`8000003`3oool2000005l0oooo2000o`0B0?ooo`006P3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`8000005`3oool2000000X0oooo0`00001Q0?ooo`P00?l04P3oool001/0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo1P00000K0?ooo`X0
0000I@3oool6003o00@000003`3oool001`0oooo00<000000?ooo`3oool0W03oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S@3oool6003o01<0oooo
000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08l0oooo0P00o`0E0?ooo`007@3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2V
0?ooo`007P3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0440oooo0`00002_0?oo
o`007`3oool00`000000oooo0?ooo`2F0?ooo`800000AP3oool00`000000oooo0?ooo`2]0?ooo`00
7`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?H0oooo000P0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0mP3oool00240oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`3g0?ooo`008P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
0?L0oooo000R0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0n03oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`3i0?ooo`00903oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3k0?oo
o`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0?`0oooo000W0?ooo`800000
Q`3oool00`000000oooo0?ooo`3m0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo0?h0oooo000Y0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0o`3oool0
02X0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3o0?ooo`40oooo000[0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3oool10?ooo`00;03oool2000007d0oooo
0P00003o0?ooo`@0oooo000]0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`00;P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo1@3oool0
02l0oooo0P00001f0?ooo`800000o`3oool80?ooo`00<@3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo0?l0oooo203oool00380oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`3o0?ooo`P0oooo000c0?ooo`800000K`3oool200000?l0oooo2`3oool003D0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo000f0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=`3oool00`000000oooo0?ooo`1V0?ooo`80
0000o`3oool?0?ooo`00>03oool2000006@0oooo0P00003o0?oooa40oooo000j0?ooo`800000H03o
ool200000?l0oooo4`3oool003`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o
0?oooa<0oooo000m0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooolD0?oo
o`00?P3oool2000005P0oooo0P00003o0?oooaL0oooo00100?ooo`<00000D`3oool200000?l0oooo
6@3oool004<0oooo0P00001?0?ooo`800000o`3ooolK0?ooo`00A@3oool2000004/0oooo0P00003o
0?oooad0oooo00170?ooo`800000A`3oool200000?l0oooo7`3oool004T0oooo1000000n0?ooo`D0
0000o`3ooolQ0?ooo`00C@3oool2000003X0oooo0P00003o0?ooobH0oooo001?0?ooo`<00000=@3o
ool200000?l0oooo:03oool00580oooo1000000/0?ooo`D00000o`3ooolZ0?ooo`00EP3oool50000
02<0oooo1000003o0?ooobl0oooo001K0?ooo`L000005@3oool700000?l0oooo<`3oool00680oooo
5@00003o0?ooocX0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
0 0 1 r
.05 w
.97619 .5 Mdot
.5 Mabswid
.5 .5 m
.97619 .5 L
s
0 1 0 r
.5 .5 m
.97619 .5 L
s
1 0 0 r
.97619 .5 m
.97619 .5 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 1 0 r
.05 w
.97619 .60332 Mdot
1 0 0 r
.97619 .30902 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000cB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool;00000?l0oooo?`3o
ool005h0oooo2@00000;0?ooo`T00000o`3ooolf0?ooo`00F@3oool5000001d0oooo1000003o0?oo
oc80oooo001E0?ooo`@000009P3oool500000?l0oooo;@3oool00500oooo1@00000_0?ooo`@00000
o`3ooolY0?ooo`00CP3oool2000003P0oooo0`00003o0?ooobH0oooo001<0?ooo`800000?@3oool2
00000?l0oooo903oool004X0oooo0P0000110?ooo`800000o`3ooolR0?ooo`00B03oool2000004D0
oooo0P00003o0?ooob00oooo00160?ooo`800000B@3oool200000?l0oooo7P3oool004<0oooo0`00
001=0?ooo`800000o`3ooolL0?ooo`00@@3oool200000580oooo0P00003o0?oooaX0oooo000o0?oo
o`800000EP3oool200000?l0oooo603oool003d0oooo0P00001J0?ooo`800000o`3ooolF0?ooo`00
>`3oool2000005h0oooo0P00003o0?oooa@0oooo000i0?ooo`800000HP3oool200000?l0oooo4P3o
ool003P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo403oool003L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000f0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`00=03oool2000006d0oooo0P00003o0?ooo``0oooo
000c0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3oool90?ooo`00<P3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo203oool00300oooo0P00001e0?oo
o`030000003oool0oooo0?l0oooo1`3oool002l0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00;@3oool00`000000oooo0?ooo`1j0?ooo`800000o`3oool50?ooo`00;03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo0P3oool002/0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000Y0?ooo`800000P`3oool00`000000
oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0?h0oooo
000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o@3oool002L0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`3m0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0n`3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3j0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000R0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0n03oool00280oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0?L0
oooo000P0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0mP3oool001l0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`3f0?ooo`007`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0@@3oool700000:`0oooo000N0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000M0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:H0oooo000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo000L0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0=P3oool6000000H0oooo00<000000?ooo`3oool0103oool2
000004L0oooo2000000N0?ooo`P00000<P3oool001/0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool30000
00P0oooo00<000000?ooo`3oool0603oool3000000P0oooo0`00000_0?ooo`006P3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo0P00000F0?ooo`8000003P3oool2000002d0
oooo000J0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0?P3oool3000000H0oooo
00<000000?ooo`3oool0@03oool2000000l0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Z0?ooo`006@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool00`000000oooo0?ooo`0C
0?ooo`800000:P3oool001P0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool001P0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool09P3oool001L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03X0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`005P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`005P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000008@3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08P3oool001D0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0000000T0?ooo`030000003oool0oooo0240oooo000E0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`00
5@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0
803oool001D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo01l0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo
0000000V0?ooo`030000003oool0oooo01h0oooo000D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo000C
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool09@3oool4000000H0oooo0P0000060?ooo`@000001@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01`0oooo000B0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool200000340oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3o
ool00180oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0I0?ooo`H000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo000A0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo100000050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00140
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00140oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0S0?ooo`@000003P3oool5000000@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`00
403oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0F0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool04P3oool700000140oooo1P00000C0?ooo`@000002P3o
ool00`000000oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`090?ooo`@000005@3o
ool4000001D0oooo000@0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`060000003oool0oooo
0000003oool00000503oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool6000000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001@0oooo000?
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005@3o
ool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool4000001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`003`3oool00`000000oooo0?oo
o`2f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04`3oool300000140oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`00
00004`3oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@00000
503oool4000000H0oooo00<000000?ooo`3oool03P3oool2000000`0oooo00<000000?ooo`3oool0
1@3oool5000001H0oooo1000000C0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`003`3oool0
0`000000oooo0?ooo`2e0?ooo`<0003o?@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0100oooo000?0?ooo`030000003oool0oooo0;<0oooo1`000?lk0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02<0oooo00<000000?l0003o00003`3oool000l0oooo00<000000?ooo`3oool0/`3oool70000oc/0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08@3oool60?l000d0oooo000?0?ooo`030000003oool0oooo0;80oooo
2@000?lj0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0240oooo1P3o000=0?ooo`003`3oool00`000000oooo0?oo
o`1J0?oooed00?l000@0o`000000o`000?l0003o=P3ooonI000000P0o`0000<000000?ooo`3oool0
2@3oool000l0oooo00<000000?ooo`3oool0/P3oool90000ocX0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo
0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o000<0?ooo`003`3oool0
0`000000oooo0?ooo`2c0?ooo`L0003o>`3oool2000002<0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo1P3o000=0?ooo`003`3oool00`00
0000oooo0?ooo`2c0?ooo`L0003o>`3oool200000280oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo1P3o000=0?ooo`003`3oool00`000000
oooo0?ooo`2e0?ooo`<0003o?@3oool00`000000oooo0000000Q0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0P0?ooo`80o`003`3oool000l0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo
000?0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0?03oool010000000oooo0?oo
o`00000O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0`0?ooo`003`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo03`0oooo00@0
00000?ooo`3oool000007P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0<03oool000l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?oo
o`0l0?ooo`050000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool000l0oooo00<0
00000?ooo`3oool0]P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?oo
o`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0;@3oool00100oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0
]@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
;03oool00100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0]03oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:`3oool0
0100oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0:`3oool00140oooo00<000000?ooo`3oool0/`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:P3oool00140oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0:P3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0S0?ooo`@000001P3oool2000000H0oooo100000050?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0:@3oool00140oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0:03oool00180oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`800000
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0W0?ooo`004P3oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02H0oooo000B0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool09@3oool4000000h0oooo1@0000040?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool08`3oool001@0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo00D0
00000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
8P3oool001@0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00h0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo0280oooo000E0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03`3oool2000002H0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03`3oool2000002D0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0O0?ooo`005@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000S0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000Q0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool07P3oool001H0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool07P3oool001L0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07@3oool001L0oooo00<000000?ooo`3oool0Y@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0703o
ool001P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool06`3oool001P0oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool06P3oool001T0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0FP3oool2000001T0oooo000J0?ooo`030000003oool0oooo0:00oooo00<0
00000?ooo`3oool0?@3oool7000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`050?ooo`800?l03`3oool001X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B
0?ooo`8000003`3oool200000640oooo00<000000?ooo`3oool00P3oool6003o00d0oooo000J0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo0P00000G0?ooo`8000002P3oool3000006@0oooo0P0000020?oo
o`H00?l03@3oool001/0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo00@0oooo1P00000K0?ooo`X00000J@3oool00`0000000?l0003o0006003o00`0
oooo000L0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0980oooo2000o`0<0?ooo`007@3oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2C0?ooo`H00?l03@3oool001d0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T`3oool6003o00d0oooo000N0?oo
o`030000003oool0oooo09T0oooo00<000000?ooo`3oool0@@3oool300000:l0oooo000O0?ooo`03
0000003oool0oooo09H0oooo0P0000160?ooo`030000003oool0oooo0:d0oooo000O0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo0?L0oooo000R0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0m`3oool00280
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0?T0oooo000T0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`3j
0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?/0oooo000V0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0o03oool002L0oooo0P0000270?ooo`030000
003oool0oooo0?d0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0oP3o
ool002T0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3o0?ooo`00:P3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo0?l0oooo0@3oool002/0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`3o0?ooo`40oooo000/0?ooo`800000O@3oool200000?l0oooo
103oool002d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000^
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0o`3oool50?ooo`00;`3oool20000
07H0oooo0P00003o0?ooo`P0oooo000a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0o`3oool80?ooo`00<P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0oooo
203oool003<0oooo0P00001_0?ooo`800000o`3oool;0?ooo`00=@3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo0?l0oooo2`3oool003H0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`3o0?ooo``0oooo000g0?ooo`030000003oool0oooo06H0oooo0P00003o0?ooo`l0
oooo000h0?ooo`800000I03oool200000?l0oooo4@3oool003X0oooo0P00001P0?ooo`800000o`3o
oolC0?ooo`00?03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo4`3oool0
03d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa@0oooo000n0?ooo`80
0000F03oool200000?l0oooo5`3oool00400oooo0`00001C0?ooo`800000o`3ooolI0?ooo`00@`3o
ool2000004l0oooo0P00003o0?oooa/0oooo00150?ooo`800000B`3oool200000?l0oooo7@3oool0
04L0oooo0P0000170?ooo`800000o`3ooolO0?ooo`00B@3oool4000003h0oooo1@00003o0?ooob40
oooo001=0?ooo`800000>P3oool200000?l0oooo9P3oool004l0oooo0`00000e0?ooo`800000o`3o
oolX0?ooo`00DP3oool4000002`0oooo1@00003o0?ooobX0oooo001F0?ooo`D000008`3oool40000
0?l0oooo;`3oool005/0oooo1`00000E0?ooo`L00000o`3ooolc0?ooo`00HP3ooolE00000?l0oooo
>P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {204.688, 0}} -> {-0.0528339, -0.0238146, \
0.00732832, 0.00732832}, {{10.8125, 205.75}, {199.813, 4.875}} -> {-1.16649, \
-1.10253, 0.0161592, 0.0161592}, {{225.188, 420.125}, {199.813, 4.875}} -> \
{-10.8016, -2.16324, 0.06156, 0.0317055}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Technical\ publishing\ and\ Publicon\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "Publicon is a new technical publishing environment offered by Wolfram \
Research that uses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook technology to easily produce journal/book quality documents.  It \
has an interactive interface and allows you to save in several formats, \
including ",
  Cell[BoxData[
      ButtonBox[
        StyleBox[
          RowBox[{"L", 
            StyleBox[
              AdjustmentBox["A",
                BoxMargins->{{-0.36, -0.1}, {0, 0}},
                BoxBaselineShift->-0.2],
              FontSize->Smaller], "T", 
            AdjustmentBox["E",
              BoxMargins->{{-0.075, -0.085}, {0, 0}},
              BoxBaselineShift->0.5], "X"}]],
        ButtonData:>{
          URL[ 
          "file:///C:/Web/RD_HTML/RKnapp/Talks/India/Data/AMS_JournalSample.\
tex"], None},
        ButtonStyle->"Hyperlink"]]],
  ", PDF, HTML, and ",
  ButtonBox["MathML",
    ButtonData:>{
      URL[ 
      "file:///C:/Web/RD_HTML/RKnapp/Talks/India/Data/AMS_JournalSample.xml"],
       None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox["Conclusion",
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has been designed and implemented from the perspective that scientific \
exploration and productivity are improved by an interactive computing \
environment that enables you to mix mathematical and numerical computations, \
work with a wide variety of data, visualize results, and communicate \
conclusions.  Some important features that alone, or in combination, are \
unique to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are"
}], "Text"],

Cell["\<\
Natural language built on symbolic expressions allowing complete \
generality.\
\>", "BulletedList"],

Cell["\<\
Flexibility with many types and sizes of numbers allowing for more \
precise computations when necessary.\
\>", "BulletedList"],

Cell["\<\
Task based command set with automatic algorithm selection allows \
you to focus on the science.\
\>", "BulletedList"],

Cell["\<\
Depth of algorithmic knowledge exceeds what one person would be \
able to master.\
\>", "BulletedList"],

Cell["\<\
Libraries optimized for particular platforms are used for low-level \
tasks to achieve maximal processor speed.\
\>", "BulletedList"],

Cell[TextData[{
  "Data processing capabilities are extremely powerful when the mathematical \
and statistical capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are combined with a wide variety of data formats."
}], "BulletedList"],

Cell["\<\
Communication with other programs extends the possibilities even \
further.\
\>", "BulletedList"],

Cell[TextData[{
  "Results can be communicated electronically or via print using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks."
}], "BulletedList"],

Cell["", "Text"],

Cell[TextData[{
  "As a thought to leave you with:  People often comment to me about the \
depth and breadth of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s capabilities.  Much of what makes the development of these features \
possible is that we use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " extensively for prototyping and development of additional algorithms and \
commands."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"SlideShow",
WindowToolbars->{},
WindowSize->{1390, 933},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
ShowSelection->True,
CellLabelAutoDelete->False,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Wolfram Technology Conference 2004", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 50}, {10, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Title", "SlideShow"],
    CellMargins->{{100, 50}, {10, 80}}],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 50}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "SlideShow"],
    CellMargins->{{100, 50}, {30, 2}}],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "SlideShow"],
    CellMargins->{{100, 25}, {30, 10}}],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 50}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "SlideShow"],
    CellMargins->{{100, 50}, {11, 35}}],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{72, 50}, {6, 15}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellMargins->{{100, 50}, {8, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 0}, {8, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{72, 50}, {6, 12}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "SlideShow"],
    CellMargins->{{100, 50}, {6, 12}}],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{60, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Helvetica"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{72, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{100, 50}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 50}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->10],
  
  Cell[StyleData["SmallText", "SlideShow"],
    CellMargins->{{100, 50}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->10],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, 50}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {8, 10}},
    ShowCellLabel->False,
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "SlideShow"],
    CellMargins->{{100, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, 50}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {10, 8}},
    ShowCellLabel->False,
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Message", "SlideShow"],
    CellMargins->{{100, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Print", "SlideShow"],
    CellMargins->{{100, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "SlideShow"],
    ShowCellBracket->True,
    ImageMargins->{{100, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.392157, 0.396078, 0.717647]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Presentation Specific", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellMargins->{{50, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "\[Bullet]", "BulletedList", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"BulletedList",
    FontFamily->"Helvetica"],
  
  Cell[StyleData["BulletedList", "Presentation"],
    CellMargins->{{62, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["BulletedList", "SlideShow"],
    CellMargins->{{90, 50}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["BulletedList", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{100, 27}, {2, 20}},
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{200, 27}, {2, 50}},
    FontSize->28],
  
  Cell[StyleData["Author", "SlideShow"],
    CellMargins->{{200, 27}, {2, 50}},
    FontSize->28],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{100, 27}, {2, 20}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Affiliation"],
    CellMargins->{{100, 27}, {30, 12}},
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Affiliation", "Presentation"],
    CellMargins->{{200, 27}, {2, 10}},
    FontSize->28],
  
  Cell[StyleData["Affiliation", "SlideShow"],
    CellMargins->{{200, 27}, {2, 10}},
    FontSize->28],
  
  Cell[StyleData["Affiliation", "Printout"],
    CellMargins->{{100, 27}, {2, 12}},
    FontSize->14]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Header Graphic", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ConferenceGraphicCell"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    PageBreakBelow->False,
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    Background->GrayLevel[1],
    Magnification->1],
  
  Cell[StyleData["ConferenceGraphicCell", "Presentation"]],
  
  Cell[StyleData["ConferenceGraphicCell", "SlideShow"]],
  
  Cell[StyleData["ConferenceGraphicCell", "Printout"],
    FontSize->8,
    Magnification->0.75]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "SlideShow"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "SlideShow"],
    CellMargins->{{100, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}, {"Outline3", 0}, {"Outline4", 0}},
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "SlideShow"]],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}, {"Outline4", 0}},
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "SlideShow"]],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "SlideShow"]],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "SlideShow"]],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "SlideShow"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "SlideShow"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 50}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 0},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.850004],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 40, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"],
    FontSize->10,
    Magnification->1],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellOpen->False,
    FontSize->1]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{20, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{14, 10}, {6, 12}}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlidePreviousNextLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    FontSize->12,
    FontColor->GrayLevel[0.500008],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlidePreviousNextLink", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["SlidePreviousNextLink", "SlideShow"]],
  
  Cell[StyleData["SlidePreviousNextLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PreviousNext"],
    CellMargins->{{60, 10}, {7, 7}},
    TextAlignment->0.75,
    LineSpacing->{1, 3},
    CounterIncrements->"PreviousNext",
    FontFamily->"Helvetica",
    FontSize->12,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["PreviousNext", "Presentation"],
    CellMargins->{{24, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["PreviousNext", "SlideShow"],
    CellMargins->{{50, 50}, {50, 15}},
    FontSize->14],
  
  Cell[StyleData["PreviousNext", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SlideShowHeader"->{
    Cell[1776, 53, 1679, 44, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[6629, 213, 1788, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[150703, 2610, 1800, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[681423, 11340, 1815, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1950561, 27075, 1814, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1955114, 27213, 1785, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1957624, 27292, 1800, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1959859, 27357, 1800, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1962903, 27458, 1788, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1968177, 27608, 1788, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1970834, 27693, 1787, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1973493, 27777, 1782, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1977242, 27898, 1796, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1980733, 28018, 1804, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1983203, 28091, 1803, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2131866, 30741, 1814, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2134632, 30834, 1814, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2139553, 31013, 1814, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2206752, 33360, 1803, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2209054, 33429, 1791, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2214131, 33615, 1803, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2224951, 33966, 1791, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2227453, 34042, 1788, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2229792, 34108, 1787, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2233887, 34228, 1787, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2236879, 34312, 1787, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2240705, 34430, 1796, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2248306, 34642, 1851, 50, 40, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[2250596, 34707, 1789, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[3002447, 56390, 1789, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[3553794, 75525, 1797, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[8253241, 174784, 1823, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[8518683, 180132, 1823, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[8527961, 180338, 1823, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[8550117, 180953, 1823, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10445562, 281517, 1798, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10447925, 281588, 1790, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[11825613, 310052, 1795, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[11872765, 311351, 1789, 48, 75, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[16062028, 369346, 1787, 48, 75, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[16635563, 376468, 1787, 48, 75, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[16641717, 376649, 1781, 48, 75, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[17022539, 389937, 1791, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[17027725, 390134, 1805, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[17951114, 411591, 1815, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[17954080, 411679, 1787, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"]},
  "M185A.1.2"->{
    Cell[1961782, 27412, 109, 2, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1962178, 27428, 202, 6, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1964694, 27508, 91, 1, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1965834, 27537, 202, 6, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1966815, 27569, 74, 1, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1969968, 27658, 77, 1, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1970154, 27665, 218, 6, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1972851, 27750, 219, 6, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[1975597, 27837, 99, 1, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2216892, 33689, 367, 8, 85, "DisplayFormula",
      Evaluatable->False,
      CellTags->"M185A.1.2"],
    Cell[2217262, 33699, 140, 4, 64, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2217721, 33721, 277, 9, 65, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2218721, 33755, 277, 9, 65, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2219778, 33790, 277, 9, 65, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2220833, 33825, 277, 9, 65, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2221894, 33860, 277, 9, 65, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2222941, 33895, 277, 9, 65, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2223929, 33929, 277, 9, 65, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[2238807, 34369, 277, 7, 86, "MathCaption",
      CellTags->"M185A.1.2"],
    Cell[11875337, 311430, 88, 1, 64, "MathCaption",
      CellTags->"M185A.1.2"]},
  "b:2.5"->{
    Cell[16637353, 376518, 1375, 43, 238, "Text",
      CellTags->"b:2.5"],
    Cell[16638731, 376563, 208, 6, 49, "Text",
      CellTags->"b:2.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SlideShowHeader", 18047595, 414786},
  {"M185A.1.2", 18052271, 414879},
  {"b:2.5", 18053951, 414921}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 1679, 44, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[3458, 99, 160, 6, 378, "Title"],
Cell[3621, 107, 56, 1, 128, "Author"],
Cell[3680, 110, 70, 1, 68, "Affiliation"],

Cell[CellGroupData[{
Cell[3775, 115, 39, 0, 50, "Subsubsection"],

Cell[CellGroupData[{
Cell[3839, 119, 317, 7, 75, "Input",
  InitializationCell->True],
Cell[4159, 128, 277, 5, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4473, 138, 151, 4, 45, "Input",
  InitializationCell->True],
Cell[4627, 144, 98, 2, 70, "Output"]
}, Open  ]],
Cell[4740, 149, 227, 7, 45, "Input",
  InitializationCell->True],
Cell[4970, 158, 105, 3, 45, "Input",
  InitializationCell->True],
Cell[5078, 163, 128, 3, 45, "Input",
  InitializationCell->True],
Cell[5209, 168, 117, 3, 45, "Input",
  InitializationCell->True],
Cell[5329, 173, 212, 6, 46, "Input",
  InitializationCell->True],
Cell[5544, 181, 210, 6, 46, "Input",
  InitializationCell->True],
Cell[5757, 189, 115, 3, 68, "MathCaption"],
Cell[5875, 194, 705, 13, 315, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6629, 213, 1788, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[8420, 263, 141216, 2317, 174, 141124, 2314, "GraphicsData", "Bitmap", \
"Graphics"],
Cell[149639, 2582, 274, 5, 129, "Text"],
Cell[149916, 2589, 97, 3, 59, "BulletedList"],
Cell[150016, 2594, 69, 0, 59, "BulletedList"],
Cell[150088, 2596, 578, 9, 228, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150703, 2610, 1800, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[152506, 2660, 583, 10, 196, "Text"],
Cell[153092, 2672, 528294, 8663, 684, 528202, 8660, "GraphicsData", "Bitmap", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[681423, 11340, 1815, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[683241, 11390, 218, 6, 97, "Text"],

Cell[CellGroupData[{
Cell[683484, 11400, 49, 0, 59, "Subsection"],
Cell[683536, 11402, 1266038, 15633, 545, 1265911, 15629, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[1949577, 27037, 201, 5, 97, "Text"],
Cell[1949781, 27044, 140, 4, 64, "Text"],
Cell[1949924, 27050, 150, 3, 88, "BulletedList"],
Cell[1950077, 27055, 123, 3, 59, "BulletedList"],
Cell[1950203, 27060, 143, 3, 88, "BulletedList"],
Cell[1950349, 27065, 163, 4, 60, "BulletedList"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1950561, 27075, 1814, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1952378, 27125, 789, 18, 232, "Text"],
Cell[1953170, 27145, 459, 10, 164, "Text"],
Cell[1953632, 27157, 404, 8, 163, "Text"],
Cell[1954039, 27167, 159, 4, 129, "Text"],
Cell[1954201, 27173, 103, 3, 96, "Text"],
Cell[1954307, 27178, 131, 4, 129, "Text"],
Cell[1954441, 27184, 114, 4, 129, "Text"],
Cell[1954558, 27190, 142, 5, 162, "Text"],
Cell[1954703, 27197, 216, 5, 162, "Text"],
Cell[1954922, 27204, 155, 4, 129, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1955114, 27213, 1785, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1956902, 27263, 230, 6, 97, "Text"],
Cell[1957135, 27271, 126, 5, 60, "BulletedList"],
Cell[1957264, 27278, 142, 3, 88, "BulletedList"],
Cell[1957409, 27283, 178, 4, 88, "BulletedList"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1957624, 27292, 1800, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1959427, 27342, 395, 10, 131, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1959859, 27357, 1800, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1961662, 27407, 117, 3, 63, "Text"],
Cell[1961782, 27412, 109, 2, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1961916, 27418, 130, 3, 95, "Input"],
Cell[1962049, 27423, 114, 2, 85, "Output"]
}, Open  ]],
Cell[1962178, 27428, 202, 6, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1962405, 27438, 70, 2, 57, "Input"],
Cell[1962478, 27442, 376, 10, 91, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1962903, 27458, 1788, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1964694, 27508, 91, 1, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1964810, 27513, 659, 13, 298, "Input"],
Cell[1965472, 27528, 347, 6, 125, "Output"]
}, Open  ]],
Cell[1965834, 27537, 202, 6, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1966061, 27547, 73, 2, 57, "Input"],
Cell[1966137, 27551, 663, 15, 193, "Output"]
}, Open  ]],
Cell[1966815, 27569, 74, 1, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1966914, 27574, 127, 3, 57, "Input"],
Cell[1967044, 27579, 1084, 23, 307, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1968177, 27608, 1788, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1969968, 27658, 77, 1, 64, "MathCaption",
  CellTags->"M185A.1.2"],
Cell[1970048, 27661, 103, 2, 56, "Input"],
Cell[1970154, 27665, 218, 6, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1970397, 27675, 134, 3, 56, "Input"],
Cell[1970534, 27680, 251, 7, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1970834, 27693, 1787, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1972624, 27743, 224, 5, 97, "Text"],
Cell[1972851, 27750, 219, 6, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1973095, 27760, 114, 2, 56, "Input"],
Cell[1973212, 27764, 232, 7, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1973493, 27777, 1782, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1975278, 27827, 72, 0, 63, "Text"],
Cell[1975353, 27829, 241, 6, 97, "Text"],
Cell[1975597, 27837, 99, 1, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[1975721, 27842, 177, 3, 95, "Input"],
Cell[1975901, 27847, 83, 2, 76, "Output"]
}, Open  ]],
Cell[1975999, 27852, 95, 3, 63, "Text"],
Cell[1976097, 27857, 211, 4, 86, "MathCaption"],

Cell[CellGroupData[{
Cell[1976333, 27865, 152, 4, 57, "Input"],
Cell[1976488, 27871, 76, 2, 57, "Output"]
}, Open  ]],
Cell[1976579, 27876, 97, 3, 63, "Text"],
Cell[1976679, 27881, 230, 5, 86, "MathCaption"],
Cell[1976912, 27888, 293, 5, 138, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1977242, 27898, 1796, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1979041, 27948, 88, 3, 63, "Text"],
Cell[1979132, 27953, 116, 3, 64, "MathCaption"],
Cell[1979251, 27958, 99, 2, 57, "Input"],
Cell[1979353, 27962, 85, 1, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[1979463, 27967, 126, 3, 95, "Input"],
Cell[1979592, 27972, 190, 3, 93, "Output"]
}, Open  ]],
Cell[1979797, 27978, 74, 0, 63, "Text"],
Cell[1979874, 27980, 105, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[1980004, 27987, 136, 3, 57, "Input"],
Cell[1980143, 27992, 288, 5, 171, "Output"]
}, Open  ]],
Cell[1980446, 28000, 47, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[1980518, 28004, 69, 2, 57, "Input"],
Cell[1980590, 28008, 65, 2, 57, "Output"]
}, Open  ]],
Cell[1980670, 28013, 26, 0, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1980733, 28018, 1804, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1982540, 28068, 136, 3, 96, "Text"],
Cell[1982679, 28073, 137, 3, 64, "MathCaption"],
Cell[1982819, 28078, 347, 8, 261, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1983203, 28091, 1803, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1985009, 28141, 108, 3, 63, "Text"],
Cell[1985120, 28146, 109, 3, 64, "MathCaption"],
Cell[1985232, 28151, 91, 2, 57, "Input"],
Cell[1985326, 28155, 120, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[1985471, 28162, 104, 2, 57, "Input"],
Cell[1985578, 28166, 158, 4, 57, "Output"]
}, Open  ]],
Cell[1985751, 28173, 153, 3, 96, "Text"],
Cell[1985907, 28178, 40, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[1985972, 28182, 74, 2, 57, "Input"],
Cell[1986049, 28186, 55732, 966, 444, 6476, 353, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[2041796, 29155, 84, 1, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[2041905, 29160, 73, 2, 57, "Input"],
Cell[2041981, 29164, 22021, 419, 3171, "Output"]
}, Closed]],
Cell[2064017, 29586, 207, 4, 85, "Text"],
Cell[2064227, 29592, 111, 3, 64, "MathCaption"],
Cell[2064341, 29597, 192, 4, 91, "Input"],
Cell[2064536, 29603, 101, 3, 63, "Text"],
Cell[2064640, 29608, 110, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2064775, 29615, 116, 2, 57, "Input"],
Cell[2064894, 29619, 66418, 1098, 444, 6496, 353, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2131315, 30719, 158, 4, 43, "Output"]
}, Closed]],
Cell[2131488, 30726, 105, 3, 32, "MathCaption"],
Cell[2131596, 30731, 233, 5, 91, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2131866, 30741, 1814, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2133683, 30791, 226, 6, 97, "Text"],
Cell[2133912, 30799, 83, 1, 64, "MathCaption"],
Cell[2133998, 30802, 97, 2, 57, "Input"],
Cell[2134098, 30806, 87, 2, 58, "Input"],
Cell[2134188, 30810, 100, 3, 63, "Text"],
Cell[2134291, 30815, 104, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2134420, 30822, 73, 2, 57, "Input"],
Cell[2134496, 30826, 87, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2134632, 30834, 1814, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2136449, 30884, 267, 5, 129, "Text"],
Cell[2136719, 30891, 100, 3, 63, "Text"],
Cell[2136822, 30896, 60, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2136907, 30900, 120, 3, 57, "Input"],
Cell[2137030, 30905, 105, 2, 76, "Output"]
}, Open  ]],
Cell[2137150, 30910, 75, 0, 63, "Text"],
Cell[2137228, 30912, 174, 5, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2137427, 30921, 148, 3, 57, "Input"],
Cell[2137578, 30926, 132, 3, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2137747, 30934, 70, 2, 57, "Input"],
Cell[2137820, 30938, 115, 2, 58, "Output"]
}, Open  ]],
Cell[2137950, 30943, 171, 4, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2138146, 30951, 73, 2, 57, "Input"],
Cell[2138222, 30955, 130, 3, 70, "Output"]
}, Open  ]],
Cell[2138367, 30961, 110, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2138502, 30968, 73, 2, 57, "Input"],
Cell[2138578, 30972, 106, 2, 57, "Output"]
}, Open  ]],
Cell[2138699, 30977, 231, 4, 86, "MathCaption"],

Cell[CellGroupData[{
Cell[2138955, 30985, 79, 2, 57, "Input"],
Cell[2139037, 30989, 95, 2, 57, "Output"]
}, Open  ]],
Cell[2139147, 30994, 156, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2139328, 31001, 88, 2, 57, "Input"],
Cell[2139419, 31005, 85, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2139553, 31013, 1814, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2141370, 31063, 123, 3, 63, "Text"],
Cell[2141496, 31068, 237, 8, 64, "MathCaption"],
Cell[2141736, 31078, 111, 2, 58, "Input"],
Cell[2141850, 31082, 51, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2141926, 31086, 145, 3, 57, "Input"],
Cell[2142074, 31091, 61681, 2189, 279, 27282, 1759, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2203770, 33283, 121, 3, 63, "Text"],
Cell[2203894, 33288, 70, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2203989, 33292, 85, 2, 57, "Input"],
Cell[2204077, 33296, 2138, 36, 408, "Output"]
}, Open  ]],
Cell[2206230, 33335, 93, 3, 63, "Text"],
Cell[2206326, 33340, 184, 4, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2206535, 33348, 86, 2, 57, "Input"],
Cell[2206624, 33352, 79, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2206752, 33360, 1803, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2208558, 33410, 276, 7, 97, "Text"],
Cell[2208837, 33419, 180, 5, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2209054, 33429, 1791, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2210848, 33479, 74, 0, 63, "Text"],
Cell[2210925, 33481, 453, 9, 163, "Text"],
Cell[2211381, 33492, 129, 3, 63, "Text"],
Cell[2211513, 33497, 51, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2211589, 33501, 61, 2, 57, "Input"],
Cell[2211653, 33505, 115, 4, 58, "Output"]
}, Open  ]],
Cell[2211783, 33512, 113, 3, 63, "Text"],
Cell[2211899, 33517, 61, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2211985, 33521, 65, 2, 57, "Input"],
Cell[2212053, 33525, 116, 4, 57, "Output"]
}, Open  ]],
Cell[2212184, 33532, 172, 4, 96, "Text"],
Cell[2212359, 33538, 54, 0, 64, "MathCaption"],
Cell[2212416, 33540, 75, 2, 57, "Input"],
Cell[2212494, 33544, 106, 3, 63, "Text"],
Cell[2212603, 33549, 117, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2212745, 33556, 94, 2, 57, "Input"],
Cell[2212842, 33560, 78, 2, 57, "Output"]
}, Open  ]],
Cell[2212935, 33565, 248, 6, 97, "Text"],
Cell[2213186, 33573, 154, 3, 96, "Text"],
Cell[2213343, 33578, 123, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2213491, 33585, 98, 2, 57, "Input"],
Cell[2213592, 33589, 109, 2, 57, "Output"]
}, Open  ]],
Cell[2213716, 33594, 111, 3, 63, "Text"],
Cell[2213830, 33599, 74, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2213929, 33603, 71, 2, 57, "Input"],
Cell[2214003, 33607, 79, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2214131, 33615, 1803, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2215937, 33665, 543, 11, 197, "Text"],
Cell[2216483, 33678, 406, 9, 163, "Text"],
Cell[2216892, 33689, 367, 8, 85, "DisplayFormula",
  Evaluatable->False,
  CellTags->"M185A.1.2"],
Cell[2217262, 33699, 140, 4, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2217427, 33707, 77, 2, 57, "Input"],
Cell[2217507, 33711, 67, 2, 57, "Output"]
}, Open  ]],
Cell[2217589, 33716, 129, 3, 63, "Text"],
Cell[2217721, 33721, 277, 9, 65, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2218023, 33734, 214, 4, 105, "Input"],
Cell[2218240, 33740, 466, 12, 81, "Output"]
}, Open  ]],
Cell[2218721, 33755, 277, 9, 65, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2219023, 33768, 214, 4, 105, "Input"],
Cell[2219240, 33774, 523, 13, 81, "Output"]
}, Open  ]],
Cell[2219778, 33790, 277, 9, 65, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2220080, 33803, 214, 4, 105, "Input"],
Cell[2220297, 33809, 521, 13, 87, "Output"]
}, Open  ]],
Cell[2220833, 33825, 277, 9, 65, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2221135, 33838, 214, 4, 105, "Input"],
Cell[2221352, 33844, 527, 13, 87, "Output"]
}, Open  ]],
Cell[2221894, 33860, 277, 9, 65, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2222196, 33873, 214, 4, 105, "Input"],
Cell[2222413, 33879, 513, 13, 87, "Output"]
}, Open  ]],
Cell[2222941, 33895, 277, 9, 65, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2223243, 33908, 214, 4, 105, "Input"],
Cell[2223460, 33914, 454, 12, 87, "Output"]
}, Open  ]],
Cell[2223929, 33929, 277, 9, 65, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2224231, 33942, 214, 4, 105, "Input"],
Cell[2224448, 33948, 454, 12, 87, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2224951, 33966, 1791, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2226745, 34016, 112, 3, 63, "Text"],
Cell[2226860, 34021, 64, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2226949, 34025, 147, 3, 57, "Input"],
Cell[2227099, 34030, 305, 6, 91, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2227453, 34042, 1788, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2229244, 34092, 359, 6, 162, "Text"],
Cell[2229606, 34100, 149, 3, 96, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2229792, 34108, 1787, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2231582, 34158, 117, 3, 63, "Text"],
Cell[2231702, 34163, 117, 3, 64, "MathCaption"],
Cell[2231822, 34168, 189, 4, 91, "Input"],
Cell[2232014, 34174, 69, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2232108, 34178, 67, 2, 57, "Input"],
Cell[2232178, 34182, 62, 2, 57, "Output"]
}, Open  ]],
Cell[2232255, 34187, 173, 4, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2232453, 34195, 69, 2, 57, "Input"],
Cell[2232525, 34199, 327, 5, 38, "Message"],
Cell[2232855, 34206, 327, 5, 38, "Message"],
Cell[2233185, 34213, 653, 9, 295, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2233887, 34228, 1787, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2235677, 34278, 73, 0, 63, "Text"],
Cell[2235753, 34280, 77, 0, 64, "MathCaption"],
Cell[2235833, 34282, 143, 4, 57, "Input"],
Cell[2235979, 34288, 64, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2236068, 34292, 68, 2, 57, "Input"],
Cell[2236139, 34296, 691, 10, 295, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2236879, 34312, 1787, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2238669, 34362, 135, 5, 64, "Text"],
Cell[2238807, 34369, 277, 7, 86, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[2239109, 34380, 281, 7, 159, "Input",
  Evaluatable->False],
Cell[2239393, 34389, 1263, 35, 361, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2240705, 34430, 1796, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2242504, 34480, 339, 10, 96, "Text"],
Cell[2242846, 34492, 4311, 115, 144, "DisplayFormula"],
Cell[2247160, 34609, 471, 9, 162, "Text"],
Cell[2247634, 34620, 454, 10, 164, "Text"],
Cell[2248091, 34632, 178, 5, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2248306, 34642, 1851, 50, 40, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2250160, 34694, 399, 8, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2250596, 34707, 1789, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[2252388, 34757, 120, 3, 64, "MathCaption"],
Cell[2252511, 34762, 96, 2, 57, "Input"],
Cell[2252610, 34766, 54, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2252689, 34770, 99, 2, 57, "Input"],
Cell[2252791, 34774, 210, 4, 102, "Output"]
}, Open  ]],
Cell[2253016, 34781, 236, 4, 96, "Text"],
Cell[2253255, 34787, 212, 4, 96, "Text"],
Cell[2253470, 34793, 176, 5, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2253671, 34802, 202, 5, 65, "Input"],
Cell[2253876, 34809, 109936, 3502, 444, 39364, 2625, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2363815, 38313, 380, 9, 91, "Output"]
}, Open  ]],
Cell[2364210, 38325, 561, 14, 163, "Text"],
Cell[2364774, 38341, 95, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2364894, 38348, 227, 5, 104, "Input"],
Cell[2365124, 38355, 120347, 3683, 444, 40620, 2693, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2485474, 42040, 468, 10, 92, "Output"]
}, Open  ]],
Cell[2485957, 42053, 107, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[2486089, 42060, 232, 5, 104, "Input"],
Cell[2486324, 42067, 255442, 7046, 444, 73220, 4791, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2741769, 49115, 445, 10, 92, "Output"]
}, Open  ]],
Cell[2742229, 49128, 220, 6, 97, "Text"],
Cell[2742452, 49136, 163, 4, 64, "MathCaption"],
Cell[2742618, 49142, 79, 1, 57, "Input"],

Cell[CellGroupData[{
Cell[2742722, 49147, 279, 6, 104, "Input"],
Cell[2743004, 49155, 550, 8, 154, "Message"],
Cell[2743557, 49165, 258392, 7207, 444, 76219, 4953, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3001952, 56374, 446, 10, 92, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3002447, 56390, 1789, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[3004239, 56440, 99, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[3004363, 56447, 155, 4, 57, "Input"],
Cell[3004521, 56453, 544989, 18959, 303, 229381, 15058, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3549513, 75414, 4232, 105, 375, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3553794, 75525, 1797, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[3555594, 75575, 202, 6, 97, "Text"],
Cell[3555799, 75583, 241, 5, 129, "Text"],
Cell[3556043, 75590, 57, 0, 59, "BulletedList"],
Cell[3556103, 75592, 56, 0, 59, "BulletedList"],
Cell[3556162, 75594, 73, 0, 59, "BulletedList"],
Cell[3556238, 75596, 67, 0, 59, "BulletedList"],
Cell[3556308, 75598, 94, 3, 63, "Text"],
Cell[3556405, 75603, 329, 6, 129, "Text"],
Cell[3556737, 75611, 95, 3, 64, "MathCaption"],
Cell[3556835, 75616, 1352, 21, 472, "Input"],
Cell[3558190, 75639, 335, 6, 129, "Text"],
Cell[3558528, 75647, 84, 1, 64, "MathCaption"],
Cell[3558615, 75650, 698, 13, 159, "Input"],
Cell[3559316, 75665, 111, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[3559452, 75672, 1391, 24, 397, "Input"],
Cell[3560846, 75698, 416, 9, 91, "Output"]
}, Open  ]],
Cell[3561277, 75710, 74, 0, 63, "Text"],
Cell[3561354, 75712, 71, 2, 63, "Text"],
Cell[3561428, 75716, 68, 2, 63, "Text"],
Cell[3561499, 75720, 188, 6, 64, "Text"],
Cell[3561690, 75728, 72, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[3561787, 75732, 331, 7, 91, "Input"],

Cell[CellGroupData[{
Cell[3562143, 75743, 187003, 3394, 363, 158601, 3038, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3749149, 79139, 189901, 3505, 363, 159960, 3130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3939053, 82646, 193408, 3633, 363, 161718, 3237, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4132464, 86281, 197468, 3768, 363, 163510, 3344, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4329935, 90051, 200555, 3904, 363, 165434, 3465, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4530493, 93957, 202953, 3983, 363, 166378, 3526, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4733449, 97942, 207017, 4114, 363, 168114, 3629, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4940469, 102058, 211140, 4272, 363, 170394, 3764, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5151612, 106332, 215247, 4428, 363, 172646, 3897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5366862, 110762, 218231, 4542, 363, 174172, 3993, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5585096, 115306, 221588, 4676, 363, 176099, 4109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5806687, 119984, 224436, 4761, 363, 177307, 4174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6031126, 124747, 228827, 4919, 363, 179588, 4306, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6259956, 129668, 232886, 5078, 363, 182015, 4445, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6492845, 134748, 236187, 5212, 363, 183732, 4559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6729035, 139962, 239465, 5334, 363, 185568, 4663, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6968503, 145298, 243458, 5496, 363, 188051, 4807, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7211964, 150796, 247110, 5645, 363, 190046, 4935, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7459077, 156443, 247396, 5634, 363, 189676, 4916, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7706476, 162079, 249957, 5737, 363, 191464, 5010, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7956436, 167818, 250791, 5786, 363, 192164, 5057, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[8207254, 173608, 351, 7, 130, "Text"],
Cell[8207608, 173617, 76, 0, 59, "BulletedList"],
Cell[8207687, 173619, 119, 3, 59, "BulletedList"],
Cell[8207809, 173624, 202, 4, 88, "BulletedList"],
Cell[8208014, 173630, 76, 0, 59, "BulletedList"],
Cell[8208093, 173632, 322, 6, 117, "BulletedList"],
Cell[8208418, 173640, 124, 3, 59, "BulletedList"],
Cell[8208545, 173645, 114, 3, 64, "MathCaption"],
Cell[8208662, 173650, 313, 7, 125, "Input"],
Cell[8208978, 173659, 98, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8209101, 173666, 119, 3, 57, "Input"],
Cell[8209223, 173671, 951, 16, 261, "Output"]
}, Open  ]],
Cell[8210189, 173690, 73, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8210287, 173694, 134, 3, 57, "Input"],
Cell[8210424, 173699, 23829, 557, 279, 4369, 312, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8234268, 174259, 69, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8234362, 174263, 98, 2, 57, "Input"],
Cell[8234463, 174267, 16988, 440, 279, 3833, 272, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8251466, 174710, 187, 6, 64, "MathCaption"],
Cell[8251656, 174718, 80, 2, 57, "Input"],
Cell[8251739, 174722, 77, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8251841, 174726, 209, 5, 57, "Input"],
Cell[8252053, 174733, 94, 2, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8252184, 174740, 96, 2, 57, "Input"],
Cell[8252283, 174744, 78, 2, 57, "Output"]
}, Open  ]],
Cell[8252376, 174749, 38, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8252439, 174753, 69, 2, 57, "Input"],
Cell[8252511, 174757, 77, 2, 57, "Output"]
}, Open  ]],
Cell[8252603, 174762, 371, 10, 96, "Text"],
Cell[8252977, 174774, 227, 5, 97, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8253241, 174784, 1823, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[8255067, 174834, 136, 3, 96, "Text"],
Cell[8255206, 174839, 558, 12, 197, "Text"],
Cell[8255767, 174853, 349, 6, 162, "Text"],
Cell[8256119, 174861, 178822, 3322, 916, 30220, 1482, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8434944, 178185, 266, 6, 97, "Text"],
Cell[8435213, 178193, 83433, 1934, 569, 33472, 1313, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8518683, 180132, 1823, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[8520509, 180182, 339, 6, 129, "Text"],
Cell[8520851, 180190, 232, 5, 97, "Text"],
Cell[8521086, 180197, 145, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8521256, 180204, 254, 6, 91, "Input"],
Cell[8521513, 180212, 325, 9, 57, "Output"]
}, Open  ]],
Cell[8521853, 180224, 62, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8521940, 180228, 71, 2, 57, "Input"],
Cell[8522014, 180232, 5898, 100, 795, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8527961, 180338, 1823, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[8529787, 180388, 98, 3, 63, "Text"],
Cell[8529888, 180393, 53, 0, 64, "MathCaption"],
Cell[8529944, 180395, 101, 2, 57, "Input"],
Cell[8530048, 180399, 59, 2, 63, "Text"],
Cell[8530110, 180403, 358, 9, 42, "DisplayFormula"],
Cell[8530471, 180414, 256, 9, 65, "Text"],
Cell[8530730, 180425, 215, 6, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8530970, 180435, 149, 4, 57, "Input"],
Cell[8531122, 180441, 325, 9, 57, "Output"]
}, Open  ]],
Cell[8531462, 180453, 134, 3, 63, "Text"],
Cell[8531599, 180458, 189, 5, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8531813, 180467, 95, 2, 57, "Input"],
Cell[8531911, 180471, 708, 10, 159, "Output"]
}, Open  ]],
Cell[8532634, 180484, 103, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8532762, 180491, 110, 2, 57, "Input"],
Cell[8532875, 180495, 655, 10, 159, "Output"]
}, Open  ]],
Cell[8533545, 180508, 116, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8533686, 180515, 319, 7, 125, "Input"],
Cell[8534008, 180524, 15394, 398, 279, 3493, 246, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8549417, 180925, 247, 6, 97, "Text"],
Cell[8549667, 180933, 125, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8549817, 180940, 157, 3, 91, "Input"],
Cell[8549977, 180945, 91, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8550117, 180953, 1823, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[8551943, 181003, 110, 3, 63, "Text"],
Cell[8552056, 181008, 76, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8552157, 181012, 256, 6, 91, "Input"],
Cell[8552416, 181020, 354, 11, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8552807, 181036, 149, 4, 57, "Input"],
Cell[8552959, 181042, 354, 11, 57, "Output"]
}, Open  ]],
Cell[8553328, 181056, 152, 4, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[8553505, 181064, 162, 3, 57, "Input"],
Cell[8553670, 181069, 83, 2, 57, "Output"]
}, Open  ]],
Cell[8553768, 181074, 200, 4, 86, "MathCaption"],

Cell[CellGroupData[{
Cell[8553993, 181082, 510, 11, 159, "Input"],
Cell[8554506, 181095, 1890566, 100398, 279, 1876628, 100221, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[10445087, 281496, 125, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[10445237, 281503, 182, 4, 91, "Input"],
Cell[10445422, 281509, 91, 2, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10445562, 281517, 1798, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[10447363, 281567, 155, 4, 64, "Text"],
Cell[10447521, 281573, 183, 4, 96, "Text"],
Cell[10447707, 281579, 181, 4, 96, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10447925, 281588, 1790, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[10449718, 281638, 136, 3, 96, "Text"],
Cell[10449857, 281643, 151, 3, 64, "MathCaption"],
Cell[10450011, 281648, 98, 2, 57, "Input"],
Cell[10450112, 281652, 129, 5, 64, "MathCaption"],
Cell[10450244, 281659, 74, 2, 57, "Input"],
Cell[10450321, 281663, 212, 6, 97, "Text"],
Cell[10450536, 281671, 96, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[10450657, 281678, 84, 2, 57, "Input"],
Cell[10450744, 281682, 1094, 18, 465, "Output"]
}, Open  ]],
Cell[10451853, 281703, 128, 3, 63, "Text"],
Cell[10451984, 281708, 83, 1, 64, "MathCaption"],
Cell[10452070, 281711, 144, 4, 57, "Input"],
Cell[10452217, 281717, 99, 3, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[10452341, 281724, 235, 6, 91, "Input"],
Cell[10452579, 281732, 328743, 4252, 444, 61687, 950, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[10781337, 285987, 358, 8, 130, "Text"],
Cell[10781698, 285997, 85, 1, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[10781808, 286002, 98, 2, 57, "Input"],
Cell[10781909, 286006, 89, 2, 57, "Output"]
}, Open  ]],
Cell[10782013, 286011, 324, 6, 129, "Text"],
Cell[10782340, 286019, 175, 4, 64, "MathCaption"],
Cell[10782518, 286025, 226, 5, 91, "Input"],
Cell[10782747, 286032, 65, 0, 64, "MathCaption"],
Cell[10782815, 286034, 72, 2, 57, "Input"],

Cell[CellGroupData[{
Cell[10782912, 286040, 141, 3, 57, "Input"],
Cell[10783056, 286045, 983968, 22662, 363, 767047, 19979, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11767039, 308710, 56, 0, 64, "MathCaption"],
Cell[11767098, 308712, 178, 4, 58, "Input"],
Cell[11767279, 308718, 103, 3, 64, "MathCaption"],
Cell[11767385, 308723, 158, 4, 57, "Input"],

Cell[CellGroupData[{
Cell[11767568, 308731, 190, 4, 91, "Input"],
Cell[11767761, 308737, 161, 3, 57, "Output"]
}, Open  ]],
Cell[11767937, 308743, 62, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[11768024, 308747, 508, 10, 227, "Input"],
Cell[11768535, 308759, 57029, 1287, 444, 8405, 681, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11825613, 310052, 1795, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[11827411, 310102, 524, 14, 165, "Text"],
Cell[11827938, 310118, 128, 3, 63, "Text"],
Cell[11828069, 310123, 59, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[11828153, 310127, 77, 2, 57, "Input"],
Cell[11828233, 310131, 44483, 1214, 27865, "Print"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11872765, 311351, 1789, 48, 75, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[11874557, 311401, 226, 6, 49, "Text"],
Cell[11874786, 311409, 127, 3, 64, "MathCaption"],
Cell[11874916, 311414, 80, 2, 42, "Input"],
Cell[11874999, 311418, 61, 0, 64, "MathCaption"],
Cell[11875063, 311420, 105, 2, 42, "Input"],
Cell[11875171, 311424, 163, 4, 48, "Text"],
Cell[11875337, 311430, 88, 1, 64, "MathCaption",
  CellTags->"M185A.1.2"],

Cell[CellGroupData[{
Cell[11875450, 311435, 110, 2, 42, "Input"],
Cell[11875563, 311439, 4143466, 56561, 588, 2934666, 41632, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16019032, 368002, 205, 4, 35, "Print"],
Cell[16019240, 368008, 209, 4, 35, "Print"],
Cell[16019452, 368014, 193, 4, 35, "Print"],
Cell[16019648, 368020, 199, 4, 35, "Print"],
Cell[16019850, 368026, 41247, 1289, 279, 16736, 981, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16061100, 369317, 207, 4, 35, "Print"],
Cell[16061310, 369323, 207, 4, 35, "Print"],
Cell[16061520, 369329, 213, 4, 35, "Print"],
Cell[16061736, 369335, 243, 5, 35, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16062028, 369346, 1787, 48, 75, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[16063818, 369396, 164, 5, 49, "Text"],
Cell[16063985, 369403, 571541, 7060, 1164, 571405, 7055, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[16635563, 376468, 1787, 48, 75, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[16637353, 376518, 1375, 43, 238, "Text",
  CellTags->"b:2.5"],
Cell[16638731, 376563, 208, 6, 49, "Text",
  CellTags->"b:2.5"],
Cell[16638942, 376571, 1976, 49, 619, "Text"],
Cell[16640921, 376622, 90, 3, 48, "Text"],
Cell[16641014, 376627, 666, 17, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16641717, 376649, 1781, 48, 75, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[16643501, 376699, 237, 5, 76, "Text"],
Cell[16643741, 376706, 405, 10, 77, "Text"],
Cell[16644149, 376718, 101, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[16644275, 376724, 429, 7, 94, "Input"],
Cell[16644707, 376733, 220550, 7500, 612, 90629, 5892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16865260, 384235, 6661, 143, 117, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16871958, 384383, 633, 10, 120, "Input"],
Cell[16872594, 384395, 142919, 5386, 612, 83396, 4646, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17015516, 389783, 6974, 148, 190, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17022539, 389937, 1791, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[17024333, 389987, 364, 10, 96, "Text"],
Cell[17024700, 389999, 235, 7, 63, "Text"],
Cell[17024938, 390008, 75, 0, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[17025038, 390012, 152, 3, 91, "Input"],
Cell[17025193, 390017, 2483, 111, 2278, "Print"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17027725, 390134, 1805, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[17029533, 390184, 314, 8, 98, "Text"],
Cell[17029850, 390194, 169, 4, 64, "MathCaption"],

Cell[CellGroupData[{
Cell[17030044, 390202, 1021, 18, 329, "Input"],

Cell[CellGroupData[{
Cell[17031090, 390224, 34131, 820, 218, 6937, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17065224, 391046, 34673, 826, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17099900, 391874, 36084, 844, 218, 6946, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17135987, 392720, 37674, 863, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17173664, 393585, 38487, 873, 218, 6944, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17212154, 394460, 38922, 879, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17251079, 395341, 37041, 856, 218, 6927, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17288123, 396199, 38918, 879, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17327044, 397080, 38459, 873, 218, 6944, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17365506, 397955, 37650, 863, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17403159, 398820, 36116, 844, 218, 6946, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17439278, 399666, 34677, 826, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17473958, 400494, 34285, 822, 218, 6929, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17508246, 401318, 34681, 826, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17542930, 402146, 36072, 844, 218, 6946, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17579005, 402992, 37609, 862, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17616617, 403856, 38439, 873, 218, 6944, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17655059, 404731, 38926, 879, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17693988, 405612, 37008, 855, 218, 6927, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17730999, 406469, 38893, 878, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17769895, 407349, 38479, 873, 218, 6944, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17808377, 408224, 37553, 862, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17845933, 409088, 36051, 843, 218, 6946, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17881987, 409933, 34706, 827, 218, 6949, 479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17916696, 410762, 34357, 822, 218, 6937, 479, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17951114, 411591, 1815, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[17952932, 411641, 1111, 33, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17954080, 411679, 1787, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[17955870, 411729, 527, 12, 164, "Text"],
Cell[17956400, 411743, 110, 3, 59, "BulletedList"],
Cell[17956513, 411748, 137, 3, 59, "BulletedList"],
Cell[17956653, 411753, 127, 3, 59, "BulletedList"],
Cell[17956783, 411758, 113, 3, 59, "BulletedList"],
Cell[17956899, 411763, 143, 3, 88, "BulletedList"],
Cell[17957045, 411768, 256, 6, 89, "BulletedList"],
Cell[17957304, 411776, 107, 3, 59, "BulletedList"],
Cell[17957414, 411781, 171, 5, 60, "BulletedList"],
Cell[17957588, 411788, 16, 0, 63, "Text"],
Cell[17957607, 411790, 423, 11, 132, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

